(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  10695232,     261427]*)
(*NotebookOutlinePosition[  10698045,     261506]*)
(*  CellTagsIndexPosition[  10697775,     261494]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["NDSolve", "Section"],

Cell[TextData[{
  "One clear advantage of the new modular framework is that it is possible to \
add new methods much more easily.  By default, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses a method which automatically switches between a stiff and non-stiff \
solver as needed, but you can choose a method which may be appropriate or \
more efficient for a particular problem by using the ",
  StyleBox["Method", "MR"],
  " option to NDSolve."
}], "Text"],

Cell[TextData[{
  "\[FilledSmallSquare] Possible explicit settings for the ",
  StyleBox["Method", "MR"],
  " option include:  "
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"Adams\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"predictor\[Hyphen]corrector Adams method \
with orders 1 through 12 "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"BDF\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"implicit backward differentiation \
formulas with orders 1 through 5 "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"ExplicitRungeKutta\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"adaptive embedded pairs of 2(1) through \
9(8) Runge\[Hyphen]Kutta methods "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"ImplicitRungeKutta\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"families of arbitrary\[Hyphen]order \
implicit Runge\[Hyphen]Kutta methods "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    
                    StyleBox["\<\"\\\"SymplecticPartitionedRungeKutta\\\"\"\>\
",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"interleaved Runge\[Hyphen]Kutta methods \
for separable Hamiltonian systems "\)]]}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "2ColumnTable",
  CellTags->{"NDSolve", "S0.1634"}],

Cell[TextData[{
  "\[FilledSmallSquare] With ",
  StyleBox["Method->", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula"],
  StyleBox["\"", "MR"],
  StyleBox["controller", "TI"],
  StyleBox["\",", "MR"],
  " ",
  StyleBox["Method->\"", "MR"],
  StyleBox["submethod", "TI"],
  StyleBox["\"", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula"],
  " or ",
  StyleBox["Method->", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula"],
  StyleBox["\"", "MR"],
  StyleBox["controller", "TI"],
  StyleBox["\",", "MR"],
  " ",
  StyleBox["Method->", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\<\"m\"\>",
            "TI"], "1"], TraditionalForm]], "InlineFormula"],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\<\"m\"\>",
            "TI"], "2"], TraditionalForm]], "InlineFormula"],
  StyleBox[",", "MR"],
  " \[Ellipsis] ",
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula"],
  " possible controller methods include: "
}], "Notes",
  CellTags->{"S0.1634", "NDSolve"}],

Cell[BoxData[
    FormBox[GridBox[{
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"Composition\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"compose a list of submethods "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"DoubleStep\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"adapt step size by the \
double\[Hyphen]step method "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"Extrapolation\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"adapt order and step size using \
polynomial extrapolation "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"FixedStep\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"use a constant step size "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"OrthogonalProjection\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"project solutions to fulfill orthogonal \
constraints "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"Projection\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"project solutions to fulfill general \
constraints "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"Splitting\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"split equations and use different \
submethods "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"StiffnessSwitching\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"switch from explicit to implicit methods \
if stiffness is detected "\)]]}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "2ColumnTable",
  CellTags->{"NDSolve", "S0.1634"}],

Cell["\<\
\[FilledSmallSquare] Methods used mainly as submethods include: \
\>", "Notes",
  CellTags->{"S0.1634", "NDSolve"}],

Cell[BoxData[
    FormBox[GridBox[{
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"ExplicitEuler\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"forward Euler method "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"ExplicitMidpoint\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"midpoint rule method "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"ExplicitModifiedMidpoint\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"midpoint rule method with Gragg smoothing \
"\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"LinearlyImplicitEuler\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"linearly implicit Euler method "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"LinearlyImplicitMidpoint\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"linearly implicit midpoint rule method \
"\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    
                    StyleBox["\<\"\\\"LinearlyImplicitModifiedMidpoint\\\"\"\>\
",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"linearly implicit Bader\[Hyphen]smoothed \
midpoint rule method "\)]]},
          {Cell[BoxData[
                FormBox[
                  RowBox[{
                    StyleBox["\<\"\\\"LocallyExact\\\"\"\>",
                      "MR"], "\<\" \"\>"}], TraditionalForm]]], Cell[BoxData[
                \(TraditionalForm\`"numerical approximation to locally exact \
symbolic solution "\)]]}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "2ColumnTable",
  CellTags->{"NDSolve", "S0.1634"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell["\<\
Another useful aspect of the flexibility comes from the separation of the \
solution phase from the equation processing phase.  This is best demonstrated \
by an example.\
\>", "Text"],

Cell["\<\
This loads a package which uses J/Link for plotting solutions of PDEs.  \
\>", "MathCaption"],

Cell[BoxData[
    \(\(Needs["\<PDEPlot`\>"];\)\)], "Input",
  CellLabel->"In[12]:="],

Cell["This shows a nonlinear equation.", "MathCaption"],

Cell[BoxData[{\(L\  = \ 50;\), "\[IndentingNewLine]", 
    StyleBox[\(nn\  = \ Automatic;\),
      FontColor->RGBColor[0, 1, 
      0]], "\[IndentingNewLine]", \(background[t_]\  := \ 
        3\ Sin[Sqrt[5/6]\ t]^2/\((2\  + \ 
                3\ Cos[Sqrt[5/6]\ t]^2)\);\), "\[IndentingNewLine]", \(uu[t, 
          x]\  = \ u[t, x]\  + \ background[t];\), "\[IndentingNewLine]", 
    RowBox[{"sol", " ", "=", " ", 
      RowBox[{"NDSolvePlot", "[", 
        RowBox[{\({D[uu[t, x], t, t]\  \[Equal] \ 
              D[uu[t, x], x, 
                  x]\  + \ \((1\  - \ uu[t, x]^2)\) \((1\  + \ 
                      8/3\ uu[t, x])\), \ \ u[0, x]\  \[Equal] \ 
              Exp[\(-x^2\)], \ \(\(Derivative[1, 0]\)[u]\)[0, x]\  \[Equal] \ 
              0, u[t, \ \(-L\)]\  \[Equal] \ u[t, L]}\), ",", " ", "u", ",", 
          " ", \({t, \ 0, L}\), ",", \({x, \(-L\), L}\), ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Method", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"\"\<MethodOfLines\>\"", ",", " ", 
                RowBox[{"\"\<SpatialDiscretization\>\"", "\[Rule]", 
                  RowBox[{"{", 
                    RowBox[{"\"\<TensorProductGrid\>\"", ",", " ", 
                      RowBox[{"\"\<MinPoints\>\"", "\[Rule]", 
                        StyleBox["nn",
                          FontColor->RGBColor[0, 1, 0]]}], ",", " ", 
                      RowBox[{"MaxPoints", "\[Rule]", 
                        StyleBox["nn",
                          FontColor->RGBColor[0, 1, 0]]}], ",", 
                      
                      StyleBox[\("\<DifferenceOrder\>" -> \
"\<Pseudospectral\>"\),
                        FontColor->RGBColor[0, 0, 1]]}], "}"}]}]}], "}"}]}], 
          ",", "\[IndentingNewLine]", " ", \(Frames \[Rule] 100\), ",", 
          " ", \(PlotRange \[Rule] {{\(-L\), L}, {\(-4\), 4}}\)}], 
        "]"}]}]}], "Input",
  CellLabel->"In[47]:="],

Cell[TextData[{
  "The NDSolvePlot program works by using a function ",
  StyleBox["NDSolve`ProcessEquations", "MR"],
  " which gives an ",
  StyleBox["NDSolve`StateData", "MR"],
  " object containing all of the information needed to compute the solution \
of the PDE.  Using the command ",
  StyleBox["NDSolve`Iterate", "MR"],
  ", the program advances the solution to times at regular intervals and \
plots the solution before continuing further."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell["Here is a density plot of the solution.", "MathCaption"],

Cell[BoxData[
    \(\(DensityPlot[
        Evaluate[First[u[\(-t\), x]\  /. \ sol]], \ \ {x, \(-L\), L}, {t, 
          0, \(-L\)}, \ PlotPoints \[Rule] 200, \ Mesh \[Rule] False, \ 
        AspectRatio \[Rule] 1/2];\)\)], "Input",
  CellLabel->"In[23]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell["\<\
NDSolve is now also able to solve 1 + n dimensional initial value problems. \
\
\>", "Text"],

Cell["\<\
Here are equations which models the formation of folds in the brain.\
\>", "MathCaption"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"eqs", "=", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                
                FractionBox[\(\[PartialD]\(\[Psi](t, x, 
                      y)\)\), \(\[PartialD]t\),
                  MultilineFunction->None], "\[Equal]", 
                RowBox[{
                  
                  FractionBox[\(\[PartialD]\^2\( \[Psi](t, x, 
                        y)\)\), \(\[PartialD]x\[ThinSpace]\[PartialD]x\),
                    MultilineFunction->None], "+", 
                  
                  FractionBox[\(\[PartialD]\^2\( \[Psi](t, x, 
                        y)\)\), \(\[PartialD]y\[ThinSpace]\[PartialD]y\),
                    MultilineFunction->None], 
                  "+", \(\[Gamma]\ \((\(-\(1\/3\)\)\ \(\[Psi](t, x, y)\)\^3 + \
\[Psi](t, x, y) + \[Eta](t, x, y))\)\)}]}], ",", 
              RowBox[{
                
                FractionBox[\(\[PartialD]\(\[Eta](t, x, 
                      y)\)\), \(\[PartialD]t\),
                  MultilineFunction->None], "\[Equal]", 
                RowBox[{
                  RowBox[{"\[Delta]", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        
                        FractionBox[\(\[PartialD]\^2\( \[Eta](t, x, 
                              y)\)\), \
\(\[PartialD]x\[ThinSpace]\[PartialD]x\),
                          MultilineFunction->None], "+", 
                        
                        FractionBox[\(\[PartialD]\^2\( \[Eta](t, x, 
                              y)\)\), \
\(\[PartialD]y\[ThinSpace]\[PartialD]y\),
                          MultilineFunction->None]}], ")"}]}], 
                  "-", \(\(\[Nu] + \[Beta]\ \(\[Eta](t, x, y)\) + \[Psi](t, 
                          x, y)\)\/\[Gamma]\)}]}]}], "}"}]}], ";"}], 
      TraditionalForm]], "Input",
  CellLabel->"In[26]:="],

Cell["\<\
This defines a function which gives an effectively random intial condition.\
\>", "MathCaption"],

Cell[BoxData[
    \(\[DoubleStruckR]\[DoubleStruckI]\[DoubleStruckC][
        n_] := \((Function @@ {#1} &)\)[\[Sum]\+\(i = 0\)\%n\(\[Sum]\+\(j = 0\
\)\%n Random[Real, {\(-1\), 1}]\ Cos[i\ #1 + 2\ \[Pi]\ Random[]]\ Cos[
                j\ #2 + 2\ \[Pi]\ Random[]]\)]\)], "Input",
  CellLabel->"In[25]:="],

Cell["This solves the system", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(L = 200; T = 100; \), "\n", 
    \(\[Gamma] = 2; \[Beta] = 1; \[Nu] = 0.1; \[Delta] = 20; 
    nx\  = \ \(ny\  = \ 120\);\), "\n", 
    \(Timing[
      ndsol = NDSolve[
          Flatten[{eqs, \[Psi][0, x, 
                  y] \[Equal] \(\[DoubleStruckR]\[DoubleStruckI]\
\[DoubleStruckC][8]\)[x\/L, y\/L], \[Eta][0, x, 
                  y] \[Equal] \(\[DoubleStruckR]\[DoubleStruckI]\
\[DoubleStruckC][8]\)[x\/L, y\/L], \[Psi][t, \(-L\), y] \[Equal] \[Psi][
                  t, \(+L\), y], \[Psi][t, x, \(-L\)] \[Equal] \[Psi][t, 
                  x, \(+L\)], \[Eta][t, \(-L\), y] \[Equal] \[Eta][t, \(+L\), 
                  y], \[Eta][t, x, \(-L\)] \[Equal] \[Eta][t, 
                  x, \(+L\)]}], {\[Psi], \[Eta]}, {t, T, T}, {x, \(-L\), 
            L}, {y, \(-L\), L}, 
          Method \[Rule] {"\<MethodOfLines\>", "\<SpatialDiscretization\>" \
\[Rule] {"\<TensorProductGrid\>", "\<DifferenceOrder\>" \[Rule] 
                    2, \ "\<MinPoints\>" \[Rule] {nx, ny}, \ 
                  MaxPoints \[Rule] {nx, ny}}}]]\)}], "Input",
  CellLabel->"In[27]:=",
  Evaluatable->False],

Cell[BoxData[
    RowBox[{\(NDSolve::"ibcinc"\), \(\(:\)\(\ \)\), "\<\"Warning: Boundary \
and initial conditions are inconsistent. \\!\\(\\*ButtonBox[\\\"More\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"NDSolve::ibcinc\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[27]:="],

Cell[BoxData[
    RowBox[{\(NDSolve::"eerri"\), \(\(:\)\(\ \)\), "\<\"Warning: Estimated \
initial error on the specified spatial grid in the direction of independent \
variable \\!\\(x\\) exceeds prescribed error tolerance. \\!\\(\\*ButtonBox[\\\
\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"NDSolve::eerri\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[27]:="],

Cell[BoxData[
    RowBox[{\(NDSolve::"eerri"\), \(\(:\)\(\ \)\), "\<\"Warning: Estimated \
initial error on the specified spatial grid in the direction of independent \
variable \\!\\(y\\) exceeds prescribed error tolerance. \\!\\(\\*ButtonBox[\\\
\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"NDSolve::eerri\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[27]:="],

Cell[BoxData[
    RowBox[{\(NDSolve::"eerr"\), \(\(:\)\(\ \)\), "\<\"Warning: Scaled local \
spatial error estimate of \\!\\(2219.452871600264`\\) at \\!\\(t\\) = \
\\!\\(100.`\\) in the direction of independent variable \\!\\(x\\) is much \
greater than prescribed error tolerance. Grid spacing with \\!\\(120\\) \
points may be too large to achieve the desired accuracy or precision.  A \
singularity may have formed or you may want to specify a smaller grid spacing \
using the MaxStepSize or MinPoints options. \\!\\(\\*ButtonBox[\\\"More\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"NDSolve::eerr\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[27]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(311.228`\ Second\), ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"\[Psi]", "\[Rule]", 
                
                TagBox[\(InterpolatingFunction[{{100.`, 
                        100.`}, {"...", \(-200.`\), 200.`, 
                        "..."}, {"...", \(-200.`\), 200.`, "..."}}, "<>"]\),
                  False,
                  Editable->False]}], ",", 
              RowBox[{"\[Eta]", "\[Rule]", 
                
                TagBox[\(InterpolatingFunction[{{100.`, 
                        100.`}, {"...", \(-200.`\), 200.`, 
                        "..."}, {"...", \(-200.`\), 200.`, "..."}}, "<>"]\),
                  False,
                  Editable->False]}]}], "}"}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[29]="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell["Here is a stylized plot of the solution surface", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[CapitalPsi]\  = \ 
        First[\[Psi]\  /. \ ndsol];\)\), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Evaluate[
          Sign[\[CapitalPsi][T, x, y]]*
            Abs[\[CapitalPsi][T, x, y]]^\((1/20)\)], {x, \(-L\), 
          L}, {y, \(-L\), L}, PlotRange \[Rule] All, 
        PlotPoints \[Rule] 3 {nx, ny}, Mesh \[Rule] False];\)\)}], "Input",
  CellLabel->"In[45]:=",
  Evaluatable->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -24 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -15.8219 -9 ]
[.50253 .05935 2.17811 0 ]
[.68156 -0.01098 -14.8837 -9 ]
[.68156 -0.01098 3.11632 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 24 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 24 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 18 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 18 3.14607 ]
[.02345 .26929 -12 -2.74584 ]
[.02345 .26929 0 6.25416 ]
[.01535 .32005 -24 -2.78878 ]
[.01535 .32005 0 6.21122 ]
[.00698 .37252 -6 -2.83329 ]
[.00698 .37252 0 6.16671 ]
[-0.00168 .42678 -18 -2.87948 ]
[-0.00168 .42678 0 6.12052 ]
[-0.01064 .48291 -6 -2.92744 ]
[-0.01064 .48291 0 6.07256 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-200)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-100)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(100)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(200)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-200)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-100)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(100)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(200)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03567 .26452 m
.04179 .26214 L
s
[(-1)] .02345 .26929 1 -0.38981 Mshowa
.02761 .31539 m
.03374 .31306 L
s
[(-0.5)] .01535 .32005 1 -0.38027 Mshowa
.01928 .36796 m
.02543 .36569 L
s
[(0)] .00698 .37252 1 -0.37038 Mshowa
.01066 .42233 m
.01684 .42011 L
s
[(0.5)] -0.00168 .42678 1 -0.36011 Mshowa
.00175 .47858 m
.00794 .47642 L
s
[(1)] -0.01064 .48291 1 -0.34946 Mshowa
.125 Mabswid
.03408 .27456 m
.03775 .27314 L
s
.03248 .28467 m
.03615 .28325 L
s
.03087 .29484 m
.03454 .29343 L
s
.02925 .30508 m
.03292 .30368 L
s
.02597 .32577 m
.02965 .32437 L
s
.02431 .33621 m
.028 .33482 L
s
.02265 .34672 m
.02633 .34534 L
s
.02097 .35731 m
.02466 .35594 L
s
.01758 .37869 m
.02127 .37733 L
s
.01587 .38949 m
.01957 .38814 L
s
.01415 .40036 m
.01784 .39902 L
s
.01241 .41131 m
.01611 .40997 L
s
.00891 .43343 m
.01261 .4321 L
s
.00714 .4446 m
.01084 .44328 L
s
.00535 .45585 m
.00906 .45454 L
s
.00356 .46718 m
.00727 .46587 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.36 .261 .605 r
.39748 .7958 .39817 .80264 .39965 .8029 .39886 .79908 Mtetra
.454 .377 .681 r
.39886 .79908 .39965 .8029 .40116 .80239 .40031 .8003 Mtetra
.509 .496 .778 r
.40031 .8003 .40116 .80239 .40269 .80143 .40179 .80069 Mtetra
.611 .751 .944 r
.40179 .80069 .40269 .80143 .4042 .80088 .40329 .80041 Mtetra
.683 .841 .959 r
.40329 .80041 .4042 .80088 .40571 .80032 .40481 .79984 Mtetra
.722 .841 .938 r
.40481 .79984 .40571 .80032 .40723 .7998 .40633 .79913 Mtetra
.582 .761 .964 r
.40633 .79913 .40723 .7998 .40874 .79946 .40783 .7989 Mtetra
.605 .802 .975 r
.40783 .7989 .40874 .79946 .41024 .79917 .40934 .79858 Mtetra
.699 .809 .934 r
.40934 .79858 .41024 .79917 .41175 .7989 .41086 .79797 Mtetra
.827 .743 .772 r
.41086 .79797 .41175 .7989 .41326 .79857 .41242 .79607 Mtetra
.779 .619 .683 r
.41242 .79607 .41326 .79857 .41477 .79825 .41401 .7932 Mtetra
.749 .558 .636 r
.41401 .7932 .41477 .79825 .41628 .79795 .41565 .78878 Mtetra
.631 .448 .617 r
.41565 .78878 .41628 .79795 .41779 .79773 .4172 .78708 Mtetra
.559 .389 .606 r
.4172 .78708 .41779 .79773 .4193 .79753 .41868 .7877 Mtetra
.528 .368 .607 r
.41868 .7877 .4193 .79753 .42082 .79731 .42014 .78913 Mtetra
.531 .378 .618 r
.42014 .78913 .42082 .79731 .42233 .797 .42161 .79028 Mtetra
.537 .392 .631 r
.42161 .79028 .42233 .797 .42385 .79666 .42309 .79113 Mtetra
.55 .413 .647 r
.42309 .79113 .42385 .79666 .42537 .79631 .42459 .79165 Mtetra
.541 .419 .663 r
.42459 .79165 .42537 .79631 .42688 .79639 .42608 .79221 Mtetra
.588 .46 .674 r
.42608 .79221 .42688 .79639 .42839 .79618 .42759 .79214 Mtetra
.652 .506 .671 r
.42759 .79214 .42839 .79618 .42993 .79532 .42913 .79109 Mtetra
.82 .612 .622 r
.42913 .79109 .42993 .79532 .43155 .791 .43084 .78339 Mtetra
.93 .677 .534 r
.43084 .78339 .43155 .791 .43784 .60305 .43708 .59924 Mtetra
.77 .583 .645 r
.43708 .59924 .43784 .60305 .43945 .59612 .43862 .59516 Mtetra
.774 .732 .814 r
.43862 .59516 .43945 .59612 .44092 .59465 .44008 .594 Mtetra
.671 .781 .932 r
.44008 .594 .44092 .59465 .44236 .59415 .44152 .59353 Mtetra
.578 .766 .968 r
.44152 .59353 .44236 .59415 .4438 .59403 .44296 .59331 Mtetra
.746 .776 .878 r
.44296 .59331 .4438 .59403 .44525 .59331 .44442 .59249 Mtetra
.724 .751 .874 r
.44442 .59249 .44525 .59331 .4467 .59276 .44587 .59177 Mtetra
.629 .689 .888 r
.44587 .59177 .4467 .59276 .44814 .5928 .44732 .59148 Mtetra
0 .196 .726 r
.44732 .59148 .44814 .5928 .44951 .596 .44873 .59289 Mtetra
0 0 .313 r
.44873 .59289 .44951 .596 .4469 .78326 .45007 .59744 Mtetra
0 0 .374 r
.45007 .59744 .4469 .78326 .44829 .78948 .44753 .7828 Mtetra
.304 .224 .597 r
.44753 .7828 .44829 .78948 .4498 .79027 .44897 .78666 Mtetra
.422 .364 .688 r
.44897 .78666 .4498 .79027 .45133 .78993 .45047 .78805 Mtetra
.454 .487 .803 r
.45047 .78805 .45133 .78993 .45287 .78916 .45199 .78862 Mtetra
.475 .764 .994 r
.45199 .78862 .45287 .78916 .45441 .78867 .45352 .78854 Mtetra
.494 .88 .968 r
.45352 .78854 .45441 .78867 .45595 .78825 .45506 .78814 Mtetra
.588 .916 .973 r
.45506 .78814 .45595 .78825 .45749 .78783 .4566 .78758 Mtetra
.565 .879 .992 r
.4566 .78758 .45749 .78783 .45903 .78739 .45814 .78716 Mtetra
.527 .869 .991 r
.45814 .78716 .45903 .78739 .46057 .78696 .45968 .78679 Mtetra
.492 .87 .978 r
.45968 .78679 .46057 .78696 .46211 .78653 .46122 .78642 Mtetra
.23 .739 .885 r
.46122 .78642 .46211 .78653 .46364 .78652 .46276 .7863 Mtetra
.418 .827 .975 r
.46276 .7863 .46364 .78652 .46518 .78636 .4643 .78607 Mtetra
.682 .898 .974 r
.4643 .78607 .46518 .78636 .46673 .7856 .46585 .78542 Mtetra
.909 .87 .788 r
.46585 .78542 .46673 .7856 .46833 .78193 .46742 .7832 Mtetra
.988 .893 .583 r
.46742 .7832 .46833 .78193 .47272 .59493 .46904 .77822 Mtetra
0 0 .369 r
.46904 .77822 .47272 .59493 .47431 .58615 .47338 .59193 Mtetra
0 0 .279 r
.47338 .59193 .47431 .58615 .47579 .58433 .47492 .58639 Mtetra
0 0 .016 r
.47492 .58639 .47579 .58433 .47725 .5838 .47641 .58413 Mtetra
.8 1 .823 r
.47641 .58413 .47725 .5838 .47871 .58372 .47789 .58274 Mtetra
.721 .721 .849 r
.47789 .58274 .47871 .58372 .48018 .58348 .47936 .58198 Mtetra
.646 .618 .807 r
.47936 .58198 .48018 .58348 .48164 .58314 .48083 .58158 Mtetra
.615 .596 .809 r
.48083 .58158 .48164 .58314 .4831 .5828 .48229 .58137 Mtetra
.617 .612 .823 r
.48229 .58137 .4831 .5828 .48457 .58243 .48376 .58113 Mtetra
.623 .634 .841 r
.48376 .58113 .48457 .58243 .48604 .58202 .48522 .58088 Mtetra
.628 .661 .863 r
.48522 .58088 .48604 .58202 .48751 .58157 .48669 .58059 Mtetra
.653 .701 .882 r
.48669 .58059 .48751 .58157 .48898 .58106 .48816 .58019 Mtetra
.676 .734 .894 r
.48816 .58019 .48898 .58106 .49045 .5805 .48963 .5797 Mtetra
.69 .751 .898 r
.48963 .5797 .49045 .5805 .49192 .57996 .4911 .57914 Mtetra
.764 .762 .851 r
.4911 .57914 .49192 .57996 .4934 .57914 .49258 .57816 Mtetra
.743 .727 .837 r
.49258 .57816 .4934 .57914 .49487 .57843 .49406 .57725 Mtetra
.637 .66 .855 r
.49406 .57725 .49487 .57843 .49634 .57828 .49553 .57693 Mtetra
0 0 .444 r
.49553 .57693 .49634 .57828 .49779 .58064 .49698 .57914 Mtetra
.949 .686 .502 r
.49698 .57914 .49779 .58064 .49786 .76727 .497 .76613 Mtetra
.957 .635 .369 r
.497 .76613 .49786 .76727 .49936 .77563 .49849 .77528 Mtetra
.705 .166 0 r
.49849 .77528 .49936 .77563 .50091 .77723 .50004 .77676 Mtetra
.545 .813 .995 r
.50004 .77676 .50091 .77723 .50247 .77716 .5016 .7765 Mtetra
.784 .808 .872 r
.5016 .7765 .50247 .77716 .50404 .77613 .50317 .7754 Mtetra
.87 .781 .761 r
.50317 .7754 .50404 .77613 .50562 .77274 .50475 .77307 Mtetra
.975 .834 .64 r
.50475 .77307 .50562 .77274 .5081 .58705 .50634 .76808 Mtetra
0 0 .379 r
.50634 .76808 .5081 .58705 .50963 .57568 .50879 .58143 Mtetra
0 0 .279 r
.50879 .58143 .50963 .57568 .51112 .57346 .51029 .57569 Mtetra
0 0 .087 r
.51029 .57569 .51112 .57346 .5126 .57284 .51178 .57338 Mtetra
.7 .96 .706 r
.51178 .57338 .5126 .57284 .51408 .57267 .51327 .57192 Mtetra
.75 .778 .876 r
.51327 .57192 .51408 .57267 .51557 .5724 .51476 .57106 Mtetra
.664 .646 .823 r
.51476 .57106 .51557 .5724 .51705 .57196 .51624 .57057 Mtetra
.635 .628 .826 r
.51624 .57057 .51705 .57196 .51854 .57154 .51773 .57025 Mtetra
.645 .645 .836 r
.51773 .57025 .51854 .57154 .52002 .57114 .51921 .56987 Mtetra
.66 .655 .835 r
.51921 .56987 .52002 .57114 .52151 .57074 .5207 .56941 Mtetra
.659 .646 .826 r
.5207 .56941 .52151 .57074 .523 .57035 .52219 .56896 Mtetra
.657 .637 .819 r
.52219 .56896 .523 .57035 .52448 .56991 .52368 .5685 Mtetra
.656 .634 .817 r
.52368 .5685 .52448 .56991 .52597 .56945 .52517 .56805 Mtetra
.655 .636 .818 r
.52517 .56805 .52597 .56945 .52746 .56898 .52666 .5676 Mtetra
.656 .639 .821 r
.52666 .5676 .52746 .56898 .52895 .56852 .52815 .56716 Mtetra
.656 .641 .823 r
.52815 .56716 .52895 .56852 .53045 .56807 .52964 .56671 Mtetra
.656 .642 .825 r
.52964 .56671 .53045 .56807 .53194 .56762 .53113 .56627 Mtetra
.656 .643 .825 r
.53113 .56627 .53194 .56762 .53343 .56716 .53263 .56582 Mtetra
.657 .644 .826 r
.53263 .56582 .53343 .56716 .53492 .56671 .53412 .56538 Mtetra
.656 .646 .827 r
.53412 .56538 .53492 .56671 .53642 .56626 .53562 .56493 Mtetra
.681 .656 .819 r
.53562 .56493 .53642 .56626 .53791 .56559 .53711 .56433 Mtetra
.69 .669 .825 r
.53711 .56433 .53791 .56559 .53941 .56487 .53861 .56369 Mtetra
.634 .66 .858 r
.53861 .56369 .53941 .56487 .54091 .56462 .5401 .56337 Mtetra
.238 .444 .86 r
.5401 .56337 .54091 .56462 .54242 .56618 .54161 .56421 Mtetra
0 0 .34 r
.54161 .56421 .54242 .56618 .544 .58161 .54313 .56765 Mtetra
.973 .705 .462 r
.54313 .56765 .544 .58161 .54661 .76218 .54572 .75315 Mtetra
.302 .208 .579 r
.54572 .75315 .54661 .76218 .54821 .76424 .54734 .75867 Mtetra
.582 .436 .649 r
.54734 .75867 .54821 .76424 .54981 .76408 .54893 .75868 Mtetra
.631 .472 .649 r
.54893 .75868 .54981 .76408 .5514 .76337 .55052 .75771 Mtetra
.63 .469 .646 r
.55052 .75771 .5514 .76337 .55299 .76266 .5521 .75673 Mtetra
.604 .448 .644 r
.5521 .75673 .55299 .76266 .55458 .76223 .5537 .75627 Mtetra
.604 .448 .643 r
.5537 .75627 .55458 .76223 .55618 .76179 .55529 .7558 Mtetra
.603 .447 .643 r
.55529 .7558 .55618 .76179 .55777 .76136 .55688 .75535 Mtetra
.601 .446 .643 r
.55688 .75535 .55777 .76136 .55937 .76095 .55848 .75494 Mtetra
.601 .445 .643 r
.55848 .75494 .55937 .76095 .56096 .76054 .56007 .75455 Mtetra
.6 .445 .643 r
.56007 .75455 .56096 .76054 .56256 .76014 .56167 .75417 Mtetra
.599 .445 .643 r
.56167 .75417 .56256 .76014 .56416 .75975 .56327 .7538 Mtetra
.599 .445 .644 r
.56327 .7538 .56416 .75975 .56576 .75935 .56487 .75344 Mtetra
.6 .446 .644 r
.56487 .75344 .56576 .75935 .56736 .75895 .56647 .75307 Mtetra
.601 .447 .644 r
.56647 .75307 .56736 .75895 .56897 .75855 .56807 .75268 Mtetra
.602 .447 .645 r
.56807 .75268 .56897 .75855 .57057 .75814 .56967 .75228 Mtetra
.602 .448 .645 r
.56967 .75228 .57057 .75814 .57217 .75772 .57127 .75185 Mtetra
.603 .449 .645 r
.57127 .75185 .57217 .75772 .57378 .7573 .57287 .75141 Mtetra
.604 .449 .644 r
.57287 .75141 .57378 .7573 .57538 .75687 .57448 .75096 Mtetra
.613 .455 .644 r
.57448 .75096 .57538 .75687 .57699 .75643 .57608 .75032 Mtetra
.621 .459 .641 r
.57608 .75032 .57699 .75643 .5786 .75597 .57768 .74945 Mtetra
.596 .438 .637 r
.57768 .74945 .5786 .75597 .5802 .75552 .57928 .74912 Mtetra
.529 .391 .638 r
.57928 .74912 .5802 .75552 .58181 .7551 .58091 .75013 Mtetra
.439 .347 .655 r
.58091 .75013 .58181 .7551 .58342 .75472 .58256 .75199 Mtetra
.398 .39 .734 r
.58256 .75199 .58342 .75472 .58504 .75434 .5842 .75323 Mtetra
.372 .564 .91 r
.5842 .75323 .58504 .75434 .58665 .75395 .58583 .7537 Mtetra
.476 .85 .987 r
.58583 .7537 .58665 .75395 .58826 .75353 .58744 .75338 Mtetra
.539 .899 .971 r
.58744 .75338 .58826 .75353 .58988 .7531 .58906 .75288 Mtetra
.557 .891 .985 r
.58906 .75288 .58988 .7531 .59149 .75265 .59067 .75241 Mtetra
.437 .835 .979 r
.59067 .75241 .59149 .75265 .59311 .75218 .59229 .75215 Mtetra
.274 .776 .865 r
.59229 .75215 .59311 .75218 .59472 .75171 .59391 .75188 Mtetra
0 0 0 r
.59391 .75188 .59472 .75171 .59634 .75126 .59553 .75157 Mtetra
.59553 .75157 .59634 .75126 .59796 .75085 .59715 .75118 Mtetra
.59715 .75118 .59796 .75085 .59958 .75045 .59877 .75076 Mtetra
.59877 .75076 .59958 .75045 .6012 .75005 .6004 .75033 Mtetra
.6004 .75033 .6012 .75005 .60282 .74963 .60202 .74991 Mtetra
.60202 .74991 .60282 .74963 .60444 .74921 .60364 .74947 Mtetra
.60364 .74947 .60444 .74921 .60607 .74878 .60526 .74899 Mtetra
.295 .786 .743 r
.60526 .74899 .60607 .74878 .60769 .74837 .60689 .74844 Mtetra
.429 .871 .868 r
.60689 .74844 .60769 .74837 .60932 .74794 .60851 .74787 Mtetra
.453 .873 .935 r
.60851 .74787 .60932 .74794 .61095 .74764 .61014 .74742 Mtetra
.358 .8 .958 r
.61014 .74742 .61095 .74764 .61258 .7476 .61177 .74724 Mtetra
.598 .869 .993 r
.61177 .74724 .61258 .7476 .61421 .74711 .6134 .74678 Mtetra
.824 .904 .895 r
.6134 .74678 .61421 .74711 .61581 .74538 .61501 .7455 Mtetra
.973 .872 .676 r
.61501 .7455 .61581 .74538 .61725 .73786 .61655 .74172 Mtetra
.971 .789 .361 r
.61655 .74172 .61725 .73786 .61384 .54661 .61783 .72777 Mtetra
.048 0 .433 r
.61783 .72777 .61384 .54661 .61529 .54267 .61464 .54671 Mtetra
.484 .214 .429 r
.61464 .54671 .61529 .54267 .61681 .54181 .61617 .54584 Mtetra
.55 .271 .446 r
.61617 .54584 .61681 .54181 .61836 .54155 .61773 .54577 Mtetra
.499 .23 .438 r
.61773 .54577 .61836 .54155 .61991 .54146 .61926 .54503 Mtetra
.201 0 .317 r
.61926 .54503 .61991 .54146 .62145 .54098 .62074 .54225 Mtetra
0 0 0 r
.62074 .54225 .62145 .54098 .62299 .5405 .62224 .54016 Mtetra
.85 .894 .869 r
.62224 .54016 .62299 .5405 .62454 .54004 .62375 .53876 Mtetra
.661 .66 .838 r
.62375 .53876 .62454 .54004 .62608 .5396 .6253 .53829 Mtetra
.618 .636 .846 r
.6253 .53829 .62608 .5396 .62763 .53917 .62685 .53804 Mtetra
.603 .661 .879 r
.62685 .53804 .62763 .53917 .62917 .53871 .6284 .53785 Mtetra
.655 .736 .909 r
.6284 .53785 .62917 .53871 .63072 .53821 .62995 .53742 Mtetra
.667 .758 .918 r
.62995 .53742 .63072 .53821 .63226 .5377 .6315 .53693 Mtetra
.695 .772 .911 r
.6315 .53693 .63226 .5377 .63381 .53715 .63304 .53633 Mtetra
.756 .775 .869 r
.63304 .53633 .63381 .53715 .63535 .53632 .63458 .5354 Mtetra
.703 .738 .879 r
.63458 .5354 .63535 .53632 .6369 .53588 .63612 .53474 Mtetra
.556 .638 .887 r
.63612 .53474 .6369 .53588 .63848 .53638 .63769 .53473 Mtetra
0 .11 .662 r
.63769 .53473 .63848 .53638 .64024 .54192 .63933 .53687 Mtetra
0 0 .324 r
.63933 .53687 .64024 .54192 .64846 .73327 .64119 .54522 Mtetra
.071 0 .452 r
.64119 .54522 .64846 .73327 .65026 .73713 .64928 .73147 Mtetra
.423 .327 .642 r
.64928 .73147 .65026 .73713 .65193 .7373 .65103 .73385 Mtetra
.482 .414 .704 r
.65103 .73385 .65193 .7373 .65358 .7368 .65273 .73484 Mtetra
.511 .516 .798 r
.65273 .73484 .65358 .7368 .65522 .73603 .65441 .73522 Mtetra
.413 .661 .962 r
.65441 .73522 .65522 .73603 .65688 .73597 .65609 .73542 Mtetra
.572 .807 .988 r
.65609 .73542 .65688 .73597 .65854 .7355 .65775 .73511 Mtetra
.771 .9 .932 r
.65775 .73511 .65854 .7355 .66016 .73415 .65939 .73412 Mtetra
.96 .89 .716 r
.65939 .73412 .66016 .73415 .6616 .7281 .66094 .73101 Mtetra
.844 .767 .258 r
.66094 .73101 .6616 .7281 .65576 .53534 .66231 .72322 Mtetra
.068 0 .446 r
.66231 .72322 .65576 .53534 .65714 .53036 .65657 .53431 Mtetra
.172 0 .328 r
.65657 .53431 .65714 .53036 .65868 .52932 .65802 .53096 Mtetra
0 0 .046 r
.65802 .53096 .65868 .52932 .66025 .52892 .65953 .52912 Mtetra
.695 .981 .824 r
.65953 .52912 .66025 .52892 .66183 .52882 .66107 .52795 Mtetra
.699 .751 .892 r
.66107 .52795 .66183 .52882 .66339 .52833 .66263 .52732 Mtetra
.653 .706 .886 r
.66263 .52732 .66339 .52833 .66495 .52786 .66419 .5269 Mtetra
.639 .712 .9 r
.66419 .5269 .66495 .52786 .66652 .52739 .66577 .52654 Mtetra
.757 .77 .864 r
.66577 .52654 .66652 .52739 .66807 .52652 .66731 .52558 Mtetra
.711 .739 .873 r
.66731 .52558 .66807 .52652 .66964 .526 .66887 .52487 Mtetra
.61 .666 .879 r
.66887 .52487 .66964 .526 .67123 .52615 .67045 .52464 Mtetra
0 .195 .722 r
.67045 .52464 .67123 .52615 .67301 .5305 .67212 .52646 Mtetra
0 0 .466 r
.67212 .52646 .67301 .5305 .68319 .72267 .67397 .53226 Mtetra
.087 .008 .461 r
.67397 .53226 .68319 .72267 .6851 .72759 .68406 .72132 Mtetra
.394 .301 .631 r
.68406 .72132 .6851 .72759 .6868 .72784 .68589 .72439 Mtetra
.456 .398 .704 r
.68589 .72439 .6868 .72784 .68847 .72734 .68764 .7256 Mtetra
.49 .529 .824 r
.68764 .7256 .68847 .72734 .69012 .72643 .68935 .72602 Mtetra
.571 .849 .996 r
.68935 .72602 .69012 .72643 .69179 .72594 .69103 .72563 Mtetra
.669 .908 .977 r
.69103 .72563 .69179 .72594 .69346 .72544 .69269 .72494 Mtetra
.729 .87 .947 r
.69269 .72494 .69346 .72544 .69513 .7249 .69435 .72413 Mtetra
.636 .77 .944 r
.69435 .72413 .69513 .7249 .6968 .72432 .69603 .72372 Mtetra
.595 .803 .979 r
.69603 .72372 .6968 .72432 .69847 .72373 .69771 .72337 Mtetra
.525 .849 .998 r
.69771 .72337 .69847 .72373 .70015 .72315 .69939 .72303 Mtetra
.452 .869 .946 r
.69939 .72303 .70015 .72315 .70182 .72263 .70107 .7226 Mtetra
.412 .858 .903 r
.70107 .7226 .70182 .72263 .7035 .72216 .70275 .72213 Mtetra
.43 .868 .905 r
.70275 .72213 .7035 .72216 .70518 .72174 .70443 .72163 Mtetra
.521 .903 .951 r
.70443 .72163 .70518 .72174 .70687 .72142 .70611 .72107 Mtetra
.624 .888 .988 r
.70611 .72107 .70687 .72142 .70856 .72114 .70779 .72051 Mtetra
.659 .819 .961 r
.70779 .72051 .70856 .72114 .71025 .72085 .70947 .71998 Mtetra
.473 .678 .955 r
.70947 .71998 .71025 .72085 .71197 .72099 .71118 .72008 Mtetra
.579 .715 .936 r
.71118 .72008 .71197 .72099 .71367 .72078 .71288 .71989 Mtetra
.739 .773 .88 r
.71288 .71989 .71367 .72078 .71533 .71984 .71455 .71899 Mtetra
.939 .766 .641 r
.71455 .71899 .71533 .71984 .71677 .71478 .71599 .71394 Mtetra
.969 .689 .446 r
.71599 .71394 .71677 .71478 .70786 .52081 .70712 .51993 Mtetra
.944 .751 .611 r
.70712 .51993 .70786 .52081 .70915 .51485 .70842 .51397 Mtetra
.802 .777 .83 r
.70842 .51397 .70915 .51485 .7107 .51352 .70996 .51265 Mtetra
.646 .736 .915 r
.70996 .51265 .7107 .51352 .71229 .51312 .71156 .51224 Mtetra
.53 .689 .94 r
.71156 .51224 .71229 .51312 .71391 .5131 .71317 .51222 Mtetra
.727 .762 .88 r
.71317 .51222 .71391 .5131 .71549 .51231 .71475 .51143 Mtetra
.699 .753 .893 r
.71475 .51143 .71549 .51231 .71707 .51168 .71634 .51079 Mtetra
.532 .687 .938 r
.71634 .51079 .71707 .51168 .71869 .51165 .71796 .51076 Mtetra
.807 .363 0 r
.71796 .51076 .71869 .51165 .72052 .51508 .71978 .51419 Mtetra
.97 .683 .426 r
.71978 .51419 .72052 .51508 .73356 .70823 .73279 .70741 Mtetra
.92 .528 .152 r
.73279 .70741 .73356 .70823 .73564 .7142 .73487 .71338 Mtetra
0 .358 .82 r
.73487 .71338 .73564 .7142 .73743 .71523 .73666 .71444 Mtetra
.6 .754 .952 r
.73666 .71444 .73743 .71523 .73914 .71492 .73837 .71414 Mtetra
.807 .811 .854 r
.73837 .71414 .73914 .71492 .74079 .7136 .74002 .71279 Mtetra
.942 .775 .646 r
.74002 .71279 .74079 .7136 .74225 .70918 .74146 .70799 Mtetra
.971 .688 .437 r
.74146 .70799 .74225 .70918 .73196 .51546 .73113 .51297 Mtetra
.876 .666 .615 r
.73113 .51297 .73196 .51546 .73314 .50811 .73237 .50659 Mtetra
.765 .677 .765 r
.73237 .50659 .73314 .50811 .73467 .50645 .73392 .50513 Mtetra
.631 .646 .847 r
.73392 .50513 .73467 .50645 .73627 .50593 .73553 .5048 Mtetra
.52 .628 .898 r
.73553 .5048 .73627 .50593 .7379 .50582 .73717 .5049 Mtetra
.64 .727 .911 r
.73717 .5049 .7379 .50582 .73952 .50546 .73879 .50452 Mtetra
.67 .732 .897 r
.73879 .50452 .73952 .50546 .74113 .50501 .7404 .50401 Mtetra
.628 .704 .9 r
.7404 .50401 .74113 .50501 .74274 .50457 .74201 .50368 Mtetra
.469 .658 .943 r
.74201 .50368 .74274 .50457 .74433 .50381 .74367 .50382 Mtetra
.502 0 0 r
.74367 .50382 .74433 .50381 .74593 .5032 .74536 .50461 Mtetra
.744 .364 .334 r
.74536 .50461 .74593 .5032 .74757 .50316 .74715 .5067 Mtetra
.966 .676 .427 r
.74715 .5067 .74757 .50316 .74942 .5061 .76145 .69483 Mtetra
.586 .375 .562 r
.76145 .69483 .74942 .5061 .76416 .69884 .76378 .7036 Mtetra
.667 .377 .472 r
.76378 .7036 .76416 .69884 .76637 .70565 .76569 .70592 Mtetra
0 0 0 r
.76569 .70592 .76637 .70565 .76819 .70664 .76741 .70542 Mtetra
.828 .74 .768 r
.76741 .70542 .76819 .70664 .76992 .70626 .76902 .70341 Mtetra
.787 .618 .672 r
.76902 .70341 .76992 .70626 .77161 .70542 .77055 .70022 Mtetra
.681 .509 .647 r
.77055 .70022 .77161 .70542 .77332 .70481 .77215 .69805 Mtetra
.605 .443 .636 r
.77215 .69805 .77332 .70481 .77505 .70435 .77386 .69746 Mtetra
.582 .427 .636 r
.77386 .69746 .77505 .70435 .77677 .70388 .77561 .69743 Mtetra
.592 .437 .64 r
.77561 .69743 .77677 .70388 .77849 .70342 .77735 .69718 Mtetra
.599 .444 .642 r
.77735 .69718 .77849 .70342 .78022 .70298 .77908 .69679 Mtetra
.599 .444 .643 r
.77908 .69679 .78022 .70298 .78195 .70253 .78081 .6964 Mtetra
.6 .445 .644 r
.78081 .6964 .78195 .70253 .78368 .70209 .78254 .696 Mtetra
.6 .446 .644 r
.78254 .696 .78368 .70209 .78541 .70164 .78427 .69559 Mtetra
.601 .447 .645 r
.78427 .69559 .78541 .70164 .78714 .7012 .786 .69518 Mtetra
.786 .69518 .78714 .7012 .78887 .70075 .78774 .69475 Mtetra
.601 .448 .645 r
.78774 .69475 .78887 .70075 .7906 .70031 .78947 .69433 Mtetra
.602 .448 .646 r
.78947 .69433 .7906 .70031 .79234 .69986 .7912 .6939 Mtetra
.7912 .6939 .79234 .69986 .79407 .69941 .79294 .69346 Mtetra
.602 .449 .646 r
.79294 .69346 .79407 .69941 .79581 .69896 .79467 .69302 Mtetra
.79467 .69302 .79581 .69896 .79755 .6985 .79641 .69258 Mtetra
.79641 .69258 .79755 .6985 .79929 .69805 .79815 .69213 Mtetra
.603 .449 .646 r
.79815 .69213 .79929 .69805 .80102 .6976 .79988 .69168 Mtetra
.603 .45 .646 r
.79988 .69168 .80102 .6976 .80276 .69714 .80162 .69123 Mtetra
.80162 .69123 .80276 .69714 .80451 .69669 .80336 .69078 Mtetra
.603 .45 .647 r
.80336 .69078 .80451 .69669 .80625 .69623 .8051 .69032 Mtetra
.8051 .69032 .80625 .69623 .80799 .69577 .80684 .68987 Mtetra
.80684 .68987 .80799 .69577 .80974 .69532 .80859 .68941 Mtetra
.80859 .68941 .80974 .69532 .81148 .69486 .81033 .68895 Mtetra
.81033 .68895 .81148 .69486 .81323 .6944 .81207 .6885 Mtetra
.81207 .6885 .81323 .6944 .81497 .69394 .81382 .68804 Mtetra
.81382 .68804 .81497 .69394 .81672 .69348 .81557 .68758 Mtetra
.81557 .68758 .81672 .69348 .81847 .69302 .81731 .68712 Mtetra
.81731 .68712 .81847 .69302 .82022 .69256 .81906 .68665 Mtetra
.81906 .68665 .82022 .69256 .82197 .6921 .82081 .68619 Mtetra
.82081 .68619 .82197 .6921 .82373 .69164 .82256 .68573 Mtetra
.82256 .68573 .82373 .69164 .82548 .69118 .82431 .68527 Mtetra
.82431 .68527 .82548 .69118 .82723 .69072 .82607 .6848 Mtetra
.82607 .6848 .82723 .69072 .82899 .69025 .82782 .68434 Mtetra
.82782 .68434 .82899 .69025 .83075 .68979 .82958 .68388 Mtetra
.82958 .68388 .83075 .68979 .83251 .68933 .83133 .68341 Mtetra
.83133 .68341 .83251 .68933 .83426 .68887 .83309 .68295 Mtetra
.83309 .68295 .83426 .68887 .83602 .6884 .83485 .68248 Mtetra
.83485 .68248 .83602 .6884 .83778 .68794 .83661 .68202 Mtetra
.83661 .68202 .83778 .68794 .83955 .68748 .83837 .68155 Mtetra
.83837 .68155 .83955 .68748 .84131 .68701 .84013 .68109 Mtetra
.84013 .68109 .84131 .68701 .84307 .68655 .84189 .68062 Mtetra
.84189 .68062 .84307 .68655 .84484 .68608 .84365 .68016 Mtetra
.84365 .68016 .84484 .68608 .84661 .68562 .84542 .67969 Mtetra
.84542 .67969 .84661 .68562 .84837 .68515 .84718 .67923 Mtetra
.84718 .67923 .84837 .68515 .85014 .68469 .84895 .67876 Mtetra
.84895 .67876 .85014 .68469 .85191 .68422 .85072 .67829 Mtetra
.85072 .67829 .85191 .68422 .85368 .68376 .85249 .67782 Mtetra
.85249 .67782 .85368 .68376 .85545 .68329 .85426 .67736 Mtetra
.85426 .67736 .85545 .68329 .85723 .68282 .85603 .67689 Mtetra
.85603 .67689 .85723 .68282 .859 .68236 .8578 .67642 Mtetra
.8578 .67642 .859 .68236 .86078 .68189 .85957 .67595 Mtetra
.85957 .67595 .86078 .68189 .86255 .68142 .86135 .67548 Mtetra
.86135 .67548 .86255 .68142 .86433 .68095 .86312 .67501 Mtetra
.86312 .67501 .86433 .68095 .86611 .68049 .8649 .67454 Mtetra
.8649 .67454 .86611 .68049 .86789 .68002 .86668 .67407 Mtetra
.86668 .67407 .86789 .68002 .86967 .67955 .86845 .6736 Mtetra
.86845 .6736 .86967 .67955 .87145 .67908 .87023 .67313 Mtetra
.87023 .67313 .87145 .67908 .87323 .67861 .87201 .67266 Mtetra
.87201 .67266 .87323 .67861 .87501 .67814 .8738 .67219 Mtetra
.8738 .67219 .87501 .67814 .8768 .67767 .87558 .67171 Mtetra
.87558 .67171 .8768 .67767 .87859 .6772 .87736 .67124 Mtetra
.87736 .67124 .87859 .6772 .88037 .67673 .87915 .67077 Mtetra
.87915 .67077 .88037 .67673 .88216 .67625 .88093 .67029 Mtetra
.88093 .67029 .88216 .67625 .88395 .67578 .88272 .66982 Mtetra
.88272 .66982 .88395 .67578 .88574 .67531 .88451 .66934 Mtetra
.88451 .66934 .88574 .67531 .88753 .67484 .8863 .66886 Mtetra
.8863 .66886 .88753 .67484 .88932 .67436 .88809 .66838 Mtetra
.603 .45 .646 r
.88809 .66838 .88932 .67436 .89112 .67389 .88988 .6679 Mtetra
.88988 .6679 .89112 .67389 .89291 .67341 .89167 .66742 Mtetra
.89167 .66742 .89291 .67341 .89471 .67294 .89346 .66694 Mtetra
.89346 .66694 .89471 .67294 .8965 .67246 .89526 .66646 Mtetra
.89526 .66646 .8965 .67246 .8983 .67199 .89705 .66598 Mtetra
.89705 .66598 .8983 .67199 .9001 .67151 .89885 .6655 Mtetra
.89885 .6655 .9001 .67151 .9019 .67103 .90064 .66502 Mtetra
.90064 .66502 .9019 .67103 .9037 .67056 .90244 .66454 Mtetra
.90244 .66454 .9037 .67056 .9055 .67008 .90424 .66405 Mtetra
.90424 .66405 .9055 .67008 .9073 .6696 .90604 .66357 Mtetra
.603 .449 .646 r
.90604 .66357 .9073 .6696 .90911 .66913 .90784 .66309 Mtetra
.90784 .66309 .90911 .66913 .91091 .66865 .90965 .66261 Mtetra
.90965 .66261 .91091 .66865 .91272 .66817 .91145 .66213 Mtetra
.91145 .66213 .91272 .66817 .91453 .6677 .91326 .66164 Mtetra
.91326 .66164 .91453 .6677 .91634 .66722 .91506 .66116 Mtetra
.91506 .66116 .91634 .66722 .91815 .66674 .91687 .66067 Mtetra
.91687 .66067 .91815 .66674 .91996 .66625 .91868 .66018 Mtetra
.603 .449 .645 r
.91868 .66018 .91996 .66625 .92177 .66577 .92049 .65969 Mtetra
.604 .449 .645 r
.92049 .65969 .92177 .66577 .92358 .66528 .9223 .65919 Mtetra
.9223 .65919 .92358 .66528 .92539 .6648 .92411 .65869 Mtetra
.92411 .65869 .92539 .6648 .92721 .6643 .92592 .65819 Mtetra
.92592 .65819 .92721 .6643 .92902 .66381 .92773 .65768 Mtetra
.92773 .65768 .92902 .66381 .93084 .66331 .92954 .65716 Mtetra
.92954 .65716 .93084 .66331 .93265 .66281 .93135 .65664 Mtetra
.605 .449 .644 r
.93135 .65664 .93265 .66281 .93447 .66231 .93316 .65611 Mtetra
.604 .449 .644 r
.93316 .65611 .93447 .66231 .93629 .66182 .93498 .65559 Mtetra
.603 .448 .644 r
.93498 .65559 .93629 .66182 .93811 .66133 .9368 .65509 Mtetra
.601 .446 .644 r
.9368 .65509 .93811 .66133 .93994 .66086 .93862 .65464 Mtetra
.93862 .65464 .93994 .66086 .94176 .66039 .94045 .6542 Mtetra
.594 .442 .645 r
.94045 .6542 .94176 .66039 .9436 .66 .9423 .65392 Mtetra
.566 .425 .648 r
.9423 .65392 .9436 .66 .94548 .65996 .94422 .65425 Mtetra
.603 .453 .651 r
.94422 .65425 .94548 .65996 .94731 .65948 .94605 .6538 Mtetra
.685 .506 .639 r
.94605 .6538 .94731 .65948 .949 .65789 .94763 .65129 Mtetra
.975 .67 .361 r
.94763 .65129 .949 .65789 .95004 .65091 .92579 .45723 Mtetra
.585 .378 .566 r
.92579 .45723 .95004 .65091 .92763 .45333 .9267 .45011 Mtetra
.761 .59 .665 r
.9267 .45011 .92763 .45333 .92885 .44877 .92813 .44728 Mtetra
.701 .663 .81 r
.92813 .44728 .92885 .44877 .93051 .44778 .92981 .44645 Mtetra
.639 .658 .852 r
.92981 .44645 .93051 .44778 .93224 .44741 .93154 .44605 Mtetra
.606 .636 .855 r
.93154 .44605 .93224 .44741 .93401 .44731 .9333 .44583 Mtetra
.652 .642 .827 r
.9333 .44583 .93401 .44731 .93574 .44683 .93502 .44535 Mtetra
.651 .642 .828 r
.93502 .44535 .93574 .44683 .93746 .44635 .93675 .44487 Mtetra
.651 .641 .827 r
.93675 .44487 .93746 .44635 .93919 .44588 .93847 .44438 Mtetra
.653 .642 .826 r
.93847 .44438 .93919 .44588 .94091 .44538 .9402 .44389 Mtetra
.654 .642 .826 r
.9402 .44389 .94091 .44538 .94264 .44488 .94193 .44339 Mtetra
.655 .642 .826 r
.94193 .44339 .94264 .44488 .94436 .44437 .94365 .44288 Mtetra
.655 .643 .826 r
.94365 .44288 .94436 .44437 .94609 .44386 .94538 .44237 Mtetra
.656 .644 .826 r
.94538 .44237 .94609 .44386 .94782 .44334 .94711 .44185 Mtetra
.657 .644 .826 r
.94711 .44185 .94782 .44334 .94954 .44282 .94883 .44133 Mtetra
.658 .645 .826 r
.94883 .44133 .94954 .44282 .95127 .44228 .95056 .4408 Mtetra
.66 .646 .826 r
.95056 .4408 .95127 .44228 .953 .44174 .95229 .44026 Mtetra
.662 .648 .826 r
.95229 .44026 .953 .44174 .95472 .44119 .95401 .43971 Mtetra
.665 .65 .825 r
.95401 .43971 .95472 .44119 .95645 .44061 .95574 .43914 Mtetra
.666 .651 .826 r
.95574 .43914 .95645 .44061 .95817 .44003 .95746 .43856 Mtetra
.668 .653 .826 r
.95746 .43856 .95817 .44003 .95989 .43943 .95919 .43796 Mtetra
.708 .672 .813 r
.95919 .43796 .95989 .43943 .96156 .43843 .96088 .43709 Mtetra
.679 .676 .84 r
.96088 .43709 .96156 .43843 .96328 .43779 .9626 .43645 Mtetra
.597 .637 .862 r
.9626 .43645 .96328 .43779 .96509 .43781 .96438 .43628 Mtetra
.145 .332 .793 r
.96438 .43628 .96509 .43781 .96742 .44167 .96642 .43799 Mtetra
.053 .125 .621 r
.96642 .43799 .96742 .44167 .99604 .63862 .9689 .44288 Mtetra
.213 .12 .528 r
.9689 .44288 .99604 .63862 .99876 .64446 .99722 .63707 Mtetra
0 0 .374 r
.40322 .60807 .39748 .7958 .39886 .79908 .3984 .78561 Mtetra
.029 0 .457 r
.3984 .78561 .39886 .79908 .40031 .8003 .39948 .79742 Mtetra
.03 .129 .635 r
.39948 .79742 .40031 .8003 .40179 .80069 .40089 .79994 Mtetra
.491 .707 .966 r
.40089 .79994 .40179 .80069 .40329 .80041 .40238 .79995 Mtetra
.684 .845 .96 r
.40238 .79995 .40329 .80041 .40481 .79984 .4039 .79938 Mtetra
.762 .848 .916 r
.4039 .79938 .40481 .79984 .40633 .79913 .40543 .79849 Mtetra
.526 .751 .978 r
.40543 .79849 .40633 .79913 .40783 .7989 .40693 .79838 Mtetra
.616 .812 .975 r
.40693 .79838 .40783 .7989 .40934 .79858 .40844 .79801 Mtetra
.769 .821 .893 r
.40844 .79801 .40934 .79858 .41086 .79797 .40997 .79706 Mtetra
.892 .732 .677 r
.40997 .79706 .41086 .79797 .41242 .79607 .41161 .79275 Mtetra
.934 .683 .534 r
.41161 .79275 .41242 .79607 .41401 .7932 .41879 .60881 Mtetra
.587 .38 .568 r
.41879 .60881 .41401 .7932 .41565 .78878 .42044 .60166 Mtetra
.576 .372 .566 r
.42044 .60166 .41565 .78878 .4172 .78708 .4219 .60046 Mtetra
.575 .37 .566 r
.4219 .60046 .4172 .78708 .41868 .7877 .42333 .60021 Mtetra
.574 .369 .566 r
.42333 .60021 .41868 .7877 .42014 .78913 .42474 .60053 Mtetra
.42474 .60053 .42014 .78913 .42161 .79028 .42616 .60087 Mtetra
.573 .369 .566 r
.42616 .60087 .42161 .79028 .42309 .79113 .42757 .60141 Mtetra
.42757 .60141 .42309 .79113 .42459 .79165 .42898 .60213 Mtetra
.42898 .60213 .42459 .79165 .42608 .79221 .43039 .60298 Mtetra
.574 .37 .566 r
.43039 .60298 .42608 .79221 .42759 .79214 .43181 .60326 Mtetra
.576 .372 .566 r
.43181 .60326 .42759 .79214 .42913 .79109 .43328 .60213 Mtetra
.58 .375 .567 r
.43328 .60213 .42913 .79109 .43084 .78339 .4348 .59863 Mtetra
.579 .374 .567 r
.4348 .59863 .43084 .78339 .43708 .59924 .4363 .59599 Mtetra
.711 .556 .676 r
.4363 .59599 .43708 .59924 .43862 .59516 .43779 .59413 Mtetra
.722 .708 .837 r
.43779 .59413 .43862 .59516 .44008 .594 .43924 .59335 Mtetra
.659 .782 .939 r
.43924 .59335 .44008 .594 .44152 .59353 .44068 .59292 Mtetra
.618 .782 .96 r
.44068 .59292 .44152 .59353 .44296 .59331 .44213 .5926 Mtetra
.726 .776 .893 r
.44213 .5926 .44296 .59331 .44442 .59249 .44358 .5919 Mtetra
.722 .805 .917 r
.44358 .5919 .44442 .59249 .44587 .59177 .44503 .59122 Mtetra
.653 .808 .957 r
.44503 .59122 .44587 .59177 .44732 .59148 .44648 .59079 Mtetra
.375 .66 .969 r
.44648 .59079 .44732 .59148 .44873 .59289 .44792 .59098 Mtetra
.366 .42 .785 r
.44792 .59098 .44873 .59289 .45007 .59744 .44934 .59188 Mtetra
.408 .308 .629 r
.44934 .59188 .45007 .59744 .44753 .7828 .45073 .59416 Mtetra
0 0 .388 r
.45073 .59416 .44753 .7828 .44897 .78666 .4483 .77629 Mtetra
.072 .026 .494 r
.4483 .77629 .44897 .78666 .45047 .78805 .44963 .78523 Mtetra
.055 .152 .649 r
.44963 .78523 .45047 .78805 .45199 .78862 .45111 .78772 Mtetra
.363 .607 .942 r
.45111 .78772 .45199 .78862 .45352 .78854 .45263 .78805 Mtetra
.62 .827 .98 r
.45263 .78805 .45352 .78854 .45506 .78814 .45417 .78765 Mtetra
.715 .846 .944 r
.45417 .78765 .45506 .78814 .4566 .78758 .45572 .78696 Mtetra
.667 .801 .946 r
.45572 .78696 .4566 .78758 .45814 .78716 .45726 .78646 Mtetra
.649 .775 .941 r
.45726 .78646 .45814 .78716 .45968 .78679 .4588 .78603 Mtetra
.65 .762 .931 r
.4588 .78603 .45968 .78679 .46122 .78642 .46034 .78561 Mtetra
.604 .736 .937 r
.46034 .78561 .46122 .78642 .46276 .7863 .46188 .78536 Mtetra
.625 .71 .907 r
.46188 .78536 .46276 .7863 .4643 .78607 .46342 .78506 Mtetra
.675 .711 .875 r
.46342 .78506 .4643 .78607 .46585 .78542 .46497 .78453 Mtetra
.766 .754 .842 r
.46497 .78453 .46585 .78542 .46742 .7832 .46653 .78345 Mtetra
.883 .982 .824 r
.46653 .78345 .46742 .7832 .46904 .77822 .46809 .78169 Mtetra
.072 0 .227 r
.46809 .78169 .46904 .77822 .47338 .59193 .46968 .77868 Mtetra
.536 .336 .556 r
.46968 .77868 .47338 .59193 .47492 .58639 .47155 .75664 Mtetra
0 0 .374 r
.47155 .75664 .47492 .58639 .47641 .58413 .47556 .58553 Mtetra
.872 .911 .506 r
.47556 .58553 .47641 .58413 .47789 .58274 .47707 .58215 Mtetra
.813 .81 .848 r
.47707 .58215 .47789 .58274 .47936 .58198 .47854 .58089 Mtetra
.662 .683 .859 r
.47854 .58089 .47936 .58198 .48083 .58158 .48001 .58045 Mtetra
.588 .647 .876 r
.48001 .58045 .48083 .58158 .48229 .58137 .48147 .58032 Mtetra
.6 .67 .888 r
.48147 .58032 .48229 .58137 .48376 .58113 .48294 .58014 Mtetra
.615 .686 .893 r
.48294 .58014 .48376 .58113 .48522 .58088 .4844 .5799 Mtetra
.618 .691 .896 r
.4844 .5799 .48522 .58088 .48669 .58059 .48587 .57965 Mtetra
.645 .707 .892 r
.48587 .57965 .48669 .58059 .48816 .58019 .48734 .57929 Mtetra
.668 .721 .889 r
.48734 .57929 .48816 .58019 .48963 .5797 .48881 .57883 Mtetra
.681 .733 .889 r
.48881 .57883 .48963 .5797 .4911 .57914 .49028 .57831 Mtetra
.758 .756 .851 r
.49028 .57831 .4911 .57914 .49258 .57816 .49176 .57736 Mtetra
.75 .762 .863 r
.49176 .57736 .49258 .57816 .49406 .57725 .49324 .57647 Mtetra
.623 .739 .93 r
.49324 .57647 .49406 .57725 .49553 .57693 .49471 .57617 Mtetra
.804 .329 0 r
.49471 .57617 .49553 .57693 .49698 .57914 .49616 .57846 Mtetra
.948 .684 .503 r
.49616 .57846 .49698 .57914 .497 .76613 .49613 .76602 Mtetra
.93 .611 .414 r
.49613 .76602 .497 .76613 .49849 .77528 .49762 .77463 Mtetra
.531 0 0 r
.49762 .77463 .49849 .77528 .50004 .77676 .49917 .77597 Mtetra
.63 .752 .936 r
.49917 .77597 .50004 .77676 .5016 .7765 .50074 .77562 Mtetra
.761 .76 .851 r
.50074 .77562 .5016 .7765 .50317 .7754 .50231 .77459 Mtetra
.795 .776 .835 r
.50231 .77459 .50317 .7754 .50475 .77307 .50388 .7733 Mtetra
.867 .989 .831 r
.50388 .7733 .50475 .77307 .50634 .76808 .50546 .77162 Mtetra
.144 0 .268 r
.50546 .77162 .50634 .76808 .50879 .58143 .50704 .76879 Mtetra
.553 .349 .559 r
.50704 .76879 .50879 .58143 .51029 .57569 .50866 .75583 Mtetra
0 0 .392 r
.50866 .75583 .51029 .57569 .51178 .57338 .51096 .57514 Mtetra
.754 .827 .363 r
.51096 .57514 .51178 .57338 .51327 .57192 .51246 .57154 Mtetra
.854 .86 .845 r
.51246 .57154 .51327 .57192 .51476 .57106 .51395 .57005 Mtetra
.681 .706 .866 r
.51395 .57005 .51476 .57106 .51624 .57057 .51543 .56951 Mtetra
.613 .673 .883 r
.51543 .56951 .51624 .57057 .51773 .57025 .51692 .56929 Mtetra
.625 .698 .897 r
.51692 .56929 .51773 .57025 .51921 .56987 .5184 .569 Mtetra
.656 .728 .902 r
.5184 .569 .51921 .56987 .5207 .56941 .51989 .56858 Mtetra
.654 .737 .911 r
.51989 .56858 .5207 .56941 .52219 .56896 .52138 .56817 Mtetra
.656 .749 .919 r
.52138 .56817 .52219 .56896 .52368 .5685 .52287 .56775 Mtetra
.658 .758 .924 r
.52287 .56775 .52368 .5685 .52517 .56805 .52436 .56732 Mtetra
.659 .763 .927 r
.52436 .56732 .52517 .56805 .52666 .5676 .52585 .56688 Mtetra
.658 .767 .93 r
.52585 .56688 .52666 .5676 .52815 .56716 .52734 .56645 Mtetra
.658 .769 .932 r
.52734 .56645 .52815 .56716 .52964 .56671 .52883 .56601 Mtetra
.658 .772 .933 r
.52883 .56601 .52964 .56671 .53113 .56627 .53033 .56557 Mtetra
.658 .774 .935 r
.53033 .56557 .53113 .56627 .53263 .56582 .53182 .56514 Mtetra
.657 .776 .936 r
.53182 .56514 .53263 .56582 .53412 .56538 .53332 .5647 Mtetra
.658 .779 .938 r
.53332 .5647 .53412 .56538 .53562 .56493 .53481 .56426 Mtetra
.682 .786 .929 r
.53481 .56426 .53562 .56493 .53711 .56433 .53631 .56373 Mtetra
.689 .807 .938 r
.53631 .56373 .53711 .56433 .53861 .56369 .53781 .56316 Mtetra
.626 .816 .973 r
.53781 .56316 .53861 .56369 .5401 .56337 .5393 .56278 Mtetra
.33 .671 .976 r
.5393 .56278 .5401 .56337 .54161 .56421 .54081 .56297 Mtetra
.132 .381 .836 r
.54081 .56297 .54161 .56421 .54313 .56765 .54231 .56399 Mtetra
.394 .34 .678 r
.54231 .56399 .54313 .56765 .54572 .75315 .54383 .56566 Mtetra
.572 .368 .566 r
.54383 .56566 .54572 .75315 .54734 .75867 .54534 .56707 Mtetra
.575 .37 .566 r
.54534 .56707 .54734 .75867 .54893 .75868 .54685 .56685 Mtetra
.576 .371 .566 r
.54685 .56685 .54893 .75868 .55052 .75771 .54835 .56598 Mtetra
.54835 .56598 .55052 .75771 .5521 .75673 .54985 .56517 Mtetra
.575 .371 .566 r
.54985 .56517 .5521 .75673 .5537 .75627 .55136 .56467 Mtetra
.55136 .56467 .5537 .75627 .55529 .7558 .55287 .56418 Mtetra
.55287 .56418 .55529 .7558 .55688 .75535 .55438 .56371 Mtetra
.55438 .56371 .55688 .75535 .55848 .75494 .55589 .56326 Mtetra
.55589 .56326 .55848 .75494 .56007 .75455 .5574 .56283 Mtetra
.5574 .56283 .56007 .75455 .56167 .75417 .55891 .5624 Mtetra
.575 .37 .566 r
.55891 .5624 .56167 .75417 .56327 .7538 .56042 .56199 Mtetra
.56042 .56199 .56327 .7538 .56487 .75344 .56193 .56159 Mtetra
.56193 .56159 .56487 .75344 .56647 .75307 .56345 .56117 Mtetra
.575 .371 .566 r
.56345 .56117 .56647 .75307 .56807 .75268 .56496 .56075 Mtetra
.56496 .56075 .56807 .75268 .56967 .75228 .56648 .56031 Mtetra
.56648 .56031 .56967 .75228 .57127 .75185 .568 .55984 Mtetra
.568 .55984 .57127 .75185 .57287 .75141 .56951 .55935 Mtetra
.56951 .55935 .57287 .75141 .57448 .75096 .57103 .55887 Mtetra
.576 .371 .566 r
.57103 .55887 .57448 .75096 .57608 .75032 .57254 .55804 Mtetra
.57254 .55804 .57608 .75032 .57768 .74945 .57405 .55695 Mtetra
.575 .37 .566 r
.57405 .55695 .57768 .74945 .57928 .74912 .57558 .55669 Mtetra
.569 .366 .566 r
.57558 .55669 .57928 .74912 .58091 .75013 .57715 .5599 Mtetra
.037 0 .432 r
.57715 .5599 .58091 .75013 .58256 .75199 .58166 .74714 Mtetra
.083 .101 .58 r
.58166 .74714 .58256 .75199 .5842 .75323 .58335 .75165 Mtetra
.092 .308 .786 r
.58335 .75165 .5842 .75323 .58583 .7537 .585 .75308 Mtetra
.544 .775 .984 r
.585 .75308 .58583 .7537 .58744 .75338 .58662 .75289 Mtetra
.67 .849 .968 r
.58662 .75289 .58744 .75338 .58906 .75288 .58823 .75232 Mtetra
.68 .83 .955 r
.58823 .75232 .58906 .75288 .59067 .75241 .58984 .75173 Mtetra
.595 .773 .965 r
.58984 .75173 .59067 .75241 .59229 .75215 .59146 .75144 Mtetra
.598 .768 .961 r
.59146 .75144 .59229 .75215 .59391 .75188 .59308 .75115 Mtetra
.615 .766 .952 r
.59308 .75115 .59391 .75188 .59553 .75157 .5947 .75081 Mtetra
.638 .768 .941 r
.5947 .75081 .59553 .75157 .59715 .75118 .59633 .75041 Mtetra
.646 .767 .937 r
.59633 .75041 .59715 .75118 .59877 .75076 .59795 .74998 Mtetra
.648 .766 .935 r
.59795 .74998 .59877 .75076 .6004 .75033 .59957 .74954 Mtetra
.645 .763 .935 r
.59957 .74954 .6004 .75033 .60202 .74991 .60119 .74912 Mtetra
.651 .763 .931 r
.60119 .74912 .60202 .74991 .60364 .74947 .60282 .74867 Mtetra
.665 .765 .924 r
.60282 .74867 .60364 .74947 .60526 .74899 .60444 .74817 Mtetra
.685 .766 .913 r
.60444 .74817 .60526 .74899 .60689 .74844 .60606 .74759 Mtetra
.687 .76 .907 r
.60606 .74759 .60689 .74844 .60851 .74787 .60769 .74699 Mtetra
.668 .748 .91 r
.60769 .74699 .60851 .74787 .61014 .74742 .60931 .74648 Mtetra
.621 .719 .917 r
.60931 .74648 .61014 .74742 .61177 .74724 .61094 .74617 Mtetra
.653 .704 .884 r
.61094 .74617 .61177 .74724 .6134 .74678 .61257 .74573 Mtetra
.727 .731 .854 r
.61257 .74573 .6134 .74678 .61501 .7455 .61419 .74488 Mtetra
.861 .824 .81 r
.61419 .74488 .61501 .7455 .61655 .74172 .61579 .74304 Mtetra
0 0 0 r
.61579 .74304 .61655 .74172 .61783 .72777 .61737 .74058 Mtetra
.505 .286 .515 r
.61737 .74058 .61783 .72777 .61464 .54671 .61894 .73811 Mtetra
.574 .366 .561 r
.61894 .73811 .61464 .54671 .61617 .54584 .62059 .73807 Mtetra
.573 .366 .561 r
.62059 .73807 .61617 .54584 .61773 .54577 .62222 .73783 Mtetra
.57 .363 .561 r
.62222 .73783 .61773 .54577 .61926 .54503 .62381 .7355 Mtetra
.058 0 .438 r
.62381 .7355 .61926 .54503 .62074 .54225 .62012 .54678 Mtetra
0 0 .147 r
.62012 .54678 .62074 .54225 .62224 .54016 .62149 .54037 Mtetra
.953 .942 .732 r
.62149 .54037 .62224 .54016 .62375 .53876 .62298 .53782 Mtetra
.696 .731 .877 r
.62298 .53782 .62375 .53876 .6253 .53829 .62452 .5372 Mtetra
.6 .667 .887 r
.62452 .5372 .6253 .53829 .62685 .53804 .62607 .53701 Mtetra
.555 .661 .907 r
.62607 .53701 .62685 .53804 .6284 .53785 .62763 .53697 Mtetra
.648 .732 .911 r
.62763 .53697 .6284 .53785 .62995 .53742 .62918 .53657 Mtetra
.66 .743 .911 r
.62918 .53657 .62995 .53742 .6315 .53693 .63073 .53612 Mtetra
.684 .758 .908 r
.63073 .53612 .6315 .53693 .63304 .53633 .63228 .53556 Mtetra
.735 .782 .89 r
.63228 .53556 .63304 .53633 .63458 .5354 .63382 .53477 Mtetra
.708 .813 .93 r
.63382 .53477 .63458 .5354 .63612 .53474 .63536 .53411 Mtetra
.614 .786 .964 r
.63536 .53411 .63612 .53474 .63769 .53473 .63692 .53377 Mtetra
.374 .588 .927 r
.63692 .53377 .63769 .53473 .63933 .53687 .6385 .53416 Mtetra
.417 .396 .729 r
.6385 .53416 .63933 .53687 .64119 .54522 .64011 .53532 Mtetra
.464 .322 .603 r
.64011 .53532 .64119 .54522 .64928 .73147 .64179 .53852 Mtetra
.082 .001 .456 r
.64179 .53852 .64928 .73147 .65103 .73385 .65 .72662 Mtetra
.209 .16 .58 r
.65 .72662 .65103 .73385 .65273 .73484 .65187 .73238 Mtetra
.202 .284 .725 r
.65187 .73238 .65273 .73484 .65441 .73522 .65361 .73435 Mtetra
.413 .648 .954 r
.65361 .73435 .65441 .73522 .65609 .73542 .65528 .73458 Mtetra
.629 .749 .934 r
.65528 .73458 .65609 .73542 .65775 .73511 .65694 .73422 Mtetra
.734 .765 .878 r
.65694 .73422 .65775 .73511 .65939 .73412 .65858 .73335 Mtetra
.809 .805 .848 r
.65858 .73335 .65939 .73412 .66094 .73101 .66021 .732 Mtetra
0 0 0 r
.66021 .732 .66094 .73101 .66231 .72322 .6618 .72986 Mtetra
.323 .113 .432 r
.6618 .72986 .66231 .72322 .65657 .53431 .66332 .7259 Mtetra
.083 0 .451 r
.66332 .7259 .65657 .53431 .65802 .53096 .65754 .53714 Mtetra
0 0 .296 r
.65754 .53714 .65802 .53096 .65953 .52912 .65884 .52987 Mtetra
.885 .946 .586 r
.65884 .52987 .65953 .52912 .66107 .52795 .66031 .52708 Mtetra
.733 .761 .875 r
.66031 .52708 .66107 .52795 .66263 .52732 .66186 .52627 Mtetra
.643 .694 .882 r
.66186 .52627 .66263 .52732 .66419 .5269 .66343 .52589 Mtetra
.598 .685 .902 r
.66343 .52589 .66419 .5269 .66577 .52654 .66501 .52569 Mtetra
.731 .766 .881 r
.66501 .52569 .66577 .52654 .66731 .52558 .66657 .52489 Mtetra
.711 .801 .921 r
.66657 .52489 .66731 .52558 .66887 .52487 .66813 .52422 Mtetra
.639 .791 .955 r
.66813 .52422 .66887 .52487 .67045 .52464 .6697 .5238 Mtetra
.385 .627 .949 r
.6697 .5238 .67045 .52464 .67212 .52646 .6713 .52409 Mtetra
.422 .421 .753 r
.6713 .52409 .67212 .52646 .67397 .53226 .67294 .52509 Mtetra
.452 .329 .622 r
.67294 .52509 .67397 .53226 .68406 .72132 .67465 .52767 Mtetra
.1 .018 .466 r
.67465 .52767 .68406 .72132 .68589 .72439 .68476 .71611 Mtetra
.195 .143 .568 r
.68476 .71611 .68589 .72439 .68764 .7256 .68676 .72303 Mtetra
.183 .264 .713 r
.68676 .72303 .68764 .7256 .68935 .72602 .68856 .72522 Mtetra
.556 .733 .958 r
.68856 .72522 .68935 .72602 .69103 .72563 .69025 .72506 Mtetra
.709 .847 .948 r
.69025 .72506 .69103 .72563 .69269 .72494 .69191 .72434 Mtetra
.769 .846 .909 r
.69191 .72434 .69269 .72494 .69435 .72413 .69356 .72334 Mtetra
.65 .77 .937 r
.69356 .72334 .69435 .72413 .69603 .72372 .69524 .72288 Mtetra
.631 .752 .935 r
.69524 .72288 .69603 .72372 .69771 .72337 .69692 .7225 Mtetra
.63 .743 .929 r
.69692 .7225 .69771 .72337 .69939 .72303 .6986 .72212 Mtetra
.651 .742 .916 r
.6986 .72212 .69939 .72303 .70107 .7226 .70028 .72167 Mtetra
.658 .74 .911 r
.70028 .72167 .70107 .7226 .70275 .72213 .70196 .72119 Mtetra
.663 .74 .907 r
.70196 .72119 .70275 .72213 .70443 .72163 .70364 .72069 Mtetra
.672 .743 .904 r
.70364 .72069 .70443 .72163 .70611 .72107 .70532 .72015 Mtetra
.671 .745 .906 r
.70532 .72015 .70611 .72107 .70779 .72051 .707 .7196 Mtetra
.664 .747 .912 r
.707 .7196 .70779 .72051 .70947 .71998 .70868 .7191 Mtetra
.467 .67 .952 r
.70868 .7191 .70947 .71998 .71118 .72008 .7104 .71922 Mtetra
.569 .723 .946 r
.7104 .71922 .71118 .72008 .71288 .71989 .7121 .71905 Mtetra
.739 .783 .888 r
.7121 .71905 .71288 .71989 .71455 .71899 .71377 .71816 Mtetra
.939 .767 .641 r
.71377 .71816 .71455 .71899 .71599 .71394 .71521 .71312 Mtetra
.969 .689 .446 r
.71521 .71312 .71599 .71394 .70712 .51993 .70638 .51906 Mtetra
.945 .752 .611 r
.70638 .51906 .70712 .51993 .70842 .51397 .70768 .5131 Mtetra
.802 .778 .831 r
.70768 .5131 .70842 .51397 .70996 .51265 .70922 .51177 Mtetra
.646 .737 .915 r
.70922 .51177 .70996 .51265 .71156 .51224 .71082 .51137 Mtetra
.53 .689 .94 r
.71082 .51137 .71156 .51224 .71317 .51222 .71244 .51134 Mtetra
.727 .762 .88 r
.71244 .51134 .71317 .51222 .71475 .51143 .71401 .51055 Mtetra
.699 .753 .894 r
.71401 .51055 .71475 .51143 .71634 .51079 .7156 .5099 Mtetra
.533 .688 .939 r
.7156 .5099 .71634 .51079 .71796 .51076 .71722 .50987 Mtetra
.807 .363 0 r
.71722 .50987 .71796 .51076 .71978 .51419 .71905 .51329 Mtetra
.97 .683 .426 r
.71905 .51329 .71978 .51419 .73279 .70741 .73202 .70655 Mtetra
.92 .528 .149 r
.73202 .70655 .73279 .70741 .73487 .71338 .7341 .71255 Mtetra
0 .358 .822 r
.7341 .71255 .73487 .71338 .73666 .71444 .73589 .71361 Mtetra
.6 .746 .947 r
.73589 .71361 .73666 .71444 .73837 .71414 .7376 .71332 Mtetra
.803 .803 .851 r
.7376 .71332 .73837 .71414 .74002 .71279 .73925 .71199 Mtetra
.941 .776 .649 r
.73925 .71199 .74002 .71279 .74146 .70799 .7407 .70726 Mtetra
.971 .689 .436 r
.7407 .70726 .74146 .70799 .73113 .51297 .73042 .51233 Mtetra
.962 .764 .59 r
.73042 .51233 .73113 .51297 .73237 .50659 .73165 .50579 Mtetra
.825 .799 .827 r
.73165 .50579 .73237 .50659 .73392 .50513 .73319 .50431 Mtetra
.625 .745 .933 r
.73319 .50431 .73392 .50513 .73553 .5048 .73481 .50397 Mtetra
.476 .676 .953 r
.73481 .50397 .73553 .5048 .73717 .5049 .73645 .50406 Mtetra
.67 .755 .914 r
.73645 .50406 .73717 .5049 .73879 .50452 .73806 .50355 Mtetra
.684 .73 .886 r
.73806 .50355 .73879 .50452 .7404 .50401 .73966 .50297 Mtetra
.595 .68 .901 r
.73966 .50297 .7404 .50401 .74201 .50368 .74129 .50278 Mtetra
0 .211 .723 r
.74129 .50278 .74201 .50368 .74367 .50382 .74302 .50421 Mtetra
.898 .513 .291 r
.74302 .50421 .74367 .50382 .74536 .50461 .745 .50926 Mtetra
.965 .674 .43 r
.745 .50926 .74536 .50461 .74715 .5067 .75931 .69948 Mtetra
.58 .37 .561 r
.75931 .69948 .74715 .5067 .76145 .69483 .76134 .70374 Mtetra
.609 .357 .511 r
.76134 .70374 .76145 .69483 .76378 .7036 .76319 .7052 Mtetra
.541 .159 .266 r
.76319 .7052 .76378 .7036 .76569 .70592 .76495 .70542 Mtetra
.897 .87 .804 r
.76495 .70542 .76569 .70592 .76741 .70542 .76656 .70333 Mtetra
.883 .687 .633 r
.76656 .70333 .76741 .70542 .76902 .70341 .76793 .69781 Mtetra
.968 .682 .437 r
.76793 .69781 .76902 .70341 .77055 .70022 .75632 .50558 Mtetra
.58 .374 .566 r
.75632 .50558 .77055 .70022 .77215 .69805 .75771 .50183 Mtetra
.575 .371 .566 r
.75771 .50183 .77215 .69805 .77386 .69746 .75932 .50119 Mtetra
.574 .37 .566 r
.75932 .50119 .77386 .69746 .77561 .69743 .76099 .50135 Mtetra
.575 .37 .566 r
.76099 .50135 .77561 .69743 .77735 .69718 .76264 .5012 Mtetra
.76264 .5012 .77735 .69718 .77908 .69679 .76427 .50081 Mtetra
.76427 .50081 .77908 .69679 .78081 .6964 .76591 .50043 Mtetra
.76591 .50043 .78081 .6964 .78254 .696 .76754 .50004 Mtetra
.76754 .50004 .78254 .696 .78427 .69559 .76917 .49962 Mtetra
.76917 .49962 .78427 .69559 .786 .69518 .77081 .49919 Mtetra
.77081 .49919 .786 .69518 .78774 .69475 .77244 .49875 Mtetra
.77244 .49875 .78774 .69475 .78947 .69433 .77408 .49831 Mtetra
.77408 .49831 .78947 .69433 .7912 .6939 .77571 .49785 Mtetra
.575 .371 .566 r
.77571 .49785 .7912 .6939 .79294 .69346 .77735 .4974 Mtetra
.77735 .4974 .79294 .69346 .79467 .69302 .77898 .49693 Mtetra
.77898 .49693 .79467 .69302 .79641 .69258 .78062 .49647 Mtetra
.78062 .49647 .79641 .69258 .79815 .69213 .78226 .49599 Mtetra
.78226 .49599 .79815 .69213 .79988 .69168 .78389 .49552 Mtetra
.78389 .49552 .79988 .69168 .80162 .69123 .78553 .49504 Mtetra
.78553 .49504 .80162 .69123 .80336 .69078 .78717 .49456 Mtetra
.78717 .49456 .80336 .69078 .8051 .69032 .78881 .49408 Mtetra
.78881 .49408 .8051 .69032 .80684 .68987 .79045 .49359 Mtetra
.79045 .49359 .80684 .68987 .80859 .68941 .79209 .4931 Mtetra
.79209 .4931 .80859 .68941 .81033 .68895 .79374 .49262 Mtetra
.79374 .49262 .81033 .68895 .81207 .6885 .79538 .49213 Mtetra
.79538 .49213 .81207 .6885 .81382 .68804 .79703 .49164 Mtetra
.79703 .49164 .81382 .68804 .81557 .68758 .79867 .49115 Mtetra
.79867 .49115 .81557 .68758 .81731 .68712 .80032 .49066 Mtetra
.80032 .49066 .81731 .68712 .81906 .68665 .80196 .49017 Mtetra
.80196 .49017 .81906 .68665 .82081 .68619 .80361 .48967 Mtetra
.80361 .48967 .82081 .68619 .82256 .68573 .80526 .48918 Mtetra
.80526 .48918 .82256 .68573 .82431 .68527 .80691 .48869 Mtetra
.80691 .48869 .82431 .68527 .82607 .6848 .80856 .48819 Mtetra
.80856 .48819 .82607 .6848 .82782 .68434 .81021 .4877 Mtetra
.81021 .4877 .82782 .68434 .82958 .68388 .81187 .4872 Mtetra
.81187 .4872 .82958 .68388 .83133 .68341 .81352 .48671 Mtetra
.81352 .48671 .83133 .68341 .83309 .68295 .81517 .48621 Mtetra
.81517 .48621 .83309 .68295 .83485 .68248 .81683 .48572 Mtetra
.81683 .48572 .83485 .68248 .83661 .68202 .81849 .48522 Mtetra
.81849 .48522 .83661 .68202 .83837 .68155 .82014 .48473 Mtetra
.82014 .48473 .83837 .68155 .84013 .68109 .8218 .48423 Mtetra
.8218 .48423 .84013 .68109 .84189 .68062 .82346 .48374 Mtetra
.82346 .48374 .84189 .68062 .84365 .68016 .82512 .48324 Mtetra
.82512 .48324 .84365 .68016 .84542 .67969 .82678 .48274 Mtetra
.82678 .48274 .84542 .67969 .84718 .67923 .82845 .48225 Mtetra
.82845 .48225 .84718 .67923 .84895 .67876 .83011 .48175 Mtetra
.83011 .48175 .84895 .67876 .85072 .67829 .83177 .48125 Mtetra
.83177 .48125 .85072 .67829 .85249 .67782 .83344 .48075 Mtetra
.83344 .48075 .85249 .67782 .85426 .67736 .8351 .48026 Mtetra
.8351 .48026 .85426 .67736 .85603 .67689 .83677 .47976 Mtetra
.83677 .47976 .85603 .67689 .8578 .67642 .83844 .47926 Mtetra
.83844 .47926 .8578 .67642 .85957 .67595 .84011 .47876 Mtetra
.84011 .47876 .85957 .67595 .86135 .67548 .84178 .47826 Mtetra
.84178 .47826 .86135 .67548 .86312 .67501 .84345 .47776 Mtetra
.84345 .47776 .86312 .67501 .8649 .67454 .84512 .47726 Mtetra
.84512 .47726 .8649 .67454 .86668 .67407 .84679 .47676 Mtetra
.84679 .47676 .86668 .67407 .86845 .6736 .84847 .47626 Mtetra
.84847 .47626 .86845 .6736 .87023 .67313 .85014 .47576 Mtetra
.85014 .47576 .87023 .67313 .87201 .67266 .85182 .47525 Mtetra
.85182 .47525 .87201 .67266 .8738 .67219 .85349 .47475 Mtetra
.85349 .47475 .8738 .67219 .87558 .67171 .85517 .47425 Mtetra
.85517 .47425 .87558 .67171 .87736 .67124 .85685 .47374 Mtetra
.85685 .47374 .87736 .67124 .87915 .67077 .85853 .47324 Mtetra
.85853 .47324 .87915 .67077 .88093 .67029 .86021 .47273 Mtetra
.86021 .47273 .88093 .67029 .88272 .66982 .86189 .47222 Mtetra
.86189 .47222 .88272 .66982 .88451 .66934 .86357 .47172 Mtetra
.86357 .47172 .88451 .66934 .8863 .66886 .86525 .47121 Mtetra
.86525 .47121 .8863 .66886 .88809 .66838 .86694 .4707 Mtetra
.86694 .4707 .88809 .66838 .88988 .6679 .86862 .47018 Mtetra
.86862 .47018 .88988 .6679 .89167 .66742 .87031 .46967 Mtetra
.87031 .46967 .89167 .66742 .89346 .66694 .87199 .46916 Mtetra
.87199 .46916 .89346 .66694 .89526 .66646 .87368 .46865 Mtetra
.87368 .46865 .89526 .66646 .89705 .66598 .87537 .46813 Mtetra
.87537 .46813 .89705 .66598 .89885 .6655 .87706 .46762 Mtetra
.87706 .46762 .89885 .6655 .90064 .66502 .87875 .4671 Mtetra
.87875 .4671 .90064 .66502 .90244 .66454 .88044 .46659 Mtetra
.88044 .46659 .90244 .66454 .90424 .66405 .88213 .46607 Mtetra
.88213 .46607 .90424 .66405 .90604 .66357 .88383 .46556 Mtetra
.88383 .46556 .90604 .66357 .90784 .66309 .88552 .46505 Mtetra
.88552 .46505 .90784 .66309 .90965 .66261 .88722 .46453 Mtetra
.88722 .46453 .90965 .66261 .91145 .66213 .88891 .46402 Mtetra
.88891 .46402 .91145 .66213 .91326 .66164 .89061 .4635 Mtetra
.89061 .4635 .91326 .66164 .91506 .66116 .89231 .46298 Mtetra
.89231 .46298 .91506 .66116 .91687 .66067 .89401 .46246 Mtetra
.89401 .46246 .91687 .66067 .91868 .66018 .8957 .46194 Mtetra
.8957 .46194 .91868 .66018 .92049 .65969 .89741 .46142 Mtetra
.89741 .46142 .92049 .65969 .9223 .65919 .89911 .4609 Mtetra
.89911 .4609 .9223 .65919 .92411 .65869 .90081 .46037 Mtetra
.90081 .46037 .92411 .65869 .92592 .65819 .90251 .45984 Mtetra
.90251 .45984 .92592 .65819 .92773 .65768 .90421 .45931 Mtetra
.90421 .45931 .92773 .65768 .92954 .65716 .90592 .45877 Mtetra
.90592 .45877 .92954 .65716 .93135 .65664 .90762 .45824 Mtetra
.90762 .45824 .93135 .65664 .93316 .65611 .90933 .45769 Mtetra
.90933 .45769 .93316 .65611 .93498 .65559 .91103 .45716 Mtetra
.91103 .45716 .93498 .65559 .9368 .65509 .91274 .45664 Mtetra
.91274 .45664 .9368 .65509 .93862 .65464 .91446 .45616 Mtetra
.575 .37 .566 r
.91446 .45616 .93862 .65464 .94045 .6542 .91618 .45569 Mtetra
.91618 .45569 .94045 .6542 .9423 .65392 .91791 .45533 Mtetra
.574 .37 .566 r
.91791 .45533 .9423 .65392 .94422 .65425 .9197 .4554 Mtetra
.575 .37 .566 r
.9197 .4554 .94422 .65425 .94605 .6538 .92142 .455 Mtetra
.577 .372 .566 r
.92142 .455 .94605 .6538 .94763 .65129 .92301 .4534 Mtetra
.579 .373 .566 r
.92301 .4534 .94763 .65129 .92579 .45723 .92442 .45037 Mtetra
.662 .478 .625 r
.92442 .45037 .92579 .45723 .9267 .45011 .92592 .44807 Mtetra
.747 .634 .735 r
.92592 .44807 .9267 .45011 .92813 .44728 .9275 .44647 Mtetra
.696 .791 .924 r
.9275 .44647 .92813 .44728 .92981 .44645 .9292 .44581 Mtetra
.62 .811 .974 r
.9292 .44581 .92981 .44645 .93154 .44605 .93093 .44539 Mtetra
.592 .79 .975 r
.93093 .44539 .93154 .44605 .9333 .44583 .93267 .44506 Mtetra
.65 .781 .944 r
.93267 .44506 .9333 .44583 .93502 .44535 .9344 .44458 Mtetra
.649 .782 .945 r
.9344 .44458 .93502 .44535 .93675 .44487 .93613 .44409 Mtetra
.65 .783 .945 r
.93613 .44409 .93675 .44487 .93847 .44438 .93785 .44361 Mtetra
.653 .783 .943 r
.93785 .44361 .93847 .44438 .9402 .44389 .93958 .44311 Mtetra
.654 .784 .943 r
.93958 .44311 .9402 .44389 .94193 .44339 .94131 .44262 Mtetra
.655 .785 .944 r
.94131 .44262 .94193 .44339 .94365 .44288 .94303 .44211 Mtetra
.656 .786 .944 r
.94303 .44211 .94365 .44288 .94538 .44237 .94476 .4416 Mtetra
.657 .788 .944 r
.94476 .4416 .94538 .44237 .94711 .44185 .94649 .44109 Mtetra
.658 .79 .945 r
.94649 .44109 .94711 .44185 .94883 .44133 .94822 .44057 Mtetra
.66 .791 .945 r
.94822 .44057 .94883 .44133 .95056 .4408 .94995 .44004 Mtetra
.662 .793 .945 r
.94995 .44004 .95056 .4408 .95229 .44026 .95168 .43951 Mtetra
.665 .796 .944 r
.95168 .43951 .95229 .44026 .95401 .43971 .9534 .43896 Mtetra
.67 .798 .943 r
.9534 .43896 .95401 .43971 .95574 .43914 .95513 .43839 Mtetra
.673 .8 .943 r
.95513 .43839 .95574 .43914 .95746 .43856 .95685 .43781 Mtetra
.678 .801 .941 r
.95685 .43781 .95746 .43856 .95919 .43796 .95858 .43721 Mtetra
.717 .814 .925 r
.95858 .43721 .95919 .43796 .96088 .43709 .96028 .43644 Mtetra
.683 .833 .955 r
.96028 .43644 .96088 .43709 .9626 .43645 .962 .4358 Mtetra
.61 .803 .974 r
.962 .4358 .9626 .43645 .96438 .43628 .96376 .4354 Mtetra
.435 .65 .949 r
.96376 .4354 .96438 .43628 .96642 .43799 .9656 .43563 Mtetra
.468 .457 .763 r
.9656 .43563 .96642 .43799 .9689 .44288 .96752 .43646 Mtetra
.482 .364 .642 r
.96752 .43646 .9689 .44288 .99722 .63707 .96962 .43854 Mtetra
.151 .132 .581 r
.40251 .60317 .40322 .60807 .3984 .78561 .40379 .60684 Mtetra
0 0 .327 r
.40379 .60684 .3984 .78561 .39948 .79742 .39869 .7935 Mtetra
0 0 .243 r
.39869 .7935 .39948 .79742 .40089 .79994 .39999 .79921 Mtetra
.333 .639 .964 r
.39999 .79921 .40089 .79994 .40238 .79995 .40148 .79947 Mtetra
.686 .838 .956 r
.40148 .79947 .40238 .79995 .4039 .79938 .40299 .79889 Mtetra
.786 .84 .893 r
.40299 .79889 .4039 .79938 .40543 .79849 .40452 .79786 Mtetra
.484 .74 .984 r
.40452 .79786 .40543 .79849 .40693 .79838 .40602 .79782 Mtetra
.631 .807 .967 r
.40602 .79782 .40693 .79838 .40844 .79801 .40754 .79742 Mtetra
.801 .813 .861 r
.40754 .79742 .40844 .79801 .40997 .79706 .40908 .79623 Mtetra
.915 .722 .627 r
.40908 .79623 .40997 .79706 .41161 .79275 .41081 .78899 Mtetra
.933 .682 .535 r
.41081 .78899 .41161 .79275 .41879 .60881 .41813 .60211 Mtetra
.717 .521 .624 r
.41813 .60211 .41879 .60881 .42044 .60166 .41969 .59788 Mtetra
.654 .508 .672 r
.41969 .59788 .42044 .60166 .4219 .60046 .42114 .59686 Mtetra
.611 .483 .682 r
.42114 .59686 .4219 .60046 .42333 .60021 .42257 .59653 Mtetra
.584 .463 .681 r
.42257 .59653 .42333 .60021 .42474 .60053 .424 .59651 Mtetra
.609 .472 .671 r
.424 .59651 .42474 .60053 .42616 .60087 .42543 .59616 Mtetra
.606 .459 .656 r
.42543 .59616 .42616 .60087 .42757 .60141 .42687 .59578 Mtetra
.601 .445 .642 r
.42687 .59578 .42757 .60141 .42898 .60213 .42831 .59541 Mtetra
.595 .432 .63 r
.42831 .59541 .42898 .60213 .43039 .60298 .42974 .59508 Mtetra
.592 .422 .62 r
.42974 .59508 .43039 .60298 .43181 .60326 .43118 .59476 Mtetra
.591 .419 .617 r
.43118 .59476 .43181 .60326 .43328 .60213 .43262 .59442 Mtetra
.596 .426 .622 r
.43262 .59442 .43328 .60213 .4348 .59863 .43406 .594 Mtetra
.611 .464 .658 r
.43406 .594 .4348 .59863 .4363 .59599 .43551 .59356 Mtetra
.635 .539 .728 r
.43551 .59356 .4363 .59599 .43779 .59413 .43695 .5931 Mtetra
.657 .69 .869 r
.43695 .5931 .43779 .59413 .43924 .59335 .4384 .59269 Mtetra
.65 .775 .939 r
.4384 .59269 .43924 .59335 .44068 .59292 .43984 .59229 Mtetra
.652 .784 .944 r
.43984 .59229 .44068 .59292 .44213 .5926 .44129 .59188 Mtetra
.675 .763 .918 r
.44129 .59188 .44213 .5926 .44358 .5919 .44274 .5914 Mtetra
.67 .826 .958 r
.44274 .5914 .44358 .5919 .44503 .59122 .44419 .5909 Mtetra
.638 .874 .985 r
.44419 .5909 .44503 .59122 .44648 .59079 .44564 .59042 Mtetra
.744 .873 .939 r
.44564 .59042 .44648 .59079 .44792 .59098 .44709 .58965 Mtetra
.674 .648 .816 r
.44709 .58965 .44792 .59098 .44934 .59188 .44855 .5891 Mtetra
.578 .489 .718 r
.44855 .5891 .44934 .59188 .45073 .59416 .44999 .58914 Mtetra
.26 .21 .61 r
.44999 .58914 .45073 .59416 .4483 .77629 .45136 .59235 Mtetra
0 0 .365 r
.45136 .59235 .4483 .77629 .44963 .78523 .44885 .77995 Mtetra
0 0 .425 r
.44885 .77995 .44963 .78523 .45111 .78772 .45024 .78608 Mtetra
.36 .462 .829 r
.45024 .78608 .45111 .78772 .45263 .78805 .45176 .78684 Mtetra
.649 .668 .855 r
.45176 .78684 .45263 .78805 .45417 .78765 .4533 .78644 Mtetra
.716 .69 .824 r
.4533 .78644 .45417 .78765 .45572 .78696 .45485 .78562 Mtetra
.663 .653 .831 r
.45485 .78562 .45572 .78696 .45726 .78646 .45639 .78512 Mtetra
.64 .646 .84 r
.45639 .78512 .45726 .78646 .4588 .78603 .45793 .78476 Mtetra
.64 .655 .849 r
.45793 .78476 .4588 .78603 .46034 .78561 .45947 .7844 Mtetra
.641 .665 .858 r
.45947 .7844 .46034 .78561 .46188 .78536 .46101 .78404 Mtetra
.643 .65 .842 r
.46101 .78404 .46188 .78536 .46342 .78506 .46256 .78367 Mtetra
.646 .641 .831 r
.46256 .78367 .46342 .78506 .46497 .78453 .4641 .78327 Mtetra
.582 .633 .868 r
.4641 .78327 .46497 .78453 .46653 .78345 .46564 .78318 Mtetra
.474 .838 .992 r
.46564 .78318 .46653 .78345 .46809 .78169 .46719 .78292 Mtetra
.167 0 0 r
.46719 .78292 .46809 .78169 .46968 .77868 .46874 .78206 Mtetra
0 0 .112 r
.46874 .78206 .46968 .77868 .47155 .75664 .47034 .77829 Mtetra
.975 .721 .484 r
.47034 .77829 .47155 .75664 .47556 .58553 .47465 .5905 Mtetra
0 0 0 r
.47465 .5905 .47556 .58553 .47707 .58215 .47623 .58227 Mtetra
.902 .956 .822 r
.47623 .58227 .47707 .58215 .47854 .58089 .47771 .5805 Mtetra
.642 .856 .981 r
.47771 .5805 .47854 .58089 .48001 .58045 .47918 .58003 Mtetra
.405 .764 .994 r
.47918 .58003 .48001 .58045 .48147 .58032 .48064 .57999 Mtetra
.531 .841 .999 r
.48064 .57999 .48147 .58032 .48294 .58014 .48211 .57971 Mtetra
.644 .843 .977 r
.48211 .57971 .48294 .58014 .4844 .5799 .48358 .57925 Mtetra
.664 .785 .938 r
.48358 .57925 .4844 .5799 .48587 .57965 .48505 .5788 Mtetra
.666 .733 .9 r
.48505 .5788 .48587 .57965 .48734 .57929 .48652 .57834 Mtetra
.665 .713 .884 r
.48652 .57834 .48734 .57929 .48881 .57883 .48799 .57789 Mtetra
.666 .715 .885 r
.48799 .57789 .48881 .57883 .49028 .57831 .48946 .57744 Mtetra
.733 .746 .862 r
.48946 .57744 .49028 .57831 .49176 .57736 .49094 .57664 Mtetra
.728 .78 .894 r
.49094 .57664 .49176 .57736 .49324 .57647 .49242 .57591 Mtetra
.55 .778 .983 r
.49242 .57591 .49324 .57647 .49471 .57617 .49389 .57573 Mtetra
.839 .372 .052 r
.49389 .57573 .49471 .57617 .49616 .57846 .49534 .57798 Mtetra
.948 .684 .503 r
.49534 .57798 .49616 .57846 .49613 .76602 .49528 .76411 Mtetra
.967 .644 .312 r
.49528 .76411 .49613 .76602 .49762 .77463 .49676 .77323 Mtetra
0 .261 .769 r
.49676 .77323 .49762 .77463 .49917 .77597 .49831 .77463 Mtetra
.615 .636 .848 r
.49831 .77463 .49917 .77597 .50074 .77562 .49988 .77439 Mtetra
.702 .686 .831 r
.49988 .77439 .50074 .77562 .50231 .77459 .50145 .77366 Mtetra
.639 .72 .907 r
.50145 .77366 .50231 .77459 .50388 .7733 .50301 .77329 Mtetra
.262 .769 .853 r
.50301 .77329 .50388 .7733 .50546 .77162 .50458 .77304 Mtetra
.252 0 .088 r
.50458 .77304 .50546 .77162 .50704 .76879 .50615 .77221 Mtetra
.014 0 .203 r
.50615 .77221 .50704 .76879 .50866 .75583 .50774 .76893 Mtetra
.968 .709 .488 r
.50774 .76893 .50866 .75583 .51096 .57514 .51011 .58218 Mtetra
0 0 .079 r
.51011 .58218 .51096 .57514 .51246 .57154 .51164 .57187 Mtetra
.929 .966 .762 r
.51164 .57187 .51246 .57154 .51395 .57005 .51313 .56969 Mtetra
.677 .875 .973 r
.51313 .56969 .51395 .57005 .51543 .56951 .51462 .56911 Mtetra
.462 .795 .999 r
.51462 .56911 .51543 .56951 .51692 .56929 .51611 .56898 Mtetra
.498 .838 .998 r
.51611 .56898 .51692 .56929 .5184 .569 .51759 .56872 Mtetra
.614 .886 .99 r
.51759 .56872 .5184 .569 .51989 .56858 .51908 .56824 Mtetra
.628 .871 .988 r
.51908 .56824 .51989 .56858 .52138 .56817 .52057 .56777 Mtetra
.629 .854 .985 r
.52057 .56777 .52138 .56817 .52287 .56775 .52206 .56733 Mtetra
.624 .845 .984 r
.52206 .56733 .52287 .56775 .52436 .56732 .52355 .56691 Mtetra
.618 .847 .986 r
.52355 .56691 .52436 .56732 .52585 .56688 .52504 .56649 Mtetra
.615 .853 .989 r
.52504 .56649 .52585 .56688 .52734 .56645 .52653 .56608 Mtetra
.613 .859 .99 r
.52653 .56608 .52734 .56645 .52883 .56601 .52803 .56565 Mtetra
.611 .862 .991 r
.52803 .56565 .52883 .56601 .53033 .56557 .52952 .56523 Mtetra
.609 .865 .991 r
.52952 .56523 .53033 .56557 .53182 .56514 .53102 .5648 Mtetra
.607 .867 .992 r
.53102 .5648 .53182 .56514 .53332 .5647 .53251 .56437 Mtetra
.608 .87 .992 r
.53251 .56437 .53332 .5647 .53481 .56426 .53401 .56393 Mtetra
.616 .873 .99 r
.53401 .56393 .53481 .56426 .53631 .56373 .53551 .56347 Mtetra
.6 .89 .99 r
.53551 .56347 .53631 .56373 .53781 .56316 .537 .563 Mtetra
.557 .898 .979 r
.537 .563 .53781 .56316 .5393 .56278 .5385 .56254 Mtetra
.57 .884 .991 r
.5385 .56254 .5393 .56278 .54081 .56297 .54 .56211 Mtetra
.649 .73 .908 r
.54 .56211 .54081 .56297 .54231 .56399 .5415 .56172 Mtetra
.63 .547 .742 r
.5415 .56172 .54231 .56399 .54383 .56566 .54301 .56132 Mtetra
.611 .47 .665 r
.54301 .56132 .54383 .56566 .54534 .56707 .54451 .56089 Mtetra
.604 .442 .636 r
.54451 .56089 .54534 .56707 .54685 .56685 .54601 .56041 Mtetra
.603 .44 .634 r
.54601 .56041 .54685 .56685 .54835 .56598 .54751 .55991 Mtetra
.604 .444 .638 r
.54751 .55991 .54835 .56598 .54985 .56517 .54902 .55942 Mtetra
.605 .447 .642 r
.54902 .55942 .54985 .56517 .55136 .56467 .55052 .55896 Mtetra
.605 .448 .642 r
.55052 .55896 .55136 .56467 .55287 .56418 .55203 .55849 Mtetra
.55203 .55849 .55287 .56418 .55438 .56371 .55354 .55803 Mtetra
.604 .448 .643 r
.55354 .55803 .55438 .56371 .55589 .56326 .55505 .55758 Mtetra
.55505 .55758 .55589 .56326 .5574 .56283 .55655 .55713 Mtetra
.604 .447 .642 r
.55655 .55713 .5574 .56283 .55891 .5624 .55806 .55669 Mtetra
.55806 .55669 .55891 .5624 .56042 .56199 .55957 .55624 Mtetra
.604 .446 .642 r
.55957 .55624 .56042 .56199 .56193 .56159 .56109 .5558 Mtetra
.603 .446 .641 r
.56109 .5558 .56193 .56159 .56345 .56117 .5626 .55535 Mtetra
.5626 .55535 .56345 .56117 .56496 .56075 .56411 .55491 Mtetra
.56411 .55491 .56496 .56075 .56648 .56031 .56562 .55446 Mtetra
.604 .446 .64 r
.56562 .55446 .56648 .56031 .568 .55984 .56714 .554 Mtetra
.604 .446 .641 r
.56714 .554 .568 .55984 .56951 .55935 .56865 .55353 Mtetra
.56865 .55353 .56951 .55935 .57103 .55887 .57017 .55306 Mtetra
.612 .452 .641 r
.57017 .55306 .57103 .55887 .57254 .55804 .57169 .55243 Mtetra
.62 .46 .643 r
.57169 .55243 .57254 .55804 .57405 .55695 .5732 .55165 Mtetra
.6 .449 .648 r
.5732 .55165 .57405 .55695 .57558 .55669 .57472 .55131 Mtetra
.509 .384 .646 r
.57472 .55131 .57558 .55669 .57715 .5599 .57626 .55244 Mtetra
0 0 .43 r
.57626 .55244 .57715 .5599 .58166 .74714 .57793 .56154 Mtetra
.017 0 .424 r
.57793 .56154 .58166 .74714 .58335 .75165 .58249 .74916 Mtetra
0 .132 .653 r
.58249 .74916 .58335 .75165 .585 .75308 .58416 .75177 Mtetra
.576 .628 .866 r
.58416 .75177 .585 .75308 .58662 .75289 .58578 .75171 Mtetra
.69 .694 .849 r
.58578 .75171 .58662 .75289 .58823 .75232 .58739 .75105 Mtetra
.703 .687 .832 r
.58739 .75105 .58823 .75232 .58984 .75173 .589 .7503 Mtetra
.647 .642 .831 r
.589 .7503 .58984 .75173 .59146 .75144 .59062 .74987 Mtetra
.646 .625 .814 r
.59062 .74987 .59146 .75144 .59308 .75115 .59224 .74944 Mtetra
.644 .608 .799 r
.59224 .74944 .59308 .75115 .5947 .75081 .59386 .749 Mtetra
.641 .597 .789 r
.59386 .749 .5947 .75081 .59633 .75041 .59548 .74857 Mtetra
.641 .595 .787 r
.59548 .74857 .59633 .75041 .59795 .74998 .5971 .74814 Mtetra
.642 .595 .786 r
.5971 .74814 .59795 .74998 .59957 .74954 .59872 .74769 Mtetra
.644 .596 .785 r
.59872 .74769 .59957 .74954 .60119 .74912 .60034 .74723 Mtetra
.643 .592 .782 r
.60034 .74723 .60119 .74912 .60282 .74867 .60197 .74678 Mtetra
.64 .59 .782 r
.60197 .74678 .60282 .74867 .60444 .74817 .60359 .74635 Mtetra
.636 .594 .79 r
.60359 .74635 .60444 .74817 .60606 .74759 .60522 .74595 Mtetra
.638 .614 .809 r
.60522 .74595 .60606 .74759 .60769 .74699 .60685 .74557 Mtetra
.642 .641 .834 r
.60685 .74557 .60769 .74699 .60931 .74648 .60848 .74517 Mtetra
.647 .66 .848 r
.60848 .74517 .60931 .74648 .61094 .74617 .6101 .74475 Mtetra
.648 .645 .833 r
.6101 .74475 .61094 .74617 .61257 .74573 .61173 .74432 Mtetra
.651 .648 .834 r
.61173 .74432 .61257 .74573 .61419 .74488 .61337 .74387 Mtetra
.661 .72 .892 r
.61337 .74387 .61419 .74488 .61579 .74304 .615 .7434 Mtetra
0 0 0 r
.615 .7434 .61579 .74304 .61737 .74058 .61663 .74291 Mtetra
.485 .155 .333 r
.61663 .74291 .61737 .74058 .61894 .73811 .61826 .74256 Mtetra
.555 .279 .451 r
.61826 .74256 .61894 .73811 .62059 .73807 .61991 .74256 Mtetra
.526 .254 .445 r
.61991 .74256 .62059 .73807 .62222 .73783 .62155 .74213 Mtetra
.422 .161 .411 r
.62155 .74213 .62222 .73783 .62381 .7355 .62315 .74055 Mtetra
0 0 .176 r
.62315 .74055 .62381 .7355 .62012 .54678 .62461 .73371 Mtetra
.028 0 .427 r
.62461 .73371 .62012 .54678 .62149 .54037 .62079 .54178 Mtetra
.895 .877 .443 r
.62079 .54178 .62149 .54037 .62298 .53782 .62222 .5375 Mtetra
.772 .911 .934 r
.62222 .5375 .62298 .53782 .62452 .5372 .62375 .53655 Mtetra
.618 .784 .961 r
.62375 .53655 .62452 .5372 .62607 .53701 .6253 .53621 Mtetra
.553 .715 .948 r
.6253 .53621 .62607 .53701 .62763 .53697 .62686 .5361 Mtetra
.655 .735 .909 r
.62686 .5361 .62763 .53697 .62918 .53657 .62841 .53567 Mtetra
.653 .728 .904 r
.62841 .53567 .62918 .53657 .63073 .53612 .62996 .53525 Mtetra
.658 .737 .908 r
.62996 .53525 .63073 .53612 .63228 .53556 .63151 .5348 Mtetra
.677 .77 .921 r
.63151 .5348 .63228 .53556 .63382 .53477 .63306 .53428 Mtetra
.665 .845 .969 r
.63306 .53428 .63382 .53477 .63536 .53411 .63461 .53375 Mtetra
.661 .882 .98 r
.63461 .53375 .63536 .53411 .63692 .53377 .63616 .53317 Mtetra
.752 .829 .911 r
.63616 .53317 .63692 .53377 .6385 .53416 .6377 .53231 Mtetra
.646 .589 .776 r
.6377 .53231 .6385 .53416 .64011 .53532 .63925 .53184 Mtetra
.542 .445 .695 r
.63925 .53184 .64011 .53532 .64179 .53852 .64084 .53228 Mtetra
.162 .133 .575 r
.64084 .53228 .64179 .53852 .65 .72662 .6426 .53768 Mtetra
.053 0 .446 r
.6426 .53768 .65 .72662 .65187 .73238 .65099 .7295 Mtetra
0 0 .534 r
.65099 .7295 .65187 .73238 .65361 .73435 .6528 .73347 Mtetra
.461 .666 .951 r
.6528 .73347 .65361 .73435 .65528 .73458 .65447 .7336 Mtetra
.675 .731 .892 r
.65447 .7336 .65528 .73458 .65694 .73422 .65612 .73305 Mtetra
.717 .711 .843 r
.65612 .73305 .65694 .73422 .65858 .73335 .65777 .73222 Mtetra
.557 .653 .9 r
.65777 .73222 .65858 .73335 .66021 .732 .65944 .73218 Mtetra
.205 .726 .711 r
.65944 .73218 .66021 .732 .6618 .72986 .6611 .73174 Mtetra
.24 0 .181 r
.6611 .73174 .6618 .72986 .66332 .7259 .66273 .73044 Mtetra
0 0 .187 r
.66273 .73044 .66332 .7259 .65754 .53714 .66416 .72428 Mtetra
.047 0 .438 r
.66416 .72428 .65754 .53714 .65884 .52987 .65816 .53115 Mtetra
.95 .877 .47 r
.65816 .53115 .65884 .52987 .66031 .52708 .65955 .52621 Mtetra
.76 .766 .858 r
.65955 .52621 .66031 .52708 .66186 .52627 .6611 .52522 Mtetra
.636 .692 .885 r
.6611 .52522 .66186 .52627 .66343 .52589 .66267 .52487 Mtetra
.55 .662 .911 r
.66267 .52487 .66343 .52589 .66501 .52569 .66426 .52484 Mtetra
.673 .749 .908 r
.66426 .52484 .66501 .52569 .66657 .52489 .66582 .52433 Mtetra
.662 .824 .961 r
.66582 .52433 .66657 .52489 .66813 .52422 .66739 .52382 Mtetra
.635 .867 .986 r
.66739 .52382 .66813 .52422 .6697 .5238 .66896 .52332 Mtetra
.754 .865 .93 r
.66896 .52332 .6697 .5238 .6713 .52409 .67051 .52245 Mtetra
.658 .615 .794 r
.67051 .52245 .6713 .52409 .67294 .52509 .67208 .52192 Mtetra
.571 .475 .706 r
.67208 .52192 .67294 .52509 .67465 .52767 .67368 .52204 Mtetra
.258 .21 .611 r
.67368 .52204 .67465 .52767 .68476 .71611 .67547 .52618 Mtetra
.074 0 .457 r
.67547 .52618 .68476 .71611 .68676 .72303 .6858 .71851 Mtetra
0 .042 .559 r
.6858 .71851 .68676 .72303 .68856 .72522 .68773 .72368 Mtetra
.501 .559 .847 r
.68773 .72368 .68856 .72522 .69025 .72506 .68944 .72397 Mtetra
.666 .709 .879 r
.68944 .72397 .69025 .72506 .69191 .72434 .69112 .72346 Mtetra
.746 .774 .876 r
.69112 .72346 .69191 .72434 .69356 .72334 .69277 .72252 Mtetra
.676 .77 .922 r
.69277 .72252 .69356 .72334 .69524 .72288 .69444 .72196 Mtetra
.677 .747 .904 r
.69444 .72196 .69524 .72288 .69692 .7225 .69612 .72139 Mtetra
.676 .71 .874 r
.69612 .72139 .69692 .7225 .6986 .72212 .69779 .72082 Mtetra
.665 .673 .848 r
.69779 .72082 .6986 .72212 .70028 .72167 .69947 .72029 Mtetra
.658 .659 .84 r
.69947 .72029 .70028 .72167 .70196 .72119 .70115 .71979 Mtetra
.652 .654 .839 r
.70115 .71979 .70196 .72119 .70364 .72069 .70283 .71933 Mtetra
.642 .655 .847 r
.70283 .71933 .70364 .72069 .70532 .72015 .70452 .71893 Mtetra
.635 .675 .87 r
.70452 .71893 .70532 .72015 .707 .7196 .70621 .71856 Mtetra
.628 .705 .901 r
.70621 .71856 .707 .7196 .70868 .7191 .7079 .71822 Mtetra
.441 .66 .954 r
.7079 .71822 .70868 .7191 .7104 .71922 .70962 .7184 Mtetra
.559 .729 .954 r
.70962 .7184 .7104 .71922 .7121 .71905 .71132 .71824 Mtetra
.742 .792 .893 r
.71132 .71824 .7121 .71905 .71377 .71816 .71299 .71735 Mtetra
.94 .769 .642 r
.71299 .71735 .71377 .71816 .71521 .71312 .71443 .71232 Mtetra
.969 .69 .445 r
.71443 .71232 .71521 .71312 .70638 .51906 .70564 .51822 Mtetra
.947 .753 .61 r
.70564 .51822 .70638 .51906 .70768 .5131 .70694 .51223 Mtetra
.803 .779 .831 r
.70694 .51223 .70768 .5131 .70922 .51177 .70848 .5109 Mtetra
.646 .738 .916 r
.70848 .5109 .70922 .51177 .71082 .51137 .71008 .51049 Mtetra
.53 .69 .941 r
.71008 .51049 .71082 .51137 .71244 .51134 .7117 .51046 Mtetra
.728 .763 .88 r
.7117 .51046 .71244 .51134 .71401 .51055 .71328 .50967 Mtetra
.7 .754 .894 r
.71328 .50967 .71401 .51055 .7156 .5099 .71486 .50902 Mtetra
.533 .689 .939 r
.71486 .50902 .7156 .5099 .71722 .50987 .71649 .50899 Mtetra
.806 .362 0 r
.71649 .50899 .71722 .50987 .71905 .51329 .71831 .5124 Mtetra
.97 .683 .426 r
.71831 .5124 .71905 .51329 .73202 .70655 .73124 .70569 Mtetra
.92 .529 .149 r
.73124 .70569 .73202 .70655 .7341 .71255 .73332 .71171 Mtetra
0 .361 .824 r
.73332 .71171 .7341 .71255 .73589 .71361 .73512 .71277 Mtetra
.6 .742 .944 r
.73512 .71277 .73589 .71361 .7376 .71332 .73683 .71249 Mtetra
.798 .798 .852 r
.73683 .71249 .7376 .71332 .73925 .71199 .73848 .71119 Mtetra
.937 .779 .66 r
.73848 .71119 .73925 .71199 .7407 .70726 .73995 .70677 Mtetra
.972 .689 .435 r
.73995 .70677 .7407 .70726 .73042 .51233 .72976 .51272 Mtetra
.997 .809 .527 r
.72976 .51272 .73042 .51233 .73165 .50579 .73095 .50537 Mtetra
.871 .888 .844 r
.73095 .50537 .73165 .50579 .73319 .50431 .73248 .50375 Mtetra
.64 .825 .972 r
.73248 .50375 .73319 .50431 .73481 .50397 .73409 .50329 Mtetra
.493 .729 .977 r
.73409 .50329 .73481 .50397 .73645 .50406 .73573 .50325 Mtetra
.708 .776 .905 r
.73573 .50325 .73645 .50406 .73806 .50355 .73732 .50257 Mtetra
.696 .734 .88 r
.73732 .50257 .73806 .50355 .73966 .50297 .73892 .50193 Mtetra
.559 .665 .908 r
.73892 .50193 .73966 .50297 .74129 .50278 .74056 .50187 Mtetra
.729 .274 0 r
.74056 .50187 .74129 .50278 .74302 .50421 .7424 .50486 Mtetra
.97 .68 .42 r
.7424 .50486 .74302 .50421 .745 .50926 .75676 .69787 Mtetra
.583 .373 .561 r
.75676 .69787 .745 .50926 .75931 .69948 .75895 .70459 Mtetra
.622 .342 .473 r
.75895 .70459 .75931 .69948 .76134 .70374 .76078 .70589 Mtetra
.503 .161 .32 r
.76078 .70589 .76134 .70374 .76319 .7052 .76252 .70571 Mtetra
0 0 0 r
.76252 .70571 .76319 .7052 .76495 .70542 .76419 .70453 Mtetra
.928 .778 .675 r
.76419 .70453 .76495 .70542 .76656 .70333 .76567 .70052 Mtetra
.971 .686 .431 r
.76567 .70052 .76656 .70333 .76793 .69781 .75409 .50691 Mtetra
.587 .38 .567 r
.75409 .50691 .76793 .69781 .75632 .50558 .75515 .49832 Mtetra
.647 .466 .624 r
.75515 .49832 .75632 .50558 .75771 .50183 .75667 .4964 Mtetra
.61 .456 .648 r
.75667 .4964 .75771 .50183 .75932 .50119 .75829 .49584 Mtetra
.588 .442 .65 r
.75829 .49584 .75932 .50119 .76099 .50135 .75994 .49571 Mtetra
.597 .445 .646 r
.75994 .49571 .76099 .50135 .76264 .5012 .76157 .4954 Mtetra
.603 .447 .643 r
.76157 .4954 .76264 .5012 .76427 .50081 .7632 .49496 Mtetra
.602 .446 .642 r
.7632 .49496 .76427 .50081 .76591 .50043 .76483 .49452 Mtetra
.602 .445 .642 r
.76483 .49452 .76591 .50043 .76754 .50004 .76645 .49407 Mtetra
.602 .445 .641 r
.76645 .49407 .76754 .50004 .76917 .49962 .76808 .49361 Mtetra
.76808 .49361 .76917 .49962 .77081 .49919 .76971 .49315 Mtetra
.602 .445 .64 r
.76971 .49315 .77081 .49919 .77244 .49875 .77134 .49269 Mtetra
.603 .444 .64 r
.77134 .49269 .77244 .49875 .77408 .49831 .77297 .49222 Mtetra
.77297 .49222 .77408 .49831 .77571 .49785 .7746 .49174 Mtetra
.603 .444 .639 r
.7746 .49174 .77571 .49785 .77735 .4974 .77624 .49127 Mtetra
.77624 .49127 .77735 .4974 .77898 .49693 .77787 .49079 Mtetra
.77787 .49079 .77898 .49693 .78062 .49647 .7795 .49031 Mtetra
.7795 .49031 .78062 .49647 .78226 .49599 .78114 .48982 Mtetra
.78114 .48982 .78226 .49599 .78389 .49552 .78277 .48934 Mtetra
.603 .443 .639 r
.78277 .48934 .78389 .49552 .78553 .49504 .78441 .48885 Mtetra
.603 .443 .638 r
.78441 .48885 .78553 .49504 .78717 .49456 .78604 .48836 Mtetra
.78604 .48836 .78717 .49456 .78881 .49408 .78768 .48787 Mtetra
.78768 .48787 .78881 .49408 .79045 .49359 .78932 .48739 Mtetra
.78932 .48739 .79045 .49359 .79209 .4931 .79096 .48689 Mtetra
.79096 .48689 .79209 .4931 .79374 .49262 .7926 .4864 Mtetra
.7926 .4864 .79374 .49262 .79538 .49213 .79424 .48591 Mtetra
.79424 .48591 .79538 .49213 .79703 .49164 .79588 .48542 Mtetra
.79588 .48542 .79703 .49164 .79867 .49115 .79753 .48493 Mtetra
.79753 .48493 .79867 .49115 .80032 .49066 .79917 .48443 Mtetra
.79917 .48443 .80032 .49066 .80196 .49017 .80082 .48394 Mtetra
.80082 .48394 .80196 .49017 .80361 .48967 .80246 .48345 Mtetra
.80246 .48345 .80361 .48967 .80526 .48918 .80411 .48295 Mtetra
.80411 .48295 .80526 .48918 .80691 .48869 .80576 .48246 Mtetra
.80576 .48246 .80691 .48869 .80856 .48819 .80741 .48196 Mtetra
.80741 .48196 .80856 .48819 .81021 .4877 .80906 .48147 Mtetra
.80906 .48147 .81021 .4877 .81187 .4872 .81071 .48097 Mtetra
.81071 .48097 .81187 .4872 .81352 .48671 .81236 .48048 Mtetra
.81236 .48048 .81352 .48671 .81517 .48621 .81401 .47998 Mtetra
.81401 .47998 .81517 .48621 .81683 .48572 .81566 .47948 Mtetra
.81566 .47948 .81683 .48572 .81849 .48522 .81732 .47899 Mtetra
.81732 .47899 .81849 .48522 .82014 .48473 .81897 .47849 Mtetra
.81897 .47849 .82014 .48473 .8218 .48423 .82063 .47799 Mtetra
.82063 .47799 .8218 .48423 .82346 .48374 .82229 .47749 Mtetra
.82229 .47749 .82346 .48374 .82512 .48324 .82395 .477 Mtetra
.82395 .477 .82512 .48324 .82678 .48274 .8256 .4765 Mtetra
.8256 .4765 .82678 .48274 .82845 .48225 .82726 .476 Mtetra
.82726 .476 .82845 .48225 .83011 .48175 .82893 .4755 Mtetra
.82893 .4755 .83011 .48175 .83177 .48125 .83059 .475 Mtetra
.83059 .475 .83177 .48125 .83344 .48075 .83225 .4745 Mtetra
.83225 .4745 .83344 .48075 .8351 .48026 .83391 .474 Mtetra
.83391 .474 .8351 .48026 .83677 .47976 .83558 .47351 Mtetra
.83558 .47351 .83677 .47976 .83844 .47926 .83724 .47301 Mtetra
.83724 .47301 .83844 .47926 .84011 .47876 .83891 .4725 Mtetra
.83891 .4725 .84011 .47876 .84178 .47826 .84058 .472 Mtetra
.84058 .472 .84178 .47826 .84345 .47776 .84225 .4715 Mtetra
.84225 .4715 .84345 .47776 .84512 .47726 .84392 .471 Mtetra
.84392 .471 .84512 .47726 .84679 .47676 .84559 .4705 Mtetra
.84559 .4705 .84679 .47676 .84847 .47626 .84726 .47 Mtetra
.84726 .47 .84847 .47626 .85014 .47576 .84893 .4695 Mtetra
.84893 .4695 .85014 .47576 .85182 .47525 .85061 .46899 Mtetra
.85061 .46899 .85182 .47525 .85349 .47475 .85228 .46849 Mtetra
.85228 .46849 .85349 .47475 .85517 .47425 .85396 .46799 Mtetra
.85396 .46799 .85517 .47425 .85685 .47374 .85563 .46748 Mtetra
.85563 .46748 .85685 .47374 .85853 .47324 .85731 .46698 Mtetra
.85731 .46698 .85853 .47324 .86021 .47273 .85899 .46647 Mtetra
.85899 .46647 .86021 .47273 .86189 .47222 .86067 .46597 Mtetra
.86067 .46597 .86189 .47222 .86357 .47172 .86235 .46546 Mtetra
.603 .444 .638 r
.86235 .46546 .86357 .47172 .86525 .47121 .86403 .46495 Mtetra
.86403 .46495 .86525 .47121 .86694 .4707 .86571 .46445 Mtetra
.86571 .46445 .86694 .4707 .86862 .47018 .86739 .46394 Mtetra
.86739 .46394 .86862 .47018 .87031 .46967 .86908 .46343 Mtetra
.603 .444 .639 r
.86908 .46343 .87031 .46967 .87199 .46916 .87076 .46292 Mtetra
.87076 .46292 .87199 .46916 .87368 .46865 .87245 .46241 Mtetra
.87245 .46241 .87368 .46865 .87537 .46813 .87413 .4619 Mtetra
.87413 .4619 .87537 .46813 .87706 .46762 .87582 .46139 Mtetra
.87582 .46139 .87706 .46762 .87875 .4671 .87751 .46088 Mtetra
.87751 .46088 .87875 .4671 .88044 .46659 .8792 .46037 Mtetra
.8792 .46037 .88044 .46659 .88213 .46607 .88089 .45986 Mtetra
.88089 .45986 .88213 .46607 .88383 .46556 .88258 .45935 Mtetra
.88258 .45935 .88383 .46556 .88552 .46505 .88427 .45883 Mtetra
.88427 .45883 .88552 .46505 .88722 .46453 .88597 .45832 Mtetra
.88597 .45832 .88722 .46453 .88891 .46402 .88766 .45781 Mtetra
.88766 .45781 .88891 .46402 .89061 .4635 .88936 .4573 Mtetra
.88936 .4573 .89061 .4635 .89231 .46298 .89105 .45679 Mtetra
.89105 .45679 .89231 .46298 .89401 .46246 .89275 .45627 Mtetra
.603 .445 .639 r
.89275 .45627 .89401 .46246 .8957 .46194 .89445 .45576 Mtetra
.89445 .45576 .8957 .46194 .89741 .46142 .89615 .45525 Mtetra
.603 .445 .64 r
.89615 .45525 .89741 .46142 .89911 .4609 .89785 .45473 Mtetra
.604 .445 .64 r
.89785 .45473 .89911 .4609 .90081 .46037 .89955 .45422 Mtetra
.89955 .45422 .90081 .46037 .90251 .45984 .90125 .4537 Mtetra
.90125 .4537 .90251 .45984 .90421 .45931 .90295 .45318 Mtetra
.90295 .45318 .90421 .45931 .90592 .45877 .90466 .45267 Mtetra
.604 .446 .64 r
.90466 .45267 .90592 .45877 .90762 .45824 .90636 .45215 Mtetra
.604 .446 .641 r
.90636 .45215 .90762 .45824 .90933 .45769 .90807 .45163 Mtetra
.90807 .45163 .90933 .45769 .91103 .45716 .90978 .45112 Mtetra
.90978 .45112 .91103 .45716 .91274 .45664 .91149 .45061 Mtetra
.91149 .45061 .91274 .45664 .91446 .45616 .9132 .4501 Mtetra
.603 .446 .641 r
.9132 .4501 .91446 .45616 .91618 .45569 .91491 .44961 Mtetra
.603 .445 .641 r
.91491 .44961 .91618 .45569 .91791 .45533 .91662 .44912 Mtetra
.601 .443 .64 r
.91662 .44912 .91791 .45533 .9197 .4554 .91834 .44866 Mtetra
.599 .437 .634 r
.91834 .44866 .9197 .4554 .92142 .455 .92006 .44819 Mtetra
.6 .437 .633 r
.92006 .44819 .92142 .455 .92301 .4534 .92178 .4477 Mtetra
.607 .452 .646 r
.92178 .4477 .92301 .4534 .92442 .45037 .92349 .44714 Mtetra
.629 .512 .702 r
.92349 .44714 .92442 .45037 .92592 .44807 .9252 .44658 Mtetra
.66 .645 .824 r
.9252 .44658 .92592 .44807 .9275 .44647 .92691 .44604 Mtetra
.596 .865 .993 r
.92691 .44604 .9275 .44647 .9292 .44581 .92864 .44557 Mtetra
.508 .881 .975 r
.92864 .44557 .9292 .44581 .93093 .44539 .93037 .44511 Mtetra
.523 .88 .983 r
.93037 .44511 .93093 .44539 .93267 .44506 .93209 .44466 Mtetra
.585 .872 .994 r
.93209 .44466 .93267 .44506 .9344 .44458 .93382 .44418 Mtetra
.585 .874 .994 r
.93382 .44418 .9344 .44458 .93613 .44409 .93555 .4437 Mtetra
.587 .875 .994 r
.93555 .4437 .93613 .44409 .93785 .44361 .93728 .44321 Mtetra
.589 .876 .993 r
.93728 .44321 .93785 .44361 .93958 .44311 .939 .44272 Mtetra
.59 .877 .993 r
.939 .44272 .93958 .44311 .94131 .44262 .94073 .44223 Mtetra
.59 .879 .993 r
.94073 .44223 .94131 .44262 .94303 .44211 .94246 .44173 Mtetra
.588 .88 .993 r
.94246 .44173 .94303 .44211 .94476 .4416 .94419 .44123 Mtetra
.588 .882 .992 r
.94419 .44123 .94476 .4416 .94649 .44109 .94592 .44072 Mtetra
.588 .884 .992 r
.94592 .44072 .94649 .44109 .94822 .44057 .94765 .44021 Mtetra
.588 .886 .991 r
.94765 .44021 .94822 .44057 .94995 .44004 .94938 .43969 Mtetra
.59 .889 .99 r
.94938 .43969 .94995 .44004 .95168 .43951 .95111 .43916 Mtetra
.595 .893 .989 r
.95111 .43916 .95168 .43951 .9534 .43896 .95284 .43861 Mtetra
.603 .897 .988 r
.95284 .43861 .9534 .43896 .95513 .43839 .95457 .43804 Mtetra
.61 .901 .986 r
.95457 .43804 .95513 .43839 .95685 .43781 .9563 .43746 Mtetra
.62 .903 .985 r
.9563 .43746 .95685 .43781 .95858 .43721 .95802 .43685 Mtetra
.641 .908 .982 r
.95802 .43685 .95858 .43721 .96028 .43644 .95974 .43619 Mtetra
.599 .922 .97 r
.95974 .43619 .96028 .43644 .962 .4358 .96146 .43554 Mtetra
.6 .919 .973 r
.96146 .43554 .962 .4358 .96376 .4354 .96318 .43489 Mtetra
.764 .9 .937 r
.96318 .43489 .96376 .4354 .9656 .43563 .96486 .4339 Mtetra
.667 .623 .796 r
.96486 .4339 .9656 .43563 .96752 .43646 .96658 .43326 Mtetra
.582 .486 .71 r
.96658 .43326 .96752 .43646 .96962 .43854 .9684 .43327 Mtetra
.885 .483 .043 r
.40168 .60185 .40251 .60317 .40379 .60684 .40297 .6052 Mtetra
.939 .684 .525 r
.40297 .6052 .40379 .60684 .39869 .7935 .39782 .79202 Mtetra
.959 .624 .32 r
.39782 .79202 .39869 .7935 .39999 .79921 .39908 .79856 Mtetra
.257 .628 .961 r
.39908 .79856 .39999 .79921 .40148 .79947 .40057 .79886 Mtetra
.694 .804 .933 r
.40057 .79886 .40148 .79947 .40299 .79889 .40209 .79827 Mtetra
.782 .806 .873 r
.40209 .79827 .40299 .79889 .40452 .79786 .40362 .79721 Mtetra
.542 .756 .976 r
.40362 .79721 .40452 .79786 .40602 .79782 .40513 .79707 Mtetra
.646 .759 .931 r
.40513 .79707 .40602 .79782 .40754 .79742 .40664 .79667 Mtetra
.764 .776 .863 r
.40664 .79667 .40754 .79742 .40908 .79623 .40817 .79568 Mtetra
.913 .759 .677 r
.40817 .79568 .40908 .79623 .41081 .78899 .40981 .79132 Mtetra
.942 .691 .529 r
.40981 .79132 .41081 .78899 .41813 .60211 .41711 .6069 Mtetra
0 0 0 r
.41711 .6069 .41813 .60211 .41969 .59788 .41875 .59989 Mtetra
.314 0 .228 r
.41875 .59989 .41969 .59788 .42114 .59686 .42021 .59891 Mtetra
.492 .154 .323 r
.42021 .59891 .42114 .59686 .42257 .59653 .42164 .59868 Mtetra
.507 .176 .34 r
.42164 .59868 .42257 .59653 .424 .59651 .42307 .59851 Mtetra
.032 0 .079 r
.42307 .59851 .424 .59651 .42543 .59616 .42455 .59675 Mtetra
.809 .99 .738 r
.42455 .59675 .42543 .59616 .42687 .59578 .42602 .59507 Mtetra
.81 .778 .822 r
.42602 .59507 .42687 .59578 .42831 .59541 .42749 .59372 Mtetra
.673 .609 .775 r
.42749 .59372 .42831 .59541 .42974 .59508 .42894 .5931 Mtetra
.632 .564 .761 r
.42894 .5931 .42974 .59508 .43118 .59476 .43038 .59274 Mtetra
.613 .551 .762 r
.43038 .59274 .43118 .59476 .43262 .59442 .43181 .59252 Mtetra
.618 .563 .771 r
.43181 .59252 .43262 .59442 .43406 .594 .43325 .59227 Mtetra
.617 .577 .787 r
.43325 .59227 .43406 .594 .43551 .59356 .43469 .59203 Mtetra
.616 .599 .811 r
.43469 .59203 .43551 .59356 .43695 .5931 .43613 .59181 Mtetra
.618 .632 .842 r
.43613 .59181 .43695 .5931 .4384 .59269 .43757 .59158 Mtetra
.622 .663 .869 r
.43757 .59158 .4384 .59269 .43984 .59229 .43901 .59133 Mtetra
.63 .695 .892 r
.43901 .59133 .43984 .59229 .44129 .59188 .44045 .59103 Mtetra
.654 .728 .904 r
.44045 .59103 .44129 .59188 .44274 .5914 .4419 .59064 Mtetra
.67 .754 .913 r
.4419 .59064 .44274 .5914 .44419 .5909 .44335 .59017 Mtetra
.683 .765 .913 r
.44335 .59017 .44419 .5909 .44564 .59042 .4448 .58966 Mtetra
.75 .767 .867 r
.4448 .58966 .44564 .59042 .44709 .58965 .44626 .5888 Mtetra
.722 .744 .869 r
.44626 .5888 .44709 .58965 .44855 .5891 .44772 .58808 Mtetra
.63 .683 .882 r
.44772 .58808 .44855 .5891 .44999 .58914 .44916 .58778 Mtetra
0 .121 .671 r
.44916 .58778 .44999 .58914 .45136 .59235 .45057 .58937 Mtetra
.733 .45 0 r
.45057 .58937 .45136 .59235 .44885 .77995 .4519 .59469 Mtetra
0 0 .374 r
.4519 .59469 .44885 .77995 .45024 .78608 .44948 .77965 Mtetra
.492 .362 .632 r
.44948 .77965 .45024 .78608 .45176 .78684 .45098 .78119 Mtetra
.612 .456 .646 r
.45098 .78119 .45176 .78684 .4533 .78644 .45252 .78059 Mtetra
.621 .46 .643 r
.45252 .78059 .4533 .78644 .45485 .78562 .45406 .77978 Mtetra
.483 .362 .639 r
.45406 .77978 .45485 .78562 .45639 .78512 .45557 .7813 Mtetra
.409 .349 .679 r
.45557 .7813 .45639 .78512 .45793 .78476 .45707 .78287 Mtetra
.337 .417 .796 r
.45707 .78287 .45793 .78476 .45947 .7844 .45859 .78384 Mtetra
.404 .727 .99 r
.45859 .78384 .45947 .7844 .46101 .78404 .46012 .78389 Mtetra
.487 .871 .974 r
.46012 .78389 .46101 .78404 .46256 .78367 .46167 .78351 Mtetra
.587 .908 .98 r
.46167 .78351 .46256 .78367 .4641 .78327 .46321 .78298 Mtetra
.417 .811 .986 r
.46321 .78298 .4641 .78327 .46564 .78318 .46476 .78281 Mtetra
.5 .824 1 r
.46476 .78281 .46564 .78318 .46719 .78292 .4663 .78257 Mtetra
.69 .884 .97 r
.4663 .78257 .46719 .78292 .46874 .78206 .46785 .78192 Mtetra
.919 .871 .775 r
.46785 .78192 .46874 .78206 .47034 .77829 .46943 .77953 Mtetra
.994 .872 .582 r
.46943 .77953 .47034 .77829 .47465 .5905 .47106 .7739 Mtetra
0 0 .369 r
.47106 .7739 .47465 .5905 .47623 .58227 .47531 .58755 Mtetra
.284 .06 .387 r
.47531 .58755 .47623 .58227 .47771 .5805 .47682 .58441 Mtetra
.53 .252 .438 r
.47682 .58441 .47771 .5805 .47918 .58003 .47829 .58411 Mtetra
.558 .281 .451 r
.47829 .58411 .47918 .58003 .48064 .57999 .47975 .58415 Mtetra
.329 .079 .375 r
.47975 .58415 .48064 .57999 .48211 .57971 .48125 .58199 Mtetra
0 0 .068 r
.48125 .58199 .48211 .57971 .48358 .57925 .48274 .57959 Mtetra
.881 .991 .797 r
.48274 .57959 .48358 .57925 .48505 .5788 .48423 .57783 Mtetra
.734 .727 .844 r
.48423 .57783 .48505 .5788 .48652 .57834 .4857 .57699 Mtetra
.64 .634 .828 r
.4857 .57699 .48652 .57834 .48799 .57789 .48717 .57664 Mtetra
.609 .635 .852 r
.48717 .57664 .48799 .57789 .48946 .57744 .48864 .57644 Mtetra
.689 .71 .864 r
.48864 .57644 .48946 .57744 .49094 .57664 .49012 .57587 Mtetra
.71 .763 .894 r
.49012 .57587 .49094 .57664 .49242 .57591 .4916 .57522 Mtetra
.61 .759 .95 r
.4916 .57522 .49242 .57591 .49389 .57573 .49307 .57494 Mtetra
0 .195 .685 r
.49307 .57494 .49389 .57573 .49534 .57798 .49453 .57604 Mtetra
.775 .419 0 r
.49453 .57604 .49534 .57798 .49528 .76411 .49597 .58006 Mtetra
0 0 .39 r
.49597 .58006 .49528 .76411 .49676 .77323 .49595 .76588 Mtetra
.27 .194 .584 r
.49595 .76588 .49676 .77323 .49831 .77463 .49747 .7706 Mtetra
.428 .357 .675 r
.49747 .7706 .49831 .77463 .49988 .77439 .49902 .77214 Mtetra
.466 .461 .769 r
.49902 .77214 .49988 .77439 .50145 .77366 .50058 .77281 Mtetra
.404 .643 .954 r
.50058 .77281 .50145 .77366 .50301 .77329 .50215 .77304 Mtetra
.397 .809 .977 r
.50215 .77304 .50301 .77329 .50458 .77304 .50371 .77285 Mtetra
.682 .929 .969 r
.50371 .77285 .50458 .77304 .50615 .77221 .50529 .77213 Mtetra
.917 .899 .794 r
.50529 .77213 .50615 .77221 .50774 .76893 .50687 .76994 Mtetra
.993 .876 .593 r
.50687 .76994 .50774 .76893 .51011 .58218 .50846 .76471 Mtetra
0 0 .382 r
.50846 .76471 .51011 .58218 .51164 .57187 .5108 .57759 Mtetra
.197 0 .367 r
.5108 .57759 .51164 .57187 .51313 .56969 .5123 .57338 Mtetra
.509 .229 .424 r
.5123 .57338 .51313 .56969 .51462 .56911 .51379 .5729 Mtetra
.547 .265 .439 r
.51379 .5729 .51462 .56911 .51611 .56898 .51528 .57283 Mtetra
.377 .115 .384 r
.51528 .57283 .51611 .56898 .51759 .56872 .51677 .57114 Mtetra
.009 0 .136 r
.51677 .57114 .51759 .56872 .51908 .56824 .51827 .56879 Mtetra
.817 .987 .722 r
.51827 .56879 .51908 .56824 .52057 .56777 .51976 .567 Mtetra
.772 .775 .855 r
.51976 .567 .52057 .56777 .52206 .56733 .52125 .56597 Mtetra
.663 .645 .822 r
.52125 .56597 .52206 .56733 .52355 .56691 .52274 .56548 Mtetra
.633 .623 .823 r
.52274 .56548 .52355 .56691 .52504 .56649 .52423 .56516 Mtetra
.64 .639 .833 r
.52423 .56516 .52504 .56649 .52653 .56608 .52573 .56481 Mtetra
.654 .654 .838 r
.52573 .56481 .52653 .56608 .52803 .56565 .52722 .56438 Mtetra
.65 .652 .839 r
.52722 .56438 .52803 .56565 .52952 .56523 .52871 .56398 Mtetra
.639 .651 .846 r
.52871 .56398 .52952 .56523 .53102 .5648 .53021 .56363 Mtetra
.629 .661 .862 r
.53021 .56363 .53102 .5648 .53251 .56437 .53171 .56334 Mtetra
.628 .686 .885 r
.53171 .56334 .53251 .56437 .53401 .56393 .5332 .56304 Mtetra
.639 .721 .907 r
.5332 .56304 .53401 .56393 .53551 .56347 .5347 .56269 Mtetra
.657 .752 .92 r
.5347 .56269 .53551 .56347 .537 .563 .5362 .56226 Mtetra
.67 .767 .923 r
.5362 .56226 .537 .563 .5385 .56254 .5377 .56178 Mtetra
.69 .767 .911 r
.5377 .56178 .5385 .56254 .54 .56211 .5392 .56122 Mtetra
.7 .739 .882 r
.5392 .56122 .54 .56211 .5415 .56172 .5407 .5606 Mtetra
.692 .693 .846 r
.5407 .5606 .5415 .56172 .54301 .56132 .5422 .55998 Mtetra
.674 .652 .82 r
.5422 .55998 .54301 .56132 .54451 .56089 .5437 .55942 Mtetra
.66 .63 .809 r
.5437 .55942 .54451 .56089 .54601 .56041 .54521 .55893 Mtetra
.656 .628 .809 r
.54521 .55893 .54601 .56041 .54751 .55991 .54671 .55846 Mtetra
.656 .631 .813 r
.54671 .55846 .54751 .55991 .54902 .55942 .54821 .558 Mtetra
.657 .634 .816 r
.54821 .558 .54902 .55942 .55052 .55896 .54972 .55753 Mtetra
.656 .634 .816 r
.54972 .55753 .55052 .55896 .55203 .55849 .55123 .55707 Mtetra
.656 .634 .817 r
.55123 .55707 .55203 .55849 .55354 .55803 .55273 .55661 Mtetra
.655 .634 .817 r
.55273 .55661 .55354 .55803 .55505 .55758 .55424 .55616 Mtetra
.55424 .55616 .55505 .55758 .55655 .55713 .55575 .55571 Mtetra
.654 .634 .817 r
.55575 .55571 .55655 .55713 .55806 .55669 .55726 .55526 Mtetra
.654 .633 .817 r
.55726 .55526 .55806 .55669 .55957 .55624 .55877 .55481 Mtetra
.55877 .55481 .55957 .55624 .56109 .5558 .56028 .55436 Mtetra
.56028 .55436 .56109 .5558 .5626 .55535 .5618 .55392 Mtetra
.654 .632 .816 r
.5618 .55392 .5626 .55535 .56411 .55491 .56331 .55347 Mtetra
.56331 .55347 .56411 .55491 .56562 .55446 .56482 .55302 Mtetra
.655 .633 .816 r
.56482 .55302 .56562 .55446 .56714 .554 .56634 .55257 Mtetra
.656 .634 .816 r
.56634 .55257 .56714 .554 .56865 .55353 .56785 .55211 Mtetra
.656 .635 .818 r
.56785 .55211 .56865 .55353 .57017 .55306 .56937 .55165 Mtetra
.674 .644 .812 r
.56937 .55165 .57017 .55306 .57169 .55243 .57089 .55107 Mtetra
.692 .659 .813 r
.57089 .55107 .57169 .55243 .5732 .55165 .5724 .55039 Mtetra
.645 .654 .844 r
.5724 .55039 .5732 .55165 .57472 .55131 .57392 .55 Mtetra
.378 .515 .869 r
.57392 .55 .57472 .55131 .57626 .55244 .57546 .55058 Mtetra
0 0 .423 r
.57546 .55058 .57626 .55244 .57793 .56154 .57703 .5537 Mtetra
.968 .696 .463 r
.57703 .5537 .57793 .56154 .58249 .74916 .5815 .73869 Mtetra
.234 .153 .555 r
.5815 .73869 .58249 .74916 .58416 .75177 .58324 .7463 Mtetra
.572 .431 .651 r
.58324 .7463 .58416 .75177 .58578 .75171 .58487 .74646 Mtetra
.626 .471 .652 r
.58487 .74646 .58578 .75171 .58739 .75105 .58648 .74562 Mtetra
.634 .474 .649 r
.58648 .74562 .58739 .75105 .589 .7503 .58808 .74457 Mtetra
.604 .45 .647 r
.58808 .74457 .589 .7503 .59062 .74987 .5897 .74413 Mtetra
.604 .45 .646 r
.5897 .74413 .59062 .74987 .59224 .74944 .59131 .74368 Mtetra
.604 .451 .646 r
.59131 .74368 .59224 .74944 .59386 .749 .59293 .74322 Mtetra
.604 .45 .646 r
.59293 .74322 .59386 .749 .59548 .74857 .59455 .74275 Mtetra
.604 .45 .645 r
.59455 .74275 .59548 .74857 .5971 .74814 .59617 .74229 Mtetra
.611 .454 .645 r
.59617 .74229 .5971 .74814 .59872 .74769 .59778 .74168 Mtetra
.622 .46 .642 r
.59778 .74168 .59872 .74769 .60034 .74723 .5994 .7408 Mtetra
.599 .44 .638 r
.5994 .7408 .60034 .74723 .60197 .74678 .60102 .7404 Mtetra
.54 .4 .639 r
.60102 .7404 .60197 .74678 .60359 .74635 .60267 .74119 Mtetra
.446 .349 .652 r
.60267 .74119 .60359 .74635 .60522 .74595 .60435 .74305 Mtetra
.409 .389 .725 r
.60435 .74305 .60522 .74595 .60685 .74557 .60601 .74432 Mtetra
.374 .538 .889 r
.60601 .74432 .60685 .74557 .60848 .74517 .60766 .74487 Mtetra
.487 .843 .994 r
.60766 .74487 .60848 .74517 .6101 .74475 .6093 .74457 Mtetra
.546 .896 .977 r
.6093 .74457 .6101 .74475 .61173 .74432 .61092 .74408 Mtetra
.572 .892 .988 r
.61092 .74408 .61173 .74432 .61337 .74387 .61256 .74359 Mtetra
.447 .83 .987 r
.61256 .74359 .61337 .74387 .615 .7434 .61419 .74334 Mtetra
.289 .783 .88 r
.61419 .74334 .615 .7434 .61663 .74291 .61583 .74308 Mtetra
0 0 0 r
.61583 .74308 .61663 .74291 .61826 .74256 .61747 .7428 Mtetra
.007 0 0 r
.61747 .7428 .61826 .74256 .61991 .74256 .61911 .74256 Mtetra
.47 .889 .908 r
.61911 .74256 .61991 .74256 .62155 .74213 .62074 .742 Mtetra
.817 .958 .905 r
.62074 .742 .62155 .74213 .62315 .74055 .62236 .74072 Mtetra
.971 .899 .693 r
.62236 .74072 .62315 .74055 .62461 .73371 .62392 .73736 Mtetra
.853 .757 .245 r
.62392 .73736 .62461 .73371 .62079 .54178 .6253 .72798 Mtetra
.047 0 .434 r
.6253 .72798 .62079 .54178 .62222 .5375 .62157 .54102 Mtetra
.099 0 .275 r
.62157 .54102 .62222 .5375 .62375 .53655 .62304 .53775 Mtetra
0 0 0 r
.62304 .53775 .62375 .53655 .6253 .53621 .62455 .53593 Mtetra
.805 .921 .915 r
.62455 .53593 .6253 .53621 .62686 .5361 .62608 .53482 Mtetra
.66 .661 .839 r
.62608 .53482 .62686 .5361 .62841 .53567 .62763 .53435 Mtetra
.616 .634 .846 r
.62763 .53435 .62841 .53567 .62996 .53525 .62918 .53411 Mtetra
.6 .659 .879 r
.62918 .53411 .62996 .53525 .63151 .5348 .63074 .53393 Mtetra
.661 .737 .906 r
.63074 .53393 .63151 .5348 .63306 .53428 .63229 .53347 Mtetra
.674 .758 .914 r
.63229 .53347 .63306 .53428 .63461 .53375 .63384 .53296 Mtetra
.704 .772 .904 r
.63384 .53296 .63461 .53375 .63616 .53317 .63539 .53232 Mtetra
.776 .771 .849 r
.63539 .53232 .63616 .53317 .6377 .53231 .63692 .53122 Mtetra
.701 .706 .852 r
.63692 .53122 .6377 .53231 .63925 .53184 .63847 .53055 Mtetra
.491 .578 .87 r
.63847 .53055 .63925 .53184 .64084 .53228 .64005 .5308 Mtetra
.879 .498 .027 r
.64005 .5308 .64084 .53228 .6426 .53768 .6418 .53592 Mtetra
.965 .686 .454 r
.6418 .53592 .6426 .53768 .65099 .7295 .65019 .72897 Mtetra
.899 .481 .148 r
.65019 .72897 .65099 .7295 .6528 .73347 .65201 .7331 Mtetra
.328 .748 .976 r
.65201 .7331 .6528 .73347 .65447 .7336 .65368 .73309 Mtetra
.707 .857 .954 r
.65368 .73309 .65447 .7336 .65612 .73305 .65532 .73237 Mtetra
.759 .82 .901 r
.65532 .73237 .65612 .73305 .65777 .73222 .65696 .73142 Mtetra
.416 .667 .964 r
.65696 .73142 .65777 .73222 .65944 .73218 .65864 .7316 Mtetra
.541 .788 .989 r
.65864 .7316 .65944 .73218 .6611 .73174 .66031 .73138 Mtetra
.791 .908 .922 r
.66031 .73138 .6611 .73174 .66273 .73044 .66195 .73028 Mtetra
.973 .798 .606 r
.66195 .73028 .66273 .73044 .66416 .72428 .66339 .72425 Mtetra
.966 .691 .462 r
.66339 .72425 .66416 .72428 .65816 .53115 .65739 .52994 Mtetra
.912 .728 .64 r
.65739 .52994 .65816 .53115 .65955 .52621 .65877 .52489 Mtetra
.719 .678 .81 r
.65877 .52489 .65955 .52621 .6611 .52522 .66032 .524 Mtetra
.607 .648 .865 r
.66032 .524 .6611 .52522 .66267 .52487 .6619 .52379 Mtetra
.503 .626 .905 r
.6619 .52379 .66267 .52487 .66426 .52484 .6635 .52393 Mtetra
.653 .728 .904 r
.6635 .52393 .66426 .52484 .66582 .52433 .66507 .5235 Mtetra
.665 .753 .916 r
.66507 .5235 .66582 .52433 .66739 .52382 .66664 .52302 Mtetra
.679 .765 .916 r
.66664 .52302 .66739 .52382 .66896 .52332 .66821 .52248 Mtetra
.759 .776 .866 r
.66821 .52248 .66896 .52332 .67051 .52245 .66976 .52151 Mtetra
.714 .743 .874 r
.66976 .52151 .67051 .52245 .67208 .52192 .67132 .52079 Mtetra
.616 .668 .877 r
.67132 .52079 .67208 .52192 .67368 .52204 .6729 .52054 Mtetra
0 .213 .733 r
.6729 .52054 .67368 .52204 .67547 .52618 .67458 .5223 Mtetra
0 0 .477 r
.67458 .5223 .67547 .52618 .6858 .71851 .67642 .52783 Mtetra
.087 .008 .461 r
.67642 .52783 .6858 .71851 .68773 .72368 .68669 .71732 Mtetra
.388 .296 .629 r
.68669 .71732 .68773 .72368 .68944 .72397 .68853 .72049 Mtetra
.456 .397 .703 r
.68853 .72049 .68944 .72397 .69112 .72346 .69028 .72171 Mtetra
.493 .53 .823 r
.69028 .72171 .69112 .72346 .69277 .72252 .692 .72211 Mtetra
.568 .852 .997 r
.692 .72211 .69277 .72252 .69444 .72196 .69368 .72172 Mtetra
.66 .926 .973 r
.69368 .72172 .69444 .72196 .69612 .72139 .69535 .721 Mtetra
.739 .901 .951 r
.69535 .721 .69612 .72139 .69779 .72082 .69701 .72012 Mtetra
.681 .802 .94 r
.69701 .72012 .69779 .72082 .69947 .72029 .69868 .71952 Mtetra
.664 .78 .935 r
.69868 .71952 .69947 .72029 .70115 .71979 .70036 .719 Mtetra
.651 .771 .936 r
.70036 .719 .70115 .71979 .70283 .71933 .70204 .71853 Mtetra
.635 .765 .941 r
.70204 .71853 .70283 .71933 .70452 .71893 .70373 .71812 Mtetra
.624 .759 .943 r
.70373 .71812 .70452 .71893 .70621 .71856 .70542 .71775 Mtetra
.617 .756 .945 r
.70542 .71775 .70621 .71856 .7079 .71822 .70711 .71741 Mtetra
.418 .668 .965 r
.70711 .71741 .7079 .71822 .70962 .7184 .70883 .71759 Mtetra
.554 .733 .959 r
.70883 .71759 .70962 .7184 .71132 .71824 .71054 .71744 Mtetra
.741 .795 .897 r
.71054 .71744 .71132 .71824 .71299 .71735 .71221 .71656 Mtetra
.942 .772 .643 r
.71221 .71656 .71299 .71735 .71443 .71232 .71365 .71157 Mtetra
.969 .69 .445 r
.71365 .71157 .71443 .71232 .70564 .51822 .7049 .51743 Mtetra
.949 .756 .607 r
.7049 .51743 .70564 .51822 .70694 .51223 .7062 .51137 Mtetra
.805 .781 .831 r
.7062 .51137 .70694 .51223 .70848 .5109 .70774 .51003 Mtetra
.647 .739 .916 r
.70774 .51003 .70848 .5109 .71008 .51049 .70934 .50962 Mtetra
.53 .691 .941 r
.70934 .50962 .71008 .51049 .7117 .51046 .71096 .50959 Mtetra
.729 .764 .881 r
.71096 .50959 .7117 .51046 .71328 .50967 .71254 .50879 Mtetra
.701 .755 .894 r
.71254 .50879 .71328 .50967 .71486 .50902 .71413 .50814 Mtetra
.533 .69 .94 r
.71413 .50814 .71486 .50902 .71649 .50899 .71575 .5081 Mtetra
.807 .363 0 r
.71575 .5081 .71649 .50899 .71831 .5124 .71757 .51151 Mtetra
.97 .683 .426 r
.71757 .51151 .71831 .5124 .73124 .70569 .73047 .70487 Mtetra
.921 .53 .155 r
.73047 .70487 .73124 .70569 .73332 .71171 .73255 .71088 Mtetra
0 .356 .82 r
.73255 .71088 .73332 .71171 .73512 .71277 .73434 .71194 Mtetra
.597 .746 .948 r
.73434 .71194 .73512 .71277 .73683 .71249 .73606 .71167 Mtetra
.798 .802 .855 r
.73606 .71167 .73683 .71249 .73848 .71119 .73771 .71037 Mtetra
.936 .779 .661 r
.73771 .71037 .73848 .71119 .73995 .70677 .73918 .70599 Mtetra
.971 .689 .436 r
.73918 .70599 .73995 .70677 .72976 .51272 .72904 .51196 Mtetra
.96 .751 .576 r
.72904 .51196 .72976 .51272 .73095 .50537 .73022 .50452 Mtetra
.834 .788 .808 r
.73022 .50452 .73095 .50537 .73248 .50375 .73175 .50289 Mtetra
.659 .747 .915 r
.73175 .50289 .73248 .50375 .73409 .50329 .73336 .50243 Mtetra
.531 .694 .943 r
.73336 .50243 .73409 .50329 .73573 .50325 .735 .50239 Mtetra
.713 .764 .892 r
.735 .50239 .73573 .50325 .73732 .50257 .73659 .50167 Mtetra
.703 .753 .891 r
.73659 .50167 .73732 .50257 .73892 .50193 .73819 .50101 Mtetra
.541 .684 .932 r
.73819 .50101 .73892 .50193 .74056 .50187 .73983 .50096 Mtetra
.786 .341 0 r
.73983 .50096 .74056 .50187 .7424 .50486 .7417 .50436 Mtetra
.971 .681 .417 r
.7417 .50436 .7424 .50486 .75676 .69787 .75611 .69876 Mtetra
.886 .518 .341 r
.75611 .69876 .75676 .69787 .75895 .70459 .75823 .70451 Mtetra
.549 0 0 r
.75823 .70451 .75895 .70459 .76078 .70589 .76005 .70557 Mtetra
.521 .862 .993 r
.76005 .70557 .76078 .70589 .76252 .70571 .76178 .70519 Mtetra
.837 .877 .872 r
.76178 .70519 .76252 .70571 .76419 .70453 .76343 .70374 Mtetra
.945 .781 .647 r
.76343 .70374 .76419 .70453 .76567 .70052 .76486 .69902 Mtetra
.972 .687 .427 r
.76486 .69902 .76567 .70052 .75409 .50691 .75315 .5028 Mtetra
.824 .609 .612 r
.75315 .5028 .75409 .50691 .75515 .49832 .75435 .49629 Mtetra
.758 .634 .724 r
.75435 .49629 .75515 .49832 .75667 .4964 .75588 .49452 Mtetra
.655 .594 .774 r
.75588 .49452 .75667 .4964 .75829 .49584 .7575 .49396 Mtetra
.598 .565 .787 r
.7575 .49396 .75829 .49584 .75994 .49571 .75915 .49382 Mtetra
.613 .572 .784 r
.75915 .49382 .75994 .49571 .76157 .4954 .76079 .49358 Mtetra
.626 .585 .788 r
.76079 .49358 .76157 .4954 .7632 .49496 .76242 .49325 Mtetra
.626 .596 .8 r
.76242 .49325 .7632 .49496 .76483 .49452 .76406 .49293 Mtetra
.638 .615 .811 r
.76406 .49293 .76483 .49452 .76645 .49407 .76569 .49254 Mtetra
.648 .627 .815 r
.76569 .49254 .76645 .49407 .76808 .49361 .76732 .49209 Mtetra
.651 .629 .815 r
.76732 .49209 .76808 .49361 .76971 .49315 .76895 .49162 Mtetra
.651 .628 .814 r
.76895 .49162 .76971 .49315 .77134 .49269 .77058 .49115 Mtetra
.77058 .49115 .77134 .49269 .77297 .49222 .77221 .49068 Mtetra
.652 .628 .813 r
.77221 .49068 .77297 .49222 .7746 .49174 .77384 .49021 Mtetra
.77384 .49021 .7746 .49174 .77624 .49127 .77547 .48973 Mtetra
.652 .629 .813 r
.77547 .48973 .77624 .49127 .77787 .49079 .77711 .48925 Mtetra
.653 .629 .813 r
.77711 .48925 .77787 .49079 .7795 .49031 .77874 .48877 Mtetra
.77874 .48877 .7795 .49031 .78114 .48982 .78038 .48828 Mtetra
.78038 .48828 .78114 .48982 .78277 .48934 .78201 .4878 Mtetra
.78201 .4878 .78277 .48934 .78441 .48885 .78365 .48731 Mtetra
.654 .629 .813 r
.78365 .48731 .78441 .48885 .78604 .48836 .78528 .48682 Mtetra
.78528 .48682 .78604 .48836 .78768 .48787 .78692 .48633 Mtetra
.78692 .48633 .78768 .48787 .78932 .48739 .78856 .48584 Mtetra
.78856 .48584 .78932 .48739 .79096 .48689 .7902 .48535 Mtetra
.7902 .48535 .79096 .48689 .7926 .4864 .79184 .48486 Mtetra
.79184 .48486 .7926 .4864 .79424 .48591 .79348 .48437 Mtetra
.79348 .48437 .79424 .48591 .79588 .48542 .79513 .48387 Mtetra
.79513 .48387 .79588 .48542 .79753 .48493 .79677 .48338 Mtetra
.79677 .48338 .79753 .48493 .79917 .48443 .79841 .48288 Mtetra
.79841 .48288 .79917 .48443 .80082 .48394 .80006 .48239 Mtetra
.80006 .48239 .80082 .48394 .80246 .48345 .80171 .4819 Mtetra
.80171 .4819 .80246 .48345 .80411 .48295 .80335 .4814 Mtetra
.80335 .4814 .80411 .48295 .80576 .48246 .805 .48091 Mtetra
.805 .48091 .80576 .48246 .80741 .48196 .80665 .48041 Mtetra
.80665 .48041 .80741 .48196 .80906 .48147 .8083 .47991 Mtetra
.8083 .47991 .80906 .48147 .81071 .48097 .80995 .47942 Mtetra
.80995 .47942 .81071 .48097 .81236 .48048 .8116 .47892 Mtetra
.8116 .47892 .81236 .48048 .81401 .47998 .81326 .47842 Mtetra
.81326 .47842 .81401 .47998 .81566 .47948 .81491 .47793 Mtetra
.81491 .47793 .81566 .47948 .81732 .47899 .81656 .47743 Mtetra
.81656 .47743 .81732 .47899 .81897 .47849 .81822 .47693 Mtetra
.81822 .47693 .81897 .47849 .82063 .47799 .81988 .47643 Mtetra
.81988 .47643 .82063 .47799 .82229 .47749 .82153 .47594 Mtetra
.82153 .47594 .82229 .47749 .82395 .477 .82319 .47544 Mtetra
.82319 .47544 .82395 .477 .8256 .4765 .82485 .47494 Mtetra
.82485 .47494 .8256 .4765 .82726 .476 .82651 .47444 Mtetra
.82651 .47444 .82726 .476 .82893 .4755 .82817 .47394 Mtetra
.82817 .47394 .82893 .4755 .83059 .475 .82984 .47344 Mtetra
.82984 .47344 .83059 .475 .83225 .4745 .8315 .47294 Mtetra
.8315 .47294 .83225 .4745 .83391 .474 .83316 .47244 Mtetra
.83316 .47244 .83391 .474 .83558 .47351 .83483 .47194 Mtetra
.83483 .47194 .83558 .47351 .83724 .47301 .8365 .47144 Mtetra
.8365 .47144 .83724 .47301 .83891 .4725 .83816 .47094 Mtetra
.83816 .47094 .83891 .4725 .84058 .472 .83983 .47044 Mtetra
.83983 .47044 .84058 .472 .84225 .4715 .8415 .46994 Mtetra
.8415 .46994 .84225 .4715 .84392 .471 .84317 .46944 Mtetra
.84317 .46944 .84392 .471 .84559 .4705 .84484 .46893 Mtetra
.84484 .46893 .84559 .4705 .84726 .47 .84651 .46843 Mtetra
.84651 .46843 .84726 .47 .84893 .4695 .84819 .46793 Mtetra
.84819 .46793 .84893 .4695 .85061 .46899 .84986 .46743 Mtetra
.84986 .46743 .85061 .46899 .85228 .46849 .85153 .46692 Mtetra
.85153 .46692 .85228 .46849 .85396 .46799 .85321 .46642 Mtetra
.85321 .46642 .85396 .46799 .85563 .46748 .85489 .46591 Mtetra
.85489 .46591 .85563 .46748 .85731 .46698 .85656 .46541 Mtetra
.85656 .46541 .85731 .46698 .85899 .46647 .85824 .4649 Mtetra
.85824 .4649 .85899 .46647 .86067 .46597 .85992 .4644 Mtetra
.85992 .4644 .86067 .46597 .86235 .46546 .8616 .46389 Mtetra
.8616 .46389 .86235 .46546 .86403 .46495 .86328 .46338 Mtetra
.86328 .46338 .86403 .46495 .86571 .46445 .86497 .46287 Mtetra
.86497 .46287 .86571 .46445 .86739 .46394 .86665 .46236 Mtetra
.86665 .46236 .86739 .46394 .86908 .46343 .86833 .46186 Mtetra
.655 .629 .813 r
.86833 .46186 .86908 .46343 .87076 .46292 .87002 .46135 Mtetra
.87002 .46135 .87076 .46292 .87245 .46241 .8717 .46084 Mtetra
.8717 .46084 .87245 .46241 .87413 .4619 .87339 .46032 Mtetra
.87339 .46032 .87413 .4619 .87582 .46139 .87508 .45981 Mtetra
.655 .629 .812 r
.87508 .45981 .87582 .46139 .87751 .46088 .87677 .4593 Mtetra
.87677 .4593 .87751 .46088 .8792 .46037 .87846 .45879 Mtetra
.87846 .45879 .8792 .46037 .88089 .45986 .88015 .45828 Mtetra
.88015 .45828 .88089 .45986 .88258 .45935 .88184 .45777 Mtetra
.88184 .45777 .88258 .45935 .88427 .45883 .88353 .45725 Mtetra
.654 .629 .812 r
.88353 .45725 .88427 .45883 .88597 .45832 .88523 .45674 Mtetra
.88523 .45674 .88597 .45832 .88766 .45781 .88692 .45623 Mtetra
.88692 .45623 .88766 .45781 .88936 .4573 .88862 .45572 Mtetra
.88862 .45572 .88936 .4573 .89105 .45679 .89031 .4552 Mtetra
.654 .629 .813 r
.89031 .4552 .89105 .45679 .89275 .45627 .89201 .45469 Mtetra
.89201 .45469 .89275 .45627 .89445 .45576 .89371 .45418 Mtetra
.89371 .45418 .89445 .45576 .89615 .45525 .89541 .45366 Mtetra
.654 .63 .813 r
.89541 .45366 .89615 .45525 .89785 .45473 .89711 .45315 Mtetra
.655 .63 .813 r
.89711 .45315 .89785 .45473 .89955 .45422 .89881 .45264 Mtetra
.89881 .45264 .89955 .45422 .90125 .4537 .90052 .45212 Mtetra
.655 .63 .814 r
.90052 .45212 .90125 .4537 .90295 .45318 .90222 .45161 Mtetra
.655 .631 .814 r
.90222 .45161 .90295 .45318 .90466 .45267 .90392 .45109 Mtetra
.90392 .45109 .90466 .45267 .90636 .45215 .90563 .45058 Mtetra
.655 .631 .815 r
.90563 .45058 .90636 .45215 .90807 .45163 .90734 .45006 Mtetra
.654 .632 .815 r
.90734 .45006 .90807 .45163 .90978 .45112 .90905 .44955 Mtetra
.654 .632 .816 r
.90905 .44955 .90978 .45112 .91149 .45061 .91075 .44904 Mtetra
.653 .632 .816 r
.91075 .44904 .91149 .45061 .9132 .4501 .91247 .44854 Mtetra
.653 .631 .816 r
.91247 .44854 .9132 .4501 .91491 .44961 .91418 .44804 Mtetra
.652 .631 .816 r
.91418 .44804 .91491 .44961 .91662 .44912 .91589 .44754 Mtetra
.652 .629 .815 r
.91589 .44754 .91662 .44912 .91834 .44866 .91761 .44704 Mtetra
.648 .623 .811 r
.91761 .44704 .91834 .44866 .92006 .44819 .91933 .44656 Mtetra
.641 .619 .812 r
.91933 .44656 .92006 .44819 .92178 .4477 .92105 .44613 Mtetra
.627 .619 .823 r
.92105 .44613 .92178 .4477 .92349 .44714 .92279 .4458 Mtetra
.624 .648 .853 r
.92279 .4458 .92349 .44714 .9252 .44658 .92453 .44548 Mtetra
.626 .693 .892 r
.92453 .44548 .9252 .44658 .92691 .44604 .92627 .44514 Mtetra
.644 .747 .924 r
.92627 .44514 .92691 .44604 .92864 .44557 .928 .4447 Mtetra
.651 .759 .928 r
.928 .4447 .92864 .44557 .93037 .44511 .92973 .44423 Mtetra
.655 .757 .924 r
.92973 .44423 .93037 .44511 .93209 .44466 .93145 .44374 Mtetra
.654 .748 .918 r
.93145 .44374 .93209 .44466 .93382 .44418 .93318 .44326 Mtetra
.655 .747 .918 r
.93318 .44326 .93382 .44418 .93555 .4437 .9349 .44278 Mtetra
.656 .747 .917 r
.9349 .44278 .93555 .4437 .93728 .44321 .93663 .44229 Mtetra
.657 .747 .916 r
.93663 .44229 .93728 .44321 .939 .44272 .93836 .4418 Mtetra
.657 .747 .917 r
.93836 .4418 .939 .44272 .94073 .44223 .94009 .44131 Mtetra
.657 .748 .917 r
.94009 .44131 .94073 .44223 .94246 .44173 .94182 .44081 Mtetra
.657 .75 .918 r
.94182 .44081 .94246 .44173 .94419 .44123 .94355 .44032 Mtetra
.657 .752 .919 r
.94355 .44032 .94419 .44123 .94592 .44072 .94529 .43982 Mtetra
.658 .754 .921 r
.94529 .43982 .94592 .44072 .94765 .44021 .94702 .43932 Mtetra
.657 .757 .924 r
.94702 .43932 .94765 .44021 .94938 .43969 .94875 .43883 Mtetra
.66 .764 .927 r
.94875 .43883 .94938 .43969 .95111 .43916 .95049 .43831 Mtetra
.663 .77 .929 r
.95049 .43831 .95111 .43916 .95284 .43861 .95222 .43778 Mtetra
.67 .778 .93 r
.95222 .43778 .95284 .43861 .95457 .43804 .95395 .43722 Mtetra
.676 .782 .93 r
.95395 .43722 .95457 .43804 .9563 .43746 .95568 .43664 Mtetra
.682 .786 .929 r
.95568 .43664 .9563 .43746 .95802 .43685 .9574 .43603 Mtetra
.687 .787 .927 r
.9574 .43603 .95802 .43685 .95974 .43619 .95913 .4354 Mtetra
.694 .796 .928 r
.95913 .4354 .95974 .43619 .96146 .43554 .96085 .43473 Mtetra
.704 .797 .923 r
.96085 .43473 .96146 .43554 .96318 .43489 .96256 .43403 Mtetra
.795 .81 .864 r
.96256 .43403 .96318 .43489 .96486 .4339 .9642 .43279 Mtetra
.722 .735 .861 r
.9642 .43279 .96486 .4339 .96658 .43326 .9659 .43194 Mtetra
.599 .641 .863 r
.9659 .43194 .96658 .43326 .9684 .43327 .96769 .43174 Mtetra
.916 .524 .235 r
.40083 .60116 .40168 .60185 .40297 .6052 .40211 .60462 Mtetra
.937 .682 .526 r
.40211 .60462 .40297 .6052 .39782 .79202 .3969 .79174 Mtetra
.922 .594 .403 r
.3969 .79174 .39782 .79202 .39908 .79856 .39818 .79795 Mtetra
.267 .64 .964 r
.39818 .79795 .39908 .79856 .40057 .79886 .39967 .79821 Mtetra
.696 .795 .926 r
.39967 .79821 .40057 .79886 .40209 .79827 .40118 .79762 Mtetra
.778 .798 .869 r
.40118 .79762 .40209 .79827 .40362 .79721 .40272 .79657 Mtetra
.604 .776 .963 r
.40272 .79657 .40362 .79721 .40513 .79707 .40423 .79628 Mtetra
.648 .749 .923 r
.40423 .79628 .40513 .79707 .40664 .79667 .40574 .79588 Mtetra
.715 .763 .89 r
.40574 .79588 .40664 .79667 .40817 .79568 .40727 .79518 Mtetra
.868 .812 .792 r
.40727 .79518 .40817 .79568 .40981 .79132 .40883 .7932 Mtetra
.631 .781 .33 r
.40883 .7932 .40981 .79132 .41711 .6069 .41043 .79012 Mtetra
.565 .358 .559 r
.41043 .79012 .41711 .6069 .41875 .59989 .4121 .78489 Mtetra
.573 .365 .561 r
.4121 .78489 .41875 .59989 .42021 .59891 .4136 .78493 Mtetra
.574 .366 .561 r
.4136 .78493 .42021 .59891 .42164 .59868 .41508 .7855 Mtetra
.571 .363 .56 r
.41508 .7855 .42164 .59868 .42307 .59851 .41663 .78399 Mtetra
0 0 .356 r
.41663 .78399 .42307 .59851 .42455 .59675 .42356 .60073 Mtetra
0 0 .019 r
.42356 .60073 .42455 .59675 .42602 .59507 .42514 .5956 Mtetra
.953 .947 .725 r
.42514 .5956 .42602 .59507 .42749 .59372 .42665 .59299 Mtetra
.754 .773 .869 r
.42665 .59299 .42749 .59372 .42894 .5931 .4281 .59212 Mtetra
.649 .696 .88 r
.4281 .59212 .42894 .5931 .43038 .59274 .42954 .59174 Mtetra
.584 .671 .899 r
.42954 .59174 .43038 .59274 .43181 .59252 .43097 .59161 Mtetra
.617 .703 .906 r
.43097 .59161 .43181 .59252 .43325 .59227 .43241 .59136 Mtetra
.615 .702 .907 r
.43241 .59136 .43325 .59227 .43469 .59203 .43385 .59112 Mtetra
.608 .698 .907 r
.43385 .59112 .43469 .59203 .43613 .59181 .43529 .59089 Mtetra
.607 .697 .907 r
.43529 .59089 .43613 .59181 .43757 .59158 .43673 .59068 Mtetra
.61 .701 .908 r
.43673 .59068 .43757 .59158 .43901 .59133 .43817 .59044 Mtetra
.62 .709 .909 r
.43817 .59044 .43901 .59133 .44045 .59103 .43961 .59018 Mtetra
.646 .724 .905 r
.43961 .59018 .44045 .59103 .4419 .59064 .44106 .58981 Mtetra
.663 .736 .904 r
.44106 .58981 .4419 .59064 .44335 .59017 .44251 .58938 Mtetra
.677 .746 .903 r
.44251 .58938 .44335 .59017 .4448 .58966 .44396 .58888 Mtetra
.725 .761 .881 r
.44396 .58888 .4448 .58966 .44626 .5888 .44542 .58816 Mtetra
.718 .796 .913 r
.44542 .58816 .44626 .5888 .44772 .58808 .44688 .5875 Mtetra
.653 .801 .954 r
.44688 .5875 .44772 .58808 .44916 .58778 .44833 .58707 Mtetra
.157 .536 .923 r
.44833 .58707 .44916 .58778 .45057 .58937 .44976 .58756 Mtetra
.23 .348 .778 r
.44976 .58756 .45057 .58937 .4519 .59469 .45118 .58876 Mtetra
.452 .335 .629 r
.45118 .58876 .4519 .59469 .44948 .77965 .45258 .59068 Mtetra
.574 .369 .566 r
.45258 .59068 .44948 .77965 .45098 .78119 .45403 .59059 Mtetra
.575 .37 .566 r
.45403 .59059 .45098 .78119 .45252 .78059 .4555 .58975 Mtetra
.574 .369 .566 r
.4555 .58975 .45252 .78059 .45406 .77978 .45695 .58969 Mtetra
.004 0 .403 r
.45695 .58969 .45406 .77978 .45557 .7813 .45495 .76673 Mtetra
.027 0 .458 r
.45495 .76673 .45557 .7813 .45707 .78287 .45623 .78002 Mtetra
0 .059 .598 r
.45623 .78002 .45707 .78287 .45859 .78384 .45771 .78292 Mtetra
.291 .567 .933 r
.45771 .78292 .45859 .78384 .46012 .78389 .45924 .78339 Mtetra
.605 .822 .983 r
.45924 .78339 .46012 .78389 .46167 .78351 .46078 .78302 Mtetra
.707 .845 .949 r
.46078 .78302 .46167 .78351 .46321 .78298 .46233 .78236 Mtetra
.625 .791 .962 r
.46233 .78236 .46321 .78298 .46476 .78281 .46388 .78199 Mtetra
.63 .742 .928 r
.46388 .78199 .46476 .78281 .4663 .78257 .46543 .78165 Mtetra
.684 .733 .887 r
.46543 .78165 .4663 .78257 .46785 .78192 .46698 .78108 Mtetra
.801 .767 .822 r
.46698 .78108 .46785 .78192 .46943 .77953 .46854 .77971 Mtetra
.92 .948 .797 r
.46854 .77971 .46943 .77953 .47106 .7739 .47012 .7776 Mtetra
.174 0 .284 r
.47012 .7776 .47106 .7739 .47531 .58755 .4717 .77486 Mtetra
.572 .364 .561 r
.4717 .77486 .47531 .58755 .47682 .58441 .47326 .77384 Mtetra
.573 .365 .561 r
.47326 .77384 .47682 .58441 .47829 .58411 .47481 .77383 Mtetra
.572 .365 .561 r
.47481 .77383 .47829 .58411 .47975 .58415 .47636 .77316 Mtetra
.558 .353 .559 r
.47636 .77316 .47975 .58415 .48125 .58199 .47803 .76378 Mtetra
0 0 .377 r
.47803 .76378 .48125 .58199 .48274 .57959 .48189 .58108 Mtetra
.907 .908 .506 r
.48189 .58108 .48274 .57959 .48423 .57783 .4834 .57724 Mtetra
.82 .812 .843 r
.4834 .57724 .48423 .57783 .4857 .57699 .48488 .57592 Mtetra
.648 .683 .87 r
.48488 .57592 .4857 .57699 .48717 .57664 .48636 .57555 Mtetra
.57 .649 .888 r
.48636 .57555 .48717 .57664 .48864 .57644 .48782 .57548 Mtetra
.652 .706 .886 r
.48782 .57548 .48864 .57644 .49012 .57587 .4893 .57509 Mtetra
.69 .757 .902 r
.4893 .57509 .49012 .57587 .4916 .57522 .49077 .57453 Mtetra
.642 .768 .94 r
.49077 .57453 .4916 .57522 .49307 .57494 .49225 .57415 Mtetra
.476 .682 .956 r
.49225 .57415 .49307 .57494 .49453 .57604 .49372 .57422 Mtetra
.418 .462 .799 r
.49372 .57422 .49453 .57604 .49597 .58006 .49519 .57492 Mtetra
.442 .339 .643 r
.49519 .57492 .49597 .58006 .49595 .76588 .49665 .57673 Mtetra
.531 .335 .56 r
.49665 .57673 .49595 .76588 .49747 .7706 .49794 .59972 Mtetra
0 0 .399 r
.49794 .59972 .49747 .7706 .49902 .77214 .49818 .76861 Mtetra
.119 .162 .632 r
.49818 .76861 .49902 .77214 .50058 .77281 .49972 .77156 Mtetra
.253 .469 .875 r
.49972 .77156 .50058 .77281 .50215 .77304 .50128 .77234 Mtetra
.584 .76 .962 r
.50128 .77234 .50215 .77304 .50371 .77285 .50285 .7721 Mtetra
.725 .781 .897 r
.50285 .7721 .50371 .77285 .50529 .77213 .50442 .77134 Mtetra
.807 .78 .827 r
.50442 .77134 .50529 .77213 .50687 .76994 .506 .76994 Mtetra
.916 .921 .803 r
.506 .76994 .50687 .76994 .50846 .76471 .50758 .76783 Mtetra
.062 0 .206 r
.50758 .76783 .50846 .76471 .5108 .57759 .50916 .76502 Mtetra
.571 .363 .56 r
.50916 .76502 .5108 .57759 .5123 .57338 .51074 .76344 Mtetra
.573 .365 .561 r
.51074 .76344 .5123 .57338 .51379 .5729 .51231 .76342 Mtetra
.572 .365 .561 r
.51231 .76342 .51379 .5729 .51528 .57283 .51388 .76282 Mtetra
.561 .356 .559 r
.51388 .76282 .51528 .57283 .51677 .57114 .51547 .75516 Mtetra
0 0 .394 r
.51547 .75516 .51677 .57114 .51827 .56879 .51745 .57064 Mtetra
.809 .842 .378 r
.51745 .57064 .51827 .56879 .51976 .567 .51895 .56658 Mtetra
.864 .849 .826 r
.51895 .56658 .51976 .567 .52125 .56597 .52044 .56494 Mtetra
.683 .704 .863 r
.52044 .56494 .52125 .56597 .52274 .56548 .52193 .56439 Mtetra
.615 .668 .878 r
.52193 .56439 .52274 .56548 .52423 .56516 .52342 .56415 Mtetra
.625 .688 .889 r
.52342 .56415 .52423 .56516 .52573 .56481 .52492 .56387 Mtetra
.657 .714 .89 r
.52492 .56387 .52573 .56481 .52722 .56438 .52641 .56345 Mtetra
.65 .713 .894 r
.52641 .56345 .52722 .56438 .52871 .56398 .52791 .56306 Mtetra
.634 .71 .902 r
.52791 .56306 .52871 .56398 .53021 .56363 .5294 .56273 Mtetra
.618 .709 .911 r
.5294 .56273 .53021 .56363 .53171 .56334 .5309 .56246 Mtetra
.617 .714 .915 r
.5309 .56246 .53171 .56334 .5332 .56304 .5324 .56219 Mtetra
.632 .726 .915 r
.5324 .56219 .5332 .56304 .5347 .56269 .5339 .56186 Mtetra
.654 .738 .911 r
.5339 .56186 .5347 .56269 .5362 .56226 .5354 .56144 Mtetra
.667 .746 .909 r
.5354 .56144 .5362 .56226 .5377 .56178 .5369 .56098 Mtetra
.686 .754 .903 r
.5369 .56098 .5377 .56178 .5392 .56122 .5384 .56043 Mtetra
.699 .761 .9 r
.5384 .56043 .5392 .56122 .5407 .5606 .5399 .55983 Mtetra
.699 .765 .903 r
.5399 .55983 .5407 .5606 .5422 .55998 .5414 .55922 Mtetra
.687 .766 .912 r
.5414 .55922 .5422 .55998 .5437 .55942 .5429 .55867 Mtetra
.671 .765 .921 r
.5429 .55867 .5437 .55942 .54521 .55893 .5444 .55819 Mtetra
.665 .765 .925 r
.5444 .55819 .54521 .55893 .54671 .55846 .54591 .55773 Mtetra
.663 .767 .927 r
.54591 .55773 .54671 .55846 .54821 .558 .54742 .55727 Mtetra
.664 .768 .927 r
.54742 .55727 .54821 .558 .54972 .55753 .54892 .5568 Mtetra
.663 .769 .928 r
.54892 .5568 .54972 .55753 .55123 .55707 .55043 .55634 Mtetra
.662 .769 .929 r
.55043 .55634 .55123 .55707 .55273 .55661 .55194 .55589 Mtetra
.55194 .55589 .55273 .55661 .55424 .55616 .55345 .55543 Mtetra
.661 .768 .929 r
.55345 .55543 .55424 .55616 .55575 .55571 .55495 .55498 Mtetra
.66 .768 .929 r
.55495 .55498 .55575 .55571 .55726 .55526 .55647 .55453 Mtetra
.55647 .55453 .55726 .55526 .55877 .55481 .55798 .55408 Mtetra
.66 .767 .929 r
.55798 .55408 .55877 .55481 .56028 .55436 .55949 .55363 Mtetra
.659 .767 .93 r
.55949 .55363 .56028 .55436 .5618 .55392 .561 .55319 Mtetra
.561 .55319 .5618 .55392 .56331 .55347 .56252 .55274 Mtetra
.659 .768 .93 r
.56252 .55274 .56331 .55347 .56482 .55302 .56403 .55229 Mtetra
.659 .769 .931 r
.56403 .55229 .56482 .55302 .56634 .55257 .56555 .55184 Mtetra
.66 .771 .932 r
.56555 .55184 .56634 .55257 .56785 .55211 .56706 .55139 Mtetra
.66 .773 .933 r
.56706 .55139 .56785 .55211 .56937 .55165 .56858 .55094 Mtetra
.678 .78 .927 r
.56858 .55094 .56937 .55165 .57089 .55107 .5701 .55042 Mtetra
.695 .798 .929 r
.5701 .55042 .57089 .55107 .5724 .55039 .57161 .54983 Mtetra
.641 .813 .966 r
.57161 .54983 .5724 .55039 .57392 .55 .57313 .5494 Mtetra
.415 .712 .985 r
.57313 .5494 .57392 .55 .57546 .55058 .57466 .54947 Mtetra
.099 .388 .846 r
.57466 .54947 .57546 .55058 .57703 .5537 .5762 .55045 Mtetra
.365 .336 .693 r
.5762 .55045 .57703 .5537 .5815 .73869 .57776 .55213 Mtetra
.571 .367 .566 r
.57776 .55213 .5815 .73869 .58324 .7463 .57932 .55392 Mtetra
.574 .369 .566 r
.57932 .55392 .58324 .7463 .58487 .74646 .58086 .55386 Mtetra
.575 .37 .566 r
.58086 .55386 .58487 .74646 .58648 .74562 .58238 .55301 Mtetra
.575 .371 .566 r
.58238 .55301 .58648 .74562 .58808 .74457 .5839 .55209 Mtetra
.575 .37 .566 r
.5839 .55209 .58808 .74457 .5897 .74413 .58542 .5516 Mtetra
.58542 .5516 .5897 .74413 .59131 .74368 .58695 .55111 Mtetra
.58695 .55111 .59131 .74368 .59293 .74322 .58848 .5506 Mtetra
.58848 .5506 .59293 .74322 .59455 .74275 .59001 .55008 Mtetra
.59001 .55008 .59455 .74275 .59617 .74229 .59154 .54957 Mtetra
.59154 .54957 .59617 .74229 .59778 .74168 .59307 .54881 Mtetra
.576 .371 .566 r
.59307 .54881 .59778 .74168 .5994 .7408 .59459 .54764 Mtetra
.574 .37 .566 r
.59459 .54764 .5994 .7408 .60102 .7404 .59613 .54729 Mtetra
.57 .366 .565 r
.59613 .54729 .60102 .7404 .60267 .74119 .59773 .54973 Mtetra
.051 0 .439 r
.59773 .54973 .60267 .74119 .60435 .74305 .60342 .7376 Mtetra
.107 .108 .575 r
.60342 .7376 .60435 .74305 .60601 .74432 .60516 .74257 Mtetra
.075 .272 .76 r
.60516 .74257 .60601 .74432 .60766 .74487 .60684 .74422 Mtetra
.531 .763 .982 r
.60684 .74422 .60766 .74487 .6093 .74457 .60848 .74407 Mtetra
.663 .847 .97 r
.60848 .74407 .6093 .74457 .61092 .74408 .61011 .74351 Mtetra
.687 .834 .954 r
.61011 .74351 .61092 .74408 .61256 .74359 .61173 .74289 Mtetra
.59 .769 .965 r
.61173 .74289 .61256 .74359 .61419 .74334 .61337 .74261 Mtetra
.6 .765 .958 r
.61337 .74261 .61419 .74334 .61583 .74308 .61501 .74232 Mtetra
.616 .762 .949 r
.61501 .74232 .61583 .74308 .61747 .7428 .61665 .74198 Mtetra
.636 .753 .933 r
.61665 .74198 .61747 .7428 .61911 .74256 .61829 .74159 Mtetra
.681 .734 .89 r
.61829 .74159 .61911 .74256 .62074 .742 .61992 .74101 Mtetra
.734 .745 .861 r
.61992 .74101 .62074 .742 .62236 .74072 .62154 .74013 Mtetra
.832 .837 .85 r
.62154 .74013 .62236 .74072 .62392 .73736 .62316 .73866 Mtetra
0 0 0 r
.62316 .73866 .62392 .73736 .6253 .72798 .62474 .7364 Mtetra
.343 .14 .454 r
.62474 .7364 .6253 .72798 .62157 .54102 .62626 .73178 Mtetra
.055 0 .437 r
.62626 .73178 .62157 .54102 .62304 .53775 .62242 .54205 Mtetra
0 0 .168 r
.62242 .54205 .62304 .53775 .62455 .53593 .62381 .53626 Mtetra
.935 .968 .726 r
.62381 .53626 .62455 .53593 .62608 .53482 .6253 .53387 Mtetra
.696 .731 .878 r
.6253 .53387 .62608 .53482 .62763 .53435 .62685 .53325 Mtetra
.599 .665 .886 r
.62685 .53325 .62763 .53435 .62918 .53411 .6284 .53307 Mtetra
.554 .657 .905 r
.6284 .53307 .62918 .53411 .63074 .53393 .62997 .53303 Mtetra
.654 .731 .905 r
.62997 .53303 .63074 .53393 .63229 .53347 .63152 .53261 Mtetra
.667 .741 .905 r
.63152 .53261 .63229 .53347 .63384 .53296 .63307 .53212 Mtetra
.697 .757 .898 r
.63307 .53212 .63384 .53296 .63539 .53232 .63462 .53151 Mtetra
.777 .781 .856 r
.63462 .53151 .63539 .53232 .63692 .53122 .63616 .53043 Mtetra
.708 .77 .901 r
.63616 .53043 .63692 .53122 .63847 .53055 .63771 .52976 Mtetra
.366 .633 .957 r
.63771 .52976 .63847 .53055 .64005 .5308 .63929 .53005 Mtetra
.93 .546 .204 r
.63929 .53005 .64005 .5308 .6418 .53592 .64105 .53543 Mtetra
.963 .684 .457 r
.64105 .53543 .6418 .53592 .65019 .72897 .64939 .72842 Mtetra
.894 .47 .13 r
.64939 .72842 .65019 .72897 .65201 .7331 .6512 .73239 Mtetra
.498 .733 .978 r
.6512 .73239 .65201 .7331 .65368 .73309 .65287 .73234 Mtetra
.719 .797 .913 r
.65287 .73234 .65368 .73309 .65532 .73237 .65452 .73158 Mtetra
.761 .795 .881 r
.65452 .73158 .65532 .73237 .65696 .73142 .65616 .73058 Mtetra
.44 .671 .96 r
.65616 .73058 .65696 .73142 .65864 .7316 .65784 .73073 Mtetra
.595 .73 .938 r
.65784 .73073 .65864 .7316 .66031 .73138 .65951 .73049 Mtetra
.774 .775 .854 r
.65951 .73049 .66031 .73138 .66195 .73028 .66114 .72935 Mtetra
.938 .746 .618 r
.66114 .72935 .66195 .73028 .66339 .72425 .66257 .72304 Mtetra
.964 .69 .464 r
.66257 .72304 .66339 .72425 .65739 .52994 .65662 .52874 Mtetra
.91 .729 .645 r
.65662 .52874 .65739 .52994 .65877 .52489 .65801 .52389 Mtetra
.733 .734 .852 r
.65801 .52389 .65877 .52489 .66032 .524 .65956 .52303 Mtetra
.592 .691 .911 r
.65956 .52303 .66032 .524 .6619 .52379 .66114 .52284 Mtetra
.469 .641 .932 r
.66114 .52284 .6619 .52379 .6635 .52393 .66274 .52301 Mtetra
.645 .724 .906 r
.66274 .52301 .6635 .52393 .66507 .5235 .66431 .52262 Mtetra
.658 .736 .908 r
.66431 .52262 .66507 .5235 .66664 .52302 .66588 .52217 Mtetra
.673 .749 .908 r
.66588 .52217 .66664 .52302 .66821 .52248 .66745 .52165 Mtetra
.734 .772 .883 r
.66745 .52165 .66821 .52248 .66976 .52151 .66901 .52084 Mtetra
.715 .807 .922 r
.66901 .52084 .66976 .52151 .67132 .52079 .67057 .52015 Mtetra
.644 .797 .956 r
.67057 .52015 .67132 .52079 .6729 .52054 .67215 .51971 Mtetra
.382 .631 .952 r
.67215 .51971 .6729 .52054 .67458 .5223 .67376 .52 Mtetra
.417 .423 .758 r
.67376 .52 .67458 .5223 .67642 .52783 .6754 .52098 Mtetra
.446 .328 .625 r
.6754 .52098 .67642 .52783 .68669 .71732 .67712 .52352 Mtetra
.101 .018 .466 r
.67712 .52352 .68669 .71732 .68853 .72049 .68737 .71182 Mtetra
.193 .139 .564 r
.68737 .71182 .68853 .72049 .69028 .72171 .68941 .7191 Mtetra
.182 .26 .71 r
.68941 .7191 .69028 .72171 .692 .72211 .69121 .72132 Mtetra
.542 .731 .962 r
.69121 .72132 .692 .72211 .69368 .72172 .6929 .7212 Mtetra
.709 .861 .954 r
.6929 .7212 .69368 .72172 .69535 .721 .69457 .72046 Mtetra
.779 .865 .913 r
.69457 .72046 .69535 .721 .69701 .72012 .69622 .71941 Mtetra
.686 .805 .938 r
.69622 .71941 .69701 .72012 .69868 .71952 .6979 .7188 Mtetra
.667 .793 .942 r
.6979 .7188 .69868 .71952 .70036 .719 .69958 .71826 Mtetra
.653 .785 .944 r
.69958 .71826 .70036 .719 .70204 .71853 .70126 .71777 Mtetra
.635 .774 .947 r
.70126 .71777 .70204 .71853 .70373 .71812 .70295 .71736 Mtetra
.622 .768 .95 r
.70295 .71736 .70373 .71812 .70542 .71775 .70464 .71699 Mtetra
.614 .765 .952 r
.70464 .71699 .70542 .71775 .70711 .71741 .70633 .71664 Mtetra
.408 .674 .969 r
.70633 .71664 .70711 .71741 .70883 .71759 .70805 .71682 Mtetra
.55 .739 .963 r
.70805 .71682 .70883 .71759 .71054 .71744 .70976 .71667 Mtetra
.741 .799 .899 r
.70976 .71667 .71054 .71744 .71221 .71656 .71143 .71578 Mtetra
.942 .773 .644 r
.71143 .71578 .71221 .71656 .71365 .71157 .71288 .71085 Mtetra
.969 .69 .445 r
.71288 .71085 .71365 .71157 .7049 .51743 .70417 .51666 Mtetra
.951 .757 .605 r
.70417 .51666 .7049 .51743 .7062 .51137 .70546 .51052 Mtetra
.806 .783 .831 r
.70546 .51052 .7062 .51137 .70774 .51003 .707 .50917 Mtetra
.648 .741 .917 r
.707 .50917 .70774 .51003 .70934 .50962 .7086 .50875 Mtetra
.531 .692 .942 r
.7086 .50875 .70934 .50962 .71096 .50959 .71022 .50872 Mtetra
.73 .765 .881 r
.71022 .50872 .71096 .50959 .71254 .50879 .7118 .50791 Mtetra
.701 .756 .894 r
.7118 .50791 .71254 .50879 .71413 .50814 .71339 .50726 Mtetra
.534 .691 .94 r
.71339 .50726 .71413 .50814 .71575 .5081 .71501 .50722 Mtetra
.808 .363 0 r
.71501 .50722 .71575 .5081 .71757 .51151 .71683 .51063 Mtetra
.97 .683 .426 r
.71683 .51063 .71757 .51151 .73047 .70487 .7297 .70405 Mtetra
.921 .53 .156 r
.7297 .70405 .73047 .70487 .73255 .71088 .73178 .71006 Mtetra
0 .355 .819 r
.73178 .71006 .73255 .71088 .73434 .71194 .73357 .71112 Mtetra
.596 .745 .948 r
.73357 .71112 .73434 .71194 .73606 .71167 .73529 .71084 Mtetra
.797 .801 .855 r
.73529 .71084 .73606 .71167 .73771 .71037 .73694 .70956 Mtetra
.936 .779 .662 r
.73694 .70956 .73771 .71037 .73918 .70599 .73841 .7052 Mtetra
.971 .689 .436 r
.73841 .7052 .73918 .70599 .72904 .51196 .72831 .5112 Mtetra
.961 .75 .575 r
.72831 .5112 .72904 .51196 .73022 .50452 .72949 .50366 Mtetra
.834 .788 .808 r
.72949 .50366 .73022 .50452 .73175 .50289 .73102 .50203 Mtetra
.659 .747 .915 r
.73102 .50203 .73175 .50289 .73336 .50243 .73263 .50156 Mtetra
.532 .695 .943 r
.73263 .50156 .73336 .50243 .735 .50239 .73427 .50152 Mtetra
.715 .763 .891 r
.73427 .50152 .735 .50239 .73659 .50167 .73586 .50079 Mtetra
.705 .759 .894 r
.73586 .50079 .73659 .50167 .73819 .50101 .73746 .50012 Mtetra
.541 .693 .938 r
.73746 .50012 .73819 .50101 .73983 .50096 .7391 .50006 Mtetra
.781 .335 0 r
.7391 .50006 .73983 .50096 .7417 .50436 .74096 .50341 Mtetra
.972 .682 .415 r
.74096 .50341 .7417 .50436 .75611 .69876 .75533 .69777 Mtetra
.904 .507 .092 r
.75533 .69777 .75611 .69876 .75823 .70451 .75746 .7036 Mtetra
0 .375 .838 r
.75746 .7036 .75823 .70451 .76005 .70557 .75929 .70469 Mtetra
.629 .744 .93 r
.75929 .70469 .76005 .70557 .76178 .70519 .76101 .70431 Mtetra
.811 .794 .836 r
.76101 .70431 .76178 .70519 .76343 .70374 .76267 .70286 Mtetra
.94 .772 .647 r
.76267 .70286 .76343 .70374 .76486 .69902 .7641 .69809 Mtetra
.973 .688 .426 r
.7641 .69809 .76486 .69902 .75315 .5028 .75241 .50176 Mtetra
.946 .744 .598 r
.75241 .50176 .75315 .5028 .75435 .49629 .75363 .49535 Mtetra
.838 .775 .792 r
.75363 .49535 .75435 .49629 .75588 .49452 .75516 .49358 Mtetra
.678 .739 .897 r
.75516 .49358 .75588 .49452 .7575 .49396 .75678 .49303 Mtetra
.569 .697 .927 r
.75678 .49303 .7575 .49396 .75915 .49382 .75842 .4929 Mtetra
.595 .71 .924 r
.75842 .4929 .75915 .49382 .76079 .49358 .76007 .49267 Mtetra
.617 .723 .922 r
.76007 .49267 .76079 .49358 .76242 .49325 .7617 .49237 Mtetra
.613 .728 .928 r
.7617 .49237 .76242 .49325 .76406 .49293 .76334 .49208 Mtetra
.634 .743 .927 r
.76334 .49208 .76406 .49293 .76569 .49254 .76498 .4917 Mtetra
.65 .753 .925 r
.76498 .4917 .76569 .49254 .76732 .49209 .76661 .49126 Mtetra
.657 .757 .924 r
.76661 .49126 .76732 .49209 .76895 .49162 .76824 .49079 Mtetra
.656 .758 .925 r
.76824 .49079 .76895 .49162 .77058 .49115 .76987 .49033 Mtetra
.656 .759 .926 r
.76987 .49033 .77058 .49115 .77221 .49068 .7715 .48986 Mtetra
.657 .76 .926 r
.7715 .48986 .77221 .49068 .77384 .49021 .77313 .48939 Mtetra
.658 .761 .926 r
.77313 .48939 .77384 .49021 .77547 .48973 .77477 .48891 Mtetra
.659 .762 .926 r
.77477 .48891 .77547 .48973 .77711 .48925 .7764 .48844 Mtetra
.66 .763 .926 r
.7764 .48844 .77711 .48925 .77874 .48877 .77803 .48795 Mtetra
.77803 .48795 .77874 .48877 .78038 .48828 .77967 .48747 Mtetra
.66 .764 .926 r
.77967 .48747 .78038 .48828 .78201 .4878 .78131 .48698 Mtetra
.661 .764 .926 r
.78131 .48698 .78201 .4878 .78365 .48731 .78294 .4865 Mtetra
.78294 .4865 .78365 .48731 .78528 .48682 .78458 .48601 Mtetra
.78458 .48601 .78528 .48682 .78692 .48633 .78622 .48552 Mtetra
.78622 .48552 .78692 .48633 .78856 .48584 .78786 .48503 Mtetra
.662 .764 .926 r
.78786 .48503 .78856 .48584 .7902 .48535 .7895 .48453 Mtetra
.7895 .48453 .7902 .48535 .79184 .48486 .79114 .48404 Mtetra
.79114 .48404 .79184 .48486 .79348 .48437 .79278 .48355 Mtetra
.79278 .48355 .79348 .48437 .79513 .48387 .79443 .48306 Mtetra
.79443 .48306 .79513 .48387 .79677 .48338 .79607 .48256 Mtetra
.79607 .48256 .79677 .48338 .79841 .48288 .79772 .48207 Mtetra
.79772 .48207 .79841 .48288 .80006 .48239 .79936 .48157 Mtetra
.79936 .48157 .80006 .48239 .80171 .4819 .80101 .48108 Mtetra
.80101 .48108 .80171 .4819 .80335 .4814 .80266 .48058 Mtetra
.80266 .48058 .80335 .4814 .805 .48091 .80431 .48008 Mtetra
.80431 .48008 .805 .48091 .80665 .48041 .80596 .47959 Mtetra
.80596 .47959 .80665 .48041 .8083 .47991 .80761 .47909 Mtetra
.80761 .47909 .8083 .47991 .80995 .47942 .80926 .47859 Mtetra
.80926 .47859 .80995 .47942 .8116 .47892 .81091 .4781 Mtetra
.81091 .4781 .8116 .47892 .81326 .47842 .81256 .4776 Mtetra
.81256 .4776 .81326 .47842 .81491 .47793 .81422 .4771 Mtetra
.81422 .4771 .81491 .47793 .81656 .47743 .81587 .4766 Mtetra
.81587 .4766 .81656 .47743 .81822 .47693 .81753 .47611 Mtetra
.81753 .47611 .81822 .47693 .81988 .47643 .81919 .47561 Mtetra
.81919 .47561 .81988 .47643 .82153 .47594 .82085 .47511 Mtetra
.82085 .47511 .82153 .47594 .82319 .47544 .82251 .47461 Mtetra
.82251 .47461 .82319 .47544 .82485 .47494 .82417 .47411 Mtetra
.82417 .47411 .82485 .47494 .82651 .47444 .82583 .47361 Mtetra
.82583 .47361 .82651 .47444 .82817 .47394 .82749 .47311 Mtetra
.82749 .47311 .82817 .47394 .82984 .47344 .82915 .47261 Mtetra
.82915 .47261 .82984 .47344 .8315 .47294 .83082 .47211 Mtetra
.83082 .47211 .8315 .47294 .83316 .47244 .83248 .47161 Mtetra
.83248 .47161 .83316 .47244 .83483 .47194 .83415 .47111 Mtetra
.83415 .47111 .83483 .47194 .8365 .47144 .83581 .47061 Mtetra
.83581 .47061 .8365 .47144 .83816 .47094 .83748 .47011 Mtetra
.83748 .47011 .83816 .47094 .83983 .47044 .83915 .46961 Mtetra
.83915 .46961 .83983 .47044 .8415 .46994 .84082 .46911 Mtetra
.84082 .46911 .8415 .46994 .84317 .46944 .84249 .4686 Mtetra
.84249 .4686 .84317 .46944 .84484 .46893 .84416 .4681 Mtetra
.84416 .4681 .84484 .46893 .84651 .46843 .84584 .4676 Mtetra
.84584 .4676 .84651 .46843 .84819 .46793 .84751 .4671 Mtetra
.84751 .4671 .84819 .46793 .84986 .46743 .84918 .46659 Mtetra
.84918 .46659 .84986 .46743 .85153 .46692 .85086 .46609 Mtetra
.85086 .46609 .85153 .46692 .85321 .46642 .85254 .46558 Mtetra
.85254 .46558 .85321 .46642 .85489 .46591 .85421 .46508 Mtetra
.85421 .46508 .85489 .46591 .85656 .46541 .85589 .46457 Mtetra
.85589 .46457 .85656 .46541 .85824 .4649 .85757 .46407 Mtetra
.85757 .46407 .85824 .4649 .85992 .4644 .85925 .46356 Mtetra
.85925 .46356 .85992 .4644 .8616 .46389 .86093 .46305 Mtetra
.663 .764 .926 r
.86093 .46305 .8616 .46389 .86328 .46338 .86261 .46254 Mtetra
.663 .764 .925 r
.86261 .46254 .86328 .46338 .86497 .46287 .8643 .46203 Mtetra
.8643 .46203 .86497 .46287 .86665 .46236 .86598 .46152 Mtetra
.86598 .46152 .86665 .46236 .86833 .46186 .86767 .46101 Mtetra
.86767 .46101 .86833 .46186 .87002 .46135 .86935 .4605 Mtetra
.86935 .4605 .87002 .46135 .8717 .46084 .87104 .45999 Mtetra
.87104 .45999 .8717 .46084 .87339 .46032 .87273 .45948 Mtetra
.87273 .45948 .87339 .46032 .87508 .45981 .87441 .45897 Mtetra
.663 .763 .924 r
.87441 .45897 .87508 .45981 .87677 .4593 .8761 .45845 Mtetra
.8761 .45845 .87677 .4593 .87846 .45879 .87779 .45794 Mtetra
.87779 .45794 .87846 .45879 .88015 .45828 .87949 .45743 Mtetra
.87949 .45743 .88015 .45828 .88184 .45777 .88118 .45691 Mtetra
.663 .762 .924 r
.88118 .45691 .88184 .45777 .88353 .45725 .88287 .4564 Mtetra
.88287 .4564 .88353 .45725 .88523 .45674 .88457 .45589 Mtetra
.88457 .45589 .88523 .45674 .88692 .45623 .88626 .45537 Mtetra
.88626 .45537 .88692 .45623 .88862 .45572 .88796 .45486 Mtetra
.88796 .45486 .88862 .45572 .89031 .4552 .88966 .45435 Mtetra
.88966 .45435 .89031 .4552 .89201 .45469 .89136 .45383 Mtetra
.89136 .45383 .89201 .45469 .89371 .45418 .89305 .45332 Mtetra
.89305 .45332 .89371 .45418 .89541 .45366 .89476 .45281 Mtetra
.89476 .45281 .89541 .45366 .89711 .45315 .89646 .45229 Mtetra
.662 .762 .924 r
.89646 .45229 .89711 .45315 .89881 .45264 .89816 .45178 Mtetra
.662 .763 .924 r
.89816 .45178 .89881 .45264 .90052 .45212 .89986 .45127 Mtetra
.662 .763 .925 r
.89986 .45127 .90052 .45212 .90222 .45161 .90157 .45075 Mtetra
.90157 .45075 .90222 .45161 .90392 .45109 .90327 .45024 Mtetra
.662 .764 .926 r
.90327 .45024 .90392 .45109 .90563 .45058 .90498 .44973 Mtetra
.90498 .44973 .90563 .45058 .90734 .45006 .90669 .44922 Mtetra
.661 .765 .927 r
.90669 .44922 .90734 .45006 .90905 .44955 .9084 .4487 Mtetra
.66 .765 .927 r
.9084 .4487 .90905 .44955 .91075 .44904 .91011 .4482 Mtetra
.66 .765 .928 r
.91011 .4482 .91075 .44904 .91247 .44854 .91182 .44769 Mtetra
.659 .764 .928 r
.91182 .44769 .91247 .44854 .91418 .44804 .91353 .44719 Mtetra
.658 .764 .928 r
.91353 .44719 .91418 .44804 .91589 .44754 .91525 .44669 Mtetra
.659 .764 .927 r
.91525 .44669 .91589 .44754 .91761 .44704 .91696 .44618 Mtetra
.654 .76 .927 r
.91696 .44618 .91761 .44704 .91933 .44656 .91868 .4457 Mtetra
.644 .754 .929 r
.91868 .4457 .91933 .44656 .92105 .44613 .92041 .44526 Mtetra
.62 .741 .933 r
.92041 .44526 .92105 .44613 .92279 .4458 .92214 .44491 Mtetra
.616 .736 .932 r
.92214 .44491 .92279 .4458 .92453 .44548 .92388 .44458 Mtetra
.622 .736 .928 r
.92388 .44458 .92453 .44548 .92627 .44514 .92562 .44422 Mtetra
.647 .743 .919 r
.92562 .44422 .92627 .44514 .928 .4447 .92735 .44377 Mtetra
.655 .743 .915 r
.92735 .44377 .928 .4447 .92973 .44423 .92908 .44329 Mtetra
.658 .743 .912 r
.92908 .44329 .92973 .44423 .93145 .44374 .9308 .4428 Mtetra
.656 .74 .912 r
.9308 .4428 .93145 .44374 .93318 .44326 .93253 .44231 Mtetra
.657 .739 .91 r
.93253 .44231 .93318 .44326 .9349 .44278 .93426 .44182 Mtetra
.657 .738 .91 r
.93426 .44182 .9349 .44278 .93663 .44229 .93598 .44133 Mtetra
.93598 .44133 .93663 .44229 .93836 .4418 .93771 .44084 Mtetra
.93771 .44084 .93836 .4418 .94009 .44131 .93945 .44035 Mtetra
.656 .739 .911 r
.93945 .44035 .94009 .44131 .94182 .44081 .94118 .43986 Mtetra
.655 .74 .912 r
.94118 .43986 .94182 .44081 .94355 .44032 .94291 .43938 Mtetra
.655 .742 .914 r
.94291 .43938 .94355 .44032 .94529 .43982 .94465 .4389 Mtetra
.655 .745 .916 r
.94465 .4389 .94529 .43982 .94702 .43932 .94638 .43841 Mtetra
.653 .748 .92 r
.94638 .43841 .94702 .43932 .94875 .43883 .94812 .43793 Mtetra
.655 .754 .923 r
.94812 .43793 .94875 .43883 .95049 .43831 .94986 .43744 Mtetra
.66 .761 .925 r
.94986 .43744 .95049 .43831 .95222 .43778 .95159 .43693 Mtetra
.668 .77 .926 r
.95159 .43693 .95222 .43778 .95395 .43722 .95333 .43638 Mtetra
.675 .776 .926 r
.95333 .43638 .95395 .43722 .95568 .43664 .95506 .4358 Mtetra
.682 .78 .925 r
.95506 .4358 .95568 .43664 .9574 .43603 .95678 .4352 Mtetra
.689 .784 .923 r
.95678 .4352 .9574 .43603 .95913 .4354 .9585 .43456 Mtetra
.696 .785 .92 r
.9585 .43456 .95913 .4354 .96085 .43473 .96022 .43389 Mtetra
.705 .787 .915 r
.96022 .43389 .96085 .43473 .96256 .43403 .96194 .43317 Mtetra
.798 .813 .864 r
.96194 .43317 .96256 .43403 .9642 .43279 .96358 .43192 Mtetra
.733 .792 .899 r
.96358 .43192 .9642 .43279 .9659 .43194 .96528 .43107 Mtetra
.571 .723 .945 r
.96528 .43107 .9659 .43194 .96769 .43174 .96707 .43088 Mtetra
.91 .541 .318 r
.39996 .60079 .40083 .60116 .40211 .60462 .40123 .60461 Mtetra
.936 .681 .527 r
.40123 .60461 .40211 .60462 .3969 .79174 .39597 .79191 Mtetra
.898 .567 .412 r
.39597 .79191 .3969 .79174 .39818 .79795 .39727 .79733 Mtetra
.307 .662 .973 r
.39727 .79733 .39818 .79795 .39967 .79821 .39876 .79754 Mtetra
.697 .79 .922 r
.39876 .79754 .39967 .79821 .40118 .79762 .40028 .79694 Mtetra
.773 .795 .871 r
.40028 .79694 .40118 .79762 .40272 .79657 .40181 .79593 Mtetra
.654 .789 .946 r
.40181 .79593 .40272 .79657 .40423 .79628 .40333 .79548 Mtetra
.65 .75 .923 r
.40333 .79548 .40423 .79628 .40574 .79588 .40484 .79508 Mtetra
.649 .748 .922 r
.40484 .79508 .40574 .79588 .40727 .79518 .40636 .79467 Mtetra
.644 .825 .97 r
.40636 .79467 .40727 .79518 .40883 .7932 .40787 .79423 Mtetra
.285 0 0 r
.40787 .79423 .40883 .7932 .41043 .79012 .40939 .79378 Mtetra
.51 .224 .416 r
.40939 .79378 .41043 .79012 .4121 .78489 .41091 .79334 Mtetra
.57 .326 .507 r
.41091 .79334 .4121 .78489 .4136 .78493 .41241 .79348 Mtetra
.558 .316 .505 r
.41241 .79348 .4136 .78493 .41508 .7855 .41393 .79328 Mtetra
.523 .281 .49 r
.41393 .79328 .41508 .7855 .41663 .78399 .41546 .79234 Mtetra
.213 .024 .394 r
.41546 .79234 .41663 .78399 .42356 .60073 .41714 .78669 Mtetra
0 0 .343 r
.41714 .78669 .42356 .60073 .42514 .5956 .4242 .59819 Mtetra
.816 .822 .342 r
.4242 .59819 .42514 .5956 .42665 .59299 .42577 .59319 Mtetra
.78 .993 .878 r
.42577 .59319 .42665 .59299 .4281 .59212 .42724 .59203 Mtetra
.472 .874 .958 r
.42724 .59203 .4281 .59212 .42954 .59174 .42868 .59165 Mtetra
.115 .662 .822 r
.42868 .59165 .42954 .59174 .43097 .59161 .43011 .59163 Mtetra
.31 .8 .866 r
.43011 .59163 .43097 .59161 .43241 .59136 .43155 .59133 Mtetra
.396 .846 .917 r
.43155 .59133 .43241 .59136 .43385 .59112 .43299 .59099 Mtetra
.477 .87 .968 r
.43299 .59099 .43385 .59112 .43529 .59089 .43443 .59064 Mtetra
.584 .879 .993 r
.43443 .59064 .43529 .59089 .43673 .59068 .43588 .59023 Mtetra
.643 .836 .975 r
.43588 .59023 .43673 .59068 .43817 .59044 .43733 .58979 Mtetra
.663 .78 .936 r
.43733 .58979 .43817 .59044 .43961 .59018 .43878 .58934 Mtetra
.659 .734 .905 r
.43878 .58934 .43961 .59018 .44106 .58981 .44022 .58893 Mtetra
.658 .722 .896 r
.44022 .58893 .44106 .58981 .44251 .58938 .44167 .58851 Mtetra
.66 .727 .899 r
.44167 .58851 .44251 .58938 .44396 .58888 .44312 .58809 Mtetra
.671 .747 .908 r
.44312 .58809 .44396 .58888 .44542 .58816 .44458 .58763 Mtetra
.666 .815 .955 r
.44458 .58763 .44542 .58816 .44688 .5875 .44603 .58715 Mtetra
.638 .865 .984 r
.44603 .58715 .44688 .5875 .44833 .58707 .44748 .58668 Mtetra
.62 .85 .986 r
.44748 .58668 .44833 .58707 .44976 .58756 .44893 .58627 Mtetra
.648 .645 .833 r
.44893 .58627 .44976 .58756 .45118 .58876 .45039 .58589 Mtetra
.621 .512 .708 r
.45039 .58589 .45118 .58876 .45258 .59068 .45184 .5855 Mtetra
.625 .467 .648 r
.45184 .5855 .45258 .59068 .45403 .59059 .4533 .58471 Mtetra
.612 .451 .639 r
.4533 .58471 .45403 .59059 .4555 .58975 .45477 .58407 Mtetra
.584 .432 .642 r
.45477 .58407 .4555 .58975 .45695 .58969 .45622 .58401 Mtetra
.343 .26 .616 r
.45622 .58401 .45695 .58969 .45495 .76673 .45761 .58696 Mtetra
0 0 .357 r
.45761 .58696 .45495 .76673 .45623 .78002 .45544 .7746 Mtetra
0 0 .386 r
.45544 .7746 .45623 .78002 .45771 .78292 .45684 .78128 Mtetra
.311 .433 .824 r
.45684 .78128 .45771 .78292 .45924 .78339 .45836 .78218 Mtetra
.641 .666 .859 r
.45836 .78218 .45924 .78339 .46078 .78302 .45991 .78182 Mtetra
.711 .69 .829 r
.45991 .78182 .46078 .78302 .46233 .78236 .46146 .78103 Mtetra
.66 .656 .834 r
.46146 .78103 .46233 .78236 .46388 .78199 .46301 .78055 Mtetra
.635 .63 .829 r
.46301 .78055 .46388 .78199 .46543 .78165 .46456 .78021 Mtetra
.638 .632 .828 r
.46456 .78021 .46543 .78165 .46698 .78108 .46611 .77985 Mtetra
.655 .667 .85 r
.46611 .77985 .46698 .78108 .46854 .77971 .46766 .77941 Mtetra
.613 .88 .99 r
.46766 .77941 .46854 .77971 .47012 .7776 .46921 .77892 Mtetra
.347 0 .119 r
.46921 .77892 .47012 .7776 .4717 .77486 .47076 .77843 Mtetra
.542 .252 .424 r
.47076 .77843 .4717 .77486 .47326 .77384 .47231 .77835 Mtetra
.544 .27 .451 r
.47231 .77835 .47326 .77384 .47481 .77383 .47386 .77817 Mtetra
.495 .224 .432 r
.47386 .77817 .47481 .77383 .47636 .77316 .47542 .77743 Mtetra
.117 0 .283 r
.47542 .77743 .47636 .77316 .47803 .76378 .47702 .77394 Mtetra
.961 .705 .501 r
.47702 .77394 .47803 .76378 .48189 .58108 .48097 .58705 Mtetra
0 0 0 r
.48097 .58705 .48189 .58108 .4834 .57724 .48257 .57739 Mtetra
.92 .944 .798 r
.48257 .57739 .4834 .57724 .48488 .57592 .48406 .57539 Mtetra
.7 .826 .943 r
.48406 .57539 .48488 .57592 .48636 .57555 .48553 .57479 Mtetra
.578 .731 .947 r
.48553 .57479 .48636 .57555 .48782 .57548 .487 .57462 Mtetra
.638 .723 .91 r
.487 .57462 .48782 .57548 .4893 .57509 .48848 .57427 Mtetra
.671 .745 .906 r
.48848 .57427 .4893 .57509 .49077 .57453 .48995 .5738 Mtetra
.662 .763 .925 r
.48995 .5738 .49077 .57453 .49225 .57415 .49143 .57335 Mtetra
.717 .759 .885 r
.49143 .57335 .49225 .57415 .49372 .57422 .49291 .57266 Mtetra
.674 .625 .791 r
.49291 .57266 .49372 .57422 .49519 .57492 .49439 .57205 Mtetra
.592 .496 .713 r
.49439 .57205 .49519 .57492 .49665 .57673 .49586 .57196 Mtetra
.38 .302 .642 r
.49586 .57196 .49665 .57673 .49794 .59972 .49732 .57419 Mtetra
.983 .722 .45 r
.49732 .57419 .49794 .59972 .49818 .76861 .49737 .75999 Mtetra
0 0 .429 r
.49737 .75999 .49818 .76861 .49972 .77156 .49886 .76952 Mtetra
.205 .32 .76 r
.49886 .76952 .49972 .77156 .50128 .77234 .50042 .77099 Mtetra
.606 .633 .851 r
.50042 .77099 .50128 .77234 .50285 .7721 .50199 .77079 Mtetra
.693 .673 .827 r
.50199 .77079 .50285 .7721 .50442 .77134 .50356 .7701 Mtetra
.688 .682 .839 r
.50356 .7701 .50442 .77134 .506 .76994 .50513 .76947 Mtetra
.652 .846 .975 r
.50513 .76947 .506 .76994 .50758 .76783 .5067 .76896 Mtetra
.288 0 .035 r
.5067 .76896 .50758 .76783 .50916 .76502 .50828 .76843 Mtetra
.532 .238 .413 r
.50828 .76843 .50916 .76502 .51074 .76344 .50985 .76825 Mtetra
.548 .278 .458 r
.50985 .76825 .51074 .76344 .51231 .76342 .51143 .76811 Mtetra
.508 .24 .444 r
.51143 .76811 .51231 .76342 .51388 .76282 .513 .76743 Mtetra
.249 .017 .353 r
.513 .76743 .51388 .76282 .51547 .75516 .51459 .7644 Mtetra
.964 .704 .492 r
.51459 .7644 .51547 .75516 .51745 .57064 .51661 .5793 Mtetra
0 0 .118 r
.51661 .5793 .51745 .57064 .51895 .56658 .51813 .56689 Mtetra
.941 .953 .752 r
.51813 .56689 .51895 .56658 .52044 .56494 .51963 .56456 Mtetra
.692 .871 .966 r
.51963 .56456 .52044 .56494 .52193 .56439 .52112 .56394 Mtetra
.49 .792 .998 r
.52112 .56394 .52193 .56439 .52342 .56415 .52261 .56379 Mtetra
.483 .816 .999 r
.52261 .56379 .52342 .56415 .52492 .56387 .52411 .56359 Mtetra
.567 .873 .994 r
.52411 .56359 .52492 .56387 .52641 .56345 .5256 .5632 Mtetra
.556 .876 .993 r
.5256 .5632 .52641 .56345 .52791 .56306 .5271 .5628 Mtetra
.577 .883 .992 r
.5271 .5628 .52791 .56306 .5294 .56273 .5286 .56237 Mtetra
.628 .868 .987 r
.5286 .56237 .5294 .56273 .5309 .56246 .53009 .5619 Mtetra
.659 .816 .959 r
.53009 .5619 .5309 .56246 .5324 .56219 .53159 .56143 Mtetra
.662 .76 .923 r
.53159 .56143 .5324 .56219 .5339 .56186 .53309 .56098 Mtetra
.658 .73 .902 r
.53309 .56098 .5339 .56186 .5354 .56144 .53459 .56055 Mtetra
.658 .726 .9 r
.53459 .56055 .5354 .56144 .5369 .56098 .53609 .56013 Mtetra
.661 .737 .906 r
.53609 .56013 .5369 .56098 .5384 .56043 .53759 .55968 Mtetra
.665 .763 .923 r
.53759 .55968 .5384 .56043 .5399 .55983 .53909 .55922 Mtetra
.661 .801 .95 r
.53909 .55922 .5399 .55983 .5414 .55922 .5406 .55875 Mtetra
.648 .839 .974 r
.5406 .55875 .5414 .55922 .5429 .55867 .5421 .55828 Mtetra
.633 .861 .985 r
.5421 .55828 .5429 .55867 .5444 .55819 .5436 .55782 Mtetra
.628 .865 .987 r
.5436 .55782 .5444 .55819 .54591 .55773 .54511 .55735 Mtetra
.628 .864 .987 r
.54511 .55735 .54591 .55773 .54742 .55727 .54662 .55689 Mtetra
.628 .862 .987 r
.54662 .55689 .54742 .55727 .54892 .5568 .54812 .55643 Mtetra
.627 .863 .987 r
.54812 .55643 .54892 .5568 .55043 .55634 .54963 .55597 Mtetra
.625 .863 .987 r
.54963 .55597 .55043 .55634 .55194 .55589 .55114 .55551 Mtetra
.624 .862 .988 r
.55114 .55551 .55194 .55589 .55345 .55543 .55265 .55505 Mtetra
.623 .862 .988 r
.55265 .55505 .55345 .55543 .55495 .55498 .55416 .5546 Mtetra
.622 .862 .988 r
.55416 .5546 .55495 .55498 .55647 .55453 .55567 .55415 Mtetra
.621 .861 .988 r
.55567 .55415 .55647 .55453 .55798 .55408 .55718 .5537 Mtetra
.62 .861 .988 r
.55718 .5537 .55798 .55408 .55949 .55363 .5587 .55325 Mtetra
.619 .861 .989 r
.5587 .55325 .55949 .55363 .561 .55319 .56021 .55281 Mtetra
.617 .861 .989 r
.56021 .55281 .561 .55319 .56252 .55274 .56172 .55237 Mtetra
.615 .863 .99 r
.56172 .55237 .56252 .55274 .56403 .55229 .56324 .55193 Mtetra
.614 .864 .99 r
.56324 .55193 .56403 .55229 .56555 .55184 .56476 .55148 Mtetra
.613 .866 .99 r
.56476 .55148 .56555 .55184 .56706 .55139 .56627 .55104 Mtetra
.614 .868 .99 r
.56627 .55104 .56706 .55139 .56858 .55094 .56779 .55059 Mtetra
.62 .871 .989 r
.56779 .55059 .56858 .55094 .5701 .55042 .56931 .55012 Mtetra
.613 .885 .99 r
.56931 .55012 .5701 .55042 .57161 .54983 .57083 .54964 Mtetra
.568 .899 .982 r
.57083 .54964 .57161 .54983 .57313 .5494 .57235 .54916 Mtetra
.566 .886 .99 r
.57235 .54916 .57313 .5494 .57466 .54947 .57387 .54873 Mtetra
.64 .759 .935 r
.57387 .54873 .57466 .54947 .5762 .55045 .57539 .54835 Mtetra
.63 .559 .756 r
.57539 .54835 .5762 .55045 .57776 .55213 .57692 .54797 Mtetra
.611 .473 .669 r
.57692 .54797 .57776 .55213 .57932 .55392 .57844 .54755 Mtetra
.602 .44 .635 r
.57844 .54755 .57932 .55392 .58086 .55386 .57997 .54707 Mtetra
.602 .436 .63 r
.57997 .54707 .58086 .55386 .58238 .55301 .58149 .54656 Mtetra
.603 .44 .634 r
.58149 .54656 .58238 .55301 .5839 .55209 .58302 .54606 Mtetra
.604 .444 .638 r
.58302 .54606 .5839 .55209 .58542 .5516 .58454 .54559 Mtetra
.603 .444 .639 r
.58454 .54559 .58542 .5516 .58695 .55111 .58607 .54511 Mtetra
.604 .444 .639 r
.58607 .54511 .58695 .55111 .58848 .5506 .5876 .54463 Mtetra
.604 .445 .639 r
.5876 .54463 .58848 .5506 .59001 .55008 .58913 .54415 Mtetra
.604 .445 .64 r
.58913 .54415 .59001 .55008 .59154 .54957 .59066 .54367 Mtetra
.61 .45 .64 r
.59066 .54367 .59154 .54957 .59307 .54881 .59219 .54306 Mtetra
.62 .458 .641 r
.59219 .54306 .59307 .54881 .59459 .54764 .59371 .54225 Mtetra
.602 .45 .647 r
.59371 .54225 .59459 .54764 .59613 .54729 .59525 .54186 Mtetra
.528 .398 .647 r
.59525 .54186 .59613 .54729 .59773 .54973 .59681 .54272 Mtetra
.017 .018 .513 r
.59681 .54272 .59773 .54973 .60342 .7376 .59851 .5499 Mtetra
.028 0 .431 r
.59851 .5499 .60342 .7376 .60516 .74257 .60429 .73982 Mtetra
0 .088 .62 r
.60429 .73982 .60516 .74257 .60684 .74422 .606 .74288 Mtetra
.562 .617 .865 r
.606 .74288 .60684 .74422 .60848 .74407 .60764 .74287 Mtetra
.685 .692 .851 r
.60764 .74287 .60848 .74407 .61011 .74351 .60927 .74225 Mtetra
.709 .69 .83 r
.60927 .74225 .61011 .74351 .61173 .74289 .61089 .74144 Mtetra
.649 .642 .829 r
.61089 .74144 .61173 .74289 .61337 .74261 .61253 .74099 Mtetra
.646 .62 .81 r
.61253 .74099 .61337 .74261 .61501 .74232 .61416 .74055 Mtetra
.639 .602 .796 r
.61416 .74055 .61501 .74232 .61665 .74198 .6158 .74014 Mtetra
.628 .59 .791 r
.6158 .74014 .61665 .74198 .61829 .74159 .61744 .7398 Mtetra
.63 .595 .796 r
.61744 .7398 .61829 .74159 .61992 .74101 .61908 .73945 Mtetra
.625 .616 .822 r
.61908 .73945 .61992 .74101 .62154 .74013 .62072 .73914 Mtetra
.565 .687 .923 r
.62072 .73914 .62154 .74013 .62316 .73866 .62237 .73903 Mtetra
0 0 0 r
.62237 .73903 .62316 .73866 .62474 .7364 .62401 .7385 Mtetra
.186 0 .182 r
.62401 .7385 .62474 .7364 .62626 .73178 .62561 .73686 Mtetra
0 0 .185 r
.62561 .73686 .62626 .73178 .62242 .54205 .62707 .73006 Mtetra
.032 0 .428 r
.62707 .73006 .62242 .54205 .62381 .53626 .62311 .5379 Mtetra
.837 .841 .375 r
.62311 .5379 .62381 .53626 .6253 .53387 .62455 .53356 Mtetra
.773 .912 .934 r
.62455 .53356 .6253 .53387 .62685 .53325 .62608 .5326 Mtetra
.619 .783 .96 r
.62608 .5326 .62685 .53325 .6284 .53307 .62763 .53225 Mtetra
.553 .713 .946 r
.62763 .53225 .6284 .53307 .62997 .53303 .6292 .53214 Mtetra
.661 .734 .904 r
.6292 .53214 .62997 .53303 .63152 .53261 .63075 .53169 Mtetra
.659 .727 .899 r
.63075 .53169 .63152 .53261 .63307 .53212 .6323 .53124 Mtetra
.675 .741 .9 r
.6323 .53124 .63307 .53212 .63462 .53151 .63386 .53072 Mtetra
.755 .782 .875 r
.63386 .53072 .63462 .53151 .63616 .53043 .6354 .5298 Mtetra
.676 .808 .945 r
.6354 .5298 .63616 .53043 .63771 .52976 .63695 .52926 Mtetra
.142 .59 .928 r
.63695 .52926 .63771 .52976 .63929 .53005 .63854 .52963 Mtetra
.926 .544 .25 r
.63854 .52963 .63929 .53005 .64105 .53543 .64029 .53487 Mtetra
.964 .684 .456 r
.64029 .53487 .64105 .53543 .64939 .72842 .64856 .72695 Mtetra
.783 .381 0 r
.64856 .72695 .64939 .72842 .6512 .73239 .65037 .731 Mtetra
.531 .597 .865 r
.65037 .731 .6512 .73239 .65287 .73234 .65205 .73113 Mtetra
.673 .689 .856 r
.65205 .73113 .65287 .73234 .65452 .73158 .6537 .73056 Mtetra
.725 .739 .863 r
.6537 .73056 .65452 .73158 .65616 .73058 .65535 .72973 Mtetra
.508 .697 .954 r
.65535 .72973 .65616 .73058 .65784 .73073 .65702 .72973 Mtetra
.643 .716 .901 r
.65702 .72973 .65784 .73073 .65951 .73049 .65869 .72932 Mtetra
.77 .727 .813 r
.65869 .72932 .65951 .73049 .66114 .72935 .66032 .72805 Mtetra
.919 .725 .624 r
.66032 .72805 .66114 .72935 .66257 .72304 .66176 .72185 Mtetra
.964 .69 .464 r
.66176 .72185 .66257 .72304 .65662 .52874 .65588 .52844 Mtetra
.963 .8 .631 r
.65588 .52844 .65662 .52874 .65801 .52389 .65727 .52351 Mtetra
.785 .9 .923 r
.65727 .52351 .65801 .52389 .65956 .52303 .65881 .5225 Mtetra
.604 .819 .982 r
.65881 .5225 .65956 .52303 .66114 .52284 .66039 .52214 Mtetra
.502 .723 .971 r
.66039 .52214 .66114 .52284 .66274 .52301 .66198 .5221 Mtetra
.652 .729 .905 r
.66198 .5221 .66274 .52301 .66431 .52262 .66355 .52168 Mtetra
.652 .722 .9 r
.66355 .52168 .66431 .52262 .66588 .52217 .66512 .52126 Mtetra
.655 .73 .904 r
.66512 .52126 .66588 .52217 .66745 .52165 .6667 .52082 Mtetra
.676 .755 .91 r
.6667 .52082 .66745 .52165 .66901 .52084 .66827 .52029 Mtetra
.668 .831 .962 r
.66827 .52029 .66901 .52084 .67057 .52015 .66984 .51975 Mtetra
.64 .872 .985 r
.66984 .51975 .67057 .52015 .67215 .51971 .67141 .51923 Mtetra
.751 .868 .933 r
.67141 .51923 .67215 .51971 .67376 .52 .67297 .51838 Mtetra
.658 .618 .798 r
.67297 .51838 .67376 .52 .6754 .52098 .67454 .51786 Mtetra
.571 .476 .708 r
.67454 .51786 .6754 .52098 .67712 .52352 .67615 .51797 Mtetra
.268 .218 .615 r
.67615 .51797 .67712 .52352 .68737 .71182 .67793 .52196 Mtetra
.073 0 .457 r
.67793 .52196 .68737 .71182 .68941 .7191 .68844 .71443 Mtetra
0 .037 .554 r
.68844 .71443 .68941 .7191 .69121 .72132 .69038 .71979 Mtetra
.489 .554 .849 r
.69038 .71979 .69121 .72132 .6929 .7212 .6921 .72013 Mtetra
.665 .713 .884 r
.6921 .72013 .6929 .7212 .69457 .72046 .69378 .71962 Mtetra
.747 .783 .882 r
.69378 .71962 .69457 .72046 .69622 .71941 .69544 .71868 Mtetra
.674 .792 .938 r
.69544 .71868 .69622 .71941 .6979 .7188 .69712 .71811 Mtetra
.666 .805 .95 r
.69712 .71811 .6979 .7188 .69958 .71826 .6988 .71757 Mtetra
.66 .802 .951 r
.6988 .71757 .69958 .71826 .70126 .71777 .70048 .71705 Mtetra
.633 .783 .953 r
.70048 .71705 .70126 .71777 .70295 .71736 .70216 .71663 Mtetra
.62 .778 .957 r
.70216 .71663 .70295 .71736 .70464 .71699 .70386 .71625 Mtetra
.612 .774 .958 r
.70386 .71625 .70464 .71699 .70633 .71664 .70555 .7159 Mtetra
.405 .682 .974 r
.70555 .7159 .70633 .71664 .70805 .71682 .70727 .71606 Mtetra
.552 .745 .966 r
.70727 .71606 .70805 .71682 .70976 .71667 .70897 .7159 Mtetra
.742 .802 .9 r
.70897 .7159 .70976 .71667 .71143 .71578 .71064 .71501 Mtetra
.941 .774 .646 r
.71064 .71501 .71143 .71578 .71288 .71085 .7121 .71012 Mtetra
.969 .69 .445 r
.7121 .71012 .71288 .71085 .70417 .51666 .70343 .51592 Mtetra
.953 .758 .602 r
.70343 .51592 .70417 .51666 .70546 .51052 .70472 .50967 Mtetra
.809 .786 .831 r
.70472 .50967 .70546 .51052 .707 .50917 .70626 .50831 Mtetra
.649 .744 .919 r
.70626 .50831 .707 .50917 .7086 .50875 .70786 .50789 Mtetra
.531 .695 .943 r
.70786 .50789 .7086 .50875 .71022 .50872 .70948 .50785 Mtetra
.731 .766 .881 r
.70948 .50785 .71022 .50872 .7118 .50791 .71106 .50704 Mtetra
.702 .757 .894 r
.71106 .50704 .7118 .50791 .71339 .50726 .71265 .50638 Mtetra
.534 .692 .94 r
.71265 .50638 .71339 .50726 .71501 .50722 .71427 .50634 Mtetra
.808 .364 0 r
.71427 .50634 .71501 .50722 .71683 .51063 .7161 .50976 Mtetra
.97 .683 .426 r
.7161 .50976 .71683 .51063 .7297 .70405 .72892 .70322 Mtetra
.921 .53 .156 r
.72892 .70322 .7297 .70405 .73178 .71006 .731 .70923 Mtetra
0 .355 .819 r
.731 .70923 .73178 .71006 .73357 .71112 .73279 .71029 Mtetra
.596 .745 .948 r
.73279 .71029 .73357 .71112 .73529 .71084 .73451 .71002 Mtetra
.796 .801 .855 r
.73451 .71002 .73529 .71084 .73694 .70956 .73617 .70874 Mtetra
.935 .779 .663 r
.73617 .70874 .73694 .70956 .73841 .7052 .73764 .7044 Mtetra
.971 .689 .436 r
.73764 .7044 .73841 .7052 .72831 .5112 .72758 .51045 Mtetra
.961 .75 .573 r
.72758 .51045 .72831 .5112 .72949 .50366 .72875 .50281 Mtetra
.835 .789 .807 r
.72875 .50281 .72949 .50366 .73102 .50203 .73029 .50116 Mtetra
.66 .748 .915 r
.73029 .50116 .73102 .50203 .73263 .50156 .7319 .50069 Mtetra
.534 .696 .943 r
.7319 .50069 .73263 .50156 .73427 .50152 .73354 .50065 Mtetra
.713 .763 .891 r
.73354 .50065 .73427 .50152 .73586 .50079 .73513 .49993 Mtetra
.706 .762 .896 r
.73513 .49993 .73586 .50079 .73746 .50012 .73673 .49925 Mtetra
.546 .701 .941 r
.73673 .49925 .73746 .50012 .7391 .50006 .73837 .49917 Mtetra
.749 .294 0 r
.73837 .49917 .7391 .50006 .74096 .50341 .74022 .50225 Mtetra
.972 .682 .415 r
.74022 .50225 .74096 .50341 .75533 .69777 .7545 .69583 Mtetra
.82 .46 0 r
.7545 .69583 .75533 .69777 .75746 .7036 .75667 .70229 Mtetra
.151 .391 .84 r
.75667 .70229 .75746 .7036 .75929 .70469 .7585 .70349 Mtetra
.614 .673 .883 r
.7585 .70349 .75929 .70469 .76101 .70431 .76023 .70322 Mtetra
.778 .75 .827 r
.76023 .70322 .76101 .70431 .76267 .70286 .7619 .70193 Mtetra
.928 .773 .668 r
.7619 .70193 .76267 .70286 .7641 .69809 .76337 .69774 Mtetra
.973 .688 .425 r
.76337 .69774 .7641 .69809 .75241 .50176 .75185 .50331 Mtetra
.971 .816 .395 r
.75185 .50331 .75241 .50176 .75363 .49535 .75297 .49544 Mtetra
.889 .989 .793 r
.75297 .49544 .75363 .49535 .75516 .49358 .7545 .49358 Mtetra
.437 .875 .885 r
.7545 .49358 .75516 .49358 .75678 .49303 .75612 .49304 Mtetra
.088 .647 .75 r
.75612 .49304 .75678 .49303 .75842 .4929 .75777 .49292 Mtetra
.243 .758 .808 r
.75777 .49292 .75842 .4929 .76007 .49267 .7594 .4926 Mtetra
.451 .876 .923 r
.7594 .4926 .76007 .49267 .7617 .49237 .76103 .49212 Mtetra
.554 .889 .986 r
.76103 .49212 .7617 .49237 .76334 .49208 .76266 .49165 Mtetra
.607 .858 .991 r
.76266 .49165 .76334 .49208 .76498 .4917 .76429 .49119 Mtetra
.619 .838 .984 r
.76429 .49119 .76498 .4917 .76661 .49126 .76592 .49075 Mtetra
.618 .838 .984 r
.76592 .49075 .76661 .49126 .76824 .49079 .76755 .49031 Mtetra
.617 .847 .986 r
.76755 .49031 .76824 .49079 .76987 .49033 .76918 .48986 Mtetra
.618 .852 .987 r
.76918 .48986 .76987 .49033 .7715 .48986 .77082 .4894 Mtetra
.619 .854 .987 r
.77082 .4894 .7715 .48986 .77313 .48939 .77245 .48894 Mtetra
.62 .856 .988 r
.77245 .48894 .77313 .48939 .77477 .48891 .77409 .48846 Mtetra
.621 .857 .988 r
.77409 .48846 .77477 .48891 .7764 .48844 .77572 .48799 Mtetra
.622 .858 .988 r
.77572 .48799 .7764 .48844 .77803 .48795 .77736 .48751 Mtetra
.622 .859 .987 r
.77736 .48751 .77803 .48795 .77967 .48747 .77899 .48702 Mtetra
.623 .859 .987 r
.77899 .48702 .77967 .48747 .78131 .48698 .78063 .48654 Mtetra
.623 .86 .987 r
.78063 .48654 .78131 .48698 .78294 .4865 .78227 .48605 Mtetra
.624 .86 .987 r
.78227 .48605 .78294 .4865 .78458 .48601 .78391 .48556 Mtetra
.78391 .48556 .78458 .48601 .78622 .48552 .78555 .48507 Mtetra
.624 .861 .987 r
.78555 .48507 .78622 .48552 .78786 .48503 .78719 .48458 Mtetra
.625 .861 .987 r
.78719 .48458 .78786 .48503 .7895 .48453 .78883 .48409 Mtetra
.78883 .48409 .7895 .48453 .79114 .48404 .79047 .48359 Mtetra
.79047 .48359 .79114 .48404 .79278 .48355 .79211 .4831 Mtetra
.79211 .4831 .79278 .48355 .79443 .48306 .79376 .48261 Mtetra
.79376 .48261 .79443 .48306 .79607 .48256 .7954 .48211 Mtetra
.7954 .48211 .79607 .48256 .79772 .48207 .79705 .48162 Mtetra
.79705 .48162 .79772 .48207 .79936 .48157 .7987 .48112 Mtetra
.7987 .48112 .79936 .48157 .80101 .48108 .80034 .48062 Mtetra
.80034 .48062 .80101 .48108 .80266 .48058 .80199 .48013 Mtetra
.626 .861 .987 r
.80199 .48013 .80266 .48058 .80431 .48008 .80364 .47963 Mtetra
.80364 .47963 .80431 .48008 .80596 .47959 .80529 .47913 Mtetra
.80529 .47913 .80596 .47959 .80761 .47909 .80694 .47864 Mtetra
.626 .86 .987 r
.80694 .47864 .80761 .47909 .80926 .47859 .8086 .47814 Mtetra
.8086 .47814 .80926 .47859 .81091 .4781 .81025 .47764 Mtetra
.81025 .47764 .81091 .4781 .81256 .4776 .8119 .47714 Mtetra
.8119 .47714 .81256 .4776 .81422 .4771 .81356 .47665 Mtetra
.81356 .47665 .81422 .4771 .81587 .4766 .81522 .47615 Mtetra
.81522 .47615 .81587 .4766 .81753 .47611 .81687 .47565 Mtetra
.81687 .47565 .81753 .47611 .81919 .47561 .81853 .47515 Mtetra
.81853 .47515 .81919 .47561 .82085 .47511 .82019 .47465 Mtetra
.82019 .47465 .82085 .47511 .82251 .47461 .82185 .47415 Mtetra
.82185 .47415 .82251 .47461 .82417 .47411 .82351 .47365 Mtetra
.625 .86 .987 r
.82351 .47365 .82417 .47411 .82583 .47361 .82517 .47315 Mtetra
.82517 .47315 .82583 .47361 .82749 .47311 .82684 .47265 Mtetra
.82684 .47265 .82749 .47311 .82915 .47261 .8285 .47215 Mtetra
.8285 .47215 .82915 .47261 .83082 .47211 .83017 .47165 Mtetra
.83017 .47165 .83082 .47211 .83248 .47161 .83183 .47115 Mtetra
.83183 .47115 .83248 .47161 .83415 .47111 .8335 .47065 Mtetra
.8335 .47065 .83415 .47111 .83581 .47061 .83517 .47015 Mtetra
.83517 .47015 .83581 .47061 .83748 .47011 .83684 .46965 Mtetra
.625 .861 .987 r
.83684 .46965 .83748 .47011 .83915 .46961 .83851 .46915 Mtetra
.83851 .46915 .83915 .46961 .84082 .46911 .84018 .46864 Mtetra
.84018 .46864 .84082 .46911 .84249 .4686 .84185 .46814 Mtetra
.84185 .46814 .84249 .4686 .84416 .4681 .84352 .46764 Mtetra
.84352 .46764 .84416 .4681 .84584 .4676 .84519 .46713 Mtetra
.84519 .46713 .84584 .4676 .84751 .4671 .84687 .46663 Mtetra
.84687 .46663 .84751 .4671 .84918 .46659 .84854 .46613 Mtetra
.84854 .46613 .84918 .46659 .85086 .46609 .85022 .46562 Mtetra
.85022 .46562 .85086 .46609 .85254 .46558 .8519 .46512 Mtetra
.626 .861 .987 r
.8519 .46512 .85254 .46558 .85421 .46508 .85358 .46461 Mtetra
.85358 .46461 .85421 .46508 .85589 .46457 .85526 .4641 Mtetra
.85526 .4641 .85589 .46457 .85757 .46407 .85694 .4636 Mtetra
.85694 .4636 .85757 .46407 .85925 .46356 .85862 .46309 Mtetra
.85862 .46309 .85925 .46356 .86093 .46305 .8603 .46258 Mtetra
.627 .861 .987 r
.8603 .46258 .86093 .46305 .86261 .46254 .86198 .46207 Mtetra
.86198 .46207 .86261 .46254 .8643 .46203 .86367 .46156 Mtetra
.627 .861 .986 r
.86367 .46156 .8643 .46203 .86598 .46152 .86535 .46105 Mtetra
.628 .86 .986 r
.86535 .46105 .86598 .46152 .86767 .46101 .86704 .46054 Mtetra
.86704 .46054 .86767 .46101 .86935 .4605 .86872 .46002 Mtetra
.629 .86 .986 r
.86872 .46002 .86935 .4605 .87104 .45999 .87041 .45951 Mtetra
.87041 .45951 .87104 .45999 .87273 .45948 .8721 .459 Mtetra
.63 .859 .986 r
.8721 .459 .87273 .45948 .87441 .45897 .87379 .45848 Mtetra
.63 .859 .985 r
.87379 .45848 .87441 .45897 .8761 .45845 .87548 .45797 Mtetra
.63 .858 .985 r
.87548 .45797 .8761 .45845 .87779 .45794 .87717 .45745 Mtetra
.631 .858 .985 r
.87717 .45745 .87779 .45794 .87949 .45743 .87886 .45694 Mtetra
.631 .857 .985 r
.87886 .45694 .87949 .45743 .88118 .45691 .88056 .45642 Mtetra
.88056 .45642 .88118 .45691 .88287 .4564 .88225 .4559 Mtetra
.88225 .4559 .88287 .4564 .88457 .45589 .88395 .45539 Mtetra
.631 .856 .985 r
.88395 .45539 .88457 .45589 .88626 .45537 .88564 .45487 Mtetra
.88564 .45487 .88626 .45537 .88796 .45486 .88734 .45436 Mtetra
.88734 .45436 .88796 .45486 .88966 .45435 .88904 .45385 Mtetra
.88904 .45385 .88966 .45435 .89136 .45383 .89074 .45333 Mtetra
.63 .855 .985 r
.89074 .45333 .89136 .45383 .89305 .45332 .89244 .45282 Mtetra
.89244 .45282 .89305 .45332 .89476 .45281 .89414 .45231 Mtetra
.63 .856 .985 r
.89414 .45231 .89476 .45281 .89646 .45229 .89584 .45179 Mtetra
.629 .856 .985 r
.89584 .45179 .89646 .45229 .89816 .45178 .89755 .45128 Mtetra
.89755 .45128 .89816 .45178 .89986 .45127 .89925 .45077 Mtetra
.89925 .45077 .89986 .45127 .90157 .45075 .90096 .45026 Mtetra
.628 .857 .986 r
.90096 .45026 .90157 .45075 .90327 .45024 .90266 .44975 Mtetra
.627 .857 .986 r
.90266 .44975 .90327 .45024 .90498 .44973 .90437 .44923 Mtetra
.626 .857 .986 r
.90437 .44923 .90498 .44973 .90669 .44922 .90608 .44872 Mtetra
.625 .858 .987 r
.90608 .44872 .90669 .44922 .9084 .4487 .90779 .44822 Mtetra
.624 .858 .987 r
.90779 .44822 .9084 .4487 .91011 .4482 .9095 .44771 Mtetra
.623 .858 .987 r
.9095 .44771 .91011 .4482 .91182 .44769 .91122 .4472 Mtetra
.622 .858 .987 r
.91122 .4472 .91182 .44769 .91353 .44719 .91293 .4467 Mtetra
.621 .857 .988 r
.91293 .4467 .91353 .44719 .91525 .44669 .91465 .4462 Mtetra
.619 .857 .988 r
.91465 .4462 .91525 .44669 .91696 .44618 .91636 .4457 Mtetra
.616 .858 .989 r
.91636 .4457 .91696 .44618 .91868 .4457 .91808 .44521 Mtetra
.616 .855 .989 r
.91808 .44521 .91868 .4457 .92041 .44526 .9198 .44472 Mtetra
.622 .843 .984 r
.9198 .44472 .92041 .44526 .92214 .44491 .92152 .44424 Mtetra
.64 .809 .964 r
.92152 .44424 .92214 .44491 .92388 .44458 .92325 .44376 Mtetra
.651 .771 .937 r
.92325 .44376 .92388 .44458 .92562 .44422 .92497 .44328 Mtetra
.656 .741 .913 r
.92497 .44328 .92562 .44422 .92735 .44377 .9267 .4428 Mtetra
.657 .734 .906 r
.9267 .4428 .92735 .44377 .92908 .44329 .92842 .44231 Mtetra
.657 .733 .905 r
.92842 .44231 .92908 .44329 .9308 .4428 .93015 .44182 Mtetra
.658 .734 .906 r
.93015 .44182 .9308 .4428 .93253 .44231 .93187 .44133 Mtetra
.658 .733 .905 r
.93187 .44133 .93253 .44231 .93426 .44182 .9336 .44083 Mtetra
.658 .732 .904 r
.9336 .44083 .93426 .44182 .93598 .44133 .93533 .44034 Mtetra
.657 .731 .904 r
.93533 .44034 .93598 .44133 .93771 .44084 .93706 .43985 Mtetra
.656 .731 .905 r
.93706 .43985 .93771 .44084 .93945 .44035 .9388 .43937 Mtetra
.655 .732 .906 r
.9388 .43937 .93945 .44035 .94118 .43986 .94053 .43888 Mtetra
.653 .733 .908 r
.94053 .43888 .94118 .43986 .94291 .43938 .94227 .43841 Mtetra
.652 .735 .91 r
.94227 .43841 .94291 .43938 .94465 .4389 .944 .43794 Mtetra
.652 .738 .913 r
.944 .43794 .94465 .4389 .94638 .43841 .94574 .43747 Mtetra
.65 .741 .916 r
.94574 .43747 .94638 .43841 .94812 .43793 .94748 .43701 Mtetra
.652 .746 .918 r
.94748 .43701 .94812 .43793 .94986 .43744 .94922 .43653 Mtetra
.657 .752 .92 r
.94922 .43653 .94986 .43744 .95159 .43693 .95096 .43604 Mtetra
.665 .759 .921 r
.95096 .43604 .95159 .43693 .95333 .43638 .9527 .4355 Mtetra
.672 .766 .921 r
.9527 .4355 .95333 .43638 .95506 .4358 .95443 .43494 Mtetra
.68 .773 .921 r
.95443 .43494 .95506 .4358 .95678 .4352 .95616 .43434 Mtetra
.693 .78 .918 r
.95616 .43434 .95678 .4352 .9585 .43456 .95788 .43368 Mtetra
.697 .777 .914 r
.95788 .43368 .9585 .43456 .96022 .43389 .9596 .43301 Mtetra
.7 .777 .911 r
.9596 .43301 .96022 .43389 .96194 .43317 .96132 .43231 Mtetra
.781 .809 .875 r
.96132 .43231 .96194 .43317 .96358 .43192 .96298 .43118 Mtetra
.713 .818 .93 r
.96298 .43118 .96358 .43192 .96528 .43107 .96469 .43043 Mtetra
.483 .749 .988 r
.96469 .43043 .96528 .43107 .96707 .43088 .96649 .43036 Mtetra
.926 .549 .269 r
.3991 .60005 .39996 .60079 .40123 .60461 .40037 .60396 Mtetra
.937 .682 .526 r
.40037 .60396 .40123 .60461 .39597 .79191 .39506 .7914 Mtetra
.927 .581 .36 r
.39506 .7914 .39597 .79191 .39727 .79733 .39636 .79667 Mtetra
.342 .669 .975 r
.39636 .79667 .39727 .79733 .39876 .79754 .39785 .79687 Mtetra
.695 .788 .922 r
.39785 .79687 .39876 .79754 .40028 .79694 .39937 .79628 Mtetra
.766 .796 .877 r
.39937 .79628 .40028 .79694 .40181 .79593 .40091 .7953 Mtetra
.615 .785 .963 r
.40091 .7953 .40181 .79593 .40333 .79548 .40242 .79497 Mtetra
.561 .802 .989 r
.40242 .79497 .40333 .79548 .40484 .79508 .40393 .79472 Mtetra
.487 .821 .999 r
.40393 .79472 .40484 .79508 .40636 .79467 .40544 .79451 Mtetra
.319 .784 .938 r
.40544 .79451 .40636 .79467 .40787 .79423 .40695 .79435 Mtetra
0 0 0 r
.40695 .79435 .40787 .79423 .40939 .79378 .40846 .79417 Mtetra
.109 0 0 r
.40846 .79417 .40939 .79378 .41091 .79334 .40997 .79393 Mtetra
.307 0 0 r
.40997 .79393 .41091 .79334 .41241 .79348 .41148 .79382 Mtetra
0 0 0 r
.41148 .79382 .41241 .79348 .41393 .79328 .413 .79342 Mtetra
.665 .97 .907 r
.413 .79342 .41393 .79328 .41546 .79234 .41454 .79253 Mtetra
.952 .871 .72 r
.41454 .79253 .41546 .79234 .41714 .78669 .41614 .78931 Mtetra
.999 .836 .51 r
.41614 .78931 .41714 .78669 .4242 .59819 .41794 .77985 Mtetra
0 0 .346 r
.41794 .77985 .4242 .59819 .42577 .59319 .4248 .59682 Mtetra
.341 .074 .355 r
.4248 .59682 .42577 .59319 .42724 .59203 .42628 .59509 Mtetra
.512 .215 .399 r
.42628 .59509 .42724 .59203 .42868 .59165 .42772 .59477 Mtetra
.578 .28 .427 r
.42772 .59477 .42868 .59165 .43011 .59163 .42915 .59508 Mtetra
.566 .276 .435 r
.42915 .59508 .43011 .59163 .43155 .59133 .43058 .59525 Mtetra
.545 .266 .443 r
.43058 .59525 .43155 .59133 .43299 .59099 .43201 .59515 Mtetra
.492 .221 .431 r
.43201 .59515 .43299 .59099 .43443 .59064 .43347 .59441 Mtetra
.236 0 .318 r
.43347 .59441 .43443 .59064 .43588 .59023 .43497 .592 Mtetra
0 0 0 r
.43497 .592 .43588 .59023 .43733 .58979 .43646 .58986 Mtetra
.887 .949 .843 r
.43646 .58986 .43733 .58979 .43878 .58934 .43794 .58824 Mtetra
.714 .696 .831 r
.43794 .58824 .43878 .58934 .44022 .58893 .4394 .58749 Mtetra
.651 .626 .812 r
.4394 .58749 .44022 .58893 .44167 .58851 .44085 .58708 Mtetra
.625 .614 .82 r
.44085 .58708 .44167 .58851 .44312 .58809 .4423 .58681 Mtetra
.63 .638 .84 r
.4423 .58681 .44312 .58809 .44458 .58763 .44374 .58651 Mtetra
.634 .668 .865 r
.44374 .58651 .44458 .58763 .44603 .58715 .44519 .5862 Mtetra
.643 .704 .891 r
.44519 .5862 .44603 .58715 .44748 .58668 .44665 .58585 Mtetra
.688 .742 .893 r
.44665 .58585 .44748 .58668 .44893 .58627 .4481 .58531 Mtetra
.698 .717 .864 r
.4481 .58531 .44893 .58627 .45039 .58589 .44956 .5847 Mtetra
.689 .675 .832 r
.44956 .5847 .45039 .58589 .45184 .5855 .45102 .58409 Mtetra
.699 .649 .796 r
.45102 .58409 .45184 .5855 .4533 .58471 .45248 .58334 Mtetra
.677 .646 .812 r
.45248 .58334 .4533 .58471 .45477 .58407 .45394 .58276 Mtetra
.603 .623 .844 r
.45394 .58276 .45477 .58407 .45622 .58401 .45539 .5826 Mtetra
0 .151 .694 r
.45539 .5826 .45622 .58401 .45761 .58696 .45681 .58417 Mtetra
.757 .46 0 r
.45681 .58417 .45761 .58696 .45544 .7746 .45816 .58936 Mtetra
0 0 .375 r
.45816 .58936 .45544 .7746 .45684 .78128 .45607 .77489 Mtetra
.473 .349 .63 r
.45607 .77489 .45684 .78128 .45836 .78218 .45757 .77668 Mtetra
.608 .455 .648 r
.45757 .77668 .45836 .78218 .45991 .78182 .45911 .77617 Mtetra
.62 .462 .646 r
.45911 .77617 .45991 .78182 .46146 .78103 .46067 .7754 Mtetra
.494 .373 .643 r
.46067 .7754 .46146 .78103 .46301 .78055 .46218 .77672 Mtetra
.418 .355 .68 r
.46218 .77672 .46301 .78055 .46456 .78021 .4637 .77823 Mtetra
.351 .417 .789 r
.4637 .77823 .46456 .78021 .46611 .77985 .46522 .77921 Mtetra
.344 .675 .977 r
.46522 .77921 .46611 .77985 .46766 .77941 .46677 .77939 Mtetra
.235 .751 .846 r
.46677 .77939 .46766 .77941 .46921 .77892 .46831 .77917 Mtetra
0 0 0 r
.46831 .77917 .46921 .77892 .47076 .77843 .46987 .77878 Mtetra
.065 0 0 r
.46987 .77878 .47076 .77843 .47231 .77835 .47142 .77852 Mtetra
.2 .725 .729 r
.47142 .77852 .47231 .77835 .47386 .77817 .47297 .77815 Mtetra
.664 .954 .948 r
.47297 .77815 .47386 .77817 .47542 .77743 .47453 .77737 Mtetra
.918 .896 .79 r
.47453 .77737 .47542 .77743 .47702 .77394 .47612 .77513 Mtetra
.99 .89 .587 r
.47612 .77513 .47702 .77394 .48097 .58705 .47773 .77013 Mtetra
0 0 .368 r
.47773 .77013 .48097 .58705 .48257 .57739 .48166 .58303 Mtetra
0 0 .26 r
.48166 .58303 .48257 .57739 .48406 .57539 .4832 .57739 Mtetra
0 0 0 r
.4832 .57739 .48406 .57539 .48553 .57479 .48469 .57513 Mtetra
.797 .999 .816 r
.48469 .57513 .48553 .57479 .487 .57462 .48618 .57372 Mtetra
.736 .742 .856 r
.48618 .57372 .487 .57462 .48848 .57427 .48766 .57289 Mtetra
.663 .64 .817 r
.48766 .57289 .48848 .57427 .48995 .5738 .48914 .5724 Mtetra
.637 .627 .823 r
.48914 .5724 .48995 .5738 .49143 .57335 .49061 .57205 Mtetra
.685 .66 .82 r
.49061 .57205 .49143 .57335 .49291 .57266 .49209 .57144 Mtetra
.691 .673 .827 r
.49209 .57144 .49291 .57266 .49439 .57205 .49357 .57079 Mtetra
.626 .643 .847 r
.49357 .57079 .49439 .57205 .49586 .57196 .49505 .57052 Mtetra
.203 .387 .823 r
.49505 .57052 .49586 .57196 .49732 .57419 .49651 .57154 Mtetra
0 0 .451 r
.49651 .57154 .49732 .57419 .49737 .75999 .49796 .57514 Mtetra
0 0 .391 r
.49796 .57514 .49737 .75999 .49886 .76952 .49805 .76141 Mtetra
.241 .167 .569 r
.49805 .76141 .49886 .76952 .50042 .77099 .49957 .76694 Mtetra
.419 .351 .674 r
.49957 .76694 .50042 .77099 .50199 .77079 .50113 .76855 Mtetra
.458 .457 .77 r
.50113 .76855 .50199 .77079 .50356 .7701 .50269 .76924 Mtetra
.449 .664 .954 r
.50269 .76924 .50356 .7701 .50513 .76947 .50426 .76939 Mtetra
.27 .769 .886 r
.50426 .76939 .50513 .76947 .5067 .76896 .50583 .76919 Mtetra
0 0 0 r
.50583 .76919 .5067 .76896 .50828 .76843 .50741 .76879 Mtetra
.039 0 0 r
.50741 .76879 .50828 .76843 .50985 .76825 .50898 .76848 Mtetra
0 0 0 r
.50898 .76848 .50985 .76825 .51143 .76811 .51056 .76814 Mtetra
.608 .946 .932 r
.51056 .76814 .51143 .76811 .513 .76743 .51214 .7674 Mtetra
.917 .914 .8 r
.51214 .7674 .513 .76743 .51459 .7644 .51372 .76526 Mtetra
.992 .871 .604 r
.51372 .76526 .51459 .7644 .51661 .5793 .51531 .76011 Mtetra
0 0 .379 r
.51531 .76011 .51661 .5793 .51813 .56689 .51731 .57268 Mtetra
.137 0 .345 r
.51731 .57268 .51813 .56689 .51963 .56456 .51881 .56795 Mtetra
.475 .19 .4 r
.51881 .56795 .51963 .56456 .52112 .56394 .52031 .56723 Mtetra
.559 .265 .424 r
.52031 .56723 .52112 .56394 .52261 .56379 .5218 .56734 Mtetra
.574 .284 .438 r
.5218 .56734 .52261 .56379 .52411 .56359 .5233 .56762 Mtetra
.551 .272 .446 r
.5233 .56762 .52411 .56359 .5256 .5632 .52479 .56757 Mtetra
.512 .243 .443 r
.52479 .56757 .5256 .5632 .5271 .5628 .52629 .56698 Mtetra
.354 .102 .387 r
.52629 .56698 .5271 .5628 .5286 .56237 .52779 .56495 Mtetra
.041 0 .168 r
.52779 .56495 .5286 .56237 .53009 .5619 .52929 .56253 Mtetra
.794 .974 .682 r
.52929 .56253 .53009 .5619 .53159 .56143 .53078 .56068 Mtetra
.782 .782 .853 r
.53078 .56068 .53159 .56143 .53309 .56098 .53228 .55959 Mtetra
.665 .642 .817 r
.53228 .55959 .53309 .56098 .53459 .56055 .53378 .55908 Mtetra
.635 .619 .816 r
.53378 .55908 .53459 .56055 .53609 .56013 .53528 .55874 Mtetra
.64 .632 .826 r
.53528 .55874 .53609 .56013 .53759 .55968 .53678 .55837 Mtetra
.658 .65 .831 r
.53678 .55837 .53759 .55968 .53909 .55922 .53829 .55792 Mtetra
.658 .652 .832 r
.53829 .55792 .53909 .55922 .5406 .55875 .53979 .55746 Mtetra
.659 .654 .834 r
.53979 .55746 .5406 .55875 .5421 .55828 .54129 .55701 Mtetra
.659 .656 .835 r
.54129 .55701 .5421 .55828 .5436 .55782 .5428 .55655 Mtetra
.66 .657 .836 r
.5428 .55655 .5436 .55782 .54511 .55735 .5443 .55608 Mtetra
.66 .658 .837 r
.5443 .55608 .54511 .55735 .54662 .55689 .54581 .55562 Mtetra
.659 .658 .838 r
.54581 .55562 .54662 .55689 .54812 .55643 .54732 .55516 Mtetra
.659 .659 .838 r
.54732 .55516 .54812 .55643 .54963 .55597 .54883 .55471 Mtetra
.54883 .55471 .54963 .55597 .55114 .55551 .55034 .55425 Mtetra
.659 .659 .839 r
.55034 .55425 .55114 .55551 .55265 .55505 .55185 .55379 Mtetra
.658 .659 .839 r
.55185 .55379 .55265 .55505 .55416 .5546 .55336 .55334 Mtetra
.658 .658 .839 r
.55336 .55334 .55416 .5546 .55567 .55415 .55487 .55289 Mtetra
.55487 .55289 .55567 .55415 .55718 .5537 .55638 .55244 Mtetra
.657 .658 .839 r
.55638 .55244 .55718 .5537 .5587 .55325 .55789 .55199 Mtetra
.55789 .55199 .5587 .55325 .56021 .55281 .55941 .55154 Mtetra
.657 .657 .839 r
.55941 .55154 .56021 .55281 .56172 .55237 .56092 .55109 Mtetra
.654 .655 .839 r
.56092 .55109 .56172 .55237 .56324 .55193 .56244 .55066 Mtetra
.644 .653 .844 r
.56244 .55066 .56324 .55193 .56476 .55148 .56396 .55029 Mtetra
.631 .658 .858 r
.56396 .55029 .56476 .55148 .56627 .55104 .56548 .54998 Mtetra
.63 .682 .881 r
.56548 .54998 .56627 .55104 .56779 .55059 .567 .54967 Mtetra
.638 .715 .903 r
.567 .54967 .56779 .55059 .56931 .55012 .56852 .54932 Mtetra
.656 .748 .918 r
.56852 .54932 .56931 .55012 .57083 .54964 .57004 .54889 Mtetra
.669 .766 .923 r
.57004 .54889 .57083 .54964 .57235 .54916 .57156 .5484 Mtetra
.686 .769 .914 r
.57156 .5484 .57235 .54916 .57387 .54873 .57308 .54785 Mtetra
.7 .744 .886 r
.57308 .54785 .57387 .54873 .57539 .54835 .5746 .54722 Mtetra
.692 .694 .847 r
.5746 .54722 .57539 .54835 .57692 .54797 .57612 .54659 Mtetra
.676 .651 .818 r
.57612 .54659 .57692 .54797 .57844 .54755 .57764 .54601 Mtetra
.659 .624 .803 r
.57764 .54601 .57844 .54755 .57997 .54707 .57917 .54551 Mtetra
.655 .62 .802 r
.57917 .54551 .57997 .54707 .58149 .54656 .58069 .54503 Mtetra
.654 .622 .805 r
.58069 .54503 .58149 .54656 .58302 .54606 .58222 .54456 Mtetra
.655 .626 .809 r
.58222 .54456 .58302 .54606 .58454 .54559 .58374 .54409 Mtetra
.655 .627 .809 r
.58374 .54409 .58454 .54559 .58607 .54511 .58527 .54362 Mtetra
.656 .627 .809 r
.58527 .54362 .58607 .54511 .5876 .54463 .5868 .54314 Mtetra
.657 .628 .81 r
.5868 .54314 .5876 .54463 .58913 .54415 .58833 .54266 Mtetra
.656 .629 .811 r
.58833 .54266 .58913 .54415 .59066 .54367 .58986 .54218 Mtetra
.669 .635 .807 r
.58986 .54218 .59066 .54367 .59219 .54306 .59139 .54163 Mtetra
.69 .649 .804 r
.59139 .54163 .59219 .54306 .59371 .54225 .59292 .54092 Mtetra
.65 .647 .834 r
.59292 .54092 .59371 .54225 .59525 .54186 .59445 .5405 Mtetra
.448 .545 .863 r
.59445 .5405 .59525 .54186 .59681 .54272 .596 .54091 Mtetra
0 0 .493 r
.596 .54091 .59681 .54272 .59851 .5499 .59761 .54377 Mtetra
.968 .693 .458 r
.59761 .54377 .59851 .5499 .60429 .73982 .60319 .72645 Mtetra
.178 .103 .528 r
.60319 .72645 .60429 .73982 .606 .74288 .60507 .73735 Mtetra
.566 .427 .651 r
.60507 .73735 .606 .74288 .60764 .74287 .60671 .73761 Mtetra
.624 .47 .652 r
.60671 .73761 .60764 .74287 .60927 .74225 .60834 .7368 Mtetra
.642 .48 .648 r
.60834 .7368 .60927 .74225 .61089 .74144 .60995 .73555 Mtetra
.622 .461 .644 r
.60995 .73555 .61089 .74144 .61253 .74099 .61157 .73468 Mtetra
.6 .442 .64 r
.61157 .73468 .61253 .74099 .61416 .74055 .6132 .73427 Mtetra
.547 .405 .64 r
.6132 .73427 .61416 .74055 .6158 .74014 .61486 .73493 Mtetra
.45 .351 .652 r
.61486 .73493 .6158 .74014 .61744 .7398 .61656 .73677 Mtetra
.414 .387 .72 r
.61656 .73677 .61744 .7398 .61908 .73945 .61824 .73806 Mtetra
.336 .492 .866 r
.61824 .73806 .61908 .73945 .62072 .73914 .61991 .7388 Mtetra
.172 .66 .923 r
.61991 .7388 .62072 .73914 .62237 .73903 .62157 .73896 Mtetra
.366 .828 .912 r
.62157 .73896 .62237 .73903 .62401 .7385 .62321 .73861 Mtetra
.722 .987 .88 r
.62321 .73861 .62401 .7385 .62561 .73686 .62483 .73747 Mtetra
.957 .945 .648 r
.62483 .73747 .62561 .73686 .62707 .73006 .6264 .73423 Mtetra
0 0 0 r
.6264 .73423 .62707 .73006 .62311 .5379 .62781 .72568 Mtetra
.047 0 .434 r
.62781 .72568 .62311 .5379 .62455 .53356 .6239 .53706 Mtetra
.093 0 .271 r
.6239 .53706 .62455 .53356 .62608 .5326 .62537 .53378 Mtetra
0 0 0 r
.62537 .53378 .62608 .5326 .62763 .53225 .62688 .53198 Mtetra
.802 .923 .917 r
.62688 .53198 .62763 .53225 .6292 .53214 .62841 .53088 Mtetra
.664 .665 .841 r
.62841 .53088 .6292 .53214 .63075 .53169 .62996 .53039 Mtetra
.619 .64 .849 r
.62996 .53039 .63075 .53169 .6323 .53124 .63153 .53013 Mtetra
.614 .67 .88 r
.63153 .53013 .6323 .53124 .63386 .53072 .63309 .52988 Mtetra
.728 .765 .882 r
.63309 .52988 .63386 .53072 .6354 .5298 .63463 .52911 Mtetra
.677 .789 .934 r
.63463 .52911 .6354 .5298 .63695 .52926 .63619 .52857 Mtetra
.445 .702 .976 r
.63619 .52857 .63695 .52926 .63854 .52963 .63776 .52864 Mtetra
.629 .169 0 r
.63776 .52864 .63854 .52963 .64029 .53487 .63942 .53096 Mtetra
.874 .584 .063 r
.63942 .53096 .64029 .53487 .64856 .72695 .64139 .54231 Mtetra
.067 0 .45 r
.64139 .54231 .64856 .72695 .65037 .731 .6494 .72554 Mtetra
.432 .336 .647 r
.6494 .72554 .65037 .731 .65205 .73113 .65115 .72771 Mtetra
.491 .421 .706 r
.65115 .72771 .65205 .73113 .6537 .73056 .65285 .72861 Mtetra
.528 .527 .797 r
.65285 .72861 .6537 .73056 .65535 .72973 .65454 .72888 Mtetra
.49 .692 .958 r
.65454 .72888 .65535 .72973 .65702 .72973 .65622 .72892 Mtetra
.651 .766 .933 r
.65622 .72892 .65702 .72973 .65869 .72932 .65788 .72846 Mtetra
.778 .783 .857 r
.65788 .72846 .65869 .72932 .66032 .72805 .65951 .72731 Mtetra
.916 .789 .706 r
.65951 .72731 .66032 .72805 .66176 .72185 .66106 .72392 Mtetra
.992 .809 .433 r
.66106 .72392 .66176 .72185 .65588 .52844 .66234 .71342 Mtetra
.063 0 .443 r
.66234 .71342 .65588 .52844 .65727 .52351 .65667 .52689 Mtetra
.119 0 .28 r
.65667 .52689 .65727 .52351 .65881 .5225 .65814 .52377 Mtetra
0 0 0 r
.65814 .52377 .65881 .5225 .66039 .52214 .65966 .52198 Mtetra
.804 .958 .914 r
.65966 .52198 .66039 .52214 .66198 .5221 .6612 .52083 Mtetra
.664 .665 .84 r
.6612 .52083 .66198 .5221 .66355 .52168 .66277 .52032 Mtetra
.619 .633 .843 r
.66277 .52032 .66355 .52168 .66512 .52126 .66435 .52006 Mtetra
.595 .648 .873 r
.66435 .52006 .66512 .52126 .6667 .52082 .66594 .5199 Mtetra
.657 .729 .903 r
.66594 .5199 .6667 .52082 .66827 .52029 .66751 .51946 Mtetra
.671 .753 .913 r
.66751 .51946 .66827 .52029 .66984 .51975 .66908 .51895 Mtetra
.684 .765 .913 r
.66908 .51895 .66984 .51975 .67141 .51923 .67066 .51839 Mtetra
.758 .775 .866 r
.67066 .51839 .67141 .51923 .67297 .51838 .67221 .51742 Mtetra
.713 .74 .872 r
.67221 .51742 .67297 .51838 .67454 .51786 .67378 .5167 Mtetra
.617 .665 .874 r
.67378 .5167 .67454 .51786 .67615 .51797 .67536 .51644 Mtetra
0 .23 .743 r
.67536 .51644 .67615 .51797 .67793 .52196 .67704 .51817 Mtetra
0 0 .481 r
.67704 .51817 .67793 .52196 .68844 .71443 .6789 .52356 Mtetra
.086 .007 .461 r
.6789 .52356 .68844 .71443 .69038 .71979 .68933 .71345 Mtetra
.382 .292 .628 r
.68933 .71345 .69038 .71979 .6921 .72013 .69118 .71667 Mtetra
.454 .397 .704 r
.69118 .71667 .6921 .72013 .69378 .71962 .69294 .7179 Mtetra
.489 .531 .827 r
.69294 .7179 .69378 .71962 .69544 .71868 .69467 .7183 Mtetra
.545 .853 .998 r
.69467 .7183 .69544 .71868 .69712 .71811 .69636 .71793 Mtetra
.624 .929 .969 r
.69636 .71793 .69712 .71811 .6988 .71757 .69803 .71725 Mtetra
.713 .917 .964 r
.69803 .71725 .6988 .71757 .70048 .71705 .6997 .71643 Mtetra
.647 .817 .965 r
.6997 .71643 .70048 .71705 .70216 .71663 .70138 .71593 Mtetra
.622 .787 .961 r
.70138 .71593 .70216 .71663 .70386 .71625 .70307 .71554 Mtetra
.6 .775 .964 r
.70307 .71554 .70386 .71625 .70555 .7159 .70477 .71522 Mtetra
.323 .652 .97 r
.70477 .71522 .70555 .7159 .70727 .71606 .7065 .71549 Mtetra
.452 .754 .994 r
.7065 .71549 .70727 .71606 .70897 .7159 .70821 .71544 Mtetra
.71 .88 .96 r
.70821 .71544 .70897 .7159 .71064 .71501 .70988 .71468 Mtetra
.965 .819 .649 r
.70988 .71468 .71064 .71501 .7121 .71012 .71136 .71016 Mtetra
.97 .691 .444 r
.71136 .71016 .7121 .71012 .70343 .51592 .70273 .51595 Mtetra
.987 .794 .56 r
.70273 .51595 .70343 .51592 .70472 .50967 .70398 .50888 Mtetra
.819 .797 .831 r
.70398 .50888 .70472 .50967 .70626 .50831 .70552 .50745 Mtetra
.652 .744 .917 r
.70552 .50745 .70626 .50831 .70786 .50789 .70712 .50702 Mtetra
.53 .692 .942 r
.70712 .50702 .70786 .50789 .70948 .50785 .70874 .50699 Mtetra
.733 .768 .881 r
.70874 .50699 .70948 .50785 .71106 .50704 .71032 .50617 Mtetra
.704 .758 .894 r
.71032 .50617 .71106 .50704 .71265 .50638 .71191 .5055 Mtetra
.535 .692 .94 r
.71191 .5055 .71265 .50638 .71427 .50634 .71353 .50546 Mtetra
.809 .364 0 r
.71353 .50546 .71427 .50634 .7161 .50976 .71536 .50888 Mtetra
.97 .683 .426 r
.71536 .50888 .7161 .50976 .72892 .70322 .72815 .7024 Mtetra
.921 .529 .155 r
.72815 .7024 .72892 .70322 .731 .70923 .73022 .7084 Mtetra
0 .355 .819 r
.73022 .7084 .731 .70923 .73279 .71029 .73202 .70946 Mtetra
.595 .744 .948 r
.73202 .70946 .73279 .71029 .73451 .71002 .73374 .70919 Mtetra
.796 .801 .856 r
.73374 .70919 .73451 .71002 .73617 .70874 .73539 .70791 Mtetra
.935 .779 .664 r
.73539 .70791 .73617 .70874 .73764 .7044 .73687 .70359 Mtetra
.971 .689 .436 r
.73687 .70359 .73764 .7044 .72758 .51045 .72685 .50965 Mtetra
.959 .747 .573 r
.72685 .50965 .72758 .51045 .72875 .50281 .72802 .50194 Mtetra
.834 .786 .806 r
.72802 .50194 .72875 .50281 .73029 .50116 .72956 .50029 Mtetra
.66 .745 .913 r
.72956 .50029 .73029 .50116 .7319 .50069 .73117 .49982 Mtetra
.534 .694 .942 r
.73117 .49982 .7319 .50069 .73354 .50065 .73281 .49978 Mtetra
.716 .764 .891 r
.73281 .49978 .73354 .50065 .73513 .49993 .7344 .49905 Mtetra
.706 .759 .893 r
.7344 .49905 .73513 .49993 .73673 .49925 .736 .49836 Mtetra
.542 .694 .938 r
.736 .49836 .73673 .49925 .73837 .49917 .73764 .4983 Mtetra
.789 .34 0 r
.73764 .4983 .73837 .49917 .74022 .50225 .7395 .50164 Mtetra
.972 .681 .416 r
.7395 .50164 .74022 .50225 .7545 .69583 .7538 .69605 Mtetra
.91 .527 .28 r
.7538 .69605 .7545 .69583 .75667 .70229 .75593 .7019 Mtetra
.332 0 0 r
.75593 .7019 .75667 .70229 .7585 .70349 .75775 .70286 Mtetra
.629 .812 .971 r
.75775 .70286 .7585 .70349 .76023 .70322 .75947 .70241 Mtetra
.801 .808 .857 r
.75947 .70241 .76023 .70322 .7619 .70193 .76114 .7011 Mtetra
.907 .798 .728 r
.76114 .7011 .7619 .70193 .76337 .69774 .76269 .69815 Mtetra
.999 .82 .527 r
.76269 .69815 .76337 .69774 .75185 .50331 .76396 .69096 Mtetra
.106 .023 .469 r
.76396 .69096 .75185 .50331 .75297 .49544 .7526 .49965 Mtetra
.319 .085 .393 r
.7526 .49965 .75297 .49544 .7545 .49358 .75407 .49701 Mtetra
.514 .225 .413 r
.75407 .49701 .7545 .49358 .75612 .49304 .75571 .4966 Mtetra
.539 .25 .424 r
.75571 .4966 .75612 .49304 .75777 .49292 .75736 .49647 Mtetra
.362 .103 .381 r
.75736 .49647 .75777 .49292 .7594 .4926 .75889 .4946 Mtetra
.053 0 .154 r
.75889 .4946 .7594 .4926 .76103 .49212 .76039 .49239 Mtetra
.801 .99 .742 r
.76039 .49239 .76103 .49212 .76266 .49165 .76193 .49068 Mtetra
.744 .754 .86 r
.76193 .49068 .76266 .49165 .76429 .49119 .76353 .48975 Mtetra
.656 .642 .824 r
.76353 .48975 .76429 .49119 .76592 .49075 .76516 .48926 Mtetra
.631 .624 .825 r
.76516 .48926 .76592 .49075 .76755 .49031 .7668 .48892 Mtetra
.643 .643 .835 r
.7668 .48892 .76755 .49031 .76918 .48986 .76843 .48852 Mtetra
.653 .654 .838 r
.76843 .48852 .76918 .48986 .77082 .4894 .77007 .48805 Mtetra
.654 .654 .838 r
.77007 .48805 .77082 .4894 .77245 .48894 .7717 .48759 Mtetra
.655 .655 .838 r
.7717 .48759 .77245 .48894 .77409 .48846 .77334 .48712 Mtetra
.656 .656 .838 r
.77334 .48712 .77409 .48846 .77572 .48799 .77497 .48664 Mtetra
.657 .656 .838 r
.77497 .48664 .77572 .48799 .77736 .48751 .77661 .48616 Mtetra
.657 .657 .838 r
.77661 .48616 .77736 .48751 .77899 .48702 .77824 .48567 Mtetra
.77824 .48567 .77899 .48702 .78063 .48654 .77988 .48519 Mtetra
.658 .657 .838 r
.77988 .48519 .78063 .48654 .78227 .48605 .78152 .4847 Mtetra
.78152 .4847 .78227 .48605 .78391 .48556 .78316 .48421 Mtetra
.78316 .48421 .78391 .48556 .78555 .48507 .7848 .48372 Mtetra
.658 .657 .837 r
.7848 .48372 .78555 .48507 .78719 .48458 .78644 .48323 Mtetra
.78644 .48323 .78719 .48458 .78883 .48409 .78808 .48273 Mtetra
.78808 .48273 .78883 .48409 .79047 .48359 .78973 .48224 Mtetra
.78973 .48224 .79047 .48359 .79211 .4831 .79137 .48174 Mtetra
.79137 .48174 .79211 .4831 .79376 .48261 .79301 .48125 Mtetra
.79301 .48125 .79376 .48261 .7954 .48211 .79466 .48075 Mtetra
.79466 .48075 .7954 .48211 .79705 .48162 .79631 .48026 Mtetra
.79631 .48026 .79705 .48162 .7987 .48112 .79795 .47976 Mtetra
.79795 .47976 .7987 .48112 .80034 .48062 .7996 .47926 Mtetra
.7996 .47926 .80034 .48062 .80199 .48013 .80125 .47877 Mtetra
.80125 .47877 .80199 .48013 .80364 .47963 .8029 .47827 Mtetra
.8029 .47827 .80364 .47963 .80529 .47913 .80455 .47777 Mtetra
.80455 .47777 .80529 .47913 .80694 .47864 .8062 .47727 Mtetra
.8062 .47727 .80694 .47864 .8086 .47814 .80786 .47678 Mtetra
.80786 .47678 .8086 .47814 .81025 .47764 .80951 .47628 Mtetra
.80951 .47628 .81025 .47764 .8119 .47714 .81117 .47578 Mtetra
.81117 .47578 .8119 .47714 .81356 .47665 .81282 .47528 Mtetra
.81282 .47528 .81356 .47665 .81522 .47615 .81448 .47478 Mtetra
.81448 .47478 .81522 .47615 .81687 .47565 .81614 .47428 Mtetra
.81614 .47428 .81687 .47565 .81853 .47515 .81779 .47378 Mtetra
.81779 .47378 .81853 .47515 .82019 .47465 .81945 .47328 Mtetra
.81945 .47328 .82019 .47465 .82185 .47415 .82111 .47278 Mtetra
.82111 .47278 .82185 .47415 .82351 .47365 .82278 .47228 Mtetra
.82278 .47228 .82351 .47365 .82517 .47315 .82444 .47178 Mtetra
.82444 .47178 .82517 .47315 .82684 .47265 .8261 .47128 Mtetra
.8261 .47128 .82684 .47265 .8285 .47215 .82777 .47078 Mtetra
.82777 .47078 .8285 .47215 .83017 .47165 .82943 .47028 Mtetra
.82943 .47028 .83017 .47165 .83183 .47115 .8311 .46978 Mtetra
.8311 .46978 .83183 .47115 .8335 .47065 .83277 .46928 Mtetra
.83277 .46928 .8335 .47065 .83517 .47015 .83443 .46878 Mtetra
.83443 .46878 .83517 .47015 .83684 .46965 .8361 .46828 Mtetra
.8361 .46828 .83684 .46965 .83851 .46915 .83777 .46777 Mtetra
.83777 .46777 .83851 .46915 .84018 .46864 .83945 .46727 Mtetra
.83945 .46727 .84018 .46864 .84185 .46814 .84112 .46677 Mtetra
.84112 .46677 .84185 .46814 .84352 .46764 .84279 .46626 Mtetra
.84279 .46626 .84352 .46764 .84519 .46713 .84446 .46576 Mtetra
.84446 .46576 .84519 .46713 .84687 .46663 .84614 .46526 Mtetra
.84614 .46526 .84687 .46663 .84854 .46613 .84782 .46475 Mtetra
.84782 .46475 .84854 .46613 .85022 .46562 .84949 .46425 Mtetra
.84949 .46425 .85022 .46562 .8519 .46512 .85117 .46374 Mtetra
.659 .657 .837 r
.85117 .46374 .8519 .46512 .85358 .46461 .85285 .46323 Mtetra
.85285 .46323 .85358 .46461 .85526 .4641 .85453 .46273 Mtetra
.85453 .46273 .85526 .4641 .85694 .4636 .85621 .46222 Mtetra
.85621 .46222 .85694 .4636 .85862 .46309 .85789 .46171 Mtetra
.85789 .46171 .85862 .46309 .8603 .46258 .85957 .4612 Mtetra
.85957 .4612 .8603 .46258 .86198 .46207 .86126 .46069 Mtetra
.86126 .46069 .86198 .46207 .86367 .46156 .86294 .46018 Mtetra
.86294 .46018 .86367 .46156 .86535 .46105 .86463 .45967 Mtetra
.86463 .45967 .86535 .46105 .86704 .46054 .86631 .45915 Mtetra
.86631 .45915 .86704 .46054 .86872 .46002 .868 .45864 Mtetra
.659 .657 .836 r
.868 .45864 .86872 .46002 .87041 .45951 .86969 .45812 Mtetra
.86969 .45812 .87041 .45951 .8721 .459 .87138 .45761 Mtetra
.87138 .45761 .8721 .459 .87379 .45848 .87307 .45709 Mtetra
.659 .656 .836 r
.87307 .45709 .87379 .45848 .87548 .45797 .87476 .45657 Mtetra
.87476 .45657 .87548 .45797 .87717 .45745 .87645 .45606 Mtetra
.87645 .45606 .87717 .45745 .87886 .45694 .87814 .45554 Mtetra
.659 .656 .835 r
.87814 .45554 .87886 .45694 .88056 .45642 .87983 .45502 Mtetra
.87983 .45502 .88056 .45642 .88225 .4559 .88153 .45451 Mtetra
.659 .655 .835 r
.88153 .45451 .88225 .4559 .88395 .45539 .88322 .45399 Mtetra
.88322 .45399 .88395 .45539 .88564 .45487 .88492 .45347 Mtetra
.88492 .45347 .88564 .45487 .88734 .45436 .88662 .45296 Mtetra
.88662 .45296 .88734 .45436 .88904 .45385 .88832 .45244 Mtetra
.658 .655 .835 r
.88832 .45244 .88904 .45385 .89074 .45333 .89002 .45193 Mtetra
.89002 .45193 .89074 .45333 .89244 .45282 .89172 .45142 Mtetra
.658 .655 .836 r
.89172 .45142 .89244 .45282 .89414 .45231 .89342 .4509 Mtetra
.89342 .4509 .89414 .45231 .89584 .45179 .89512 .45039 Mtetra
.89512 .45039 .89584 .45179 .89755 .45128 .89683 .44988 Mtetra
.89683 .44988 .89755 .45128 .89925 .45077 .89853 .44937 Mtetra
.89853 .44937 .89925 .45077 .90096 .45026 .90024 .44886 Mtetra
.658 .656 .836 r
.90024 .44886 .90096 .45026 .90266 .44975 .90195 .44835 Mtetra
.658 .656 .837 r
.90195 .44835 .90266 .44975 .90437 .44923 .90366 .44784 Mtetra
.657 .656 .837 r
.90366 .44784 .90437 .44923 .90608 .44872 .90537 .44733 Mtetra
.90537 .44733 .90608 .44872 .90779 .44822 .90708 .44682 Mtetra
.90708 .44682 .90779 .44822 .9095 .44771 .90879 .44631 Mtetra
.657 .656 .838 r
.90879 .44631 .9095 .44771 .91122 .4472 .9105 .4458 Mtetra
.657 .656 .837 r
.9105 .4458 .91122 .4472 .91293 .4467 .91222 .4453 Mtetra
.656 .655 .837 r
.91222 .4453 .91293 .4467 .91465 .4462 .91393 .44479 Mtetra
.91393 .44479 .91465 .4462 .91636 .4457 .91565 .44429 Mtetra
.656 .654 .836 r
.91565 .44429 .91636 .4457 .91808 .44521 .91737 .44379 Mtetra
.655 .652 .835 r
.91737 .44379 .91808 .44521 .9198 .44472 .91909 .44329 Mtetra
.654 .65 .834 r
.91909 .44329 .9198 .44472 .92152 .44424 .92081 .44279 Mtetra
.653 .648 .833 r
.92081 .44279 .92152 .44424 .92325 .44376 .92253 .4423 Mtetra
.653 .647 .831 r
.92253 .4423 .92325 .44376 .92497 .44328 .92425 .44181 Mtetra
.654 .645 .829 r
.92425 .44181 .92497 .44328 .9267 .4428 .92598 .44131 Mtetra
.654 .643 .828 r
.92598 .44131 .9267 .4428 .92842 .44231 .9277 .44081 Mtetra
.653 .642 .826 r
.9277 .44081 .92842 .44231 .93015 .44182 .92943 .44031 Mtetra
.653 .641 .825 r
.92943 .44031 .93015 .44182 .93187 .44133 .93115 .43981 Mtetra
.653 .64 .824 r
.93115 .43981 .93187 .44133 .9336 .44083 .93288 .43931 Mtetra
.652 .639 .824 r
.93288 .43931 .9336 .44083 .93533 .44034 .93461 .43882 Mtetra
.652 .638 .823 r
.93461 .43882 .93533 .44034 .93706 .43985 .93634 .43833 Mtetra
.651 .637 .823 r
.93634 .43833 .93706 .43985 .9388 .43937 .93808 .43784 Mtetra
.649 .637 .824 r
.93808 .43784 .9388 .43937 .94053 .43888 .93981 .43736 Mtetra
.65 .637 .824 r
.93981 .43736 .94053 .43888 .94227 .43841 .94155 .43688 Mtetra
.646 .634 .824 r
.94155 .43688 .94227 .43841 .944 .43794 .94329 .43642 Mtetra
.641 .633 .827 r
.94329 .43642 .944 .43794 .94574 .43747 .94503 .436 Mtetra
.624 .631 .837 r
.94503 .436 .94574 .43747 .94748 .43701 .94679 .43568 Mtetra
.621 .652 .859 r
.94679 .43568 .94748 .43701 .94922 .43653 .94855 .43538 Mtetra
.626 .684 .885 r
.94855 .43538 .94922 .43653 .95096 .43604 .95031 .43504 Mtetra
.653 .729 .905 r
.95031 .43504 .95096 .43604 .9527 .4355 .95206 .43456 Mtetra
.667 .748 .911 r
.95206 .43456 .9527 .4355 .95443 .43494 .95379 .43402 Mtetra
.679 .759 .912 r
.95379 .43402 .95443 .43494 .95616 .43434 .95552 .43343 Mtetra
.69 .765 .908 r
.95552 .43343 .95616 .43434 .95788 .43368 .95725 .43278 Mtetra
.696 .769 .908 r
.95725 .43278 .95788 .43368 .9596 .43301 .95897 .4321 Mtetra
.7 .772 .907 r
.95897 .4321 .9596 .43301 .96132 .43231 .96069 .43141 Mtetra
.779 .798 .868 r
.96069 .43141 .96132 .43231 .96298 .43118 .96235 .43027 Mtetra
.712 .774 .901 r
.96235 .43027 .96298 .43118 .96469 .43043 .96406 .42951 Mtetra
.539 .696 .941 r
.96406 .42951 .96469 .43043 .96649 .43036 .96587 .42945 Mtetra
.927 .553 .273 r
.39825 .5993 .3991 .60005 .40037 .60396 .39952 .60328 Mtetra
.937 .682 .526 r
.39952 .60328 .40037 .60396 .39506 .7914 .39415 .79084 Mtetra
.928 .58 .352 r
.39415 .79084 .39506 .7914 .39636 .79667 .39545 .79601 Mtetra
.346 .667 .974 r
.39545 .79601 .39636 .79667 .39785 .79687 .39695 .7962 Mtetra
.692 .79 .925 r
.39695 .7962 .39785 .79687 .39937 .79628 .39847 .79562 Mtetra
.764 .8 .882 r
.39847 .79562 .39937 .79628 .40091 .7953 .4 .79468 Mtetra
.608 .782 .964 r
.4 .79468 .40091 .7953 .40242 .79497 .40151 .79436 Mtetra
.574 .778 .975 r
.40151 .79436 .40242 .79497 .40393 .79472 .40302 .79413 Mtetra
.557 .777 .981 r
.40302 .79413 .40393 .79472 .40544 .79451 .40453 .79392 Mtetra
.536 .772 .985 r
.40453 .79392 .40544 .79451 .40695 .79435 .40604 .79376 Mtetra
.551 .775 .982 r
.40604 .79376 .40695 .79435 .40846 .79417 .40755 .79356 Mtetra
.582 .781 .974 r
.40755 .79356 .40846 .79417 .40997 .79393 .40907 .79331 Mtetra
.596 .78 .968 r
.40907 .79331 .40997 .79393 .41148 .79382 .41058 .79302 Mtetra
.662 .754 .918 r
.41058 .79302 .41148 .79382 .413 .79342 .4121 .79257 Mtetra
.718 .751 .878 r
.4121 .79257 .413 .79342 .41454 .79253 .41364 .79184 Mtetra
.837 .786 .803 r
.41364 .79184 .41454 .79253 .41614 .78931 .4152 .79013 Mtetra
.896 .978 .689 r
.4152 .79013 .41614 .78931 .41794 .77985 .41678 .78769 Mtetra
.385 .163 .449 r
.41678 .78769 .41794 .77985 .4248 .59682 .41839 .7844 Mtetra
.57 .363 .56 r
.41839 .7844 .4248 .59682 .42628 .59509 .41995 .78292 Mtetra
.573 .365 .56 r
.41995 .78292 .42628 .59509 .42772 .59477 .42146 .78273 Mtetra
.42146 .78273 .42772 .59477 .42915 .59508 .42297 .78306 Mtetra
.574 .366 .56 r
.42297 .78306 .42915 .59508 .43058 .59525 .42446 .78373 Mtetra
.573 .365 .56 r
.42446 .78373 .43058 .59525 .43201 .59515 .42598 .78372 Mtetra
.571 .363 .56 r
.42598 .78372 .43201 .59515 .43347 .59441 .42753 .78243 Mtetra
0 0 .372 r
.42753 .78243 .43347 .59441 .43497 .592 .43387 .60086 Mtetra
0 0 .203 r
.43387 .60086 .43497 .592 .43646 .58986 .43558 .5907 Mtetra
.967 .937 .659 r
.43558 .5907 .43646 .58986 .43794 .58824 .4371 .58746 Mtetra
.776 .765 .844 r
.4371 .58746 .43794 .58824 .4394 .58749 .43857 .5864 Mtetra
.658 .679 .859 r
.43857 .5864 .4394 .58749 .44085 .58708 .44002 .58597 Mtetra
.593 .654 .88 r
.44002 .58597 .44085 .58708 .4423 .58681 .44146 .58583 Mtetra
.615 .688 .895 r
.44146 .58583 .4423 .58681 .44374 .58651 .44291 .58559 Mtetra
.62 .702 .903 r
.44291 .58559 .44374 .58651 .44519 .5862 .44436 .58532 Mtetra
.629 .714 .908 r
.44436 .58532 .44519 .5862 .44665 .58585 .44581 .58502 Mtetra
.678 .74 .897 r
.44581 .58502 .44665 .58585 .4481 .58531 .44726 .58452 Mtetra
.697 .754 .895 r
.44726 .58452 .4481 .58531 .44956 .5847 .44872 .58394 Mtetra
.7 .762 .9 r
.44872 .58394 .44956 .5847 .45102 .58409 .45018 .58335 Mtetra
.708 .769 .899 r
.45018 .58335 .45102 .58409 .45248 .58334 .45164 .58272 Mtetra
.682 .796 .935 r
.45164 .58272 .45248 .58334 .45394 .58276 .4531 .5822 Mtetra
.597 .792 .974 r
.4531 .5822 .45394 .58276 .45539 .5826 .45456 .58191 Mtetra
.102 .51 .906 r
.45456 .58191 .45539 .5826 .45681 .58417 .456 .58244 Mtetra
.182 .329 .778 r
.456 .58244 .45681 .58417 .45816 .58936 .45742 .58369 Mtetra
.436 .327 .631 r
.45742 .58369 .45816 .58936 .45607 .77489 .45884 .58571 Mtetra
.573 .369 .565 r
.45884 .58571 .45607 .77489 .45757 .77668 .46029 .58582 Mtetra
.575 .37 .565 r
.46029 .58582 .45757 .77668 .45911 .77617 .46176 .58499 Mtetra
.574 .369 .565 r
.46176 .58499 .45911 .77617 .46067 .7754 .46322 .58493 Mtetra
.004 0 .404 r
.46322 .58493 .46067 .7754 .46218 .77672 .46153 .76279 Mtetra
.042 0 .467 r
.46153 .76279 .46218 .77672 .4637 .77823 .46285 .77531 Mtetra
0 .069 .602 r
.46285 .77531 .4637 .77823 .46522 .77921 .46435 .77824 Mtetra
.214 .511 .911 r
.46435 .77824 .46522 .77921 .46677 .77939 .46588 .77886 Mtetra
.544 .794 .991 r
.46588 .77886 .46677 .77939 .46831 .77917 .46743 .77864 Mtetra
.67 .828 .959 r
.46743 .77864 .46831 .77917 .46987 .77878 .46899 .7781 Mtetra
.646 .785 .948 r
.46899 .7781 .46987 .77878 .47142 .77852 .47054 .77768 Mtetra
.663 .746 .912 r
.47054 .77768 .47142 .77852 .47297 .77815 .4721 .77721 Mtetra
.71 .736 .872 r
.4721 .77721 .47297 .77815 .47453 .77737 .47366 .7765 Mtetra
.78 .763 .838 r
.47366 .7765 .47453 .77737 .47612 .77513 .47523 .77532 Mtetra
.897 .968 .822 r
.47523 .77532 .47612 .77513 .47773 .77013 .4768 .77347 Mtetra
.016 0 .192 r
.4768 .77347 .47773 .77013 .48166 .58303 .4784 .77035 Mtetra
.042 0 .414 r
.4784 .77035 .48166 .58303 .4832 .57739 .48209 .59925 Mtetra
0 0 .335 r
.48209 .59925 .4832 .57739 .48469 .57513 .48384 .57658 Mtetra
.853 .9 .484 r
.48384 .57658 .48469 .57513 .48618 .57372 .48535 .57318 Mtetra
.828 .824 .845 r
.48535 .57318 .48618 .57372 .48766 .57289 .48684 .57183 Mtetra
.677 .694 .858 r
.48684 .57183 .48766 .57289 .48914 .5724 .48832 .5713 Mtetra
.615 .666 .877 r
.48832 .5713 .48914 .5724 .49061 .57205 .48979 .57107 Mtetra
.664 .705 .878 r
.48979 .57107 .49061 .57205 .49209 .57144 .49127 .57062 Mtetra
.685 .748 .899 r
.49127 .57062 .49209 .57144 .49357 .57079 .49275 .57008 Mtetra
.628 .759 .941 r
.49275 .57008 .49357 .57079 .49505 .57052 .49423 .56974 Mtetra
.434 .668 .961 r
.49423 .56974 .49505 .57052 .49651 .57154 .4957 .56989 Mtetra
.357 .448 .817 r
.4957 .56989 .49651 .57154 .49796 .57514 .49717 .57068 Mtetra
.398 .321 .653 r
.49717 .57068 .49796 .57514 .49805 .76141 .49864 .57263 Mtetra
.548 .349 .562 r
.49864 .57263 .49805 .76141 .49957 .76694 .50002 .58663 Mtetra
0 0 .399 r
.50002 .58663 .49957 .76694 .50113 .76855 .50028 .76497 Mtetra
.108 .153 .627 r
.50028 .76497 .50113 .76855 .50269 .76924 .50183 .768 Mtetra
.234 .459 .872 r
.50183 .768 .50269 .76924 .50426 .76939 .50339 .76881 Mtetra
.527 .776 .989 r
.50339 .76881 .50426 .76939 .50583 .76919 .50497 .76864 Mtetra
.662 .827 .963 r
.50497 .76864 .50583 .76919 .50741 .76879 .50654 .76813 Mtetra
.658 .794 .947 r
.50654 .76813 .50741 .76879 .50898 .76848 .50812 .76765 Mtetra
.659 .751 .918 r
.50812 .76765 .50898 .76848 .51056 .76814 .5097 .76719 Mtetra
.705 .738 .877 r
.5097 .76719 .51056 .76814 .51214 .7674 .51127 .76651 Mtetra
.794 .763 .825 r
.51127 .76651 .51214 .7674 .51372 .76526 .51286 .76517 Mtetra
.915 .903 .799 r
.51286 .76517 .51372 .76526 .51531 .76011 .51444 .76303 Mtetra
.005 0 .165 r
.51444 .76303 .51531 .76011 .51731 .57268 .51603 .76018 Mtetra
.569 .362 .56 r
.51603 .76018 .51731 .57268 .51881 .56795 .51761 .7579 Mtetra
.572 .364 .56 r
.51761 .7579 .51881 .56795 .52031 .56723 .51919 .7573 Mtetra
.573 .365 .56 r
.51919 .7573 .52031 .56723 .5218 .56734 .52077 .75739 Mtetra
.52077 .75739 .5218 .56734 .5233 .56762 .52235 .75783 Mtetra
.52235 .75783 .5233 .56762 .52479 .56757 .52393 .758 Mtetra
.572 .364 .56 r
.52393 .758 .52479 .56757 .52629 .56698 .52551 .75719 Mtetra
.563 .357 .559 r
.52551 .75719 .52629 .56698 .52779 .56495 .52709 .75092 Mtetra
0 0 .398 r
.52709 .75092 .52779 .56495 .52929 .56253 .52848 .56465 Mtetra
.758 .797 .309 r
.52848 .56465 .52929 .56253 .53078 .56068 .52998 .56029 Mtetra
.877 .854 .815 r
.52998 .56029 .53078 .56068 .53228 .55959 .53147 .55852 Mtetra
.688 .7 .856 r
.53147 .55852 .53228 .55959 .53378 .55908 .53297 .55793 Mtetra
.621 .662 .868 r
.53297 .55793 .53378 .55908 .53528 .55874 .53447 .55767 Mtetra
.626 .678 .879 r
.53447 .55767 .53528 .55874 .53678 .55837 .53598 .55738 Mtetra
.662 .706 .879 r
.53598 .55738 .53678 .55837 .53829 .55792 .53748 .55693 Mtetra
.662 .707 .881 r
.53748 .55693 .53829 .55792 .53979 .55746 .53898 .55648 Mtetra
.663 .709 .882 r
.53898 .55648 .53979 .55746 .54129 .55701 .54049 .55603 Mtetra
.664 .711 .883 r
.54049 .55603 .54129 .55701 .5428 .55655 .54199 .55557 Mtetra
.664 .712 .884 r
.54199 .55557 .5428 .55655 .5443 .55608 .5435 .55512 Mtetra
.664 .713 .884 r
.5435 .55512 .5443 .55608 .54581 .55562 .54501 .55466 Mtetra
.664 .713 .885 r
.54501 .55466 .54581 .55562 .54732 .55516 .54652 .5542 Mtetra
.54652 .5542 .54732 .55516 .54883 .55471 .54802 .55374 Mtetra
.664 .714 .885 r
.54802 .55374 .54883 .55471 .55034 .55425 .54953 .55328 Mtetra
.664 .713 .885 r
.54953 .55328 .55034 .55425 .55185 .55379 .55104 .55283 Mtetra
.663 .713 .885 r
.55104 .55283 .55185 .55379 .55336 .55334 .55256 .55237 Mtetra
.55256 .55237 .55336 .55334 .55487 .55289 .55407 .55192 Mtetra
.662 .713 .886 r
.55407 .55192 .55487 .55289 .55638 .55244 .55558 .55147 Mtetra
.661 .712 .886 r
.55558 .55147 .55638 .55244 .55789 .55199 .55709 .55102 Mtetra
.661 .713 .886 r
.55709 .55102 .55789 .55199 .55941 .55154 .55861 .55058 Mtetra
.661 .713 .887 r
.55861 .55058 .55941 .55154 .56092 .55109 .56012 .55013 Mtetra
.656 .712 .889 r
.56012 .55013 .56092 .55109 .56244 .55066 .56164 .54971 Mtetra
.641 .709 .896 r
.56164 .54971 .56244 .55066 .56396 .55029 .56316 .54935 Mtetra
.621 .705 .905 r
.56316 .54935 .56396 .55029 .56548 .54998 .56468 .54906 Mtetra
.619 .71 .911 r
.56468 .54906 .56548 .54998 .567 .54967 .5662 .54878 Mtetra
.63 .721 .912 r
.5662 .54878 .567 .54967 .56852 .54932 .56772 .54845 Mtetra
.653 .734 .909 r
.56772 .54845 .56852 .54932 .57004 .54889 .56924 .54804 Mtetra
.666 .742 .907 r
.56924 .54804 .57004 .54889 .57156 .5484 .57076 .54757 Mtetra
.683 .75 .903 r
.57076 .54757 .57156 .5484 .57308 .54785 .57229 .54703 Mtetra
.698 .758 .898 r
.57229 .54703 .57308 .54785 .5746 .54722 .57381 .54642 Mtetra
.7 .762 .9 r
.57381 .54642 .5746 .54722 .57612 .54659 .57533 .5458 Mtetra
.69 .763 .907 r
.57533 .5458 .57612 .54659 .57764 .54601 .57685 .54523 Mtetra
.672 .76 .917 r
.57685 .54523 .57764 .54601 .57917 .54551 .57838 .54474 Mtetra
.665 .761 .921 r
.57838 .54474 .57917 .54551 .58069 .54503 .5799 .54426 Mtetra
.663 .762 .923 r
.5799 .54426 .58069 .54503 .58222 .54456 .58143 .5438 Mtetra
.665 .764 .924 r
.58143 .5438 .58222 .54456 .58374 .54409 .58296 .54333 Mtetra
.664 .764 .925 r
.58296 .54333 .58374 .54409 .58527 .54362 .58449 .54286 Mtetra
.664 .765 .925 r
.58449 .54286 .58527 .54362 .5868 .54314 .58601 .54239 Mtetra
.665 .766 .925 r
.58601 .54239 .5868 .54314 .58833 .54266 .58754 .54191 Mtetra
.665 .768 .927 r
.58754 .54191 .58833 .54266 .58986 .54218 .58908 .54144 Mtetra
.677 .772 .923 r
.58908 .54144 .58986 .54218 .59139 .54163 .59061 .54092 Mtetra
.697 .788 .921 r
.59061 .54092 .59139 .54163 .59292 .54092 .59214 .54032 Mtetra
.648 .806 .959 r
.59214 .54032 .59292 .54092 .59445 .5405 .59367 .53988 Mtetra
.467 .731 .984 r
.59367 .53988 .59445 .5405 .596 .54091 .59522 .53987 Mtetra
.097 .403 .856 r
.59522 .53987 .596 .54091 .59761 .54377 .59678 .5408 Mtetra
.35 .339 .707 r
.59678 .5408 .59761 .54377 .60319 .72645 .59836 .54242 Mtetra
.57 .366 .565 r
.59836 .54242 .60319 .72645 .60507 .73735 .59996 .54434 Mtetra
.573 .369 .565 r
.59996 .54434 .60507 .73735 .60671 .73761 .60151 .54431 Mtetra
.575 .37 .565 r
.60151 .54431 .60671 .73761 .60834 .7368 .60304 .54347 Mtetra
.575 .37 .566 r
.60304 .54347 .60834 .7368 .60995 .73555 .60456 .54226 Mtetra
.60456 .54226 .60995 .73555 .61157 .73468 .60609 .54104 Mtetra
.574 .369 .565 r
.60609 .54104 .61157 .73468 .6132 .73427 .60763 .54064 Mtetra
.57 .366 .565 r
.60763 .54064 .6132 .73427 .61486 .73493 .60924 .54275 Mtetra
.058 0 .443 r
.60924 .54275 .61486 .73493 .61656 .73677 .61561 .73095 Mtetra
.122 .113 .573 r
.61561 .73095 .61656 .73677 .61824 .73806 .61739 .73618 Mtetra
.044 .234 .734 r
.61739 .73618 .61824 .73806 .61991 .7388 .61909 .73806 Mtetra
.394 .675 .972 r
.61909 .73806 .61991 .7388 .62157 .73896 .62075 .73824 Mtetra
.63 .778 .952 r
.62075 .73824 .62157 .73896 .62321 .73861 .62239 .73784 Mtetra
.747 .794 .89 r
.62239 .73784 .62321 .73861 .62483 .73747 .62402 .73693 Mtetra
.842 .852 .852 r
.62402 .73693 .62483 .73747 .6264 .73423 .62563 .73541 Mtetra
0 0 0 r
.62563 .73541 .6264 .73423 .62781 .72568 .62722 .733 Mtetra
.278 .08 .423 r
.62722 .733 .62781 .72568 .6239 .53706 .62874 .72815 Mtetra
.055 0 .437 r
.62874 .72815 .6239 .53706 .62537 .53378 .62475 .53816 Mtetra
0 0 .179 r
.62475 .53816 .62537 .53378 .62688 .53198 .62614 .53235 Mtetra
.931 .97 .717 r
.62614 .53235 .62688 .53198 .62841 .53088 .62764 .52994 Mtetra
.699 .735 .879 r
.62764 .52994 .62841 .53088 .62996 .53039 .62919 .5293 Mtetra
.601 .67 .889 r
.62919 .5293 .62996 .53039 .63153 .53013 .63075 .5291 Mtetra
.562 .667 .908 r
.63075 .5291 .63153 .53013 .63309 .52988 .63232 .52903 Mtetra
.698 .756 .896 r
.63232 .52903 .63309 .52988 .63463 .52911 .63387 .52841 Mtetra
.674 .788 .935 r
.63387 .52841 .63463 .52911 .63619 .52857 .63542 .52789 Mtetra
.589 .764 .962 r
.63542 .52789 .63619 .52857 .63776 .52864 .63699 .52763 Mtetra
.395 .588 .92 r
.63699 .52763 .63776 .52864 .63942 .53096 .63858 .52801 Mtetra
.44 .4 .717 r
.63858 .52801 .63942 .53096 .64139 .54231 .64019 .52912 Mtetra
.497 .336 .593 r
.64019 .52912 .64139 .54231 .6494 .72554 .64188 .53222 Mtetra
.08 0 .454 r
.64188 .53222 .6494 .72554 .65115 .72771 .65011 .72049 Mtetra
.219 .167 .582 r
.65011 .72049 .65115 .72771 .65285 .72861 .65198 .72612 Mtetra
.218 .292 .727 r
.65198 .72612 .65285 .72861 .65454 .72888 .65373 .72805 Mtetra
.468 .683 .959 r
.65373 .72805 .65454 .72888 .65622 .72892 .65541 .72813 Mtetra
.665 .773 .93 r
.65541 .72813 .65622 .72892 .65788 .72846 .65707 .72762 Mtetra
.76 .783 .872 r
.65707 .72762 .65788 .72846 .65951 .72731 .65871 .7266 Mtetra
.816 .82 .853 r
.65871 .7266 .65951 .72731 .66106 .72392 .66034 .72522 Mtetra
0 0 0 r
.66034 .72522 .66106 .72392 .66234 .71342 .66194 .72302 Mtetra
.396 .189 .478 r
.66194 .72302 .66234 .71342 .65667 .52689 .66345 .71867 Mtetra
.075 0 .448 r
.66345 .71867 .65667 .52689 .65814 .52377 .65759 .52836 Mtetra
0 0 .222 r
.65759 .52836 .65814 .52377 .65966 .52198 .65895 .52247 Mtetra
.925 .966 .67 r
.65895 .52247 .65966 .52198 .6612 .52083 .66043 .51987 Mtetra
.705 .735 .875 r
.66043 .51987 .6612 .52083 .66277 .52032 .662 .51919 Mtetra
.608 .665 .879 r
.662 .51919 .66277 .52032 .66435 .52006 .66358 .51896 Mtetra
.545 .645 .899 r
.66358 .51896 .66435 .52006 .66594 .5199 .66517 .51897 Mtetra
.65 .724 .902 r
.66517 .51897 .66594 .5199 .66751 .51946 .66675 .51855 Mtetra
.664 .735 .903 r
.66675 .51855 .66751 .51946 .66908 .51895 .66833 .51808 Mtetra
.677 .746 .903 r
.66833 .51808 .66908 .51895 .67066 .51839 .6699 .51754 Mtetra
.733 .768 .881 r
.6699 .51754 .67066 .51839 .67221 .51742 .67146 .51673 Mtetra
.714 .803 .92 r
.67146 .51673 .67221 .51742 .67378 .5167 .67303 .51604 Mtetra
.643 .793 .954 r
.67303 .51604 .67378 .5167 .67536 .51644 .67461 .51561 Mtetra
.38 .629 .951 r
.67461 .51561 .67536 .51644 .67704 .51817 .67623 .5159 Mtetra
.409 .421 .761 r
.67623 .5159 .67704 .51817 .6789 .52356 .67788 .5169 Mtetra
.439 .325 .626 r
.67788 .5169 .6789 .52356 .68933 .71345 .6796 .51947 Mtetra
.101 .018 .466 r
.6796 .51947 .68933 .71345 .69118 .71667 .69002 .70799 Mtetra
.191 .137 .563 r
.69002 .70799 .69118 .71667 .69294 .7179 .69207 .71531 Mtetra
.173 .256 .71 r
.69207 .71531 .69294 .7179 .69467 .7183 .69388 .71755 Mtetra
.518 .73 .97 r
.69388 .71755 .69467 .7183 .69636 .71793 .69558 .71747 Mtetra
.691 .874 .967 r
.69558 .71747 .69636 .71793 .69803 .71725 .69726 .71678 Mtetra
.764 .884 .932 r
.69726 .71678 .69803 .71725 .6997 .71643 .69892 .7158 Mtetra
.654 .819 .962 r
.69892 .7158 .6997 .71643 .70138 .71593 .7006 .71528 Mtetra
.62 .801 .969 r
.7006 .71528 .70138 .71593 .70307 .71554 .70229 .71488 Mtetra
.598 .79 .972 r
.70229 .71488 .70307 .71554 .70477 .71522 .70399 .71454 Mtetra
.321 .655 .971 r
.70399 .71454 .70477 .71522 .7065 .71549 .70572 .71481 Mtetra
.487 .738 .983 r
.70572 .71481 .7065 .71549 .70821 .71544 .70743 .71476 Mtetra
.716 .819 .929 r
.70743 .71476 .70821 .71544 .70988 .71468 .70911 .71401 Mtetra
.943 .789 .661 r
.70911 .71401 .70988 .71468 .71136 .71016 .71059 .70961 Mtetra
.97 .69 .445 r
.71059 .70961 .71136 .71016 .70273 .51595 .70201 .51554 Mtetra
.971 .767 .571 r
.70201 .51554 .70273 .51595 .70398 .50888 .70324 .50808 Mtetra
.822 .795 .827 r
.70324 .50808 .70398 .50888 .70552 .50745 .70478 .50662 Mtetra
.655 .751 .92 r
.70478 .50662 .70552 .50745 .70712 .50702 .70638 .50617 Mtetra
.53 .697 .946 r
.70638 .50617 .70712 .50702 .70874 .50699 .708 .50613 Mtetra
.735 .77 .881 r
.708 .50613 .70874 .50699 .71032 .50617 .70958 .5053 Mtetra
.705 .759 .894 r
.70958 .5053 .71032 .50617 .71191 .5055 .71117 .50462 Mtetra
.537 .693 .94 r
.71117 .50462 .71191 .5055 .71353 .50546 .71279 .50457 Mtetra
.808 .364 0 r
.71279 .50457 .71353 .50546 .71536 .50888 .71462 .50799 Mtetra
.97 .683 .426 r
.71462 .50799 .71536 .50888 .72815 .7024 .72737 .70157 Mtetra
.92 .529 .154 r
.72737 .70157 .72815 .7024 .73022 .7084 .72945 .70757 Mtetra
0 .356 .82 r
.72945 .70757 .73022 .7084 .73202 .70946 .73124 .70863 Mtetra
.595 .744 .948 r
.73124 .70863 .73202 .70946 .73374 .70919 .73296 .70836 Mtetra
.795 .8 .856 r
.73296 .70836 .73374 .70919 .73539 .70791 .73462 .70708 Mtetra
.934 .779 .664 r
.73462 .70708 .73539 .70791 .73687 .70359 .7361 .70277 Mtetra
.971 .689 .436 r
.7361 .70277 .73687 .70359 .72685 .50965 .72612 .50883 Mtetra
.959 .746 .573 r
.72612 .50883 .72685 .50965 .72802 .50194 .72729 .50107 Mtetra
.834 .785 .805 r
.72729 .50107 .72802 .50194 .72956 .50029 .72883 .49942 Mtetra
.66 .745 .913 r
.72883 .49942 .72956 .50029 .73117 .49982 .73044 .49895 Mtetra
.532 .693 .943 r
.73044 .49895 .73117 .49982 .73281 .49978 .73208 .49891 Mtetra
.716 .765 .891 r
.73208 .49891 .73281 .49978 .7344 .49905 .73367 .49818 Mtetra
.706 .762 .896 r
.73367 .49818 .7344 .49905 .736 .49836 .73527 .4975 Mtetra
.535 .697 .943 r
.73527 .4975 .736 .49836 .73764 .4983 .73691 .49744 Mtetra
.801 .354 0 r
.73691 .49744 .73764 .4983 .7395 .50164 .73878 .50087 Mtetra
.972 .681 .416 r
.73878 .50087 .7395 .50164 .7538 .69605 .75305 .69546 Mtetra
.916 .517 .162 r
.75305 .69546 .7538 .69605 .75593 .7019 .75517 .70116 Mtetra
.026 .447 .872 r
.75517 .70116 .75593 .7019 .75775 .70286 .75698 .70198 Mtetra
.667 .761 .921 r
.75698 .70198 .75775 .70286 .75947 .70241 .7587 .70145 Mtetra
.777 .773 .849 r
.7587 .70145 .75947 .70241 .76114 .7011 .76037 .70024 Mtetra
.84 .801 .813 r
.76037 .70024 .76114 .7011 .76269 .69815 .76201 .6985 Mtetra
.889 .982 .702 r
.76201 .6985 .76269 .69815 .76396 .69096 .7636 .69615 Mtetra
.334 .109 .415 r
.7636 .69615 .76396 .69096 .7526 .49965 .76515 .69304 Mtetra
.571 .363 .56 r
.76515 .69304 .7526 .49965 .75407 .49701 .76682 .69183 Mtetra
.573 .365 .56 r
.76682 .69183 .75407 .49701 .75571 .4966 .76858 .69184 Mtetra
.572 .364 .56 r
.76858 .69184 .75571 .4966 .75736 .49647 .77028 .69102 Mtetra
.171 .07 .489 r
.77028 .69102 .75736 .49647 .75889 .4946 .75941 .51136 Mtetra
.087 0 .431 r
.75941 .51136 .75889 .4946 .76039 .49239 .75983 .49369 Mtetra
.735 .799 .32 r
.75983 .49369 .76039 .49239 .76193 .49068 .76123 .49003 Mtetra
.833 .841 .852 r
.76123 .49003 .76193 .49068 .76353 .48975 .76279 .48861 Mtetra
.671 .696 .865 r
.76279 .48861 .76353 .48975 .76516 .48926 .76442 .48808 Mtetra
.611 .663 .875 r
.76442 .48808 .76516 .48926 .7668 .48892 .76606 .48783 Mtetra
.635 .691 .885 r
.76606 .48783 .7668 .48892 .76843 .48852 .7677 .48747 Mtetra
.657 .709 .886 r
.7677 .48747 .76843 .48852 .77007 .48805 .76934 .48701 Mtetra
.76934 .48701 .77007 .48805 .7717 .48759 .77097 .48655 Mtetra
.659 .711 .886 r
.77097 .48655 .7717 .48759 .77334 .48712 .77261 .48608 Mtetra
.66 .712 .886 r
.77261 .48608 .77334 .48712 .77497 .48664 .77425 .4856 Mtetra
.661 .712 .886 r
.77425 .4856 .77497 .48664 .77661 .48616 .77588 .48512 Mtetra
.662 .712 .886 r
.77588 .48512 .77661 .48616 .77824 .48567 .77752 .48463 Mtetra
.662 .713 .886 r
.77752 .48463 .77824 .48567 .77988 .48519 .77916 .48415 Mtetra
.77916 .48415 .77988 .48519 .78152 .4847 .7808 .48366 Mtetra
.663 .713 .885 r
.7808 .48366 .78152 .4847 .78316 .48421 .78244 .48317 Mtetra
.78244 .48317 .78316 .48421 .7848 .48372 .78408 .48268 Mtetra
.78408 .48268 .7848 .48372 .78644 .48323 .78572 .48218 Mtetra
.78572 .48218 .78644 .48323 .78808 .48273 .78736 .48169 Mtetra
.78736 .48169 .78808 .48273 .78973 .48224 .789 .4812 Mtetra
.789 .4812 .78973 .48224 .79137 .48174 .79065 .4807 Mtetra
.79065 .4807 .79137 .48174 .79301 .48125 .79229 .4802 Mtetra
.79229 .4802 .79301 .48125 .79466 .48075 .79394 .47971 Mtetra
.79394 .47971 .79466 .48075 .79631 .48026 .79559 .47921 Mtetra
.664 .713 .885 r
.79559 .47921 .79631 .48026 .79795 .47976 .79724 .47871 Mtetra
.79724 .47871 .79795 .47976 .7996 .47926 .79888 .47822 Mtetra
.79888 .47822 .7996 .47926 .80125 .47877 .80053 .47772 Mtetra
.80053 .47772 .80125 .47877 .8029 .47827 .80218 .47722 Mtetra
.80218 .47722 .8029 .47827 .80455 .47777 .80384 .47672 Mtetra
.80384 .47672 .80455 .47777 .8062 .47727 .80549 .47622 Mtetra
.663 .713 .885 r
.80549 .47622 .8062 .47727 .80786 .47678 .80714 .47572 Mtetra
.80714 .47572 .80786 .47678 .80951 .47628 .8088 .47523 Mtetra
.8088 .47523 .80951 .47628 .81117 .47578 .81045 .47473 Mtetra
.663 .712 .885 r
.81045 .47473 .81117 .47578 .81282 .47528 .81211 .47423 Mtetra
.81211 .47423 .81282 .47528 .81448 .47478 .81377 .47373 Mtetra
.81377 .47373 .81448 .47478 .81614 .47428 .81542 .47323 Mtetra
.81542 .47323 .81614 .47428 .81779 .47378 .81708 .47273 Mtetra
.81708 .47273 .81779 .47378 .81945 .47328 .81874 .47223 Mtetra
.81874 .47223 .81945 .47328 .82111 .47278 .82041 .47173 Mtetra
.82041 .47173 .82111 .47278 .82278 .47228 .82207 .47123 Mtetra
.82207 .47123 .82278 .47228 .82444 .47178 .82373 .47073 Mtetra
.82373 .47073 .82444 .47178 .8261 .47128 .8254 .47023 Mtetra
.8254 .47023 .8261 .47128 .82777 .47078 .82706 .46972 Mtetra
.82706 .46972 .82777 .47078 .82943 .47028 .82873 .46922 Mtetra
.82873 .46922 .82943 .47028 .8311 .46978 .83039 .46872 Mtetra
.663 .713 .885 r
.83039 .46872 .8311 .46978 .83277 .46928 .83206 .46822 Mtetra
.83206 .46822 .83277 .46928 .83443 .46878 .83373 .46772 Mtetra
.83373 .46772 .83443 .46878 .8361 .46828 .8354 .46722 Mtetra
.8354 .46722 .8361 .46828 .83777 .46777 .83707 .46671 Mtetra
.83707 .46671 .83777 .46777 .83945 .46727 .83874 .46621 Mtetra
.83874 .46621 .83945 .46727 .84112 .46677 .84042 .46571 Mtetra
.84042 .46571 .84112 .46677 .84279 .46626 .84209 .4652 Mtetra
.84209 .4652 .84279 .46626 .84446 .46576 .84376 .4647 Mtetra
.84376 .4647 .84446 .46576 .84614 .46526 .84544 .46419 Mtetra
.84544 .46419 .84614 .46526 .84782 .46475 .84712 .46369 Mtetra
.84712 .46369 .84782 .46475 .84949 .46425 .84879 .46318 Mtetra
.664 .713 .885 r
.84879 .46318 .84949 .46425 .85117 .46374 .85047 .46268 Mtetra
.85047 .46268 .85117 .46374 .85285 .46323 .85215 .46217 Mtetra
.85215 .46217 .85285 .46323 .85453 .46273 .85383 .46166 Mtetra
.85383 .46166 .85453 .46273 .85621 .46222 .85551 .46115 Mtetra
.85551 .46115 .85621 .46222 .85789 .46171 .8572 .46064 Mtetra
.8572 .46064 .85789 .46171 .85957 .4612 .85888 .46013 Mtetra
.664 .713 .884 r
.85888 .46013 .85957 .4612 .86126 .46069 .86056 .45962 Mtetra
.86056 .45962 .86126 .46069 .86294 .46018 .86225 .45911 Mtetra
.86225 .45911 .86294 .46018 .86463 .45967 .86393 .45859 Mtetra
.665 .713 .884 r
.86393 .45859 .86463 .45967 .86631 .45915 .86562 .45808 Mtetra
.86562 .45808 .86631 .45915 .868 .45864 .86731 .45756 Mtetra
.665 .712 .883 r
.86731 .45756 .868 .45864 .86969 .45812 .86899 .45705 Mtetra
.86899 .45705 .86969 .45812 .87138 .45761 .87068 .45653 Mtetra
.87068 .45653 .87138 .45761 .87307 .45709 .87237 .45601 Mtetra
.665 .711 .882 r
.87237 .45601 .87307 .45709 .87476 .45657 .87407 .45549 Mtetra
.87407 .45549 .87476 .45657 .87645 .45606 .87576 .45497 Mtetra
.87576 .45497 .87645 .45606 .87814 .45554 .87745 .45445 Mtetra
.665 .71 .881 r
.87745 .45445 .87814 .45554 .87983 .45502 .87914 .45393 Mtetra
.87914 .45393 .87983 .45502 .88153 .45451 .88084 .45341 Mtetra
.664 .709 .881 r
.88084 .45341 .88153 .45451 .88322 .45399 .88254 .45289 Mtetra
.88254 .45289 .88322 .45399 .88492 .45347 .88423 .45238 Mtetra
.88423 .45238 .88492 .45347 .88662 .45296 .88593 .45186 Mtetra
.88593 .45186 .88662 .45296 .88832 .45244 .88763 .45135 Mtetra
.664 .708 .881 r
.88763 .45135 .88832 .45244 .89002 .45193 .88933 .45083 Mtetra
.663 .708 .881 r
.88933 .45083 .89002 .45193 .89172 .45142 .89103 .45032 Mtetra
.89103 .45032 .89172 .45142 .89342 .4509 .89274 .4498 Mtetra
.89274 .4498 .89342 .4509 .89512 .45039 .89444 .44929 Mtetra
.663 .708 .882 r
.89444 .44929 .89512 .45039 .89683 .44988 .89615 .44878 Mtetra
.663 .709 .882 r
.89615 .44878 .89683 .44988 .89853 .44937 .89785 .44827 Mtetra
.662 .709 .882 r
.89785 .44827 .89853 .44937 .90024 .44886 .89956 .44776 Mtetra
.89956 .44776 .90024 .44886 .90195 .44835 .90127 .44725 Mtetra
.662 .709 .883 r
.90127 .44725 .90195 .44835 .90366 .44784 .90298 .44674 Mtetra
.662 .71 .883 r
.90298 .44674 .90366 .44784 .90537 .44733 .90469 .44623 Mtetra
.90469 .44623 .90537 .44733 .90708 .44682 .9064 .44573 Mtetra
.662 .71 .884 r
.9064 .44573 .90708 .44682 .90879 .44631 .90811 .44522 Mtetra
.90811 .44522 .90879 .44631 .9105 .4458 .90983 .44471 Mtetra
.90983 .44471 .9105 .4458 .91222 .4453 .91154 .4442 Mtetra
.91154 .4442 .91222 .4453 .91393 .44479 .91326 .44369 Mtetra
.662 .71 .883 r
.91326 .44369 .91393 .44479 .91565 .44429 .91497 .44319 Mtetra
.661 .709 .883 r
.91497 .44319 .91565 .44429 .91737 .44379 .91669 .44268 Mtetra
.661 .707 .882 r
.91669 .44268 .91737 .44379 .91909 .44329 .91841 .44217 Mtetra
.66 .706 .881 r
.91841 .44217 .91909 .44329 .92081 .44279 .92013 .44167 Mtetra
.66 .704 .879 r
.92013 .44167 .92081 .44279 .92253 .4423 .92185 .44116 Mtetra
.66 .702 .877 r
.92185 .44116 .92253 .4423 .92425 .44181 .92358 .44066 Mtetra
.661 .7 .876 r
.92358 .44066 .92425 .44181 .92598 .44131 .9253 .44015 Mtetra
.66 .698 .874 r
.9253 .44015 .92598 .44131 .9277 .44081 .92702 .43965 Mtetra
.66 .697 .873 r
.92702 .43965 .9277 .44081 .92943 .44031 .92875 .43914 Mtetra
.66 .695 .872 r
.92875 .43914 .92943 .44031 .93115 .43981 .93048 .43863 Mtetra
.659 .694 .871 r
.93048 .43863 .93115 .43981 .93288 .43931 .9322 .43813 Mtetra
.658 .693 .871 r
.9322 .43813 .93288 .43931 .93461 .43882 .93393 .43763 Mtetra
.657 .692 .871 r
.93393 .43763 .93461 .43882 .93634 .43833 .93567 .43714 Mtetra
.655 .691 .872 r
.93567 .43714 .93634 .43833 .93808 .43784 .9374 .43666 Mtetra
.654 .691 .873 r
.9374 .43666 .93808 .43784 .93981 .43736 .93914 .43618 Mtetra
.653 .692 .874 r
.93914 .43618 .93981 .43736 .94155 .43688 .94087 .43571 Mtetra
.648 .691 .877 r
.94087 .43571 .94155 .43688 .94329 .43642 .94262 .43527 Mtetra
.639 .69 .881 r
.94262 .43527 .94329 .43642 .94503 .436 .94436 .43486 Mtetra
.615 .682 .89 r
.94436 .43486 .94503 .436 .94679 .43568 .94613 .43457 Mtetra
.61 .686 .896 r
.94613 .43457 .94679 .43568 .94855 .43538 .9479 .4343 Mtetra
.615 .696 .901 r
.9479 .4343 .94855 .43538 .95031 .43504 .94966 .434 Mtetra
.646 .718 .9 r
.94966 .434 .95031 .43504 .95206 .43456 .95141 .43356 Mtetra
.661 .732 .902 r
.95141 .43356 .95206 .43456 .95379 .43402 .95315 .43305 Mtetra
.674 .744 .903 r
.95315 .43305 .95379 .43402 .95552 .43343 .95488 .43248 Mtetra
.687 .755 .903 r
.95488 .43248 .95552 .43343 .95725 .43278 .95661 .43184 Mtetra
.694 .761 .904 r
.95661 .43184 .95725 .43278 .95897 .4321 .95833 .43118 Mtetra
.698 .765 .903 r
.95833 .43118 .95897 .4321 .96069 .43141 .96005 .43049 Mtetra
.778 .793 .865 r
.96005 .43049 .96069 .43141 .96235 .43027 .96171 .42934 Mtetra
.711 .77 .898 r
.96171 .42934 .96235 .43027 .96406 .42951 .96343 .42858 Mtetra
.54 .693 .939 r
.96343 .42858 .96406 .42951 .96587 .42945 .96524 .42852 Mtetra
.929 .556 .278 r
.39739 .59855 .39825 .5993 .39952 .60328 .39866 .6026 Mtetra
.937 .682 .526 r
.39866 .6026 .39952 .60328 .39415 .79084 .39323 .79025 Mtetra
.928 .578 .346 r
.39323 .79025 .39415 .79084 .39545 .79601 .39455 .79533 Mtetra
.326 .654 .971 r
.39455 .79533 .39545 .79601 .39695 .7962 .39604 .79556 Mtetra
.686 .795 .932 r
.39604 .79556 .39695 .7962 .39847 .79562 .39756 .795 Mtetra
.769 .807 .884 r
.39756 .795 .39847 .79562 .4 .79468 .39909 .79403 Mtetra
.676 .794 .937 r
.39909 .79403 .4 .79468 .40151 .79436 .40061 .79351 Mtetra
.671 .742 .904 r
.40061 .79351 .40151 .79436 .40302 .79413 .40213 .79302 Mtetra
.662 .689 .865 r
.40213 .79302 .40302 .79413 .40453 .79392 .40365 .79256 Mtetra
.641 .641 .835 r
.40365 .79256 .40453 .79392 .40604 .79376 .40516 .7922 Mtetra
.631 .612 .813 r
.40516 .7922 .40604 .79376 .40755 .79356 .40668 .79188 Mtetra
.625 .596 .8 r
.40668 .79188 .40755 .79356 .40907 .79331 .4082 .79158 Mtetra
.62 .589 .797 r
.4082 .79158 .40907 .79331 .41058 .79302 .40971 .79132 Mtetra
.622 .592 .799 r
.40971 .79132 .41058 .79302 .4121 .79257 .41123 .79104 Mtetra
.631 .616 .817 r
.41123 .79104 .4121 .79257 .41364 .79184 .41275 .79072 Mtetra
.664 .688 .862 r
.41275 .79072 .41364 .79184 .4152 .79013 .41427 .79025 Mtetra
.408 .86 .859 r
.41427 .79025 .4152 .79013 .41678 .78769 .4158 .78974 Mtetra
.431 .087 .279 r
.4158 .78974 .41678 .78769 .41839 .7844 .41733 .78923 Mtetra
.53 .262 .453 r
.41733 .78923 .41839 .7844 .41995 .78292 .41885 .78884 Mtetra
.541 .284 .475 r
.41885 .78884 .41995 .78292 .42146 .78273 .42038 .78849 Mtetra
.54 .282 .473 r
.42038 .78849 .42146 .78273 .42297 .78306 .4219 .78814 Mtetra
.561 .294 .468 r
.4219 .78814 .42297 .78306 .42446 .78373 .42342 .78819 Mtetra
.538 .264 .448 r
.42342 .78819 .42446 .78373 .42598 .78372 .42494 .78796 Mtetra
.475 .203 .42 r
.42494 .78796 .42598 .78372 .42753 .78243 .42649 .78704 Mtetra
0 0 .19 r
.42649 .78704 .42753 .78243 .43387 .60086 .42813 .78237 Mtetra
0 0 .333 r
.42813 .78237 .43387 .60086 .43558 .5907 .43464 .59341 Mtetra
.906 .848 .396 r
.43464 .59341 .43558 .5907 .4371 .58746 .43624 .58732 Mtetra
.855 .916 .873 r
.43624 .58732 .4371 .58746 .43857 .5864 .43772 .58595 Mtetra
.632 .837 .979 r
.43772 .58595 .43857 .5864 .44002 .58597 .43917 .58554 Mtetra
.417 .763 .996 r
.43917 .58554 .44002 .58597 .44146 .58583 .44061 .58549 Mtetra
.583 .856 .995 r
.44061 .58549 .44146 .58583 .44291 .58559 .44206 .58513 Mtetra
.648 .834 .972 r
.44206 .58513 .44291 .58559 .44436 .58532 .44351 .58468 Mtetra
.662 .784 .939 r
.44351 .58468 .44436 .58532 .44581 .58502 .44497 .58423 Mtetra
.662 .746 .912 r
.44497 .58423 .44581 .58502 .44726 .58452 .44642 .5838 Mtetra
.66 .762 .925 r
.44642 .5838 .44726 .58452 .44872 .58394 .44788 .58337 Mtetra
.653 .802 .955 r
.44788 .58337 .44872 .58394 .45018 .58335 .44934 .58294 Mtetra
.643 .848 .979 r
.44934 .58294 .45018 .58335 .45164 .58272 .45079 .58248 Mtetra
.601 .889 .99 r
.45079 .58248 .45164 .58272 .4531 .5822 .45225 .58202 Mtetra
.566 .894 .985 r
.45225 .58202 .4531 .5822 .45456 .58191 .45371 .58158 Mtetra
.587 .86 .995 r
.45371 .58158 .45456 .58191 .456 .58244 .45517 .5812 Mtetra
.641 .65 .844 r
.45517 .5812 .456 .58244 .45742 .58369 .45663 .58085 Mtetra
.618 .512 .711 r
.45663 .58085 .45742 .58369 .45884 .58571 .45809 .5805 Mtetra
.623 .465 .647 r
.45809 .5805 .45884 .58571 .46029 .58582 .45956 .57974 Mtetra
.611 .448 .637 r
.45956 .57974 .46029 .58582 .46176 .58499 .46102 .57909 Mtetra
.584 .43 .639 r
.46102 .57909 .46176 .58499 .46322 .58493 .46248 .57902 Mtetra
.363 .271 .616 r
.46248 .57902 .46322 .58493 .46153 .76279 .46388 .58189 Mtetra
0 0 .361 r
.46388 .58189 .46153 .76279 .46285 .77531 .46206 .76984 Mtetra
0 0 .392 r
.46206 .76984 .46285 .77531 .46435 .77824 .46348 .77656 Mtetra
.284 .413 .817 r
.46348 .77656 .46435 .77824 .46588 .77886 .46501 .77755 Mtetra
.634 .649 .847 r
.46501 .77755 .46588 .77886 .46743 .77864 .46656 .77721 Mtetra
.698 .658 .806 r
.46656 .77721 .46743 .77864 .46899 .7781 .46812 .77644 Mtetra
.656 .615 .796 r
.46812 .77644 .46899 .7781 .47054 .77768 .46968 .77594 Mtetra
.634 .597 .795 r
.46968 .77594 .47054 .77768 .4721 .77721 .47123 .77558 Mtetra
.641 .612 .804 r
.47123 .77558 .4721 .77721 .47366 .7765 .47279 .77518 Mtetra
.6 .633 .856 r
.47279 .77518 .47366 .7765 .47523 .77532 .47434 .77501 Mtetra
.523 .851 .997 r
.47434 .77501 .47523 .77532 .4768 .77347 .4759 .77469 Mtetra
.139 0 0 r
.4759 .77469 .4768 .77347 .4784 .77035 .47746 .77378 Mtetra
0 0 .137 r
.47746 .77378 .4784 .77035 .48209 .59925 .47907 .77009 Mtetra
0 0 .329 r
.47907 .77009 .48209 .59925 .48384 .57658 .48294 .58168 Mtetra
0 0 0 r
.48294 .58168 .48384 .57658 .48535 .57318 .48452 .57333 Mtetra
.915 .952 .805 r
.48452 .57333 .48535 .57318 .48684 .57183 .48601 .5714 Mtetra
.676 .856 .968 r
.48601 .5714 .48684 .57183 .48832 .5713 .48749 .57086 Mtetra
.483 .79 .999 r
.48749 .57086 .48832 .5713 .48979 .57107 .48896 .57072 Mtetra
.57 .851 .997 r
.48896 .57072 .48979 .57107 .49127 .57062 .49044 .57037 Mtetra
.628 .898 .986 r
.49044 .57037 .49127 .57062 .49275 .57008 .49192 .56985 Mtetra
.606 .896 .988 r
.49192 .56985 .49275 .57008 .49423 .56974 .4934 .56936 Mtetra
.71 .873 .958 r
.4934 .56936 .49423 .56974 .4957 .56989 .49488 .5687 Mtetra
.68 .675 .838 r
.49488 .5687 .4957 .56989 .49717 .57068 .49637 .56813 Mtetra
.588 .507 .731 r
.49637 .56813 .49717 .57068 .49864 .57263 .49784 .56808 Mtetra
.369 .299 .646 r
.49784 .56808 .49864 .57263 .50002 .58663 .49931 .57029 Mtetra
.973 .709 .471 r
.49931 .57029 .50002 .58663 .50028 .76497 .49947 .75617 Mtetra
0 0 .424 r
.49947 .75617 .50028 .76497 .50183 .768 .50097 .76597 Mtetra
.2 .317 .76 r
.50097 .76597 .50183 .768 .50339 .76881 .50253 .76745 Mtetra
.617 .635 .846 r
.50253 .76745 .50339 .76881 .50497 .76864 .5041 .7672 Mtetra
.693 .655 .808 r
.5041 .7672 .50497 .76864 .50654 .76813 .50568 .76646 Mtetra
.666 .62 .794 r
.50568 .76646 .50654 .76813 .50812 .76765 .50726 .76588 Mtetra
.633 .595 .793 r
.50726 .76588 .50812 .76765 .5097 .76719 .50883 .76551 Mtetra
.638 .607 .801 r
.50883 .76551 .5097 .76719 .51127 .76651 .51041 .76512 Mtetra
.657 .649 .831 r
.51041 .76512 .51127 .76651 .51286 .76517 .51199 .76465 Mtetra
.666 .835 .964 r
.51199 .76465 .51286 .76517 .51444 .76303 .51357 .76411 Mtetra
.273 0 .013 r
.51357 .76411 .51444 .76303 .51603 .76018 .51515 .76357 Mtetra
.502 .209 .401 r
.51515 .76357 .51603 .76018 .51761 .7579 .51673 .76311 Mtetra
.534 .27 .461 r
.51673 .76311 .51761 .7579 .51919 .7573 .51832 .76272 Mtetra
.536 .274 .465 r
.51832 .76272 .51919 .7573 .52077 .75739 .5199 .76234 Mtetra
.549 .28 .461 r
.5199 .76234 .52077 .75739 .52235 .75783 .52148 .76222 Mtetra
.546 .27 .447 r
.52148 .76222 .52235 .75783 .52393 .758 .52307 .7621 Mtetra
.499 .222 .425 r
.52307 .7621 .52393 .758 .52551 .75719 .52466 .76144 Mtetra
.25 .011 .342 r
.52466 .76144 .52551 .75719 .52709 .75092 .52624 .75865 Mtetra
.985 .774 .374 r
.52624 .75865 .52709 .75092 .52848 .56465 .52781 .73192 Mtetra
0 0 .389 r
.52781 .73192 .52848 .56465 .52998 .56029 .52917 .56066 Mtetra
.951 .947 .728 r
.52917 .56066 .52998 .56029 .53147 .55852 .53066 .55809 Mtetra
.709 .864 .955 r
.53066 .55809 .53147 .55852 .53297 .55793 .53217 .55743 Mtetra
.526 .792 .994 r
.53217 .55743 .53297 .55793 .53447 .55767 .53367 .55724 Mtetra
.514 .812 .999 r
.53367 .55724 .53447 .55767 .53598 .55738 .53517 .55703 Mtetra
.612 .868 .991 r
.53517 .55703 .53598 .55738 .53748 .55693 .53668 .55659 Mtetra
.607 .869 .992 r
.53668 .55659 .53748 .55693 .53898 .55648 .53818 .55615 Mtetra
.606 .872 .992 r
.53818 .55615 .53898 .55648 .54049 .55603 .53969 .55571 Mtetra
.609 .875 .991 r
.53969 .55571 .54049 .55603 .54199 .55557 .54119 .55526 Mtetra
.609 .876 .991 r
.54119 .55526 .54199 .55557 .5435 .55512 .5427 .5548 Mtetra
.61 .877 .991 r
.5427 .5548 .5435 .55512 .54501 .55466 .54421 .55434 Mtetra
.609 .877 .991 r
.54421 .55434 .54501 .55466 .54652 .5542 .54572 .55388 Mtetra
.54572 .55388 .54652 .5542 .54802 .55374 .54723 .55343 Mtetra
.54723 .55343 .54802 .55374 .54953 .55328 .54874 .55297 Mtetra
.54874 .55297 .54953 .55328 .55104 .55283 .55025 .55251 Mtetra
.608 .876 .991 r
.55025 .55251 .55104 .55283 .55256 .55237 .55176 .55205 Mtetra
.607 .876 .992 r
.55176 .55205 .55256 .55237 .55407 .55192 .55327 .5516 Mtetra
.606 .875 .992 r
.55327 .5516 .55407 .55192 .55558 .55147 .55479 .55115 Mtetra
.603 .874 .992 r
.55479 .55115 .55558 .55147 .55709 .55102 .5563 .5507 Mtetra
.596 .873 .993 r
.5563 .5507 .55709 .55102 .55861 .55058 .55782 .55027 Mtetra
.584 .873 .994 r
.55782 .55027 .55861 .55058 .56012 .55013 .55933 .54985 Mtetra
.577 .878 .993 r
.55933 .54985 .56012 .55013 .56164 .54971 .56085 .54943 Mtetra
.589 .882 .992 r
.56085 .54943 .56164 .54971 .56316 .54935 .56237 .54898 Mtetra
.629 .869 .987 r
.56237 .54898 .56316 .54935 .56468 .54906 .56389 .5485 Mtetra
.658 .818 .96 r
.56389 .5485 .56468 .54906 .5662 .54878 .5654 .54802 Mtetra
.663 .763 .924 r
.5654 .54802 .5662 .54878 .56772 .54845 .56693 .54756 Mtetra
.658 .728 .901 r
.56693 .54756 .56772 .54845 .56924 .54804 .56845 .54712 Mtetra
.658 .723 .897 r
.56845 .54712 .56924 .54804 .57076 .54757 .56997 .54669 Mtetra
.661 .732 .902 r
.56997 .54669 .57076 .54757 .57229 .54703 .57149 .54624 Mtetra
.666 .756 .918 r
.57149 .54624 .57229 .54703 .57381 .54642 .57302 .54577 Mtetra
.663 .793 .944 r
.57302 .54577 .57381 .54642 .57533 .5458 .57454 .54529 Mtetra
.652 .831 .969 r
.57454 .54529 .57533 .5458 .57685 .54523 .57606 .54481 Mtetra
.636 .856 .983 r
.57606 .54481 .57685 .54523 .57838 .54474 .57759 .54434 Mtetra
.631 .861 .986 r
.57759 .54434 .57838 .54474 .5799 .54426 .57912 .54387 Mtetra
.63 .861 .986 r
.57912 .54387 .5799 .54426 .58143 .5438 .58065 .5434 Mtetra
.63 .859 .986 r
.58065 .5434 .58143 .5438 .58296 .54333 .58217 .54293 Mtetra
.629 .86 .986 r
.58217 .54293 .58296 .54333 .58449 .54286 .5837 .54246 Mtetra
.628 .861 .986 r
.5837 .54246 .58449 .54286 .58601 .54239 .58523 .542 Mtetra
.626 .862 .987 r
.58523 .542 .58601 .54239 .58754 .54191 .58676 .54153 Mtetra
.625 .865 .988 r
.58676 .54153 .58754 .54191 .58908 .54144 .5883 .54107 Mtetra
.627 .867 .987 r
.5883 .54107 .58908 .54144 .59061 .54092 .58983 .54059 Mtetra
.623 .879 .989 r
.58983 .54059 .59061 .54092 .59214 .54032 .59136 .5401 Mtetra
.578 .896 .986 r
.59136 .5401 .59214 .54032 .59367 .53988 .5929 .53962 Mtetra
.57 .884 .991 r
.5929 .53962 .59367 .53988 .59522 .53987 .59443 .53918 Mtetra
.631 .775 .95 r
.59443 .53918 .59522 .53987 .59678 .5408 .59597 .53881 Mtetra
.63 .568 .766 r
.59597 .53881 .59678 .5408 .59836 .54242 .59751 .53845 Mtetra
.611 .478 .674 r
.59751 .53845 .59836 .54242 .59996 .54434 .59905 .53804 Mtetra
.603 .441 .635 r
.59905 .53804 .59996 .54434 .60151 .54431 .60059 .53753 Mtetra
.602 .437 .631 r
.60059 .53753 .60151 .54431 .60304 .54347 .60213 .53701 Mtetra
.607 .443 .634 r
.60213 .53701 .60304 .54347 .60456 .54226 .60366 .53639 Mtetra
.621 .457 .64 r
.60366 .53639 .60456 .54226 .60609 .54104 .6052 .53554 Mtetra
.603 .449 .645 r
.6052 .53554 .60609 .54104 .60763 .54064 .60674 .53511 Mtetra
.539 .404 .646 r
.60674 .53511 .60763 .54064 .60924 .54275 .60831 .53582 Mtetra
.094 .075 .542 r
.60831 .53582 .60924 .54275 .61561 .73095 .61003 .54229 Mtetra
.033 0 .434 r
.61003 .54229 .61561 .73095 .61739 .73618 .61651 .73322 Mtetra
0 .068 .603 r
.61651 .73322 .61739 .73618 .61909 .73806 .61825 .73658 Mtetra
.547 .591 .85 r
.61825 .73658 .61909 .73806 .62075 .73824 .6199 .73666 Mtetra
.663 .634 .81 r
.6199 .73666 .62075 .73824 .62239 .73784 .62154 .7361 Mtetra
.678 .624 .787 r
.62154 .7361 .62239 .73784 .62402 .73693 .62318 .73538 Mtetra
.585 .601 .834 r
.62318 .73538 .62402 .73693 .62563 .73541 .62483 .73529 Mtetra
.515 .896 .958 r
.62483 .73529 .62563 .73541 .62722 .733 .62648 .73478 Mtetra
.119 0 .104 r
.62648 .73478 .62722 .733 .62874 .72815 .62809 .73321 Mtetra
0 0 .201 r
.62809 .73321 .62874 .72815 .62475 .53816 .62956 .72666 Mtetra
.033 0 .428 r
.62956 .72666 .62475 .53816 .62614 .53235 .62545 .53415 Mtetra
.805 .815 .333 r
.62545 .53415 .62614 .53235 .62764 .52994 .62688 .52965 Mtetra
.776 .918 .933 r
.62688 .52965 .62764 .52994 .62919 .5293 .62842 .52867 Mtetra
.62 .79 .963 r
.62842 .52867 .62919 .5293 .63075 .5291 .62998 .52831 Mtetra
.555 .719 .95 r
.62998 .52831 .63075 .5291 .63232 .52903 .63155 .52819 Mtetra
.674 .749 .907 r
.63155 .52819 .63232 .52903 .63387 .52841 .6331 .52767 Mtetra
.668 .775 .929 r
.6331 .52767 .63387 .52841 .63542 .52789 .63466 .52717 Mtetra
.675 .783 .931 r
.63466 .52717 .63542 .52789 .63699 .52763 .63621 .52665 Mtetra
.732 .736 .855 r
.63621 .52665 .63699 .52763 .63858 .52801 .63776 .5258 Mtetra
.638 .559 .749 r
.63776 .5258 .63858 .52801 .64019 .52912 .63932 .52534 Mtetra
.548 .441 .685 r
.63932 .52534 .64019 .52912 .64188 .53222 .64091 .52574 Mtetra
.189 .149 .579 r
.64091 .52574 .64188 .53222 .65011 .72049 .64268 .53107 Mtetra
.051 0 .444 r
.64268 .53107 .65011 .72049 .65198 .72612 .6511 .72318 Mtetra
0 0 .532 r
.6511 .72318 .65198 .72612 .65373 .72805 .65292 .72721 Mtetra
.447 .675 .961 r
.65292 .72721 .65373 .72805 .65541 .72813 .6546 .72734 Mtetra
.678 .777 .926 r
.6546 .72734 .65541 .72813 .65707 .72762 .65626 .72678 Mtetra
.74 .78 .885 r
.65626 .72678 .65707 .72762 .65871 .7266 .65791 .72589 Mtetra
.518 .74 .976 r
.65791 .72589 .65871 .7266 .66034 .72522 .65959 .72579 Mtetra
.084 0 0 r
.65959 .72579 .66034 .72522 .66194 .72302 .66125 .7253 Mtetra
.302 0 .255 r
.66125 .7253 .66194 .72302 .66345 .71867 .66288 .72396 Mtetra
0 0 .255 r
.66288 .72396 .66345 .71867 .65759 .52836 .66431 .71754 Mtetra
.053 0 .44 r
.66431 .71754 .65759 .52836 .65895 .52247 .6583 .52435 Mtetra
.793 .794 .3 r
.6583 .52435 .65895 .52247 .66043 .51987 .6597 .51954 Mtetra
.787 .913 .925 r
.6597 .51954 .66043 .51987 .662 .51919 .66125 .51851 Mtetra
.634 .782 .952 r
.66125 .51851 .662 .51919 .66358 .51896 .66282 .51811 Mtetra
.542 .7 .943 r
.66282 .51811 .66358 .51896 .66517 .51897 .66441 .51804 Mtetra
.657 .727 .901 r
.66441 .51804 .66517 .51897 .66675 .51855 .66599 .51759 Mtetra
.656 .72 .896 r
.66599 .51759 .66675 .51855 .66833 .51808 .66757 .51715 Mtetra
.659 .729 .901 r
.66757 .51715 .66833 .51808 .6699 .51754 .66914 .5167 Mtetra
.677 .754 .909 r
.66914 .5167 .6699 .51754 .67146 .51673 .67072 .51617 Mtetra
.668 .827 .96 r
.67072 .51617 .67146 .51673 .67303 .51604 .6723 .51563 Mtetra
.638 .867 .985 r
.6723 .51563 .67303 .51604 .67461 .51561 .67387 .51512 Mtetra
.743 .866 .937 r
.67387 .51512 .67461 .51561 .67623 .5159 .67544 .5143 Mtetra
.655 .619 .801 r
.67544 .5143 .67623 .5159 .67788 .5169 .67702 .51379 Mtetra
.569 .475 .709 r
.67702 .51379 .67788 .5169 .6796 .51947 .67863 .51393 Mtetra
.268 .218 .615 r
.67863 .51393 .6796 .51947 .69002 .70799 .68042 .5179 Mtetra
.073 0 .457 r
.68042 .5179 .69002 .70799 .69207 .71531 .6911 .7107 Mtetra
0 .031 .552 r
.6911 .7107 .69207 .71531 .69388 .71755 .69305 .71605 Mtetra
.467 .549 .856 r
.69305 .71605 .69388 .71755 .69558 .71747 .69478 .71646 Mtetra
.654 .722 .899 r
.69478 .71646 .69558 .71747 .69726 .71678 .69647 .716 Mtetra
.736 .797 .901 r
.69647 .716 .69726 .71678 .69892 .7158 .69813 .71514 Mtetra
.634 .801 .963 r
.69813 .71514 .69892 .7158 .7006 .71528 .69982 .7147 Mtetra
.614 .817 .978 r
.69982 .7147 .7006 .71528 .70229 .71488 .70152 .71429 Mtetra
.618 .817 .977 r
.70152 .71429 .70229 .71488 .70399 .71454 .70321 .71386 Mtetra
.449 .721 .983 r
.70321 .71386 .70399 .71454 .70572 .71481 .70492 .71389 Mtetra
.602 .725 .931 r
.70492 .71389 .70572 .71481 .70743 .71476 .70663 .71362 Mtetra
.734 .726 .844 r
.70663 .71362 .70743 .71476 .70911 .71401 .70829 .71267 Mtetra
.905 .73 .654 r
.70829 .71267 .70911 .71401 .71059 .70961 .70977 .70796 Mtetra
.968 .688 .447 r
.70977 .70796 .71059 .70961 .70201 .51554 .70123 .51389 Mtetra
.913 .706 .608 r
.70123 .51389 .70201 .51554 .70324 .50808 .7025 .50723 Mtetra
.815 .787 .826 r
.7025 .50723 .70324 .50808 .70478 .50662 .70404 .50581 Mtetra
.657 .76 .925 r
.70404 .50581 .70478 .50662 .70638 .50617 .70564 .50535 Mtetra
.537 .709 .951 r
.70564 .50535 .70638 .50617 .708 .50613 .70726 .50527 Mtetra
.738 .772 .88 r
.70726 .50527 .708 .50613 .70958 .5053 .70884 .50443 Mtetra
.707 .76 .893 r
.70884 .50443 .70958 .5053 .71117 .50462 .71043 .50374 Mtetra
.539 .694 .94 r
.71043 .50374 .71117 .50462 .71279 .50457 .71205 .50369 Mtetra
.808 .363 0 r
.71205 .50369 .71279 .50457 .71462 .50799 .71388 .5071 Mtetra
.97 .683 .426 r
.71388 .5071 .71462 .50799 .72737 .70157 .72659 .70073 Mtetra
.92 .529 .152 r
.72659 .70073 .72737 .70157 .72945 .70757 .72867 .70673 Mtetra
0 .356 .82 r
.72867 .70673 .72945 .70757 .73124 .70863 .73046 .7078 Mtetra
.595 .743 .947 r
.73046 .7078 .73124 .70863 .73296 .70836 .73218 .70753 Mtetra
.795 .8 .856 r
.73218 .70753 .73296 .70836 .73462 .70708 .73384 .70625 Mtetra
.934 .778 .665 r
.73384 .70625 .73462 .70708 .7361 .70277 .73532 .70195 Mtetra
.971 .689 .436 r
.73532 .70195 .7361 .70277 .72612 .50883 .72539 .508 Mtetra
.959 .746 .573 r
.72539 .508 .72612 .50883 .72729 .50107 .72655 .50019 Mtetra
.834 .785 .805 r
.72655 .50019 .72729 .50107 .72883 .49942 .72809 .49854 Mtetra
.658 .744 .913 r
.72809 .49854 .72883 .49942 .73044 .49895 .7297 .49808 Mtetra
.529 .693 .943 r
.7297 .49808 .73044 .49895 .73208 .49891 .73134 .49804 Mtetra
.711 .764 .894 r
.73134 .49804 .73208 .49891 .73367 .49818 .73294 .49734 Mtetra
.704 .768 .902 r
.73294 .49734 .73367 .49818 .73527 .4975 .73455 .49667 Mtetra
.536 .708 .951 r
.73455 .49667 .73527 .4975 .73691 .49744 .73619 .4966 Mtetra
.764 .306 0 r
.73619 .4966 .73691 .49744 .73878 .50087 .73803 .49968 Mtetra
.972 .682 .414 r
.73803 .49968 .73878 .50087 .75305 .69546 .75219 .69323 Mtetra
.764 .423 0 r
.75219 .69323 .75305 .69546 .75517 .70116 .75436 .69967 Mtetra
.313 .464 .851 r
.75436 .69967 .75517 .70116 .75698 .70198 .75617 .70059 Mtetra
.64 .654 .848 r
.75617 .70059 .75698 .70198 .7587 .70145 .7579 .70019 Mtetra
.717 .705 .837 r
.7579 .70019 .7587 .70145 .76037 .70024 .7596 .69931 Mtetra
.704 .76 .895 r
.7596 .69931 .76037 .70024 .76201 .6985 .76131 .69859 Mtetra
.389 .849 .821 r
.76131 .69859 .76201 .6985 .7636 .69615 .76302 .69797 Mtetra
.404 .048 .243 r
.76302 .69797 .7636 .69615 .76515 .69304 .76474 .69734 Mtetra
.542 .263 .44 r
.76474 .69734 .76515 .69304 .76682 .69183 .76649 .69719 Mtetra
.546 .28 .464 r
.76649 .69719 .76682 .69183 .76858 .69184 .76823 .69697 Mtetra
.508 .246 .453 r
.76823 .69697 .76858 .69184 .77028 .69102 .76994 .69613 Mtetra
.255 .046 .392 r
.76994 .69613 .77028 .69102 .75941 .51136 .77143 .69226 Mtetra
.072 0 .459 r
.77143 .69226 .75941 .51136 .75983 .49369 .75948 .4982 Mtetra
0 0 .13 r
.75948 .4982 .75983 .49369 .76123 .49003 .76057 .49008 Mtetra
.905 .98 .789 r
.76057 .49008 .76123 .49003 .76279 .48861 .7621 .48812 Mtetra
.665 .858 .973 r
.7621 .48812 .76279 .48861 .76442 .48808 .76372 .48754 Mtetra
.496 .781 .996 r
.76372 .48754 .76442 .48808 .76606 .48783 .76538 .4874 Mtetra
.54 .832 .999 r
.76538 .4874 .76606 .48783 .7677 .48747 .76702 .48709 Mtetra
.596 .87 .993 r
.76702 .48709 .7677 .48747 .76934 .48701 .76866 .48663 Mtetra
.593 .87 .994 r
.76866 .48663 .76934 .48701 .77097 .48655 .7703 .48617 Mtetra
.596 .873 .993 r
.7703 .48617 .77097 .48655 .77261 .48608 .77193 .48571 Mtetra
.599 .875 .993 r
.77193 .48571 .77261 .48608 .77425 .4856 .77357 .48523 Mtetra
.6 .876 .992 r
.77357 .48523 .77425 .4856 .77588 .48512 .77521 .48475 Mtetra
.601 .876 .992 r
.77521 .48475 .77588 .48512 .77752 .48463 .77685 .48427 Mtetra
.602 .877 .992 r
.77685 .48427 .77752 .48463 .77916 .48415 .77848 .48378 Mtetra
.602 .878 .992 r
.77848 .48378 .77916 .48415 .7808 .48366 .78012 .48329 Mtetra
.603 .878 .992 r
.78012 .48329 .7808 .48366 .78244 .48317 .78177 .4828 Mtetra
.78177 .4828 .78244 .48317 .78408 .48268 .78341 .48231 Mtetra
.604 .878 .992 r
.78341 .48231 .78408 .48268 .78572 .48218 .78505 .48182 Mtetra
.78505 .48182 .78572 .48218 .78736 .48169 .78669 .48132 Mtetra
.78669 .48132 .78736 .48169 .789 .4812 .78834 .48083 Mtetra
.605 .878 .992 r
.78834 .48083 .789 .4812 .79065 .4807 .78998 .48033 Mtetra
.78998 .48033 .79065 .4807 .79229 .4802 .79163 .47983 Mtetra
.79163 .47983 .79229 .4802 .79394 .47971 .79328 .47934 Mtetra
.79328 .47934 .79394 .47971 .79559 .47921 .79492 .47884 Mtetra
.606 .878 .992 r
.79492 .47884 .79559 .47921 .79724 .47871 .79657 .47834 Mtetra
.79657 .47834 .79724 .47871 .79888 .47822 .79822 .47784 Mtetra
.79822 .47784 .79888 .47822 .80053 .47772 .79987 .47734 Mtetra
.79987 .47734 .80053 .47772 .80218 .47722 .80152 .47684 Mtetra
.80152 .47684 .80218 .47722 .80384 .47672 .80318 .47634 Mtetra
.80318 .47634 .80384 .47672 .80549 .47622 .80483 .47584 Mtetra
.80483 .47584 .80549 .47622 .80714 .47572 .80649 .47535 Mtetra
.80649 .47535 .80714 .47572 .8088 .47523 .80814 .47485 Mtetra
.80814 .47485 .8088 .47523 .81045 .47473 .8098 .47435 Mtetra
.8098 .47435 .81045 .47473 .81211 .47423 .81145 .47385 Mtetra
.81145 .47385 .81211 .47423 .81377 .47373 .81311 .47335 Mtetra
.606 .877 .992 r
.81311 .47335 .81377 .47373 .81542 .47323 .81477 .47284 Mtetra
.81477 .47284 .81542 .47323 .81708 .47273 .81643 .47234 Mtetra
.81643 .47234 .81708 .47273 .81874 .47223 .81809 .47184 Mtetra
.81809 .47184 .81874 .47223 .82041 .47173 .81976 .47134 Mtetra
.81976 .47134 .82041 .47173 .82207 .47123 .82142 .47084 Mtetra
.82142 .47084 .82207 .47123 .82373 .47073 .82308 .47034 Mtetra
.82308 .47034 .82373 .47073 .8254 .47023 .82475 .46984 Mtetra
.82475 .46984 .8254 .47023 .82706 .46972 .82641 .46934 Mtetra
.605 .877 .992 r
.82641 .46934 .82706 .46972 .82873 .46922 .82808 .46884 Mtetra
.82808 .46884 .82873 .46922 .83039 .46872 .82975 .46834 Mtetra
.605 .878 .992 r
.82975 .46834 .83039 .46872 .83206 .46822 .83142 .46783 Mtetra
.83142 .46783 .83206 .46822 .83373 .46772 .83309 .46733 Mtetra
.83309 .46733 .83373 .46772 .8354 .46722 .83476 .46683 Mtetra
.83476 .46683 .8354 .46722 .83707 .46671 .83643 .46633 Mtetra
.83643 .46633 .83707 .46671 .83874 .46621 .8381 .46582 Mtetra
.8381 .46582 .83874 .46621 .84042 .46571 .83978 .46532 Mtetra
.83978 .46532 .84042 .46571 .84209 .4652 .84145 .46482 Mtetra
.84145 .46482 .84209 .4652 .84376 .4647 .84313 .46431 Mtetra
.84313 .46431 .84376 .4647 .84544 .46419 .84481 .46381 Mtetra
.84481 .46381 .84544 .46419 .84712 .46369 .84648 .4633 Mtetra
.84648 .4633 .84712 .46369 .84879 .46318 .84816 .46279 Mtetra
.84816 .46279 .84879 .46318 .85047 .46268 .84984 .46229 Mtetra
.84984 .46229 .85047 .46268 .85215 .46217 .85152 .46178 Mtetra
.606 .878 .992 r
.85152 .46178 .85215 .46217 .85383 .46166 .8532 .46127 Mtetra
.606 .879 .991 r
.8532 .46127 .85383 .46166 .85551 .46115 .85488 .46076 Mtetra
.607 .879 .991 r
.85488 .46076 .85551 .46115 .8572 .46064 .85657 .46025 Mtetra
.85657 .46025 .8572 .46064 .85888 .46013 .85825 .45974 Mtetra
.608 .879 .991 r
.85825 .45974 .85888 .46013 .86056 .45962 .85994 .45923 Mtetra
.609 .878 .991 r
.85994 .45923 .86056 .45962 .86225 .45911 .86162 .45871 Mtetra
.61 .878 .991 r
.86162 .45871 .86225 .45911 .86393 .45859 .86331 .4582 Mtetra
.611 .878 .991 r
.86331 .4582 .86393 .45859 .86562 .45808 .865 .45768 Mtetra
.612 .878 .991 r
.865 .45768 .86562 .45808 .86731 .45756 .86668 .45716 Mtetra
.613 .878 .991 r
.86668 .45716 .86731 .45756 .86899 .45705 .86837 .45664 Mtetra
.615 .877 .99 r
.86837 .45664 .86899 .45705 .87068 .45653 .87006 .45611 Mtetra
.616 .876 .99 r
.87006 .45611 .87068 .45653 .87237 .45601 .87175 .45559 Mtetra
.617 .876 .99 r
.87175 .45559 .87237 .45601 .87407 .45549 .87344 .45507 Mtetra
.619 .875 .99 r
.87344 .45507 .87407 .45549 .87576 .45497 .87514 .45454 Mtetra
.619 .874 .99 r
.87514 .45454 .87576 .45497 .87745 .45445 .87683 .45402 Mtetra
.62 .873 .989 r
.87683 .45402 .87745 .45445 .87914 .45393 .87853 .45349 Mtetra
.62 .872 .989 r
.87853 .45349 .87914 .45393 .88084 .45341 .88022 .45297 Mtetra
.62 .871 .989 r
.88022 .45297 .88084 .45341 .88254 .45289 .88192 .45245 Mtetra
.62 .87 .989 r
.88192 .45245 .88254 .45289 .88423 .45238 .88362 .45193 Mtetra
.62 .869 .989 r
.88362 .45193 .88423 .45238 .88593 .45186 .88532 .45141 Mtetra
.88532 .45141 .88593 .45186 .88763 .45135 .88702 .4509 Mtetra
.619 .868 .989 r
.88702 .4509 .88763 .45135 .88933 .45083 .88872 .45038 Mtetra
.88872 .45038 .88933 .45083 .89103 .45032 .89042 .44987 Mtetra
.618 .868 .99 r
.89042 .44987 .89103 .45032 .89274 .4498 .89212 .44936 Mtetra
.617 .868 .99 r
.89212 .44936 .89274 .4498 .89444 .44929 .89383 .44884 Mtetra
.89383 .44884 .89444 .44929 .89615 .44878 .89554 .44833 Mtetra
.616 .868 .99 r
.89554 .44833 .89615 .44878 .89785 .44827 .89724 .44782 Mtetra
.614 .868 .99 r
.89724 .44782 .89785 .44827 .89956 .44776 .89895 .44732 Mtetra
.613 .868 .991 r
.89895 .44732 .89956 .44776 .90127 .44725 .90066 .44681 Mtetra
.612 .869 .991 r
.90066 .44681 .90127 .44725 .90298 .44674 .90237 .4463 Mtetra
.611 .869 .991 r
.90237 .4463 .90298 .44674 .90469 .44623 .90409 .4458 Mtetra
.61 .87 .991 r
.90409 .4458 .90469 .44623 .9064 .44573 .9058 .44529 Mtetra
.609 .871 .991 r
.9058 .44529 .9064 .44573 .90811 .44522 .90751 .44479 Mtetra
.90751 .44479 .90811 .44522 .90983 .44471 .90923 .44428 Mtetra
.609 .872 .991 r
.90923 .44428 .90983 .44471 .91154 .4442 .91094 .44377 Mtetra
.91094 .44377 .91154 .4442 .91326 .44369 .91266 .44326 Mtetra
.61 .872 .991 r
.91266 .44326 .91326 .44369 .91497 .44319 .91438 .44275 Mtetra
.611 .872 .991 r
.91438 .44275 .91497 .44319 .91669 .44268 .9161 .44224 Mtetra
.612 .871 .991 r
.9161 .44224 .91669 .44268 .91841 .44217 .91782 .44172 Mtetra
.614 .87 .99 r
.91782 .44172 .91841 .44217 .92013 .44167 .91954 .44121 Mtetra
.617 .867 .99 r
.91954 .44121 .92013 .44167 .92185 .44116 .92126 .44069 Mtetra
.62 .864 .989 r
.92126 .44069 .92185 .44116 .92358 .44066 .92298 .44018 Mtetra
.623 .862 .988 r
.92298 .44018 .92358 .44066 .9253 .44015 .9247 .43966 Mtetra
.624 .86 .987 r
.9247 .43966 .9253 .44015 .92702 .43965 .92643 .43915 Mtetra
.624 .858 .987 r
.92643 .43915 .92702 .43965 .92875 .43914 .92815 .43864 Mtetra
.624 .856 .987 r
.92815 .43864 .92875 .43914 .93048 .43863 .92988 .43813 Mtetra
.623 .855 .987 r
.92988 .43813 .93048 .43863 .9322 .43813 .93161 .43762 Mtetra
.621 .853 .987 r
.93161 .43762 .9322 .43813 .93393 .43763 .93334 .43712 Mtetra
.617 .852 .988 r
.93334 .43712 .93393 .43763 .93567 .43714 .93507 .43664 Mtetra
.612 .851 .989 r
.93507 .43664 .93567 .43714 .9374 .43666 .93681 .43616 Mtetra
.604 .851 .991 r
.93681 .43616 .9374 .43666 .93914 .43618 .93855 .4357 Mtetra
.586 .848 .994 r
.93855 .4357 .93914 .43618 .94087 .43571 .94029 .43527 Mtetra
.57 .856 .997 r
.94029 .43527 .94087 .43571 .94262 .43527 .94204 .43485 Mtetra
.566 .862 .996 r
.94204 .43485 .94262 .43527 .94436 .43486 .94378 .43442 Mtetra
.596 .866 .993 r
.94378 .43442 .94436 .43486 .94613 .43457 .94553 .43394 Mtetra
.639 .823 .971 r
.94553 .43394 .94613 .43457 .9479 .4343 .94727 .43345 Mtetra
.655 .765 .93 r
.94727 .43345 .9479 .4343 .94966 .434 .94901 .43295 Mtetra
.65 .717 .897 r
.94901 .43295 .94966 .434 .95141 .43356 .95075 .43249 Mtetra
.654 .714 .892 r
.95075 .43249 .95141 .43356 .95315 .43305 .9525 .43201 Mtetra
.662 .725 .896 r
.9525 .43201 .95315 .43305 .95488 .43248 .95424 .43149 Mtetra
.683 .746 .899 r
.95424 .43149 .95488 .43248 .95661 .43184 .95597 .43087 Mtetra
.69 .753 .9 r
.95597 .43087 .95661 .43184 .95833 .43118 .95769 .43022 Mtetra
.696 .758 .9 r
.95769 .43022 .95833 .43118 .96005 .43049 .95942 .42954 Mtetra
.776 .788 .863 r
.95942 .42954 .96005 .43049 .96171 .42934 .96108 .4284 Mtetra
.71 .767 .897 r
.96108 .4284 .96171 .42934 .96343 .42858 .96279 .42765 Mtetra
.538 .69 .937 r
.96279 .42765 .96343 .42858 .96524 .42852 .9646 .42759 Mtetra
.93 .558 .277 r
.39654 .59776 .39739 .59855 .39866 .6026 .3978 .60187 Mtetra
.937 .682 .526 r
.3978 .60187 .39866 .6026 .39323 .79025 .39232 .78963 Mtetra
.929 .577 .34 r
.39232 .78963 .39323 .79025 .39455 .79533 .39364 .79465 Mtetra
.226 .599 .95 r
.39364 .79465 .39455 .79533 .39604 .79556 .39512 .79501 Mtetra
.672 .818 .953 r
.39512 .79501 .39604 .79556 .39756 .795 .39664 .79449 Mtetra
.799 .831 .876 r
.39664 .79449 .39756 .795 .39909 .79403 .39818 .79334 Mtetra
.835 .784 .803 r
.39818 .79334 .39909 .79403 .40061 .79351 .39974 .79165 Mtetra
.787 .651 .712 r
.39974 .79165 .40061 .79351 .40213 .79302 .40132 .78933 Mtetra
.743 .571 .661 r
.40132 .78933 .40213 .79302 .40365 .79256 .40293 .78636 Mtetra
.655 .481 .637 r
.40293 .78636 .40365 .79256 .40516 .7922 .40449 .78462 Mtetra
.59 .424 .625 r
.40449 .78462 .40516 .7922 .40668 .79188 .406 .78436 Mtetra
.528 .379 .622 r
.406 .78436 .40668 .79188 .4082 .79158 .40747 .78545 Mtetra
.424 .315 .626 r
.40747 .78545 .4082 .79158 .40971 .79132 .4089 .78772 Mtetra
.378 .334 .682 r
.4089 .78772 .40971 .79132 .41123 .79104 .41036 .78934 Mtetra
.278 .405 .812 r
.41036 .78934 .41123 .79104 .41275 .79072 .41184 .79033 Mtetra
.295 .719 .971 r
.41184 .79033 .41275 .79072 .41427 .79025 .41335 .79039 Mtetra
.134 .679 .72 r
.41335 .79039 .41427 .79025 .4158 .78974 .41487 .79014 Mtetra
0 0 0 r
.41487 .79014 .4158 .78974 .41733 .78923 .41639 .78972 Mtetra
.41639 .78972 .41733 .78923 .41885 .78884 .41792 .78925 Mtetra
.41792 .78925 .41885 .78884 .42038 .78849 .41945 .78874 Mtetra
.295 .786 .74 r
.41945 .78874 .42038 .78849 .4219 .78814 .42098 .78822 Mtetra
.082 .642 .722 r
.42098 .78822 .4219 .78814 .42342 .78819 .4225 .78807 Mtetra
.406 .839 .95 r
.4225 .78807 .42342 .78819 .42494 .78796 .42403 .78778 Mtetra
.7 .926 .966 r
.42403 .78778 .42494 .78796 .42649 .78704 .42557 .78703 Mtetra
.936 .861 .741 r
.42557 .78703 .42649 .78704 .42813 .78237 .42717 .78415 Mtetra
.998 .85 .551 r
.42717 .78415 .42813 .78237 .43464 .59341 .42889 .77682 Mtetra
0 0 .349 r
.42889 .77682 .43464 .59341 .43624 .58732 .43528 .59129 Mtetra
.341 .082 .368 r
.43528 .59129 .43624 .58732 .43772 .58595 .43677 .58938 Mtetra
.524 .236 .418 r
.43677 .58938 .43772 .58595 .43917 .58554 .43822 .58912 Mtetra
.546 .259 .431 r
.43822 .58912 .43917 .58554 .44061 .58549 .43966 .58906 Mtetra
.258 0 .318 r
.43966 .58906 .44061 .58549 .44206 .58513 .44116 .58689 Mtetra
0 0 0 r
.44116 .58689 .44206 .58513 .44351 .58468 .44265 .58478 Mtetra
.884 .959 .844 r
.44265 .58478 .44351 .58468 .44497 .58423 .44414 .58318 Mtetra
.721 .707 .837 r
.44414 .58318 .44497 .58423 .44642 .5838 .4456 .5824 Mtetra
.654 .633 .817 r
.4456 .5824 .44642 .5838 .44788 .58337 .44705 .58197 Mtetra
.627 .621 .826 r
.44705 .58197 .44788 .58337 .44934 .58294 .44851 .58169 Mtetra
.628 .644 .847 r
.44851 .58169 .44934 .58294 .45079 .58248 .44996 .5814 Mtetra
.63 .675 .874 r
.44996 .5814 .45079 .58248 .45225 .58202 .45142 .58111 Mtetra
.637 .71 .9 r
.45142 .58111 .45225 .58202 .45371 .58158 .45287 .58078 Mtetra
.681 .749 .902 r
.45287 .58078 .45371 .58158 .45517 .5812 .45434 .58026 Mtetra
.695 .723 .871 r
.45434 .58026 .45517 .5812 .45663 .58085 .4558 .57967 Mtetra
.687 .677 .835 r
.4558 .57967 .45663 .58085 .45809 .5805 .45726 .57907 Mtetra
.697 .647 .796 r
.45726 .57907 .45809 .5805 .45956 .57974 .45873 .57833 Mtetra
.677 .642 .807 r
.45873 .57833 .45956 .57974 .46102 .57909 .4602 .57774 Mtetra
.606 .619 .838 r
.4602 .57774 .46102 .57909 .46248 .57902 .46166 .57756 Mtetra
0 .184 .716 r
.46166 .57756 .46248 .57902 .46388 .58189 .46309 .57909 Mtetra
.762 .464 0 r
.46309 .57909 .46388 .58189 .46206 .76984 .46445 .58438 Mtetra
0 0 .377 r
.46445 .58438 .46206 .76984 .46348 .77656 .46269 .77033 Mtetra
.46 .342 .631 r
.46269 .77033 .46348 .77656 .46501 .77755 .4642 .77224 Mtetra
.608 .457 .651 r
.4642 .77224 .46501 .77755 .46656 .77721 .46576 .77176 Mtetra
.621 .465 .648 r
.46576 .77176 .46656 .77721 .46812 .77644 .46731 .77099 Mtetra
.505 .383 .647 r
.46731 .77099 .46812 .77644 .46968 .77594 .46884 .77212 Mtetra
.429 .363 .682 r
.46884 .77212 .46968 .77594 .47123 .77558 .47037 .77354 Mtetra
.381 .43 .786 r
.47037 .77354 .47123 .77558 .47279 .77518 .47191 .77445 Mtetra
.311 .632 .963 r
.47191 .77445 .47279 .77518 .47434 .77501 .47346 .77475 Mtetra
.433 .825 .985 r
.47346 .77475 .47434 .77501 .4759 .77469 .47501 .77452 Mtetra
.7 .934 .964 r
.47501 .77452 .4759 .77469 .47746 .77378 .47658 .77375 Mtetra
.928 .892 .775 r
.47658 .77375 .47746 .77378 .47907 .77009 .47816 .77134 Mtetra
.995 .868 .576 r
.47816 .77134 .47907 .77009 .48294 .58168 .47979 .76553 Mtetra
0 0 .37 r
.47979 .76553 .48294 .58168 .48452 .57333 .48362 .57813 Mtetra
.219 0 .35 r
.48362 .57813 .48452 .57333 .48601 .5714 .48513 .57483 Mtetra
.505 .217 .411 r
.48513 .57483 .48601 .5714 .48749 .57086 .48661 .57437 Mtetra
.539 .251 .426 r
.48661 .57437 .48749 .57086 .48896 .57072 .48809 .57425 Mtetra
.331 .064 .351 r
.48809 .57425 .48896 .57072 .49044 .57037 .48959 .57245 Mtetra
0 0 .041 r
.48959 .57245 .49044 .57037 .49192 .56985 .49108 .57025 Mtetra
.853 .998 .785 r
.49108 .57025 .49192 .56985 .4934 .56936 .49258 .56855 Mtetra
.783 .766 .838 r
.49258 .56855 .4934 .56936 .49488 .5687 .49406 .56741 Mtetra
.691 .665 .819 r
.49406 .56741 .49488 .5687 .49637 .56813 .49555 .56675 Mtetra
.604 .616 .836 r
.49555 .56675 .49637 .56813 .49784 .56808 .49703 .56658 Mtetra
.14 .338 .8 r
.49703 .56658 .49784 .56808 .49931 .57029 .4985 .56777 Mtetra
0 0 .319 r
.4985 .56777 .49931 .57029 .49947 .75617 .49995 .57181 Mtetra
0 0 .389 r
.49995 .57181 .49947 .75617 .50097 .76597 .50015 .75843 Mtetra
.385 .276 .606 r
.50015 .75843 .50097 .76597 .50253 .76745 .50169 .76188 Mtetra
.599 .448 .648 r
.50169 .76188 .50253 .76745 .5041 .7672 .50327 .76154 Mtetra
.62 .461 .646 r
.50327 .76154 .5041 .7672 .50568 .76646 .50484 .76077 Mtetra
.527 .396 .646 r
.50484 .76077 .50568 .76646 .50726 .76588 .50641 .76165 Mtetra
.434 .356 .67 r
.50641 .76165 .50726 .76588 .50883 .76551 .50798 .76321 Mtetra
.384 .409 .763 r
.50798 .76321 .50883 .76551 .51041 .76512 .50955 .76425 Mtetra
.372 .625 .951 r
.50955 .76425 .51041 .76512 .51199 .76465 .51112 .76455 Mtetra
.292 .78 .903 r
.51112 .76455 .51199 .76465 .51357 .76411 .5127 .76434 Mtetra
0 0 0 r
.5127 .76434 .51357 .76411 .51515 .76357 .51429 .76397 Mtetra
.51429 .76397 .51515 .76357 .51673 .76311 .51587 .76358 Mtetra
.06 0 0 r
.51587 .76358 .51673 .76311 .51832 .76272 .51745 .76319 Mtetra
.026 0 0 r
.51745 .76319 .51832 .76272 .5199 .76234 .51904 .76276 Mtetra
.071 0 0 r
.51904 .76276 .5199 .76234 .52148 .76222 .52062 .76244 Mtetra
0 0 0 r
.52062 .76244 .52148 .76222 .52307 .7621 .52221 .7621 Mtetra
.597 .94 .938 r
.52221 .7621 .52307 .7621 .52466 .76144 .5238 .76139 Mtetra
.909 .922 .814 r
.5238 .76139 .52466 .76144 .52624 .75865 .52538 .75939 Mtetra
.99 .873 .615 r
.52538 .75939 .52624 .75865 .52781 .73192 .52697 .75449 Mtetra
.982 .723 .46 r
.52697 .75449 .52781 .73192 .52917 .56066 .52836 .56698 Mtetra
.096 0 .339 r
.52836 .56698 .52917 .56066 .53066 .55809 .52986 .56146 Mtetra
.462 .177 .394 r
.52986 .56146 .53066 .55809 .53217 .55743 .53136 .56064 Mtetra
.551 .254 .417 r
.53136 .56064 .53217 .55743 .53367 .55724 .53287 .56068 Mtetra
.551 .26 .426 r
.53287 .56068 .53367 .55724 .53517 .55703 .53438 .56069 Mtetra
.513 .231 .422 r
.53438 .56069 .53517 .55703 .53668 .55659 .53588 .56027 Mtetra
.515 .232 .423 r
.53588 .56027 .53668 .55659 .53818 .55615 .53739 .55986 Mtetra
.514 .232 .424 r
.53739 .55986 .53818 .55615 .53969 .55571 .5389 .55943 Mtetra
.512 .231 .424 r
.5389 .55943 .53969 .55571 .54119 .55526 .54041 .55898 Mtetra
.511 .23 .424 r
.54041 .55898 .54119 .55526 .5427 .5548 .54192 .55853 Mtetra
.54192 .55853 .5427 .5548 .54421 .55434 .54343 .55806 Mtetra
.511 .229 .423 r
.54343 .55806 .54421 .55434 .54572 .55388 .54494 .5576 Mtetra
.51 .229 .423 r
.54494 .5576 .54572 .55388 .54723 .55343 .54645 .55713 Mtetra
.54645 .55713 .54723 .55343 .54874 .55297 .54796 .55667 Mtetra
.51 .228 .423 r
.54796 .55667 .54874 .55297 .55025 .55251 .54948 .5562 Mtetra
.51 .228 .422 r
.54948 .5562 .55025 .55251 .55176 .55205 .55099 .55574 Mtetra
.511 .229 .422 r
.55099 .55574 .55176 .55205 .55327 .5516 .55251 .55528 Mtetra
.512 .229 .422 r
.55251 .55528 .55327 .5516 .55479 .55115 .55402 .55484 Mtetra
.512 .23 .423 r
.55402 .55484 .55479 .55115 .5563 .5507 .55554 .55439 Mtetra
.53 .246 .428 r
.55554 .55439 .5563 .5507 .55782 .55027 .55706 .55415 Mtetra
.548 .266 .439 r
.55706 .55415 .55782 .55027 .55933 .54985 .55858 .55409 Mtetra
.513 .241 .44 r
.55858 .55409 .55933 .54985 .56085 .54943 .5601 .55355 Mtetra
.385 .128 .397 r
.5601 .55355 .56085 .54943 .56237 .54898 .56161 .55177 Mtetra
.099 0 .218 r
.56161 .55177 .56237 .54898 .56389 .5485 .56311 .54931 Mtetra
.69 .91 .566 r
.56311 .54931 .56389 .5485 .5654 .54802 .56461 .54739 Mtetra
.807 .816 .858 r
.56461 .54739 .5654 .54802 .56693 .54756 .56612 .54617 Mtetra
.67 .647 .818 r
.56612 .54617 .56693 .54756 .56845 .54712 .56764 .54563 Mtetra
.638 .619 .815 r
.56764 .54563 .56845 .54712 .56997 .54669 .56917 .54526 Mtetra
.637 .627 .824 r
.56917 .54526 .56997 .54669 .57149 .54624 .57069 .54491 Mtetra
.657 .65 .831 r
.57069 .54491 .57149 .54624 .57302 .54577 .57221 .54445 Mtetra
.658 .652 .832 r
.57221 .54445 .57302 .54577 .57454 .54529 .57374 .54399 Mtetra
.659 .654 .834 r
.57374 .54399 .57454 .54529 .57606 .54481 .57526 .54352 Mtetra
.659 .656 .836 r
.57526 .54352 .57606 .54481 .57759 .54434 .57679 .54306 Mtetra
.659 .658 .837 r
.57679 .54306 .57759 .54434 .57912 .54387 .57832 .54259 Mtetra
.659 .658 .838 r
.57832 .54259 .57912 .54387 .58065 .5434 .57985 .54213 Mtetra
.659 .659 .839 r
.57985 .54213 .58065 .5434 .58217 .54293 .58138 .54166 Mtetra
.659 .66 .84 r
.58138 .54166 .58217 .54293 .5837 .54246 .58291 .5412 Mtetra
.659 .661 .84 r
.58291 .5412 .5837 .54246 .58523 .542 .58444 .54073 Mtetra
.66 .661 .84 r
.58444 .54073 .58523 .542 .58676 .54153 .58597 .54027 Mtetra
.657 .66 .841 r
.58597 .54027 .58676 .54153 .5883 .54107 .5875 .53981 Mtetra
.649 .659 .846 r
.5875 .53981 .5883 .54107 .58983 .54059 .58904 .53941 Mtetra
.634 .664 .862 r
.58904 .53941 .58983 .54059 .59136 .5401 .59057 .53908 Mtetra
.636 .695 .888 r
.59057 .53908 .59136 .5401 .5929 .53962 .59211 .53873 Mtetra
.657 .732 .905 r
.59211 .53873 .5929 .53962 .59443 .53918 .59365 .5383 Mtetra
.694 .744 .89 r
.59365 .5383 .59443 .53918 .59597 .53881 .59518 .53769 Mtetra
.693 .697 .85 r
.59518 .53769 .59597 .53881 .59751 .53845 .59671 .53706 Mtetra
.678 .652 .817 r
.59671 .53706 .59751 .53845 .59905 .53804 .59825 .53645 Mtetra
.66 .62 .799 r
.59825 .53645 .59905 .53804 .60059 .53753 .59979 .53593 Mtetra
.656 .616 .798 r
.59979 .53593 .60059 .53753 .60213 .53701 .60133 .53543 Mtetra
.665 .623 .798 r
.60133 .53543 .60213 .53701 .60366 .53639 .60286 .53488 Mtetra
.691 .642 .796 r
.60286 .53488 .60366 .53639 .6052 .53554 .6044 .53414 Mtetra
.654 .639 .823 r
.6044 .53414 .6052 .53554 .60674 .53511 .60594 .53369 Mtetra
.491 .557 .851 r
.60594 .53369 .60674 .53511 .60831 .53582 .6075 .53398 Mtetra
0 0 .557 r
.6075 .53398 .60831 .53582 .61003 .54229 .60913 .53666 Mtetra
.969 .692 .454 r
.60913 .53666 .61003 .54229 .61651 .73322 .61515 .71159 Mtetra
.127 .052 .494 r
.61515 .71159 .61651 .73322 .61825 .73658 .6173 .73083 Mtetra
.574 .43 .647 r
.6173 .73083 .61825 .73658 .6199 .73666 .61895 .73095 Mtetra
.614 .458 .647 r
.61895 .73095 .6199 .73666 .62154 .7361 .62059 .73028 Mtetra
.58 .433 .646 r
.62059 .73028 .62154 .7361 .62318 .73538 .62224 .73028 Mtetra
.414 .329 .651 r
.62224 .73028 .62318 .73538 .62483 .73529 .62396 .73247 Mtetra
.431 .408 .732 r
.62396 .73247 .62483 .73529 .62648 .73478 .62564 .73357 Mtetra
.59 .653 .881 r
.62564 .73357 .62648 .73478 .62809 .73321 .6273 .73342 Mtetra
.963 .924 .713 r
.6273 .73342 .62809 .73321 .62956 .72666 .62887 .73042 Mtetra
.723 .687 .145 r
.62887 .73042 .62956 .72666 .62545 .53415 .63029 .72232 Mtetra
.047 0 .434 r
.63029 .72232 .62545 .53415 .62688 .52965 .62624 .5333 Mtetra
.151 0 .301 r
.62624 .5333 .62688 .52965 .62842 .52867 .62772 .53018 Mtetra
0 0 0 r
.62772 .53018 .62842 .52867 .62998 .52831 .62924 .52845 Mtetra
.709 .986 .863 r
.62924 .52845 .62998 .52831 .63155 .52819 .63077 .52735 Mtetra
.701 .76 .898 r
.63077 .52735 .63155 .52819 .6331 .52767 .63233 .52671 Mtetra
.659 .72 .894 r
.63233 .52671 .6331 .52767 .63466 .52717 .63388 .52627 Mtetra
.665 .733 .9 r
.63388 .52627 .63466 .52717 .63621 .52665 .63544 .52579 Mtetra
.777 .772 .848 r
.63544 .52579 .63621 .52665 .63776 .5258 .63698 .52468 Mtetra
.702 .702 .847 r
.63698 .52468 .63776 .5258 .63932 .52534 .63853 .52398 Mtetra
.512 .58 .86 r
.63853 .52398 .63932 .52534 .64091 .52574 .64012 .52418 Mtetra
.857 .477 0 r
.64012 .52418 .64091 .52574 .64268 .53107 .64187 .52915 Mtetra
.966 .686 .452 r
.64187 .52915 .64268 .53107 .6511 .72318 .6503 .7226 Mtetra
.901 .485 .145 r
.6503 .7226 .6511 .72318 .65292 .72721 .65213 .72686 Mtetra
.313 .745 .97 r
.65213 .72686 .65292 .72721 .6546 .72734 .6538 .72685 Mtetra
.708 .864 .956 r
.6538 .72685 .6546 .72734 .65626 .72678 .65546 .72612 Mtetra
.769 .829 .899 r
.65546 .72612 .65626 .72678 .65791 .72589 .6571 .72511 Mtetra
.482 .706 .968 r
.6571 .72511 .65791 .72589 .65959 .72579 .65878 .72513 Mtetra
.566 .775 .977 r
.65878 .72513 .65959 .72579 .66125 .7253 .66046 .72489 Mtetra
.728 .891 .954 r
.66046 .72489 .66125 .7253 .66288 .72396 .66211 .72406 Mtetra
.968 .903 .7 r
.66211 .72406 .66288 .72396 .66431 .71754 .66367 .72081 Mtetra
.862 .762 .253 r
.66367 .72081 .66431 .71754 .6583 .52435 .665 .71174 Mtetra
.063 0 .444 r
.665 .71174 .6583 .52435 .6597 .51954 .6591 .52291 Mtetra
.106 0 .274 r
.6591 .52291 .6597 .51954 .66125 .51851 .66057 .51973 Mtetra
0 0 0 r
.66057 .51973 .66125 .51851 .66282 .51811 .66209 .51792 Mtetra
.812 .951 .91 r
.66209 .51792 .66282 .51811 .66441 .51804 .66363 .51674 Mtetra
.687 .671 .829 r
.66363 .51674 .66441 .51804 .66599 .51759 .6652 .51609 Mtetra
.645 .626 .816 r
.6652 .51609 .66599 .51759 .66757 .51715 .66678 .51568 Mtetra
.623 .619 .826 r
.66678 .51568 .66757 .51715 .66914 .5167 .66837 .51539 Mtetra
.637 .649 .845 r
.66837 .51539 .66914 .5167 .67072 .51617 .66995 .51503 Mtetra
.64 .68 .872 r
.66995 .51503 .67072 .51617 .6723 .51563 .67153 .51467 Mtetra
.649 .717 .898 r
.67153 .51467 .6723 .51563 .67387 .51512 .67312 .51426 Mtetra
.75 .77 .869 r
.67312 .51426 .67387 .51512 .67544 .5143 .67468 .51334 Mtetra
.711 .74 .874 r
.67468 .51334 .67544 .5143 .67702 .51379 .67625 .51262 Mtetra
.616 .663 .873 r
.67625 .51262 .67702 .51379 .67863 .51393 .67784 .51237 Mtetra
0 .229 .741 r
.67784 .51237 .67863 .51393 .68042 .5179 .67953 .51412 Mtetra
0 0 .451 r
.67953 .51412 .68042 .5179 .6911 .7107 .6814 .51982 Mtetra
.085 .006 .461 r
.6814 .51982 .6911 .7107 .69305 .71605 .69201 .71003 Mtetra
.379 .293 .632 r
.69201 .71003 .69305 .71605 .69478 .71646 .69387 .71313 Mtetra
.45 .399 .71 r
.69387 .71313 .69478 .71646 .69647 .716 .69563 .71434 Mtetra
.473 .531 .836 r
.69563 .71434 .69647 .716 .69813 .71514 .69737 .71479 Mtetra
.319 .749 .972 r
.69737 .71479 .69813 .71514 .69982 .7147 .69908 .71477 Mtetra
.258 .768 .796 r
.69908 .71477 .69982 .7147 .70152 .71429 .70077 .71437 Mtetra
.506 .911 .862 r
.70077 .71437 .70152 .71429 .70321 .71386 .70245 .71362 Mtetra
.797 .944 .921 r
.70245 .71362 .70321 .71386 .70492 .71389 .7041 .71244 Mtetra
.794 .701 .763 r
.7041 .71244 .70492 .71389 .70663 .71362 .70573 .71064 Mtetra
.773 .606 .673 r
.70573 .71064 .70663 .71362 .70829 .71267 .70729 .70763 Mtetra
.903 .651 .547 r
.70729 .70763 .70829 .71267 .70977 .70796 .70798 .68794 Mtetra
.941 .663 .483 r
.70798 .68794 .70977 .70796 .70123 .51389 .7003 .50968 Mtetra
.748 .561 .643 r
.7003 .50968 .70123 .51389 .7025 .50723 .70174 .50622 Mtetra
.767 .746 .834 r
.70174 .50622 .7025 .50723 .70404 .50581 .70331 .5051 Mtetra
.655 .785 .943 r
.70331 .5051 .70404 .50581 .70564 .50535 .7049 .50463 Mtetra
.565 .751 .965 r
.7049 .50463 .70564 .50535 .70726 .50527 .70652 .50444 Mtetra
.745 .778 .88 r
.70652 .50444 .70726 .50527 .70884 .50443 .7081 .50355 Mtetra
.71 .761 .892 r
.7081 .50355 .70884 .50443 .71043 .50374 .70969 .50286 Mtetra
.545 .695 .938 r
.70969 .50286 .71043 .50374 .71205 .50369 .71131 .50279 Mtetra
.803 .358 0 r
.71131 .50279 .71205 .50369 .71388 .5071 .71313 .50618 Mtetra
.97 .683 .426 r
.71313 .50618 .71388 .5071 .72659 .70073 .72581 .69985 Mtetra
.92 .529 .148 r
.72581 .69985 .72659 .70073 .72867 .70673 .72789 .70589 Mtetra
0 .356 .82 r
.72789 .70589 .72867 .70673 .73046 .7078 .72968 .70696 Mtetra
.594 .743 .947 r
.72968 .70696 .73046 .7078 .73218 .70753 .7314 .70669 Mtetra
.794 .799 .856 r
.7314 .70669 .73218 .70753 .73384 .70625 .73307 .70542 Mtetra
.934 .778 .665 r
.73307 .70542 .73384 .70625 .73532 .70195 .73455 .70113 Mtetra
.971 .689 .436 r
.73455 .70113 .73532 .70195 .72539 .508 .72465 .50716 Mtetra
.959 .745 .572 r
.72465 .50716 .72539 .508 .72655 .50019 .72582 .49932 Mtetra
.833 .785 .806 r
.72582 .49932 .72655 .50019 .72809 .49854 .72736 .49767 Mtetra
.656 .745 .915 r
.72736 .49767 .72809 .49854 .7297 .49808 .72897 .49721 Mtetra
.524 .693 .945 r
.72897 .49721 .7297 .49808 .73134 .49804 .73061 .49719 Mtetra
.69 .76 .905 r
.73061 .49719 .73134 .49804 .73294 .49734 .73222 .49658 Mtetra
.695 .787 .922 r
.73222 .49658 .73294 .49734 .73455 .49667 .73382 .49596 Mtetra
.564 .753 .967 r
.73382 .49596 .73455 .49667 .73619 .4966 .73546 .49576 Mtetra
0 .135 .65 r
.73546 .49576 .73619 .4966 .73803 .49968 .7372 .4973 Mtetra
.678 .364 0 r
.7372 .4973 .73803 .49968 .75219 .69323 .73923 .50321 Mtetra
.111 .03 .476 r
.73923 .50321 .75219 .69323 .75436 .69967 .75325 .69358 Mtetra
.373 .291 .633 r
.75325 .69358 .75436 .69967 .75617 .70059 .75522 .69689 Mtetra
.471 .402 .698 r
.75522 .69689 .75617 .70059 .7579 .70019 .75705 .69808 Mtetra
.504 .504 .789 r
.75705 .69808 .7579 .70019 .7596 .69931 .75884 .69854 Mtetra
.531 .736 .969 r
.75884 .69854 .7596 .69931 .76131 .69859 .76059 .69842 Mtetra
.466 .872 .956 r
.76059 .69842 .76131 .69859 .76302 .69797 .76231 .69798 Mtetra
.437 .876 .876 r
.76231 .69798 .76302 .69797 .76474 .69734 .76403 .69738 Mtetra
.173 .71 .771 r
.76403 .69738 .76474 .69734 .76649 .69719 .76578 .69711 Mtetra
.298 .79 .88 r
.76578 .69711 .76649 .69719 .76823 .69697 .76752 .69681 Mtetra
.615 .936 .958 r
.76752 .69681 .76823 .69697 .76994 .69613 .76923 .69608 Mtetra
.944 .94 .755 r
.76923 .69608 .76994 .69613 .77143 .69226 .77082 .69356 Mtetra
.955 .846 .422 r
.77082 .69356 .77143 .69226 .75948 .4982 .77215 .68734 Mtetra
.109 .026 .471 r
.77215 .68734 .75948 .4982 .76057 .49008 .76025 .49481 Mtetra
.268 .055 .393 r
.76025 .49481 .76057 .49008 .7621 .48812 .76167 .49134 Mtetra
.487 .196 .397 r
.76167 .49134 .7621 .48812 .76372 .48754 .76329 .49072 Mtetra
.558 .255 .411 r
.76329 .49072 .76372 .48754 .76538 .4874 .76497 .49086 Mtetra
.538 .246 .419 r
.76497 .49086 .76538 .4874 .76702 .48709 .76664 .49073 Mtetra
.516 .232 .421 r
.76664 .49073 .76702 .48709 .76866 .48663 .76828 .49032 Mtetra
.517 .234 .423 r
.76828 .49032 .76866 .48663 .7703 .48617 .76992 .4899 Mtetra
.516 .234 .424 r
.76992 .4899 .7703 .48617 .77193 .48571 .77156 .48947 Mtetra
.515 .234 .425 r
.77156 .48947 .77193 .48571 .77357 .48523 .7732 .48902 Mtetra
.515 .234 .426 r
.7732 .48902 .77357 .48523 .77521 .48475 .77485 .48855 Mtetra
.514 .234 .426 r
.77485 .48855 .77521 .48475 .77685 .48427 .77649 .48808 Mtetra
.514 .234 .427 r
.77649 .48808 .77685 .48427 .77848 .48378 .77813 .48761 Mtetra
.77813 .48761 .77848 .48378 .78012 .48329 .77978 .48712 Mtetra
.77978 .48712 .78012 .48329 .78177 .4828 .78142 .48664 Mtetra
.78142 .48664 .78177 .4828 .78341 .48231 .78306 .48615 Mtetra
.78306 .48615 .78341 .48231 .78505 .48182 .78471 .48566 Mtetra
.513 .234 .427 r
.78471 .48566 .78505 .48182 .78669 .48132 .78636 .48516 Mtetra
.78636 .48516 .78669 .48132 .78834 .48083 .788 .48467 Mtetra
.788 .48467 .78834 .48083 .78998 .48033 .78965 .48417 Mtetra
.513 .233 .427 r
.78965 .48417 .78998 .48033 .79163 .47983 .7913 .48367 Mtetra
.7913 .48367 .79163 .47983 .79328 .47934 .79295 .48317 Mtetra
.79295 .48317 .79328 .47934 .79492 .47884 .7946 .48267 Mtetra
.7946 .48267 .79492 .47884 .79657 .47834 .79625 .48217 Mtetra
.79625 .48217 .79657 .47834 .79822 .47784 .79791 .48167 Mtetra
.79791 .48167 .79822 .47784 .79987 .47734 .79956 .48117 Mtetra
.79956 .48117 .79987 .47734 .80152 .47684 .80121 .48067 Mtetra
.80121 .48067 .80152 .47684 .80318 .47634 .80287 .48017 Mtetra
.80287 .48017 .80318 .47634 .80483 .47584 .80453 .47966 Mtetra
.513 .233 .426 r
.80453 .47966 .80483 .47584 .80649 .47535 .80618 .47916 Mtetra
.80618 .47916 .80649 .47535 .80814 .47485 .80784 .47866 Mtetra
.80784 .47866 .80814 .47485 .8098 .47435 .8095 .47816 Mtetra
.513 .232 .426 r
.8095 .47816 .8098 .47435 .81145 .47385 .81116 .47766 Mtetra
.81116 .47766 .81145 .47385 .81311 .47335 .81282 .47716 Mtetra
.81282 .47716 .81311 .47335 .81477 .47284 .81449 .47666 Mtetra
.513 .233 .426 r
.81449 .47666 .81477 .47284 .81643 .47234 .81615 .47616 Mtetra
.81615 .47616 .81643 .47234 .81809 .47184 .81781 .47566 Mtetra
.81781 .47566 .81809 .47184 .81976 .47134 .81948 .47516 Mtetra
.81948 .47516 .81976 .47134 .82142 .47084 .82115 .47466 Mtetra
.82115 .47466 .82142 .47084 .82308 .47034 .82281 .47416 Mtetra
.82281 .47416 .82308 .47034 .82475 .46984 .82448 .47366 Mtetra
.82448 .47366 .82475 .46984 .82641 .46934 .82615 .47316 Mtetra
.513 .233 .427 r
.82615 .47316 .82641 .46934 .82808 .46884 .82782 .47266 Mtetra
.82782 .47266 .82808 .46884 .82975 .46834 .82949 .47216 Mtetra
.82949 .47216 .82975 .46834 .83142 .46783 .83117 .47166 Mtetra
.83117 .47166 .83142 .46783 .83309 .46733 .83284 .47116 Mtetra
.83284 .47116 .83309 .46733 .83476 .46683 .83451 .47066 Mtetra
.83451 .47066 .83476 .46683 .83643 .46633 .83619 .47016 Mtetra
.83619 .47016 .83643 .46633 .8381 .46582 .83787 .46966 Mtetra
.513 .234 .427 r
.83787 .46966 .8381 .46582 .83978 .46532 .83954 .46916 Mtetra
.83954 .46916 .83978 .46532 .84145 .46482 .84122 .46866 Mtetra
.84122 .46866 .84145 .46482 .84313 .46431 .8429 .46815 Mtetra
.8429 .46815 .84313 .46431 .84481 .46381 .84458 .46765 Mtetra
.513 .233 .427 r
.84458 .46765 .84481 .46381 .84648 .4633 .84626 .46714 Mtetra
.84626 .46714 .84648 .4633 .84816 .46279 .84794 .46664 Mtetra
.84794 .46664 .84816 .46279 .84984 .46229 .84963 .46613 Mtetra
.84963 .46613 .84984 .46229 .85152 .46178 .85131 .46562 Mtetra
.85131 .46562 .85152 .46178 .8532 .46127 .85299 .46511 Mtetra
.85299 .46511 .8532 .46127 .85488 .46076 .85468 .46459 Mtetra
.512 .232 .427 r
.85468 .46459 .85488 .46076 .85657 .46025 .85636 .46408 Mtetra
.512 .232 .426 r
.85636 .46408 .85657 .46025 .85825 .45974 .85805 .46356 Mtetra
.85805 .46356 .85825 .45974 .85994 .45923 .85974 .46303 Mtetra
.511 .231 .426 r
.85974 .46303 .85994 .45923 .86162 .45871 .86143 .46251 Mtetra
.511 .23 .425 r
.86143 .46251 .86162 .45871 .86331 .4582 .86311 .46198 Mtetra
.51 .23 .425 r
.86311 .46198 .86331 .4582 .865 .45768 .8648 .46144 Mtetra
.509 .229 .424 r
.8648 .46144 .865 .45768 .86668 .45716 .86649 .4609 Mtetra
.509 .228 .423 r
.86649 .4609 .86668 .45716 .86837 .45664 .86818 .46036 Mtetra
.508 .227 .422 r
.86818 .46036 .86837 .45664 .87006 .45611 .86987 .45981 Mtetra
.507 .225 .421 r
.86987 .45981 .87006 .45611 .87175 .45559 .87156 .45925 Mtetra
.505 .223 .42 r
.87156 .45925 .87175 .45559 .87344 .45507 .87325 .45869 Mtetra
.505 .222 .418 r
.87325 .45869 .87344 .45507 .87514 .45454 .87494 .45812 Mtetra
.504 .22 .416 r
.87494 .45812 .87514 .45454 .87683 .45402 .87664 .45756 Mtetra
.504 .219 .415 r
.87664 .45756 .87683 .45402 .87853 .45349 .87833 .45701 Mtetra
.504 .219 .414 r
.87833 .45701 .87853 .45349 .88022 .45297 .88003 .45647 Mtetra
.504 .218 .413 r
.88003 .45647 .88022 .45297 .88192 .45245 .88173 .45593 Mtetra
.504 .218 .412 r
.88173 .45593 .88192 .45245 .88362 .45193 .88343 .45539 Mtetra
.505 .217 .412 r
.88343 .45539 .88362 .45193 .88532 .45141 .88513 .45487 Mtetra
.505 .217 .411 r
.88513 .45487 .88532 .45141 .88702 .4509 .88683 .45434 Mtetra
.88683 .45434 .88702 .4509 .88872 .45038 .88853 .45382 Mtetra
.505 .218 .411 r
.88853 .45382 .88872 .45038 .89042 .44987 .89024 .45331 Mtetra
.506 .218 .411 r
.89024 .45331 .89042 .44987 .89212 .44936 .89195 .4528 Mtetra
.89195 .4528 .89212 .44936 .89383 .44884 .89366 .45229 Mtetra
.507 .219 .411 r
.89366 .45229 .89383 .44884 .89554 .44833 .89537 .45179 Mtetra
.507 .22 .412 r
.89537 .45179 .89554 .44833 .89724 .44782 .89708 .45129 Mtetra
.508 .22 .412 r
.89708 .45129 .89724 .44782 .89895 .44732 .89879 .4508 Mtetra
.509 .222 .413 r
.89879 .4508 .89895 .44732 .90066 .44681 .90051 .45032 Mtetra
.51 .223 .414 r
.90051 .45032 .90066 .44681 .90237 .4463 .90223 .44983 Mtetra
.511 .224 .415 r
.90223 .44983 .90237 .4463 .90409 .4458 .90394 .44936 Mtetra
.512 .226 .417 r
.90394 .44936 .90409 .4458 .9058 .44529 .90566 .44889 Mtetra
.512 .227 .418 r
.90566 .44889 .9058 .44529 .90751 .44479 .90739 .44841 Mtetra
.511 .227 .419 r
.90739 .44841 .90751 .44479 .90923 .44428 .90911 .44792 Mtetra
.511 .227 .42 r
.90911 .44792 .90923 .44428 .91094 .44377 .91083 .44743 Mtetra
.91083 .44743 .91094 .44377 .91266 .44326 .91255 .44693 Mtetra
.91255 .44693 .91266 .44326 .91438 .44275 .91427 .44642 Mtetra
.51 .227 .42 r
.91427 .44642 .91438 .44275 .9161 .44224 .91599 .4459 Mtetra
.509 .226 .42 r
.91599 .4459 .9161 .44224 .91782 .44172 .91771 .44537 Mtetra
.508 .225 .419 r
.91771 .44537 .91782 .44172 .91954 .44121 .91943 .44483 Mtetra
.507 .224 .418 r
.91943 .44483 .91954 .44121 .92126 .44069 .92115 .44429 Mtetra
.507 .223 .417 r
.92115 .44429 .92126 .44069 .92298 .44018 .92288 .44375 Mtetra
.92288 .44375 .92298 .44018 .9247 .43966 .9246 .44322 Mtetra
.508 .222 .416 r
.9246 .44322 .9247 .43966 .92643 .43915 .92633 .4427 Mtetra
.508 .223 .416 r
.92633 .4427 .92643 .43915 .92815 .43864 .92806 .44219 Mtetra
.509 .223 .416 r
.92806 .44219 .92815 .43864 .92988 .43813 .92979 .44168 Mtetra
.511 .225 .416 r
.92979 .44168 .92988 .43813 .93161 .43762 .93152 .4412 Mtetra
.513 .227 .417 r
.93152 .4412 .93161 .43762 .93334 .43712 .93326 .44073 Mtetra
.516 .23 .419 r
.93326 .44073 .93334 .43712 .93507 .43664 .935 .4403 Mtetra
.52 .234 .422 r
.935 .4403 .93507 .43664 .93681 .43616 .93675 .4399 Mtetra
.526 .241 .425 r
.93675 .4399 .93681 .43616 .93855 .4357 .93851 .43958 Mtetra
.559 .27 .433 r
.93851 .43958 .93855 .4357 .94029 .43527 .94033 .4397 Mtetra
.543 .267 .447 r
.94033 .4397 .94029 .43527 .94204 .43485 .94211 .43951 Mtetra
.492 .232 .448 r
.94211 .43951 .94204 .43485 .94378 .43442 .94378 .43847 Mtetra
.331 .1 .406 r
.94378 .43847 .94378 .43442 .94553 .43394 .94524 .43575 Mtetra
.085 0 .177 r
.94524 .43575 .94553 .43394 .94727 .43345 .94676 .43356 Mtetra
.768 .988 .755 r
.94676 .43356 .94727 .43345 .94901 .43295 .94836 .43194 Mtetra
.691 .743 .891 r
.94836 .43194 .94901 .43295 .95075 .43249 .95008 .43128 Mtetra
.646 .685 .872 r
.95008 .43128 .95075 .43249 .9525 .43201 .95183 .43084 Mtetra
.63 .684 .882 r
.95183 .43084 .9525 .43201 .95424 .43149 .95359 .43048 Mtetra
.68 .738 .895 r
.95359 .43048 .95424 .43149 .95597 .43087 .95532 .42987 Mtetra
.686 .744 .895 r
.95532 .42987 .95597 .43087 .95769 .43022 .95705 .42924 Mtetra
.692 .751 .896 r
.95705 .42924 .95769 .43022 .95942 .42954 .95878 .42857 Mtetra
.774 .783 .86 r
.95878 .42857 .95942 .42954 .96108 .4284 .96044 .42743 Mtetra
.71 .761 .893 r
.96044 .42743 .96108 .4284 .96279 .42765 .96216 .42668 Mtetra
.541 .685 .932 r
.96216 .42668 .96279 .42765 .9646 .42759 .96397 .42663 Mtetra
.931 .56 .28 r
.39568 .59697 .39654 .59776 .3978 .60187 .39694 .60112 Mtetra
.937 .682 .526 r
.39694 .60112 .3978 .60187 .39232 .78963 .39141 .78899 Mtetra
.929 .576 .336 r
.39141 .78899 .39232 .78963 .39364 .79465 .39273 .79395 Mtetra
.105 .524 .91 r
.39273 .79395 .39364 .79465 .39512 .79501 .39421 .79446 Mtetra
.658 .817 .96 r
.39421 .79446 .39512 .79501 .39664 .79449 .39573 .79398 Mtetra
.822 .829 .854 r
.39573 .79398 .39664 .79449 .39818 .79334 .39727 .79264 Mtetra
.892 .757 .706 r
.39727 .79264 .39818 .79334 .39974 .79165 .3989 .7892 Mtetra
.887 .67 .602 r
.3989 .7892 .39974 .79165 .40132 .78933 .4008 .77771 Mtetra
.921 .671 .542 r
.4008 .77771 .40132 .78933 .40293 .78636 .40843 .59752 Mtetra
.577 .371 .565 r
.40843 .59752 .40293 .78636 .40449 .78462 .40992 .59549 Mtetra
.574 .369 .565 r
.40992 .59549 .40449 .78462 .406 .78436 .41136 .59507 Mtetra
.571 .366 .565 r
.41136 .59507 .406 .78436 .40747 .78545 .41275 .5962 Mtetra
0 0 .372 r
.41275 .5962 .40747 .78545 .4089 .78772 .40833 .77683 Mtetra
0 0 .451 r
.40833 .77683 .4089 .78772 .41036 .78934 .40951 .78689 Mtetra
0 0 .568 r
.40951 .78689 .41036 .78934 .41184 .79033 .41093 .78959 Mtetra
.281 .615 .957 r
.41093 .78959 .41184 .79033 .41335 .79039 .41244 .78992 Mtetra
.558 .817 .994 r
.41244 .78992 .41335 .79039 .41487 .79014 .41396 .78965 Mtetra
.681 .839 .959 r
.41396 .78965 .41487 .79014 .41639 .78972 .41549 .78908 Mtetra
.674 .797 .94 r
.41549 .78908 .41639 .78972 .41792 .78925 .41702 .78856 Mtetra
.686 .784 .925 r
.41702 .78856 .41792 .78925 .41945 .78874 .41855 .788 Mtetra
.69 .772 .914 r
.41855 .788 .41945 .78874 .42098 .78822 .42009 .78742 Mtetra
.615 .743 .937 r
.42009 .78742 .42098 .78822 .4225 .78807 .42161 .78713 Mtetra
.636 .714 .903 r
.42161 .78713 .4225 .78807 .42403 .78778 .42314 .78678 Mtetra
.687 .718 .873 r
.42314 .78678 .42403 .78778 .42557 .78703 .42468 .7862 Mtetra
.818 .764 .803 r
.42468 .7862 .42557 .78703 .42717 .78415 .42624 .7846 Mtetra
.933 .963 .758 r
.42624 .7846 .42717 .78415 .42889 .77682 .42783 .78224 Mtetra
.273 .045 .374 r
.42783 .78224 .42889 .77682 .43528 .59129 .42943 .77903 Mtetra
.571 .363 .56 r
.42943 .77903 .43528 .59129 .43677 .58938 .43097 .77832 Mtetra
.572 .364 .56 r
.43097 .77832 .43677 .58938 .43822 .58912 .4325 .77833 Mtetra
.571 .363 .56 r
.4325 .77833 .43822 .58912 .43966 .58906 .43404 .77745 Mtetra
0 0 .375 r
.43404 .77745 .43966 .58906 .44116 .58689 .44007 .59591 Mtetra
0 0 .215 r
.44007 .59591 .44116 .58689 .44265 .58478 .44177 .58569 Mtetra
.962 .94 .645 r
.44177 .58569 .44265 .58478 .44414 .58318 .44329 .58243 Mtetra
.785 .774 .843 r
.44329 .58243 .44414 .58318 .4456 .5824 .44477 .58131 Mtetra
.661 .683 .86 r
.44477 .58131 .4456 .5824 .44705 .58197 .44622 .58088 Mtetra
.595 .658 .881 r
.44622 .58088 .44705 .58197 .44851 .58169 .44767 .58072 Mtetra
.609 .689 .899 r
.44767 .58072 .44851 .58169 .44996 .5814 .44913 .5805 Mtetra
.614 .705 .909 r
.44913 .5805 .44996 .5814 .45142 .58111 .45058 .58025 Mtetra
.621 .717 .915 r
.45058 .58025 .45142 .58111 .45287 .58078 .45204 .57997 Mtetra
.671 .744 .905 r
.45204 .57997 .45287 .58078 .45434 .58026 .4535 .57949 Mtetra
.693 .758 .902 r
.4535 .57949 .45434 .58026 .4558 .57967 .45496 .57893 Mtetra
.697 .766 .905 r
.45496 .57893 .4558 .57967 .45726 .57907 .45643 .57834 Mtetra
.709 .773 .902 r
.45643 .57834 .45726 .57907 .45873 .57833 .45789 .57771 Mtetra
.685 .798 .935 r
.45789 .57771 .45873 .57833 .4602 .57774 .45936 .57718 Mtetra
.601 .795 .974 r
.45936 .57718 .4602 .57774 .46166 .57756 .46082 .57688 Mtetra
.109 .516 .91 r
.46082 .57688 .46166 .57756 .46309 .57909 .46227 .5774 Mtetra
.152 .315 .776 r
.46227 .5774 .46309 .57909 .46445 .58438 .4637 .57869 Mtetra
.426 .319 .63 r
.4637 .57869 .46445 .58438 .46269 .77033 .46513 .58083 Mtetra
.573 .368 .565 r
.46513 .58083 .46269 .77033 .4642 .77224 .46658 .58111 Mtetra
.575 .369 .565 r
.46658 .58111 .4642 .77224 .46576 .77176 .46806 .58024 Mtetra
.573 .368 .565 r
.46806 .58024 .46576 .77176 .46731 .77099 .46953 .58011 Mtetra
.007 0 .406 r
.46953 .58011 .46731 .77099 .46884 .77212 .46817 .7583 Mtetra
.059 .004 .474 r
.46817 .7583 .46884 .77212 .47037 .77354 .46953 .77051 Mtetra
0 .098 .615 r
.46953 .77051 .47037 .77354 .47191 .77445 .47103 .7734 Mtetra
.227 .5 .902 r
.47103 .7734 .47191 .77445 .47346 .77475 .47257 .77406 Mtetra
.601 .77 .961 r
.47257 .77406 .47346 .77475 .47501 .77452 .47413 .77377 Mtetra
.734 .782 .891 r
.47413 .77377 .47501 .77452 .47658 .77375 .4757 .77297 Mtetra
.816 .779 .818 r
.4757 .77297 .47658 .77375 .47816 .77134 .47727 .77146 Mtetra
.928 .931 .787 r
.47727 .77146 .47816 .77134 .47979 .76553 .47886 .76922 Mtetra
.103 0 .251 r
.47886 .76922 .47979 .76553 .48362 .57813 .48046 .76614 Mtetra
.57 .362 .56 r
.48046 .76614 .48362 .57813 .48513 .57483 .48203 .76468 Mtetra
.572 .364 .56 r
.48203 .76468 .48513 .57483 .48661 .57437 .48359 .76465 Mtetra
.571 .363 .56 r
.48359 .76465 .48661 .57437 .48809 .57425 .48515 .76393 Mtetra
.548 .344 .556 r
.48515 .76393 .48809 .57425 .48959 .57245 .48687 .7488 Mtetra
0 0 .379 r
.48687 .7488 .48959 .57245 .49108 .57025 .49024 .5717 Mtetra
.887 .906 .497 r
.49024 .5717 .49108 .57025 .49258 .56855 .49175 .56804 Mtetra
.848 .829 .829 r
.49175 .56804 .49258 .56855 .49406 .56741 .49324 .5665 Mtetra
.696 .732 .878 r
.49324 .5665 .49406 .56741 .49555 .56675 .49473 .5659 Mtetra
.572 .706 .933 r
.49473 .5659 .49555 .56675 .49703 .56658 .49621 .56576 Mtetra
.249 .56 .934 r
.49621 .56576 .49703 .56658 .4985 .56777 .49768 .56623 Mtetra
.184 .359 .805 r
.49768 .56623 .4985 .56777 .49995 .57181 .49916 .56736 Mtetra
.407 .327 .654 r
.49916 .56736 .49995 .57181 .50015 .75843 .50063 .56922 Mtetra
.572 .367 .565 r
.50063 .56922 .50015 .75843 .50169 .76188 .50211 .56992 Mtetra
.574 .369 .565 r
.50211 .56992 .50169 .76188 .50327 .76154 .5036 .56915 Mtetra
.573 .368 .565 r
.5036 .56915 .50327 .76154 .50484 .76077 .50509 .56891 Mtetra
.559 .357 .563 r
.50509 .56891 .50484 .76077 .50641 .76165 .50654 .57684 Mtetra
0 0 .401 r
.50654 .57684 .50641 .76165 .50798 .76321 .50712 .75961 Mtetra
.016 .088 .596 r
.50712 .75961 .50798 .76321 .50955 .76425 .50868 .76305 Mtetra
.142 .411 .856 r
.50868 .76305 .50955 .76425 .51112 .76455 .51026 .76399 Mtetra
.515 .778 .992 r
.51026 .76399 .51112 .76455 .5127 .76434 .51184 .76383 Mtetra
.646 .834 .973 r
.51184 .76383 .5127 .76434 .51429 .76397 .51342 .76335 Mtetra
.653 .805 .956 r
.51342 .76335 .51429 .76397 .51587 .76358 .515 .76288 Mtetra
.636 .778 .949 r
.515 .76288 .51587 .76358 .51745 .76319 .51659 .76248 Mtetra
.652 .779 .941 r
.51659 .76248 .51745 .76319 .51904 .76276 .51817 .76203 Mtetra
.646 .773 .94 r
.51817 .76203 .51904 .76276 .52062 .76244 .51976 .7616 Mtetra
.659 .751 .918 r
.51976 .7616 .52062 .76244 .52221 .7621 .52135 .76114 Mtetra
.699 .736 .879 r
.52135 .76114 .52221 .7621 .5238 .76139 .52293 .76048 Mtetra
.787 .761 .829 r
.52293 .76048 .5238 .76139 .52538 .75939 .52452 .7592 Mtetra
.908 .887 .8 r
.52452 .7592 .52538 .75939 .52697 .75449 .52611 .75707 Mtetra
0 0 .086 r
.52611 .75707 .52697 .75449 .52836 .56698 .5277 .75423 Mtetra
.569 .361 .559 r
.5277 .75423 .52836 .56698 .52986 .56146 .52929 .75177 Mtetra
.571 .363 .56 r
.52929 .75177 .52986 .56146 .53136 .56064 .53087 .75106 Mtetra
.572 .364 .56 r
.53087 .75106 .53136 .56064 .53287 .56068 .53247 .75109 Mtetra
.53247 .75109 .53287 .56068 .53438 .56069 .53406 .75102 Mtetra
.53406 .75102 .53438 .56069 .53588 .56027 .53565 .75063 Mtetra
.53565 .75063 .53588 .56027 .53739 .55986 .53724 .75025 Mtetra
.53724 .75025 .53739 .55986 .5389 .55943 .53884 .74984 Mtetra
.53884 .74984 .5389 .55943 .54041 .55898 .54043 .74942 Mtetra
.54043 .74942 .54041 .55898 .54192 .55853 .54203 .749 Mtetra
.54203 .749 .54192 .55853 .54343 .55806 .54362 .74856 Mtetra
.54362 .74856 .54343 .55806 .54494 .5576 .54522 .74812 Mtetra
.54522 .74812 .54494 .5576 .54645 .55713 .54682 .74768 Mtetra
.54682 .74768 .54645 .55713 .54796 .55667 .54842 .74723 Mtetra
.54842 .74723 .54796 .55667 .54948 .5562 .55002 .74679 Mtetra
.55002 .74679 .54948 .5562 .55099 .55574 .55162 .74634 Mtetra
.55162 .74634 .55099 .55574 .55251 .55528 .55322 .74591 Mtetra
.55322 .74591 .55251 .55528 .55402 .55484 .55483 .74549 Mtetra
.55483 .74549 .55402 .55484 .55554 .55439 .55643 .74506 Mtetra
.55643 .74506 .55554 .55439 .55706 .55415 .55804 .74505 Mtetra
.573 .364 .56 r
.55804 .74505 .55706 .55415 .55858 .55409 .55965 .7453 Mtetra
.571 .363 .56 r
.55965 .7453 .55858 .55409 .5601 .55355 .56126 .74462 Mtetra
.565 .358 .559 r
.56126 .74462 .5601 .55355 .56161 .55177 .56282 .73994 Mtetra
.011 0 .412 r
.56282 .73994 .56161 .55177 .56311 .54931 .56235 .552 Mtetra
0 0 0 r
.56235 .552 .56311 .54931 .56461 .54739 .56382 .54716 Mtetra
.91 .882 .794 r
.56382 .54716 .56461 .54739 .56612 .54617 .56532 .5451 Mtetra
.698 .705 .852 r
.56532 .5451 .56612 .54617 .56764 .54563 .56684 .54444 Mtetra
.629 .661 .862 r
.56684 .54444 .56764 .54563 .56917 .54526 .56837 .54414 Mtetra
.618 .668 .876 r
.56837 .54414 .56917 .54526 .57069 .54491 .56989 .54388 Mtetra
.662 .702 .876 r
.56989 .54388 .57069 .54491 .57221 .54445 .57142 .54343 Mtetra
.661 .703 .878 r
.57142 .54343 .57221 .54445 .57374 .54399 .57294 .54297 Mtetra
.662 .705 .879 r
.57294 .54297 .57374 .54399 .57526 .54352 .57447 .54252 Mtetra
.663 .707 .88 r
.57447 .54252 .57526 .54352 .57679 .54306 .576 .54206 Mtetra
.663 .708 .881 r
.576 .54206 .57679 .54306 .57832 .54259 .57752 .54159 Mtetra
.663 .709 .882 r
.57752 .54159 .57832 .54259 .57985 .54213 .57905 .54113 Mtetra
.663 .71 .882 r
.57905 .54113 .57985 .54213 .58138 .54166 .58058 .54067 Mtetra
.663 .71 .883 r
.58058 .54067 .58138 .54166 .58291 .5412 .58211 .54021 Mtetra
.663 .711 .884 r
.58211 .54021 .58291 .5412 .58444 .54073 .58364 .53975 Mtetra
.663 .712 .885 r
.58364 .53975 .58444 .54073 .58597 .54027 .58518 .53929 Mtetra
.659 .712 .887 r
.58518 .53929 .58597 .54027 .5875 .53981 .58671 .53885 Mtetra
.646 .71 .894 r
.58671 .53885 .5875 .53981 .58904 .53941 .58824 .53846 Mtetra
.623 .706 .905 r
.58824 .53846 .58904 .53941 .59057 .53908 .58978 .53816 Mtetra
.625 .714 .91 r
.58978 .53816 .59057 .53908 .59211 .53873 .59132 .53785 Mtetra
.649 .731 .909 r
.59132 .53785 .59211 .53873 .59365 .5383 .59286 .53745 Mtetra
.691 .751 .898 r
.59286 .53745 .59365 .5383 .59518 .53769 .59439 .53687 Mtetra
.699 .758 .898 r
.59439 .53687 .59518 .53769 .59671 .53706 .59593 .53625 Mtetra
.694 .76 .903 r
.59593 .53625 .59671 .53706 .59825 .53645 .59746 .53565 Mtetra
.674 .758 .914 r
.59746 .53565 .59825 .53645 .59979 .53593 .599 .53514 Mtetra
.669 .76 .919 r
.599 .53514 .59979 .53593 .60133 .53543 .60054 .53465 Mtetra
.677 .764 .917 r
.60054 .53465 .60133 .53543 .60286 .53488 .60208 .53413 Mtetra
.702 .779 .911 r
.60208 .53413 .60286 .53488 .6044 .53414 .60362 .5335 Mtetra
.66 .797 .948 r
.60362 .5335 .6044 .53414 .60594 .53369 .60516 .53302 Mtetra
.514 .739 .976 r
.60516 .53302 .60594 .53369 .6075 .53398 .60672 .53294 Mtetra
.147 .435 .872 r
.60672 .53294 .6075 .53398 .60913 .53666 .6083 .5338 Mtetra
.359 .351 .714 r
.6083 .5338 .60913 .53666 .61515 .71159 .60989 .53531 Mtetra
.57 .366 .565 r
.60989 .53531 .61515 .71159 .6173 .73083 .6115 .53703 Mtetra
.574 .369 .565 r
.6115 .53703 .6173 .73083 .61895 .73095 .61304 .53628 Mtetra
.61304 .53628 .61895 .73095 .62059 .73028 .61459 .53568 Mtetra
.57 .366 .565 r
.61459 .53568 .62059 .73028 .62224 .73028 .6162 .53736 Mtetra
.06 0 .444 r
.6162 .53736 .62224 .73028 .62396 .73247 .62299 .72649 Mtetra
.186 .156 .59 r
.62299 .72649 .62396 .73247 .62564 .73357 .62478 .73134 Mtetra
.287 .358 .762 r
.62478 .73134 .62564 .73357 .6273 .73342 .62648 .73279 Mtetra
.776 .833 .897 r
.62648 .73279 .6273 .73342 .62887 .73042 .62812 .73174 Mtetra
0 0 0 r
.62812 .73174 .62887 .73042 .63029 .72232 .62971 .72949 Mtetra
.281 .082 .422 r
.62971 .72949 .63029 .72232 .62624 .5333 .63123 .72479 Mtetra
.062 0 .439 r
.63123 .72479 .62624 .5333 .62772 .53018 .62715 .53594 Mtetra
0 0 .267 r
.62715 .53594 .62772 .53018 .62924 .52845 .62851 .52914 Mtetra
.89 .959 .622 r
.62851 .52914 .62924 .52845 .63077 .52735 .63 .52651 Mtetra
.734 .768 .88 r
.63 .52651 .63077 .52735 .63233 .52671 .63155 .5257 Mtetra
.647 .704 .889 r
.63155 .5257 .63233 .52671 .63388 .52627 .63311 .52531 Mtetra
.63 .709 .903 r
.63311 .52531 .63388 .52627 .63544 .52579 .63467 .52498 Mtetra
.78 .782 .854 r
.63467 .52498 .63544 .52579 .63698 .52468 .63621 .52387 Mtetra
.712 .77 .898 r
.63621 .52387 .63698 .52468 .63853 .52398 .63777 .52318 Mtetra
.395 .647 .958 r
.63777 .52318 .63853 .52398 .64012 .52418 .63935 .52342 Mtetra
.927 .541 .194 r
.63935 .52342 .64012 .52418 .64187 .52915 .64112 .5287 Mtetra
.964 .684 .455 r
.64112 .5287 .64187 .52915 .6503 .7226 .6495 .72213 Mtetra
.897 .477 .153 r
.6495 .72213 .6503 .7226 .65213 .72686 .65132 .7262 Mtetra
.487 .743 .985 r
.65132 .7262 .65213 .72686 .6538 .72685 .653 .72614 Mtetra
.723 .808 .918 r
.653 .72614 .6538 .72685 .65546 .72612 .65465 .72537 Mtetra
.773 .806 .88 r
.65465 .72537 .65546 .72612 .6571 .72511 .65629 .7243 Mtetra
.557 .731 .956 r
.65629 .7243 .6571 .72511 .65878 .72513 .65797 .72414 Mtetra
.609 .709 .915 r
.65797 .72414 .65878 .72513 .66046 .72489 .65964 .72387 Mtetra
.679 .728 .887 r
.65964 .72387 .66046 .72489 .66211 .72406 .66131 .72329 Mtetra
.818 .807 .841 r
.66131 .72329 .66211 .72406 .66367 .72081 .66294 .72185 Mtetra
.61 .823 .423 r
.66294 .72185 .66367 .72081 .665 .71174 .66453 .71951 Mtetra
.324 .122 .444 r
.66453 .71951 .665 .71174 .6591 .52291 .66604 .71491 Mtetra
.075 0 .448 r
.66604 .71491 .6591 .52291 .66057 .51973 .66003 .52429 Mtetra
0 0 .218 r
.66003 .52429 .66057 .51973 .66209 .51792 .66138 .5184 Mtetra
.931 .964 .67 r
.66138 .5184 .66209 .51792 .66363 .51674 .66287 .51575 Mtetra
.73 .738 .858 r
.66287 .51575 .66363 .51674 .6652 .51609 .66443 .51492 Mtetra
.645 .674 .863 r
.66443 .51492 .6652 .51609 .66678 .51568 .66601 .51452 Mtetra
.589 .654 .882 r
.66601 .51452 .66678 .51568 .66837 .51539 .6676 .51438 Mtetra
.626 .698 .896 r
.6676 .51438 .66837 .51539 .66995 .51503 .66919 .51406 Mtetra
.625 .707 .904 r
.66919 .51406 .66995 .51503 .67153 .51467 .67077 .51375 Mtetra
.635 .722 .911 r
.67077 .51375 .67153 .51467 .67312 .51426 .67236 .51339 Mtetra
.722 .762 .884 r
.67236 .51339 .67312 .51426 .67468 .51334 .67393 .51263 Mtetra
.709 .799 .92 r
.67393 .51263 .67468 .51334 .67625 .51262 .6755 .51196 Mtetra
.641 .791 .954 r
.6755 .51196 .67625 .51262 .67784 .51237 .67709 .51153 Mtetra
.358 .617 .949 r
.67709 .51153 .67784 .51237 .67953 .51412 .67871 .51187 Mtetra
.386 .409 .761 r
.67871 .51187 .67953 .51412 .6814 .51982 .68037 .51297 Mtetra
.424 .313 .623 r
.68037 .51297 .6814 .51982 .69201 .71003 .68211 .51583 Mtetra
.098 .016 .465 r
.68211 .51583 .69201 .71003 .69387 .71313 .69274 .70534 Mtetra
.193 .146 .572 r
.69274 .70534 .69387 .71313 .69563 .71434 .69476 .71187 Mtetra
.157 .255 .716 r
.69476 .71187 .69563 .71434 .69737 .71479 .69658 .71406 Mtetra
.273 .614 .957 r
.69658 .71406 .69737 .71479 .69908 .71477 .69831 .71445 Mtetra
.522 .86 .994 r
.69831 .71445 .69908 .71477 .70077 .71437 .7 .71407 Mtetra
.774 .931 .936 r
.7 .71407 .70077 .71437 .70245 .71362 .70167 .71302 Mtetra
.91 .829 .754 r
.70167 .71302 .70245 .71362 .7041 .71244 .70325 .71039 Mtetra
.88 .686 .637 r
.70325 .71039 .7041 .71244 .70573 .71064 .70469 .70493 Mtetra
.963 .683 .457 r
.70469 .70493 .70573 .71064 .70729 .70763 .69657 .51391 Mtetra
.581 .374 .565 r
.69657 .51391 .70729 .70763 .70798 .68794 .69794 .50887 Mtetra
.577 .371 .565 r
.69794 .50887 .70798 .68794 .7003 .50968 .69944 .5066 Mtetra
.692 .552 .691 r
.69944 .5066 .7003 .50968 .70174 .50622 .70099 .50518 Mtetra
.716 .728 .86 r
.70099 .50518 .70174 .50622 .70331 .5051 .70257 .50442 Mtetra
.655 .792 .948 r
.70257 .50442 .70331 .5051 .7049 .50463 .70417 .50394 Mtetra
.613 .777 .959 r
.70417 .50394 .7049 .50463 .70652 .50444 .70578 .50361 Mtetra
.751 .78 .876 r
.70578 .50361 .70652 .50444 .7081 .50355 .70735 .50268 Mtetra
.713 .761 .891 r
.70735 .50268 .7081 .50355 .70969 .50286 .70894 .50197 Mtetra
.55 .698 .937 r
.70894 .50197 .70969 .50286 .71131 .50279 .71057 .50188 Mtetra
.801 .356 0 r
.71057 .50188 .71131 .50279 .71313 .50618 .71239 .50526 Mtetra
.97 .683 .426 r
.71239 .50526 .71313 .50618 .72581 .69985 .72503 .69897 Mtetra
.92 .53 .149 r
.72503 .69897 .72581 .69985 .72789 .70589 .72711 .70505 Mtetra
0 .355 .82 r
.72711 .70505 .72789 .70589 .72968 .70696 .7289 .70612 Mtetra
.594 .741 .947 r
.7289 .70612 .72968 .70696 .7314 .70669 .73063 .70585 Mtetra
.794 .798 .856 r
.73063 .70585 .7314 .70669 .73307 .70542 .73229 .70458 Mtetra
.933 .778 .665 r
.73229 .70458 .73307 .70542 .73455 .70113 .73377 .70029 Mtetra
.971 .689 .436 r
.73377 .70029 .73455 .70113 .72465 .50716 .72391 .50632 Mtetra
.958 .745 .572 r
.72391 .50632 .72465 .50716 .72582 .49932 .72508 .49844 Mtetra
.833 .785 .806 r
.72508 .49844 .72582 .49932 .72736 .49767 .72662 .4968 Mtetra
.653 .744 .916 r
.72662 .4968 .72736 .49767 .72897 .49721 .72824 .49635 Mtetra
.521 .692 .946 r
.72824 .49635 .72897 .49721 .73061 .49719 .72988 .49633 Mtetra
.661 .752 .917 r
.72988 .49633 .73061 .49719 .73222 .49658 .73149 .49585 Mtetra
.681 .79 .932 r
.73149 .49585 .73222 .49658 .73382 .49596 .7331 .49529 Mtetra
.613 .784 .963 r
.7331 .49529 .73382 .49596 .73546 .49576 .73473 .49493 Mtetra
.427 .656 .955 r
.73473 .49493 .73546 .49576 .7372 .4973 .73639 .49513 Mtetra
.422 .438 .771 r
.73639 .49513 .7372 .4973 .73923 .50321 .7381 .49605 Mtetra
.46 .337 .625 r
.7381 .49605 .73923 .50321 .75325 .69358 .73991 .49851 Mtetra
.132 .045 .482 r
.73991 .49851 .75325 .69358 .75522 .69689 .75387 .68716 Mtetra
.233 .165 .571 r
.75387 .68716 .75522 .69689 .75705 .69808 .75614 .69499 Mtetra
.241 .275 .697 r
.75614 .69499 .75705 .69808 .75884 .69854 .75805 .69743 Mtetra
.417 .595 .917 r
.75805 .69743 .75884 .69854 .76059 .69842 .75983 .69781 Mtetra
.626 .816 .974 r
.75983 .69781 .76059 .69842 .76231 .69798 .76156 .69735 Mtetra
.713 .839 .942 r
.76156 .69735 .76231 .69798 .76403 .69738 .76327 .6966 Mtetra
.642 .776 .945 r
.76327 .6966 .76403 .69738 .76578 .69711 .765 .69614 Mtetra
.632 .728 .917 r
.765 .69614 .76578 .69711 .76752 .69681 .76674 .69576 Mtetra
.681 .729 .886 r
.76674 .69576 .76752 .69681 .76923 .69608 .76846 .69515 Mtetra
.81 .786 .83 r
.76846 .69515 .76923 .69608 .77082 .69356 .77013 .69367 Mtetra
.925 .972 .753 r
.77013 .69367 .77082 .69356 .77215 .68734 .77173 .69132 Mtetra
.232 .005 .35 r
.77173 .69132 .77215 .68734 .76025 .49481 .77327 .68816 Mtetra
.569 .362 .56 r
.77327 .68816 .76025 .49481 .76167 .49134 .77488 .68596 Mtetra
.572 .364 .56 r
.77488 .68596 .76167 .49134 .76329 .49072 .77661 .68543 Mtetra
.573 .364 .56 r
.77661 .68543 .76329 .49072 .76497 .49086 .77839 .68559 Mtetra
.572 .364 .56 r
.77839 .68559 .76497 .49086 .76664 .49073 .78015 .68544 Mtetra
.78015 .68544 .76664 .49073 .76828 .49032 .78189 .68505 Mtetra
.78189 .68505 .76828 .49032 .76992 .4899 .78364 .68467 Mtetra
.78364 .68467 .76992 .4899 .77156 .48947 .78538 .68426 Mtetra
.78538 .68426 .77156 .48947 .7732 .48902 .78712 .68384 Mtetra
.78712 .68384 .7732 .48902 .77485 .48855 .78887 .6834 Mtetra
.78887 .6834 .77485 .48855 .77649 .48808 .79061 .68296 Mtetra
.79061 .68296 .77649 .48808 .77813 .48761 .79236 .68251 Mtetra
.79236 .68251 .77813 .48761 .77978 .48712 .7941 .68206 Mtetra
.7941 .68206 .77978 .48712 .78142 .48664 .79585 .6816 Mtetra
.79585 .6816 .78142 .48664 .78306 .48615 .7976 .68114 Mtetra
.7976 .68114 .78306 .48615 .78471 .48566 .79935 .68068 Mtetra
.79935 .68068 .78471 .48566 .78636 .48516 .8011 .68022 Mtetra
.8011 .68022 .78636 .48516 .788 .48467 .80285 .67975 Mtetra
.80285 .67975 .788 .48467 .78965 .48417 .8046 .67928 Mtetra
.8046 .67928 .78965 .48417 .7913 .48367 .80635 .67881 Mtetra
.80635 .67881 .7913 .48367 .79295 .48317 .8081 .67834 Mtetra
.8081 .67834 .79295 .48317 .7946 .48267 .80986 .67786 Mtetra
.80986 .67786 .7946 .48267 .79625 .48217 .81161 .67739 Mtetra
.81161 .67739 .79625 .48217 .79791 .48167 .81337 .67692 Mtetra
.81337 .67692 .79791 .48167 .79956 .48117 .81513 .67644 Mtetra
.81513 .67644 .79956 .48117 .80121 .48067 .81688 .67597 Mtetra
.81688 .67597 .80121 .48067 .80287 .48017 .81864 .6755 Mtetra
.81864 .6755 .80287 .48017 .80453 .47966 .8204 .67502 Mtetra
.8204 .67502 .80453 .47966 .80618 .47916 .82217 .67455 Mtetra
.82217 .67455 .80618 .47916 .80784 .47866 .82393 .67408 Mtetra
.82393 .67408 .80784 .47866 .8095 .47816 .82569 .6736 Mtetra
.82569 .6736 .8095 .47816 .81116 .47766 .82746 .67313 Mtetra
.82746 .67313 .81116 .47766 .81282 .47716 .82922 .67266 Mtetra
.82922 .67266 .81282 .47716 .81449 .47666 .83099 .67219 Mtetra
.83099 .67219 .81449 .47666 .81615 .47616 .83276 .67172 Mtetra
.83276 .67172 .81615 .47616 .81781 .47566 .83453 .67125 Mtetra
.83453 .67125 .81781 .47566 .81948 .47516 .8363 .67078 Mtetra
.8363 .67078 .81948 .47516 .82115 .47466 .83807 .67031 Mtetra
.83807 .67031 .82115 .47466 .82281 .47416 .83985 .66984 Mtetra
.83985 .66984 .82281 .47416 .82448 .47366 .84162 .66937 Mtetra
.84162 .66937 .82448 .47366 .82615 .47316 .8434 .6689 Mtetra
.8434 .6689 .82615 .47316 .82782 .47266 .84517 .66843 Mtetra
.84517 .66843 .82782 .47266 .82949 .47216 .84695 .66796 Mtetra
.84695 .66796 .82949 .47216 .83117 .47166 .84873 .66749 Mtetra
.84873 .66749 .83117 .47166 .83284 .47116 .85051 .66703 Mtetra
.85051 .66703 .83284 .47116 .83451 .47066 .85229 .66656 Mtetra
.85229 .66656 .83451 .47066 .83619 .47016 .85407 .66609 Mtetra
.85407 .66609 .83619 .47016 .83787 .46966 .85585 .66562 Mtetra
.85585 .66562 .83787 .46966 .83954 .46916 .85764 .66515 Mtetra
.85764 .66515 .83954 .46916 .84122 .46866 .85942 .66467 Mtetra
.85942 .66467 .84122 .46866 .8429 .46815 .86121 .6642 Mtetra
.86121 .6642 .8429 .46815 .84458 .46765 .863 .66373 Mtetra
.863 .66373 .84458 .46765 .84626 .46714 .86479 .66325 Mtetra
.86479 .66325 .84626 .46714 .84794 .46664 .86657 .66277 Mtetra
.86657 .66277 .84794 .46664 .84963 .46613 .86836 .66229 Mtetra
.86836 .66229 .84963 .46613 .85131 .46562 .87016 .66181 Mtetra
.87016 .66181 .85131 .46562 .85299 .46511 .87195 .66133 Mtetra
.87195 .66133 .85299 .46511 .85468 .46459 .87374 .66084 Mtetra
.87374 .66084 .85468 .46459 .85636 .46408 .87553 .66036 Mtetra
.87553 .66036 .85636 .46408 .85805 .46356 .87733 .65986 Mtetra
.87733 .65986 .85805 .46356 .85974 .46303 .87912 .65937 Mtetra
.87912 .65937 .85974 .46303 .86143 .46251 .88092 .65886 Mtetra
.88092 .65886 .86143 .46251 .86311 .46198 .88271 .65836 Mtetra
.88271 .65836 .86311 .46198 .8648 .46144 .88451 .65784 Mtetra
.88451 .65784 .8648 .46144 .86649 .4609 .88631 .65732 Mtetra
.88631 .65732 .86649 .4609 .86818 .46036 .88811 .65679 Mtetra
.88811 .65679 .86818 .46036 .86987 .45981 .8899 .65625 Mtetra
.8899 .65625 .86987 .45981 .87156 .45925 .8917 .6557 Mtetra
.8917 .6557 .87156 .45925 .87325 .45869 .8935 .65513 Mtetra
.8935 .65513 .87325 .45869 .87494 .45812 .89529 .65455 Mtetra
.89529 .65455 .87494 .45812 .87664 .45756 .89709 .65398 Mtetra
.89709 .65398 .87664 .45756 .87833 .45701 .89889 .65343 Mtetra
.89889 .65343 .87833 .45701 .88003 .45647 .90069 .65289 Mtetra
.90069 .65289 .88003 .45647 .88173 .45593 .9025 .65236 Mtetra
.9025 .65236 .88173 .45593 .88343 .45539 .90431 .65183 Mtetra
.90431 .65183 .88343 .45539 .88513 .45487 .90612 .65132 Mtetra
.90612 .65132 .88513 .45487 .88683 .45434 .90793 .65082 Mtetra
.90793 .65082 .88683 .45434 .88853 .45382 .90974 .65032 Mtetra
.90974 .65032 .88853 .45382 .89024 .45331 .91156 .64984 Mtetra
.91156 .64984 .89024 .45331 .89195 .4528 .91338 .64936 Mtetra
.91338 .64936 .89195 .4528 .89366 .45229 .9152 .64889 Mtetra
.9152 .64889 .89366 .45229 .89537 .45179 .91702 .64843 Mtetra
.91702 .64843 .89537 .45179 .89708 .45129 .91885 .64799 Mtetra
.91885 .64799 .89708 .45129 .89879 .4508 .92067 .64755 Mtetra
.92067 .64755 .89879 .4508 .90051 .45032 .9225 .64711 Mtetra
.9225 .64711 .90051 .45032 .90223 .44983 .92434 .64669 Mtetra
.92434 .64669 .90223 .44983 .90394 .44936 .92617 .64629 Mtetra
.92617 .64629 .90394 .44936 .90566 .44889 .92801 .64588 Mtetra
.92801 .64588 .90566 .44889 .90739 .44841 .92984 .64546 Mtetra
.92984 .64546 .90739 .44841 .90911 .44792 .93168 .64501 Mtetra
.93168 .64501 .90911 .44792 .91083 .44743 .93351 .64455 Mtetra
.93351 .64455 .91083 .44743 .91255 .44693 .93534 .64408 Mtetra
.93534 .64408 .91255 .44693 .91427 .44642 .93717 .64359 Mtetra
.93717 .64359 .91427 .44642 .91599 .4459 .93901 .64309 Mtetra
.93901 .64309 .91599 .4459 .91771 .44537 .94084 .64257 Mtetra
.94084 .64257 .91771 .44537 .91943 .44483 .94267 .64202 Mtetra
.94267 .64202 .91943 .44483 .92115 .44429 .9445 .64147 Mtetra
.9445 .64147 .92115 .44429 .92288 .44375 .94633 .64092 Mtetra
.94633 .64092 .92288 .44375 .9246 .44322 .94816 .64039 Mtetra
.94816 .64039 .9246 .44322 .92633 .4427 .95 .63987 Mtetra
.95 .63987 .92633 .4427 .92806 .44219 .95184 .63937 Mtetra
.95184 .63937 .92806 .44219 .92979 .44168 .95368 .63888 Mtetra
.95368 .63888 .92979 .44168 .93152 .4412 .95553 .63843 Mtetra
.95553 .63843 .93152 .4412 .93326 .44073 .95738 .63801 Mtetra
.95738 .63801 .93326 .44073 .935 .4403 .95925 .63765 Mtetra
.95925 .63765 .935 .4403 .93675 .4399 .96111 .63732 Mtetra
.96111 .63732 .93675 .4399 .93851 .43958 .963 .63709 Mtetra
.573 .364 .56 r
.963 .63709 .93851 .43958 .94033 .4397 .96497 .63758 Mtetra
.572 .364 .56 r
.96497 .63758 .94033 .4397 .94211 .43951 .96686 .63736 Mtetra
.57 .363 .56 r
.96686 .63736 .94211 .43951 .94378 .43847 .96856 .63568 Mtetra
.214 .114 .518 r
.96856 .63568 .94378 .43847 .94524 .43575 .94595 .44535 Mtetra
.119 .007 .439 r
.94595 .44535 .94524 .43575 .94676 .43356 .94633 .43423 Mtetra
.802 .859 .409 r
.94633 .43423 .94676 .43356 .94836 .43194 .9477 .43092 Mtetra
.731 .758 .875 r
.9477 .43092 .94836 .43194 .95008 .43128 .9494 .43005 Mtetra
.64 .677 .87 r
.9494 .43005 .95008 .43128 .95183 .43084 .95115 .42964 Mtetra
.595 .662 .885 r
.95115 .42964 .95183 .43084 .95359 .43048 .95294 .42944 Mtetra
.677 .733 .893 r
.95294 .42944 .95359 .43048 .95532 .42987 .95467 .42885 Mtetra
.682 .738 .893 r
.95467 .42885 .95532 .42987 .95705 .42924 .95641 .42824 Mtetra
.688 .745 .894 r
.95641 .42824 .95705 .42924 .95878 .42857 .95814 .42759 Mtetra
.772 .779 .859 r
.95814 .42759 .95878 .42857 .96044 .42743 .9598 .42645 Mtetra
.708 .758 .891 r
.9598 .42645 .96044 .42743 .96216 .42668 .96152 .42571 Mtetra
.54 .683 .931 r
.96152 .42571 .96216 .42668 .96397 .42663 .96333 .42566 Mtetra
.931 .562 .284 r
.39482 .59618 .39568 .59697 .39694 .60112 .39608 .60038 Mtetra
.937 .682 .526 r
.39608 .60038 .39694 .60112 .39141 .78899 .3905 .78834 Mtetra
.929 .575 .332 r
.3905 .78834 .39141 .78899 .39273 .79395 .39182 .79325 Mtetra
0 .446 .86 r
.39182 .79325 .39273 .79395 .39421 .79446 .39329 .79389 Mtetra
.648 .809 .96 r
.39329 .79389 .39421 .79446 .39573 .79398 .39481 .79345 Mtetra
.835 .819 .834 r
.39481 .79345 .39573 .79398 .39727 .79264 .39637 .79194 Mtetra
.914 .737 .649 r
.39637 .79194 .39727 .79264 .3989 .7892 .39807 .78625 Mtetra
.934 .683 .535 r
.39807 .78625 .3989 .7892 .4008 .77771 .40613 .59735 Mtetra
.582 .376 .566 r
.40613 .59735 .4008 .77771 .40843 .59752 .40773 .59227 Mtetra
.653 .486 .645 r
.40773 .59227 .40843 .59752 .40992 .59549 .4092 .59085 Mtetra
.61 .463 .657 r
.4092 .59085 .40992 .59549 .41136 .59507 .41064 .5904 Mtetra
.547 .418 .657 r
.41064 .5904 .41136 .59507 .41275 .5962 .41205 .59086 Mtetra
.194 .156 .584 r
.41205 .59086 .41275 .5962 .40833 .77683 .41335 .5946 Mtetra
0 0 .336 r
.41335 .5946 .40833 .77683 .40951 .78689 .40872 .78263 Mtetra
0 0 .345 r
.40872 .78263 .40951 .78689 .41093 .78959 .41005 .78815 Mtetra
.417 .524 .859 r
.41005 .78815 .41093 .78959 .41244 .78992 .41155 .78864 Mtetra
.651 .657 .843 r
.41155 .78864 .41244 .78992 .41396 .78965 .41308 .78823 Mtetra
.704 .658 .802 r
.41308 .78823 .41396 .78965 .41549 .78908 .41462 .78742 Mtetra
.646 .608 .798 r
.41462 .78742 .41549 .78908 .41702 .78856 .41614 .78698 Mtetra
.641 .616 .809 r
.41614 .78698 .41702 .78856 .41855 .788 .41767 .7866 Mtetra
.645 .639 .829 r
.41767 .7866 .41855 .788 .42009 .78742 .4192 .7862 Mtetra
.646 .666 .854 r
.4192 .7862 .42009 .78742 .42161 .78713 .42073 .78581 Mtetra
.648 .652 .84 r
.42073 .78581 .42161 .78713 .42314 .78678 .42226 .78541 Mtetra
.651 .645 .831 r
.42226 .78541 .42314 .78678 .42468 .7862 .42379 .78498 Mtetra
.668 .673 .846 r
.42379 .78498 .42468 .7862 .42624 .7846 .42533 .78447 Mtetra
.586 .911 .977 r
.42533 .78447 .42624 .7846 .42783 .78224 .42686 .78393 Mtetra
.39 .019 .21 r
.42686 .78393 .42783 .78224 .42943 .77903 .4284 .7834 Mtetra
.553 .277 .45 r
.4284 .7834 .42943 .77903 .43097 .77832 .42993 .78339 Mtetra
.543 .277 .461 r
.42993 .78339 .43097 .77832 .4325 .77833 .43146 .78317 Mtetra
.492 .227 .441 r
.43146 .78317 .4325 .77833 .43404 .77745 .43301 .7823 Mtetra
0 0 .238 r
.43301 .7823 .43404 .77745 .44007 .59591 .43465 .77778 Mtetra
0 0 .336 r
.43465 .77778 .44007 .59591 .44177 .58569 .44084 .58859 Mtetra
.884 .832 .364 r
.44084 .58859 .44177 .58569 .44329 .58243 .44244 .58232 Mtetra
.865 .92 .864 r
.44244 .58232 .44329 .58243 .44477 .58131 .44392 .58087 Mtetra
.637 .839 .978 r
.44392 .58087 .44477 .58131 .44622 .58088 .44537 .58044 Mtetra
.419 .765 .996 r
.44537 .58044 .44622 .58088 .44767 .58072 .44682 .58039 Mtetra
.561 .852 .997 r
.44682 .58039 .44767 .58072 .44913 .5805 .44828 .58006 Mtetra
.636 .84 .979 r
.44828 .58006 .44913 .5805 .45058 .58025 .44974 .57963 Mtetra
.654 .791 .948 r
.44974 .57963 .45058 .58025 .45204 .57997 .4512 .5792 Mtetra
.657 .752 .92 r
.4512 .5792 .45204 .57997 .4535 .57949 .45266 .57878 Mtetra
.655 .765 .93 r
.45266 .57878 .4535 .57949 .45496 .57893 .45412 .57836 Mtetra
.648 .805 .958 r
.45412 .57836 .45496 .57893 .45643 .57834 .45558 .57794 Mtetra
.641 .851 .98 r
.45558 .57794 .45643 .57834 .45789 .57771 .45705 .57748 Mtetra
.6 .891 .99 r
.45705 .57748 .45789 .57771 .45936 .57718 .45851 .57701 Mtetra
.562 .896 .983 r
.45851 .57701 .45936 .57718 .46082 .57688 .45998 .57656 Mtetra
.577 .863 .996 r
.45998 .57656 .46082 .57688 .46227 .5774 .46144 .57619 Mtetra
.639 .656 .85 r
.46144 .57619 .46227 .5774 .4637 .57869 .4629 .57585 Mtetra
.617 .511 .711 r
.4629 .57585 .4637 .57869 .46513 .58083 .46437 .57551 Mtetra
.622 .463 .646 r
.46437 .57551 .46513 .58083 .46658 .58111 .46584 .57475 Mtetra
.611 .445 .633 r
.46584 .57475 .46658 .58111 .46806 .58024 .46732 .57407 Mtetra
.586 .429 .636 r
.46732 .57407 .46806 .58024 .46953 .58011 .46878 .57395 Mtetra
.392 .29 .618 r
.46878 .57395 .46953 .58011 .46817 .7583 .4702 .57664 Mtetra
0 0 .366 r
.4702 .57664 .46817 .7583 .46953 .77051 .46873 .76445 Mtetra
0 0 .406 r
.46873 .76445 .46953 .77051 .47103 .7734 .47017 .77163 Mtetra
.249 .38 .8 r
.47017 .77163 .47103 .7734 .47257 .77406 .4717 .77277 Mtetra
.621 .647 .854 r
.4717 .77277 .47257 .77406 .47413 .77377 .47326 .77249 Mtetra
.701 .679 .826 r
.47326 .77249 .47413 .77377 .4757 .77297 .47483 .77176 Mtetra
.691 .686 .84 r
.47483 .77176 .4757 .77297 .47727 .77146 .47639 .7711 Mtetra
.66 .877 .979 r
.47639 .7711 .47727 .77146 .47886 .76922 .47796 .77053 Mtetra
.309 0 .092 r
.47796 .77053 .47886 .76922 .48046 .76614 .47952 .76994 Mtetra
.537 .251 .428 r
.47952 .76994 .48046 .76614 .48203 .76468 .48108 .76979 Mtetra
.546 .28 .462 r
.48108 .76979 .48203 .76468 .48359 .76465 .48264 .76961 Mtetra
.505 .241 .447 r
.48264 .76961 .48359 .76465 .48515 .76393 .48421 .76886 Mtetra
.203 0 .34 r
.48421 .76886 .48515 .76393 .48687 .7488 .48582 .76536 Mtetra
.971 .714 .487 r
.48582 .76536 .48687 .7488 .49024 .5717 .48935 .57694 Mtetra
0 0 0 r
.48935 .57694 .49024 .5717 .49175 .56804 .49092 .56822 Mtetra
.925 .949 .789 r
.49092 .56822 .49175 .56804 .49324 .5665 .49241 .56616 Mtetra
.692 .883 .969 r
.49241 .56616 .49324 .5665 .49473 .5659 .4939 .56553 Mtetra
.482 .814 1 r
.4939 .56553 .49473 .5659 .49621 .56576 .49538 .56534 Mtetra
.526 .814 .998 r
.49538 .56534 .49621 .56576 .49768 .56623 .49686 .56511 Mtetra
.634 .672 .868 r
.49686 .56511 .49768 .56623 .49916 .56736 .49835 .5648 Mtetra
.615 .523 .726 r
.49835 .5648 .49916 .56736 .50063 .56922 .49983 .5645 Mtetra
.62 .469 .656 r
.49983 .5645 .50063 .56922 .50211 .56992 .50132 .56386 Mtetra
.613 .449 .637 r
.50132 .56386 .50211 .56992 .5036 .56915 .50281 .56317 Mtetra
.59 .434 .638 r
.50281 .56317 .5036 .56915 .50509 .56891 .5043 .56298 Mtetra
.446 .332 .63 r
.5043 .56298 .50509 .56891 .50654 .57684 .50578 .56501 Mtetra
.967 .702 .478 r
.50578 .56501 .50654 .57684 .50712 .75961 .5063 .7505 Mtetra
0 0 .402 r
.5063 .7505 .50712 .75961 .50868 .76305 .50782 .76108 Mtetra
.132 .282 .751 r
.50782 .76108 .50868 .76305 .51026 .76399 .50939 .76268 Mtetra
.608 .641 .857 r
.50939 .76268 .51026 .76399 .51184 .76383 .51097 .76247 Mtetra
.693 .666 .819 r
.51097 .76247 .51184 .76383 .51342 .76335 .51256 .76175 Mtetra
.675 .632 .799 r
.51256 .76175 .51342 .76335 .515 .76288 .51414 .76111 Mtetra
.643 .601 .792 r
.51414 .76111 .515 .76288 .51659 .76248 .51573 .76067 Mtetra
.643 .597 .788 r
.51573 .76067 .51659 .76248 .51817 .76203 .51731 .76023 Mtetra
.638 .595 .79 r
.51731 .76023 .51817 .76203 .51976 .7616 .5189 .75983 Mtetra
.634 .596 .794 r
.5189 .75983 .51976 .7616 .52135 .76114 .52048 .75946 Mtetra
.638 .607 .803 r
.52048 .75946 .52135 .76114 .52293 .76048 .52207 .75907 Mtetra
.656 .647 .829 r
.52207 .75907 .52293 .76048 .52452 .7592 .52366 .7586 Mtetra
.676 .816 .95 r
.52366 .7586 .52452 .7592 .52611 .75707 .52525 .75804 Mtetra
.223 0 0 r
.52525 .75804 .52611 .75707 .5277 .75423 .52684 .75748 Mtetra
.494 .198 .391 r
.52684 .75748 .5277 .75423 .52929 .75177 .52843 .75699 Mtetra
.532 .268 .46 r
.52843 .75699 .52929 .75177 .53087 .75106 .53003 .75657 Mtetra
.536 .275 .466 r
.53003 .75657 .53087 .75106 .53247 .75109 .53162 .75619 Mtetra
.532 .266 .458 r
.53162 .75619 .53247 .75109 .53406 .75102 .53321 .75579 Mtetra
.528 .258 .45 r
.53321 .75579 .53406 .75102 .53565 .75063 .53481 .75538 Mtetra
.527 .257 .449 r
.53481 .75538 .53565 .75063 .53724 .75025 .53641 .75496 Mtetra
.527 .256 .448 r
.53641 .75496 .53724 .75025 .53884 .74984 .538 .75454 Mtetra
.526 .256 .448 r
.538 .75454 .53884 .74984 .54043 .74942 .5396 .75412 Mtetra
.5396 .75412 .54043 .74942 .54203 .749 .5412 .75369 Mtetra
.526 .255 .448 r
.5412 .75369 .54203 .749 .54362 .74856 .5428 .75326 Mtetra
.5428 .75326 .54362 .74856 .54522 .74812 .5444 .75283 Mtetra
.526 .256 .448 r
.5444 .75283 .54522 .74812 .54682 .74768 .546 .7524 Mtetra
.546 .7524 .54682 .74768 .54842 .74723 .5476 .75196 Mtetra
.5476 .75196 .54842 .74723 .55002 .74679 .54921 .75152 Mtetra
.54921 .75152 .55002 .74679 .55162 .74634 .55081 .75109 Mtetra
.526 .257 .449 r
.55081 .75109 .55162 .74634 .55322 .74591 .55242 .75066 Mtetra
.527 .257 .449 r
.55242 .75066 .55322 .74591 .55483 .74549 .55402 .75023 Mtetra
.55402 .75023 .55483 .74549 .55643 .74506 .55563 .7498 Mtetra
.541 .269 .453 r
.55563 .7498 .55643 .74506 .55804 .74505 .55724 .74958 Mtetra
.549 .273 .45 r
.55724 .74958 .55804 .74505 .55965 .7453 .55885 .7495 Mtetra
.507 .231 .43 r
.55885 .7495 .55965 .7453 .56126 .74462 .56046 .74892 Mtetra
.328 .078 .374 r
.56046 .74892 .56126 .74462 .56282 .73994 .56205 .7466 Mtetra
0 0 0 r
.56205 .7466 .56282 .73994 .56235 .552 .56355 .73514 Mtetra
0 0 .403 r
.56355 .73514 .56235 .552 .56382 .54716 .56304 .54774 Mtetra
.964 .941 .664 r
.56304 .54774 .56382 .54716 .56532 .5451 .56453 .54466 Mtetra
.732 .867 .944 r
.56453 .54466 .56532 .5451 .56684 .54444 .56605 .5439 Mtetra
.56 .794 .987 r
.56605 .5439 .56684 .54444 .56837 .54414 .56757 .54366 Mtetra
.503 .792 .997 r
.56757 .54366 .56837 .54414 .56989 .54388 .5691 .5435 Mtetra
.619 .861 .989 r
.5691 .5435 .56989 .54388 .57142 .54343 .57063 .54305 Mtetra
.614 .862 .99 r
.57063 .54305 .57142 .54343 .57294 .54297 .57215 .54261 Mtetra
.613 .865 .991 r
.57215 .54261 .57294 .54297 .57447 .54252 .57368 .54216 Mtetra
.615 .869 .99 r
.57368 .54216 .57447 .54252 .576 .54206 .57521 .5417 Mtetra
.615 .87 .99 r
.57521 .5417 .576 .54206 .57752 .54159 .57674 .54124 Mtetra
.614 .871 .99 r
.57674 .54124 .57752 .54159 .57905 .54113 .57827 .54078 Mtetra
.613 .871 .991 r
.57827 .54078 .57905 .54113 .58058 .54067 .5798 .54032 Mtetra
.611 .871 .991 r
.5798 .54032 .58058 .54067 .58211 .54021 .58133 .53987 Mtetra
.605 .871 .992 r
.58133 .53987 .58211 .54021 .58364 .53975 .58286 .53942 Mtetra
.595 .871 .993 r
.58286 .53942 .58364 .53975 .58518 .53929 .58439 .53899 Mtetra
.588 .877 .993 r
.58439 .53899 .58518 .53929 .58671 .53885 .58593 .53855 Mtetra
.595 .881 .992 r
.58593 .53855 .58671 .53885 .58824 .53846 .58746 .53809 Mtetra
.629 .871 .987 r
.58746 .53809 .58824 .53846 .58978 .53816 .589 .5376 Mtetra
.66 .821 .961 r
.589 .5376 .58978 .53816 .59132 .53785 .59053 .53711 Mtetra
.668 .771 .927 r
.59053 .53711 .59132 .53785 .59286 .53745 .59207 .53662 Mtetra
.665 .749 .913 r
.59207 .53662 .59286 .53745 .59439 .53687 .59361 .53615 Mtetra
.662 .777 .935 r
.59361 .53615 .59439 .53687 .59593 .53625 .59515 .53568 Mtetra
.653 .818 .963 r
.59515 .53568 .59593 .53625 .59746 .53565 .59669 .53521 Mtetra
.64 .852 .981 r
.59669 .53521 .59746 .53565 .599 .53514 .59823 .53473 Mtetra
.637 .861 .984 r
.59823 .53473 .599 .53514 .60054 .53465 .59977 .53424 Mtetra
.641 .862 .983 r
.59977 .53424 .60054 .53465 .60208 .53413 .60131 .53374 Mtetra
.644 .871 .983 r
.60131 .53374 .60208 .53413 .60362 .5335 .60285 .53323 Mtetra
.608 .894 .989 r
.60285 .53323 .60362 .5335 .60516 .53302 .60439 .53272 Mtetra
.598 .883 .992 r
.60439 .53272 .60516 .53302 .60672 .53294 .60594 .53225 Mtetra
.637 .779 .949 r
.60594 .53225 .60672 .53294 .6083 .5338 .60749 .53186 Mtetra
.632 .574 .771 r
.60749 .53186 .6083 .5338 .60989 .53531 .60904 .53148 Mtetra
.618 .485 .678 r
.60904 .53148 .60989 .53531 .6115 .53703 .61058 .53099 Mtetra
.619 .455 .637 r
.61058 .53099 .6115 .53703 .61304 .53628 .61212 .53013 Mtetra
.602 .442 .637 r
.61212 .53013 .61304 .53628 .61459 .53568 .61367 .52966 Mtetra
.548 .405 .639 r
.61367 .52966 .61459 .53568 .6162 .53736 .61525 .53027 Mtetra
.127 .097 .551 r
.61525 .53027 .6162 .53736 .62299 .72649 .61698 .53659 Mtetra
.038 0 .436 r
.61698 .53659 .62299 .72649 .62478 .73134 .6239 .72824 Mtetra
0 .061 .596 r
.6239 .72824 .62478 .73134 .62648 .73279 .62566 .73177 Mtetra
.394 .602 .931 r
.62566 .73177 .62648 .73279 .62812 .73174 .62733 .73213 Mtetra
0 0 0 r
.62733 .73213 .62812 .73174 .62971 .72949 .62897 .73149 Mtetra
.079 0 .118 r
.62897 .73149 .62971 .72949 .63123 .72479 .63058 .7296 Mtetra
0 0 .186 r
.63058 .7296 .63123 .72479 .62715 .53594 .63206 .72327 Mtetra
.026 0 .426 r
.63206 .72327 .62715 .53594 .62851 .52914 .6278 .53035 Mtetra
.957 .889 .5 r
.6278 .53035 .62851 .52914 .63 .52651 .62923 .52567 Mtetra
.76 .773 .863 r
.62923 .52567 .63 .52651 .63155 .5257 .63077 .5247 Mtetra
.635 .701 .893 r
.63077 .5247 .63155 .5257 .63311 .52531 .63233 .52435 Mtetra
.581 .69 .916 r
.63233 .52435 .63311 .52531 .63467 .52498 .6339 .5242 Mtetra
.76 .786 .875 r
.6339 .5242 .63467 .52498 .63621 .52387 .63545 .52325 Mtetra
.68 .811 .945 r
.63545 .52325 .63621 .52387 .63777 .52318 .63701 .52269 Mtetra
.165 .607 .936 r
.63701 .52269 .63777 .52318 .63935 .52342 .6386 .52302 Mtetra
.925 .543 .251 r
.6386 .52302 .63935 .52342 .64112 .5287 .64036 .52828 Mtetra
.964 .684 .455 r
.64036 .52828 .64112 .5287 .6495 .72213 .64867 .72079 Mtetra
.814 .403 0 r
.64867 .72079 .6495 .72213 .65132 .7262 .65049 .72487 Mtetra
.531 .608 .875 r
.65049 .72487 .65132 .7262 .653 .72614 .65217 .72497 Mtetra
.678 .699 .862 r
.65217 .72497 .653 .72614 .65465 .72537 .65383 .72438 Mtetra
.737 .75 .863 r
.65383 .72438 .65465 .72537 .65629 .7243 .65548 .72347 Mtetra
.643 .758 .932 r
.65548 .72347 .65629 .7243 .65797 .72414 .65715 .72304 Mtetra
.652 .702 .883 r
.65715 .72304 .65797 .72414 .65964 .72387 .65882 .72259 Mtetra
.654 .672 .855 r
.65882 .72259 .65964 .72387 .66131 .72329 .66049 .72213 Mtetra
.578 .66 .893 r
.66049 .72213 .66131 .72329 .66294 .72185 .66217 .72201 Mtetra
.276 .776 .753 r
.66217 .72201 .66294 .72185 .66453 .71951 .66384 .7215 Mtetra
.255 0 .199 r
.66384 .7215 .66453 .71951 .66604 .71491 .66547 .72018 Mtetra
0 0 .248 r
.66547 .72018 .66604 .71491 .66003 .52429 .6669 .71367 Mtetra
.053 0 .44 r
.6669 .71367 .66003 .52429 .66138 .5184 .66073 .52021 Mtetra
.812 .807 .318 r
.66073 .52021 .66138 .5184 .66287 .51575 .66213 .5154 Mtetra
.781 .908 .929 r
.66213 .5154 .66287 .51575 .66443 .51492 .66368 .5144 Mtetra
.6 .823 .985 r
.66368 .5144 .66443 .51492 .66601 .51452 .66527 .51404 Mtetra
.423 .758 .995 r
.66527 .51404 .66601 .51452 .6676 .51438 .66686 .514 Mtetra
.616 .87 .99 r
.66686 .514 .6676 .51438 .66919 .51406 .66844 .51352 Mtetra
.649 .83 .97 r
.66844 .51352 .66919 .51406 .67077 .51375 .67002 .51304 Mtetra
.663 .784 .939 r
.67002 .51304 .67077 .51375 .67236 .51339 .6716 .51254 Mtetra
.674 .754 .911 r
.6716 .51254 .67236 .51339 .67393 .51263 .67318 .51202 Mtetra
.662 .813 .956 r
.67318 .51202 .67393 .51263 .6755 .51196 .67477 .51151 Mtetra
.627 .854 .985 r
.67477 .51151 .6755 .51196 .67709 .51153 .67635 .51104 Mtetra
.729 .864 .945 r
.67635 .51104 .67709 .51153 .67871 .51187 .67792 .51027 Mtetra
.648 .617 .805 r
.67792 .51027 .67871 .51187 .68037 .51297 .67951 .50982 Mtetra
.561 .47 .708 r
.67951 .50982 .68037 .51297 .68211 .51583 .68113 .51002 Mtetra
.245 .199 .606 r
.68113 .51002 .68211 .51583 .69274 .70534 .68294 .5144 Mtetra
.074 0 .457 r
.68294 .5144 .69274 .70534 .69476 .71187 .69381 .70777 Mtetra
0 .034 .562 r
.69381 .70777 .69476 .71187 .69658 .71406 .69576 .71263 Mtetra
.339 .488 .861 r
.69576 .71263 .69658 .71406 .69831 .71445 .69751 .71341 Mtetra
.628 .708 .903 r
.69751 .71341 .69831 .71445 .7 .71407 .6992 .71306 Mtetra
.788 .76 .828 r
.6992 .71306 .7 .71407 .70167 .71302 .70085 .71172 Mtetra
.904 .734 .661 r
.70085 .71172 .70167 .71302 .70325 .71039 .70234 .70723 Mtetra
.966 .687 .452 r
.70234 .70723 .70325 .71039 .70469 .70493 .69425 .51399 Mtetra
.585 .377 .565 r
.69425 .51399 .70469 .70493 .69657 .51391 .69549 .50644 Mtetra
.633 .455 .623 r
.69549 .50644 .69657 .51391 .69794 .50887 .69703 .50491 Mtetra
.621 .485 .676 r
.69703 .50491 .69794 .50887 .69944 .5066 .69862 .50435 Mtetra
.602 .538 .755 r
.69862 .50435 .69944 .5066 .70099 .50518 .70024 .50418 Mtetra
.657 .714 .89 r
.70024 .50418 .70099 .50518 .70257 .50442 .70184 .50373 Mtetra
.658 .793 .946 r
.70184 .50373 .70257 .50442 .70417 .50394 .70343 .50324 Mtetra
.657 .789 .945 r
.70343 .50324 .70417 .50394 .70578 .50361 .70503 .50276 Mtetra
.756 .779 .872 r
.70503 .50276 .70578 .50361 .70735 .50268 .70661 .50181 Mtetra
.714 .761 .889 r
.70661 .50181 .70735 .50268 .70894 .50197 .7082 .50108 Mtetra
.552 .699 .938 r
.7082 .50108 .70894 .50197 .71057 .50188 .70982 .50099 Mtetra
.801 .355 0 r
.70982 .50099 .71057 .50188 .71239 .50526 .71164 .50435 Mtetra
.97 .683 .426 r
.71164 .50435 .71239 .50526 .72503 .69897 .72425 .69809 Mtetra
.921 .531 .151 r
.72425 .69809 .72503 .69897 .72711 .70505 .72633 .70419 Mtetra
0 .354 .82 r
.72633 .70419 .72711 .70505 .7289 .70612 .72812 .70527 Mtetra
.593 .74 .946 r
.72812 .70527 .7289 .70612 .73063 .70585 .72985 .70501 Mtetra
.793 .798 .856 r
.72985 .70501 .73063 .70585 .73229 .70458 .73151 .70374 Mtetra
.933 .778 .666 r
.73151 .70374 .73229 .70458 .73377 .70029 .733 .69946 Mtetra
.971 .689 .436 r
.733 .69946 .73377 .70029 .72391 .50632 .72318 .50546 Mtetra
.958 .744 .572 r
.72318 .50546 .72391 .50632 .72508 .49844 .72435 .49755 Mtetra
.832 .784 .807 r
.72435 .49755 .72508 .49844 .72662 .4968 .72589 .49592 Mtetra
.651 .742 .917 r
.72589 .49592 .72662 .4968 .72824 .49635 .7275 .49548 Mtetra
.516 .69 .946 r
.7275 .49548 .72824 .49635 .72988 .49633 .72915 .49548 Mtetra
.63 .74 .927 r
.72915 .49548 .72988 .49633 .73149 .49585 .73077 .49512 Mtetra
.665 .785 .938 r
.73077 .49512 .73149 .49585 .7331 .49529 .73238 .49461 Mtetra
.658 .8 .951 r
.73238 .49461 .7331 .49529 .73473 .49493 .734 .49412 Mtetra
.728 .782 .895 r
.734 .49412 .73473 .49493 .73639 .49513 .7356 .49333 Mtetra
.664 .607 .781 r
.7356 .49333 .73639 .49513 .7381 .49605 .73721 .49272 Mtetra
.583 .478 .7 r
.73721 .49272 .7381 .49605 .73991 .49851 .73886 .4927 Mtetra
.376 .292 .633 r
.73886 .4927 .73991 .49851 .75387 .68716 .74071 .49582 Mtetra
.105 .026 .474 r
.74071 .49582 .75387 .68716 .75614 .69499 .75505 .6893 Mtetra
.043 .068 .56 r
.75505 .6893 .75614 .69499 .75805 .69743 .75722 .6956 Mtetra
.37 .452 .815 r
.75722 .6956 .75805 .69743 .75983 .69781 .75904 .69656 Mtetra
.634 .674 .871 r
.75904 .69656 .75983 .69781 .76156 .69735 .76078 .69619 Mtetra
.712 .718 .854 r
.76078 .69619 .76156 .69735 .76327 .6966 .76248 .69537 Mtetra
.675 .695 .861 r
.76248 .69537 .76327 .6966 .765 .69614 .7642 .69477 Mtetra
.65 .662 .848 r
.7642 .69477 .765 .69614 .76674 .69576 .76593 .69431 Mtetra
.654 .652 .836 r
.76593 .69431 .76674 .69576 .76846 .69515 .76767 .69381 Mtetra
.666 .674 .848 r
.76767 .69381 .76846 .69515 .77013 .69367 .76939 .69325 Mtetra
.64 .881 .985 r
.76939 .69325 .77013 .69367 .77173 .69132 .77112 .69266 Mtetra
.345 0 .128 r
.77112 .69266 .77173 .69132 .77327 .68816 .77285 .69208 Mtetra
.513 .23 .422 r
.77285 .69208 .77327 .68816 .77488 .68596 .77458 .69159 Mtetra
.536 .275 .466 r
.77458 .69159 .77488 .68596 .77661 .68543 .77632 .69116 Mtetra
.538 .277 .468 r
.77632 .69116 .77661 .68543 .77839 .68559 .77806 .69076 Mtetra
.533 .267 .458 r
.77806 .69076 .77839 .68559 .78015 .68544 .77981 .69034 Mtetra
.529 .26 .451 r
.77981 .69034 .78015 .68544 .78189 .68505 .78155 .6899 Mtetra
.528 .259 .45 r
.78155 .6899 .78189 .68505 .78364 .68467 .78329 .68946 Mtetra
.527 .257 .449 r
.78329 .68946 .78364 .68467 .78538 .68426 .78504 .68901 Mtetra
.527 .256 .448 r
.78504 .68901 .78538 .68426 .78712 .68384 .78678 .68856 Mtetra
.526 .255 .447 r
.78678 .68856 .78712 .68384 .78887 .6834 .78853 .68811 Mtetra
.526 .255 .446 r
.78853 .68811 .78887 .6834 .79061 .68296 .79028 .68765 Mtetra
.526 .254 .446 r
.79028 .68765 .79061 .68296 .79236 .68251 .79203 .68719 Mtetra
.525 .254 .446 r
.79203 .68719 .79236 .68251 .7941 .68206 .79378 .68673 Mtetra
.525 .254 .445 r
.79378 .68673 .7941 .68206 .79585 .6816 .79553 .68627 Mtetra
.525 .253 .445 r
.79553 .68627 .79585 .6816 .7976 .68114 .79728 .6858 Mtetra
.79728 .6858 .7976 .68114 .79935 .68068 .79903 .68534 Mtetra
.79903 .68534 .79935 .68068 .8011 .68022 .80078 .68487 Mtetra
.80078 .68487 .8011 .68022 .80285 .67975 .80254 .68441 Mtetra
.80254 .68441 .80285 .67975 .8046 .67928 .80429 .68394 Mtetra
.80429 .68394 .8046 .67928 .80635 .67881 .80605 .68347 Mtetra
.80605 .68347 .80635 .67881 .8081 .67834 .8078 .683 Mtetra
.8078 .683 .8081 .67834 .80986 .67786 .80956 .68253 Mtetra
.80956 .68253 .80986 .67786 .81161 .67739 .81132 .68206 Mtetra
.81132 .68206 .81161 .67739 .81337 .67692 .81308 .68159 Mtetra
.81308 .68159 .81337 .67692 .81513 .67644 .81484 .68112 Mtetra
.81484 .68112 .81513 .67644 .81688 .67597 .8166 .68065 Mtetra
.8166 .68065 .81688 .67597 .81864 .6755 .81837 .68018 Mtetra
.525 .254 .446 r
.81837 .68018 .81864 .6755 .8204 .67502 .82013 .67971 Mtetra
.82013 .67971 .8204 .67502 .82217 .67455 .8219 .67924 Mtetra
.8219 .67924 .82217 .67455 .82393 .67408 .82366 .67877 Mtetra
.82366 .67877 .82393 .67408 .82569 .6736 .82543 .6783 Mtetra
.82543 .6783 .82569 .6736 .82746 .67313 .8272 .67783 Mtetra
.8272 .67783 .82746 .67313 .82922 .67266 .82897 .67736 Mtetra
.82897 .67736 .82922 .67266 .83099 .67219 .83074 .67689 Mtetra
.83074 .67689 .83099 .67219 .83276 .67172 .83252 .67642 Mtetra
.83252 .67642 .83276 .67172 .83453 .67125 .83429 .67595 Mtetra
.83429 .67595 .83453 .67125 .8363 .67078 .83606 .67548 Mtetra
.83606 .67548 .8363 .67078 .83807 .67031 .83784 .67501 Mtetra
.83784 .67501 .83807 .67031 .83985 .66984 .83962 .67454 Mtetra
.83962 .67454 .83985 .66984 .84162 .66937 .84139 .67407 Mtetra
.84139 .67407 .84162 .66937 .8434 .6689 .84317 .6736 Mtetra
.84317 .6736 .8434 .6689 .84517 .66843 .84495 .67312 Mtetra
.84495 .67312 .84517 .66843 .84695 .66796 .84673 .67265 Mtetra
.84673 .67265 .84695 .66796 .84873 .66749 .84852 .67218 Mtetra
.525 .254 .445 r
.84852 .67218 .84873 .66749 .85051 .66703 .8503 .67171 Mtetra
.8503 .67171 .85051 .66703 .85229 .66656 .85208 .67124 Mtetra
.85208 .67124 .85229 .66656 .85407 .66609 .85387 .67077 Mtetra
.85387 .67077 .85407 .66609 .85585 .66562 .85566 .6703 Mtetra
.525 .253 .445 r
.85566 .6703 .85585 .66562 .85764 .66515 .85744 .66983 Mtetra
.85744 .66983 .85764 .66515 .85942 .66467 .85923 .66935 Mtetra
.85923 .66935 .85942 .66467 .86121 .6642 .86102 .66888 Mtetra
.86102 .66888 .86121 .6642 .863 .66373 .86281 .6684 Mtetra
.86281 .6684 .863 .66373 .86479 .66325 .86461 .66793 Mtetra
.86461 .66793 .86479 .66325 .86657 .66277 .8664 .66745 Mtetra
.8664 .66745 .86657 .66277 .86836 .66229 .86819 .66698 Mtetra
.86819 .66698 .86836 .66229 .87016 .66181 .86999 .6665 Mtetra
.86999 .6665 .87016 .66181 .87195 .66133 .87178 .66602 Mtetra
.87178 .66602 .87195 .66133 .87374 .66084 .87358 .66554 Mtetra
.87358 .66554 .87374 .66084 .87553 .66036 .87538 .66506 Mtetra
.525 .253 .446 r
.87538 .66506 .87553 .66036 .87733 .65986 .87718 .66457 Mtetra
.525 .254 .446 r
.87718 .66457 .87733 .65986 .87912 .65937 .87898 .66409 Mtetra
.87898 .66409 .87912 .65937 .88092 .65886 .88078 .6636 Mtetra
.88078 .6636 .88092 .65886 .88271 .65836 .88258 .66311 Mtetra
.525 .254 .447 r
.88258 .66311 .88271 .65836 .88451 .65784 .88438 .66262 Mtetra
.88438 .66262 .88451 .65784 .88631 .65732 .88619 .66212 Mtetra
.525 .255 .448 r
.88619 .66212 .88631 .65732 .88811 .65679 .88799 .66161 Mtetra
.88799 .66161 .88811 .65679 .8899 .65625 .88979 .66111 Mtetra
.525 .256 .449 r
.88979 .66111 .8899 .65625 .8917 .6557 .8916 .6606 Mtetra
.525 .257 .45 r
.8916 .6606 .8917 .6557 .8935 .65513 .89341 .66008 Mtetra
.526 .258 .451 r
.89341 .66008 .8935 .65513 .89529 .65455 .89521 .65957 Mtetra
.526 .259 .453 r
.89521 .65957 .89529 .65455 .89709 .65398 .89702 .65905 Mtetra
.527 .261 .454 r
.89702 .65905 .89709 .65398 .89889 .65343 .89883 .65854 Mtetra
.528 .261 .455 r
.89883 .65854 .89889 .65343 .90069 .65289 .90064 .65803 Mtetra
.528 .262 .456 r
.90064 .65803 .90069 .65289 .9025 .65236 .90245 .65753 Mtetra
.529 .263 .456 r
.90245 .65753 .9025 .65236 .90431 .65183 .90427 .65703 Mtetra
.529 .264 .457 r
.90427 .65703 .90431 .65183 .90612 .65132 .90608 .65653 Mtetra
.53 .264 .457 r
.90608 .65653 .90612 .65132 .90793 .65082 .9079 .65604 Mtetra
.53 .265 .457 r
.9079 .65604 .90793 .65082 .90974 .65032 .90972 .65555 Mtetra
.53 .265 .458 r
.90972 .65555 .90974 .65032 .91156 .64984 .91154 .65507 Mtetra
.531 .265 .458 r
.91154 .65507 .91156 .64984 .91338 .64936 .91336 .65459 Mtetra
.91336 .65459 .91338 .64936 .9152 .64889 .91519 .65411 Mtetra
.531 .265 .457 r
.91519 .65411 .9152 .64889 .91702 .64843 .91701 .65364 Mtetra
.91701 .65364 .91702 .64843 .91885 .64799 .91884 .65317 Mtetra
.91884 .65317 .91885 .64799 .92067 .64755 .92067 .65271 Mtetra
.531 .265 .456 r
.92067 .65271 .92067 .64755 .9225 .64711 .9225 .65225 Mtetra
.531 .264 .456 r
.9225 .65225 .9225 .64711 .92434 .64669 .92433 .65179 Mtetra
.531 .264 .455 r
.92433 .65179 .92434 .64669 .92617 .64629 .92616 .65133 Mtetra
.53 .263 .454 r
.92616 .65133 .92617 .64629 .92801 .64588 .928 .65088 Mtetra
.53 .261 .453 r
.928 .65088 .92801 .64588 .92984 .64546 .92983 .65042 Mtetra
.529 .26 .452 r
.92983 .65042 .92984 .64546 .93168 .64501 .93167 .64995 Mtetra
.528 .259 .451 r
.93167 .64995 .93168 .64501 .93351 .64455 .9335 .64947 Mtetra
.9335 .64947 .93351 .64455 .93534 .64408 .93534 .64899 Mtetra
.527 .258 .45 r
.93534 .64899 .93534 .64408 .93717 .64359 .93718 .6485 Mtetra
.93718 .6485 .93717 .64359 .93901 .64309 .93901 .648 Mtetra
.526 .257 .45 r
.93901 .648 .93901 .64309 .94084 .64257 .94085 .64749 Mtetra
.526 .257 .451 r
.94085 .64749 .94084 .64257 .94267 .64202 .94269 .64698 Mtetra
.526 .258 .451 r
.94269 .64698 .94267 .64202 .9445 .64147 .94452 .64646 Mtetra
.527 .259 .452 r
.94452 .64646 .9445 .64147 .94633 .64092 .94636 .64594 Mtetra
.527 .259 .453 r
.94636 .64594 .94633 .64092 .94816 .64039 .9482 .64543 Mtetra
.527 .26 .453 r
.9482 .64543 .94816 .64039 .95 .63987 .95005 .64492 Mtetra
.528 .261 .453 r
.95005 .64492 .95 .63987 .95184 .63937 .95189 .64441 Mtetra
.95189 .64441 .95184 .63937 .95368 .63888 .95374 .64392 Mtetra
.529 .261 .453 r
.95374 .64392 .95368 .63888 .95553 .63843 .95558 .64343 Mtetra
.53 .261 .453 r
.95558 .64343 .95553 .63843 .95738 .63801 .95744 .64296 Mtetra
.531 .262 .452 r
.95744 .64296 .95738 .63801 .95925 .63765 .95929 .64253 Mtetra
.531 .26 .45 r
.95929 .64253 .95925 .63765 .96111 .63732 .96115 .6421 Mtetra
.533 .26 .448 r
.96115 .6421 .96111 .63732 .963 .63709 .96302 .64172 Mtetra
.556 .276 .446 r
.96302 .64172 .963 .63709 .96497 .63758 .96494 .64176 Mtetra
.527 .245 .431 r
.96494 .64176 .96497 .63758 .96686 .63736 .96681 .64139 Mtetra
.458 .189 .417 r
.96681 .64139 .96686 .63736 .96856 .63568 .96857 .64013 Mtetra
.035 0 .336 r
.96857 .64013 .96856 .63568 .94595 .44535 .96973 .63424 Mtetra
.17 .084 .508 r
.96973 .63424 .94595 .44535 .94633 .43423 .94596 .43541 Mtetra
.831 .771 .262 r
.94596 .43541 .94633 .43423 .9477 .43092 .94705 .4299 Mtetra
.759 .766 .858 r
.94705 .4299 .9477 .43092 .9494 .43005 .94872 .42883 Mtetra
.634 .678 .874 r
.94872 .42883 .9494 .43005 .95115 .42964 .95048 .42845 Mtetra
.562 .647 .892 r
.95048 .42845 .95115 .42964 .95294 .42944 .95229 .4284 Mtetra
.674 .73 .892 r
.95229 .4284 .95294 .42944 .95467 .42885 .95402 .42782 Mtetra
.679 .734 .892 r
.95402 .42782 .95467 .42885 .95641 .42824 .95576 .42722 Mtetra
.684 .74 .893 r
.95576 .42722 .95641 .42824 .95814 .42759 .95749 .42659 Mtetra
.769 .775 .858 r
.95749 .42659 .95814 .42759 .9598 .42645 .95916 .42547 Mtetra
.706 .756 .891 r
.95916 .42547 .9598 .42645 .96152 .42571 .96088 .42473 Mtetra
.537 .681 .932 r
.96088 .42473 .96152 .42571 .96333 .42566 .96269 .4247 Mtetra
.927 .543 .179 r
.39398 .59501 .39482 .59618 .39608 .60038 .39525 .59889 Mtetra
.938 .684 .525 r
.39525 .59889 .39608 .60038 .3905 .78834 .38961 .78717 Mtetra
.947 .595 .295 r
.38961 .78717 .3905 .78834 .39182 .79325 .39091 .79253 Mtetra
0 .403 .833 r
.39091 .79253 .39182 .79325 .39329 .79389 .39238 .79324 Mtetra
.644 .787 .95 r
.39238 .79324 .39329 .79389 .39481 .79345 .3939 .79283 Mtetra
.829 .801 .824 r
.3939 .79283 .39481 .79345 .39637 .79194 .39545 .7913 Mtetra
.919 .737 .64 r
.39545 .7913 .39637 .79194 .39807 .78625 .39718 .78504 Mtetra
.937 .686 .533 r
.39718 .78504 .39807 .78625 .40613 .59735 .40531 .59556 Mtetra
.854 .673 .656 r
.40531 .59556 .40613 .59735 .40773 .59227 .4069 .59084 Mtetra
.753 .665 .764 r
.4069 .59084 .40773 .59227 .4092 .59085 .40836 .58954 Mtetra
.656 .645 .828 r
.40836 .58954 .4092 .59085 .41064 .5904 .4098 .58912 Mtetra
.469 .565 .87 r
.4098 .58912 .41064 .5904 .41205 .59086 .41122 .58941 Mtetra
0 0 .512 r
.41122 .58941 .41205 .59086 .41335 .5946 .41258 .5914 Mtetra
.859 .565 .035 r
.41258 .5914 .41335 .5946 .40872 .78263 .4138 .59786 Mtetra
0 0 .352 r
.4138 .59786 .40872 .78263 .41005 .78815 .40931 .78242 Mtetra
.524 .392 .642 r
.40931 .78242 .41005 .78815 .41155 .78864 .41079 .78331 Mtetra
.611 .459 .65 r
.41079 .78331 .41155 .78864 .41308 .78823 .41232 .78276 Mtetra
.619 .463 .648 r
.41232 .78276 .41308 .78823 .41462 .78742 .41386 .78203 Mtetra
.466 .355 .643 r
.41386 .78203 .41462 .78742 .41614 .78698 .41532 .78358 Mtetra
.412 .364 .695 r
.41532 .78358 .41614 .78698 .41767 .7866 .4168 .78491 Mtetra
.343 .447 .823 r
.4168 .78491 .41767 .7866 .4192 .7862 .41829 .78573 Mtetra
.465 .78 .998 r
.41829 .78573 .4192 .7862 .42073 .78581 .41981 .78562 Mtetra
.545 .885 .986 r
.41981 .78562 .42073 .78581 .42226 .78541 .42135 .78519 Mtetra
.625 .904 .985 r
.42135 .78519 .42226 .78541 .42379 .78498 .42288 .78464 Mtetra
.589 .863 .994 r
.42288 .78464 .42379 .78498 .42533 .78447 .42442 .78423 Mtetra
.536 .872 .992 r
.42442 .78423 .42533 .78447 .42686 .78393 .42595 .78385 Mtetra
.451 .867 .949 r
.42595 .78385 .42686 .78393 .4284 .7834 .42748 .78347 Mtetra
.053 .619 .709 r
.42748 .78347 .4284 .7834 .42993 .78339 .42901 .78336 Mtetra
.319 .802 .891 r
.42901 .78336 .42993 .78339 .43146 .78317 .43054 .78308 Mtetra
.675 .942 .963 r
.43054 .78308 .43146 .78317 .43301 .7823 .43209 .78234 Mtetra
.939 .873 .745 r
.43209 .78234 .43301 .7823 .43465 .77778 .43369 .77952 Mtetra
.998 .851 .55 r
.43369 .77952 .43465 .77778 .44084 .58859 .4354 .77231 Mtetra
0 0 .351 r
.4354 .77231 .44084 .58859 .44244 .58232 .44148 .58626 Mtetra
.314 .057 .356 r
.44148 .58626 .44244 .58232 .44392 .58087 .44298 .58419 Mtetra
.521 .229 .412 r
.44298 .58419 .44392 .58087 .44537 .58044 .44443 .58392 Mtetra
.547 .258 .427 r
.44443 .58392 .44537 .58044 .44682 .58039 .44588 .58389 Mtetra
.276 .013 .322 r
.44588 .58389 .44682 .58039 .44828 .58006 .44738 .58185 Mtetra
0 0 0 r
.44738 .58185 .44828 .58006 .44974 .57963 .44888 .57978 Mtetra
.877 .972 .845 r
.44888 .57978 .44974 .57963 .4512 .5792 .45036 .57821 Mtetra
.71 .716 .854 r
.45036 .57821 .4512 .5792 .45266 .57878 .45183 .57752 Mtetra
.631 .644 .844 r
.45183 .57752 .45266 .57878 .45412 .57836 .45329 .57722 Mtetra
.598 .65 .873 r
.45329 .57722 .45412 .57836 .45558 .57794 .45475 .57705 Mtetra
.633 .717 .908 r
.45475 .57705 .45558 .57794 .45705 .57748 .45621 .57673 Mtetra
.657 .757 .924 r
.45621 .57673 .45705 .57748 .45851 .57701 .45767 .57631 Mtetra
.671 .771 .926 r
.45767 .57631 .45851 .57701 .45998 .57656 .45914 .57583 Mtetra
.695 .769 .909 r
.45914 .57583 .45998 .57656 .46144 .57619 .46061 .57526 Mtetra
.699 .725 .87 r
.46061 .57526 .46144 .57619 .4629 .57585 .46208 .57464 Mtetra
.687 .673 .831 r
.46208 .57464 .4629 .57585 .46437 .57551 .46355 .57403 Mtetra
.697 .643 .791 r
.46355 .57403 .46437 .57551 .46584 .57475 .46502 .57327 Mtetra
.679 .636 .799 r
.46502 .57327 .46584 .57475 .46732 .57407 .46649 .57264 Mtetra
.613 .613 .827 r
.46649 .57264 .46732 .57407 .46878 .57395 .46796 .57243 Mtetra
.078 .295 .779 r
.46796 .57243 .46878 .57395 .4702 .57664 .4694 .57372 Mtetra
0 0 .308 r
.4694 .57372 .4702 .57664 .46873 .76445 .4708 .57817 Mtetra
0 0 .378 r
.4708 .57817 .46873 .76445 .47017 .77163 .46937 .76506 Mtetra
.276 .205 .594 r
.46937 .76506 .47017 .77163 .4717 .77277 .47086 .76913 Mtetra
.432 .371 .689 r
.47086 .76913 .4717 .77277 .47326 .77249 .4724 .77046 Mtetra
.477 .486 .789 r
.4724 .77046 .47326 .77249 .47483 .77176 .47395 .77098 Mtetra
.513 .716 .964 r
.47395 .77098 .47483 .77176 .47639 .7711 .4755 .77094 Mtetra
.481 .869 .973 r
.4755 .77094 .47639 .7711 .47796 .77053 .47707 .77057 Mtetra
.471 .89 .908 r
.47707 .77057 .47796 .77053 .47952 .76994 .47863 .77003 Mtetra
.159 .7 .756 r
.47863 .77003 .47952 .76994 .48108 .76979 .48019 .76979 Mtetra
.245 .758 .843 r
.48019 .76979 .48108 .76979 .48264 .76961 .48176 .76954 Mtetra
.616 .934 .961 r
.48176 .76954 .48264 .76961 .48421 .76886 .48333 .76888 Mtetra
.921 .916 .795 r
.48333 .76888 .48421 .76886 .48582 .76536 .48492 .7667 Mtetra
.989 .887 .566 r
.48492 .7667 .48582 .76536 .48935 .57694 .48654 .76138 Mtetra
0 0 .371 r
.48654 .76138 .48935 .57694 .49092 .56822 .49003 .5732 Mtetra
0 0 .231 r
.49003 .5732 .49092 .56822 .49241 .56616 .49156 .56805 Mtetra
0 0 0 r
.49156 .56805 .49241 .56616 .4939 .56553 .49306 .56593 Mtetra
.736 .986 .784 r
.49306 .56593 .4939 .56553 .49538 .56534 .49456 .56459 Mtetra
.743 .777 .88 r
.49456 .56459 .49538 .56534 .49686 .56511 .49605 .56377 Mtetra
.666 .647 .822 r
.49605 .56377 .49686 .56511 .49835 .5648 .49753 .56326 Mtetra
.636 .611 .808 r
.49753 .56326 .49835 .5648 .49983 .5645 .49902 .56291 Mtetra
.668 .62 .792 r
.49902 .56291 .49983 .5645 .50132 .56386 .50051 .56234 Mtetra
.676 .631 .797 r
.50051 .56234 .50132 .56386 .50281 .56317 .502 .56173 Mtetra
.621 .616 .824 r
.502 .56173 .50281 .56317 .5043 .56298 .50348 .56147 Mtetra
.188 .367 .811 r
.50348 .56147 .5043 .56298 .50578 .56501 .50496 .56258 Mtetra
0 0 .289 r
.50496 .56258 .50578 .56501 .5063 .7505 .50643 .56667 Mtetra
0 0 .389 r
.50643 .56667 .5063 .7505 .50782 .76108 .50699 .75381 Mtetra
.351 .254 .603 r
.50699 .75381 .50782 .76108 .50939 .76268 .50855 .75755 Mtetra
.587 .445 .655 r
.50855 .75755 .50939 .76268 .51097 .76247 .51012 .75744 Mtetra
.633 .478 .655 r
.51012 .75744 .51097 .76247 .51256 .76175 .51171 .75649 Mtetra
.636 .477 .651 r
.51171 .75649 .51256 .76175 .51414 .76111 .51329 .75543 Mtetra
.617 .459 .646 r
.51329 .75543 .51414 .76111 .51573 .76067 .51488 .7547 Mtetra
.591 .438 .643 r
.51488 .7547 .51573 .76067 .51731 .76023 .51646 .75447 Mtetra
.513 .385 .644 r
.51646 .75447 .51731 .76023 .5189 .75983 .51804 .75557 Mtetra
.44 .361 .67 r
.51804 .75557 .5189 .75983 .52048 .75946 .51962 .75709 Mtetra
.394 .41 .759 r
.51962 .75709 .52048 .75946 .52207 .75907 .52121 .75813 Mtetra
.38 .61 .94 r
.52121 .75813 .52207 .75907 .52366 .7586 .5228 .75846 Mtetra
.317 .789 .925 r
.5228 .75846 .52366 .7586 .52525 .75804 .52439 .75826 Mtetra
0 0 0 r
.52439 .75826 .52525 .75804 .52684 .75748 .52598 .75789 Mtetra
.52598 .75789 .52684 .75748 .52843 .75699 .52757 .75748 Mtetra
.069 0 0 r
.52757 .75748 .52843 .75699 .53003 .75657 .52917 .75708 Mtetra
.059 0 0 r
.52917 .75708 .53003 .75657 .53162 .75619 .53076 .75666 Mtetra
.032 0 0 r
.53076 .75666 .53162 .75619 .53321 .75579 .53236 .75623 Mtetra
.014 0 0 r
.53236 .75623 .53321 .75579 .53481 .75538 .53395 .75581 Mtetra
.008 0 0 r
.53395 .75581 .53481 .75538 .53641 .75496 .53555 .75539 Mtetra
.003 0 0 r
.53555 .75539 .53641 .75496 .538 .75454 .53715 .75497 Mtetra
0 0 0 r
.53715 .75497 .538 .75454 .5396 .75412 .53875 .75454 Mtetra
.53875 .75454 .5396 .75412 .5412 .75369 .54035 .75412 Mtetra
.54035 .75412 .5412 .75369 .5428 .75326 .54195 .75369 Mtetra
.54195 .75369 .5428 .75326 .5444 .75283 .54355 .75325 Mtetra
.54355 .75325 .5444 .75283 .546 .7524 .54515 .75282 Mtetra
.54515 .75282 .546 .7524 .5476 .75196 .54676 .75239 Mtetra
.54676 .75239 .5476 .75196 .54921 .75152 .54836 .75196 Mtetra
.54836 .75196 .54921 .75152 .55081 .75109 .54997 .75151 Mtetra
.54997 .75151 .55081 .75109 .55242 .75066 .55157 .75101 Mtetra
.55157 .75101 .55242 .75066 .55402 .75023 .55318 .75045 Mtetra
.304 .792 .745 r
.55318 .75045 .55402 .75023 .55563 .7498 .55479 .74989 Mtetra
.267 .774 .804 r
.55479 .74989 .55563 .7498 .55724 .74958 .5564 .74951 Mtetra
.251 .758 .87 r
.5564 .74951 .55724 .74958 .55885 .7495 .55801 .74931 Mtetra
.574 .904 .98 r
.55801 .74931 .55885 .7495 .56046 .74892 .55962 .74878 Mtetra
.876 .933 .855 r
.55962 .74878 .56046 .74892 .56205 .7466 .56122 .74713 Mtetra
.987 .877 .632 r
.56122 .74713 .56205 .7466 .56355 .73514 .56279 .74264 Mtetra
.967 .702 .478 r
.56279 .74264 .56355 .73514 .56304 .54774 .56233 .55532 Mtetra
.028 0 .333 r
.56233 .55532 .56304 .54774 .56453 .54466 .56378 .5479 Mtetra
.44 .154 .38 r
.56378 .5479 .56453 .54466 .56605 .5439 .5653 .54694 Mtetra
.539 .237 .404 r
.5653 .54694 .56605 .5439 .56757 .54366 .56683 .54688 Mtetra
.556 .258 .417 r
.56683 .54688 .56757 .54366 .5691 .5435 .56836 .54698 Mtetra
.509 .222 .413 r
.56836 .54698 .5691 .5435 .57063 .54305 .56989 .54655 Mtetra
.511 .224 .415 r
.56989 .54655 .57063 .54305 .57215 .54261 .57142 .54614 Mtetra
.51 .224 .415 r
.57142 .54614 .57215 .54261 .57368 .54216 .57295 .54571 Mtetra
.508 .223 .416 r
.57295 .54571 .57368 .54216 .57521 .5417 .57448 .54526 Mtetra
.508 .222 .416 r
.57448 .54526 .57521 .5417 .57674 .54124 .57601 .5448 Mtetra
.508 .223 .416 r
.57601 .5448 .57674 .54124 .57827 .54078 .57754 .54434 Mtetra
.57754 .54434 .57827 .54078 .5798 .54032 .57908 .54389 Mtetra
.509 .223 .416 r
.57908 .54389 .5798 .54032 .58133 .53987 .58061 .54344 Mtetra
.522 .235 .42 r
.58061 .54344 .58133 .53987 .58286 .53942 .58215 .54312 Mtetra
.545 .259 .432 r
.58215 .54312 .58286 .53942 .58439 .53899 .58369 .54305 Mtetra
.514 .238 .434 r
.58369 .54305 .58439 .53899 .58593 .53855 .58522 .54256 Mtetra
.407 .145 .4 r
.58522 .54256 .58593 .53855 .58746 .53809 .58674 .541 Mtetra
.138 0 .246 r
.58674 .541 .58746 .53809 .589 .5376 .58824 .53854 Mtetra
.583 .829 .457 r
.58824 .53854 .589 .5376 .59053 .53711 .58975 .5366 Mtetra
.828 .85 .863 r
.58975 .5366 .59053 .53711 .59207 .53662 .59127 .53529 Mtetra
.678 .659 .824 r
.59127 .53529 .59207 .53662 .59361 .53615 .59281 .53469 Mtetra
.644 .628 .819 r
.59281 .53469 .59361 .53615 .59515 .53568 .59435 .53429 Mtetra
.638 .634 .83 r
.59435 .53429 .59515 .53568 .59669 .53521 .59589 .53393 Mtetra
.66 .66 .839 r
.59589 .53393 .59669 .53521 .59823 .53473 .59743 .53346 Mtetra
.661 .662 .841 r
.59743 .53346 .59823 .53473 .59977 .53424 .59897 .53298 Mtetra
.661 .664 .842 r
.59897 .53298 .59977 .53424 .60131 .53374 .60052 .53251 Mtetra
.662 .667 .845 r
.60052 .53251 .60131 .53374 .60285 .53323 .60206 .53203 Mtetra
.667 .675 .849 r
.60206 .53203 .60285 .53323 .60439 .53272 .6036 .53152 Mtetra
.676 .679 .845 r
.6036 .53152 .60439 .53272 .60594 .53225 .60515 .53096 Mtetra
.687 .67 .828 r
.60515 .53096 .60594 .53225 .60749 .53186 .60669 .53032 Mtetra
.678 .634 .799 r
.60669 .53032 .60749 .53186 .60904 .53148 .60823 .52968 Mtetra
.673 .607 .772 r
.60823 .52968 .60904 .53148 .61058 .53099 .60977 .52899 Mtetra
.685 .597 .752 r
.60977 .52899 .61058 .53099 .61212 .53013 .61131 .52814 Mtetra
.641 .575 .765 r
.61131 .52814 .61212 .53013 .61367 .52966 .61286 .52768 Mtetra
.484 .489 .787 r
.61286 .52768 .61367 .52966 .61525 .53027 .61443 .52819 Mtetra
.724 .383 0 r
.61443 .52819 .61525 .53027 .61698 .53659 .61613 .53286 Mtetra
.966 .689 .456 r
.61613 .53286 .61698 .53659 .6239 .72824 .62305 .72646 Mtetra
.777 .401 0 r
.62305 .72646 .6239 .72824 .62566 .73177 .62483 .73097 Mtetra
.12 .497 .905 r
.62483 .73097 .62566 .73177 .62733 .73213 .62652 .73164 Mtetra
.592 .835 .991 r
.62652 .73164 .62733 .73213 .62897 .73149 .62817 .73125 Mtetra
.869 .923 .86 r
.62817 .73125 .62897 .73149 .63058 .7296 .62979 .72964 Mtetra
.978 .818 .616 r
.62979 .72964 .63058 .7296 .63206 .72327 .63129 .7241 Mtetra
.965 .693 .468 r
.63129 .7241 .63206 .72327 .6278 .53035 .62704 .53018 Mtetra
.969 .8 .619 r
.62704 .53018 .6278 .53035 .62923 .52567 .62845 .52481 Mtetra
.762 .768 .858 r
.62845 .52481 .62923 .52567 .63077 .5247 .62999 .52381 Mtetra
.624 .724 .919 r
.62999 .52381 .63077 .5247 .63233 .52435 .63156 .52349 Mtetra
.547 .702 .941 r
.63156 .52349 .63233 .52435 .6339 .5242 .63313 .52341 Mtetra
.739 .781 .887 r
.63313 .52341 .6339 .5242 .63545 .52325 .63468 .52258 Mtetra
.679 .799 .939 r
.63468 .52258 .63545 .52325 .63701 .52269 .63624 .52203 Mtetra
.431 .707 .981 r
.63624 .52203 .63701 .52269 .6386 .52302 .63783 .5221 Mtetra
.686 .217 0 r
.63783 .5221 .6386 .52302 .64036 .52828 .63949 .52451 Mtetra
.965 .663 .254 r
.63949 .52451 .64036 .52828 .64867 .72079 .64167 .5418 Mtetra
.063 0 .448 r
.64167 .5418 .64867 .72079 .65049 .72487 .64953 .7198 Mtetra
.419 .333 .653 r
.64953 .7198 .65049 .72487 .65217 .72497 .65128 .72194 Mtetra
.475 .427 .724 r
.65128 .72194 .65217 .72497 .65383 .72438 .653 .72284 Mtetra
.513 .567 .847 r
.653 .72284 .65383 .72438 .65548 .72347 .65469 .72307 Mtetra
.575 .857 .996 r
.65469 .72307 .65548 .72347 .65715 .72304 .65636 .72266 Mtetra
.668 .89 .978 r
.65636 .72266 .65715 .72304 .65882 .72259 .65802 .72201 Mtetra
.703 .841 .949 r
.65802 .72201 .65882 .72259 .66049 .72213 .65968 .72132 Mtetra
.488 .702 .964 r
.65968 .72132 .66049 .72213 .66217 .72201 .66137 .72134 Mtetra
.564 .773 .977 r
.66137 .72134 .66217 .72201 .66384 .7215 .66305 .7211 Mtetra
.72 .896 .959 r
.66305 .7211 .66384 .7215 .66547 .72018 .6647 .72029 Mtetra
.974 .893 .681 r
.6647 .72029 .66547 .72018 .6669 .71367 .66625 .71675 Mtetra
.951 .791 .339 r
.66625 .71675 .6669 .71367 .66073 .52021 .6675 .70568 Mtetra
.063 0 .444 r
.6675 .70568 .66073 .52021 .66213 .5154 .66154 .5188 Mtetra
.438 .158 .389 r
.66154 .5188 .66213 .5154 .66368 .5144 .6631 .51771 Mtetra
.529 .235 .411 r
.6631 .51771 .66368 .5144 .66527 .51404 .66469 .51752 Mtetra
.539 .247 .421 r
.66469 .51752 .66527 .51404 .66686 .514 .66628 .51741 Mtetra
.239 0 .325 r
.66628 .51741 .66686 .514 .66844 .51352 .66778 .51492 Mtetra
0 0 0 r
.66778 .51492 .66844 .51352 .67002 .51304 .66929 .51287 Mtetra
.871 .947 .861 r
.66929 .51287 .67002 .51304 .6716 .51254 .67083 .51133 Mtetra
.678 .682 .847 r
.67083 .51133 .6716 .51254 .67318 .51202 .67241 .51076 Mtetra
.633 .655 .854 r
.67241 .51076 .67318 .51202 .67477 .51151 .674 .51042 Mtetra
.61 .676 .888 r
.674 .51042 .67477 .51151 .67635 .51104 .67559 .51018 Mtetra
.742 .768 .874 r
.67559 .51018 .67635 .51104 .67792 .51027 .67716 .50931 Mtetra
.704 .736 .876 r
.67716 .50931 .67792 .51027 .67951 .50982 .67874 .50863 Mtetra
.605 .655 .873 r
.67874 .50863 .67951 .50982 .68113 .51002 .68034 .50842 Mtetra
0 .121 .671 r
.68034 .50842 .68113 .51002 .68294 .5144 .68205 .51056 Mtetra
0 0 .165 r
.68205 .51056 .68294 .5144 .69381 .70777 .68407 .51921 Mtetra
.084 .006 .461 r
.68407 .51921 .69381 .70777 .69576 .71263 .69474 .7072 Mtetra
.479 .37 .652 r
.69474 .7072 .69576 .71263 .69751 .71341 .69653 .70879 Mtetra
.599 .463 .667 r
.69653 .70879 .69751 .71341 .6992 .71306 .69823 .7085 Mtetra
.679 .516 .658 r
.69823 .7085 .6992 .71306 .70085 .71172 .69985 .70668 Mtetra
.869 .631 .576 r
.69985 .70668 .70085 .71172 .70234 .70723 .70092 .69382 Mtetra
.952 .673 .473 r
.70092 .69382 .70234 .70723 .69425 .51399 .69326 .50834 Mtetra
.722 .529 .628 r
.69326 .50834 .69425 .51399 .69549 .50644 .69469 .50462 Mtetra
.704 .623 .764 r
.69469 .50462 .69549 .50644 .69703 .50491 .69626 .50365 Mtetra
.623 .651 .857 r
.69626 .50365 .69703 .50491 .69862 .50435 .69787 .50335 Mtetra
.534 .664 .92 r
.69787 .50335 .69862 .50435 .70024 .50418 .69949 .50336 Mtetra
.637 .749 .929 r
.69949 .50336 .70024 .50418 .70184 .50373 .70109 .50297 Mtetra
.668 .776 .93 r
.70109 .50297 .70184 .50373 .70343 .50324 .70269 .50246 Mtetra
.683 .774 .92 r
.70269 .50246 .70343 .50324 .70503 .50276 .70429 .50189 Mtetra
.774 .775 .854 r
.70429 .50189 .70503 .50276 .70661 .50181 .70586 .50079 Mtetra
.73 .736 .856 r
.70586 .50079 .70661 .50181 .7082 .50108 .70744 .49994 Mtetra
.605 .665 .881 r
.70744 .49994 .7082 .50108 .70982 .50099 .70906 .49972 Mtetra
.626 .216 0 r
.70906 .49972 .70982 .50099 .71164 .50435 .71086 .50279 Mtetra
.971 .683 .424 r
.71086 .50279 .71164 .50435 .72425 .69809 .72342 .69641 Mtetra
.89 .521 .051 r
.72342 .69641 .72425 .69809 .72633 .70419 .72554 .70329 Mtetra
0 .34 .814 r
.72554 .70329 .72633 .70419 .72812 .70527 .72734 .70443 Mtetra
.59 .741 .948 r
.72734 .70443 .72812 .70527 .72985 .70501 .72906 .70417 Mtetra
.795 .8 .856 r
.72906 .70417 .72985 .70501 .73151 .70374 .73073 .7029 Mtetra
.933 .778 .666 r
.73073 .7029 .73151 .70374 .733 .69946 .73222 .69861 Mtetra
.971 .689 .436 r
.73222 .69861 .733 .69946 .72318 .50546 .72244 .50458 Mtetra
.957 .743 .572 r
.72244 .50458 .72318 .50546 .72435 .49755 .72361 .49667 Mtetra
.831 .783 .807 r
.72361 .49667 .72435 .49755 .72589 .49592 .72515 .49504 Mtetra
.648 .74 .917 r
.72515 .49504 .72589 .49592 .7275 .49548 .72677 .49461 Mtetra
.512 .686 .946 r
.72677 .49461 .7275 .49548 .72915 .49548 .72841 .49463 Mtetra
.615 .734 .931 r
.72841 .49463 .72915 .49548 .73077 .49512 .73004 .49432 Mtetra
.658 .764 .928 r
.73004 .49432 .73077 .49512 .73238 .49461 .73166 .49385 Mtetra
.67 .777 .93 r
.73166 .49385 .73238 .49461 .734 .49412 .73327 .49332 Mtetra
.756 .793 .883 r
.73327 .49332 .734 .49412 .7356 .49333 .73486 .49238 Mtetra
.734 .754 .868 r
.73486 .49238 .7356 .49333 .73721 .49272 .73646 .49152 Mtetra
.646 .675 .864 r
.73646 .49152 .73721 .49272 .73886 .4927 .73808 .49111 Mtetra
.199 .363 .804 r
.73808 .49111 .73886 .4927 .74071 .49582 .73982 .49244 Mtetra
0 0 .512 r
.73982 .49244 .74071 .49582 .75505 .6893 .7418 .49745 Mtetra
.112 .031 .476 r
.7418 .49745 .75505 .6893 .75722 .6956 .75609 .68922 Mtetra
.354 .275 .626 r
.75609 .68922 .75722 .6956 .75904 .69656 .75809 .69292 Mtetra
.462 .399 .7 r
.75809 .69292 .75904 .69656 .76078 .69619 .75993 .69416 Mtetra
.499 .508 .797 r
.75993 .69416 .76078 .69619 .76248 .69537 .76172 .69462 Mtetra
.532 .742 .972 r
.76172 .69462 .76248 .69537 .7642 .69477 .76348 .69449 Mtetra
.536 .879 .988 r
.76348 .69449 .7642 .69477 .76593 .69431 .76521 .69404 Mtetra
.593 .904 .983 r
.76521 .69404 .76593 .69431 .76767 .69381 .76693 .69346 Mtetra
.541 .862 .996 r
.76693 .69346 .76767 .69381 .76939 .69325 .76867 .69305 Mtetra
.394 .828 .954 r
.76867 .69305 .76939 .69325 .77112 .69266 .77042 .69275 Mtetra
.145 .687 .725 r
.77042 .69275 .77112 .69266 .77285 .69208 .77217 .69245 Mtetra
.044 0 0 r
.77217 .69245 .77285 .69208 .77458 .69159 .77391 .69208 Mtetra
.092 0 0 r
.77391 .69208 .77458 .69159 .77632 .69116 .77566 .69165 Mtetra
.078 0 0 r
.77566 .69165 .77632 .69116 .77806 .69076 .7774 .6912 Mtetra
.048 0 0 r
.7774 .6912 .77806 .69076 .77981 .69034 .77914 .69075 Mtetra
.03 0 0 r
.77914 .69075 .77981 .69034 .78155 .6899 .78088 .6903 Mtetra
.021 0 0 r
.78088 .6903 .78155 .6899 .78329 .68946 .78263 .68985 Mtetra
.014 0 0 r
.78263 .68985 .78329 .68946 .78504 .68901 .78437 .6894 Mtetra
.009 0 0 r
.78437 .6894 .78504 .68901 .78678 .68856 .78612 .68895 Mtetra
.004 0 0 r
.78612 .68895 .78678 .68856 .78853 .68811 .78787 .68849 Mtetra
.001 0 0 r
.78787 .68849 .78853 .68811 .79028 .68765 .78962 .68803 Mtetra
0 0 0 r
.78962 .68803 .79028 .68765 .79203 .68719 .79137 .68757 Mtetra
.79137 .68757 .79203 .68719 .79378 .68673 .79312 .68711 Mtetra
.79312 .68711 .79378 .68673 .79553 .68627 .79487 .68664 Mtetra
.79487 .68664 .79553 .68627 .79728 .6858 .79662 .68618 Mtetra
.79662 .68618 .79728 .6858 .79903 .68534 .79837 .68572 Mtetra
.79837 .68572 .79903 .68534 .80078 .68487 .80013 .68525 Mtetra
.80013 .68525 .80078 .68487 .80254 .68441 .80188 .68478 Mtetra
.80188 .68478 .80254 .68441 .80429 .68394 .80364 .68431 Mtetra
.80364 .68431 .80429 .68394 .80605 .68347 .8054 .68385 Mtetra
.8054 .68385 .80605 .68347 .8078 .683 .80716 .68338 Mtetra
.80716 .68338 .8078 .683 .80956 .68253 .80892 .68291 Mtetra
.80892 .68291 .80956 .68253 .81132 .68206 .81068 .68244 Mtetra
.81068 .68244 .81132 .68206 .81308 .68159 .81244 .68197 Mtetra
.81244 .68197 .81308 .68159 .81484 .68112 .8142 .6815 Mtetra
.8142 .6815 .81484 .68112 .8166 .68065 .81596 .68102 Mtetra
.81596 .68102 .8166 .68065 .81837 .68018 .81773 .68055 Mtetra
.81773 .68055 .81837 .68018 .82013 .67971 .81949 .68008 Mtetra
.81949 .68008 .82013 .67971 .8219 .67924 .82126 .67961 Mtetra
.82126 .67961 .8219 .67924 .82366 .67877 .82303 .67914 Mtetra
.82303 .67914 .82366 .67877 .82543 .6783 .8248 .67867 Mtetra
.8248 .67867 .82543 .6783 .8272 .67783 .82657 .6782 Mtetra
.82657 .6782 .8272 .67783 .82897 .67736 .82834 .67773 Mtetra
.82834 .67773 .82897 .67736 .83074 .67689 .83011 .67726 Mtetra
.83011 .67726 .83074 .67689 .83252 .67642 .83189 .67679 Mtetra
.83189 .67679 .83252 .67642 .83429 .67595 .83366 .67632 Mtetra
.83366 .67632 .83429 .67595 .83606 .67548 .83544 .67585 Mtetra
.83544 .67585 .83606 .67548 .83784 .67501 .83722 .67537 Mtetra
.83722 .67537 .83784 .67501 .83962 .67454 .83899 .6749 Mtetra
.83899 .6749 .83962 .67454 .84139 .67407 .84077 .67443 Mtetra
.84077 .67443 .84139 .67407 .84317 .6736 .84255 .67396 Mtetra
.84255 .67396 .84317 .6736 .84495 .67312 .84433 .67349 Mtetra
.84433 .67349 .84495 .67312 .84673 .67265 .84612 .67302 Mtetra
.84612 .67302 .84673 .67265 .84852 .67218 .8479 .67255 Mtetra
.8479 .67255 .84852 .67218 .8503 .67171 .84969 .67208 Mtetra
.84969 .67208 .8503 .67171 .85208 .67124 .85147 .67161 Mtetra
.85147 .67161 .85208 .67124 .85387 .67077 .85326 .67114 Mtetra
.85326 .67114 .85387 .67077 .85566 .6703 .85505 .67066 Mtetra
.85505 .67066 .85566 .6703 .85744 .66983 .85684 .67019 Mtetra
.85684 .67019 .85744 .66983 .85923 .66935 .85863 .66972 Mtetra
.85863 .66972 .85923 .66935 .86102 .66888 .86042 .66924 Mtetra
.86042 .66924 .86102 .66888 .86281 .6684 .86221 .66877 Mtetra
.86221 .66877 .86281 .6684 .86461 .66793 .864 .66829 Mtetra
.864 .66829 .86461 .66793 .8664 .66745 .8658 .66782 Mtetra
.8658 .66782 .8664 .66745 .86819 .66698 .86759 .66734 Mtetra
.86759 .66734 .86819 .66698 .86999 .6665 .86939 .66686 Mtetra
.86939 .66686 .86999 .6665 .87178 .66602 .87119 .66638 Mtetra
.87119 .66638 .87178 .66602 .87358 .66554 .87299 .6659 Mtetra
.87299 .6659 .87358 .66554 .87538 .66506 .87479 .66542 Mtetra
.87479 .66542 .87538 .66506 .87718 .66457 .87659 .66494 Mtetra
.87659 .66494 .87718 .66457 .87898 .66409 .87839 .66445 Mtetra
.87839 .66445 .87898 .66409 .88078 .6636 .88019 .66396 Mtetra
.88019 .66396 .88078 .6636 .88258 .66311 .88199 .66347 Mtetra
.88199 .66347 .88258 .66311 .88438 .66262 .8838 .66298 Mtetra
.8838 .66298 .88438 .66262 .88619 .66212 .8856 .66249 Mtetra
.8856 .66249 .88619 .66212 .88799 .66161 .88741 .662 Mtetra
.88741 .662 .88799 .66161 .88979 .66111 .88922 .66148 Mtetra
.88922 .66148 .88979 .66111 .8916 .6606 .89102 .66092 Mtetra
.89102 .66092 .8916 .6606 .89341 .66008 .89281 .66028 Mtetra
.26 .755 .686 r
.89281 .66028 .89341 .66008 .89521 .65957 .8946 .65963 Mtetra
.36 .831 .809 r
.8946 .65963 .89521 .65957 .89702 .65905 .8964 .65901 Mtetra
.392 .85 .876 r
.8964 .65901 .89702 .65905 .89883 .65854 .89821 .65848 Mtetra
.392 .849 .887 r
.89821 .65848 .89883 .65854 .90064 .65803 .90003 .65797 Mtetra
.382 .844 .883 r
.90003 .65797 .90064 .65803 .90245 .65753 .90184 .65748 Mtetra
.379 .842 .877 r
.90184 .65748 .90245 .65753 .90427 .65703 .90366 .65698 Mtetra
.377 .841 .877 r
.90366 .65698 .90427 .65703 .90608 .65653 .90547 .65648 Mtetra
.374 .839 .877 r
.90547 .65648 .90608 .65653 .9079 .65604 .90729 .65599 Mtetra
.372 .838 .877 r
.90729 .65599 .9079 .65604 .90972 .65555 .90911 .6555 Mtetra
.369 .836 .877 r
.90911 .6555 .90972 .65555 .91154 .65507 .91093 .65502 Mtetra
.366 .835 .876 r
.91093 .65502 .91154 .65507 .91336 .65459 .91276 .65454 Mtetra
.363 .833 .875 r
.91276 .65454 .91336 .65459 .91519 .65411 .91458 .65406 Mtetra
.359 .831 .873 r
.91458 .65406 .91519 .65411 .91701 .65364 .91641 .65359 Mtetra
.357 .829 .872 r
.91641 .65359 .91701 .65364 .91884 .65317 .91824 .65312 Mtetra
.361 .831 .873 r
.91824 .65312 .91884 .65317 .92067 .65271 .92007 .65265 Mtetra
.357 .828 .878 r
.92007 .65265 .92067 .65271 .9225 .65225 .9219 .65219 Mtetra
.322 .808 .866 r
.9219 .65219 .9225 .65225 .92433 .65179 .92374 .65178 Mtetra
.224 .746 .807 r
.92374 .65178 .92433 .65179 .92616 .65133 .92559 .65146 Mtetra
0 0 0 r
.92559 .65146 .92616 .65133 .928 .65088 .92744 .65113 Mtetra
.92744 .65113 .928 .65088 .92983 .65042 .92929 .65077 Mtetra
.018 0 0 r
.92929 .65077 .92983 .65042 .93167 .64995 .93113 .65032 Mtetra
.016 0 0 r
.93113 .65032 .93167 .64995 .9335 .64947 .93296 .64984 Mtetra
.004 0 0 r
.93296 .64984 .9335 .64947 .93534 .64899 .9348 .64935 Mtetra
.003 0 0 r
.9348 .64935 .93534 .64899 .93718 .6485 .93664 .64887 Mtetra
0 0 0 r
.93664 .64887 .93718 .6485 .93901 .648 .93847 .64836 Mtetra
.93847 .64836 .93901 .648 .94085 .64749 .94031 .64781 Mtetra
.94031 .64781 .94085 .64749 .94269 .64698 .94213 .64717 Mtetra
.246 .744 .672 r
.94213 .64717 .94269 .64698 .94452 .64646 .94395 .64651 Mtetra
.361 .832 .805 r
.94395 .64651 .94452 .64646 .94636 .64594 .94578 .64588 Mtetra
.408 .858 .886 r
.94578 .64588 .94636 .64594 .9482 .64543 .94762 .64533 Mtetra
.415 .86 .904 r
.94762 .64533 .9482 .64543 .95005 .64492 .94946 .64481 Mtetra
.411 .857 .907 r
.94946 .64481 .95005 .64492 .95189 .64441 .95131 .64431 Mtetra
.414 .859 .906 r
.95131 .64431 .95189 .64441 .95374 .64392 .95315 .6438 Mtetra
.418 .859 .914 r
.95315 .6438 .95374 .64392 .95558 .64343 .955 .6433 Mtetra
.417 .857 .92 r
.955 .6433 .95558 .64343 .95744 .64296 .95685 .64282 Mtetra
.405 .849 .923 r
.95685 .64282 .95744 .64296 .95929 .64253 .95871 .64237 Mtetra
.403 .847 .925 r
.95871 .64237 .95929 .64253 .96115 .6421 .96057 .64194 Mtetra
.375 .831 .922 r
.96057 .64194 .96115 .6421 .96302 .64172 .96244 .64156 Mtetra
.125 .664 .848 r
.96244 .64156 .96302 .64172 .96494 .64176 .96436 .64158 Mtetra
.388 .835 .934 r
.96436 .64158 .96494 .64176 .96681 .64139 .96623 .64121 Mtetra
.755 .983 .909 r
.96623 .64121 .96681 .64139 .96857 .64013 .96799 .63998 Mtetra
.998 .843 .546 r
.96799 .63998 .96857 .64013 .96973 .63424 .96921 .6345 Mtetra
.975 .67 .317 r
.96921 .6345 .96973 .63424 .94596 .43541 .94537 .43492 Mtetra
.993 .802 .542 r
.94537 .43492 .94596 .43541 .94705 .4299 .94639 .42883 Mtetra
.76 .757 .85 r
.94639 .42883 .94705 .4299 .94872 .42883 .94806 .42773 Mtetra
.629 .698 .895 r
.94806 .42773 .94872 .42883 .95048 .42845 .94982 .42737 Mtetra
.542 .659 .912 r
.94982 .42737 .95048 .42845 .95229 .4284 .95163 .42735 Mtetra
.669 .728 .894 r
.95163 .42735 .95229 .4284 .95402 .42782 .95337 .4268 Mtetra
.677 .737 .896 r
.95337 .4268 .95402 .42782 .95576 .42722 .95511 .42621 Mtetra
.689 .744 .894 r
.95511 .42621 .95576 .42722 .95749 .42659 .95684 .42556 Mtetra
.783 .774 .845 r
.95684 .42556 .95749 .42659 .95916 .42547 .95849 .42432 Mtetra
.719 .728 .858 r
.95849 .42432 .95916 .42547 .96088 .42473 .9602 .42347 Mtetra
.586 .647 .878 r
.9602 .42347 .96088 .42473 .96269 .4247 .962 .42333 Mtetra
.927 .544 .233 r
.39312 .59412 .39398 .59501 .39525 .59889 .39439 .59793 Mtetra
.938 .683 .526 r
.39439 .59793 .39525 .59889 .38961 .78717 .3887 .78633 Mtetra
.939 .593 .338 r
.3887 .78633 .38961 .78717 .39091 .79253 .38999 .7918 Mtetra
0 .386 .82 r
.38999 .7918 .39091 .79253 .39238 .79324 .39147 .79254 Mtetra
.64 .772 .943 r
.39147 .79254 .39238 .79324 .3939 .79283 .39298 .79215 Mtetra
.822 .791 .823 r
.39298 .79215 .3939 .79283 .39545 .7913 .39454 .79066 Mtetra
.918 .739 .644 r
.39454 .79066 .39545 .7913 .39718 .78504 .39626 .78467 Mtetra
.938 .687 .532 r
.39626 .78467 .39718 .78504 .40531 .59556 .40444 .59505 Mtetra
.918 .751 .659 r
.40444 .59505 .40531 .59556 .4069 .59084 .40604 .59016 Mtetra
.799 .785 .84 r
.40604 .59016 .4069 .59084 .40836 .58954 .4075 .58896 Mtetra
.645 .794 .954 r
.4075 .58896 .40836 .58954 .4098 .58912 .40894 .58856 Mtetra
.331 .683 .979 r
.40894 .58856 .4098 .58912 .41122 .58941 .41036 .58871 Mtetra
0 .348 .793 r
.41036 .58871 .41122 .58941 .41258 .5914 .41176 .58947 Mtetra
.151 .284 .747 r
.41176 .58947 .41258 .5914 .4138 .59786 .41314 .5909 Mtetra
.442 .317 .614 r
.41314 .5909 .4138 .59786 .40931 .78242 .4145 .59322 Mtetra
.573 .368 .564 r
.4145 .59322 .40931 .78242 .41079 .78331 .41594 .59293 Mtetra
.574 .369 .565 r
.41594 .59293 .41079 .78331 .41232 .78276 .41739 .59218 Mtetra
.572 .367 .564 r
.41739 .59218 .41232 .78276 .41386 .78203 .41882 .59234 Mtetra
0 0 .371 r
.41882 .59234 .41386 .78203 .41532 .78358 .41467 .77477 Mtetra
.034 .005 .488 r
.41467 .77477 .41532 .78358 .4168 .78491 .41595 .78248 Mtetra
0 .064 .614 r
.41595 .78248 .4168 .78491 .41829 .78573 .41739 .78497 Mtetra
.381 .66 .968 r
.41739 .78497 .41829 .78573 .41981 .78562 .4189 .78517 Mtetra
.626 .841 .982 r
.4189 .78517 .41981 .78562 .42135 .78519 .42044 .78474 Mtetra
.717 .852 .946 r
.42044 .78474 .42135 .78519 .42288 .78464 .42198 .78403 Mtetra
.659 .802 .952 r
.42198 .78403 .42288 .78464 .42442 .78423 .42351 .78355 Mtetra
.65 .783 .944 r
.42351 .78355 .42442 .78423 .42595 .78385 .42505 .78312 Mtetra
.653 .769 .935 r
.42505 .78312 .42595 .78385 .42748 .78347 .42659 .78269 Mtetra
.601 .742 .944 r
.42659 .78269 .42748 .78347 .42901 .78336 .42812 .78243 Mtetra
.633 .717 .908 r
.42812 .78243 .42901 .78336 .43054 .78308 .42965 .78209 Mtetra
.687 .72 .875 r
.42965 .78209 .43054 .78308 .43209 .78234 .4312 .7815 Mtetra
.817 .766 .805 r
.4312 .7815 .43209 .78234 .43369 .77952 .43277 .77993 Mtetra
.935 .957 .761 r
.43277 .77993 .43369 .77952 .4354 .77231 .43435 .77754 Mtetra
.249 .022 .361 r
.43435 .77754 .4354 .77231 .44148 .58626 .43596 .77427 Mtetra
.571 .362 .559 r
.43596 .77427 .44148 .58626 .44298 .58419 .43751 .77342 Mtetra
.572 .364 .559 r
.43751 .77342 .44298 .58419 .44443 .58392 .43904 .77348 Mtetra
.571 .362 .559 r
.43904 .77348 .44443 .58392 .44588 .58389 .44059 .7727 Mtetra
0 0 .38 r
.44059 .7727 .44588 .58389 .44738 .58185 .44628 .59218 Mtetra
0 0 .246 r
.44628 .59218 .44738 .58185 .44888 .57978 .44799 .58082 Mtetra
.949 .942 .617 r
.44799 .58082 .44888 .57978 .45036 .57821 .44952 .57751 Mtetra
.782 .788 .858 r
.44952 .57751 .45036 .57821 .45183 .57752 .451 .57646 Mtetra
.63 .678 .877 r
.451 .57646 .45183 .57752 .45329 .57722 .45245 .57616 Mtetra
.549 .648 .899 r
.45245 .57616 .45329 .57722 .45475 .57705 .45391 .57615 Mtetra
.614 .706 .91 r
.45391 .57615 .45475 .57705 .45621 .57673 .45537 .57589 Mtetra
.652 .734 .909 r
.45537 .57589 .45621 .57673 .45767 .57631 .45683 .5755 Mtetra
.665 .744 .909 r
.45683 .5755 .45767 .57631 .45914 .57583 .4583 .57505 Mtetra
.689 .756 .902 r
.4583 .57505 .45914 .57583 .46061 .57526 .45977 .57449 Mtetra
.7 .764 .901 r
.45977 .57449 .46061 .57526 .46208 .57464 .46124 .5739 Mtetra
.7 .768 .905 r
.46124 .5739 .46208 .57464 .46355 .57403 .46271 .5733 Mtetra
.714 .773 .899 r
.46271 .5733 .46355 .57403 .46502 .57327 .46418 .57264 Mtetra
.694 .796 .928 r
.46418 .57264 .46502 .57327 .46649 .57264 .46566 .57206 Mtetra
.615 .794 .967 r
.46566 .57206 .46649 .57264 .46796 .57243 .46712 .57173 Mtetra
.346 .648 .967 r
.46712 .57173 .46796 .57243 .4694 .57372 .46859 .57196 Mtetra
.311 .407 .799 r
.46859 .57196 .4694 .57372 .4708 .57817 .47003 .57293 Mtetra
.381 .294 .631 r
.47003 .57293 .4708 .57817 .46937 .76506 .47146 .57532 Mtetra
0 0 .394 r
.47146 .57532 .46937 .76506 .47086 .76913 .47014 .75799 Mtetra
.098 .043 .5 r
.47014 .75799 .47086 .76913 .4724 .77046 .47155 .76734 Mtetra
.118 .18 .653 r
.47155 .76734 .4724 .77046 .47395 .77098 .47307 .76989 Mtetra
.342 .553 .912 r
.47307 .76989 .47395 .77098 .4755 .77094 .47462 .77038 Mtetra
.617 .809 .974 r
.47462 .77038 .4755 .77094 .47707 .77057 .47618 .77 Mtetra
.712 .827 .936 r
.47618 .77 .47707 .77057 .47863 .77003 .47775 .76931 Mtetra
.645 .774 .942 r
.47775 .76931 .47863 .77003 .48019 .76979 .47932 .76889 Mtetra
.626 .726 .918 r
.47932 .76889 .48019 .76979 .48176 .76954 .48088 .76856 Mtetra
.681 .725 .883 r
.48088 .76856 .48176 .76954 .48333 .76888 .48245 .76801 Mtetra
.775 .764 .843 r
.48245 .76801 .48333 .76888 .48492 .7667 .48403 .76687 Mtetra
.905 .962 .815 r
.48403 .76687 .48492 .7667 .48654 .76138 .48561 .76493 Mtetra
.007 0 .201 r
.48561 .76493 .48654 .76138 .49003 .5732 .48721 .76156 Mtetra
0 0 .396 r
.48721 .76156 .49003 .5732 .49156 .56805 .49061 .58019 Mtetra
0 0 .306 r
.49061 .58019 .49156 .56805 .49306 .56593 .49222 .56745 Mtetra
.799 .875 .44 r
.49222 .56745 .49306 .56593 .49456 .56459 .49373 .56415 Mtetra
.839 .851 .854 r
.49373 .56415 .49456 .56459 .49605 .56377 .49522 .56277 Mtetra
.677 .71 .873 r
.49522 .56277 .49605 .56377 .49753 .56326 .49671 .56226 Mtetra
.608 .684 .896 r
.49671 .56226 .49753 .56326 .49902 .56291 .4982 .56203 Mtetra
.654 .728 .903 r
.4982 .56203 .49902 .56291 .50051 .56234 .49968 .56162 Mtetra
.683 .774 .921 r
.49968 .56162 .50051 .56234 .502 .56173 .50117 .56109 Mtetra
.62 .781 .958 r
.50117 .56109 .502 .56173 .50348 .56147 .50266 .56076 Mtetra
.275 .606 .954 r
.50266 .56076 .50348 .56147 .50496 .56258 .50415 .56111 Mtetra
.126 .335 .801 r
.50415 .56111 .50496 .56258 .50643 .56667 .50563 .5623 Mtetra
.386 .315 .654 r
.50563 .5623 .50643 .56667 .50699 .75381 .50711 .56429 Mtetra
.57 .365 .564 r
.50711 .56429 .50699 .75381 .50855 .75755 .5086 .56584 Mtetra
.573 .368 .564 r
.5086 .56584 .50855 .75755 .51012 .75744 .51009 .56562 Mtetra
.574 .369 .565 r
.51009 .56562 .51012 .75744 .51171 .75649 .51159 .56467 Mtetra
.575 .369 .565 r
.51159 .56467 .51171 .75649 .51329 .75543 .51309 .56334 Mtetra
.574 .369 .565 r
.51309 .56334 .51329 .75543 .51488 .7547 .51459 .56233 Mtetra
.573 .367 .564 r
.51459 .56233 .51488 .7547 .51646 .75447 .51609 .56234 Mtetra
.56 .357 .563 r
.51609 .56234 .51646 .75447 .51804 .75557 .51757 .56979 Mtetra
0 0 .405 r
.51757 .56979 .51804 .75557 .51962 .75709 .51876 .75334 Mtetra
.035 .097 .597 r
.51876 .75334 .51962 .75709 .52121 .75813 .52035 .75686 Mtetra
.123 .387 .842 r
.52035 .75686 .52121 .75813 .5228 .75846 .52194 .75789 Mtetra
.503 .774 .993 r
.52194 .75789 .5228 .75846 .52439 .75826 .52353 .75776 Mtetra
.637 .837 .977 r
.52353 .75776 .52439 .75826 .52598 .75789 .52512 .75729 Mtetra
.655 .813 .959 r
.52512 .75729 .52598 .75789 .52757 .75748 .52671 .7568 Mtetra
.635 .785 .954 r
.52671 .7568 .52757 .75748 .52917 .75708 .52831 .75639 Mtetra
.644 .786 .95 r
.52831 .75639 .52917 .75708 .53076 .75666 .5299 .75596 Mtetra
.644 .784 .948 r
.5299 .75596 .53076 .75666 .53236 .75623 .5315 .75553 Mtetra
.641 .781 .948 r
.5315 .75553 .53236 .75623 .53395 .75581 .5331 .75511 Mtetra
.642 .781 .948 r
.5331 .75511 .53395 .75581 .53555 .75539 .53469 .75468 Mtetra
.642 .78 .947 r
.53469 .75468 .53555 .75539 .53715 .75497 .53629 .75426 Mtetra
.643 .78 .947 r
.53629 .75426 .53715 .75497 .53875 .75454 .53789 .75383 Mtetra
.644 .78 .946 r
.53789 .75383 .53875 .75454 .54035 .75412 .53949 .7534 Mtetra
.644 .779 .946 r
.53949 .7534 .54035 .75412 .54195 .75369 .54109 .75297 Mtetra
.645 .779 .945 r
.54109 .75297 .54195 .75369 .54355 .75325 .5427 .75253 Mtetra
.646 .779 .944 r
.5427 .75253 .54355 .75325 .54515 .75282 .5443 .75209 Mtetra
.646 .778 .944 r
.5443 .75209 .54515 .75282 .54676 .75239 .5459 .75166 Mtetra
.646 .777 .943 r
.5459 .75166 .54676 .75239 .54836 .75196 .54751 .75122 Mtetra
.653 .778 .94 r
.54751 .75122 .54836 .75196 .54997 .75151 .54912 .75076 Mtetra
.67 .78 .932 r
.54912 .75076 .54997 .75151 .55157 .75101 .55072 .75024 Mtetra
.687 .778 .92 r
.55072 .75024 .55157 .75101 .55318 .75045 .55233 .74965 Mtetra
.689 .77 .913 r
.55233 .74965 .55318 .75045 .55479 .74989 .55394 .74905 Mtetra
.658 .752 .92 r
.55394 .74905 .55479 .74989 .5564 .74951 .55555 .74858 Mtetra
.621 .721 .917 r
.55555 .74858 .5564 .74951 .55801 .74931 .55716 .74827 Mtetra
.661 .711 .885 r
.55716 .74827 .55801 .74931 .55962 .74878 .55877 .74779 Mtetra
.757 .746 .842 r
.55877 .74779 .55962 .74878 .56122 .74713 .56038 .74673 Mtetra
.892 .855 .799 r
.56038 .74673 .56122 .74713 .56279 .74264 .56197 .74465 Mtetra
0 0 0 r
.56197 .74465 .56279 .74264 .56233 .55532 .56356 .74177 Mtetra
.567 .36 .559 r
.56356 .74177 .56233 .55532 .56378 .5479 .56514 .73884 Mtetra
.571 .362 .559 r
.56514 .73884 .56378 .5479 .5653 .54694 .56675 .73798 Mtetra
.572 .363 .559 r
.56675 .73798 .5653 .54694 .56683 .54688 .56837 .738 Mtetra
.572 .364 .559 r
.56837 .738 .56683 .54688 .56836 .54698 .56999 .73807 Mtetra
.571 .363 .559 r
.56999 .73807 .56836 .54698 .56989 .54655 .57161 .73769 Mtetra
.57161 .73769 .56989 .54655 .57142 .54614 .57323 .7373 Mtetra
.57323 .7373 .57142 .54614 .57295 .54571 .57485 .7369 Mtetra
.57485 .7369 .57295 .54571 .57448 .54526 .57647 .73648 Mtetra
.57647 .73648 .57448 .54526 .57601 .5448 .57809 .73605 Mtetra
.57809 .73605 .57601 .5448 .57754 .54434 .57971 .73562 Mtetra
.57971 .73562 .57754 .54434 .57908 .54389 .58133 .7352 Mtetra
.58133 .7352 .57908 .54389 .58061 .54344 .58295 .73477 Mtetra
.572 .363 .559 r
.58295 .73477 .58061 .54344 .58215 .54312 .58458 .73466 Mtetra
.572 .364 .559 r
.58458 .73466 .58215 .54312 .58369 .54305 .58622 .73498 Mtetra
.571 .363 .559 r
.58622 .73498 .58369 .54305 .58522 .54256 .58784 .7344 Mtetra
.566 .359 .559 r
.58784 .7344 .58522 .54256 .58674 .541 .58941 .73062 Mtetra
.029 0 .421 r
.58941 .73062 .58674 .541 .58824 .53854 .58753 .54179 Mtetra
0 0 0 r
.58753 .54179 .58824 .53854 .58975 .5366 .58898 .53653 Mtetra
.933 .908 .773 r
.58898 .53653 .58975 .5366 .59127 .53529 .59048 .53424 Mtetra
.709 .715 .854 r
.59048 .53424 .59127 .53529 .59281 .53469 .59201 .53352 Mtetra
.637 .668 .863 r
.59201 .53352 .59281 .53469 .59435 .53429 .59355 .53317 Mtetra
.616 .669 .878 r
.59355 .53317 .59435 .53429 .59589 .53393 .5951 .53292 Mtetra
.663 .707 .88 r
.5951 .53292 .59589 .53393 .59743 .53346 .59664 .53245 Mtetra
.663 .708 .881 r
.59664 .53245 .59743 .53346 .59897 .53298 .59818 .53198 Mtetra
.664 .71 .883 r
.59818 .53198 .59897 .53298 .60052 .53251 .59973 .53151 Mtetra
.665 .713 .884 r
.59973 .53151 .60052 .53251 .60206 .53203 .60127 .53104 Mtetra
.67 .716 .883 r
.60127 .53104 .60206 .53203 .6036 .53152 .60281 .53054 Mtetra
.68 .721 .88 r
.60281 .53054 .6036 .53152 .60515 .53096 .60436 .52999 Mtetra
.698 .728 .874 r
.60436 .52999 .60515 .53096 .60669 .53032 .6059 .52936 Mtetra
.697 .73 .876 r
.6059 .52936 .60669 .53032 .60823 .52968 .60744 .52872 Mtetra
.706 .734 .873 r
.60744 .52872 .60823 .52968 .60977 .52899 .60899 .52805 Mtetra
.734 .743 .859 r
.60899 .52805 .60977 .52899 .61131 .52814 .61053 .5272 Mtetra
.661 .723 .895 r
.61053 .5272 .61131 .52814 .61286 .52768 .61208 .52674 Mtetra
.305 .557 .924 r
.61208 .52674 .61286 .52768 .61443 .52819 .61365 .52724 Mtetra
.91 .511 .122 r
.61365 .52724 .61443 .52819 .61613 .53286 .61534 .53181 Mtetra
.962 .685 .462 r
.61534 .53181 .61613 .53286 .62305 .72646 .62222 .72552 Mtetra
.905 .499 .114 r
.62222 .72552 .62305 .72646 .62483 .73097 .62401 .73012 Mtetra
.135 .497 .906 r
.62401 .73012 .62483 .73097 .62652 .73164 .62569 .73081 Mtetra
.634 .753 .934 r
.62569 .73081 .62652 .73164 .62817 .73125 .62735 .73042 Mtetra
.827 .79 .816 r
.62735 .73042 .62817 .73125 .62979 .72964 .62896 .7288 Mtetra
.934 .754 .635 r
.62896 .7288 .62979 .72964 .63129 .7241 .63046 .72323 Mtetra
.963 .69 .471 r
.63046 .72323 .63129 .7241 .62704 .53018 .62626 .52929 Mtetra
.93 .747 .634 r
.62626 .52929 .62704 .53018 .62845 .52481 .62768 .52395 Mtetra
.759 .768 .86 r
.62768 .52395 .62845 .52481 .62999 .52381 .62922 .52297 Mtetra
.616 .732 .929 r
.62922 .52297 .62999 .52381 .63156 .52349 .63079 .52267 Mtetra
.527 .703 .951 r
.63079 .52267 .63156 .52349 .63313 .52341 .63236 .52263 Mtetra
.712 .777 .903 r
.63236 .52263 .63313 .52341 .63468 .52258 .63392 .52194 Mtetra
.676 .807 .945 r
.63392 .52194 .63468 .52258 .63624 .52203 .63548 .5214 Mtetra
.576 .777 .974 r
.63548 .5214 .63624 .52203 .63783 .5221 .63705 .52115 Mtetra
.351 .58 .928 r
.63705 .52115 .63783 .5221 .63949 .52451 .63865 .52157 Mtetra
.414 .384 .717 r
.63865 .52157 .63949 .52451 .64167 .5418 .64027 .52283 Mtetra
.509 .336 .582 r
.64027 .52283 .64167 .5418 .64953 .7198 .64199 .52658 Mtetra
.073 0 .452 r
.64199 .52658 .64953 .7198 .65128 .72194 .65028 .71588 Mtetra
.213 .175 .597 r
.65028 .71588 .65128 .72194 .653 .72284 .65213 .72064 Mtetra
.203 .307 .749 r
.65213 .72064 .653 .72284 .65469 .72307 .65388 .72238 Mtetra
.574 .769 .971 r
.65388 .72238 .65469 .72307 .65636 .72266 .65555 .72213 Mtetra
.706 .853 .952 r
.65555 .72213 .65636 .72266 .65802 .72201 .65721 .72141 Mtetra
.749 .841 .921 r
.65721 .72141 .65802 .72201 .65968 .72132 .65887 .72051 Mtetra
.555 .732 .958 r
.65887 .72051 .65968 .72132 .66137 .72134 .66055 .72036 Mtetra
.606 .71 .917 r
.66055 .72036 .66137 .72134 .66305 .7211 .66223 .72009 Mtetra
.678 .729 .889 r
.66223 .72009 .66305 .7211 .6647 .72029 .6639 .71952 Mtetra
.852 .804 .804 r
.6639 .71952 .6647 .72029 .66625 .71675 .66552 .71766 Mtetra
.774 .911 .524 r
.66552 .71766 .66625 .71675 .6675 .70568 .6671 .71502 Mtetra
.424 .209 .481 r
.6671 .71502 .6675 .70568 .66154 .5188 .66865 .7114 Mtetra
.572 .363 .559 r
.66865 .7114 .66154 .5188 .6631 .51771 .67034 .71129 Mtetra
.67034 .71129 .6631 .51771 .66469 .51752 .67203 .71126 Mtetra
.57 .362 .559 r
.67203 .71126 .66469 .51752 .66628 .51741 .67367 .7101 Mtetra
.085 0 .452 r
.67367 .7101 .66628 .51741 .66778 .51492 .6673 .52065 Mtetra
0 0 .259 r
.6673 .52065 .66778 .51492 .66929 .51287 .66859 .51339 Mtetra
.949 .95 .645 r
.66859 .51339 .66929 .51287 .67083 .51133 .67007 .51041 Mtetra
.72 .749 .875 r
.67007 .51041 .67083 .51133 .67241 .51076 .67164 .50964 Mtetra
.62 .676 .882 r
.67164 .50964 .67241 .51076 .674 .51042 .67323 .50936 Mtetra
.56 .661 .904 r
.67323 .50936 .674 .51042 .67559 .51018 .67484 .5093 Mtetra
.712 .758 .888 r
.67484 .5093 .67559 .51018 .67716 .50931 .67641 .50859 Mtetra
.699 .796 .925 r
.67641 .50859 .67716 .50931 .67874 .50863 .67799 .50796 Mtetra
.624 .786 .959 r
.67799 .50796 .67874 .50863 .68034 .50842 .67958 .50758 Mtetra
.096 .458 .887 r
.67958 .50758 .68034 .50842 .68205 .51056 .68123 .50836 Mtetra
.252 .328 .748 r
.68123 .50836 .68205 .51056 .68407 .51921 .68292 .50997 Mtetra
.47 .33 .608 r
.68292 .50997 .68407 .51921 .69474 .7072 .68467 .51282 Mtetra
.569 .365 .564 r
.68467 .51282 .69474 .7072 .69653 .70879 .68639 .51486 Mtetra
.573 .368 .564 r
.68639 .51486 .69653 .70879 .69823 .7085 .68801 .51485 Mtetra
.577 .37 .565 r
.68801 .51485 .69823 .7085 .69985 .70668 .68951 .51239 Mtetra
.579 .372 .565 r
.68951 .51239 .69985 .70668 .70092 .69382 .69093 .50838 Mtetra
.577 .371 .565 r
.69093 .50838 .70092 .69382 .69326 .50834 .69241 .5056 Mtetra
.732 .587 .693 r
.69241 .5056 .69326 .50834 .69469 .50462 .69394 .50369 Mtetra
.703 .745 .884 r
.69394 .50369 .69469 .50462 .69626 .50365 .69552 .50301 Mtetra
.585 .785 .974 r
.69552 .50301 .69626 .50365 .69787 .50335 .69713 .50273 Mtetra
.523 .761 .983 r
.69713 .50273 .69787 .50335 .69949 .50336 .69875 .50259 Mtetra
.647 .768 .936 r
.69875 .50259 .69949 .50336 .70109 .50297 .70035 .50216 Mtetra
.678 .766 .917 r
.70035 .50216 .70109 .50297 .70269 .50246 .70195 .50161 Mtetra
.693 .761 .905 r
.70195 .50161 .70269 .50246 .70429 .50189 .70354 .50099 Mtetra
.779 .774 .848 r
.70354 .50099 .70429 .50189 .70586 .50079 .70511 .49985 Mtetra
.74 .756 .866 r
.70511 .49985 .70586 .50079 .70744 .49994 .70669 .49897 Mtetra
.605 .703 .913 r
.70669 .49897 .70744 .49994 .70906 .49972 .70831 .49872 Mtetra
.722 .274 0 r
.70831 .49872 .70906 .49972 .71086 .50279 .71011 .50172 Mtetra
.971 .683 .425 r
.71011 .50172 .71086 .50279 .72342 .69641 .72262 .69524 Mtetra
.929 .554 .158 r
.72262 .69524 .72342 .69641 .72554 .70329 .72476 .70241 Mtetra
0 .324 .801 r
.72476 .70241 .72554 .70329 .72734 .70443 .72656 .70357 Mtetra
.589 .736 .945 r
.72656 .70357 .72734 .70443 .72906 .70417 .72828 .70332 Mtetra
.793 .796 .855 r
.72828 .70332 .72906 .70417 .73073 .7029 .72995 .70205 Mtetra
.933 .777 .666 r
.72995 .70205 .73073 .7029 .73222 .69861 .73144 .69776 Mtetra
.971 .689 .436 r
.73144 .69776 .73222 .69861 .72244 .50458 .72169 .50369 Mtetra
.957 .743 .573 r
.72169 .50369 .72244 .50458 .72361 .49667 .72287 .49578 Mtetra
.83 .783 .807 r
.72287 .49578 .72361 .49667 .72515 .49504 .72441 .49415 Mtetra
.645 .739 .917 r
.72441 .49415 .72515 .49504 .72677 .49461 .72603 .49374 Mtetra
.506 .682 .946 r
.72603 .49374 .72677 .49461 .72841 .49463 .72768 .49377 Mtetra
.607 .731 .933 r
.72768 .49377 .72841 .49463 .73004 .49432 .72931 .49349 Mtetra
.652 .754 .925 r
.72931 .49349 .73004 .49432 .73166 .49385 .73093 .49304 Mtetra
.667 .766 .924 r
.73093 .49304 .73166 .49385 .73327 .49332 .73254 .49253 Mtetra
.736 .79 .895 r
.73254 .49253 .73327 .49332 .73486 .49238 .73414 .4917 Mtetra
.738 .819 .915 r
.73414 .4917 .73486 .49238 .73646 .49152 .73574 .49088 Mtetra
.675 .814 .95 r
.73574 .49088 .73646 .49152 .73808 .49111 .73736 .49032 Mtetra
.433 .67 .962 r
.73736 .49032 .73808 .49111 .73982 .49244 .73902 .49047 Mtetra
.381 .432 .789 r
.73902 .49047 .73982 .49244 .7418 .49745 .74074 .49147 Mtetra
.419 .319 .635 r
.74074 .49147 .7418 .49745 .75609 .68922 .74257 .49411 Mtetra
.131 .044 .482 r
.74257 .49411 .75609 .68922 .75809 .69292 .75673 .68315 Mtetra
.228 .161 .57 r
.75673 .68315 .75809 .69292 .75993 .69416 .75901 .6911 Mtetra
.235 .273 .697 r
.75901 .6911 .75993 .69416 .76172 .69462 .76094 .69354 Mtetra
.398 .592 .922 r
.76094 .69354 .76172 .69462 .76348 .69449 .76273 .69395 Mtetra
.603 .831 .987 r
.76273 .69395 .76348 .69449 .76521 .69404 .76447 .69352 Mtetra
.69 .867 .966 r
.76447 .69352 .76521 .69404 .76693 .69346 .76618 .69282 Mtetra
.63 .816 .971 r
.76618 .69282 .76693 .69346 .76867 .69305 .76792 .69236 Mtetra
.588 .783 .973 r
.76792 .69236 .76867 .69305 .77042 .69275 .76967 .69205 Mtetra
.592 .78 .97 r
.76967 .69205 .77042 .69275 .77217 .69245 .77142 .69173 Mtetra
.617 .785 .962 r
.77142 .69173 .77217 .69245 .77391 .69208 .77316 .69134 Mtetra
.632 .787 .956 r
.77316 .69134 .77391 .69208 .77566 .69165 .7749 .6909 Mtetra
.638 .787 .953 r
.7749 .6909 .77566 .69165 .7774 .6912 .77664 .69044 Mtetra
.638 .785 .952 r
.77664 .69044 .7774 .6912 .77914 .69075 .77839 .68999 Mtetra
.637 .783 .952 r
.77839 .68999 .77914 .69075 .78088 .6903 .78013 .68954 Mtetra
.638 .783 .951 r
.78013 .68954 .78088 .6903 .78263 .68985 .78188 .68909 Mtetra
.639 .782 .95 r
.78188 .68909 .78263 .68985 .78437 .6894 .78362 .68863 Mtetra
.78362 .68863 .78437 .6894 .78612 .68895 .78537 .68818 Mtetra
.64 .782 .95 r
.78537 .68818 .78612 .68895 .78787 .68849 .78712 .68772 Mtetra
.64 .782 .949 r
.78712 .68772 .78787 .68849 .78962 .68803 .78887 .68726 Mtetra
.641 .782 .949 r
.78887 .68726 .78962 .68803 .79137 .68757 .79062 .6868 Mtetra
.79062 .6868 .79137 .68757 .79312 .68711 .79237 .68633 Mtetra
.79237 .68633 .79312 .68711 .79487 .68664 .79412 .68587 Mtetra
.79412 .68587 .79487 .68664 .79662 .68618 .79587 .6854 Mtetra
.642 .782 .949 r
.79587 .6854 .79662 .68618 .79837 .68572 .79763 .68494 Mtetra
.642 .782 .948 r
.79763 .68494 .79837 .68572 .80013 .68525 .79938 .68447 Mtetra
.79938 .68447 .80013 .68525 .80188 .68478 .80114 .684 Mtetra
.80114 .684 .80188 .68478 .80364 .68431 .8029 .68353 Mtetra
.643 .782 .948 r
.8029 .68353 .80364 .68431 .8054 .68385 .80465 .68306 Mtetra
.80465 .68306 .8054 .68385 .80716 .68338 .80641 .68259 Mtetra
.643 .781 .948 r
.80641 .68259 .80716 .68338 .80892 .68291 .80817 .68212 Mtetra
.643 .781 .947 r
.80817 .68212 .80892 .68291 .81068 .68244 .80994 .68165 Mtetra
.80994 .68165 .81068 .68244 .81244 .68197 .8117 .68118 Mtetra
.8117 .68118 .81244 .68197 .8142 .6815 .81346 .68071 Mtetra
.643 .78 .947 r
.81346 .68071 .8142 .6815 .81596 .68102 .81523 .68023 Mtetra
.81523 .68023 .81596 .68102 .81773 .68055 .81699 .67976 Mtetra
.81699 .67976 .81773 .68055 .81949 .68008 .81876 .67929 Mtetra
.81876 .67929 .81949 .68008 .82126 .67961 .82053 .67882 Mtetra
.643 .78 .946 r
.82053 .67882 .82126 .67961 .82303 .67914 .82229 .67835 Mtetra
.643 .779 .946 r
.82229 .67835 .82303 .67914 .8248 .67867 .82406 .67787 Mtetra
.82406 .67787 .8248 .67867 .82657 .6782 .82584 .6774 Mtetra
.82584 .6774 .82657 .6782 .82834 .67773 .82761 .67693 Mtetra
.82761 .67693 .82834 .67773 .83011 .67726 .82938 .67646 Mtetra
.642 .779 .946 r
.82938 .67646 .83011 .67726 .83189 .67679 .83116 .67599 Mtetra
.83116 .67599 .83189 .67679 .83366 .67632 .83293 .67552 Mtetra
.83293 .67552 .83366 .67632 .83544 .67585 .83471 .67505 Mtetra
.642 .779 .947 r
.83471 .67505 .83544 .67585 .83722 .67537 .83649 .67457 Mtetra
.83649 .67457 .83722 .67537 .83899 .6749 .83827 .6741 Mtetra
.83827 .6741 .83899 .6749 .84077 .67443 .84005 .67363 Mtetra
.84005 .67363 .84077 .67443 .84255 .67396 .84183 .67316 Mtetra
.84183 .67316 .84255 .67396 .84433 .67349 .84361 .67269 Mtetra
.641 .779 .947 r
.84361 .67269 .84433 .67349 .84612 .67302 .84539 .67222 Mtetra
.84539 .67222 .84612 .67302 .8479 .67255 .84718 .67175 Mtetra
.641 .78 .947 r
.84718 .67175 .8479 .67255 .84969 .67208 .84896 .67128 Mtetra
.84896 .67128 .84969 .67208 .85147 .67161 .85075 .67081 Mtetra
.641 .78 .948 r
.85075 .67081 .85147 .67161 .85326 .67114 .85254 .67034 Mtetra
.85254 .67034 .85326 .67114 .85505 .67066 .85433 .66986 Mtetra
.85433 .66986 .85505 .67066 .85684 .67019 .85612 .66939 Mtetra
.641 .781 .948 r
.85612 .66939 .85684 .67019 .85863 .66972 .85791 .66892 Mtetra
.85791 .66892 .85863 .66972 .86042 .66924 .8597 .66844 Mtetra
.642 .781 .948 r
.8597 .66844 .86042 .66924 .86221 .66877 .86149 .66797 Mtetra
.86149 .66797 .86221 .66877 .864 .66829 .86329 .66749 Mtetra
.86329 .66749 .864 .66829 .8658 .66782 .86508 .66702 Mtetra
.86508 .66702 .8658 .66782 .86759 .66734 .86688 .66654 Mtetra
.86688 .66654 .86759 .66734 .86939 .66686 .86868 .66606 Mtetra
.86868 .66606 .86939 .66686 .87119 .66638 .87048 .66558 Mtetra
.643 .782 .948 r
.87048 .66558 .87119 .66638 .87299 .6659 .87228 .6651 Mtetra
.87228 .6651 .87299 .6659 .87479 .66542 .87408 .66462 Mtetra
.87408 .66462 .87479 .66542 .87659 .66494 .87588 .66413 Mtetra
.644 .782 .947 r
.87588 .66413 .87659 .66494 .87839 .66445 .87768 .66365 Mtetra
.645 .782 .947 r
.87768 .66365 .87839 .66445 .88019 .66396 .87948 .66316 Mtetra
.87948 .66316 .88019 .66396 .88199 .66347 .88129 .66267 Mtetra
.647 .782 .946 r
.88129 .66267 .88199 .66347 .8838 .66298 .88309 .66217 Mtetra
.647 .781 .945 r
.88309 .66217 .8838 .66298 .8856 .66249 .8849 .66167 Mtetra
.647 .78 .945 r
.8849 .66167 .8856 .66249 .88741 .662 .8867 .66118 Mtetra
.653 .782 .942 r
.8867 .66118 .88741 .662 .88922 .66148 .88851 .66065 Mtetra
.669 .786 .936 r
.88851 .66065 .88922 .66148 .89102 .66092 .89031 .66007 Mtetra
.69 .789 .926 r
.89031 .66007 .89102 .66092 .89281 .66028 .8921 .6594 Mtetra
.693 .781 .919 r
.8921 .6594 .89281 .66028 .8946 .65963 .89389 .65871 Mtetra
.684 .769 .916 r
.89389 .65871 .8946 .65963 .8964 .65901 .89569 .65806 Mtetra
.663 .754 .918 r
.89569 .65806 .8964 .65901 .89821 .65848 .8975 .65751 Mtetra
.655 .748 .918 r
.8975 .65751 .89821 .65848 .90003 .65797 .89931 .657 Mtetra
.652 .746 .918 r
.89931 .657 .90003 .65797 .90184 .65748 .90112 .6565 Mtetra
.654 .746 .917 r
.90112 .6565 .90184 .65748 .90366 .65698 .90294 .656 Mtetra
.653 .744 .917 r
.90294 .656 .90366 .65698 .90547 .65648 .90476 .6555 Mtetra
.651 .743 .916 r
.90476 .6555 .90547 .65648 .90729 .65599 .90658 .655 Mtetra
.65 .742 .916 r
.90658 .655 .90729 .65599 .90911 .6555 .9084 .65451 Mtetra
.649 .741 .917 r
.9084 .65451 .90911 .6555 .91093 .65502 .91022 .65403 Mtetra
.648 .74 .917 r
.91022 .65403 .91093 .65502 .91276 .65454 .91205 .65355 Mtetra
.646 .74 .918 r
.91205 .65355 .91276 .65454 .91458 .65406 .91387 .65307 Mtetra
.645 .74 .918 r
.91387 .65307 .91458 .65406 .91641 .65359 .9157 .65261 Mtetra
.644 .741 .919 r
.9157 .65261 .91641 .65359 .91824 .65312 .91753 .65214 Mtetra
.645 .742 .92 r
.91753 .65214 .91824 .65312 .92007 .65265 .91936 .65167 Mtetra
.639 .741 .922 r
.91936 .65167 .92007 .65265 .9219 .65219 .92119 .65122 Mtetra
.626 .737 .927 r
.92119 .65122 .9219 .65219 .92374 .65178 .92304 .65083 Mtetra
.599 .73 .936 r
.92304 .65083 .92374 .65178 .92559 .65146 .92489 .65054 Mtetra
.596 .737 .943 r
.92489 .65054 .92559 .65146 .92744 .65113 .92675 .65025 Mtetra
.605 .75 .947 r
.92675 .65025 .92744 .65113 .92929 .65077 .9286 .64992 Mtetra
.632 .768 .945 r
.9286 .64992 .92929 .65077 .93113 .65032 .93044 .64948 Mtetra
.641 .774 .944 r
.93044 .64948 .93113 .65032 .93296 .64984 .93228 .649 Mtetra
.645 .777 .943 r
.93228 .649 .93296 .64984 .9348 .64935 .93411 .6485 Mtetra
.642 .775 .944 r
.93411 .6485 .9348 .64935 .93664 .64887 .93595 .64802 Mtetra
.65 .777 .942 r
.93595 .64802 .93664 .64887 .93847 .64836 .93779 .64751 Mtetra
.663 .781 .936 r
.93779 .64751 .93847 .64836 .94031 .64781 .93962 .64694 Mtetra
.688 .786 .925 r
.93962 .64694 .94031 .64781 .94213 .64717 .94144 .64626 Mtetra
.693 .78 .918 r
.94144 .64626 .94213 .64717 .94395 .64651 .94326 .64557 Mtetra
.688 .768 .912 r
.94326 .64557 .94395 .64651 .94578 .64588 .94508 .64489 Mtetra
.666 .751 .913 r
.94508 .64489 .94578 .64588 .94762 .64533 .94692 .64432 Mtetra
.659 .743 .912 r
.94692 .64432 .94762 .64533 .94946 .64481 .94876 .64378 Mtetra
.655 .738 .91 r
.94876 .64378 .94946 .64481 .95131 .64431 .95061 .64327 Mtetra
.658 .736 .907 r
.95061 .64327 .95131 .64431 .95315 .6438 .95245 .64274 Mtetra
.655 .731 .905 r
.95245 .64274 .95315 .6438 .955 .6433 .9543 .64222 Mtetra
.65 .726 .905 r
.9543 .64222 .955 .6433 .95685 .64282 .95615 .64174 Mtetra
.641 .72 .905 r
.95615 .64174 .95685 .64282 .95871 .64237 .95801 .64129 Mtetra
.637 .718 .906 r
.95801 .64129 .95871 .64237 .96057 .64194 .95987 .64086 Mtetra
.625 .713 .91 r
.95987 .64086 .96057 .64194 .96244 .64156 .96174 .64048 Mtetra
.517 .663 .927 r
.96174 .64048 .96244 .64156 .96436 .64158 .96366 .64053 Mtetra
.62 .719 .916 r
.96366 .64053 .96436 .64158 .96623 .64121 .96554 .64017 Mtetra
.776 .782 .857 r
.96554 .64017 .96623 .64121 .96799 .63998 .9673 .63894 Mtetra
.967 .778 .597 r
.9673 .63894 .96799 .63998 .96921 .6345 .9685 .63329 Mtetra
.975 .669 .324 r
.9685 .63329 .96921 .6345 .94537 .43492 .94467 .43359 Mtetra
.953 .749 .59 r
.94467 .43359 .94537 .43492 .94639 .42883 .94573 .42774 Mtetra
.756 .754 .85 r
.94573 .42774 .94639 .42883 .94806 .42773 .9474 .42667 Mtetra
.626 .705 .903 r
.9474 .42667 .94806 .42773 .94982 .42737 .94917 .42632 Mtetra
.537 .664 .918 r
.94917 .42632 .94982 .42737 .95163 .42735 .95098 .42631 Mtetra
.667 .727 .895 r
.95098 .42631 .95163 .42735 .95337 .4268 .95272 .42577 Mtetra
.675 .733 .894 r
.95272 .42577 .95337 .4268 .95511 .42621 .95446 .42518 Mtetra
.688 .74 .891 r
.95446 .42518 .95511 .42621 .95684 .42556 .95619 .42453 Mtetra
.785 .775 .844 r
.95619 .42453 .95684 .42556 .95849 .42432 .95784 .42328 Mtetra
.726 .752 .873 r
.95784 .42328 .95849 .42432 .9602 .42347 .95955 .42242 Mtetra
.579 .684 .912 r
.95955 .42242 .9602 .42347 .962 .42333 .96135 .42225 Mtetra
.911 .556 .354 r
.39224 .59385 .39312 .59412 .39439 .59793 .39349 .59815 Mtetra
.936 .681 .527 r
.39349 .59815 .39439 .59793 .3887 .78633 .38776 .78628 Mtetra
.902 .558 .382 r
.38776 .78628 .3887 .78633 .38999 .7918 .38908 .79109 Mtetra
0 .408 .834 r
.38908 .79109 .38999 .7918 .39147 .79254 .39056 .79179 Mtetra
.637 .758 .936 r
.39056 .79179 .39147 .79254 .39298 .79215 .39207 .79142 Mtetra
.811 .781 .825 r
.39207 .79142 .39298 .79215 .39454 .79066 .39363 .79001 Mtetra
.914 .742 .654 r
.39363 .79001 .39454 .79066 .39626 .78467 .39533 .78457 Mtetra
.938 .687 .532 r
.39533 .78457 .39626 .78467 .40444 .59505 .40355 .59518 Mtetra
.954 .792 .643 r
.40355 .59518 .40444 .59505 .40604 .59016 .40517 .58984 Mtetra
.813 .876 .892 r
.40517 .58984 .40604 .59016 .4075 .58896 .40663 .58872 Mtetra
.547 .872 .993 r
.40663 .58872 .4075 .58896 .40894 .58856 .40807 .58836 Mtetra
.182 .694 .895 r
.40807 .58836 .40894 .58856 .41036 .58871 .40949 .58837 Mtetra
.526 .837 .999 r
.40949 .58837 .41036 .58871 .41176 .58947 .41093 .58811 Mtetra
.625 .625 .83 r
.41093 .58811 .41176 .58947 .41314 .5909 .41236 .58784 Mtetra
.609 .497 .701 r
.41236 .58784 .41314 .5909 .4145 .59322 .4138 .58756 Mtetra
.621 .459 .641 r
.4138 .58756 .4145 .59322 .41594 .59293 .41526 .58675 Mtetra
.607 .444 .635 r
.41526 .58675 .41594 .59293 .41739 .59218 .41671 .58617 Mtetra
.577 .424 .637 r
.41671 .58617 .41739 .59218 .41882 .59234 .41814 .58621 Mtetra
.256 .189 .587 r
.41814 .58621 .41882 .59234 .41467 .77477 .41945 .59004 Mtetra
0 0 .344 r
.41945 .59004 .41467 .77477 .41595 .78248 .41515 .77833 Mtetra
0 0 .382 r
.41515 .77833 .41595 .78248 .41739 .78497 .41651 .78353 Mtetra
.412 .523 .86 r
.41651 .78353 .41739 .78497 .4189 .78517 .41801 .78403 Mtetra
.659 .684 .863 r
.41801 .78403 .4189 .78517 .42044 .78474 .41955 .78358 Mtetra
.721 .7 .83 r
.41955 .78358 .42044 .78474 .42198 .78403 .42109 .78274 Mtetra
.659 .66 .84 r
.42109 .78274 .42198 .78403 .42351 .78355 .42263 .78227 Mtetra
.645 .656 .847 r
.42263 .78227 .42351 .78355 .42505 .78312 .42416 .78188 Mtetra
.646 .664 .853 r
.42416 .78188 .42505 .78312 .42659 .78269 .4257 .78149 Mtetra
.646 .671 .86 r
.4257 .78149 .42659 .78269 .42812 .78243 .42723 .7811 Mtetra
.647 .651 .84 r
.42723 .7811 .42812 .78243 .42965 .78209 .42877 .7807 Mtetra
.651 .644 .83 r
.42877 .7807 .42965 .78209 .4312 .7815 .43031 .78027 Mtetra
.669 .673 .845 r
.43031 .78027 .4312 .7815 .43277 .77993 .43185 .77975 Mtetra
.609 .91 .982 r
.43185 .77975 .43277 .77993 .43435 .77754 .4334 .7792 Mtetra
.38 .006 .197 r
.4334 .7792 .43435 .77754 .43596 .77427 .43494 .77865 Mtetra
.552 .275 .449 r
.43494 .77865 .43596 .77427 .43751 .77342 .43647 .77863 Mtetra
.545 .28 .464 r
.43647 .77863 .43751 .77342 .43904 .77348 .43801 .77844 Mtetra
.498 .233 .444 r
.43801 .77844 .43904 .77348 .44059 .7727 .43957 .77761 Mtetra
.061 0 .273 r
.43957 .77761 .44059 .7727 .44628 .59218 .4412 .77339 Mtetra
0 0 .337 r
.4412 .77339 .44628 .59218 .44799 .58082 .44705 .58432 Mtetra
.82 .783 .28 r
.44705 .58432 .44799 .58082 .44952 .57751 .44866 .57747 Mtetra
.882 .929 .848 r
.44866 .57747 .44952 .57751 .451 .57646 .45015 .57588 Mtetra
.669 .807 .949 r
.45015 .57588 .451 .57646 .45245 .57616 .45161 .5754 Mtetra
.542 .716 .953 r
.45161 .5754 .45245 .57616 .45391 .57615 .45307 .57531 Mtetra
.623 .724 .919 r
.45307 .57531 .45391 .57615 .45537 .57589 .45453 .57501 Mtetra
.649 .723 .902 r
.45453 .57501 .45537 .57589 .45683 .5755 .456 .57463 Mtetra
.649 .725 .904 r
.456 .57463 .45683 .5755 .4583 .57505 .45746 .57424 Mtetra
.658 .743 .913 r
.45746 .57424 .4583 .57505 .45977 .57449 .45893 .57382 Mtetra
.662 .778 .935 r
.45893 .57382 .45977 .57449 .46124 .5739 .4604 .57337 Mtetra
.658 .819 .961 r
.4604 .57337 .46124 .5739 .46271 .5733 .46187 .5729 Mtetra
.657 .859 .977 r
.46187 .5729 .46271 .5733 .46418 .57264 .46334 .5724 Mtetra
.622 .897 .987 r
.46334 .5724 .46418 .57264 .46566 .57206 .46481 .57189 Mtetra
.58 .901 .983 r
.46481 .57189 .46566 .57206 .46712 .57173 .46628 .57141 Mtetra
.712 .891 .962 r
.46628 .57141 .46712 .57173 .46859 .57196 .46776 .57072 Mtetra
.674 .665 .833 r
.46776 .57072 .46859 .57196 .47003 .57293 .46923 .57019 Mtetra
.578 .492 .721 r
.46923 .57019 .47003 .57293 .47146 .57532 .4707 .57021 Mtetra
.329 .259 .625 r
.4707 .57021 .47146 .57532 .47014 .75799 .47212 .57297 Mtetra
0 0 .373 r
.47212 .57297 .47014 .75799 .47155 .76734 .47075 .76105 Mtetra
0 0 .438 r
.47075 .76105 .47155 .76734 .47307 .76989 .4722 .76806 Mtetra
.265 .383 .797 r
.4722 .76806 .47307 .76989 .47462 .77038 .47374 .76919 Mtetra
.624 .667 .871 r
.47374 .76919 .47462 .77038 .47618 .77 .47531 .7689 Mtetra
.709 .71 .849 r
.47531 .7689 .47618 .77 .47775 .76931 .47688 .76816 Mtetra
.677 .691 .856 r
.47688 .76816 .47775 .76931 .47932 .76889 .47844 .7676 Mtetra
.648 .659 .847 r
.47844 .7676 .47932 .76889 .48088 .76856 .48001 .76719 Mtetra
.654 .649 .833 r
.48001 .76719 .48088 .76856 .48245 .76801 .48158 .76673 Mtetra
.611 .647 .861 r
.48158 .76673 .48245 .76801 .48403 .76687 .48315 .7665 Mtetra
.548 .847 .998 r
.48315 .7665 .48403 .76687 .48561 .76493 .48471 .76617 Mtetra
.144 0 0 r
.48471 .76617 .48561 .76493 .48721 .76156 .48629 .76526 Mtetra
0 0 .198 r
.48629 .76526 .48721 .76156 .49061 .58019 .48789 .76167 Mtetra
0 0 .362 r
.48789 .76167 .49061 .58019 .49222 .56745 .49133 .57289 Mtetra
0 0 0 r
.49133 .57289 .49222 .56745 .49373 .56415 .49289 .56441 Mtetra
.923 .962 .783 r
.49289 .56441 .49373 .56415 .49522 .56277 .49439 .56235 Mtetra
.694 .859 .961 r
.49439 .56235 .49522 .56277 .49671 .56226 .49588 .56174 Mtetra
.533 .788 .991 r
.49588 .56174 .49671 .56226 .4982 .56203 .49737 .56155 Mtetra
.576 .815 .989 r
.49737 .56155 .4982 .56203 .49968 .56162 .49886 .56126 Mtetra
.62 .864 .989 r
.49886 .56126 .49968 .56162 .50117 .56109 .50035 .56081 Mtetra
.577 .876 .994 r
.50035 .56081 .50117 .56109 .50266 .56076 .50184 .5604 Mtetra
.565 .85 .997 r
.50184 .5604 .50266 .56076 .50415 .56111 .50333 .56006 Mtetra
.626 .683 .884 r
.50333 .56006 .50415 .56111 .50563 .5623 .50482 .55977 Mtetra
.615 .525 .729 r
.50482 .55977 .50563 .5623 .50711 .56429 .50631 .55947 Mtetra
.604 .457 .655 r
.50631 .55947 .50711 .56429 .5086 .56584 .5078 .55908 Mtetra
.6 .435 .63 r
.5078 .55908 .5086 .56584 .51009 .56562 .5093 .55861 Mtetra
.6 .433 .627 r
.5093 .55861 .51009 .56562 .51159 .56467 .51079 .55812 Mtetra
.611 .445 .632 r
.51079 .55812 .51159 .56467 .51309 .56334 .51229 .5574 Mtetra
.614 .452 .638 r
.51229 .5574 .51309 .56334 .51459 .56233 .51379 .55668 Mtetra
.591 .438 .642 r
.51379 .55668 .51459 .56233 .51609 .56234 .51529 .55647 Mtetra
.457 .34 .633 r
.51529 .55647 .51609 .56234 .51757 .56979 .51678 .55834 Mtetra
.968 .702 .474 r
.51678 .55834 .51757 .56979 .51876 .75334 .51792 .74314 Mtetra
0 0 .406 r
.51792 .74314 .51876 .75334 .52035 .75686 .51948 .75484 Mtetra
.09 .249 .734 r
.51948 .75484 .52035 .75686 .52194 .75789 .52107 .7566 Mtetra
.6 .641 .863 r
.52107 .7566 .52194 .75789 .52353 .75776 .52266 .75642 Mtetra
.69 .67 .826 r
.52266 .75642 .52353 .75776 .52512 .75729 .52426 .75574 Mtetra
.677 .639 .805 r
.52426 .75574 .52512 .75729 .52671 .7568 .52585 .75509 Mtetra
.642 .607 .799 r
.52585 .75509 .52671 .7568 .52831 .75639 .52744 .75467 Mtetra
.643 .606 .797 r
.52744 .75467 .52831 .75639 .5299 .75596 .52904 .75424 Mtetra
.52904 .75424 .5299 .75596 .5315 .75553 .53064 .75381 Mtetra
.642 .606 .798 r
.53064 .75381 .5315 .75553 .5331 .75511 .53223 .75338 Mtetra
.642 .605 .797 r
.53223 .75338 .5331 .75511 .53469 .75468 .53383 .75295 Mtetra
.53383 .75295 .53469 .75468 .53629 .75426 .53543 .75253 Mtetra
.53543 .75253 .53629 .75426 .53789 .75383 .53703 .7521 Mtetra
.643 .605 .796 r
.53703 .7521 .53789 .75383 .53949 .7534 .53863 .75166 Mtetra
.53863 .75166 .53949 .7534 .54109 .75297 .54023 .75123 Mtetra
.644 .605 .795 r
.54023 .75123 .54109 .75297 .5427 .75253 .54184 .75078 Mtetra
.54184 .75078 .5427 .75253 .5443 .75209 .54344 .75034 Mtetra
.645 .605 .794 r
.54344 .75034 .5443 .75209 .5459 .75166 .54504 .74988 Mtetra
.646 .603 .791 r
.54504 .74988 .5459 .75166 .54751 .75122 .54665 .74942 Mtetra
.645 .6 .789 r
.54665 .74942 .54751 .75122 .54912 .75076 .54826 .74896 Mtetra
.643 .599 .789 r
.54826 .74896 .54912 .75076 .55072 .75024 .54986 .74851 Mtetra
.641 .605 .798 r
.54986 .74851 .55072 .75024 .55233 .74965 .55147 .74809 Mtetra
.643 .625 .817 r
.55147 .74809 .55233 .74965 .55394 .74905 .55308 .74767 Mtetra
.645 .649 .84 r
.55308 .74767 .55394 .74905 .55555 .74858 .55469 .74726 Mtetra
.646 .658 .847 r
.55469 .74726 .55555 .74858 .55716 .74827 .5563 .74685 Mtetra
.649 .645 .833 r
.5563 .74685 .55716 .74827 .55877 .74779 .55791 .74641 Mtetra
.66 .655 .834 r
.55791 .74641 .55877 .74779 .56038 .74673 .55953 .74591 Mtetra
.683 .766 .914 r
.55953 .74591 .56038 .74673 .56197 .74465 .56114 .74534 Mtetra
.082 0 0 r
.56114 .74534 .56197 .74465 .56356 .74177 .56275 .74476 Mtetra
.484 .179 .373 r
.56275 .74476 .56356 .74177 .56514 .73884 .56437 .74425 Mtetra
.533 .27 .462 r
.56437 .74425 .56514 .73884 .56675 .73798 .56598 .74383 Mtetra
.538 .279 .471 r
.56598 .74383 .56675 .73798 .56837 .738 .5676 .74345 Mtetra
.535 .272 .464 r
.5676 .74345 .56837 .738 .56999 .73807 .56922 .74306 Mtetra
.53 .262 .454 r
.56922 .74306 .56999 .73807 .57161 .73769 .57084 .74265 Mtetra
.529 .261 .453 r
.57084 .74265 .57161 .73769 .57323 .7373 .57246 .74223 Mtetra
.528 .26 .452 r
.57246 .74223 .57323 .7373 .57485 .7369 .57408 .7418 Mtetra
.527 .259 .451 r
.57408 .7418 .57485 .7369 .57647 .73648 .5757 .74137 Mtetra
.5757 .74137 .57647 .73648 .57809 .73605 .57733 .74093 Mtetra
.57733 .74093 .57809 .73605 .57971 .73562 .57895 .7405 Mtetra
.528 .259 .451 r
.57895 .7405 .57971 .73562 .58133 .7352 .58058 .74008 Mtetra
.527 .259 .451 r
.58058 .74008 .58133 .7352 .58295 .73477 .5822 .73965 Mtetra
.538 .268 .454 r
.5822 .73965 .58295 .73477 .58458 .73466 .58383 .73937 Mtetra
.551 .277 .453 r
.58383 .73937 .58458 .73466 .58622 .73498 .58547 .73932 Mtetra
.514 .239 .434 r
.58547 .73932 .58622 .73498 .58784 .7344 .5871 .73879 Mtetra
.378 .122 .395 r
.5871 .73879 .58784 .7344 .58941 .73062 .5887 .73682 Mtetra
0 0 .126 r
.5887 .73682 .58941 .73062 .58753 .54179 .59017 .72772 Mtetra
.004 0 .412 r
.59017 .72772 .58753 .54179 .58898 .53653 .58822 .53735 Mtetra
.96 .93 .599 r
.58822 .53735 .58898 .53653 .59048 .53424 .5897 .53382 Mtetra
.75 .878 .938 r
.5897 .53382 .59048 .53424 .59201 .53352 .59123 .53298 Mtetra
.58 .804 .984 r
.59123 .53298 .59201 .53352 .59355 .53317 .59277 .53269 Mtetra
.49 .787 .998 r
.59277 .53269 .59355 .53317 .5951 .53292 .59432 .53254 Mtetra
.618 .867 .989 r
.59432 .53254 .5951 .53292 .59664 .53245 .59586 .53208 Mtetra
.615 .867 .99 r
.59586 .53208 .59664 .53245 .59818 .53198 .59741 .53162 Mtetra
.616 .869 .99 r
.59741 .53162 .59818 .53198 .59973 .53151 .59895 .53115 Mtetra
.622 .873 .989 r
.59895 .53115 .59973 .53151 .60127 .53104 .6005 .53067 Mtetra
.628 .872 .988 r
.6005 .53067 .60127 .53104 .60281 .53054 .60204 .53018 Mtetra
.632 .876 .987 r
.60204 .53018 .60281 .53054 .60436 .52999 .60359 .52968 Mtetra
.63 .888 .987 r
.60359 .52968 .60436 .52999 .6059 .52936 .60513 .52915 Mtetra
.591 .905 .982 r
.60513 .52915 .6059 .52936 .60744 .52872 .60668 .52863 Mtetra
.582 .925 .958 r
.60668 .52863 .60744 .52872 .60899 .52805 .60822 .52802 Mtetra
.679 .966 .931 r
.60822 .52802 .60899 .52805 .61053 .5272 .60976 .52717 Mtetra
.444 .874 .916 r
.60976 .52717 .61053 .5272 .61208 .52674 .61131 .52671 Mtetra
.41 0 0 r
.61131 .52671 .61208 .52674 .61365 .52724 .61289 .52727 Mtetra
.916 .551 .323 r
.61289 .52727 .61365 .52724 .61534 .53181 .61461 .53278 Mtetra
.96 .682 .466 r
.61461 .53278 .61534 .53181 .62222 .72552 .62141 .72536 Mtetra
.891 .481 .219 r
.62141 .72536 .62222 .72552 .62401 .73012 .62318 .72926 Mtetra
.249 .561 .935 r
.62318 .72926 .62401 .73012 .62569 .73081 .62486 .72978 Mtetra
.663 .719 .891 r
.62486 .72978 .62569 .73081 .62735 .73042 .62651 .72929 Mtetra
.811 .74 .785 r
.62651 .72929 .62735 .73042 .62896 .7288 .62813 .72756 Mtetra
.917 .727 .63 r
.62813 .72756 .62896 .7288 .63046 .72323 .62962 .72163 Mtetra
.962 .689 .473 r
.62962 .72163 .63046 .72323 .62626 .52929 .62548 .52806 Mtetra
.908 .726 .644 r
.62548 .52806 .62626 .52929 .62768 .52395 .6269 .5231 Mtetra
.754 .769 .866 r
.6269 .5231 .62768 .52395 .62922 .52297 .62845 .52216 Mtetra
.609 .737 .936 r
.62845 .52216 .62922 .52297 .63079 .52267 .63001 .52188 Mtetra
.513 .703 .956 r
.63001 .52188 .63079 .52267 .63236 .52263 .63159 .52185 Mtetra
.679 .77 .92 r
.63159 .52185 .63236 .52263 .63392 .52194 .63315 .52132 Mtetra
.673 .809 .948 r
.63315 .52132 .63392 .52194 .63548 .5214 .63471 .52078 Mtetra
.677 .812 .948 r
.63471 .52078 .63548 .5214 .63705 .52115 .63628 .52023 Mtetra
.733 .752 .868 r
.63628 .52023 .63705 .52115 .63865 .52157 .63783 .5194 Mtetra
.635 .56 .753 r
.63783 .5194 .63865 .52157 .64027 .52283 .6394 .51896 Mtetra
.546 .438 .682 r
.6394 .51896 .64027 .52283 .64199 .52658 .64099 .51938 Mtetra
.208 .155 .575 r
.64099 .51938 .64199 .52658 .65028 .71588 .64278 .52507 Mtetra
.054 0 .445 r
.64278 .52507 .65028 .71588 .65213 .72064 .65122 .71711 Mtetra
0 .073 .593 r
.65122 .71711 .65213 .72064 .65388 .72238 .65305 .72101 Mtetra
.531 .603 .871 r
.65305 .72101 .65388 .72238 .65555 .72213 .65474 .72112 Mtetra
.675 .73 .891 r
.65474 .72112 .65555 .72213 .65721 .72141 .6564 .72056 Mtetra
.739 .781 .887 r
.6564 .72056 .65721 .72141 .65887 .72051 .65806 .71968 Mtetra
.641 .759 .934 r
.65806 .71968 .65887 .72051 .66055 .72036 .65973 .71926 Mtetra
.651 .703 .884 r
.65973 .71926 .66055 .72036 .66223 .72009 .6614 .71881 Mtetra
.656 .673 .855 r
.6614 .71881 .66223 .72009 .6639 .71952 .66307 .71833 Mtetra
.674 .696 .863 r
.66307 .71833 .6639 .71952 .66552 .71766 .66474 .71776 Mtetra
.396 .853 .834 r
.66474 .71776 .66552 .71766 .6671 .71502 .66641 .71716 Mtetra
.436 .096 .29 r
.66641 .71716 .6671 .71502 .66865 .7114 .66809 .71659 Mtetra
.559 .289 .463 r
.66809 .71659 .66865 .7114 .67034 .71129 .66978 .71664 Mtetra
.539 .274 .462 r
.66978 .71664 .67034 .71129 .67203 .71126 .67147 .71632 Mtetra
.488 .227 .445 r
.67147 .71632 .67203 .71126 .67367 .7101 .67312 .71527 Mtetra
0 0 .281 r
.67312 .71527 .67367 .7101 .6673 .52065 .67458 .70943 Mtetra
.051 0 .44 r
.67458 .70943 .6673 .52065 .66859 .51339 .66796 .51541 Mtetra
.804 .785 .284 r
.66796 .51541 .66859 .51339 .67007 .51041 .66933 .51011 Mtetra
.806 .924 .914 r
.66933 .51011 .67007 .51041 .67164 .50964 .67089 .50897 Mtetra
.643 .791 .953 r
.67089 .50897 .67164 .50964 .67323 .50936 .67248 .50854 Mtetra
.542 .71 .949 r
.67248 .50854 .67323 .50936 .67484 .5093 .67408 .50845 Mtetra
.661 .749 .916 r
.67408 .50845 .67484 .5093 .67641 .50859 .67567 .50798 Mtetra
.647 .809 .961 r
.67567 .50798 .67641 .50859 .67799 .50796 .67725 .50752 Mtetra
.603 .848 .991 r
.67725 .50752 .67799 .50796 .67958 .50758 .67885 .5071 Mtetra
.562 .821 .994 r
.67885 .5071 .67958 .50758 .68123 .50836 .68044 .5068 Mtetra
.619 .608 .817 r
.68044 .5068 .68123 .50836 .68292 .50997 .68204 .50653 Mtetra
.604 .487 .693 r
.68204 .50653 .68292 .50997 .68467 .51282 .68365 .50626 Mtetra
.595 .434 .633 r
.68365 .50626 .68467 .51282 .68639 .51486 .68524 .50589 Mtetra
.591 .417 .615 r
.68524 .50589 .68639 .51486 .68801 .51485 .68684 .50547 Mtetra
.592 .416 .613 r
.68684 .50547 .68801 .51485 .68951 .51239 .68843 .50499 Mtetra
.601 .433 .625 r
.68843 .50499 .68951 .51239 .69093 .50838 .69002 .50439 Mtetra
.624 .487 .674 r
.69002 .50439 .69093 .50838 .69241 .5056 .69161 .50377 Mtetra
.662 .602 .777 r
.69161 .50377 .69241 .5056 .69394 .50369 .6932 .50317 Mtetra
.635 .835 .977 r
.6932 .50317 .69394 .50369 .69552 .50301 .6948 .5027 Mtetra
.564 .875 .994 r
.6948 .5027 .69552 .50301 .69713 .50273 .6964 .50228 Mtetra
.611 .849 .989 r
.6964 .50228 .69713 .50273 .69875 .50259 .69801 .50184 Mtetra
.678 .782 .929 r
.69801 .50184 .69875 .50259 .70035 .50216 .6996 .50129 Mtetra
.688 .755 .903 r
.6996 .50129 .70035 .50216 .70195 .50161 .7012 .5007 Mtetra
.688 .746 .895 r
.7012 .5007 .70195 .50161 .70354 .50099 .70279 .5001 Mtetra
.755 .768 .863 r
.70279 .5001 .70354 .50099 .70511 .49985 .70437 .49912 Mtetra
.715 .798 .916 r
.70437 .49912 .70511 .49985 .70669 .49897 .70596 .49841 Mtetra
.47 .76 .993 r
.70596 .49841 .70669 .49897 .70831 .49872 .70759 .49834 Mtetra
.864 .415 .066 r
.70759 .49834 .70831 .49872 .71011 .50172 .70941 .50168 Mtetra
.969 .682 .428 r
.70941 .50168 .71011 .50172 .72262 .69524 .72189 .69541 Mtetra
.915 .54 .294 r
.72189 .69541 .72262 .69524 .72476 .70241 .72397 .70158 Mtetra
0 .335 .803 r
.72397 .70158 .72476 .70241 .72656 .70357 .72577 .70268 Mtetra
.59 .729 .94 r
.72577 .70268 .72656 .70357 .72828 .70332 .7275 .70244 Mtetra
.788 .789 .853 r
.7275 .70244 .72828 .70332 .72995 .70205 .72917 .70119 Mtetra
.932 .777 .666 r
.72917 .70119 .72995 .70205 .73144 .69776 .73066 .69691 Mtetra
.971 .689 .436 r
.73066 .69691 .73144 .69776 .72169 .50369 .72095 .50279 Mtetra
.956 .742 .573 r
.72095 .50279 .72169 .50369 .72287 .49578 .72213 .49488 Mtetra
.829 .782 .808 r
.72213 .49488 .72287 .49578 .72441 .49415 .72367 .49327 Mtetra
.643 .737 .917 r
.72367 .49327 .72441 .49415 .72603 .49374 .72529 .49286 Mtetra
.501 .679 .945 r
.72529 .49286 .72603 .49374 .72768 .49377 .72694 .4929 Mtetra
.604 .728 .933 r
.72694 .4929 .72768 .49377 .72931 .49349 .72857 .49263 Mtetra
.648 .748 .923 r
.72857 .49263 .72931 .49349 .73093 .49304 .73019 .4922 Mtetra
.657 .756 .923 r
.73019 .4922 .73093 .49304 .73254 .49253 .73181 .49173 Mtetra
.686 .776 .919 r
.73181 .49173 .73254 .49253 .73414 .4917 .73343 .49114 Mtetra
.689 .844 .957 r
.73343 .49114 .73414 .4917 .73574 .49088 .73504 .49051 Mtetra
.654 .892 .982 r
.73504 .49051 .73574 .49088 .73736 .49032 .73665 .48991 Mtetra
.728 .897 .956 r
.73665 .48991 .73736 .49032 .73902 .49047 .73825 .4891 Mtetra
.675 .661 .829 r
.73825 .4891 .73902 .49047 .74074 .49147 .73987 .4885 Mtetra
.58 .49 .717 r
.73987 .4885 .74074 .49147 .74257 .49411 .74153 .48852 Mtetra
.365 .287 .635 r
.74153 .48852 .74257 .49411 .75673 .68315 .74339 .49163 Mtetra
.105 .026 .474 r
.74339 .49163 .75673 .68315 .75901 .6911 .75793 .68548 Mtetra
.037 .065 .56 r
.75793 .68548 .75901 .6911 .76094 .69354 .76011 .69175 Mtetra
.36 .45 .818 r
.76011 .69175 .76094 .69354 .76273 .69395 .76194 .69272 Mtetra
.636 .679 .874 r
.76194 .69272 .76273 .69395 .76447 .69352 .76368 .69233 Mtetra
.713 .715 .851 r
.76368 .69233 .76447 .69352 .76618 .69282 .76539 .6915 Mtetra
.675 .68 .847 r
.76539 .6915 .76618 .69282 .76792 .69236 .76711 .69089 Mtetra
.646 .647 .837 r
.76711 .69089 .76792 .69236 .76967 .69205 .76885 .69044 Mtetra
.644 .629 .82 r
.76885 .69044 .76967 .69205 .77142 .69173 .77059 .68999 Mtetra
.641 .613 .806 r
.77059 .68999 .77142 .69173 .77316 .69134 .77233 .68954 Mtetra
.64 .607 .8 r
.77233 .68954 .77316 .69134 .7749 .6909 .77407 .68909 Mtetra
.64 .606 .799 r
.77407 .68909 .7749 .6909 .77664 .69044 .77581 .68865 Mtetra
.64 .607 .8 r
.77581 .68865 .77664 .69044 .77839 .68999 .77756 .6882 Mtetra
.64 .607 .801 r
.77756 .6882 .77839 .68999 .78013 .68954 .7793 .68775 Mtetra
.641 .607 .801 r
.7793 .68775 .78013 .68954 .78188 .68909 .78105 .68729 Mtetra
.641 .608 .801 r
.78105 .68729 .78188 .68909 .78362 .68863 .7828 .68684 Mtetra
.7828 .68684 .78362 .68863 .78537 .68818 .78454 .68638 Mtetra
.78454 .68638 .78537 .68818 .78712 .68772 .78629 .68592 Mtetra
.642 .608 .801 r
.78629 .68592 .78712 .68772 .78887 .68726 .78804 .68546 Mtetra
.78804 .68546 .78887 .68726 .79062 .6868 .78979 .685 Mtetra
.642 .609 .801 r
.78979 .685 .79062 .6868 .79237 .68633 .79154 .68454 Mtetra
.79154 .68454 .79237 .68633 .79412 .68587 .79329 .68407 Mtetra
.79329 .68407 .79412 .68587 .79587 .6854 .79505 .68361 Mtetra
.643 .609 .801 r
.79505 .68361 .79587 .6854 .79763 .68494 .7968 .68314 Mtetra
.643 .609 .8 r
.7968 .68314 .79763 .68494 .79938 .68447 .79856 .68267 Mtetra
.79856 .68267 .79938 .68447 .80114 .684 .80031 .6822 Mtetra
.80031 .6822 .80114 .684 .8029 .68353 .80207 .68173 Mtetra
.643 .608 .8 r
.80207 .68173 .8029 .68353 .80465 .68306 .80383 .68125 Mtetra
.643 .608 .799 r
.80383 .68125 .80465 .68306 .80641 .68259 .80559 .68078 Mtetra
.80559 .68078 .80641 .68259 .80817 .68212 .80735 .68031 Mtetra
.80735 .68031 .80817 .68212 .80994 .68165 .80911 .67983 Mtetra
.643 .607 .799 r
.80911 .67983 .80994 .68165 .8117 .68118 .81087 .67936 Mtetra
.643 .607 .798 r
.81087 .67936 .8117 .68118 .81346 .68071 .81264 .67888 Mtetra
.81264 .67888 .81346 .68071 .81523 .68023 .8144 .6784 Mtetra
.643 .606 .798 r
.8144 .6784 .81523 .68023 .81699 .67976 .81617 .67793 Mtetra
.642 .606 .798 r
.81617 .67793 .81699 .67976 .81876 .67929 .81793 .67746 Mtetra
.81793 .67746 .81876 .67929 .82053 .67882 .8197 .67698 Mtetra
.642 .606 .797 r
.8197 .67698 .82053 .67882 .82229 .67835 .82147 .67651 Mtetra
.82147 .67651 .82229 .67835 .82406 .67787 .82324 .67603 Mtetra
.642 .605 .797 r
.82324 .67603 .82406 .67787 .82584 .6774 .82501 .67556 Mtetra
.82501 .67556 .82584 .6774 .82761 .67693 .82678 .67509 Mtetra
.82678 .67509 .82761 .67693 .82938 .67646 .82856 .67462 Mtetra
.82856 .67462 .82938 .67646 .83116 .67599 .83033 .67414 Mtetra
.83033 .67414 .83116 .67599 .83293 .67552 .83211 .67367 Mtetra
.83211 .67367 .83293 .67552 .83471 .67505 .83389 .6732 Mtetra
.641 .605 .797 r
.83389 .6732 .83471 .67505 .83649 .67457 .83566 .67273 Mtetra
.83566 .67273 .83649 .67457 .83827 .6741 .83744 .67226 Mtetra
.641 .605 .798 r
.83744 .67226 .83827 .6741 .84005 .67363 .83922 .67179 Mtetra
.83922 .67179 .84005 .67363 .84183 .67316 .84101 .67132 Mtetra
.84101 .67132 .84183 .67316 .84361 .67269 .84279 .67085 Mtetra
.84279 .67085 .84361 .67269 .84539 .67222 .84457 .67038 Mtetra
.641 .606 .798 r
.84457 .67038 .84539 .67222 .84718 .67175 .84636 .66991 Mtetra
.84636 .66991 .84718 .67175 .84896 .67128 .84814 .66944 Mtetra
.641 .606 .799 r
.84814 .66944 .84896 .67128 .85075 .67081 .84993 .66897 Mtetra
.84993 .66897 .85075 .67081 .85254 .67034 .85172 .6685 Mtetra
.641 .607 .799 r
.85172 .6685 .85254 .67034 .85433 .66986 .85351 .66803 Mtetra
.85351 .66803 .85433 .66986 .85612 .66939 .8553 .66756 Mtetra
.642 .607 .799 r
.8553 .66756 .85612 .66939 .85791 .66892 .85709 .66709 Mtetra
.85709 .66709 .85791 .66892 .8597 .66844 .85888 .66661 Mtetra
.642 .607 .8 r
.85888 .66661 .8597 .66844 .86149 .66797 .86068 .66614 Mtetra
.642 .608 .8 r
.86068 .66614 .86149 .66797 .86329 .66749 .86247 .66566 Mtetra
.86247 .66566 .86329 .66749 .86508 .66702 .86427 .66518 Mtetra
.86427 .66518 .86508 .66702 .86688 .66654 .86606 .66471 Mtetra
.86606 .66471 .86688 .66654 .86868 .66606 .86786 .66423 Mtetra
.86786 .66423 .86868 .66606 .87048 .66558 .86966 .66375 Mtetra
.643 .608 .8 r
.86966 .66375 .87048 .66558 .87228 .6651 .87146 .66326 Mtetra
.643 .608 .799 r
.87146 .66326 .87228 .6651 .87408 .66462 .87326 .66278 Mtetra
.87326 .66278 .87408 .66462 .87588 .66413 .87506 .66229 Mtetra
.87506 .66229 .87588 .66413 .87768 .66365 .87686 .6618 Mtetra
.644 .608 .799 r
.87686 .6618 .87768 .66365 .87948 .66316 .87867 .66131 Mtetra
.644 .608 .798 r
.87867 .66131 .87948 .66316 .88129 .66267 .88047 .66081 Mtetra
.645 .608 .797 r
.88047 .66081 .88129 .66267 .88309 .66217 .88228 .66031 Mtetra
.646 .608 .796 r
.88228 .66031 .88309 .66217 .8849 .66167 .88408 .65979 Mtetra
.648 .607 .794 r
.88408 .65979 .8849 .66167 .8867 .66118 .88588 .65926 Mtetra
.647 .603 .791 r
.88588 .65926 .8867 .66118 .88851 .66065 .88769 .65873 Mtetra
.645 .602 .791 r
.88769 .65873 .88851 .66065 .89031 .66007 .8895 .65821 Mtetra
.644 .607 .798 r
.8895 .65821 .89031 .66007 .8921 .6594 .89131 .65771 Mtetra
.647 .627 .816 r
.89131 .65771 .8921 .6594 .89389 .65871 .89312 .65722 Mtetra
.652 .653 .838 r
.89312 .65722 .89389 .65871 .89569 .65806 .89493 .65671 Mtetra
.658 .676 .855 r
.89493 .65671 .89569 .65806 .8975 .65751 .89674 .65618 Mtetra
.659 .678 .857 r
.89674 .65618 .8975 .65751 .89931 .657 .89855 .65564 Mtetra
.657 .674 .855 r
.89855 .65564 .89931 .657 .90112 .6565 .90036 .65511 Mtetra
.654 .669 .851 r
.90036 .65511 .90112 .6565 .90294 .656 .90218 .6546 Mtetra
.653 .667 .851 r
.90218 .6546 .90294 .656 .90476 .6555 .904 .65409 Mtetra
.652 .666 .851 r
.904 .65409 .90476 .6555 .90658 .655 .90582 .65359 Mtetra
.65 .665 .85 r
.90582 .65359 .90658 .655 .9084 .65451 .90764 .6531 Mtetra
.649 .664 .851 r
.90764 .6531 .9084 .65451 .91022 .65403 .90946 .65262 Mtetra
.648 .663 .851 r
.90946 .65262 .91022 .65403 .91205 .65355 .91129 .65214 Mtetra
.647 .663 .852 r
.91129 .65214 .91205 .65355 .91387 .65307 .91311 .65167 Mtetra
.645 .663 .853 r
.91311 .65167 .91387 .65307 .9157 .65261 .91494 .65121 Mtetra
.644 .663 .854 r
.91494 .65121 .9157 .65261 .91753 .65214 .91677 .65075 Mtetra
.641 .664 .856 r
.91677 .65075 .91753 .65214 .91936 .65167 .91861 .65031 Mtetra
.642 .669 .861 r
.91861 .65031 .91936 .65167 .92119 .65122 .92044 .64987 Mtetra
.644 .671 .861 r
.92044 .64987 .92119 .65122 .92304 .65083 .92228 .64942 Mtetra
.648 .664 .851 r
.92228 .64942 .92304 .65083 .92489 .65054 .92411 .64894 Mtetra
.646 .638 .827 r
.92411 .64894 .92489 .65054 .92675 .65025 .92595 .64846 Mtetra
.642 .614 .806 r
.92595 .64846 .92675 .65025 .9286 .64992 .92778 .64798 Mtetra
.637 .597 .792 r
.92778 .64798 .9286 .64992 .93044 .64948 .92962 .64751 Mtetra
.637 .596 .79 r
.92962 .64751 .93044 .64948 .93228 .649 .93146 .64705 Mtetra
.639 .598 .791 r
.93146 .64705 .93228 .649 .93411 .6485 .9333 .64657 Mtetra
.644 .602 .792 r
.9333 .64657 .93411 .6485 .93595 .64802 .93514 .64606 Mtetra
.644 .6 .789 r
.93514 .64606 .93595 .64802 .93779 .64751 .93697 .64553 Mtetra
.644 .599 .788 r
.93697 .64553 .93779 .64751 .93962 .64694 .93881 .64501 Mtetra
.643 .602 .793 r
.93881 .64501 .93962 .64694 .94144 .64626 .94065 .64451 Mtetra
.646 .621 .81 r
.94065 .64451 .94144 .64626 .94326 .64557 .94249 .644 Mtetra
.652 .646 .831 r
.94249 .644 .94326 .64557 .94508 .64489 .94434 .64348 Mtetra
.66 .671 .849 r
.94434 .64348 .94508 .64489 .94692 .64432 .94617 .64292 Mtetra
.662 .673 .85 r
.94617 .64292 .94692 .64432 .94876 .64378 .94801 .64235 Mtetra
.661 .668 .846 r
.94801 .64235 .94876 .64378 .95061 .64327 .94985 .64179 Mtetra
.657 .66 .841 r
.94985 .64179 .95061 .64327 .95245 .64274 .95169 .64124 Mtetra
.654 .656 .839 r
.95169 .64124 .95245 .64274 .9543 .64222 .95354 .64071 Mtetra
.649 .652 .839 r
.95354 .64071 .9543 .64222 .95615 .64174 .95539 .64021 Mtetra
.641 .646 .84 r
.95539 .64021 .95615 .64174 .95801 .64129 .95725 .63976 Mtetra
.637 .644 .841 r
.95725 .63976 .95801 .64129 .95987 .64086 .95911 .63934 Mtetra
.627 .64 .844 r
.95911 .63934 .95987 .64086 .96174 .64048 .96098 .63898 Mtetra
.543 .598 .859 r
.96098 .63898 .96174 .64048 .96366 .64053 .96291 .63907 Mtetra
.623 .647 .853 r
.96291 .63907 .96366 .64053 .96554 .64017 .96479 .63873 Mtetra
.752 .708 .811 r
.96479 .63873 .96554 .64017 .9673 .63894 .96655 .63748 Mtetra
.949 .746 .594 r
.96655 .63748 .9673 .63894 .9685 .63329 .96769 .63135 Mtetra
.975 .669 .327 r
.96769 .63135 .9685 .63329 .94467 .43359 .94394 .43197 Mtetra
.928 .729 .613 r
.94394 .43197 .94467 .43359 .94573 .42774 .94507 .42666 Mtetra
.75 .753 .854 r
.94507 .42666 .94573 .42774 .9474 .42667 .94675 .42563 Mtetra
.624 .71 .907 r
.94675 .42563 .9474 .42667 .94917 .42632 .94851 .42529 Mtetra
.538 .669 .922 r
.94851 .42529 .94917 .42632 .95098 .42631 .95032 .42527 Mtetra
.671 .729 .894 r
.95032 .42527 .95098 .42631 .95272 .42577 .95206 .4247 Mtetra
.674 .727 .889 r
.95206 .4247 .95272 .42577 .95446 .42518 .9538 .42412 Mtetra
.678 .729 .888 r
.9538 .42412 .95446 .42518 .95619 .42453 .95554 .42352 Mtetra
.757 .769 .863 r
.95554 .42352 .95619 .42453 .95784 .42328 .95722 .42248 Mtetra
.694 .798 .929 r
.95722 .42248 .95784 .42328 .95955 .42242 .95895 .42181 Mtetra
.428 .73 .989 r
.95895 .42181 .95955 .42242 .96135 .42225 .96078 .42183 Mtetra
.93 .676 .531 r
.39122 .59731 .39224 .59385 .39349 .59815 .38559 .77947 Mtetra
.586 .375 .561 r
.38559 .77947 .39349 .59815 .38776 .78628 .38676 .78801 Mtetra
.753 .421 .422 r
.38676 .78801 .38776 .78628 .38908 .79109 .38816 .79045 Mtetra
0 .427 .835 r
.38816 .79045 .38908 .79109 .39056 .79179 .38964 .79108 Mtetra
.582 .754 .96 r
.38964 .79108 .39056 .79179 .39207 .79142 .39115 .79086 Mtetra
.795 .822 .873 r
.39115 .79086 .39207 .79142 .39363 .79001 .3927 .78972 Mtetra
.931 .773 .663 r
.3927 .78972 .39363 .79001 .39533 .78457 .39438 .78479 Mtetra
.939 .688 .532 r
.39438 .78479 .39533 .78457 .40355 .59518 .40266 .59521 Mtetra
.949 .774 .632 r
.40266 .59521 .40355 .59518 .40517 .58984 .4043 .5892 Mtetra
.794 .796 .854 r
.4043 .5892 .40517 .58984 .40663 .58872 .40577 .58808 Mtetra
.63 .775 .95 r
.40577 .58808 .40663 .58872 .40807 .58836 .4072 .58773 Mtetra
.467 .725 .982 r
.4072 .58773 .40807 .58836 .40949 .58837 .40863 .58773 Mtetra
.683 .787 .929 r
.40863 .58773 .40949 .58837 .41093 .58811 .41007 .58721 Mtetra
.693 .729 .878 r
.41007 .58721 .41093 .58811 .41236 .58784 .41152 .58664 Mtetra
.681 .671 .834 r
.41152 .58664 .41236 .58784 .4138 .58756 .41297 .58608 Mtetra
.698 .641 .789 r
.41297 .58608 .4138 .58756 .41526 .58675 .41442 .58531 Mtetra
.67 .635 .806 r
.41442 .58531 .41526 .58675 .41671 .58617 .41587 .58476 Mtetra
.589 .603 .834 r
.41587 .58476 .41671 .58617 .41814 .58621 .41731 .58467 Mtetra
0 0 .559 r
.41731 .58467 .41814 .58621 .41945 .59004 .41868 .58665 Mtetra
.878 .588 .069 r
.41868 .58665 .41945 .59004 .41515 .77833 .41989 .59379 Mtetra
0 0 .354 r
.41989 .59379 .41515 .77833 .41651 .78353 .41575 .77803 Mtetra
.522 .393 .646 r
.41575 .77803 .41651 .78353 .41801 .78403 .41724 .7789 Mtetra
.616 .464 .653 r
.41724 .7789 .41801 .78403 .41955 .78358 .41878 .77828 Mtetra
.625 .468 .65 r
.41878 .77828 .41955 .78358 .42109 .78274 .42032 .77746 Mtetra
.478 .365 .647 r
.42032 .77746 .42109 .78274 .42263 .78227 .4218 .77885 Mtetra
.417 .367 .695 r
.4218 .77885 .42263 .78227 .42416 .78188 .42329 .78016 Mtetra
.351 .447 .819 r
.42329 .78016 .42416 .78188 .4257 .78149 .42479 .78097 Mtetra
.466 .767 .996 r
.42479 .78097 .4257 .78149 .42723 .7811 .42632 .78089 Mtetra
.549 .881 .989 r
.42632 .78089 .42723 .7811 .42877 .7807 .42786 .78047 Mtetra
.626 .9 .986 r
.42786 .78047 .42877 .7807 .43031 .78027 .4294 .77992 Mtetra
.593 .861 .994 r
.4294 .77992 .43031 .78027 .43185 .77975 .43094 .77951 Mtetra
.533 .87 .992 r
.43094 .77951 .43185 .77975 .4334 .7792 .43248 .77913 Mtetra
.43 .859 .938 r
.43248 .77913 .4334 .7792 .43494 .77865 .43402 .77876 Mtetra
0 0 0 r
.43402 .77876 .43494 .77865 .43647 .77863 .43556 .77865 Mtetra
.239 .755 .831 r
.43556 .77865 .43647 .77863 .43801 .77844 .4371 .7784 Mtetra
.636 .943 .956 r
.4371 .7784 .43801 .77844 .43957 .77761 .43865 .77769 Mtetra
.934 .899 .767 r
.43865 .77769 .43957 .77761 .4412 .77339 .44025 .77518 Mtetra
.988 .879 .538 r
.44025 .77518 .4412 .77339 .44705 .58432 .44192 .76915 Mtetra
0 0 .352 r
.44192 .76915 .44705 .58432 .44866 .57747 .4477 .58173 Mtetra
0 0 .201 r
.4477 .58173 .44866 .57747 .45015 .57588 .44925 .5775 Mtetra
0 0 0 r
.44925 .5775 .45015 .57588 .45161 .5754 .45075 .57555 Mtetra
.802 .991 .879 r
.45075 .57555 .45161 .5754 .45307 .57531 .45223 .57432 Mtetra
.713 .719 .854 r
.45223 .57432 .45307 .57531 .45453 .57501 .4537 .57361 Mtetra
.65 .633 .82 r
.4537 .57361 .45453 .57501 .456 .57463 .45517 .5732 Mtetra
.621 .616 .825 r
.45517 .5732 .456 .57463 .45746 .57424 .45663 .57295 Mtetra
.625 .637 .842 r
.45663 .57295 .45746 .57424 .45893 .57382 .4581 .57267 Mtetra
.629 .663 .864 r
.4581 .57267 .45893 .57382 .4604 .57337 .45956 .57238 Mtetra
.631 .693 .89 r
.45956 .57238 .4604 .57337 .46187 .5729 .46103 .57207 Mtetra
.649 .734 .911 r
.46103 .57207 .46187 .5729 .46334 .5724 .4625 .57168 Mtetra
.665 .767 .926 r
.4625 .57168 .46334 .5724 .46481 .57189 .46397 .57122 Mtetra
.678 .784 .93 r
.46397 .57122 .46481 .57189 .46628 .57141 .46544 .57071 Mtetra
.749 .786 .883 r
.46544 .57071 .46628 .57141 .46776 .57072 .46692 .56987 Mtetra
.73 .749 .868 r
.46692 .56987 .46776 .57072 .46923 .57019 .4684 .56909 Mtetra
.643 .677 .867 r
.4684 .56909 .46923 .57019 .4707 .57021 .46988 .56873 Mtetra
.104 .319 .793 r
.46988 .56873 .4707 .57021 .47212 .57297 .47132 .56995 Mtetra
0 0 .337 r
.47132 .56995 .47212 .57297 .47075 .76105 .47272 .57439 Mtetra
0 0 .379 r
.47272 .57439 .47075 .76105 .4722 .76806 .4714 .76156 Mtetra
.273 .204 .594 r
.4714 .76156 .4722 .76806 .47374 .76919 .4729 .76561 Mtetra
.433 .374 .691 r
.4729 .76561 .47374 .76919 .47531 .7689 .47444 .7669 Mtetra
.479 .492 .793 r
.47444 .7669 .47531 .7689 .47688 .76816 .47599 .7674 Mtetra
.517 .722 .966 r
.47599 .7674 .47688 .76816 .47844 .7676 .47756 .76734 Mtetra
.543 .872 .993 r
.47756 .76734 .47844 .7676 .48001 .76719 .47912 .76695 Mtetra
.622 .901 .986 r
.47912 .76695 .48001 .76719 .48158 .76673 .48069 .7664 Mtetra
.487 .83 .998 r
.48069 .7664 .48158 .76673 .48315 .7665 .48226 .76615 Mtetra
.48 .823 .998 r
.48226 .76615 .48315 .7665 .48471 .76617 .48383 .76592 Mtetra
.661 .909 .979 r
.48383 .76592 .48471 .76617 .48629 .76526 .4854 .76528 Mtetra
.92 .921 .798 r
.4854 .76528 .48629 .76526 .48789 .76167 .48699 .76313 Mtetra
.984 .89 .551 r
.48699 .76313 .48789 .76167 .49133 .57289 .48862 .7578 Mtetra
0 0 .372 r
.48862 .7578 .49133 .57289 .49289 .56441 .49201 .56937 Mtetra
0 0 .227 r
.49201 .56937 .49289 .56441 .49439 .56235 .49354 .56421 Mtetra
0 0 0 r
.49354 .56421 .49439 .56235 .49588 .56174 .49505 .56212 Mtetra
.736 .988 .793 r
.49505 .56212 .49588 .56174 .49737 .56155 .49654 .56079 Mtetra
.739 .776 .883 r
.49654 .56079 .49737 .56155 .49886 .56126 .49804 .55999 Mtetra
.663 .659 .835 r
.49804 .55999 .49886 .56126 .50035 .56081 .49953 .55951 Mtetra
.635 .642 .84 r
.49953 .55951 .50035 .56081 .50184 .5604 .50102 .55918 Mtetra
.646 .659 .849 r
.50102 .55918 .50184 .5604 .50333 .56006 .50251 .5588 Mtetra
.659 .658 .838 r
.50251 .5588 .50333 .56006 .50482 .55977 .504 .55834 Mtetra
.656 .634 .817 r
.504 .55834 .50482 .55977 .50631 .55947 .50549 .55788 Mtetra
.653 .614 .798 r
.50549 .55788 .50631 .55947 .5078 .55908 .50699 .55742 Mtetra
.651 .605 .79 r
.50699 .55742 .5078 .55908 .5093 .55861 .50848 .55695 Mtetra
.65 .605 .79 r
.50848 .55695 .5093 .55861 .51079 .55812 .50998 .55649 Mtetra
.674 .619 .786 r
.50998 .55649 .51079 .55812 .51229 .5574 .51148 .55586 Mtetra
.678 .631 .795 r
.51148 .55586 .51229 .5574 .51379 .55668 .51297 .55522 Mtetra
.626 .617 .822 r
.51297 .55522 .51379 .55668 .51529 .55647 .51447 .55493 Mtetra
.241 .397 .819 r
.51447 .55493 .51529 .55647 .51678 .55834 .51597 .55595 Mtetra
0 0 .305 r
.51597 .55595 .51678 .55834 .51792 .74314 .51746 .55998 Mtetra
0 0 .391 r
.51746 .55998 .51792 .74314 .51948 .75484 .51863 .74761 Mtetra
.327 .238 .599 r
.51863 .74761 .51948 .75484 .52107 .7566 .52021 .75163 Mtetra
.583 .445 .659 r
.52021 .75163 .52107 .7566 .52266 .75642 .5218 .75159 Mtetra
.632 .48 .658 r
.5218 .75159 .52266 .75642 .52426 .75574 .52339 .7507 Mtetra
.627 .474 .655 r
.52339 .7507 .52426 .75574 .52585 .75509 .52499 .74988 Mtetra
.605 .456 .653 r
.52499 .74988 .52585 .75509 .52744 .75467 .52658 .74945 Mtetra
.605 .457 .653 r
.52658 .74945 .52744 .75467 .52904 .75424 .52817 .749 Mtetra
.605 .456 .653 r
.52817 .749 .52904 .75424 .53064 .75381 .52977 .74856 Mtetra
.604 .456 .653 r
.52977 .74856 .53064 .75381 .53223 .75338 .53136 .74813 Mtetra
.605 .456 .653 r
.53136 .74813 .53223 .75338 .53383 .75295 .53296 .7477 Mtetra
.53296 .7477 .53383 .75295 .53543 .75253 .53456 .74726 Mtetra
.53456 .74726 .53543 .75253 .53703 .7521 .53616 .74682 Mtetra
.53616 .74682 .53703 .7521 .53863 .75166 .53776 .74637 Mtetra
.606 .456 .652 r
.53776 .74637 .53863 .75166 .54023 .75123 .53936 .74591 Mtetra
.53936 .74591 .54023 .75123 .54184 .75078 .54096 .74543 Mtetra
.606 .456 .651 r
.54096 .74543 .54184 .75078 .54344 .75034 .54256 .74495 Mtetra
.616 .462 .65 r
.54256 .74495 .54344 .75034 .54504 .74988 .54416 .74429 Mtetra
.621 .463 .647 r
.54416 .74429 .54504 .74988 .54665 .74942 .54576 .74349 Mtetra
.597 .443 .643 r
.54576 .74349 .54665 .74942 .54826 .74896 .54737 .74314 Mtetra
.529 .397 .645 r
.54737 .74314 .54826 .74896 .54986 .74851 .54898 .744 Mtetra
.449 .362 .666 r
.54898 .744 .54986 .74851 .55147 .74809 .5506 .74554 Mtetra
.411 .41 .747 r
.5506 .74554 .55147 .74809 .55308 .74767 .55223 .74659 Mtetra
.417 .596 .919 r
.55223 .74659 .55308 .74767 .55469 .74726 .55384 .74692 Mtetra
.533 .851 .998 r
.55384 .74692 .55469 .74726 .5563 .74685 .55545 .74658 Mtetra
.593 .891 .99 r
.55545 .74658 .5563 .74685 .55791 .74641 .55707 .74607 Mtetra
.588 .872 .994 r
.55707 .74607 .55791 .74641 .55953 .74591 .55868 .74563 Mtetra
.464 .837 .99 r
.55868 .74563 .55953 .74591 .56114 .74534 .5603 .74536 Mtetra
.23 .75 .822 r
.5603 .74536 .56114 .74534 .56275 .74476 .56191 .74509 Mtetra
.012 0 0 r
.56191 .74509 .56275 .74476 .56437 .74425 .56353 .74477 Mtetra
.104 0 0 r
.56353 .74477 .56437 .74425 .56598 .74383 .56515 .74438 Mtetra
.1 0 0 r
.56515 .74438 .56598 .74383 .5676 .74345 .56677 .74397 Mtetra
.072 0 0 r
.56677 .74397 .5676 .74345 .56922 .74306 .56839 .74354 Mtetra
.048 0 0 r
.56839 .74354 .56922 .74306 .57084 .74265 .57001 .74312 Mtetra
.04 0 0 r
.57001 .74312 .57084 .74265 .57246 .74223 .57163 .74269 Mtetra
.035 0 0 r
.57163 .74269 .57246 .74223 .57408 .7418 .57325 .74227 Mtetra
.036 0 0 r
.57325 .74227 .57408 .7418 .5757 .74137 .57488 .74184 Mtetra
.027 0 0 r
.57488 .74184 .5757 .74137 .57733 .74093 .5765 .7414 Mtetra
0 0 0 r
.5765 .7414 .57733 .74093 .57895 .7405 .57813 .74091 Mtetra
.57813 .74091 .57895 .7405 .58058 .74008 .57975 .74035 Mtetra
.241 .743 .679 r
.57975 .74035 .58058 .74008 .5822 .73965 .58138 .73979 Mtetra
.246 .758 .76 r
.58138 .73979 .5822 .73965 .58383 .73937 .58301 .73937 Mtetra
.169 .706 .801 r
.58301 .73937 .58383 .73937 .58547 .73932 .58464 .73918 Mtetra
.517 .893 .964 r
.58464 .73918 .58547 .73932 .5871 .73879 .58627 .73869 Mtetra
.846 .956 .883 r
.58627 .73869 .5871 .73879 .5887 .73682 .58788 .73725 Mtetra
.985 .885 .643 r
.58788 .73725 .5887 .73682 .59017 .72772 .58944 .73305 Mtetra
.967 .699 .473 r
.58944 .73305 .59017 .72772 .58822 .53735 .58763 .54736 Mtetra
0 0 .347 r
.58763 .54736 .58822 .53735 .5897 .53382 .58898 .53705 Mtetra
.422 .137 .373 r
.58898 .53705 .5897 .53382 .59123 .53298 .59051 .53594 Mtetra
.528 .224 .395 r
.59051 .53594 .59123 .53298 .59277 .53269 .59206 .5358 Mtetra
.557 .255 .411 r
.59206 .5358 .59277 .53269 .59432 .53254 .59362 .53593 Mtetra
.505 .215 .407 r
.59362 .53593 .59432 .53254 .59586 .53208 .59516 .53548 Mtetra
.506 .216 .408 r
.59516 .53548 .59586 .53208 .59741 .53162 .59671 .53504 Mtetra
.505 .216 .408 r
.59671 .53504 .59741 .53162 .59895 .53115 .59826 .53458 Mtetra
.501 .213 .408 r
.59826 .53458 .59895 .53115 .6005 .53067 .5998 .53409 Mtetra
.499 .211 .407 r
.5998 .53409 .6005 .53067 .60204 .53018 .60135 .53358 Mtetra
.497 .208 .405 r
.60135 .53358 .60204 .53018 .60359 .52968 .6029 .53305 Mtetra
.493 .204 .403 r
.6029 .53305 .60359 .52968 .60513 .52915 .60445 .53249 Mtetra
.493 .203 .402 r
.60445 .53249 .60513 .52915 .60668 .52863 .60599 .53194 Mtetra
.477 .188 .395 r
.60599 .53194 .60668 .52863 .60822 .52802 .60754 .53125 Mtetra
.424 .139 .374 r
.60754 .53125 .60822 .52802 .60976 .52717 .60908 .53016 Mtetra
.493 .192 .385 r
.60908 .53016 .60976 .52717 .61131 .52671 .61063 .52969 Mtetra
.643 .332 .429 r
.61063 .52969 .61131 .52671 .61289 .52727 .61223 .53091 Mtetra
.955 .678 .472 r
.61223 .53091 .61289 .52727 .61461 .53278 .61876 .7182 Mtetra
.584 .372 .56 r
.61876 .7182 .61461 .53278 .62141 .72536 .62063 .72614 Mtetra
.789 .382 .281 r
.62063 .72614 .62141 .72536 .62318 .72926 .62236 .72849 Mtetra
.218 .568 .939 r
.62236 .72849 .62318 .72926 .62486 .72978 .62404 .72898 Mtetra
.621 .756 .943 r
.62404 .72898 .62486 .72978 .62651 .72929 .62569 .72863 Mtetra
.831 .827 .844 r
.62569 .72863 .62651 .72929 .62813 .72756 .62732 .72713 Mtetra
.956 .784 .629 r
.62732 .72713 .62813 .72756 .62962 .72163 .62882 .72157 Mtetra
.964 .691 .47 r
.62882 .72157 .62962 .72163 .62548 .52806 .62471 .52763 Mtetra
.955 .78 .627 r
.62471 .52763 .62548 .52806 .6269 .5231 .62612 .52229 Mtetra
.759 .779 .87 r
.62612 .52229 .6269 .5231 .62845 .52216 .62767 .52133 Mtetra
.605 .733 .935 r
.62767 .52133 .62845 .52216 .63001 .52188 .62924 .52106 Mtetra
.5 .693 .955 r
.62924 .52106 .63001 .52188 .63159 .52185 .63082 .52108 Mtetra
.664 .766 .926 r
.63082 .52108 .63159 .52185 .63315 .52132 .63238 .5206 Mtetra
.673 .784 .933 r
.63238 .5206 .63315 .52132 .63471 .52078 .63394 .52008 Mtetra
.697 .794 .925 r
.63394 .52008 .63471 .52078 .63628 .52023 .6355 .51946 Mtetra
.773 .792 .868 r
.6355 .51946 .63628 .52023 .63783 .5194 .63705 .51842 Mtetra
.714 .734 .867 r
.63705 .51842 .63783 .5194 .6394 .51896 .63861 .51769 Mtetra
.586 .631 .863 r
.63861 .51769 .6394 .51896 .64099 .51938 .64019 .51757 Mtetra
0 .122 .667 r
.64019 .51757 .64099 .51938 .64278 .52507 .64185 .5198 Mtetra
0 0 .198 r
.64185 .5198 .64278 .52507 .65122 .71711 .6438 .53005 Mtetra
.063 0 .448 r
.6438 .53005 .65122 .71711 .65305 .72101 .65208 .71593 Mtetra
.412 .329 .652 r
.65208 .71593 .65305 .72101 .65474 .72112 .65384 .71814 Mtetra
.47 .426 .727 r
.65384 .71814 .65474 .72112 .6564 .72056 .65556 .71905 Mtetra
.503 .566 .852 r
.65556 .71905 .6564 .72056 .65806 .71968 .65726 .71931 Mtetra
.49 .832 .998 r
.65726 .71931 .65806 .71968 .65973 .71926 .65894 .71904 Mtetra
.549 .894 .98 r
.65894 .71904 .65973 .71926 .6614 .71881 .66061 .71854 Mtetra
.623 .907 .984 r
.66061 .71854 .6614 .71881 .66307 .71833 .66228 .71793 Mtetra
.577 .858 .996 r
.66228 .71793 .66307 .71833 .66474 .71776 .66396 .71751 Mtetra
.511 .873 .984 r
.66396 .71751 .66474 .71776 .66641 .71716 .66564 .7171 Mtetra
.393 .845 .911 r
.66564 .7171 .66641 .71716 .66809 .71659 .66732 .71669 Mtetra
.019 0 0 r
.66732 .71669 .66809 .71659 .66978 .71664 .66901 .71661 Mtetra
.326 .809 .877 r
.66901 .71661 .66978 .71664 .67147 .71632 .67069 .71625 Mtetra
.669 .96 .94 r
.67069 .71625 .67147 .71632 .67312 .71527 .67236 .71537 Mtetra
.967 .912 .703 r
.67236 .71537 .67312 .71527 .67458 .70943 .67392 .7122 Mtetra
.884 .784 .291 r
.67392 .7122 .67458 .70943 .66796 .51541 .67527 .70396 Mtetra
.065 0 .445 r
.67527 .70396 .66796 .51541 .66933 .51011 .66876 .51359 Mtetra
.097 0 .276 r
.66876 .51359 .66933 .51011 .67089 .50897 .67022 .51025 Mtetra
0 0 0 r
.67022 .51025 .67089 .50897 .67248 .50854 .67175 .50843 Mtetra
.795 .971 .912 r
.67175 .50843 .67248 .50854 .67408 .50845 .67331 .50727 Mtetra
.673 .685 .854 r
.67331 .50727 .67408 .50845 .67567 .50798 .67489 .50672 Mtetra
.624 .653 .858 r
.67489 .50672 .67567 .50798 .67725 .50752 .67649 .50643 Mtetra
.597 .671 .892 r
.67649 .50643 .67725 .50752 .67885 .5071 .67809 .50623 Mtetra
.671 .749 .909 r
.67809 .50623 .67885 .5071 .68044 .5068 .67968 .50572 Mtetra
.68 .707 .869 r
.67968 .50572 .68044 .5068 .68204 .50653 .68126 .50515 Mtetra
.671 .655 .826 r
.68126 .50515 .68204 .50653 .68365 .50626 .68285 .50458 Mtetra
.649 .61 .797 r
.68285 .50458 .68365 .50626 .68524 .50589 .68445 .50411 Mtetra
.64 .595 .787 r
.68445 .50411 .68524 .50589 .68684 .50547 .68604 .50368 Mtetra
.634 .591 .788 r
.68604 .50368 .68684 .50547 .68843 .50499 .68764 .50329 Mtetra
.623 .595 .801 r
.68764 .50329 .68843 .50499 .69002 .50439 .68925 .50299 Mtetra
.621 .63 .838 r
.68925 .50299 .69002 .50439 .69161 .50377 .69085 .50271 Mtetra
.621 .688 .892 r
.69085 .50271 .69161 .50377 .6932 .50317 .69246 .50242 Mtetra
.638 .769 .942 r
.69246 .50242 .6932 .50317 .6948 .5027 .69406 .50201 Mtetra
.653 .79 .947 r
.69406 .50201 .6948 .5027 .6964 .50228 .69566 .50154 Mtetra
.669 .784 .935 r
.69566 .50154 .6964 .50228 .69801 .50184 .69726 .50103 Mtetra
.713 .776 .901 r
.69726 .50103 .69801 .50184 .6996 .50129 .69885 .50032 Mtetra
.697 .736 .881 r
.69885 .50032 .6996 .50129 .7012 .5007 .70044 .49967 Mtetra
.655 .709 .887 r
.70044 .49967 .7012 .5007 .70279 .5001 .70205 .49922 Mtetra
.517 .686 .943 r
.70205 .49922 .70279 .5001 .70437 .49912 .70368 .49922 Mtetra
.446 0 0 r
.70368 .49922 .70437 .49912 .70596 .49841 .70534 .49979 Mtetra
.716 .331 .318 r
.70534 .49979 .70596 .49841 .70759 .49834 .70706 .50147 Mtetra
.965 .677 .437 r
.70706 .50147 .70759 .49834 .70941 .50168 .71876 .6835 Mtetra
.593 .379 .56 r
.71876 .6835 .70941 .50168 .72189 .69541 .72131 .69815 Mtetra
.73 .4 .421 r
.72131 .69815 .72189 .69541 .72397 .70158 .7232 .70097 Mtetra
0 .449 .854 r
.7232 .70097 .72397 .70158 .72577 .70268 .72498 .7017 Mtetra
.598 .711 .923 r
.72498 .7017 .72577 .70268 .7275 .70244 .72671 .70145 Mtetra
.769 .766 .85 r
.72671 .70145 .7275 .70244 .72917 .70119 .72838 .7003 Mtetra
.93 .774 .667 r
.72838 .7003 .72917 .70119 .73066 .69691 .72987 .69604 Mtetra
.971 .689 .436 r
.72987 .69604 .73066 .69691 .72095 .50279 .72021 .50185 Mtetra
.955 .741 .574 r
.72021 .50185 .72095 .50279 .72213 .49488 .72139 .49398 Mtetra
.828 .781 .808 r
.72139 .49398 .72213 .49488 .72367 .49327 .72293 .49237 Mtetra
.641 .736 .917 r
.72293 .49237 .72367 .49327 .72529 .49286 .72456 .49197 Mtetra
.496 .676 .945 r
.72456 .49197 .72529 .49286 .72694 .4929 .7262 .49203 Mtetra
.599 .724 .932 r
.7262 .49203 .72694 .4929 .72857 .49263 .72784 .49178 Mtetra
.642 .746 .925 r
.72784 .49178 .72857 .49263 .73019 .4922 .72946 .49137 Mtetra
.651 .755 .926 r
.72946 .49137 .73019 .4922 .73181 .49173 .73108 .49093 Mtetra
.671 .768 .923 r
.73108 .49093 .73181 .49173 .73343 .49114 .7327 .4904 Mtetra
.686 .789 .928 r
.7327 .4904 .73343 .49114 .73504 .49051 .73432 .48981 Mtetra
.695 .802 .931 r
.73432 .48981 .73504 .49051 .73665 .48991 .73593 .48917 Mtetra
.765 .811 .889 r
.73593 .48917 .73665 .48991 .73825 .4891 .73752 .4882 Mtetra
.738 .765 .875 r
.73752 .4882 .73825 .4891 .73987 .4885 .73912 .48733 Mtetra
.645 .679 .868 r
.73912 .48733 .73987 .4885 .74153 .48852 .74075 .48692 Mtetra
.138 .324 .788 r
.74075 .48692 .74153 .48852 .74339 .49163 .74251 .48842 Mtetra
0 0 .391 r
.74251 .48842 .74339 .49163 .75793 .68548 .74456 .49438 Mtetra
.111 .03 .476 r
.74456 .49438 .75793 .68548 .76011 .69175 .75899 .68575 Mtetra
.46 .352 .644 r
.75899 .68575 .76011 .69175 .76194 .69272 .76089 .68781 Mtetra
.602 .461 .662 r
.76089 .68781 .76194 .69272 .76368 .69233 .76263 .68743 Mtetra
.64 .486 .658 r
.76263 .68743 .76368 .69233 .76539 .6915 .76432 .68633 Mtetra
.62 .469 .656 r
.76432 .68633 .76539 .6915 .76711 .69089 .76604 .68559 Mtetra
.605 .458 .655 r
.76604 .68559 .76711 .69089 .76885 .69044 .76778 .68512 Mtetra
.605 .457 .655 r
.76778 .68512 .76885 .69044 .77059 .68999 .76951 .68465 Mtetra
.604 .457 .654 r
.76951 .68465 .77059 .68999 .77233 .68954 .77125 .6842 Mtetra
.603 .456 .655 r
.77125 .6842 .77233 .68954 .77407 .68909 .77299 .68376 Mtetra
.77299 .68376 .77407 .68909 .77581 .68865 .77473 .68333 Mtetra
.77473 .68333 .77581 .68865 .77756 .6882 .77648 .68289 Mtetra
.603 .457 .655 r
.77648 .68289 .77756 .6882 .7793 .68775 .77822 .68246 Mtetra
.604 .457 .655 r
.77822 .68246 .7793 .68775 .78105 .68729 .77997 .68202 Mtetra
.604 .457 .656 r
.77997 .68202 .78105 .68729 .7828 .68684 .78171 .68158 Mtetra
.604 .458 .656 r
.78171 .68158 .7828 .68684 .78454 .68638 .78346 .68113 Mtetra
.78346 .68113 .78454 .68638 .78629 .68592 .78521 .68068 Mtetra
.605 .458 .656 r
.78521 .68068 .78629 .68592 .78804 .68546 .78696 .68023 Mtetra
.605 .459 .656 r
.78696 .68023 .78804 .68546 .78979 .685 .7887 .67977 Mtetra
.7887 .67977 .78979 .685 .79154 .68454 .79045 .6793 Mtetra
.79045 .6793 .79154 .68454 .79329 .68407 .79221 .67884 Mtetra
.79221 .67884 .79329 .68407 .79505 .68361 .79396 .67837 Mtetra
.606 .459 .656 r
.79396 .67837 .79505 .68361 .7968 .68314 .79571 .67789 Mtetra
.79571 .67789 .7968 .68314 .79856 .68267 .79746 .67742 Mtetra
.79746 .67742 .79856 .68267 .80031 .6822 .79922 .67694 Mtetra
.79922 .67694 .80031 .6822 .80207 .68173 .80097 .67645 Mtetra
.80097 .67645 .80207 .68173 .80383 .68125 .80273 .67596 Mtetra
.80273 .67596 .80383 .68125 .80559 .68078 .80448 .67547 Mtetra
.606 .459 .655 r
.80448 .67547 .80559 .68078 .80735 .68031 .80624 .67498 Mtetra
.606 .458 .655 r
.80624 .67498 .80735 .68031 .80911 .67983 .808 .67449 Mtetra
.808 .67449 .80911 .67983 .81087 .67936 .80976 .674 Mtetra
.80976 .674 .81087 .67936 .81264 .67888 .81152 .67351 Mtetra
.606 .458 .654 r
.81152 .67351 .81264 .67888 .8144 .6784 .81328 .67302 Mtetra
.605 .457 .654 r
.81328 .67302 .8144 .6784 .81617 .67793 .81504 .67253 Mtetra
.81504 .67253 .81617 .67793 .81793 .67746 .81681 .67204 Mtetra
.81681 .67204 .81793 .67746 .8197 .67698 .81857 .67156 Mtetra
.81857 .67156 .8197 .67698 .82147 .67651 .82034 .67108 Mtetra
.605 .456 .654 r
.82034 .67108 .82147 .67651 .82324 .67603 .82211 .6706 Mtetra
.605 .456 .653 r
.82211 .6706 .82324 .67603 .82501 .67556 .82388 .67012 Mtetra
.82388 .67012 .82501 .67556 .82678 .67509 .82565 .66964 Mtetra
.604 .456 .653 r
.82565 .66964 .82678 .67509 .82856 .67462 .82742 .66916 Mtetra
.82742 .66916 .82856 .67462 .83033 .67414 .82919 .66869 Mtetra
.82919 .66869 .83033 .67414 .83211 .67367 .83097 .66822 Mtetra
.83097 .66822 .83211 .67367 .83389 .6732 .83274 .66775 Mtetra
.83274 .66775 .83389 .6732 .83566 .67273 .83452 .66728 Mtetra
.83452 .66728 .83566 .67273 .83744 .67226 .8363 .66681 Mtetra
.604 .456 .654 r
.8363 .66681 .83744 .67226 .83922 .67179 .83808 .66635 Mtetra
.83808 .66635 .83922 .67179 .84101 .67132 .83986 .66589 Mtetra
.83986 .66589 .84101 .67132 .84279 .67085 .84164 .66543 Mtetra
.84164 .66543 .84279 .67085 .84457 .67038 .84343 .66497 Mtetra
.84343 .66497 .84457 .67038 .84636 .66991 .84521 .66451 Mtetra
.84521 .66451 .84636 .66991 .84814 .66944 .847 .66405 Mtetra
.604 .457 .655 r
.847 .66405 .84814 .66944 .84993 .66897 .84878 .66359 Mtetra
.84878 .66359 .84993 .66897 .85172 .6685 .85057 .66313 Mtetra
.85057 .66313 .85172 .6685 .85351 .66803 .85236 .66267 Mtetra
.85236 .66267 .85351 .66803 .8553 .66756 .85415 .66221 Mtetra
.85415 .66221 .8553 .66756 .85709 .66709 .85594 .66174 Mtetra
.604 .458 .655 r
.85594 .66174 .85709 .66709 .85888 .66661 .85773 .66127 Mtetra
.605 .458 .656 r
.85773 .66127 .85888 .66661 .86068 .66614 .85952 .6608 Mtetra
.85952 .6608 .86068 .66614 .86247 .66566 .86132 .66033 Mtetra
.86132 .66033 .86247 .66566 .86427 .66518 .86311 .65985 Mtetra
.86311 .65985 .86427 .66518 .86606 .66471 .86491 .65937 Mtetra
.86491 .65937 .86606 .66471 .86786 .66423 .8667 .65889 Mtetra
.8667 .65889 .86786 .66423 .86966 .66375 .8685 .65841 Mtetra
.606 .459 .656 r
.8685 .65841 .86966 .66375 .87146 .66326 .8703 .65792 Mtetra
.606 .459 .655 r
.8703 .65792 .87146 .66326 .87326 .66278 .87209 .65742 Mtetra
.87209 .65742 .87326 .66278 .87506 .66229 .87389 .65692 Mtetra
.87389 .65692 .87506 .66229 .87686 .6618 .87569 .65641 Mtetra
.607 .459 .655 r
.87569 .65641 .87686 .6618 .87867 .66131 .87749 .65589 Mtetra
.608 .459 .654 r
.87749 .65589 .87867 .66131 .88047 .66081 .87929 .65535 Mtetra
.608 .458 .653 r
.87929 .65535 .88047 .66081 .88228 .66031 .88109 .6548 Mtetra
.614 .462 .652 r
.88109 .6548 .88228 .66031 .88408 .65979 .88287 .65411 Mtetra
.622 .465 .649 r
.88287 .65411 .88408 .65979 .88588 .65926 .88464 .65321 Mtetra
.602 .448 .645 r
.88464 .65321 .88588 .65926 .88769 .65873 .88644 .65272 Mtetra
.551 .415 .649 r
.88644 .65272 .88769 .65873 .8895 .65821 .88836 .65331 Mtetra
.479 .383 .669 r
.88836 .65331 .8895 .65821 .89131 .65771 .89039 .65485 Mtetra
.455 .428 .739 r
.89039 .65485 .89131 .65771 .89312 .65722 .89236 .65591 Mtetra
.45 .578 .891 r
.89236 .65591 .89312 .65722 .89493 .65671 .89427 .65631 Mtetra
.527 .853 .997 r
.89427 .65631 .89493 .65671 .89674 .65618 .8961 .65592 Mtetra
.563 .906 .974 r
.8961 .65592 .89674 .65618 .89855 .65564 .8979 .65533 Mtetra
.608 .909 .982 r
.8979 .65533 .89855 .65564 .90036 .65511 .89971 .65468 Mtetra
.591 .873 .994 r
.89971 .65468 .90036 .65511 .90218 .6546 .90152 .65417 Mtetra
.589 .872 .994 r
.90152 .65417 .90218 .6546 .904 .65409 .90334 .65366 Mtetra
.587 .871 .994 r
.90334 .65366 .904 .65409 .90582 .65359 .90516 .65316 Mtetra
.584 .868 .995 r
.90516 .65316 .90582 .65359 .90764 .6531 .90698 .65267 Mtetra
.581 .867 .995 r
.90698 .65267 .90764 .6531 .90946 .65262 .90881 .65218 Mtetra
.577 .865 .995 r
.90881 .65218 .90946 .65262 .91129 .65214 .91063 .65171 Mtetra
.572 .864 .996 r
.91063 .65171 .91129 .65214 .91311 .65167 .91246 .65124 Mtetra
.569 .864 .996 r
.91246 .65124 .91311 .65167 .91494 .65121 .91429 .65078 Mtetra
.551 .856 .997 r
.91429 .65078 .91494 .65121 .91677 .65075 .91613 .65036 Mtetra
.488 .836 .996 r
.91613 .65036 .91677 .65075 .91861 .65031 .91798 .65005 Mtetra
.502 .876 .977 r
.91798 .65005 .91861 .65031 .92044 .64987 .91981 .64958 Mtetra
.682 .941 .964 r
.91981 .64958 .92044 .64987 .92228 .64942 .9216 .64871 Mtetra
.865 .861 .834 r
.9216 .64871 .92228 .64942 .92411 .64894 .92329 .64692 Mtetra
.796 .667 .721 r
.92329 .64692 .92411 .64894 .92595 .64846 .92491 .64459 Mtetra
.724 .558 .665 r
.92491 .64459 .92595 .64846 .92778 .64798 .92651 .64211 Mtetra
.621 .463 .646 r
.92651 .64211 .92778 .64798 .92962 .64751 .9283 .64121 Mtetra
.593 .44 .643 r
.9283 .64121 .92962 .64751 .93146 .64705 .93015 .64091 Mtetra
.589 .439 .646 r
.93015 .64091 .93146 .64705 .9333 .64657 .93202 .6407 Mtetra
.621 .463 .646 r
.93202 .6407 .9333 .64657 .93514 .64606 .93381 .63979 Mtetra
.603 .447 .643 r
.93381 .63979 .93514 .64606 .93697 .64553 .93564 .63925 Mtetra
.563 .421 .645 r
.93564 .63925 .93697 .64553 .93881 .64501 .93758 .6396 Mtetra
.483 .379 .66 r
.93758 .6396 .93881 .64501 .94065 .64451 .93968 .64127 Mtetra
.463 .418 .722 r
.93968 .64127 .94065 .64451 .94249 .644 .94173 .64244 Mtetra
.445 .535 .855 r
.94173 .64244 .94249 .644 .94434 .64348 .9437 .64299 Mtetra
.541 .837 .999 r
.9437 .64299 .94434 .64348 .94617 .64292 .94556 .64263 Mtetra
.578 .908 .978 r
.94556 .64263 .94617 .64292 .94801 .64235 .94739 .64201 Mtetra
.651 .923 .976 r
.94739 .64201 .94801 .64235 .94985 .64179 .94921 .64126 Mtetra
.673 .876 .975 r
.94921 .64126 .94985 .64179 .95169 .64124 .95104 .64055 Mtetra
.689 .837 .954 r
.95104 .64055 .95169 .64124 .95354 .64071 .95286 .63984 Mtetra
.683 .788 .929 r
.95286 .63984 .95354 .64071 .95539 .64021 .95469 .63919 Mtetra
.649 .737 .913 r
.95469 .63919 .95539 .64021 .95725 .63976 .95655 .63869 Mtetra
.637 .722 .909 r
.95655 .63869 .95725 .63976 .95911 .63934 .95841 .63826 Mtetra
.617 .712 .913 r
.95841 .63826 .95911 .63934 .96098 .63898 .96028 .63792 Mtetra
.496 .655 .93 r
.96028 .63792 .96098 .63898 .96291 .63907 .96222 .63803 Mtetra
.612 .717 .92 r
.96222 .63803 .96291 .63907 .96479 .63873 .9641 .6377 Mtetra
.78 .784 .856 r
.9641 .6377 .96479 .63873 .96655 .63748 .96586 .63644 Mtetra
.972 .772 .576 r
.96586 .63644 .96655 .63748 .96769 .63135 .96698 .63013 Mtetra
.975 .669 .324 r
.96698 .63013 .96769 .63135 .94394 .43197 .94326 .43079 Mtetra
.953 .763 .609 r
.94326 .43079 .94394 .43197 .94507 .42666 .94441 .42562 Mtetra
.751 .76 .86 r
.94441 .42562 .94507 .42666 .94675 .42563 .94609 .4246 Mtetra
.623 .71 .908 r
.94609 .4246 .94675 .42563 .94851 .42529 .94786 .42425 Mtetra
.54 .669 .921 r
.94786 .42425 .94851 .42529 .95032 .42527 .94967 .42423 Mtetra
.694 .74 .886 r
.94967 .42423 .95032 .42527 .95206 .4247 .95139 .42354 Mtetra
.673 .707 .873 r
.95139 .42354 .95206 .4247 .9538 .42412 .95313 .42296 Mtetra
.632 .688 .884 r
.95313 .42296 .9538 .42412 .95554 .42352 .9549 .42258 Mtetra
.494 .668 .941 r
.9549 .42258 .95554 .42352 .95722 .42248 .95673 .42266 Mtetra
.46 0 0 r
.95673 .42266 .95722 .42248 .95895 .42181 .95865 .42335 Mtetra
.721 .319 .287 r
.95865 .42335 .95895 .42181 .96078 .42183 .96074 .42533 Mtetra
.576 .367 .56 r
.38294 .78497 .39122 .59731 .38559 .77947 .38432 .78795 Mtetra
.608 .359 .514 r
.38432 .78795 .38559 .77947 .38676 .78801 .38577 .78925 Mtetra
.603 .208 .267 r
.38577 .78925 .38676 .78801 .38816 .79045 .38725 .78981 Mtetra
.118 .549 .918 r
.38725 .78981 .38816 .79045 .38964 .79108 .38873 .79026 Mtetra
.574 .72 .942 r
.38873 .79026 .38964 .79108 .39115 .79086 .39024 .79009 Mtetra
.759 .775 .866 r
.39024 .79009 .39115 .79086 .3927 .78972 .39178 .78913 Mtetra
.913 .752 .668 r
.39178 .78913 .3927 .78972 .39438 .78479 .39346 .78438 Mtetra
.938 .687 .532 r
.39346 .78438 .39438 .78479 .40266 .59521 .40179 .59488 Mtetra
.933 .749 .631 r
.40179 .59488 .40266 .59521 .4043 .5892 .40344 .58852 Mtetra
.792 .786 .847 r
.40344 .58852 .4043 .5892 .40577 .58808 .40491 .58738 Mtetra
.63 .762 .942 r
.40491 .58738 .40577 .58808 .4072 .58773 .40634 .58705 Mtetra
.472 .71 .973 r
.40634 .58705 .4072 .58773 .40863 .58773 .40777 .58707 Mtetra
.681 .782 .926 r
.40777 .58707 .40863 .58773 .41007 .58721 .40921 .58656 Mtetra
.697 .786 .92 r
.40921 .58656 .41007 .58721 .41152 .58664 .41066 .58598 Mtetra
.695 .786 .921 r
.41066 .58598 .41152 .58664 .41297 .58608 .41211 .58542 Mtetra
.716 .788 .908 r
.41211 .58542 .41297 .58608 .41442 .58531 .41356 .58476 Mtetra
.682 .813 .946 r
.41356 .58476 .41442 .58531 .41587 .58476 .41501 .58423 Mtetra
.583 .797 .981 r
.41501 .58423 .41587 .58476 .41731 .58467 .41645 .58397 Mtetra
0 .388 .824 r
.41645 .58397 .41731 .58467 .41868 .58665 .41786 .58468 Mtetra
.15 .279 .742 r
.41786 .58468 .41868 .58665 .41989 .59379 .41925 .58614 Mtetra
.449 .317 .608 r
.41925 .58614 .41989 .59379 .41575 .77803 .42061 .58857 Mtetra
.573 .367 .564 r
.42061 .58857 .41575 .77803 .41724 .7789 .42206 .58829 Mtetra
.574 .368 .564 r
.42206 .58829 .41724 .7789 .41878 .77828 .42353 .58738 Mtetra
.572 .367 .564 r
.42353 .58738 .41878 .77828 .42032 .77746 .42497 .5874 Mtetra
0 0 .374 r
.42497 .5874 .42032 .77746 .4218 .77885 .42115 .76958 Mtetra
.043 .009 .488 r
.42115 .76958 .4218 .77885 .42329 .78016 .42244 .77763 Mtetra
0 .069 .614 r
.42244 .77763 .42329 .78016 .42479 .78097 .42389 .78018 Mtetra
.357 .639 .961 r
.42389 .78018 .42479 .78097 .42632 .78089 .42541 .78044 Mtetra
.619 .84 .984 r
.42541 .78044 .42632 .78089 .42786 .78047 .42695 .78002 Mtetra
.713 .855 .95 r
.42695 .78002 .42786 .78047 .4294 .77992 .4285 .77932 Mtetra
.66 .806 .954 r
.4285 .77932 .4294 .77992 .43094 .77951 .43004 .77884 Mtetra
.647 .785 .947 r
.43004 .77884 .43094 .77951 .43248 .77913 .43158 .77841 Mtetra
.649 .771 .938 r
.43158 .77841 .43248 .77913 .43402 .77876 .43313 .77798 Mtetra
.595 .744 .948 r
.43313 .77798 .43402 .77876 .43556 .77865 .43467 .77774 Mtetra
.625 .719 .914 r
.43467 .77774 .43556 .77865 .4371 .7784 .43621 .77742 Mtetra
.683 .723 .88 r
.43621 .77742 .4371 .7784 .43865 .77769 .43776 .77686 Mtetra
.788 .768 .835 r
.43776 .77686 .43865 .77769 .44025 .77518 .43932 .77562 Mtetra
.899 .986 .779 r
.43932 .77562 .44025 .77518 .44192 .76915 .44091 .77358 Mtetra
.094 0 .272 r
.44091 .77358 .44192 .76915 .4477 .58173 .44253 .76994 Mtetra
0 0 .369 r
.44253 .76994 .4477 .58173 .44925 .5775 .44822 .58542 Mtetra
0 0 .221 r
.44822 .58542 .44925 .5775 .45075 .57555 .44987 .57666 Mtetra
.907 .946 .594 r
.44987 .57666 .45075 .57555 .45223 .57432 .45139 .57365 Mtetra
.793 .793 .852 r
.45139 .57365 .45223 .57432 .4537 .57361 .45287 .57251 Mtetra
.66 .681 .859 r
.45287 .57251 .4537 .57361 .45517 .5732 .45434 .57207 Mtetra
.591 .651 .878 r
.45434 .57207 .45517 .5732 .45663 .57295 .4558 .57193 Mtetra
.606 .679 .893 r
.4558 .57193 .45663 .57295 .4581 .57267 .45726 .57172 Mtetra
.614 .696 .902 r
.45726 .57172 .4581 .57267 .45956 .57238 .45873 .57147 Mtetra
.615 .706 .91 r
.45873 .57147 .45956 .57238 .46103 .57207 .46019 .57121 Mtetra
.638 .725 .911 r
.46019 .57121 .46103 .57207 .4625 .57168 .46166 .57086 Mtetra
.658 .742 .912 r
.46166 .57086 .4625 .57168 .46397 .57122 .46313 .57044 Mtetra
.674 .754 .911 r
.46313 .57044 .46397 .57122 .46544 .57071 .46461 .56995 Mtetra
.727 .769 .887 r
.46461 .56995 .46544 .57071 .46692 .56987 .46608 .56921 Mtetra
.729 .797 .906 r
.46608 .56921 .46692 .56987 .4684 .56909 .46756 .56849 Mtetra
.668 .801 .946 r
.46756 .56849 .4684 .56909 .46988 .56873 .46904 .568 Mtetra
.398 .666 .968 r
.46904 .568 .46988 .56873 .47132 .56995 .4705 .56817 Mtetra
.311 .406 .798 r
.4705 .56817 .47132 .56995 .47272 .57439 .47196 .56915 Mtetra
.373 .288 .63 r
.47196 .56915 .47272 .57439 .4714 .76156 .47339 .5716 Mtetra
0 0 .394 r
.47339 .5716 .4714 .76156 .4729 .76561 .47217 .75466 Mtetra
.103 .047 .503 r
.47217 .75466 .4729 .76561 .47444 .7669 .47359 .76379 Mtetra
.119 .181 .654 r
.47359 .76379 .47444 .7669 .47599 .7674 .47512 .76633 Mtetra
.319 .547 .914 r
.47512 .76633 .47599 .7674 .47756 .76734 .47667 .76684 Mtetra
.597 .823 .986 r
.47667 .76684 .47756 .76734 .47912 .76695 .47824 .76648 Mtetra
.703 .856 .955 r
.47824 .76648 .47912 .76695 .48069 .7664 .47981 .76581 Mtetra
.637 .81 .966 r
.47981 .76581 .48069 .7664 .48226 .76615 .48138 .76538 Mtetra
.622 .756 .942 r
.48138 .76538 .48226 .76615 .48383 .76592 .48295 .76504 Mtetra
.684 .746 .898 r
.48295 .76504 .48383 .76592 .4854 .76528 .48453 .76447 Mtetra
.78 .777 .85 r
.48453 .76447 .4854 .76528 .48699 .76313 .48611 .76332 Mtetra
.905 .966 .811 r
.48611 .76332 .48699 .76313 .48862 .7578 .4877 .76137 Mtetra
.005 0 .2 r
.4877 .76137 .48862 .7578 .49201 .56937 .4893 .75798 Mtetra
0 0 .397 r
.4893 .75798 .49201 .56937 .49354 .56421 .49259 .57672 Mtetra
0 0 .31 r
.49259 .57672 .49354 .56421 .49505 .56212 .4942 .56366 Mtetra
.79 .868 .429 r
.4942 .56366 .49505 .56212 .49654 .56079 .49571 .56035 Mtetra
.841 .849 .851 r
.49571 .56035 .49654 .56079 .49804 .55999 .49721 .55894 Mtetra
.678 .7 .863 r
.49721 .55894 .49804 .55999 .49953 .55951 .4987 .55841 Mtetra
.613 .668 .879 r
.4987 .55841 .49953 .55951 .50102 .55918 .50019 .55818 Mtetra
.627 .692 .891 r
.50019 .55818 .50102 .55918 .50251 .5588 .50168 .55788 Mtetra
.656 .72 .896 r
.50168 .55788 .50251 .5588 .504 .55834 .50318 .55746 Mtetra
.655 .728 .903 r
.50318 .55746 .504 .55834 .50549 .55788 .50467 .55704 Mtetra
.659 .739 .909 r
.50467 .55704 .50549 .55788 .50699 .55742 .50617 .55661 Mtetra
.662 .747 .913 r
.50617 .55661 .50699 .55742 .50848 .55695 .50766 .55616 Mtetra
.663 .751 .916 r
.50766 .55616 .50848 .55695 .50998 .55649 .50916 .5557 Mtetra
.687 .76 .907 r
.50916 .5557 .50998 .55649 .51148 .55586 .51065 .55515 Mtetra
.689 .78 .921 r
.51065 .55515 .51148 .55586 .51297 .55522 .51215 .55459 Mtetra
.628 .787 .958 r
.51215 .55459 .51297 .55522 .51447 .55493 .51365 .55423 Mtetra
.301 .624 .96 r
.51365 .55423 .51447 .55493 .51597 .55595 .51515 .55453 Mtetra
.091 .323 .799 r
.51515 .55453 .51597 .55595 .51746 .55998 .51665 .55575 Mtetra
.365 .304 .655 r
.51665 .55575 .51746 .55998 .51863 .74761 .51814 .55784 Mtetra
.569 .364 .564 r
.51814 .55784 .51863 .74761 .52021 .75163 .51964 .55973 Mtetra
.572 .367 .564 r
.51964 .55973 .52021 .75163 .5218 .75159 .52115 .55967 Mtetra
.574 .368 .564 r
.52115 .55967 .5218 .75159 .52339 .7507 .52266 .55871 Mtetra
.52266 .55871 .52339 .7507 .52499 .74988 .52416 .55787 Mtetra
.573 .367 .564 r
.52416 .55787 .52499 .74988 .52658 .74945 .52567 .55741 Mtetra
.52567 .55741 .52658 .74945 .52817 .749 .52718 .55693 Mtetra
.52718 .55693 .52817 .749 .52977 .74856 .52869 .55646 Mtetra
.52869 .55646 .52977 .74856 .53136 .74813 .5302 .55599 Mtetra
.5302 .55599 .53136 .74813 .53296 .7477 .53171 .55553 Mtetra
.53171 .55553 .53296 .7477 .53456 .74726 .53323 .55505 Mtetra
.573 .368 .564 r
.53323 .55505 .53456 .74726 .53616 .74682 .53474 .55457 Mtetra
.53474 .55457 .53616 .74682 .53776 .74637 .53625 .55407 Mtetra
.53625 .55407 .53776 .74637 .53936 .74591 .53777 .55355 Mtetra
.53777 .55355 .53936 .74591 .54096 .74543 .53928 .553 Mtetra
.53928 .553 .54096 .74543 .54256 .74495 .5408 .55246 Mtetra
.574 .368 .564 r
.5408 .55246 .54256 .74495 .54416 .74429 .54231 .55148 Mtetra
.54231 .55148 .54416 .74429 .54576 .74349 .54383 .55033 Mtetra
.572 .367 .564 r
.54383 .55033 .54576 .74349 .54737 .74314 .54535 .55014 Mtetra
.564 .361 .563 r
.54535 .55014 .54737 .74314 .54898 .744 .5469 .55475 Mtetra
.011 0 .416 r
.5469 .55475 .54898 .744 .5506 .74554 .54973 .74116 Mtetra
.08 .11 .591 r
.54973 .74116 .5506 .74554 .55223 .74659 .55137 .74512 Mtetra
.128 .353 .815 r
.55137 .74512 .55223 .74659 .55384 .74692 .55299 .74634 Mtetra
.552 .79 .987 r
.55299 .74634 .55384 .74692 .55545 .74658 .5546 .7461 Mtetra
.671 .855 .97 r
.5546 .7461 .55545 .74658 .55707 .74607 .55622 .74552 Mtetra
.668 .831 .962 r
.55622 .74552 .55707 .74607 .55868 .74563 .55783 .74496 Mtetra
.585 .778 .972 r
.55783 .74496 .55868 .74563 .5603 .74536 .55945 .74469 Mtetra
.587 .776 .97 r
.55945 .74469 .5603 .74536 .56191 .74509 .56107 .74441 Mtetra
.606 .779 .964 r
.56107 .74441 .56191 .74509 .56353 .74477 .56268 .74408 Mtetra
.63 .784 .955 r
.56268 .74408 .56353 .74477 .56515 .74438 .5643 .74368 Mtetra
.638 .784 .952 r
.5643 .74368 .56515 .74438 .56677 .74397 .56592 .74326 Mtetra
.641 .784 .95 r
.56592 .74326 .56677 .74397 .56839 .74354 .56754 .74283 Mtetra
.639 .782 .95 r
.56754 .74283 .56839 .74354 .57001 .74312 .56916 .7424 Mtetra
.641 .782 .948 r
.56916 .7424 .57001 .74312 .57163 .74269 .57079 .74197 Mtetra
.642 .781 .948 r
.57079 .74197 .57163 .74269 .57325 .74227 .57241 .74154 Mtetra
.641 .78 .947 r
.57241 .74154 .57325 .74227 .57488 .74184 .57403 .74111 Mtetra
.648 .781 .945 r
.57403 .74111 .57488 .74184 .5765 .7414 .57566 .74066 Mtetra
.664 .784 .938 r
.57566 .74066 .5765 .7414 .57813 .74091 .57728 .74015 Mtetra
.685 .784 .926 r
.57728 .74015 .57813 .74091 .57975 .74035 .57891 .73956 Mtetra
.688 .775 .918 r
.57891 .73956 .57975 .74035 .58138 .73979 .58053 .73896 Mtetra
.664 .759 .921 r
.58053 .73896 .58138 .73979 .58301 .73937 .58216 .73846 Mtetra
.616 .727 .925 r
.58216 .73846 .58301 .73937 .58464 .73918 .58379 .73815 Mtetra
.656 .714 .891 r
.58379 .73815 .58464 .73918 .58627 .73869 .58542 .7377 Mtetra
.744 .746 .853 r
.58542 .7377 .58627 .73869 .58788 .73725 .58705 .73674 Mtetra
.882 .84 .799 r
.58705 .73674 .58788 .73725 .58944 .73305 .58865 .7347 Mtetra
0 0 0 r
.58865 .7347 .58944 .73305 .58763 .54736 .59024 .73186 Mtetra
.566 .359 .558 r
.59024 .73186 .58763 .54736 .58898 .53705 .59182 .72866 Mtetra
.57 .362 .559 r
.59182 .72866 .58898 .53705 .59051 .53594 .59344 .72765 Mtetra
.571 .363 .559 r
.59344 .72765 .59051 .53594 .59206 .5358 .59508 .7276 Mtetra
.572 .363 .559 r
.59508 .7276 .59206 .5358 .59362 .53593 .59673 .72773 Mtetra
.571 .362 .559 r
.59673 .72773 .59362 .53593 .59516 .53548 .59836 .72733 Mtetra
.59836 .72733 .59516 .53548 .59671 .53504 .6 .72693 Mtetra
.6 .72693 .59671 .53504 .59826 .53458 .60164 .7265 Mtetra
.60164 .7265 .59826 .53458 .5998 .53409 .60327 .72605 Mtetra
.60327 .72605 .5998 .53409 .60135 .53358 .60491 .72557 Mtetra
.60491 .72557 .60135 .53358 .6029 .53305 .60655 .72507 Mtetra
.60655 .72507 .6029 .53305 .60445 .53249 .60819 .72453 Mtetra
.60819 .72453 .60445 .53249 .60599 .53194 .60983 .72399 Mtetra
.60983 .72399 .60599 .53194 .60754 .53125 .61147 .72333 Mtetra
.57 .362 .559 r
.61147 .72333 .60754 .53125 .60908 .53016 .61309 .72222 Mtetra
.571 .362 .559 r
.61309 .72222 .60908 .53016 .61063 .52969 .61474 .72175 Mtetra
.573 .364 .559 r
.61474 .72175 .61063 .52969 .61223 .53091 .61642 .72274 Mtetra
.575 .366 .559 r
.61642 .72274 .61223 .53091 .61876 .7182 .61814 .72518 Mtetra
.622 .359 .499 r
.61814 .72518 .61876 .7182 .62063 .72614 .61984 .72678 Mtetra
.643 .172 .12 r
.61984 .72678 .62063 .72614 .62236 .72849 .62153 .72771 Mtetra
.302 .616 .957 r
.62153 .72771 .62236 .72849 .62404 .72898 .62321 .72807 Mtetra
.606 .725 .929 r
.62321 .72807 .62404 .72898 .62569 .72863 .62487 .72779 Mtetra
.802 .789 .841 r
.62487 .72779 .62569 .72863 .62732 .72713 .6265 .72645 Mtetra
.942 .767 .637 r
.6265 .72645 .62732 .72713 .62882 .72157 .62801 .72103 Mtetra
.963 .691 .471 r
.62801 .72103 .62882 .72157 .62471 .52763 .62394 .52702 Mtetra
.947 .766 .626 r
.62394 .52702 .62471 .52763 .62612 .52229 .62535 .52149 Mtetra
.76 .783 .872 r
.62535 .52149 .62612 .52229 .62767 .52133 .6269 .52053 Mtetra
.599 .737 .941 r
.6269 .52053 .62767 .52133 .62924 .52106 .62846 .52027 Mtetra
.485 .693 .959 r
.62846 .52027 .62924 .52106 .63082 .52108 .63004 .52031 Mtetra
.658 .766 .929 r
.63004 .52031 .63082 .52108 .63238 .5206 .63161 .51985 Mtetra
.669 .775 .929 r
.63161 .51985 .63238 .5206 .63394 .52008 .63317 .51935 Mtetra
.692 .786 .922 r
.63317 .51935 .63394 .52008 .6355 .51946 .63473 .51875 Mtetra
.759 .804 .889 r
.63473 .51875 .6355 .51946 .63705 .51842 .63629 .51782 Mtetra
.73 .83 .926 r
.63629 .51782 .63705 .51842 .63861 .51769 .63784 .51706 Mtetra
.634 .8 .962 r
.63784 .51706 .63861 .51769 .64019 .51757 .63942 .51665 Mtetra
.317 .571 .93 r
.63942 .51665 .64019 .51757 .64185 .5198 .64102 .51711 Mtetra
.371 .37 .728 r
.64102 .51711 .64185 .5198 .6438 .53005 .64265 .51848 Mtetra
.451 .306 .593 r
.64265 .51848 .6438 .53005 .65208 .71593 .64438 .52246 Mtetra
.073 0 .451 r
.64438 .52246 .65208 .71593 .65384 .71814 .65284 .71207 Mtetra
.21 .174 .596 r
.65284 .71207 .65384 .71814 .65556 .71905 .6547 .71685 Mtetra
.186 .297 .746 r
.6547 .71685 .65556 .71905 .65726 .71931 .65646 .71864 Mtetra
.497 .747 .984 r
.65646 .71864 .65726 .71931 .65894 .71904 .65814 .71856 Mtetra
.645 .856 .98 r
.65814 .71856 .65894 .71904 .66061 .71854 .65981 .71802 Mtetra
.718 .862 .95 r
.65981 .71802 .66061 .71854 .66228 .71793 .66148 .71725 Mtetra
.644 .799 .957 r
.66148 .71725 .66228 .71793 .66396 .71751 .66315 .71678 Mtetra
.648 .786 .948 r
.66315 .71678 .66396 .71751 .66564 .7171 .66483 .71631 Mtetra
.648 .772 .939 r
.66483 .71631 .66564 .7171 .66732 .71669 .66651 .71585 Mtetra
.589 .738 .947 r
.66651 .71585 .66732 .71669 .66901 .71661 .66819 .71561 Mtetra
.636 .719 .907 r
.66819 .71561 .66901 .71661 .67069 .71625 .66988 .71522 Mtetra
.695 .733 .88 r
.66988 .71522 .67069 .71625 .67236 .71537 .67155 .71455 Mtetra
.816 .798 .835 r
.67155 .71455 .67236 .71537 .67392 .7122 .67319 .71307 Mtetra
.697 .888 .51 r
.67319 .71307 .67392 .7122 .67527 .70396 .67479 .71075 Mtetra
.295 .091 .423 r
.67479 .71075 .67527 .70396 .66876 .51359 .67631 .70638 Mtetra
.079 0 .45 r
.67631 .70638 .66876 .51359 .67022 .51025 .66972 .51543 Mtetra
0 0 .26 r
.66972 .51543 .67022 .51025 .67175 .50843 .67106 .50907 Mtetra
.895 .955 .613 r
.67106 .50907 .67175 .50843 .67331 .50727 .67255 .50636 Mtetra
.72 .755 .88 r
.67255 .50636 .67331 .50727 .67489 .50672 .67412 .50561 Mtetra
.612 .673 .884 r
.67412 .50561 .67489 .50672 .67649 .50643 .67572 .50536 Mtetra
.545 .653 .905 r
.67572 .50536 .67649 .50643 .67809 .50623 .67733 .50534 Mtetra
.662 .741 .908 r
.67733 .50534 .67809 .50623 .67968 .50572 .67892 .50487 Mtetra
.678 .755 .909 r
.67892 .50487 .67968 .50572 .68126 .50515 .68051 .50432 Mtetra
.678 .76 .913 r
.68051 .50432 .68126 .50515 .68285 .50458 .6821 .50377 Mtetra
.656 .759 .925 r
.6821 .50377 .68285 .50458 .68445 .50411 .68369 .50331 Mtetra
.644 .759 .933 r
.68369 .50331 .68445 .50411 .68604 .50368 .68529 .5029 Mtetra
.631 .759 .939 r
.68529 .5029 .68604 .50368 .68764 .50329 .68689 .50253 Mtetra
.603 .752 .949 r
.68689 .50253 .68764 .50329 .68925 .50299 .6885 .50224 Mtetra
.594 .753 .954 r
.6885 .50224 .68925 .50299 .69085 .50271 .69011 .50197 Mtetra
.601 .76 .955 r
.69011 .50197 .69085 .50271 .69246 .50242 .69171 .50168 Mtetra
.646 .776 .943 r
.69171 .50168 .69246 .50242 .69406 .50201 .69332 .50125 Mtetra
.667 .775 .93 r
.69332 .50125 .69406 .50201 .69566 .50154 .69491 .50074 Mtetra
.679 .769 .918 r
.69491 .50074 .69566 .50154 .69726 .50103 .69651 .50018 Mtetra
.743 .777 .881 r
.69651 .50018 .69726 .50103 .69885 .50032 .69809 .49931 Mtetra
.706 .732 .871 r
.69809 .49931 .69885 .50032 .70044 .49967 .69968 .4986 Mtetra
.614 .686 .894 r
.69968 .4986 .70044 .49967 .70205 .49922 .7013 .49834 Mtetra
0 .159 .675 r
.7013 .49834 .70205 .49922 .70368 .49922 .70301 .49982 Mtetra
.886 .51 .322 r
.70301 .49982 .70368 .49922 .70534 .49979 .70491 .50472 Mtetra
.962 .675 .442 r
.70491 .50472 .70534 .49979 .70706 .50147 .7169 .69451 Mtetra
.577 .367 .559 r
.7169 .69451 .70706 .50147 .71876 .6835 .71885 .69834 Mtetra
.594 .359 .529 r
.71885 .69834 .71876 .6835 .72131 .69815 .72066 .69979 Mtetra
.594 .213 .29 r
.72066 .69979 .72131 .69815 .7232 .70097 .72243 .7004 Mtetra
.243 .642 .961 r
.72243 .7004 .7232 .70097 .72498 .7017 .72419 .70069 Mtetra
.601 .706 .918 r
.72419 .70069 .72498 .7017 .72671 .70145 .72591 .70044 Mtetra
.751 .756 .857 r
.72591 .70044 .72671 .70145 .72838 .7003 .72759 .69941 Mtetra
.929 .774 .668 r
.72759 .69941 .72838 .7003 .72987 .69604 .72909 .69517 Mtetra
.971 .689 .436 r
.72909 .69517 .72987 .69604 .72021 .50185 .71946 .50091 Mtetra
.955 .741 .575 r
.71946 .50091 .72021 .50185 .72139 .49398 .72065 .49308 Mtetra
.828 .781 .808 r
.72065 .49308 .72139 .49398 .72293 .49237 .72219 .49148 Mtetra
.64 .734 .917 r
.72219 .49148 .72293 .49237 .72456 .49197 .72382 .49108 Mtetra
.493 .673 .944 r
.72382 .49108 .72456 .49197 .7262 .49203 .72547 .49115 Mtetra
.595 .721 .932 r
.72547 .49115 .7262 .49203 .72784 .49178 .7271 .49091 Mtetra
.637 .741 .924 r
.7271 .49091 .72784 .49178 .72946 .49137 .72873 .49053 Mtetra
.646 .749 .924 r
.72873 .49053 .72946 .49137 .73108 .49093 .73035 .4901 Mtetra
.665 .761 .922 r
.73035 .4901 .73108 .49093 .7327 .4904 .73197 .4896 Mtetra
.681 .773 .92 r
.73197 .4896 .7327 .4904 .73432 .48981 .73359 .48903 Mtetra
.694 .782 .919 r
.73359 .48903 .73432 .48981 .73593 .48917 .7352 .4884 Mtetra
.745 .798 .895 r
.7352 .4884 .73593 .48917 .73752 .4882 .7368 .48753 Mtetra
.74 .824 .917 r
.7368 .48753 .73752 .4882 .73912 .48733 .7384 .4867 Mtetra
.672 .818 .953 r
.7384 .4867 .73912 .48733 .74075 .48692 .74002 .48614 Mtetra
.285 .591 .947 r
.74002 .48614 .74075 .48692 .74251 .48842 .74171 .48658 Mtetra
.249 .363 .784 r
.74171 .48658 .74251 .48842 .74456 .49438 .74346 .48797 Mtetra
.44 .33 .632 r
.74346 .48797 .74456 .49438 .75899 .68575 .74529 .49047 Mtetra
.57 .365 .564 r
.74529 .49047 .75899 .68575 .76089 .68781 .74706 .49199 Mtetra
.573 .368 .564 r
.74706 .49199 .76089 .68781 .76263 .68743 .74869 .49148 Mtetra
.574 .368 .564 r
.74869 .49148 .76263 .68743 .76432 .68633 .75027 .49017 Mtetra
.573 .368 .564 r
.75027 .49017 .76432 .68633 .76604 .68559 .75188 .48936 Mtetra
.573 .367 .564 r
.75188 .48936 .76604 .68559 .76778 .68512 .75352 .48885 Mtetra
.75352 .48885 .76778 .68512 .76951 .68465 .75515 .48836 Mtetra
.75515 .48836 .76951 .68465 .77125 .6842 .75679 .48789 Mtetra
.75679 .48789 .77125 .6842 .77299 .68376 .75844 .48744 Mtetra
.75844 .48744 .77299 .68376 .77473 .68333 .76008 .48699 Mtetra
.76008 .48699 .77473 .68333 .77648 .68289 .76172 .48656 Mtetra
.76172 .48656 .77648 .68289 .77822 .68246 .76337 .48612 Mtetra
.76337 .48612 .77822 .68246 .77997 .68202 .76502 .48568 Mtetra
.76502 .48568 .77997 .68202 .78171 .68158 .76666 .48523 Mtetra
.76666 .48523 .78171 .68158 .78346 .68113 .76831 .48478 Mtetra
.76831 .48478 .78346 .68113 .78521 .68068 .76996 .48431 Mtetra
.76996 .48431 .78521 .68068 .78696 .68023 .77161 .48384 Mtetra
.77161 .48384 .78696 .68023 .7887 .67977 .77326 .48336 Mtetra
.77326 .48336 .7887 .67977 .79045 .6793 .77491 .48288 Mtetra
.77491 .48288 .79045 .6793 .79221 .67884 .77656 .48238 Mtetra
.77656 .48238 .79221 .67884 .79396 .67837 .77821 .48187 Mtetra
.77821 .48187 .79396 .67837 .79571 .67789 .77986 .48135 Mtetra
.573 .368 .564 r
.77986 .48135 .79571 .67789 .79746 .67742 .78151 .48083 Mtetra
.78151 .48083 .79746 .67742 .79922 .67694 .78316 .48029 Mtetra
.78316 .48029 .79922 .67694 .80097 .67645 .78481 .47975 Mtetra
.78481 .47975 .80097 .67645 .80273 .67596 .78646 .47919 Mtetra
.78646 .47919 .80273 .67596 .80448 .67547 .78811 .47864 Mtetra
.78811 .47864 .80448 .67547 .80624 .67498 .78976 .47808 Mtetra
.78976 .47808 .80624 .67498 .808 .67449 .79141 .47752 Mtetra
.79141 .47752 .808 .67449 .80976 .674 .79307 .47697 Mtetra
.79307 .47697 .80976 .674 .81152 .67351 .79472 .47642 Mtetra
.79472 .47642 .81152 .67351 .81328 .67302 .79638 .47588 Mtetra
.79638 .47588 .81328 .67302 .81504 .67253 .79804 .47534 Mtetra
.79804 .47534 .81504 .67253 .81681 .67204 .7997 .4748 Mtetra
.7997 .4748 .81681 .67204 .81857 .67156 .80136 .47427 Mtetra
.573 .367 .564 r
.80136 .47427 .81857 .67156 .82034 .67108 .80302 .47374 Mtetra
.80302 .47374 .82034 .67108 .82211 .6706 .80469 .47322 Mtetra
.80469 .47322 .82211 .6706 .82388 .67012 .80635 .47271 Mtetra
.80635 .47271 .82388 .67012 .82565 .66964 .80802 .47219 Mtetra
.80802 .47219 .82565 .66964 .82742 .66916 .80968 .47168 Mtetra
.80968 .47168 .82742 .66916 .82919 .66869 .81135 .47118 Mtetra
.81135 .47118 .82919 .66869 .83097 .66822 .81302 .47068 Mtetra
.81302 .47068 .83097 .66822 .83274 .66775 .8147 .47018 Mtetra
.8147 .47018 .83274 .66775 .83452 .66728 .81637 .46969 Mtetra
.81637 .46969 .83452 .66728 .8363 .66681 .81804 .4692 Mtetra
.81804 .4692 .8363 .66681 .83808 .66635 .81972 .46872 Mtetra
.81972 .46872 .83808 .66635 .83986 .66589 .8214 .46824 Mtetra
.8214 .46824 .83986 .66589 .84164 .66543 .82307 .46777 Mtetra
.82307 .46777 .84164 .66543 .84343 .66497 .82475 .4673 Mtetra
.82475 .4673 .84343 .66497 .84521 .66451 .82644 .46683 Mtetra
.82644 .46683 .84521 .66451 .847 .66405 .82812 .46637 Mtetra
.82812 .46637 .847 .66405 .84878 .66359 .8298 .4659 Mtetra
.8298 .4659 .84878 .66359 .85057 .66313 .83149 .46544 Mtetra
.83149 .46544 .85057 .66313 .85236 .66267 .83317 .46497 Mtetra
.83317 .46497 .85236 .66267 .85415 .66221 .83486 .4645 Mtetra
.83486 .4645 .85415 .66221 .85594 .66174 .83655 .46402 Mtetra
.83655 .46402 .85594 .66174 .85773 .66127 .83823 .46354 Mtetra
.83823 .46354 .85773 .66127 .85952 .6608 .83992 .46305 Mtetra
.83992 .46305 .85952 .6608 .86132 .66033 .84161 .46255 Mtetra
.84161 .46255 .86132 .66033 .86311 .65985 .8433 .46205 Mtetra
.8433 .46205 .86311 .65985 .86491 .65937 .84499 .46155 Mtetra
.84499 .46155 .86491 .65937 .8667 .65889 .84668 .46103 Mtetra
.84668 .46103 .8667 .65889 .8685 .65841 .84837 .46051 Mtetra
.84837 .46051 .8685 .65841 .8703 .65792 .85006 .45998 Mtetra
.573 .368 .564 r
.85006 .45998 .8703 .65792 .87209 .65742 .85175 .45944 Mtetra
.85175 .45944 .87209 .65742 .87389 .65692 .85344 .45889 Mtetra
.85344 .45889 .87389 .65692 .87569 .65641 .85512 .45832 Mtetra
.85512 .45832 .87569 .65641 .87749 .65589 .85681 .45772 Mtetra
.85681 .45772 .87749 .65589 .87929 .65535 .85849 .45709 Mtetra
.85849 .45709 .87929 .65535 .88109 .6548 .86018 .45645 Mtetra
.574 .368 .564 r
.86018 .45645 .88109 .6548 .88287 .65411 .86183 .45546 Mtetra
.86183 .45546 .88287 .65411 .88464 .65321 .86344 .45408 Mtetra
.573 .367 .564 r
.86344 .45408 .88464 .65321 .88644 .65272 .86515 .45369 Mtetra
.567 .363 .564 r
.86515 .45369 .88644 .65272 .88836 .65331 .86727 .45714 Mtetra
.174 .085 .507 r
.86727 .45714 .88836 .65331 .89039 .65485 .88924 .64978 Mtetra
.235 .217 .634 r
.88924 .64978 .89039 .65485 .89236 .65591 .89156 .65419 Mtetra
.233 .382 .808 r
.89156 .65419 .89236 .65591 .89427 .65631 .89358 .65565 Mtetra
.545 .783 .986 r
.89358 .65565 .89427 .65631 .8961 .65592 .89543 .6554 Mtetra
.663 .872 .978 r
.89543 .6554 .8961 .65592 .8979 .65533 .89723 .65475 Mtetra
.698 .865 .962 r
.89723 .65475 .8979 .65533 .89971 .65468 .89902 .65399 Mtetra
.64 .814 .967 r
.89902 .65399 .89971 .65468 .90152 .65417 .90084 .65348 Mtetra
.90084 .65348 .90152 .65417 .90334 .65366 .90266 .65297 Mtetra
.638 .813 .967 r
.90266 .65297 .90334 .65366 .90516 .65316 .90448 .65246 Mtetra
.634 .811 .967 r
.90448 .65246 .90516 .65316 .90698 .65267 .9063 .65197 Mtetra
.632 .809 .968 r
.9063 .65197 .90698 .65267 .90881 .65218 .90813 .65148 Mtetra
.629 .808 .969 r
.90813 .65148 .90881 .65218 .91063 .65171 .90995 .65101 Mtetra
.625 .807 .97 r
.90995 .65101 .91063 .65171 .91246 .65124 .91178 .65055 Mtetra
.624 .808 .971 r
.91178 .65055 .91246 .65124 .91429 .65078 .91362 .65009 Mtetra
.6 .799 .976 r
.91362 .65009 .91429 .65078 .91613 .65036 .91546 .6497 Mtetra
.523 .774 .989 r
.91546 .6497 .91613 .65036 .91798 .65005 .91732 .64951 Mtetra
.608 .849 .99 r
.91732 .64951 .91798 .65005 .91981 .64958 .91915 .64902 Mtetra
.81 .896 .904 r
.91915 .64902 .91981 .64958 .9216 .64871 .9209 .64773 Mtetra
.935 .796 .682 r
.9209 .64773 .9216 .64871 .92329 .64692 .92236 .644 Mtetra
.926 .681 .548 r
.92236 .644 .92329 .64692 .92491 .64459 .92303 .63339 Mtetra
.971 .668 .383 r
.92303 .63339 .92491 .64459 .92651 .64211 .90285 .44279 Mtetra
.574 .368 .564 r
.90285 .44279 .92651 .64211 .9283 .64121 .90446 .44131 Mtetra
.572 .367 .564 r
.90446 .44131 .9283 .64121 .93015 .64091 .90622 .4411 Mtetra
.90622 .4411 .93015 .64091 .93202 .6407 .90802 .44118 Mtetra
.574 .368 .564 r
.90802 .44118 .93202 .6407 .93381 .63979 .90964 .43982 Mtetra
.573 .367 .564 r
.90964 .43982 .93381 .63979 .93564 .63925 .91137 .43929 Mtetra
.57 .365 .564 r
.91137 .43929 .93564 .63925 .93758 .6396 .91337 .44105 Mtetra
.195 .103 .516 r
.91337 .44105 .93758 .6396 .93968 .64127 .93833 .63478 Mtetra
.255 .213 .617 r
.93833 .63478 .93968 .64127 .94173 .64244 .94089 .64033 Mtetra
.223 .334 .767 r
.94089 .64033 .94173 .64244 .9437 .64299 .94303 .64224 Mtetra
.538 .755 .977 r
.94303 .64224 .9437 .64299 .94556 .64263 .94491 .64206 Mtetra
.669 .864 .973 r
.94491 .64206 .94556 .64263 .94739 .64201 .94674 .64139 Mtetra
.737 .869 .942 r
.94674 .64139 .94739 .64201 .94921 .64126 .94854 .64047 Mtetra
.702 .815 .935 r
.94854 .64047 .94921 .64126 .95104 .64055 .95036 .63972 Mtetra
.706 .804 .926 r
.95036 .63972 .95104 .64055 .95286 .63984 .95218 .63895 Mtetra
.696 .786 .92 r
.95218 .63895 .95286 .63984 .95469 .63919 .954 .63824 Mtetra
.653 .756 .925 r
.954 .63824 .95469 .63919 .95655 .63869 .95586 .63772 Mtetra
.637 .743 .925 r
.95586 .63772 .95655 .63869 .95841 .63826 .95772 .63727 Mtetra
.615 .729 .927 r
.95772 .63727 .95841 .63826 .96028 .63792 .95959 .63692 Mtetra
.484 .663 .941 r
.95959 .63692 .96028 .63792 .96222 .63803 .96153 .63704 Mtetra
.608 .727 .929 r
.96153 .63704 .96222 .63803 .9641 .6377 .96341 .63671 Mtetra
.784 .795 .861 r
.96341 .63671 .9641 .6377 .96586 .63644 .96517 .63545 Mtetra
.975 .774 .57 r
.96517 .63545 .96586 .63644 .96698 .63013 .96627 .62901 Mtetra
.975 .669 .323 r
.96627 .62901 .96698 .63013 .94326 .43079 .94259 .42967 Mtetra
.956 .769 .61 r
.94259 .42967 .94326 .43079 .94441 .42562 .94375 .42459 Mtetra
.752 .764 .862 r
.94375 .42459 .94441 .42562 .94609 .4246 .94543 .42357 Mtetra
.623 .712 .909 r
.94543 .42357 .94609 .4246 .94786 .42425 .9472 .42322 Mtetra
.541 .671 .922 r
.9472 .42322 .94786 .42425 .94967 .42423 .94901 .42319 Mtetra
.72 .751 .877 r
.94901 .42319 .94967 .42423 .95139 .42354 .95072 .42237 Mtetra
.674 .705 .871 r
.95072 .42237 .95139 .42354 .95313 .42296 .95246 .42178 Mtetra
.575 .657 .892 r
.95246 .42178 .95313 .42296 .9549 .42258 .95427 .42166 Mtetra
0 .172 .699 r
.95427 .42166 .9549 .42258 .95673 .42266 .95634 .42355 Mtetra
.897 .497 .248 r
.95634 .42355 .95673 .42266 .95865 .42335 .95901 .42987 Mtetra
.97 .653 .327 r
.95901 .42987 .95865 .42335 .96074 .42533 .98679 .6235 Mtetra
.578 .306 .468 r
.3818 .78989 .38294 .78497 .38432 .78795 .38328 .79023 Mtetra
.473 .139 .319 r
.38328 .79023 .38432 .78795 .38577 .78925 .3848 .78988 Mtetra
0 0 0 r
.3848 .78988 .38577 .78925 .38725 .78981 .38633 .78916 Mtetra
.437 .714 .982 r
.38633 .78916 .38725 .78981 .38873 .79026 .38783 .7892 Mtetra
.631 .689 .886 r
.38783 .7892 .38873 .79026 .39024 .79009 .38934 .78888 Mtetra
.739 .696 .81 r
.38934 .78888 .39024 .79009 .39178 .78913 .39089 .78787 Mtetra
.882 .707 .66 r
.39089 .78787 .39178 .78913 .39346 .78438 .39258 .78282 Mtetra
.936 .685 .533 r
.39258 .78282 .39346 .78438 .40179 .59488 .40094 .59362 Mtetra
.89 .703 .642 r
.40094 .59362 .40179 .59488 .40344 .58852 .40258 .58782 Mtetra
.787 .781 .847 r
.40258 .58782 .40344 .58852 .40491 .58738 .40404 .5867 Mtetra
.627 .765 .945 r
.40404 .5867 .40491 .58738 .40634 .58705 .40548 .58637 Mtetra
.457 .707 .975 r
.40548 .58637 .40634 .58705 .40777 .58707 .40691 .58641 Mtetra
.644 .776 .944 r
.40691 .58641 .40777 .58707 .40921 .58656 .40835 .58603 Mtetra
.652 .814 .961 r
.40835 .58603 .40921 .58656 .41066 .58598 .40979 .58559 Mtetra
.64 .853 .981 r
.40979 .58559 .41066 .58598 .41211 .58542 .41124 .58514 Mtetra
.639 .886 .986 r
.41124 .58514 .41211 .58542 .41356 .58476 .41269 .58463 Mtetra
.585 .91 .977 r
.41269 .58463 .41356 .58476 .41501 .58423 .41413 .58413 Mtetra
.556 .905 .972 r
.41413 .58413 .41501 .58423 .41645 .58397 .41558 .58366 Mtetra
.571 .86 .996 r
.41558 .58366 .41645 .58397 .41786 .58468 .41703 .5833 Mtetra
.634 .627 .826 r
.41703 .5833 .41786 .58468 .41925 .58614 .41847 .58297 Mtetra
.612 .496 .697 r
.41847 .58297 .41925 .58614 .42061 .58857 .41992 .58265 Mtetra
.621 .456 .638 r
.41992 .58265 .42061 .58857 .42206 .58829 .42138 .5818 Mtetra
.608 .442 .632 r
.42138 .5818 .42206 .58829 .42353 .58738 .42284 .58117 Mtetra
.579 .423 .634 r
.42284 .58117 .42353 .58738 .42497 .5874 .42428 .58116 Mtetra
.292 .214 .594 r
.42428 .58116 .42497 .5874 .42115 .76958 .42561 .58477 Mtetra
0 0 .347 r
.42561 .58477 .42115 .76958 .42244 .77763 .42164 .77325 Mtetra
0 0 .383 r
.42164 .77325 .42244 .77763 .42389 .78018 .42301 .7787 Mtetra
.382 .501 .855 r
.42301 .7787 .42389 .78018 .42541 .78044 .42452 .7793 Mtetra
.654 .684 .865 r
.42452 .7793 .42541 .78044 .42695 .78002 .42606 .77887 Mtetra
.719 .702 .833 r
.42606 .77887 .42695 .78002 .4285 .77932 .42761 .77804 Mtetra
.661 .663 .841 r
.42761 .77804 .4285 .77932 .43004 .77884 .42916 .77756 Mtetra
.644 .657 .848 r
.42916 .77756 .43004 .77884 .43158 .77841 .4307 .77717 Mtetra
.644 .664 .855 r
.4307 .77717 .43158 .77841 .43313 .77798 .43224 .77679 Mtetra
.64 .67 .863 r
.43224 .77679 .43313 .77798 .43467 .77774 .43378 .77643 Mtetra
.642 .652 .844 r
.43378 .77643 .43467 .77774 .43621 .77742 .43532 .77605 Mtetra
.649 .646 .833 r
.43532 .77605 .43621 .77742 .43776 .77686 .43687 .77562 Mtetra
.596 .646 .87 r
.43687 .77562 .43776 .77686 .43932 .77562 .43841 .77546 Mtetra
.499 .875 .977 r
.43841 .77546 .43932 .77562 .44091 .77358 .43996 .77507 Mtetra
.171 0 .045 r
.43996 .77507 .44091 .77358 .44253 .76994 .44152 .77405 Mtetra
0 0 .151 r
.44152 .77405 .44253 .76994 .44822 .58542 .44316 .76969 Mtetra
0 0 .345 r
.44316 .76969 .44822 .58542 .44987 .57666 .44893 .58021 Mtetra
.775 .758 .245 r
.44893 .58021 .44987 .57666 .45139 .57365 .45053 .57362 Mtetra
.88 .935 .851 r
.45053 .57362 .45139 .57365 .45287 .57251 .45202 .57205 Mtetra
.644 .837 .974 r
.45202 .57205 .45287 .57251 .45434 .57207 .45349 .5716 Mtetra
.434 .762 .996 r
.45349 .5716 .45434 .57207 .4558 .57193 .45495 .57155 Mtetra
.553 .836 .998 r
.45495 .57155 .4558 .57193 .45726 .57172 .45641 .57125 Mtetra
.633 .834 .978 r
.45641 .57125 .45726 .57172 .45873 .57147 .45788 .57083 Mtetra
.65 .787 .947 r
.45788 .57083 .45873 .57147 .46019 .57121 .45935 .57041 Mtetra
.654 .745 .917 r
.45935 .57041 .46019 .57121 .46166 .57086 .46082 .57 Mtetra
.656 .73 .904 r
.46082 .57 .46166 .57086 .46313 .57044 .4623 .56958 Mtetra
.66 .734 .904 r
.4623 .56958 .46313 .57044 .46461 .56995 .46377 .56915 Mtetra
.678 .752 .907 r
.46377 .56915 .46461 .56995 .46608 .56921 .46524 .56865 Mtetra
.68 .813 .947 r
.46524 .56865 .46608 .56921 .46756 .56849 .46672 .56812 Mtetra
.648 .865 .981 r
.46672 .56812 .46756 .56849 .46904 .568 .4682 .56762 Mtetra
.715 .872 .955 r
.4682 .56762 .46904 .568 .4705 .56817 .46968 .56694 Mtetra
.672 .665 .835 r
.46968 .56694 .4705 .56817 .47196 .56915 .47115 .56641 Mtetra
.576 .492 .722 r
.47115 .56641 .47196 .56915 .47339 .5716 .47262 .56645 Mtetra
.331 .26 .625 r
.47262 .56645 .47339 .5716 .47217 .75466 .47405 .56921 Mtetra
0 0 .373 r
.47405 .56921 .47217 .75466 .47359 .76379 .47279 .75761 Mtetra
0 0 .438 r
.47279 .75761 .47359 .76379 .47512 .76633 .47425 .76454 Mtetra
.257 .384 .801 r
.47425 .76454 .47512 .76633 .47667 .76684 .47579 .76566 Mtetra
.633 .671 .869 r
.47579 .76566 .47667 .76684 .47824 .76648 .47736 .76532 Mtetra
.712 .702 .839 r
.47736 .76532 .47824 .76648 .47981 .76581 .47894 .76454 Mtetra
.673 .672 .841 r
.47894 .76454 .47981 .76581 .48138 .76538 .48051 .76398 Mtetra
.638 .64 .837 r
.48051 .76398 .48138 .76538 .48295 .76504 .48208 .76362 Mtetra
.645 .64 .831 r
.48208 .76362 .48295 .76504 .48453 .76447 .48365 .76321 Mtetra
.611 .651 .865 r
.48365 .76321 .48453 .76447 .48611 .76332 .48522 .76298 Mtetra
.551 .855 .998 r
.48522 .76298 .48611 .76332 .4877 .76137 .4868 .76262 Mtetra
.14 0 0 r
.4868 .76262 .4877 .76137 .4893 .75798 .48838 .76169 Mtetra
0 0 .204 r
.48838 .76169 .4893 .75798 .49259 .57672 .48998 .75814 Mtetra
0 0 .362 r
.48998 .75814 .49259 .57672 .4942 .56366 .49331 .5692 Mtetra
0 0 0 r
.49331 .5692 .4942 .56366 .49571 .56035 .49488 .56059 Mtetra
.924 .96 .784 r
.49488 .56059 .49571 .56035 .49721 .55894 .49638 .55851 Mtetra
.681 .857 .966 r
.49638 .55851 .49721 .55894 .4987 .55841 .49788 .55794 Mtetra
.492 .787 .997 r
.49788 .55794 .4987 .55841 .50019 .55818 .49937 .5578 Mtetra
.532 .83 .999 r
.49937 .5578 .50019 .55818 .50168 .55788 .50086 .55753 Mtetra
.626 .869 .988 r
.50086 .55753 .50168 .55788 .50318 .55746 .50235 .55706 Mtetra
.634 .857 .984 r
.50235 .55706 .50318 .55746 .50467 .55704 .50385 .5566 Mtetra
.636 .844 .98 r
.50385 .5566 .50467 .55704 .50617 .55661 .50534 .55615 Mtetra
.633 .84 .98 r
.50534 .55615 .50617 .55661 .50766 .55616 .50684 .55571 Mtetra
.63 .843 .982 r
.50684 .55571 .50766 .55616 .50916 .5557 .50833 .55528 Mtetra
.637 .85 .981 r
.50833 .55528 .50916 .5557 .51065 .55515 .50983 .55482 Mtetra
.623 .874 .989 r
.50983 .55482 .51065 .55515 .51215 .55459 .51133 .55435 Mtetra
.582 .887 .991 r
.51133 .55435 .51215 .55459 .51365 .55423 .51283 .5539 Mtetra
.563 .858 .997 r
.51283 .5539 .51365 .55423 .51515 .55453 .51433 .55354 Mtetra
.621 .693 .895 r
.51433 .55354 .51515 .55453 .51665 .55575 .51583 .55326 Mtetra
.613 .526 .733 r
.51583 .55326 .51665 .55575 .51814 .55784 .51733 .55299 Mtetra
.602 .455 .655 r
.51733 .55299 .51814 .55784 .51964 .55973 .51884 .55263 Mtetra
.597 .431 .627 r
.51884 .55263 .51964 .55973 .52115 .55967 .52034 .55218 Mtetra
.597 .428 .623 r
.52034 .55218 .52115 .55967 .52266 .55871 .52184 .55169 Mtetra
.599 .432 .627 r
.52184 .55169 .52266 .55871 .52416 .55787 .52335 .55122 Mtetra
.599 .435 .631 r
.52335 .55122 .52416 .55787 .52567 .55741 .52486 .55076 Mtetra
.52486 .55076 .52567 .55741 .52718 .55693 .52636 .5503 Mtetra
.52636 .5503 .52718 .55693 .52869 .55646 .52787 .54984 Mtetra
.52787 .54984 .52869 .55646 .5302 .55599 .52938 .54938 Mtetra
.599 .436 .631 r
.52938 .54938 .5302 .55599 .53171 .55553 .53089 .54892 Mtetra
.53089 .54892 .53171 .55553 .53323 .55505 .5324 .54846 Mtetra
.6 .436 .631 r
.5324 .54846 .53323 .55505 .53474 .55457 .53391 .54799 Mtetra
.6 .436 .632 r
.53391 .54799 .53474 .55457 .53625 .55407 .53542 .54752 Mtetra
.6 .437 .632 r
.53542 .54752 .53625 .55407 .53777 .55355 .53694 .54704 Mtetra
.601 .438 .632 r
.53694 .54704 .53777 .55355 .53928 .553 .53845 .54654 Mtetra
.601 .438 .633 r
.53845 .54654 .53928 .553 .5408 .55246 .53996 .54606 Mtetra
.61 .445 .633 r
.53996 .54606 .5408 .55246 .54231 .55148 .54148 .54537 Mtetra
.616 .451 .636 r
.54148 .54537 .54231 .55148 .54383 .55033 .54299 .54459 Mtetra
.596 .441 .642 r
.54299 .54459 .54383 .55033 .54535 .55014 .54451 .54428 Mtetra
.494 .368 .637 r
.54451 .54428 .54535 .55014 .5469 .55475 .54604 .54565 Mtetra
0 0 .298 r
.54604 .54565 .5469 .55475 .54973 .74116 .54765 .55856 Mtetra
0 0 .409 r
.54765 .55856 .54973 .74116 .55137 .74512 .5505 .7428 Mtetra
.016 .169 .681 r
.5505 .7428 .55137 .74512 .55299 .74634 .55213 .74507 Mtetra
.584 .641 .873 r
.55213 .74507 .55299 .74634 .5546 .7461 .55375 .74495 Mtetra
.694 .703 .853 r
.55375 .74495 .5546 .7461 .55622 .74552 .55536 .74428 Mtetra
.697 .69 .839 r
.55536 .74428 .55622 .74552 .55783 .74496 .55697 .74356 Mtetra
.643 .646 .838 r
.55697 .74356 .55783 .74496 .55945 .74469 .55859 .74316 Mtetra
.642 .629 .821 r
.55859 .74316 .55945 .74469 .56107 .74441 .56021 .74275 Mtetra
.641 .613 .807 r
.56021 .74275 .56107 .74441 .56268 .74408 .56182 .74233 Mtetra
.639 .604 .798 r
.56182 .74233 .56268 .74408 .5643 .74368 .56344 .74192 Mtetra
.639 .602 .796 r
.56344 .74192 .5643 .74368 .56592 .74326 .56506 .7415 Mtetra
.64 .603 .796 r
.56506 .7415 .56592 .74326 .56754 .74283 .56668 .74108 Mtetra
.641 .604 .797 r
.56668 .74108 .56754 .74283 .56916 .7424 .5683 .74065 Mtetra
.642 .604 .796 r
.5683 .74065 .56916 .7424 .57079 .74197 .56993 .74022 Mtetra
.643 .605 .796 r
.56993 .74022 .57079 .74197 .57241 .74154 .57155 .73977 Mtetra
.644 .604 .794 r
.57155 .73977 .57241 .74154 .57403 .74111 .57317 .73932 Mtetra
.644 .601 .792 r
.57317 .73932 .57403 .74111 .57566 .74066 .5748 .73886 Mtetra
.642 .601 .792 r
.5748 .73886 .57566 .74066 .57728 .74015 .57643 .73842 Mtetra
.641 .606 .799 r
.57643 .73842 .57728 .74015 .57891 .73956 .57805 .73799 Mtetra
.643 .625 .818 r
.57805 .73799 .57891 .73956 .58053 .73896 .57968 .73757 Mtetra
.645 .65 .84 r
.57968 .73757 .58053 .73896 .58216 .73846 .58131 .73716 Mtetra
.645 .662 .852 r
.58131 .73716 .58216 .73846 .58379 .73815 .58294 .73675 Mtetra
.648 .648 .837 r
.58294 .73675 .58379 .73815 .58542 .7377 .58457 .73631 Mtetra
.658 .656 .836 r
.58457 .73631 .58542 .7377 .58705 .73674 .5862 .73582 Mtetra
.685 .746 .898 r
.5862 .73582 .58705 .73674 .58865 .7347 .58783 .73522 Mtetra
0 0 0 r
.58783 .73522 .58865 .7347 .59024 .73186 .58946 .73462 Mtetra
.47 .158 .353 r
.58946 .73462 .59024 .73186 .59182 .72866 .5911 .73407 Mtetra
.532 .269 .461 r
.5911 .73407 .59182 .72866 .59344 .72765 .59273 .73364 Mtetra
.538 .28 .472 r
.59273 .73364 .59344 .72765 .59508 .7276 .59437 .73325 Mtetra
.536 .275 .466 r
.59437 .73325 .59508 .7276 .59673 .72773 .59601 .73286 Mtetra
.53 .263 .456 r
.59601 .73286 .59673 .72773 .59836 .72733 .59765 .73244 Mtetra
.529 .263 .455 r
.59765 .73244 .59836 .72733 .6 .72693 .59929 .73201 Mtetra
.529 .262 .455 r
.59929 .73201 .6 .72693 .60164 .7265 .60093 .73158 Mtetra
.528 .261 .454 r
.60093 .73158 .60164 .7265 .60327 .72605 .60257 .73114 Mtetra
.60257 .73114 .60327 .72605 .60491 .72557 .60421 .73069 Mtetra
.528 .262 .455 r
.60421 .73069 .60491 .72557 .60655 .72507 .60585 .73024 Mtetra
.528 .263 .456 r
.60585 .73024 .60655 .72507 .60819 .72453 .6075 .72979 Mtetra
.529 .264 .458 r
.6075 .72979 .60819 .72453 .60983 .72399 .60914 .72933 Mtetra
.529 .265 .459 r
.60914 .72933 .60983 .72399 .61147 .72333 .61079 .72887 Mtetra
.53 .268 .463 r
.61079 .72887 .61147 .72333 .61309 .72222 .61244 .72838 Mtetra
.536 .279 .474 r
.61244 .72838 .61309 .72222 .61474 .72175 .61408 .72793 Mtetra
.54 .283 .475 r
.61408 .72793 .61474 .72175 .61642 .72274 .61573 .72755 Mtetra
.539 .267 .451 r
.61573 .72755 .61642 .72274 .61814 .72518 .61739 .72731 Mtetra
.49 .145 .309 r
.61739 .72731 .61814 .72518 .61984 .72678 .61905 .72708 Mtetra
.098 0 0 r
.61905 .72708 .61984 .72678 .62153 .72771 .62071 .72689 Mtetra
.488 .699 .963 r
.62071 .72689 .62153 .72771 .62321 .72807 .62237 .72691 Mtetra
.643 .687 .876 r
.62237 .72691 .62321 .72807 .62487 .72779 .62403 .72651 Mtetra
.773 .711 .794 r
.62403 .72651 .62487 .72779 .6265 .72645 .62566 .7251 Mtetra
.911 .722 .634 r
.62566 .7251 .6265 .72645 .62801 .72103 .62716 .7193 Mtetra
.961 .689 .473 r
.62716 .7193 .62801 .72103 .62394 .52702 .62315 .52579 Mtetra
.909 .725 .642 r
.62315 .52579 .62394 .52702 .62535 .52149 .62457 .5207 Mtetra
.756 .784 .876 r
.62457 .5207 .62535 .52149 .6269 .52053 .62612 .51976 Mtetra
.594 .746 .949 r
.62612 .51976 .6269 .52053 .62846 .52027 .62769 .51951 Mtetra
.479 .7 .966 r
.62769 .51951 .62846 .52027 .63004 .52031 .62927 .51955 Mtetra
.657 .767 .931 r
.62927 .51955 .63004 .52031 .63161 .51985 .63084 .51909 Mtetra
.665 .771 .928 r
.63084 .51909 .63161 .51985 .63317 .51935 .6324 .5186 Mtetra
.678 .778 .926 r
.6324 .5186 .63317 .51935 .63473 .51875 .63397 .51806 Mtetra
.706 .802 .924 r
.63397 .51806 .63473 .51875 .63629 .51782 .63553 .51741 Mtetra
.69 .876 .968 r
.63553 .51741 .63629 .51782 .63784 .51706 .63709 .51676 Mtetra
.661 .903 .98 r
.63709 .51676 .63784 .51706 .63942 .51665 .63865 .51614 Mtetra
.744 .857 .933 r
.63865 .51614 .63942 .51665 .64102 .51711 .64021 .51532 Mtetra
.639 .592 .785 r
.64021 .51532 .64102 .51711 .64265 .51848 .64179 .5149 Mtetra
.542 .443 .692 r
.64179 .5149 .64265 .51848 .64438 .52246 .64339 .51532 Mtetra
.198 .148 .573 r
.64339 .51532 .64438 .52246 .65284 .71207 .64519 .52107 Mtetra
.054 0 .445 r
.64519 .52107 .65284 .71207 .6547 .71685 .65379 .71338 Mtetra
0 .065 .59 r
.65379 .71338 .6547 .71685 .65646 .71864 .65562 .71729 Mtetra
.535 .608 .873 r
.65562 .71729 .65646 .71864 .65814 .71856 .65732 .71738 Mtetra
.676 .698 .862 r
.65732 .71738 .65814 .71856 .65981 .71802 .65899 .71679 Mtetra
.724 .707 .834 r
.65899 .71679 .65981 .71802 .66148 .71725 .66064 .71588 Mtetra
.646 .655 .845 r
.66064 .71588 .66148 .71725 .66315 .71678 .66232 .71544 Mtetra
.645 .661 .851 r
.66232 .71544 .66315 .71678 .66483 .71631 .664 .71502 Mtetra
.645 .668 .857 r
.664 .71502 .66483 .71631 .66651 .71585 .66568 .7146 Mtetra
.641 .672 .864 r
.66568 .7146 .66651 .71585 .66819 .71561 .66736 .7142 Mtetra
.644 .65 .842 r
.66736 .7142 .66819 .71561 .66988 .71522 .66904 .71377 Mtetra
.651 .648 .835 r
.66904 .71377 .66988 .71522 .67155 .71455 .67073 .71331 Mtetra
.587 .652 .881 r
.67073 .71331 .67155 .71455 .67319 .71307 .67242 .71316 Mtetra
.345 .823 .823 r
.67242 .71316 .67319 .71307 .67479 .71075 .6741 .71264 Mtetra
.257 0 .185 r
.6741 .71264 .67479 .71075 .67631 .70638 .67575 .7114 Mtetra
0 0 .267 r
.67575 .7114 .67631 .70638 .66972 .51543 .67721 .70557 Mtetra
.056 0 .441 r
.67721 .70557 .66972 .51543 .67106 .50907 .67043 .5114 Mtetra
.706 .719 .196 r
.67043 .5114 .67106 .50907 .67255 .50636 .67181 .50609 Mtetra
.808 .932 .914 r
.67181 .50609 .67255 .50636 .67412 .50561 .67337 .50494 Mtetra
.634 .79 .957 r
.67337 .50494 .67412 .50561 .67572 .50536 .67496 .50453 Mtetra
.524 .702 .951 r
.67496 .50453 .67572 .50536 .67733 .50534 .67657 .50449 Mtetra
.638 .74 .923 r
.67657 .50449 .67733 .50534 .67892 .50487 .67817 .5041 Mtetra
.635 .764 .941 r
.67817 .5041 .67892 .50487 .68051 .50432 .67977 .50371 Mtetra
.615 .803 .972 r
.67977 .50371 .68051 .50432 .6821 .50377 .68136 .50334 Mtetra
.584 .845 .994 r
.68136 .50334 .6821 .50377 .68369 .50331 .68296 .50295 Mtetra
.561 .86 .997 r
.68296 .50295 .68369 .50331 .68529 .5029 .68456 .50257 Mtetra
.551 .865 .996 r
.68456 .50257 .68529 .5029 .68689 .50253 .68616 .50218 Mtetra
.554 .861 .997 r
.68616 .50218 .68689 .50253 .6885 .50224 .68776 .5018 Mtetra
.592 .847 .993 r
.68776 .5018 .6885 .50224 .69011 .50197 .68937 .5014 Mtetra
.63 .818 .973 r
.68937 .5014 .69011 .50197 .69171 .50168 .69097 .50097 Mtetra
.667 .788 .939 r
.69097 .50097 .69171 .50168 .69332 .50125 .69257 .50045 Mtetra
.679 .772 .921 r
.69257 .50045 .69332 .50125 .69491 .50074 .69416 .4999 Mtetra
.684 .762 .91 r
.69416 .4999 .69491 .50074 .69651 .50018 .69576 .49932 Mtetra
.765 .778 .864 r
.69576 .49932 .69651 .50018 .69809 .49931 .69734 .4983 Mtetra
.714 .734 .867 r
.69734 .4983 .69809 .49931 .69968 .4986 .69892 .49755 Mtetra
.571 .669 .905 r
.69892 .49755 .69968 .4986 .7013 .49834 .70055 .49744 Mtetra
.81 .366 0 r
.70055 .49744 .7013 .49834 .70301 .49982 .70236 .50085 Mtetra
.967 .68 .433 r
.70236 .50085 .70301 .49982 .70491 .50472 .71441 .69415 Mtetra
.58 .369 .559 r
.71441 .69415 .70491 .50472 .7169 .69451 .71647 .70017 Mtetra
.592 .321 .475 r
.71647 .70017 .7169 .69451 .71885 .69834 .71825 .7009 Mtetra
.491 .168 .346 r
.71825 .7009 .71885 .69834 .72066 .69979 .71996 .70055 Mtetra
.056 0 0 r
.71996 .70055 .72066 .69979 .72243 .7004 .72166 .69979 Mtetra
.481 .761 .992 r
.72166 .69979 .72243 .7004 .72419 .70069 .72339 .69969 Mtetra
.601 .709 .919 r
.72339 .69969 .72419 .70069 .72591 .70044 .72512 .69944 Mtetra
.735 .754 .868 r
.72512 .69944 .72591 .70044 .72759 .69941 .72681 .69852 Mtetra
.929 .775 .669 r
.72681 .69852 .72759 .69941 .72909 .69517 .72831 .6943 Mtetra
.971 .689 .436 r
.72831 .6943 .72909 .69517 .71946 .50091 .71871 .49998 Mtetra
.955 .741 .575 r
.71871 .49998 .71946 .50091 .72065 .49308 .7199 .49218 Mtetra
.828 .781 .808 r
.7199 .49218 .72065 .49308 .72219 .49148 .72145 .49058 Mtetra
.639 .734 .917 r
.72145 .49058 .72219 .49148 .72382 .49108 .72308 .49019 Mtetra
.492 .671 .943 r
.72308 .49019 .72382 .49108 .72547 .49115 .72473 .49026 Mtetra
.593 .718 .931 r
.72473 .49026 .72547 .49115 .7271 .49091 .72636 .49003 Mtetra
.634 .737 .922 r
.72636 .49003 .7271 .49091 .72873 .49053 .72799 .48966 Mtetra
.643 .743 .922 r
.72799 .48966 .72873 .49053 .73035 .4901 .72961 .48924 Mtetra
.663 .754 .918 r
.72961 .48924 .73035 .4901 .73197 .4896 .73124 .48875 Mtetra
.677 .761 .915 r
.73124 .48875 .73197 .4896 .73359 .48903 .73285 .4882 Mtetra
.686 .769 .914 r
.73285 .4882 .73359 .48903 .7352 .4884 .73447 .48761 Mtetra
.697 .781 .916 r
.73447 .48761 .7352 .4884 .7368 .48753 .73609 .48697 Mtetra
.692 .844 .956 r
.73609 .48697 .7368 .48753 .7384 .4867 .7377 .48633 Mtetra
.654 .891 .982 r
.7377 .48633 .7384 .4867 .74002 .48614 .73932 .48572 Mtetra
.602 .861 .992 r
.73932 .48572 .74002 .48614 .74171 .48658 .74095 .48527 Mtetra
.637 .654 .851 r
.74095 .48527 .74171 .48658 .74346 .48797 .74259 .4849 Mtetra
.614 .507 .708 r
.74259 .4849 .74346 .48797 .74529 .49047 .74422 .48454 Mtetra
.602 .445 .641 r
.74422 .48454 .74529 .49047 .74706 .49199 .74586 .48406 Mtetra
.598 .427 .622 r
.74586 .48406 .74706 .49199 .74869 .49148 .74748 .48351 Mtetra
.598 .427 .621 r
.74748 .48351 .74869 .49148 .75027 .49017 .74911 .48294 Mtetra
.599 .432 .627 r
.74911 .48294 .75027 .49017 .75188 .48936 .75074 .48241 Mtetra
.599 .434 .63 r
.75074 .48241 .75188 .48936 .75352 .48885 .75237 .48191 Mtetra
.75237 .48191 .75352 .48885 .75515 .48836 .75401 .48142 Mtetra
.598 .434 .63 r
.75401 .48142 .75515 .48836 .75679 .48789 .75564 .48093 Mtetra
.598 .433 .63 r
.75564 .48093 .75679 .48789 .75844 .48744 .75728 .48045 Mtetra
.75728 .48045 .75844 .48744 .76008 .48699 .75892 .47997 Mtetra
.598 .433 .629 r
.75892 .47997 .76008 .48699 .76172 .48656 .76056 .4795 Mtetra
.598 .432 .629 r
.76056 .4795 .76172 .48656 .76337 .48612 .7622 .47902 Mtetra
.597 .432 .629 r
.7622 .47902 .76337 .48612 .76502 .48568 .76384 .47855 Mtetra
.597 .432 .628 r
.76384 .47855 .76502 .48568 .76666 .48523 .76548 .47807 Mtetra
.76548 .47807 .76666 .48523 .76831 .48478 .76713 .47758 Mtetra
.597 .431 .628 r
.76713 .47758 .76831 .48478 .76996 .48431 .76877 .4771 Mtetra
.76877 .4771 .76996 .48431 .77161 .48384 .77041 .47661 Mtetra
.598 .431 .627 r
.77041 .47661 .77161 .48384 .77326 .48336 .77206 .47612 Mtetra
.77206 .47612 .77326 .48336 .77491 .48288 .77371 .47562 Mtetra
.77371 .47562 .77491 .48288 .77656 .48238 .77535 .47512 Mtetra
.77535 .47512 .77656 .48238 .77821 .48187 .777 .47462 Mtetra
.598 .432 .627 r
.777 .47462 .77821 .48187 .77986 .48135 .77865 .47411 Mtetra
.77865 .47411 .77986 .48135 .78151 .48083 .7803 .4736 Mtetra
.7803 .4736 .78151 .48083 .78316 .48029 .78195 .47308 Mtetra
.599 .432 .628 r
.78195 .47308 .78316 .48029 .78481 .47975 .7836 .47256 Mtetra
.599 .433 .628 r
.7836 .47256 .78481 .47975 .78646 .47919 .78525 .47204 Mtetra
.78525 .47204 .78646 .47919 .78811 .47864 .7869 .47152 Mtetra
.7869 .47152 .78811 .47864 .78976 .47808 .78855 .47099 Mtetra
.599 .433 .629 r
.78855 .47099 .78976 .47808 .79141 .47752 .7902 .47046 Mtetra
.599 .434 .629 r
.7902 .47046 .79141 .47752 .79307 .47697 .79186 .46994 Mtetra
.79186 .46994 .79307 .47697 .79472 .47642 .79351 .46942 Mtetra
.599 .434 .63 r
.79351 .46942 .79472 .47642 .79638 .47588 .79517 .4689 Mtetra
.79517 .4689 .79638 .47588 .79804 .47534 .79683 .46838 Mtetra
.599 .435 .63 r
.79683 .46838 .79804 .47534 .7997 .4748 .79849 .46786 Mtetra
.79849 .46786 .7997 .4748 .80136 .47427 .80015 .46735 Mtetra
.80015 .46735 .80136 .47427 .80302 .47374 .80181 .46684 Mtetra
.599 .435 .631 r
.80181 .46684 .80302 .47374 .80469 .47322 .80347 .46632 Mtetra
.80347 .46632 .80469 .47322 .80635 .47271 .80513 .46581 Mtetra
.80513 .46581 .80635 .47271 .80802 .47219 .8068 .46531 Mtetra
.8068 .46531 .80802 .47219 .80968 .47168 .80846 .4648 Mtetra
.80846 .4648 .80968 .47168 .81135 .47118 .81013 .46429 Mtetra
.81013 .46429 .81135 .47118 .81302 .47068 .8118 .46379 Mtetra
.8118 .46379 .81302 .47068 .8147 .47018 .81347 .46329 Mtetra
.81347 .46329 .8147 .47018 .81637 .46969 .81514 .46279 Mtetra
.81514 .46279 .81637 .46969 .81804 .4692 .81681 .46229 Mtetra
.81681 .46229 .81804 .4692 .81972 .46872 .81848 .46179 Mtetra
.598 .434 .63 r
.81848 .46179 .81972 .46872 .8214 .46824 .82015 .46129 Mtetra
.82015 .46129 .8214 .46824 .82307 .46777 .82183 .4608 Mtetra
.82183 .4608 .82307 .46777 .82475 .4673 .8235 .46031 Mtetra
.8235 .46031 .82475 .4673 .82644 .46683 .82518 .45981 Mtetra
.598 .433 .63 r
.82518 .45981 .82644 .46683 .82812 .46637 .82686 .45932 Mtetra
.82686 .45932 .82812 .46637 .8298 .4659 .82854 .45883 Mtetra
.598 .433 .629 r
.82854 .45883 .8298 .4659 .83149 .46544 .83022 .45834 Mtetra
.83022 .45834 .83149 .46544 .83317 .46497 .8319 .45785 Mtetra
.8319 .45785 .83317 .46497 .83486 .4645 .83358 .45736 Mtetra
.598 .432 .629 r
.83358 .45736 .83486 .4645 .83655 .46402 .83526 .45686 Mtetra
.598 .432 .628 r
.83526 .45686 .83655 .46402 .83823 .46354 .83694 .45636 Mtetra
.83694 .45636 .83823 .46354 .83992 .46305 .83863 .45586 Mtetra
.83863 .45586 .83992 .46305 .84161 .46255 .84031 .45535 Mtetra
.84031 .45535 .84161 .46255 .8433 .46205 .842 .45485 Mtetra
.842 .45485 .8433 .46205 .84499 .46155 .84368 .45434 Mtetra
.84368 .45434 .84499 .46155 .84668 .46103 .84537 .45383 Mtetra
.84537 .45383 .84668 .46103 .84837 .46051 .84706 .45331 Mtetra
.84706 .45331 .84837 .46051 .85006 .45998 .84875 .45279 Mtetra
.598 .433 .628 r
.84875 .45279 .85006 .45998 .85175 .45944 .85044 .45227 Mtetra
.599 .433 .628 r
.85044 .45227 .85175 .45944 .85344 .45889 .85213 .45175 Mtetra
.599 .433 .629 r
.85213 .45175 .85344 .45889 .85512 .45832 .85382 .45122 Mtetra
.6 .434 .629 r
.85382 .45122 .85512 .45832 .85681 .45772 .85551 .45067 Mtetra
.6 .435 .63 r
.85551 .45067 .85681 .45772 .85849 .45709 .8572 .45012 Mtetra
.6 .436 .63 r
.8572 .45012 .85849 .45709 .86018 .45645 .85889 .44956 Mtetra
.607 .44 .631 r
.85889 .44956 .86018 .45645 .86183 .45546 .86056 .44885 Mtetra
.615 .448 .633 r
.86056 .44885 .86183 .45546 .86344 .45408 .86222 .44795 Mtetra
.599 .442 .64 r
.86222 .44795 .86344 .45408 .86515 .45369 .86392 .44752 Mtetra
.529 .395 .642 r
.86392 .44752 .86515 .45369 .86727 .45714 .86578 .44854 Mtetra
.119 .097 .555 r
.86578 .44854 .86727 .45714 .88924 .64978 .86852 .45788 Mtetra
.161 .076 .503 r
.86852 .45788 .88924 .64978 .89156 .65419 .89067 .65153 Mtetra
.144 .239 .704 r
.89067 .65153 .89156 .65419 .89358 .65565 .89282 .65428 Mtetra
.578 .637 .873 r
.89282 .65428 .89358 .65565 .89543 .6554 .89468 .65418 Mtetra
.692 .711 .863 r
.89468 .65418 .89543 .6554 .89723 .65475 .89648 .65346 Mtetra
.712 .709 .846 r
.89648 .65346 .89723 .65475 .89902 .65399 .89825 .65259 Mtetra
.654 .667 .85 r
.89825 .65259 .89902 .65399 .90084 .65348 .90007 .65207 Mtetra
.655 .667 .849 r
.90007 .65207 .90084 .65348 .90266 .65297 .90189 .65155 Mtetra
.653 .665 .849 r
.90189 .65155 .90266 .65297 .90448 .65246 .90371 .65104 Mtetra
.65 .663 .849 r
.90371 .65104 .90448 .65246 .9063 .65197 .90554 .65055 Mtetra
.649 .662 .85 r
.90554 .65055 .9063 .65197 .90813 .65148 .90736 .65006 Mtetra
.647 .661 .85 r
.90736 .65006 .90813 .65148 .90995 .65101 .90919 .64959 Mtetra
.644 .66 .851 r
.90919 .64959 .90995 .65101 .91178 .65055 .91102 .64913 Mtetra
.644 .661 .852 r
.91102 .64913 .91178 .65055 .91362 .65009 .91285 .64867 Mtetra
.625 .653 .857 r
.91285 .64867 .91362 .65009 .91546 .6497 .9147 .64832 Mtetra
.569 .631 .873 r
.9147 .64832 .91546 .6497 .91732 .64951 .91658 .64826 Mtetra
.655 .693 .874 r
.91658 .64826 .91732 .64951 .91915 .64902 .91841 .64775 Mtetra
.809 .748 .795 r
.91841 .64775 .91915 .64902 .9209 .64773 .9201 .64603 Mtetra
.942 .725 .581 r
.9201 .64603 .9209 .64773 .92236 .644 .92118 .63888 Mtetra
.975 .673 .363 r
.92118 .63888 .92236 .644 .92303 .63339 .90028 .4408 Mtetra
.579 .372 .564 r
.90028 .4408 .92303 .63339 .90285 .44279 .90155 .43638 Mtetra
.62 .453 .635 r
.90155 .43638 .90285 .44279 .90446 .44131 .90322 .43538 Mtetra
.597 .442 .643 r
.90322 .43538 .90446 .44131 .90622 .4411 .90495 .435 Mtetra
.59 .436 .641 r
.90495 .435 .90622 .4411 .90802 .44118 .90671 .43477 Mtetra
.617 .451 .635 r
.90671 .43477 .90802 .44118 .90964 .43982 .90839 .43385 Mtetra
.603 .446 .642 r
.90839 .43385 .90964 .43982 .91137 .43929 .91011 .43333 Mtetra
.554 .414 .645 r
.91011 .43333 .91137 .43929 .91337 .44105 .91196 .43385 Mtetra
.267 .21 .606 r
.91196 .43385 .91337 .44105 .93833 .63478 .91446 .43981 Mtetra
.178 .091 .512 r
.91446 .43981 .93833 .63478 .94089 .64033 .93992 .63703 Mtetra
.117 .189 .663 r
.93992 .63703 .94089 .64033 .94303 .64224 .94227 .64076 Mtetra
.566 .615 .86 r
.94227 .64076 .94303 .64224 .94491 .64206 .94417 .64073 Mtetra
.69 .697 .851 r
.94417 .64073 .94491 .64206 .94674 .64139 .946 .63999 Mtetra
.728 .704 .827 r
.946 .63999 .94674 .64139 .94854 .64047 .94778 .63896 Mtetra
.659 .657 .837 r
.94778 .63896 .94854 .64047 .95036 .63972 .94962 .6384 Mtetra
.661 .686 .862 r
.94962 .6384 .95036 .63972 .95218 .63895 .95147 .63784 Mtetra
.659 .723 .896 r
.95147 .63784 .95218 .63895 .954 .63824 .95332 .6373 Mtetra
.648 .758 .929 r
.95332 .6373 .954 .63824 .95586 .63772 .95517 .6368 Mtetra
.641 .76 .935 r
.95517 .6368 .95586 .63772 .95772 .63727 .95703 .63633 Mtetra
.622 .745 .935 r
.95703 .63633 .95772 .63727 .95959 .63692 .9589 .63594 Mtetra
.48 .665 .944 r
.9589 .63594 .95959 .63692 .96153 .63704 .96084 .63606 Mtetra
.607 .73 .932 r
.96084 .63606 .96153 .63704 .96341 .63671 .96272 .63574 Mtetra
.785 .797 .862 r
.96272 .63574 .96341 .63671 .96517 .63545 .96448 .63446 Mtetra
.976 .774 .567 r
.96448 .63446 .96517 .63545 .96627 .62901 .96557 .62792 Mtetra
.975 .669 .323 r
.96557 .62792 .96627 .62901 .94259 .42967 .94193 .42858 Mtetra
.957 .772 .612 r
.94193 .42858 .94259 .42967 .94375 .42459 .9431 .42357 Mtetra
.753 .767 .864 r
.9431 .42357 .94375 .42459 .94543 .42357 .94478 .42255 Mtetra
.624 .715 .911 r
.94478 .42255 .94543 .42357 .9472 .42322 .94655 .4222 Mtetra
.542 .674 .924 r
.94655 .4222 .9472 .42322 .94901 .42319 .94836 .42216 Mtetra
.74 .76 .869 r
.94836 .42216 .94901 .42319 .95072 .42237 .95005 .42121 Mtetra
.676 .71 .874 r
.95005 .42121 .95072 .42237 .95246 .42178 .95179 .42062 Mtetra
.515 .63 .902 r
.95179 .42062 .95246 .42178 .95427 .42166 .95363 .42073 Mtetra
.729 .305 0 r
.95363 .42073 .95427 .42166 .95634 .42355 .95605 .42524 Mtetra
.971 .655 .305 r
.95605 .42524 .95634 .42355 .95901 .42987 .98432 .6236 Mtetra
.578 .367 .558 r
.98432 .6236 .95901 .42987 .98679 .6235 .98693 .62859 Mtetra
.283 0 0 r
.38084 .79005 .3818 .78989 .38328 .79023 .38234 .79021 Mtetra
.593 .931 .955 r
.38234 .79021 .38328 .79023 .3848 .78988 .38386 .78959 Mtetra
.816 .888 .896 r
.38386 .78959 .3848 .78988 .38633 .78916 .38541 .7884 Mtetra
.775 .778 .855 r
.38541 .7884 .38633 .78916 .38783 .7892 .38696 .78732 Mtetra
.749 .635 .734 r
.38696 .78732 .38783 .7892 .38934 .78888 .38852 .78571 Mtetra
.75 .585 .672 r
.38852 .78571 .38934 .78888 .39089 .78787 .39013 .78298 Mtetra
.931 .68 .537 r
.39013 .78298 .39089 .78787 .39258 .78282 .39815 .60663 Mtetra
.602 .391 .568 r
.39815 .60663 .39258 .78282 .40094 .59362 .40018 .59023 Mtetra
.76 .583 .658 r
.40018 .59023 .40094 .59362 .40258 .58782 .40172 .58699 Mtetra
.749 .754 .856 r
.40172 .58699 .40258 .58782 .40404 .5867 .40318 .58611 Mtetra
.615 .786 .964 r
.40318 .58611 .40404 .5867 .40548 .58637 .40462 .58579 Mtetra
.48 .744 .987 r
.40462 .58579 .40548 .58637 .40691 .58641 .40605 .58574 Mtetra
.641 .771 .942 r
.40605 .58574 .40691 .58641 .40835 .58603 .40749 .58537 Mtetra
.655 .778 .939 r
.40749 .58537 .40835 .58603 .40979 .58559 .40893 .58495 Mtetra
.661 .784 .939 r
.40893 .58495 .40979 .58559 .41124 .58514 .41038 .5845 Mtetra
.667 .787 .938 r
.41038 .5845 .41124 .58514 .41269 .58463 .41182 .58404 Mtetra
.675 .8 .941 r
.41182 .58404 .41269 .58463 .41413 .58413 .41327 .58354 Mtetra
.687 .803 .937 r
.41327 .58354 .41413 .58413 .41558 .58366 .41472 .583 Mtetra
.711 .789 .913 r
.41472 .583 .41558 .58366 .41703 .5833 .41618 .58236 Mtetra
.706 .725 .865 r
.41618 .58236 .41703 .5833 .41847 .58297 .41763 .58171 Mtetra
.688 .665 .822 r
.41763 .58171 .41847 .58297 .41992 .58265 .41909 .58109 Mtetra
.699 .633 .78 r
.41909 .58109 .41992 .58265 .42138 .5818 .42055 .58028 Mtetra
.673 .627 .795 r
.42055 .58028 .42138 .5818 .42284 .58117 .42201 .57969 Mtetra
.597 .598 .824 r
.42201 .57969 .42284 .58117 .42428 .58116 .42345 .57956 Mtetra
0 .051 .618 r
.42345 .57956 .42428 .58116 .42561 .58477 .42483 .58144 Mtetra
.848 .559 .022 r
.42483 .58144 .42561 .58477 .42164 .77325 .42608 .58813 Mtetra
0 0 .356 r
.42608 .58813 .42164 .77325 .42301 .7787 .42224 .77314 Mtetra
.507 .382 .644 r
.42224 .77314 .42301 .7787 .42452 .7793 .42374 .77423 Mtetra
.614 .464 .654 r
.42374 .77423 .42452 .7793 .42606 .77887 .42528 .77364 Mtetra
.625 .469 .651 r
.42528 .77364 .42606 .77887 .42761 .77804 .42683 .77282 Mtetra
.486 .372 .649 r
.42683 .77282 .42761 .77804 .42916 .77756 .42833 .7741 Mtetra
.421 .369 .694 r
.42833 .7741 .42916 .77756 .4307 .77717 .42982 .7754 Mtetra
.359 .446 .814 r
.42982 .7754 .4307 .77717 .43224 .77679 .43133 .77622 Mtetra
.458 .75 .992 r
.43133 .77622 .43224 .77679 .43378 .77643 .43287 .77617 Mtetra
.546 .873 .993 r
.43287 .77617 .43378 .77643 .43532 .77605 .43441 .77578 Mtetra
.625 .893 .987 r
.43441 .77578 .43532 .77605 .43687 .77562 .43596 .77525 Mtetra
.44 .799 .996 r
.43596 .77525 .43687 .77562 .43841 .77546 .4375 .7751 Mtetra
.501 .83 .999 r
.4375 .7751 .43841 .77546 .43996 .77507 .43905 .77485 Mtetra
.686 .917 .972 r
.43905 .77485 .43996 .77507 .44152 .77405 .4406 .77415 Mtetra
.941 .894 .754 r
.4406 .77415 .44152 .77405 .44316 .76969 .44221 .77148 Mtetra
.996 .863 .542 r
.44221 .77148 .44316 .76969 .44893 .58021 .4439 .76471 Mtetra
0 0 .352 r
.4439 .76471 .44893 .58021 .45053 .57362 .44958 .57769 Mtetra
.271 .023 .342 r
.44958 .57769 .45053 .57362 .45202 .57205 .45109 .57528 Mtetra
.514 .219 .404 r
.45109 .57528 .45202 .57205 .45349 .5716 .45256 .57497 Mtetra
.547 .254 .422 r
.45256 .57497 .45349 .5716 .45495 .57155 .45402 .57497 Mtetra
.297 .028 .326 r
.45402 .57497 .45495 .57155 .45641 .57125 .45552 .5731 Mtetra
0 0 0 r
.45552 .5731 .45641 .57125 .45788 .57083 .45702 .57103 Mtetra
.872 .982 .839 r
.45702 .57103 .45788 .57083 .45935 .57041 .45852 .56944 Mtetra
.718 .725 .855 r
.45852 .56944 .45935 .57041 .46082 .57 .45999 .56871 Mtetra
.633 .642 .841 r
.45999 .56871 .46082 .57 .4623 .56958 .46146 .56839 Mtetra
.603 .645 .865 r
.46146 .56839 .4623 .56958 .46377 .56915 .46293 .56821 Mtetra
.639 .707 .896 r
.46293 .56821 .46377 .56915 .46524 .56865 .46441 .56786 Mtetra
.668 .753 .914 r
.46441 .56786 .46524 .56865 .46672 .56812 .46588 .56739 Mtetra
.679 .771 .92 r
.46588 .56739 .46672 .56812 .4682 .56762 .46736 .56688 Mtetra
.745 .778 .88 r
.46736 .56688 .4682 .56762 .46968 .56694 .46884 .56605 Mtetra
.727 .744 .865 r
.46884 .56605 .46968 .56694 .47115 .56641 .47032 .56528 Mtetra
.642 .672 .863 r
.47032 .56528 .47115 .56641 .47262 .56645 .4718 .56493 Mtetra
.047 .276 .77 r
.4718 .56493 .47262 .56645 .47405 .56921 .47325 .56628 Mtetra
.684 .406 0 r
.47325 .56628 .47405 .56921 .47279 .75761 .47465 .57139 Mtetra
0 0 .378 r
.47465 .57139 .47279 .75761 .47425 .76454 .47344 .7584 Mtetra
.43 .321 .629 r
.47344 .7584 .47425 .76454 .47579 .76566 .47497 .76063 Mtetra
.608 .461 .656 r
.47497 .76063 .47579 .76566 .47736 .76532 .47654 .76016 Mtetra
.626 .471 .653 r
.47654 .76016 .47736 .76532 .47894 .76454 .47811 .75932 Mtetra
.523 .399 .653 r
.47811 .75932 .47894 .76454 .48051 .76398 .47966 .76016 Mtetra
.436 .369 .683 r
.47966 .76016 .48051 .76398 .48208 .76362 .48121 .76152 Mtetra
.393 .432 .782 r
.48121 .76152 .48208 .76362 .48365 .76321 .48277 .7624 Mtetra
.325 .619 .956 r
.48277 .7624 .48365 .76321 .48522 .76298 .48434 .76273 Mtetra
.393 .81 .975 r
.48434 .76273 .48522 .76298 .4868 .76262 .48591 .76254 Mtetra
.655 .944 .96 r
.48591 .76254 .4868 .76262 .48838 .76169 .48749 .7618 Mtetra
.931 .928 .782 r
.48749 .7618 .48838 .76169 .48998 .75814 .48908 .75949 Mtetra
.994 .875 .562 r
.48908 .75949 .48998 .75814 .49331 .5692 .49071 .75371 Mtetra
0 0 .371 r
.49071 .75371 .49331 .5692 .49488 .56059 .494 .56526 Mtetra
.154 0 .319 r
.494 .56526 .49488 .56059 .49638 .55851 .49552 .56164 Mtetra
.49 .194 .39 r
.49552 .56164 .49638 .55851 .49788 .55794 .49702 .56115 Mtetra
.536 .239 .41 r
.49702 .56115 .49788 .55794 .49937 .5578 .49851 .56105 Mtetra
.358 .079 .346 r
.49851 .56105 .49937 .5578 .50086 .55753 .50001 .55958 Mtetra
0 0 .054 r
.50001 .55958 .50086 .55753 .50235 .55706 .50152 .55749 Mtetra
.829 .998 .775 r
.50152 .55749 .50235 .55706 .50385 .5566 .50302 .55583 Mtetra
.764 .776 .863 r
.50302 .55583 .50385 .5566 .50534 .55615 .50452 .55485 Mtetra
.665 .656 .831 r
.50452 .55485 .50534 .55615 .50684 .55571 .50602 .55436 Mtetra
.637 .636 .833 r
.50602 .55436 .50684 .55571 .50833 .55528 .50751 .55401 Mtetra
.644 .652 .844 r
.50751 .55401 .50833 .55528 .50983 .55482 .50901 .55364 Mtetra
.658 .671 .851 r
.50901 .55364 .50983 .55482 .51133 .55435 .51051 .55319 Mtetra
.659 .676 .855 r
.51051 .55319 .51133 .55435 .51283 .5539 .51201 .55274 Mtetra
.661 .677 .854 r
.51201 .55274 .51283 .5539 .51433 .55354 .51351 .55229 Mtetra
.66 .661 .84 r
.51351 .55229 .51433 .55354 .51583 .55326 .51501 .55182 Mtetra
.656 .633 .815 r
.51501 .55182 .51583 .55326 .51733 .55299 .51652 .55135 Mtetra
.651 .609 .794 r
.51652 .55135 .51733 .55299 .51884 .55263 .51802 .55089 Mtetra
.647 .597 .784 r
.51802 .55089 .51884 .55263 .52034 .55218 .51952 .55043 Mtetra
.51952 .55043 .52034 .55218 .52184 .55169 .52103 .54998 Mtetra
.648 .599 .786 r
.52103 .54998 .52184 .55169 .52335 .55122 .52253 .54952 Mtetra
.648 .602 .789 r
.52253 .54952 .52335 .55122 .52486 .55076 .52404 .54907 Mtetra
.52404 .54907 .52486 .55076 .52636 .5503 .52555 .54861 Mtetra
.648 .603 .789 r
.52555 .54861 .52636 .5503 .52787 .54984 .52705 .54815 Mtetra
.649 .603 .79 r
.52705 .54815 .52787 .54984 .52938 .54938 .52856 .5477 Mtetra
.52856 .5477 .52938 .54938 .53089 .54892 .53007 .54724 Mtetra
.649 .604 .79 r
.53007 .54724 .53089 .54892 .5324 .54846 .53158 .54677 Mtetra
.65 .604 .79 r
.53158 .54677 .5324 .54846 .53391 .54799 .5331 .54631 Mtetra
.5331 .54631 .53391 .54799 .53542 .54752 .53461 .54584 Mtetra
.651 .605 .79 r
.53461 .54584 .53542 .54752 .53694 .54704 .53612 .54536 Mtetra
.653 .606 .79 r
.53612 .54536 .53694 .54704 .53845 .54654 .53763 .54487 Mtetra
.652 .607 .791 r
.53763 .54487 .53845 .54654 .53996 .54606 .53915 .54439 Mtetra
.671 .616 .785 r
.53915 .54439 .53996 .54606 .54148 .54537 .54066 .54377 Mtetra
.682 .628 .788 r
.54066 .54377 .54148 .54537 .54299 .54459 .54218 .54308 Mtetra
.638 .618 .814 r
.54218 .54308 .54299 .54459 .54451 .54428 .5437 .54271 Mtetra
.37 .471 .832 r
.5437 .54271 .54451 .54428 .54604 .54565 .54522 .54343 Mtetra
0 0 .43 r
.54522 .54343 .54604 .54565 .54765 .55856 .54677 .54684 Mtetra
.971 .702 .462 r
.54677 .54684 .54765 .55856 .5505 .7428 .54959 .73398 Mtetra
.255 .175 .569 r
.54959 .73398 .5505 .7428 .55213 .74507 .55125 .73992 Mtetra
.575 .437 .656 r
.55125 .73992 .55213 .74507 .55375 .74495 .55286 .74 Mtetra
.629 .477 .657 r
.55286 .74 .55375 .74495 .55536 .74428 .55447 .73913 Mtetra
.632 .476 .653 r
.55447 .73913 .55536 .74428 .55697 .74356 .55608 .73817 Mtetra
.602 .453 .651 r
.55608 .73817 .55697 .74356 .55859 .74316 .55769 .73776 Mtetra
.603 .453 .651 r
.55769 .73776 .55859 .74316 .56021 .74275 .55931 .73734 Mtetra
.602 .452 .651 r
.55931 .73734 .56021 .74275 .56182 .74233 .56093 .73692 Mtetra
.601 .452 .651 r
.56093 .73692 .56182 .74233 .56344 .74192 .56254 .73653 Mtetra
.56254 .73653 .56344 .74192 .56506 .7415 .56416 .73614 Mtetra
.602 .453 .652 r
.56416 .73614 .56506 .7415 .56668 .74108 .56578 .73573 Mtetra
.604 .454 .652 r
.56578 .73573 .56668 .74108 .5683 .74065 .5674 .73529 Mtetra
.5674 .73529 .5683 .74065 .56993 .74022 .56902 .73485 Mtetra
.611 .459 .651 r
.56902 .73485 .56993 .74022 .57155 .73977 .57064 .73427 Mtetra
.62 .464 .649 r
.57064 .73427 .57155 .73977 .57317 .73932 .57226 .7335 Mtetra
.598 .445 .645 r
.57226 .7335 .57317 .73932 .5748 .73886 .57389 .73312 Mtetra
.541 .407 .647 r
.57389 .73312 .5748 .73886 .57643 .73842 .57553 .73378 Mtetra
.456 .365 .664 r
.57553 .73378 .57643 .73842 .57805 .73799 .57718 .7353 Mtetra
.421 .408 .74 r
.57718 .7353 .57805 .73799 .57968 .73757 .57883 .73636 Mtetra
.41 .568 .9 r
.57883 .73636 .57968 .73757 .58131 .73716 .58047 .73678 Mtetra
.528 .842 .999 r
.58047 .73678 .58131 .73716 .58294 .73675 .58211 .73647 Mtetra
.586 .887 .991 r
.58211 .73647 .58294 .73675 .58457 .73631 .58374 .73597 Mtetra
.596 .876 .993 r
.58374 .73597 .58457 .73631 .5862 .73582 .58537 .7355 Mtetra
.479 .837 .994 r
.58537 .7355 .5862 .73582 .58783 .73522 .58701 .73522 Mtetra
.246 .759 .837 r
.58701 .73522 .58783 .73522 .58946 .73462 .58864 .73495 Mtetra
.021 0 0 r
.58864 .73495 .58946 .73462 .5911 .73407 .59028 .73464 Mtetra
.13 0 0 r
.59028 .73464 .5911 .73407 .59273 .73364 .59192 .73424 Mtetra
.132 0 0 r
.59192 .73424 .59273 .73364 .59437 .73325 .59356 .73382 Mtetra
.108 0 0 r
.59356 .73382 .59437 .73325 .59601 .73286 .5952 .73339 Mtetra
.085 0 0 r
.5952 .73339 .59601 .73286 .59765 .73244 .59684 .73296 Mtetra
.079 0 0 r
.59684 .73296 .59765 .73244 .59929 .73201 .59848 .73253 Mtetra
.075 0 0 r
.59848 .73253 .59929 .73201 .60093 .73158 .60012 .7321 Mtetra
.073 0 0 r
.60012 .7321 .60093 .73158 .60257 .73114 .60176 .73166 Mtetra
.072 0 0 r
.60176 .73166 .60257 .73114 .60421 .73069 .60341 .73122 Mtetra
.074 0 0 r
.60341 .73122 .60421 .73069 .60585 .73024 .60505 .73078 Mtetra
.077 0 0 r
.60505 .73078 .60585 .73024 .6075 .72979 .6067 .73033 Mtetra
.083 0 0 r
.6067 .73033 .6075 .72979 .60914 .72933 .60834 .72988 Mtetra
.093 0 0 r
.60834 .72988 .60914 .72933 .61079 .72887 .60999 .72944 Mtetra
.115 0 0 r
.60999 .72944 .61079 .72887 .61244 .72838 .61164 .72901 Mtetra
.137 0 0 r
.61164 .72901 .61244 .72838 .61408 .72793 .61329 .72856 Mtetra
.135 0 0 r
.61329 .72856 .61408 .72793 .61573 .72755 .61494 .72811 Mtetra
.104 0 0 r
.61494 .72811 .61573 .72755 .61739 .72731 .61659 .72767 Mtetra
0 0 0 r
.61659 .72767 .61739 .72731 .61905 .72708 .61824 .72711 Mtetra
.593 .945 .912 r
.61824 .72711 .61905 .72708 .62071 .72689 .61988 .72631 Mtetra
.803 .849 .885 r
.61988 .72631 .62071 .72689 .62237 .72691 .62152 .7251 Mtetra
.769 .658 .74 r
.62152 .7251 .62237 .72691 .62403 .72651 .62313 .72331 Mtetra
.771 .599 .666 r
.62313 .72331 .62403 .72651 .62566 .7251 .62471 .72011 Mtetra
.957 .685 .48 r
.62471 .72011 .62566 .7251 .62716 .7193 .62108 .53529 Mtetra
.593 .383 .565 r
.62108 .53529 .62716 .7193 .62315 .52579 .6223 .52289 Mtetra
.775 .604 .668 r
.6223 .52289 .62315 .52579 .62457 .5207 .62379 .51988 Mtetra
.725 .771 .889 r
.62379 .51988 .62457 .5207 .62612 .51976 .62535 .51911 Mtetra
.581 .773 .971 r
.62535 .51911 .62612 .51976 .62769 .51951 .62692 .51886 Mtetra
.493 .736 .98 r
.62692 .51886 .62769 .51951 .62927 .51955 .6285 .5188 Mtetra
.651 .771 .937 r
.6285 .5188 .62927 .51955 .63084 .51909 .63006 .51836 Mtetra
.661 .779 .936 r
.63006 .51836 .63084 .51909 .6324 .5186 .63163 .51788 Mtetra
.674 .785 .932 r
.63163 .51788 .6324 .5186 .63397 .51806 .63319 .51735 Mtetra
.692 .792 .927 r
.63319 .51735 .63397 .51806 .63553 .51741 .63476 .51676 Mtetra
.701 .81 .933 r
.63476 .51676 .63553 .51741 .63709 .51676 .63632 .51612 Mtetra
.716 .816 .927 r
.63632 .51612 .63709 .51676 .63865 .51614 .63788 .51542 Mtetra
.779 .806 .874 r
.63788 .51542 .63865 .51614 .64021 .51532 .63944 .51436 Mtetra
.715 .741 .871 r
.63944 .51436 .64021 .51532 .64179 .5149 .641 .51362 Mtetra
.586 .632 .864 r
.641 .51362 .64179 .5149 .64339 .51532 .64258 .51351 Mtetra
0 .043 .611 r
.64258 .51351 .64339 .51532 .64519 .52107 .64426 .51601 Mtetra
.924 .639 .158 r
.64426 .51601 .64519 .52107 .65379 .71338 .64648 .53325 Mtetra
.064 0 .449 r
.64648 .53325 .65379 .71338 .65562 .71729 .65465 .71209 Mtetra
.573 .437 .657 r
.65465 .71209 .65562 .71729 .65732 .71738 .65634 .71221 Mtetra
.622 .469 .655 r
.65634 .71221 .65732 .71738 .65899 .71679 .658 .71143 Mtetra
.62 .466 .652 r
.658 .71143 .65899 .71679 .66064 .71588 .65967 .71066 Mtetra
.471 .367 .655 r
.65967 .71066 .66064 .71588 .66232 .71544 .66142 .71225 Mtetra
.44 .398 .715 r
.66142 .71225 .66232 .71544 .664 .71502 .66316 .71344 Mtetra
.388 .495 .846 r
.66316 .71344 .664 .71502 .66568 .7146 .66489 .71414 Mtetra
.503 .814 1 r
.66489 .71414 .66568 .7146 .66736 .7142 .66657 .71391 Mtetra
.559 .882 .991 r
.66657 .71391 .66736 .7142 .66904 .71377 .66826 .71344 Mtetra
.628 .894 .987 r
.66826 .71344 .66904 .71377 .67073 .71331 .66993 .71286 Mtetra
.414 .775 .995 r
.66993 .71286 .67073 .71331 .67242 .71316 .67163 .71277 Mtetra
.534 .847 .998 r
.67163 .71277 .67242 .71316 .6741 .71264 .67332 .71243 Mtetra
.705 .942 .96 r
.67332 .71243 .6741 .71264 .67575 .7114 .67499 .71157 Mtetra
.967 .922 .701 r
.67499 .71157 .67575 .7114 .67721 .70557 .67656 .70844 Mtetra
.851 .768 .26 r
.67656 .70844 .67721 .70557 .67043 .5114 .67792 .70044 Mtetra
.065 0 .445 r
.67792 .70044 .67043 .5114 .67181 .50609 .67124 .50962 Mtetra
.099 0 .279 r
.67124 .50962 .67181 .50609 .67337 .50494 .67271 .50625 Mtetra
0 0 0 r
.67271 .50625 .67337 .50494 .67496 .50453 .67424 .50444 Mtetra
.78 .976 .913 r
.67424 .50444 .67496 .50453 .67657 .50449 .6758 .50332 Mtetra
.668 .687 .858 r
.6758 .50332 .67657 .50449 .67817 .5041 .67739 .5028 Mtetra
.612 .64 .854 r
.67739 .5028 .67817 .5041 .67977 .50371 .67899 .50256 Mtetra
.573 .649 .887 r
.67899 .50256 .67977 .50371 .68136 .50334 .68061 .50247 Mtetra
.617 .73 .927 r
.68061 .50247 .68136 .50334 .68296 .50295 .68221 .50216 Mtetra
.627 .753 .937 r
.68221 .50216 .68296 .50295 .68456 .50257 .68381 .5018 Mtetra
.632 .762 .941 r
.68381 .5018 .68456 .50257 .68616 .50218 .68541 .50142 Mtetra
.632 .764 .942 r
.68541 .50142 .68616 .50218 .68776 .5018 .68702 .50104 Mtetra
.64 .767 .94 r
.68702 .50104 .68776 .5018 .68937 .5014 .68862 .50063 Mtetra
.652 .769 .935 r
.68862 .50063 .68937 .5014 .69097 .50097 .69022 .50018 Mtetra
.676 .772 .923 r
.69022 .50018 .69097 .50097 .69257 .50045 .69182 .49964 Mtetra
.686 .768 .914 r
.69182 .49964 .69257 .50045 .69416 .4999 .69341 .49905 Mtetra
.69 .762 .906 r
.69341 .49905 .69416 .4999 .69576 .49932 .69501 .49845 Mtetra
.772 .776 .856 r
.69501 .49845 .69576 .49932 .69734 .4983 .69658 .49737 Mtetra
.721 .752 .876 r
.69658 .49737 .69734 .4983 .69892 .49755 .69817 .49659 Mtetra
.552 .683 .926 r
.69817 .49659 .69892 .49755 .70055 .49744 .6998 .49652 Mtetra
.859 .435 0 r
.6998 .49652 .70055 .49744 .70236 .50085 .70165 .50061 Mtetra
.969 .682 .43 r
.70165 .50061 .70236 .50085 .71441 .69415 .71373 .69531 Mtetra
.861 .497 .359 r
.71373 .69531 .71441 .69415 .71647 .70017 .71573 .70031 Mtetra
.375 0 0 r
.71573 .70031 .71647 .70017 .71825 .7009 .71749 .70073 Mtetra
.594 .923 .967 r
.71749 .70073 .71825 .7009 .71996 .70055 .7192 .70008 Mtetra
.782 .888 .921 r
.7192 .70008 .71996 .70055 .72166 .69979 .72087 .69899 Mtetra
.564 .743 .96 r
.72087 .69899 .72166 .69979 .72339 .69969 .7226 .69879 Mtetra
.592 .728 .938 r
.7226 .69879 .72339 .69969 .72512 .69944 .72433 .69854 Mtetra
.733 .777 .888 r
.72433 .69854 .72512 .69944 .72681 .69852 .72602 .69767 Mtetra
.932 .779 .669 r
.72602 .69767 .72681 .69852 .72831 .6943 .72752 .69347 Mtetra
.971 .689 .436 r
.72752 .69347 .72831 .6943 .71871 .49998 .71797 .4991 Mtetra
.957 .744 .574 r
.71797 .4991 .71871 .49998 .7199 .49218 .71916 .49128 Mtetra
.828 .782 .809 r
.71916 .49128 .7199 .49218 .72145 .49058 .72071 .48968 Mtetra
.639 .733 .917 r
.72071 .48968 .72145 .49058 .72308 .49019 .72233 .48928 Mtetra
.492 .67 .943 r
.72233 .48928 .72308 .49019 .72473 .49026 .72399 .48936 Mtetra
.593 .716 .929 r
.72399 .48936 .72473 .49026 .72636 .49003 .72562 .48913 Mtetra
.635 .732 .919 r
.72562 .48913 .72636 .49003 .72799 .48966 .72725 .48876 Mtetra
.643 .736 .916 r
.72725 .48876 .72799 .48966 .72961 .48924 .72887 .48835 Mtetra
.663 .744 .91 r
.72887 .48835 .72961 .48924 .73124 .48875 .7305 .48786 Mtetra
.676 .749 .906 r
.7305 .48786 .73124 .48875 .73285 .4882 .73212 .48731 Mtetra
.683 .753 .904 r
.73212 .48731 .73285 .4882 .73447 .48761 .73374 .48673 Mtetra
.684 .756 .906 r
.73374 .48673 .73447 .48761 .73609 .48697 .73535 .48615 Mtetra
.688 .77 .914 r
.73535 .48615 .73609 .48697 .7377 .48633 .73697 .48554 Mtetra
.694 .783 .919 r
.73697 .48554 .7377 .48633 .73932 .48572 .73859 .48492 Mtetra
.708 .781 .908 r
.73859 .48492 .73932 .48572 .74095 .48527 .74021 .48422 Mtetra
.705 .727 .867 r
.74021 .48422 .74095 .48527 .74259 .4849 .74182 .48351 Mtetra
.687 .664 .822 r
.74182 .48351 .74259 .4849 .74422 .48454 .74344 .48282 Mtetra
.664 .616 .791 r
.74344 .48282 .74422 .48454 .74586 .48406 .74506 .48222 Mtetra
.653 .599 .781 r
.74506 .48222 .74586 .48406 .74748 .48351 .74669 .48167 Mtetra
.65 .598 .783 r
.74669 .48167 .74748 .48351 .74911 .48294 .74832 .48116 Mtetra
.65 .602 .787 r
.74832 .48116 .74911 .48294 .75074 .48241 .74995 .48065 Mtetra
.649 .604 .79 r
.74995 .48065 .75074 .48241 .75237 .48191 .75158 .48015 Mtetra
.648 .604 .791 r
.75158 .48015 .75237 .48191 .75401 .48142 .75322 .47966 Mtetra
.647 .604 .792 r
.75322 .47966 .75401 .48142 .75564 .48093 .75486 .47918 Mtetra
.646 .604 .793 r
.75486 .47918 .75564 .48093 .75728 .48045 .75649 .4787 Mtetra
.75649 .4787 .75728 .48045 .75892 .47997 .75813 .47823 Mtetra
.646 .605 .794 r
.75813 .47823 .75892 .47997 .76056 .4795 .75977 .47776 Mtetra
.646 .606 .794 r
.75977 .47776 .76056 .4795 .7622 .47902 .76141 .47729 Mtetra
.646 .606 .795 r
.76141 .47729 .7622 .47902 .76384 .47855 .76306 .47681 Mtetra
.647 .607 .795 r
.76306 .47681 .76384 .47855 .76548 .47807 .7647 .47634 Mtetra
.7647 .47634 .76548 .47807 .76713 .47758 .76634 .47585 Mtetra
.648 .608 .795 r
.76634 .47585 .76713 .47758 .76877 .4771 .76799 .47537 Mtetra
.76799 .47537 .76877 .4771 .77041 .47661 .76963 .47488 Mtetra
.649 .608 .795 r
.76963 .47488 .77041 .47661 .77206 .47612 .77128 .47439 Mtetra
.649 .609 .795 r
.77128 .47439 .77206 .47612 .77371 .47562 .77292 .47389 Mtetra
.65 .609 .795 r
.77292 .47389 .77371 .47562 .77535 .47512 .77457 .47339 Mtetra
.651 .609 .795 r
.77457 .47339 .77535 .47512 .777 .47462 .77622 .47289 Mtetra
.651 .609 .794 r
.77622 .47289 .777 .47462 .77865 .47411 .77787 .47238 Mtetra
.652 .61 .794 r
.77787 .47238 .77865 .47411 .7803 .4736 .77951 .47186 Mtetra
.652 .61 .793 r
.77951 .47186 .7803 .4736 .78195 .47308 .78116 .47134 Mtetra
.653 .609 .793 r
.78116 .47134 .78195 .47308 .7836 .47256 .78281 .47081 Mtetra
.653 .609 .792 r
.78281 .47081 .7836 .47256 .78525 .47204 .78446 .47028 Mtetra
.654 .609 .791 r
.78446 .47028 .78525 .47204 .7869 .47152 .78611 .46975 Mtetra
.654 .607 .79 r
.78611 .46975 .7869 .47152 .78855 .47099 .78777 .46921 Mtetra
.653 .606 .79 r
.78777 .46921 .78855 .47099 .7902 .47046 .78942 .46868 Mtetra
.652 .605 .789 r
.78942 .46868 .7902 .47046 .79186 .46994 .79107 .46815 Mtetra
.79107 .46815 .79186 .46994 .79351 .46942 .79273 .46763 Mtetra
.651 .604 .789 r
.79273 .46763 .79351 .46942 .79517 .4689 .79439 .4671 Mtetra
.79439 .4671 .79517 .4689 .79683 .46838 .79604 .46658 Mtetra
.65 .604 .789 r
.79604 .46658 .79683 .46838 .79849 .46786 .7977 .46606 Mtetra
.65 .603 .789 r
.7977 .46606 .79849 .46786 .80015 .46735 .79936 .46555 Mtetra
.79936 .46555 .80015 .46735 .80181 .46684 .80102 .46503 Mtetra
.649 .603 .789 r
.80102 .46503 .80181 .46684 .80347 .46632 .80269 .46452 Mtetra
.80269 .46452 .80347 .46632 .80513 .46581 .80435 .46401 Mtetra
.649 .602 .789 r
.80435 .46401 .80513 .46581 .8068 .46531 .80601 .4635 Mtetra
.80601 .4635 .8068 .46531 .80846 .4648 .80768 .46299 Mtetra
.648 .602 .789 r
.80768 .46299 .80846 .4648 .81013 .46429 .80935 .46249 Mtetra
.80935 .46249 .81013 .46429 .8118 .46379 .81101 .46198 Mtetra
.81101 .46198 .8118 .46379 .81347 .46329 .81268 .46148 Mtetra
.81268 .46148 .81347 .46329 .81514 .46279 .81435 .46098 Mtetra
.647 .602 .789 r
.81435 .46098 .81514 .46279 .81681 .46229 .81602 .46048 Mtetra
.81602 .46048 .81681 .46229 .81848 .46179 .8177 .45998 Mtetra
.8177 .45998 .81848 .46179 .82015 .46129 .81937 .45949 Mtetra
.647 .601 .789 r
.81937 .45949 .82015 .46129 .82183 .4608 .82105 .45899 Mtetra
.646 .601 .79 r
.82105 .45899 .82183 .4608 .8235 .46031 .82272 .4585 Mtetra
.82272 .4585 .8235 .46031 .82518 .45981 .8244 .45801 Mtetra
.645 .602 .791 r
.8244 .45801 .82518 .45981 .82686 .45932 .82608 .45753 Mtetra
.82608 .45753 .82686 .45932 .82854 .45883 .82776 .45705 Mtetra
.646 .603 .792 r
.82776 .45705 .82854 .45883 .83022 .45834 .82944 .45656 Mtetra
.646 .604 .792 r
.82944 .45656 .83022 .45834 .8319 .45785 .83112 .45607 Mtetra
.647 .605 .793 r
.83112 .45607 .8319 .45785 .83358 .45736 .8328 .45558 Mtetra
.8328 .45558 .83358 .45736 .83526 .45686 .83448 .45508 Mtetra
.648 .605 .793 r
.83448 .45508 .83526 .45686 .83694 .45636 .83617 .45458 Mtetra
.648 .606 .793 r
.83617 .45458 .83694 .45636 .83863 .45586 .83785 .45408 Mtetra
.83785 .45408 .83863 .45586 .84031 .45535 .83954 .45358 Mtetra
.649 .606 .793 r
.83954 .45358 .84031 .45535 .842 .45485 .84122 .45307 Mtetra
.649 .607 .793 r
.84122 .45307 .842 .45485 .84368 .45434 .84291 .45256 Mtetra
.84291 .45256 .84368 .45434 .84537 .45383 .8446 .45205 Mtetra
.65 .607 .793 r
.8446 .45205 .84537 .45383 .84706 .45331 .84629 .45154 Mtetra
.65 .608 .793 r
.84629 .45154 .84706 .45331 .84875 .45279 .84797 .45102 Mtetra
.84797 .45102 .84875 .45279 .85044 .45227 .84966 .4505 Mtetra
.651 .608 .793 r
.84966 .4505 .85044 .45227 .85213 .45175 .85135 .44998 Mtetra
.652 .609 .793 r
.85135 .44998 .85213 .45175 .85382 .45122 .85304 .44945 Mtetra
.653 .61 .793 r
.85304 .44945 .85382 .45122 .85551 .45067 .85474 .44891 Mtetra
.654 .611 .793 r
.85474 .44891 .85551 .45067 .8572 .45012 .85643 .44836 Mtetra
.654 .612 .794 r
.85643 .44836 .8572 .45012 .85889 .44956 .85812 .44781 Mtetra
.669 .619 .791 r
.85812 .44781 .85889 .44956 .86056 .44885 .8598 .44715 Mtetra
.687 .634 .79 r
.8598 .44715 .86056 .44885 .86222 .44795 .86147 .44636 Mtetra
.647 .626 .814 r
.86147 .44636 .86222 .44795 .86392 .44752 .86317 .44588 Mtetra
.469 .525 .833 r
.86317 .44588 .86392 .44752 .86578 .44854 .86497 .44637 Mtetra
0 .089 .636 r
.86497 .44637 .86578 .44854 .86852 .45788 .86707 .44962 Mtetra
.975 .672 .312 r
.86707 .44962 .86852 .45788 .89067 .65153 .88902 .64179 Mtetra
.294 .214 .592 r
.88902 .64179 .89067 .65153 .89282 .65428 .89165 .64906 Mtetra
.574 .44 .661 r
.89165 .64906 .89282 .65428 .89468 .65418 .89353 .64917 Mtetra
.628 .478 .659 r
.89353 .64917 .89468 .65418 .89648 .65346 .89531 .64827 Mtetra
.639 .482 .655 r
.89531 .64827 .89648 .65346 .89825 .65259 .89705 .6471 Mtetra
.607 .458 .653 r
.89705 .6471 .89825 .65259 .90007 .65207 .89886 .64655 Mtetra
.89886 .64655 .90007 .65207 .90189 .65155 .90068 .64599 Mtetra
.606 .457 .652 r
.90068 .64599 .90189 .65155 .90371 .65104 .90249 .64545 Mtetra
.605 .455 .652 r
.90249 .64545 .90371 .65104 .90554 .65055 .90431 .64494 Mtetra
.603 .454 .652 r
.90431 .64494 .90554 .65055 .90736 .65006 .90614 .64446 Mtetra
.602 .453 .652 r
.90614 .64446 .90736 .65006 .90919 .64959 .90797 .644 Mtetra
.601 .453 .652 r
.90797 .644 .90919 .64959 .91102 .64913 .9098 .64357 Mtetra
.601 .453 .653 r
.9098 .64357 .91102 .64913 .91285 .64867 .91164 .64315 Mtetra
.591 .447 .654 r
.91164 .64315 .91285 .64867 .9147 .64832 .91349 .64292 Mtetra
.567 .433 .658 r
.91349 .64292 .9147 .64832 .91658 .64826 .91541 .64317 Mtetra
.607 .463 .661 r
.91541 .64317 .91658 .64826 .91841 .64775 .91724 .64267 Mtetra
.701 .523 .644 r
.91724 .64267 .91841 .64775 .9201 .64603 .91882 .64002 Mtetra
.975 .672 .367 r
.91882 .64002 .9201 .64603 .92118 .63888 .89841 .44493 Mtetra
.583 .374 .564 r
.89841 .44493 .92118 .63888 .90028 .4408 .89934 .43746 Mtetra
.756 .584 .663 r
.89934 .43746 .90028 .4408 .90155 .43638 .90079 .43464 Mtetra
.692 .634 .787 r
.90079 .43464 .90155 .43638 .90322 .43538 .90248 .43379 Mtetra
.638 .624 .82 r
.90248 .43379 .90322 .43538 .90495 .435 .90421 .43338 Mtetra
.623 .612 .819 r
.90421 .43338 .90495 .435 .90671 .43477 .90596 .43306 Mtetra
.688 .635 .791 r
.90596 .43306 .90671 .43477 .90839 .43385 .90765 .43225 Mtetra
.655 .631 .814 r
.90765 .43225 .90839 .43385 .91011 .43333 .90937 .43172 Mtetra
.536 .567 .833 r
.90937 .43172 .91011 .43333 .91196 .43385 .91118 .43189 Mtetra
.002 .187 .701 r
.91118 .43189 .91196 .43385 .91446 .43981 .91328 .43453 Mtetra
.76 .49 0 r
.91328 .43453 .91446 .43981 .93992 .63703 .91746 .45441 Mtetra
.188 .098 .515 r
.91746 .45441 .93992 .63703 .94227 .64076 .941 .63506 Mtetra
.581 .439 .653 r
.941 .63506 .94227 .64076 .94417 .64073 .94291 .63504 Mtetra
.627 .469 .648 r
.94291 .63504 .94417 .64073 .946 .63999 .94469 .63402 Mtetra
.617 .459 .645 r
.94469 .63402 .946 .63999 .94778 .63896 .9465 .63317 Mtetra
.499 .384 .654 r
.9465 .63317 .94778 .63896 .94962 .6384 .94859 .63467 Mtetra
.485 .416 .703 r
.94859 .63467 .94962 .6384 .95147 .63784 .95064 .63579 Mtetra
.483 .502 .802 r
.95064 .63579 .95147 .63784 .95332 .6373 .95263 .63637 Mtetra
.6 .739 .942 r
.95263 .63637 .95332 .6373 .95517 .6368 .95451 .63606 Mtetra
.642 .807 .962 r
.95451 .63606 .95517 .6368 .95703 .63633 .95636 .63554 Mtetra
.651 .797 .953 r
.95636 .63554 .95703 .63633 .9589 .63594 .95822 .635 Mtetra
.471 .672 .952 r
.95822 .635 .9589 .63594 .96084 .63606 .96015 .63512 Mtetra
.605 .739 .939 r
.96015 .63512 .96084 .63606 .96272 .63574 .96204 .63479 Mtetra
.789 .805 .865 r
.96204 .63479 .96272 .63574 .96448 .63446 .9638 .63351 Mtetra
.978 .775 .563 r
.9638 .63351 .96448 .63446 .96557 .62792 .96488 .62688 Mtetra
.975 .669 .323 r
.96488 .62688 .96557 .62792 .94193 .42858 .94127 .42753 Mtetra
.959 .776 .612 r
.94127 .42753 .94193 .42858 .9431 .42357 .94244 .42256 Mtetra
.753 .769 .866 r
.94244 .42256 .9431 .42357 .94478 .42255 .94413 .42154 Mtetra
.624 .717 .913 r
.94413 .42154 .94478 .42255 .94655 .4222 .94589 .42119 Mtetra
.542 .677 .926 r
.94589 .42119 .94655 .4222 .94836 .42216 .9477 .42114 Mtetra
.747 .765 .868 r
.9477 .42114 .94836 .42216 .95005 .42121 .94939 .42016 Mtetra
.678 .731 .89 r
.94939 .42016 .95005 .42121 .95179 .42062 .95113 .41956 Mtetra
.485 .635 .921 r
.95113 .41956 .95179 .42062 .95363 .42073 .95298 .41973 Mtetra
.785 .376 0 r
.95298 .41973 .95363 .42073 .95605 .42524 .95554 .4253 Mtetra
.971 .655 .296 r
.95554 .4253 .95605 .42524 .98432 .6236 .98388 .62441 Mtetra
.851 .419 .199 r
.98388 .62441 .98432 .6236 .98693 .62859 .98639 .62864 Mtetra
.316 .629 .961 r
.37993 .7893 .38084 .79005 .38234 .79021 .38141 .78959 Mtetra
.694 .803 .933 r
.38141 .78959 .38234 .79021 .38386 .78959 .38294 .78899 Mtetra
.819 .809 .841 r
.38294 .78899 .38386 .78959 .38541 .7884 .3845 .78761 Mtetra
.871 .756 .734 r
.3845 .78761 .38541 .7884 .38696 .78732 .38611 .78486 Mtetra
.846 .653 .642 r
.38611 .78486 .38696 .78732 .38852 .78571 .38783 .77894 Mtetra
.928 .678 .539 r
.38783 .77894 .38852 .78571 .39013 .78298 .3963 .59388 Mtetra
.579 .372 .565 r
.3963 .59388 .39013 .78298 .39815 .60663 .39789 .58958 Mtetra
.612 .415 .591 r
.39789 .58958 .39815 .60663 .40018 .59023 .39939 .58745 Mtetra
.696 .56 .697 r
.39939 .58745 .40018 .59023 .40172 .58699 .40086 .58613 Mtetra
.698 .737 .881 r
.40086 .58613 .40172 .58699 .40318 .58611 .40231 .58553 Mtetra
.609 .79 .968 r
.40231 .58553 .40318 .58611 .40462 .58579 .40375 .58522 Mtetra
.543 .773 .983 r
.40375 .58522 .40462 .58579 .40605 .58574 .40518 .58505 Mtetra
.643 .766 .938 r
.40518 .58505 .40605 .58574 .40749 .58537 .40663 .58467 Mtetra
.656 .769 .932 r
.40663 .58467 .40749 .58537 .40893 .58495 .40807 .58425 Mtetra
.664 .77 .929 r
.40807 .58425 .40893 .58495 .41038 .5845 .40952 .5838 Mtetra
.669 .77 .926 r
.40952 .5838 .41038 .5845 .41182 .58404 .41096 .58334 Mtetra
.678 .772 .922 r
.41096 .58334 .41182 .58404 .41327 .58354 .41241 .58284 Mtetra
.688 .774 .917 r
.41241 .58284 .41327 .58354 .41472 .583 .41386 .5823 Mtetra
.711 .778 .904 r
.41386 .5823 .41472 .583 .41618 .58236 .41532 .58166 Mtetra
.714 .778 .902 r
.41532 .58166 .41618 .58236 .41763 .58171 .41678 .581 Mtetra
.709 .776 .904 r
.41678 .581 .41763 .58171 .41909 .58109 .41823 .58037 Mtetra
.722 .776 .896 r
.41823 .58037 .41909 .58109 .42055 .58028 .41969 .57968 Mtetra
.691 .801 .933 r
.41969 .57968 .42055 .58028 .42201 .57969 .42115 .57912 Mtetra
.598 .79 .972 r
.42115 .57912 .42201 .57969 .42345 .57956 .42259 .57883 Mtetra
0 .426 .856 r
.42259 .57883 .42345 .57956 .42483 .58144 .42401 .5795 Mtetra
.147 .282 .746 r
.42401 .5795 .42483 .58144 .42608 .58813 .42541 .58095 Mtetra
.439 .313 .611 r
.42541 .58095 .42608 .58813 .42224 .77314 .42679 .58338 Mtetra
.572 .366 .564 r
.42679 .58338 .42224 .77314 .42374 .77423 .42823 .58328 Mtetra
.573 .367 .564 r
.42823 .58328 .42374 .77423 .42528 .77364 .42971 .58238 Mtetra
.572 .366 .563 r
.42971 .58238 .42528 .77364 .42683 .77282 .43115 .58237 Mtetra
0 0 .378 r
.43115 .58237 .42683 .77282 .42833 .7741 .42767 .76431 Mtetra
.049 .01 .487 r
.42767 .76431 .42833 .7741 .42982 .7754 .42897 .77278 Mtetra
0 .074 .615 r
.42897 .77278 .42982 .7754 .43133 .77622 .43044 .77539 Mtetra
.326 .614 .953 r
.43044 .77539 .43133 .77622 .43287 .77617 .43196 .77572 Mtetra
.607 .836 .987 r
.43196 .77572 .43287 .77617 .43441 .77578 .43351 .77532 Mtetra
.706 .855 .953 r
.43351 .77532 .43441 .77578 .43596 .77525 .43506 .77465 Mtetra
.607 .796 .971 r
.43506 .77465 .43596 .77525 .4375 .7751 .43661 .77432 Mtetra
.628 .751 .935 r
.43661 .77432 .4375 .7751 .43905 .77485 .43815 .77397 Mtetra
.691 .744 .893 r
.43815 .77397 .43905 .77485 .4406 .77415 .43971 .77337 Mtetra
.819 .778 .815 r
.43971 .77337 .4406 .77415 .44221 .77148 .44128 .77184 Mtetra
.935 .954 .766 r
.44128 .77184 .44221 .77148 .4439 .76471 .44288 .76947 Mtetra
.204 0 .329 r
.44288 .76947 .4439 .76471 .44958 .57769 .44449 .7662 Mtetra
.569 .361 .558 r
.44449 .7662 .44958 .57769 .45109 .57528 .44606 .76509 Mtetra
.571 .362 .558 r
.44606 .76509 .45109 .57528 .45256 .57497 .4476 .76513 Mtetra
.57 .361 .558 r
.4476 .76513 .45256 .57497 .45402 .57497 .44916 .76442 Mtetra
0 0 .391 r
.44916 .76442 .45402 .57497 .45552 .5731 .45437 .58738 Mtetra
0 0 .287 r
.45437 .58738 .45552 .5731 .45702 .57103 .45614 .57223 Mtetra
.933 .935 .579 r
.45614 .57223 .45702 .57103 .45852 .56944 .45767 .56878 Mtetra
.796 .797 .852 r
.45767 .56878 .45852 .56944 .45999 .56871 .45916 .56762 Mtetra
.635 .676 .872 r
.45916 .56762 .45999 .56871 .46146 .56839 .46063 .5673 Mtetra
.557 .645 .892 r
.46063 .5673 .46146 .56839 .46293 .56821 .4621 .56726 Mtetra
.617 .7 .904 r
.4621 .56726 .46293 .56821 .46441 .56786 .46357 .567 Mtetra
.66 .733 .903 r
.46357 .567 .46441 .56786 .46588 .56739 .46504 .56657 Mtetra
.673 .744 .904 r
.46504 .56657 .46588 .56739 .46736 .56688 .46652 .56608 Mtetra
.721 .761 .884 r
.46652 .56608 .46736 .56688 .46884 .56605 .468 .56537 Mtetra
.724 .79 .904 r
.468 .56537 .46884 .56605 .47032 .56528 .46948 .56466 Mtetra
.664 .796 .945 r
.46948 .56466 .47032 .56528 .4718 .56493 .47096 .56419 Mtetra
.233 .577 .943 r
.47096 .56419 .4718 .56493 .47325 .56628 .47243 .5646 Mtetra
.129 .306 .774 r
.47243 .5646 .47325 .56628 .47465 .57139 .47388 .56593 Mtetra
.399 .304 .63 r
.47388 .56593 .47465 .57139 .47344 .7584 .47532 .56823 Mtetra
.571 .365 .563 r
.47532 .56823 .47344 .7584 .47497 .76063 .47679 .5689 Mtetra
.573 .368 .564 r
.47679 .5689 .47497 .76063 .47654 .76016 .47829 .56792 Mtetra
.572 .367 .564 r
.47829 .56792 .47654 .76016 .47811 .75932 .47977 .56765 Mtetra
.022 0 .412 r
.47977 .56765 .47811 .75932 .47966 .76016 .47898 .74395 Mtetra
.058 0 .467 r
.47898 .74395 .47966 .76016 .48121 .76152 .48036 .7583 Mtetra
.013 .103 .614 r
.48036 .7583 .48121 .76152 .48277 .7624 .48189 .76131 Mtetra
.176 .46 .884 r
.48189 .76131 .48277 .7624 .48434 .76273 .48345 .76209 Mtetra
.576 .776 .974 r
.48345 .76209 .48434 .76273 .48591 .76254 .48503 .76183 Mtetra
.728 .796 .906 r
.48503 .76183 .48591 .76254 .48749 .7618 .48661 .76106 Mtetra
.819 .791 .826 r
.48661 .76106 .48749 .7618 .48908 .75949 .4882 .75957 Mtetra
.929 .924 .784 r
.4882 .75957 .48908 .75949 .49071 .75371 .48979 .75727 Mtetra
.041 0 .216 r
.48979 .75727 .49071 .75371 .494 .56526 .4914 .75404 Mtetra
.568 .36 .558 r
.4914 .75404 .494 .56526 .49552 .56164 .49299 .75214 Mtetra
.571 .362 .558 r
.49299 .75214 .49552 .56164 .49702 .56115 .49456 .75214 Mtetra
.57 .361 .558 r
.49456 .75214 .49702 .56115 .49851 .56105 .49614 .75152 Mtetra
.551 .346 .556 r
.49614 .75152 .49851 .56105 .50001 .55958 .49781 .73941 Mtetra
0 0 .382 r
.49781 .73941 .50001 .55958 .50152 .55749 .50067 .5591 Mtetra
.846 .88 .444 r
.50067 .5591 .50152 .55749 .50302 .55583 .50219 .55533 Mtetra
.852 .836 .83 r
.50219 .55533 .50302 .55583 .50452 .55485 .5037 .55377 Mtetra
.681 .696 .857 r
.5037 .55377 .50452 .55485 .50602 .55436 .5052 .55321 Mtetra
.619 .662 .87 r
.5052 .55321 .50602 .55436 .50751 .55401 .50669 .55295 Mtetra
.63 .683 .881 r
.50669 .55295 .50751 .55401 .50901 .55364 .50819 .55265 Mtetra
.659 .707 .883 r
.50819 .55265 .50901 .55364 .51051 .55319 .50969 .55221 Mtetra
.658 .708 .885 r
.50969 .55221 .51051 .55319 .51201 .55274 .51119 .55178 Mtetra
.657 .712 .888 r
.51119 .55178 .51201 .55274 .51351 .55229 .51269 .55135 Mtetra
.657 .718 .893 r
.51269 .55135 .51351 .55229 .51501 .55182 .51419 .55092 Mtetra
.658 .727 .9 r
.51419 .55092 .51501 .55182 .51652 .55135 .5157 .55049 Mtetra
.659 .735 .906 r
.5157 .55049 .51652 .55135 .51802 .55089 .5172 .55005 Mtetra
.66 .742 .911 r
.5172 .55005 .51802 .55089 .51952 .55043 .5187 .54961 Mtetra
.661 .745 .913 r
.5187 .54961 .51952 .55043 .52103 .54998 .52021 .54916 Mtetra
.661 .748 .914 r
.52021 .54916 .52103 .54998 .52253 .54952 .52171 .54871 Mtetra
.661 .749 .916 r
.52171 .54871 .52253 .54952 .52404 .54907 .52322 .54826 Mtetra
.662 .751 .916 r
.52322 .54826 .52404 .54907 .52555 .54861 .52473 .54781 Mtetra
.662 .752 .917 r
.52473 .54781 .52555 .54861 .52705 .54815 .52624 .54736 Mtetra
.663 .753 .917 r
.52624 .54736 .52705 .54815 .52856 .5477 .52775 .5469 Mtetra
.52775 .5469 .52856 .5477 .53007 .54724 .52926 .54644 Mtetra
.664 .754 .917 r
.52926 .54644 .53007 .54724 .53158 .54677 .53077 .54598 Mtetra
.53077 .54598 .53158 .54677 .5331 .54631 .53228 .54551 Mtetra
.665 .755 .917 r
.53228 .54551 .5331 .54631 .53461 .54584 .53379 .54504 Mtetra
.667 .755 .916 r
.53379 .54504 .53461 .54584 .53612 .54536 .53531 .54457 Mtetra
.668 .756 .916 r
.53531 .54457 .53612 .54536 .53763 .54487 .53682 .54408 Mtetra
.669 .757 .917 r
.53682 .54408 .53763 .54487 .53915 .54439 .53834 .5436 Mtetra
.688 .762 .909 r
.53834 .5436 .53915 .54439 .54066 .54377 .53985 .54304 Mtetra
.698 .779 .914 r
.53985 .54304 .54066 .54377 .54218 .54308 .54137 .54243 Mtetra
.646 .79 .951 r
.54137 .54243 .54218 .54308 .5437 .54271 .54289 .54201 Mtetra
.403 .677 .972 r
.54289 .54201 .5437 .54271 .54522 .54343 .54441 .54216 Mtetra
.111 .363 .827 r
.54441 .54216 .54522 .54343 .54677 .54684 .54594 .54324 Mtetra
.355 .316 .677 r
.54594 .54324 .54677 .54684 .54959 .73398 .54747 .54509 Mtetra
.568 .364 .563 r
.54747 .54509 .54959 .73398 .55125 .73992 .54902 .547 Mtetra
.572 .366 .564 r
.54902 .547 .55125 .73992 .55286 .74 .55054 .54695 Mtetra
.573 .367 .564 r
.55054 .54695 .55286 .74 .55447 .73913 .55207 .54604 Mtetra
.55207 .54604 .55447 .73913 .55608 .73817 .55359 .54515 Mtetra
.572 .367 .564 r
.55359 .54515 .55608 .73817 .55769 .73776 .55512 .5447 Mtetra
.55512 .5447 .55769 .73776 .55931 .73734 .55664 .54426 Mtetra
.55664 .54426 .55931 .73734 .56093 .73692 .55817 .54383 Mtetra
.55817 .54383 .56093 .73692 .56254 .73653 .5597 .54343 Mtetra
.5597 .54343 .56254 .73653 .56416 .73614 .56124 .54303 Mtetra
.56124 .54303 .56416 .73614 .56578 .73573 .56277 .5426 Mtetra
.573 .367 .564 r
.56277 .5426 .56578 .73573 .5674 .73529 .5643 .54212 Mtetra
.5643 .54212 .5674 .73529 .56902 .73485 .56583 .54165 Mtetra
.56583 .54165 .56902 .73485 .57064 .73427 .56736 .54083 Mtetra
.574 .368 .564 r
.56736 .54083 .57064 .73427 .57226 .7335 .56889 .53964 Mtetra
.572 .367 .564 r
.56889 .53964 .57226 .7335 .57389 .73312 .57043 .53938 Mtetra
.566 .361 .563 r
.57043 .53938 .57389 .73312 .57553 .73378 .57202 .54297 Mtetra
.027 0 .426 r
.57202 .54297 .57553 .73378 .57718 .7353 .57628 .7305 Mtetra
.106 .119 .589 r
.57628 .7305 .57718 .7353 .57883 .73636 .57797 .73476 Mtetra
.093 .308 .786 r
.57797 .73476 .57883 .73636 .58047 .73678 .57963 .73619 Mtetra
.528 .781 .99 r
.57963 .73619 .58047 .73678 .58211 .73647 .58127 .73601 Mtetra
.656 .859 .977 r
.58127 .73601 .58211 .73647 .58374 .73597 .5829 .73545 Mtetra
.673 .844 .965 r
.5829 .73545 .58374 .73597 .58537 .7355 .58453 .73486 Mtetra
.579 .785 .977 r
.58453 .73486 .58537 .7355 .58701 .73522 .58617 .73458 Mtetra
.58 .784 .976 r
.58617 .73458 .58701 .73522 .58864 .73495 .58781 .7343 Mtetra
.597 .788 .972 r
.58781 .7343 .58864 .73495 .59028 .73464 .58944 .73398 Mtetra
.625 .794 .963 r
.58944 .73398 .59028 .73464 .59192 .73424 .59108 .73357 Mtetra
.634 .795 .96 r
.59108 .73357 .59192 .73424 .59356 .73382 .59272 .73315 Mtetra
.638 .794 .958 r
.59272 .73315 .59356 .73382 .5952 .73339 .59436 .73271 Mtetra
.635 .793 .958 r
.59436 .73271 .5952 .73339 .59684 .73296 .596 .73228 Mtetra
.637 .793 .957 r
.596 .73228 .59684 .73296 .59848 .73253 .59764 .73185 Mtetra
.59764 .73185 .59848 .73253 .60012 .7321 .59929 .73142 Mtetra
.638 .793 .957 r
.59929 .73142 .60012 .7321 .60176 .73166 .60093 .73098 Mtetra
.60093 .73098 .60176 .73166 .60341 .73122 .60257 .73054 Mtetra
.639 .794 .957 r
.60257 .73054 .60341 .73122 .60505 .73078 .60422 .7301 Mtetra
.639 .795 .957 r
.60422 .7301 .60505 .73078 .6067 .73033 .60587 .72966 Mtetra
.638 .796 .958 r
.60587 .72966 .6067 .73033 .60834 .72988 .60751 .72922 Mtetra
.636 .797 .96 r
.60751 .72922 .60834 .72988 .60999 .72944 .60916 .72878 Mtetra
.63 .797 .963 r
.60916 .72878 .60999 .72944 .61164 .72901 .61081 .72836 Mtetra
.635 .801 .963 r
.61081 .72836 .61164 .72901 .61329 .72856 .61246 .72792 Mtetra
.63 .802 .965 r
.61246 .72792 .61329 .72856 .61494 .72811 .61411 .72749 Mtetra
.586 .797 .98 r
.61411 .72749 .61494 .72811 .61659 .72767 .61577 .72718 Mtetra
.66 .853 .974 r
.61577 .72718 .61659 .72767 .61824 .72711 .61742 .72661 Mtetra
.798 .869 .901 r
.61742 .72661 .61824 .72711 .61988 .72631 .61905 .72546 Mtetra
.89 .777 .73 r
.61905 .72546 .61988 .72631 .62152 .7251 .62064 .72256 Mtetra
.861 .661 .631 r
.62064 .72256 .62152 .7251 .62313 .72331 .62214 .71658 Mtetra
.954 .682 .483 r
.62214 .71658 .62313 .72331 .62471 .72011 .61852 .52719 Mtetra
.579 .372 .564 r
.61852 .52719 .62471 .72011 .62108 .53529 .61996 .52257 Mtetra
.624 .43 .599 r
.61996 .52257 .62108 .53529 .6223 .52289 .62147 .52035 Mtetra
.702 .577 .712 r
.62147 .52035 .6223 .52289 .62379 .51988 .62301 .51906 Mtetra
.681 .76 .911 r
.62301 .51906 .62379 .51988 .62535 .51911 .62458 .51851 Mtetra
.579 .786 .978 r
.62458 .51851 .62535 .51911 .62692 .51886 .62615 .51824 Mtetra
.54 .767 .982 r
.62615 .51824 .62692 .51886 .6285 .5188 .62772 .51806 Mtetra
.648 .771 .938 r
.62772 .51806 .6285 .5188 .63006 .51836 .62929 .51763 Mtetra
.661 .778 .936 r
.62929 .51763 .63006 .51836 .63163 .51788 .63086 .51715 Mtetra
.675 .782 .931 r
.63086 .51715 .63163 .51788 .63319 .51735 .63242 .51663 Mtetra
.69 .786 .924 r
.63242 .51663 .63319 .51735 .63476 .51676 .63399 .51604 Mtetra
.701 .792 .921 r
.63399 .51604 .63476 .51676 .63632 .51612 .63555 .5154 Mtetra
.715 .796 .915 r
.63555 .5154 .63632 .51612 .63788 .51542 .63711 .5147 Mtetra
.762 .805 .888 r
.63711 .5147 .63788 .51542 .63944 .51436 .63867 .51376 Mtetra
.73 .83 .927 r
.63867 .51376 .63944 .51436 .641 .51362 .64023 .513 Mtetra
.627 .798 .964 r
.64023 .513 .641 .51362 .64258 .51351 .64181 .5126 Mtetra
.084 .433 .874 r
.64181 .5126 .64258 .51351 .64426 .51601 .64343 .51344 Mtetra
.297 .329 .726 r
.64343 .51344 .64426 .51601 .64648 .53325 .64508 .51509 Mtetra
.526 .349 .584 r
.64508 .51509 .64648 .53325 .65465 .71209 .64677 .51778 Mtetra
.573 .367 .564 r
.64677 .51778 .65465 .71209 .65634 .71221 .64834 .51686 Mtetra
.64834 .51686 .65634 .71221 .658 .71143 .6499 .51593 Mtetra
.571 .366 .563 r
.6499 .51593 .658 .71143 .65967 .71066 .65151 .51634 Mtetra
.081 0 .455 r
.65151 .51634 .65967 .71066 .66142 .71225 .66037 .70525 Mtetra
.166 .132 .572 r
.66037 .70525 .66142 .71225 .66316 .71344 .6623 .71124 Mtetra
.06 .213 .709 r
.6623 .71124 .66316 .71344 .66489 .71414 .66408 .71345 Mtetra
.481 .732 .982 r
.66408 .71345 .66489 .71414 .66657 .71391 .66578 .71341 Mtetra
.632 .849 .983 r
.66578 .71341 .66657 .71391 .66826 .71344 .66746 .71291 Mtetra
.711 .858 .952 r
.66746 .71291 .66826 .71344 .66993 .71286 .66913 .71216 Mtetra
.578 .774 .972 r
.66913 .71216 .66993 .71286 .67163 .71277 .67082 .71189 Mtetra
.639 .747 .927 r
.67082 .71189 .67163 .71277 .67332 .71243 .67251 .71148 Mtetra
.702 .752 .891 r
.67251 .71148 .67332 .71243 .67499 .71157 .67419 .71078 Mtetra
.82 .807 .839 r
.67419 .71078 .67499 .71157 .67656 .70844 .67583 .70931 Mtetra
.697 .889 .513 r
.67583 .70931 .67656 .70844 .67792 .70044 .67744 .70699 Mtetra
.289 .083 .418 r
.67744 .70699 .67792 .70044 .67124 .50962 .67896 .70271 Mtetra
.081 0 .45 r
.67896 .70271 .67124 .50962 .67271 .50625 .67223 .51183 Mtetra
0 0 .28 r
.67223 .51183 .67271 .50625 .67424 .50444 .67355 .50517 Mtetra
.873 .945 .583 r
.67355 .50517 .67424 .50444 .6758 .50332 .67504 .50242 Mtetra
.722 .759 .882 r
.67504 .50242 .6758 .50332 .67739 .5028 .67662 .50166 Mtetra
.602 .665 .884 r
.67662 .50166 .67739 .5028 .67899 .50256 .67822 .50145 Mtetra
.518 .633 .904 r
.67822 .50145 .67899 .50256 .68061 .50247 .67985 .50154 Mtetra
.609 .713 .918 r
.67985 .50154 .68061 .50247 .68221 .50216 .68145 .50127 Mtetra
.624 .729 .922 r
.68145 .50127 .68221 .50216 .68381 .5018 .68305 .50094 Mtetra
.63 .737 .925 r
.68305 .50094 .68381 .5018 .68541 .50142 .68466 .50058 Mtetra
.632 .744 .929 r
.68466 .50058 .68541 .50142 .68702 .50104 .68626 .50021 Mtetra
.641 .751 .928 r
.68626 .50021 .68702 .50104 .68862 .50063 .68787 .49981 Mtetra
.655 .757 .925 r
.68787 .49981 .68862 .50063 .69022 .50018 .68947 .49935 Mtetra
.68 .764 .915 r
.68947 .49935 .69022 .50018 .69182 .49964 .69106 .4988 Mtetra
.691 .763 .907 r
.69106 .4988 .69182 .49964 .69341 .49905 .69266 .49819 Mtetra
.695 .759 .901 r
.69266 .49819 .69341 .49905 .69501 .49845 .69426 .49756 Mtetra
.774 .774 .853 r
.69426 .49756 .69501 .49845 .69658 .49737 .69583 .49646 Mtetra
.725 .758 .879 r
.69583 .49646 .69658 .49737 .69817 .49659 .69742 .49567 Mtetra
.552 .692 .932 r
.69742 .49567 .69817 .49659 .6998 .49652 .69904 .49558 Mtetra
.854 .429 0 r
.69904 .49558 .6998 .49652 .70165 .50061 .70089 .49962 Mtetra
.97 .683 .428 r
.70089 .49962 .70165 .50061 .71373 .69531 .71294 .69437 Mtetra
.894 .486 .076 r
.71294 .69437 .71373 .69531 .71573 .70031 .71494 .69944 Mtetra
.315 .599 .947 r
.71494 .69944 .71573 .70031 .71749 .70073 .7167 .69986 Mtetra
.692 .772 .912 r
.7167 .69986 .71749 .70073 .7192 .70008 .71841 .69921 Mtetra
.767 .79 .871 r
.71841 .69921 .7192 .70008 .72087 .69899 .72009 .69812 Mtetra
.57 .728 .948 r
.72009 .69812 .72087 .69899 .7226 .69879 .72182 .69794 Mtetra
.585 .736 .947 r
.72182 .69794 .7226 .69879 .72433 .69854 .72354 .6977 Mtetra
.733 .787 .896 r
.72354 .6977 .72433 .69854 .72602 .69767 .72524 .69683 Mtetra
.932 .78 .669 r
.72524 .69683 .72602 .69767 .72752 .69347 .72674 .69264 Mtetra
.971 .689 .436 r
.72674 .69264 .72752 .69347 .71797 .4991 .71723 .49825 Mtetra
.958 .745 .573 r
.71723 .49825 .71797 .4991 .71916 .49128 .71842 .49038 Mtetra
.829 .783 .809 r
.71842 .49038 .71916 .49128 .72071 .48968 .71997 .48877 Mtetra
.64 .734 .917 r
.71997 .48877 .72071 .48968 .72233 .48928 .72159 .48838 Mtetra
.495 .67 .942 r
.72159 .48838 .72233 .48928 .72399 .48936 .72324 .48844 Mtetra
.596 .714 .927 r
.72324 .48844 .72399 .48936 .72562 .48913 .72488 .48821 Mtetra
.637 .729 .915 r
.72488 .48821 .72562 .48913 .72725 .48876 .72651 .48783 Mtetra
.645 .73 .911 r
.72651 .48783 .72725 .48876 .72887 .48835 .72813 .48741 Mtetra
.663 .735 .904 r
.72813 .48741 .72887 .48835 .7305 .48786 .72976 .48692 Mtetra
.675 .739 .899 r
.72976 .48692 .7305 .48786 .73212 .48731 .73138 .48638 Mtetra
.681 .743 .897 r
.73138 .48638 .73212 .48731 .73374 .48673 .733 .48581 Mtetra
.681 .744 .899 r
.733 .48581 .73374 .48673 .73535 .48615 .73462 .48524 Mtetra
.684 .749 .901 r
.73462 .48524 .73535 .48615 .73697 .48554 .73624 .48465 Mtetra
.69 .755 .901 r
.73624 .48465 .73697 .48554 .73859 .48492 .73786 .48404 Mtetra
.706 .763 .897 r
.73786 .48404 .73859 .48492 .74021 .48422 .73947 .48335 Mtetra
.711 .766 .895 r
.73947 .48335 .74021 .48422 .74182 .48351 .74109 .48263 Mtetra
.706 .764 .897 r
.74109 .48263 .74182 .48351 .74344 .48282 .7427 .48194 Mtetra
.687 .758 .905 r
.7427 .48194 .74344 .48282 .74506 .48222 .74433 .48134 Mtetra
.672 .754 .912 r
.74433 .48134 .74506 .48222 .74669 .48167 .74596 .48081 Mtetra
.665 .754 .917 r
.74596 .48081 .74669 .48167 .74832 .48116 .74759 .4803 Mtetra
.664 .756 .919 r
.74759 .4803 .74832 .48116 .74995 .48065 .74922 .4798 Mtetra
.662 .758 .921 r
.74922 .4798 .74995 .48065 .75158 .48015 .75086 .47931 Mtetra
.659 .758 .923 r
.75086 .47931 .75158 .48015 .75322 .47966 .75249 .47882 Mtetra
.656 .759 .925 r
.75249 .47882 .75322 .47966 .75486 .47918 .75413 .47835 Mtetra
.654 .76 .928 r
.75413 .47835 .75486 .47918 .75649 .4787 .75577 .47789 Mtetra
.652 .762 .93 r
.75577 .47789 .75649 .4787 .75813 .47823 .75741 .47743 Mtetra
.652 .765 .932 r
.75741 .47743 .75813 .47823 .75977 .47776 .75905 .47696 Mtetra
.652 .767 .934 r
.75905 .47696 .75977 .47776 .76141 .47729 .7607 .4765 Mtetra
.653 .77 .935 r
.7607 .4765 .76141 .47729 .76306 .47681 .76234 .47603 Mtetra
.653 .773 .937 r
.76234 .47603 .76306 .47681 .7647 .47634 .76398 .47556 Mtetra
.654 .775 .938 r
.76398 .47556 .7647 .47634 .76634 .47585 .76563 .47509 Mtetra
.655 .777 .939 r
.76563 .47509 .76634 .47585 .76799 .47537 .76727 .47461 Mtetra
.656 .779 .939 r
.76727 .47461 .76799 .47537 .76963 .47488 .76892 .47413 Mtetra
.657 .781 .94 r
.76892 .47413 .76963 .47488 .77128 .47439 .77057 .47364 Mtetra
.658 .782 .94 r
.77057 .47364 .77128 .47439 .77292 .47389 .77221 .47314 Mtetra
.66 .783 .939 r
.77221 .47314 .77292 .47389 .77457 .47339 .77386 .47264 Mtetra
.662 .783 .939 r
.77386 .47264 .77457 .47339 .77622 .47289 .77551 .47213 Mtetra
.664 .783 .937 r
.77551 .47213 .77622 .47289 .77787 .47238 .77716 .47161 Mtetra
.666 .783 .936 r
.77716 .47161 .77787 .47238 .77951 .47186 .77881 .47109 Mtetra
.668 .781 .934 r
.77881 .47109 .77951 .47186 .78116 .47134 .78046 .47056 Mtetra
.67 .779 .932 r
.78046 .47056 .78116 .47134 .78281 .47081 .78211 .47002 Mtetra
.672 .777 .929 r
.78211 .47002 .78281 .47081 .78446 .47028 .78376 .46948 Mtetra
.673 .774 .926 r
.78376 .46948 .78446 .47028 .78611 .46975 .78541 .46892 Mtetra
.674 .771 .923 r
.78541 .46892 .78611 .46975 .78777 .46921 .78706 .46837 Mtetra
.672 .767 .921 r
.78706 .46837 .78777 .46921 .78942 .46868 .78871 .46783 Mtetra
.671 .763 .92 r
.78871 .46783 .78942 .46868 .79107 .46815 .79036 .46729 Mtetra
.67 .76 .918 r
.79036 .46729 .79107 .46815 .79273 .46763 .79202 .46676 Mtetra
.669 .758 .917 r
.79202 .46676 .79273 .46763 .79439 .4671 .79368 .46623 Mtetra
.668 .756 .917 r
.79368 .46623 .79439 .4671 .79604 .46658 .79533 .4657 Mtetra
.667 .755 .916 r
.79533 .4657 .79604 .46658 .7977 .46606 .79699 .46518 Mtetra
.667 .754 .915 r
.79699 .46518 .7977 .46606 .79936 .46555 .79865 .46466 Mtetra
.666 .753 .915 r
.79865 .46466 .79936 .46555 .80102 .46503 .80032 .46414 Mtetra
.665 .752 .915 r
.80032 .46414 .80102 .46503 .80269 .46452 .80198 .46363 Mtetra
.665 .751 .915 r
.80198 .46363 .80269 .46452 .80435 .46401 .80364 .46312 Mtetra
.664 .751 .915 r
.80364 .46312 .80435 .46401 .80601 .4635 .80531 .46261 Mtetra
.664 .75 .915 r
.80531 .46261 .80601 .4635 .80768 .46299 .80697 .4621 Mtetra
.663 .75 .915 r
.80697 .4621 .80768 .46299 .80935 .46249 .80864 .46159 Mtetra
.80864 .46159 .80935 .46249 .81101 .46198 .81031 .46109 Mtetra
.662 .75 .915 r
.81031 .46109 .81101 .46198 .81268 .46148 .81198 .46058 Mtetra
.662 .749 .915 r
.81198 .46058 .81268 .46148 .81435 .46098 .81365 .46008 Mtetra
.661 .75 .916 r
.81365 .46008 .81435 .46098 .81602 .46048 .81532 .45958 Mtetra
.66 .75 .916 r
.81532 .45958 .81602 .46048 .8177 .45998 .817 .45909 Mtetra
.659 .75 .917 r
.817 .45909 .8177 .45998 .81937 .45949 .81867 .45859 Mtetra
.659 .751 .918 r
.81867 .45859 .81937 .45949 .82105 .45899 .82035 .4581 Mtetra
.658 .751 .919 r
.82035 .4581 .82105 .45899 .82272 .4585 .82202 .45762 Mtetra
.656 .752 .921 r
.82202 .45762 .82272 .4585 .8244 .45801 .8237 .45714 Mtetra
.655 .753 .922 r
.8237 .45714 .8244 .45801 .82608 .45753 .82538 .45666 Mtetra
.654 .755 .924 r
.82538 .45666 .82608 .45753 .82776 .45705 .82707 .45619 Mtetra
.655 .758 .926 r
.82707 .45619 .82776 .45705 .82944 .45656 .82875 .45571 Mtetra
.656 .76 .927 r
.82875 .45571 .82944 .45656 .83112 .45607 .83043 .45522 Mtetra
.656 .762 .928 r
.83043 .45522 .83112 .45607 .8328 .45558 .83211 .45474 Mtetra
.657 .764 .929 r
.83211 .45474 .8328 .45558 .83448 .45508 .8338 .45425 Mtetra
.657 .766 .93 r
.8338 .45425 .83448 .45508 .83617 .45458 .83548 .45375 Mtetra
.658 .767 .93 r
.83548 .45375 .83617 .45458 .83785 .45408 .83717 .45326 Mtetra
.659 .768 .931 r
.83717 .45326 .83785 .45408 .83954 .45358 .83885 .45275 Mtetra
.659 .77 .931 r
.83885 .45275 .83954 .45358 .84122 .45307 .84054 .45225 Mtetra
.66 .77 .931 r
.84054 .45225 .84122 .45307 .84291 .45256 .84223 .45174 Mtetra
.661 .771 .931 r
.84223 .45174 .84291 .45256 .8446 .45205 .84392 .45123 Mtetra
.661 .772 .931 r
.84392 .45123 .8446 .45205 .84629 .45154 .84561 .45072 Mtetra
.662 .772 .931 r
.84561 .45072 .84629 .45154 .84797 .45102 .8473 .4502 Mtetra
.663 .773 .931 r
.8473 .4502 .84797 .45102 .84966 .4505 .84899 .44968 Mtetra
.664 .773 .931 r
.84899 .44968 .84966 .4505 .85135 .44998 .85068 .44916 Mtetra
.665 .774 .931 r
.85068 .44916 .85135 .44998 .85304 .44945 .85237 .44863 Mtetra
.667 .775 .93 r
.85237 .44863 .85304 .44945 .85474 .44891 .85406 .44809 Mtetra
.669 .776 .929 r
.85406 .44809 .85474 .44891 .85643 .44836 .85575 .44754 Mtetra
.67 .777 .93 r
.85575 .44754 .85643 .44836 .85812 .44781 .85744 .44699 Mtetra
.685 .782 .924 r
.85744 .44699 .85812 .44781 .8598 .44715 .85913 .44638 Mtetra
.704 .8 .924 r
.85913 .44638 .8598 .44715 .86147 .44636 .86081 .44568 Mtetra
.654 .809 .958 r
.86081 .44568 .86147 .44636 .86317 .44588 .86251 .44516 Mtetra
.475 .717 .976 r
.86251 .44516 .86317 .44588 .86497 .44637 .86426 .44517 Mtetra
.2 .431 .86 r
.86426 .44517 .86497 .44637 .86707 .44962 .86613 .44623 Mtetra
.374 .347 .699 r
.86613 .44623 .86707 .44962 .88902 .64179 .86809 .44816 Mtetra
.568 .364 .564 r
.86809 .44816 .88902 .64179 .89165 .64906 .8701 .45058 Mtetra
.572 .366 .564 r
.8701 .45058 .89165 .64906 .89353 .64917 .87187 .4506 Mtetra
.573 .367 .564 r
.87187 .4506 .89353 .64917 .89531 .64827 .87351 .44952 Mtetra
.574 .368 .564 r
.87351 .44952 .89531 .64827 .89705 .6471 .87515 .44832 Mtetra
.573 .367 .564 r
.87515 .44832 .89705 .6471 .89886 .64655 .87685 .4477 Mtetra
.87685 .4477 .89886 .64655 .90068 .64599 .87855 .4471 Mtetra
.87855 .4471 .90068 .64599 .90249 .64545 .88026 .44652 Mtetra
.88026 .44652 .90249 .64545 .90431 .64494 .88197 .44598 Mtetra
.88197 .44598 .90431 .64494 .90614 .64446 .88368 .44546 Mtetra
.572 .367 .564 r
.88368 .44546 .90614 .64446 .90797 .644 .8854 .44498 Mtetra
.8854 .44498 .90797 .644 .9098 .64357 .88713 .44453 Mtetra
.88713 .44453 .9098 .64357 .91164 .64315 .88885 .44409 Mtetra
.88885 .44409 .91164 .64315 .91349 .64292 .8906 .44384 Mtetra
.571 .366 .564 r
.8906 .44384 .91349 .64292 .91541 .64317 .89241 .44413 Mtetra
.572 .367 .564 r
.89241 .44413 .91541 .64317 .91724 .64267 .89414 .44371 Mtetra
.575 .369 .564 r
.89414 .44371 .91724 .64267 .91882 .64002 .89568 .44154 Mtetra
.577 .37 .564 r
.89568 .44154 .91882 .64002 .89841 .44493 .89705 .43797 Mtetra
.667 .48 .623 r
.89705 .43797 .89841 .44493 .89934 .43746 .89855 .43546 Mtetra
.755 .643 .737 r
.89855 .43546 .89934 .43746 .90079 .43464 .90014 .4338 Mtetra
.7 .787 .918 r
.90014 .4338 .90079 .43464 .90248 .43379 .90184 .43311 Mtetra
.63 .804 .966 r
.90184 .43311 .90248 .43379 .90421 .43338 .90357 .43267 Mtetra
.62 .79 .964 r
.90357 .43267 .90421 .43338 .90596 .43306 .90531 .43226 Mtetra
.702 .798 .925 r
.90531 .43226 .90596 .43306 .90765 .43225 .90701 .43156 Mtetra
.659 .814 .958 r
.90701 .43156 .90765 .43225 .90937 .43172 .90874 .43102 Mtetra
.538 .756 .977 r
.90874 .43102 .90937 .43172 .91118 .43189 .9105 .43085 Mtetra
.219 .479 .89 r
.9105 .43085 .91118 .43189 .91328 .43453 .9124 .43173 Mtetra
.377 .375 .73 r
.9124 .43173 .91328 .43453 .91746 .45441 .91438 .43334 Mtetra
.546 .364 .585 r
.91438 .43334 .91746 .45441 .941 .63506 .91643 .4354 Mtetra
.573 .367 .564 r
.91643 .4354 .941 .63506 .94291 .63504 .91811 .43441 Mtetra
.91811 .43441 .94291 .63504 .94469 .63402 .91978 .4334 Mtetra
.571 .366 .564 r
.91978 .4334 .94469 .63402 .9465 .63317 .92164 .43384 Mtetra
.203 .109 .519 r
.92164 .43384 .9465 .63317 .94859 .63467 .94688 .62534 Mtetra
.264 .198 .593 r
.94688 .62534 .94859 .63467 .95064 .63579 .94975 .63316 Mtetra
.243 .307 .731 r
.94975 .63316 .95064 .63579 .95263 .63637 .95195 .63547 Mtetra
.533 .711 .954 r
.95195 .63547 .95263 .63637 .95451 .63606 .95385 .63538 Mtetra
.652 .826 .967 r
.95385 .63538 .95451 .63606 .95636 .63554 .9557 .63481 Mtetra
.692 .826 .947 r
.9557 .63481 .95636 .63554 .95822 .635 .95753 .63409 Mtetra
.468 .677 .956 r
.95753 .63409 .95822 .635 .96015 .63512 .95947 .6342 Mtetra
.606 .744 .942 r
.95947 .6342 .96015 .63512 .96204 .63479 .96135 .63386 Mtetra
.792 .809 .866 r
.96135 .63386 .96204 .63479 .9638 .63351 .96312 .63256 Mtetra
.979 .775 .561 r
.96312 .63256 .9638 .63351 .96488 .62688 .96419 .62588 Mtetra
.975 .669 .323 r
.96419 .62588 .96488 .62688 .94127 .42753 .94061 .4265 Mtetra
.96 .778 .613 r
.94061 .4265 .94127 .42753 .94244 .42256 .94179 .42156 Mtetra
.753 .771 .867 r
.94179 .42156 .94244 .42256 .94413 .42154 .94347 .42054 Mtetra
.625 .719 .914 r
.94347 .42054 .94413 .42154 .94589 .42119 .94524 .42018 Mtetra
.543 .679 .927 r
.94524 .42018 .94589 .42119 .9477 .42114 .94705 .42013 Mtetra
.748 .767 .869 r
.94705 .42013 .9477 .42114 .94939 .42016 .94874 .41915 Mtetra
.679 .741 .897 r
.94874 .41915 .94939 .42016 .95113 .41956 .95048 .41854 Mtetra
.48 .642 .928 r
.95048 .41854 .95113 .41956 .95298 .41973 .95233 .4187 Mtetra
.777 .369 0 r
.95233 .4187 .95298 .41973 .95554 .4253 .95488 .42421 Mtetra
.97 .655 .291 r
.95488 .42421 .95554 .4253 .98388 .62441 .9832 .62344 Mtetra
.686 .254 0 r
.9832 .62344 .98388 .62441 .98639 .62864 .98571 .6277 Mtetra
.311 .525 .901 r
.37902 .78815 .37993 .7893 .38141 .78959 .3805 .7887 Mtetra
.66 .733 .903 r
.3805 .7887 .38141 .78959 .38294 .78899 .38202 .78825 Mtetra
.812 .779 .822 r
.38202 .78825 .38294 .78899 .3845 .78761 .38358 .78681 Mtetra
.903 .736 .665 r
.38358 .78681 .3845 .78761 .38611 .78486 .38527 .7819 Mtetra
.934 .683 .536 r
.38527 .7819 .38611 .78486 .38783 .77894 .39401 .59311 Mtetra
.583 .375 .565 r
.39401 .59311 .38783 .77894 .3963 .59388 .39567 .587 Mtetra
.629 .454 .628 r
.39567 .587 .3963 .59388 .39789 .58958 .39714 .58579 Mtetra
.616 .482 .676 r
.39714 .58579 .39789 .58958 .39939 .58745 .39858 .58533 Mtetra
.589 .532 .759 r
.39858 .58533 .39939 .58745 .40086 .58613 .40001 .58526 Mtetra
.634 .72 .909 r
.40001 .58526 .40086 .58613 .40231 .58553 .40144 .58494 Mtetra
.609 .785 .965 r
.40144 .58494 .40231 .58553 .40375 .58522 .40288 .58463 Mtetra
.606 .785 .967 r
.40288 .58463 .40375 .58522 .40518 .58505 .40432 .58433 Mtetra
.647 .76 .932 r
.40432 .58433 .40518 .58505 .40663 .58467 .40576 .58395 Mtetra
.658 .761 .926 r
.40576 .58395 .40663 .58467 .40807 .58425 .40721 .58352 Mtetra
.666 .762 .922 r
.40721 .58352 .40807 .58425 .40952 .5838 .40866 .58307 Mtetra
.672 .763 .918 r
.40866 .58307 .40952 .5838 .41096 .58334 .4101 .58259 Mtetra
.677 .761 .914 r
.4101 .58259 .41096 .58334 .41241 .58284 .41155 .5821 Mtetra
.681 .763 .913 r
.41155 .5821 .41241 .58284 .41386 .5823 .413 .58158 Mtetra
.683 .771 .918 r
.413 .58158 .41386 .5823 .41532 .58166 .41446 .58106 Mtetra
.682 .803 .939 r
.41446 .58106 .41532 .58166 .41678 .581 .41591 .58054 Mtetra
.675 .839 .962 r
.41591 .58054 .41678 .581 .41823 .58037 .41736 .58001 Mtetra
.667 .87 .976 r
.41736 .58001 .41823 .58037 .41969 .57968 .41882 .57948 Mtetra
.621 .904 .985 r
.41882 .57948 .41969 .57968 .42115 .57912 .42027 .57896 Mtetra
.583 .902 .983 r
.42027 .57896 .42115 .57912 .42259 .57883 .42173 .57848 Mtetra
.579 .851 .995 r
.42173 .57848 .42259 .57883 .42401 .5795 .42318 .57813 Mtetra
.631 .627 .829 r
.42318 .57813 .42401 .5795 .42541 .58095 .42463 .57782 Mtetra
.61 .497 .699 r
.42463 .57782 .42541 .58095 .42679 .58338 .42608 .57752 Mtetra
.62 .456 .638 r
.42608 .57752 .42679 .58338 .42823 .58328 .42755 .57671 Mtetra
.607 .441 .631 r
.42755 .57671 .42823 .58328 .42971 .58238 .42901 .57607 Mtetra
.58 .423 .633 r
.42901 .57607 .42971 .58238 .43115 .58237 .43045 .57604 Mtetra
.32 .234 .6 r
.43045 .57604 .43115 .58237 .42767 .76431 .43181 .57945 Mtetra
0 0 .349 r
.43181 .57945 .42767 .76431 .42897 .77278 .42817 .76814 Mtetra
0 0 .384 r
.42817 .76814 .42897 .77278 .43044 .77539 .42955 .77387 Mtetra
.347 .476 .848 r
.42955 .77387 .43044 .77539 .43196 .77572 .43107 .77458 Mtetra
.647 .682 .869 r
.43107 .77458 .43196 .77572 .43351 .77532 .43262 .77418 Mtetra
.715 .703 .837 r
.43262 .77418 .43351 .77532 .43506 .77465 .43417 .77338 Mtetra
.657 .664 .846 r
.43417 .77338 .43506 .77465 .43661 .77432 .43572 .77292 Mtetra
.637 .639 .836 r
.43572 .77292 .43661 .77432 .43815 .77397 .43727 .77257 Mtetra
.644 .641 .832 r
.43727 .77257 .43815 .77397 .43971 .77337 .43882 .77217 Mtetra
.671 .68 .85 r
.43882 .77217 .43971 .77337 .44128 .77184 .44037 .77164 Mtetra
.633 .912 .981 r
.44037 .77164 .44128 .77184 .44288 .76947 .44193 .77105 Mtetra
.352 0 .166 r
.44193 .77105 .44288 .76947 .44449 .7662 .44349 .77045 Mtetra
.545 .265 .441 r
.44349 .77045 .44449 .7662 .44606 .76509 .44503 .77036 Mtetra
.545 .279 .463 r
.44503 .77036 .44606 .76509 .4476 .76513 .44658 .77018 Mtetra
.5 .236 .445 r
.44658 .77018 .4476 .76513 .44916 .76442 .44814 .76939 Mtetra
.126 0 .302 r
.44814 .76939 .44916 .76442 .45437 .58738 .44977 .76549 Mtetra
0 0 .331 r
.44977 .76549 .45437 .58738 .45614 .57223 .4552 .57647 Mtetra
.752 .726 .198 r
.4552 .57647 .45614 .57223 .45767 .56878 .45682 .56878 Mtetra
.898 .931 .829 r
.45682 .56878 .45767 .56878 .45916 .56762 .45832 .56702 Mtetra
.679 .805 .943 r
.45832 .56702 .45916 .56762 .46063 .5673 .45979 .5665 Mtetra
.554 .714 .947 r
.45979 .5665 .46063 .5673 .4621 .56726 .46126 .56639 Mtetra
.623 .719 .915 r
.46126 .56639 .4621 .56726 .46357 .567 .46273 .5661 Mtetra
.655 .721 .897 r
.46273 .5661 .46357 .567 .46504 .56657 .46421 .56568 Mtetra
.656 .726 .9 r
.46421 .56568 .46504 .56657 .46652 .56608 .46568 .56526 Mtetra
.671 .746 .907 r
.46568 .56526 .46652 .56608 .468 .56537 .46716 .56478 Mtetra
.673 .807 .947 r
.46716 .56478 .468 .56537 .46948 .56466 .46864 .56428 Mtetra
.643 .861 .982 r
.46864 .56428 .46948 .56466 .47096 .56419 .47012 .5638 Mtetra
.593 .846 .992 r
.47012 .5638 .47096 .56419 .47243 .5646 .4716 .56343 Mtetra
.629 .66 .861 r
.4716 .56343 .47243 .5646 .47388 .56593 .47308 .56313 Mtetra
.612 .511 .715 r
.47308 .56313 .47388 .56593 .47532 .56823 .47456 .56283 Mtetra
.618 .46 .645 r
.47456 .56283 .47532 .56823 .47679 .5689 .47604 .56211 Mtetra
.609 .441 .629 r
.47604 .56211 .47679 .5689 .47829 .56792 .47753 .56139 Mtetra
.587 .427 .631 r
.47753 .56139 .47829 .56792 .47977 .56765 .47901 .5612 Mtetra
.425 .311 .619 r
.47901 .5612 .47977 .56765 .47898 .74395 .48046 .56361 Mtetra
0 0 .365 r
.48046 .56361 .47898 .74395 .48036 .7583 .47956 .75151 Mtetra
0 0 .405 r
.47956 .75151 .48036 .7583 .48189 .76131 .48102 .75949 Mtetra
.178 .331 .781 r
.48102 .75949 .48189 .76131 .48345 .76209 .48258 .76083 Mtetra
.611 .651 .865 r
.48258 .76083 .48345 .76209 .48503 .76183 .48415 .76059 Mtetra
.699 .687 .834 r
.48415 .76059 .48503 .76183 .48661 .76106 .48573 .75987 Mtetra
.699 .694 .842 r
.48573 .75987 .48661 .76106 .4882 .75957 .48731 .75916 Mtetra
.682 .87 .97 r
.48731 .75916 .4882 .75957 .48979 .75727 .48889 .75854 Mtetra
.272 0 .055 r
.48889 .75854 .48979 .75727 .4914 .75404 .49047 .75789 Mtetra
.53 .243 .424 r
.49047 .75789 .4914 .75404 .49299 .75214 .49205 .75767 Mtetra
.548 .284 .467 r
.49205 .75767 .49299 .75214 .49456 .75214 .49363 .75751 Mtetra
.512 .25 .455 r
.49363 .75751 .49456 .75214 .49614 .75152 .49522 .75681 Mtetra
.27 .043 .373 r
.49522 .75681 .49614 .75152 .49781 .73941 .49682 .75357 Mtetra
.97 .711 .485 r
.49682 .75357 .49781 .73941 .50067 .5591 .4998 .56536 Mtetra
0 0 0 r
.4998 .56536 .50067 .5591 .50219 .55533 .50136 .55552 Mtetra
.935 .942 .774 r
.50136 .55552 .50219 .55533 .5037 .55377 .50287 .55329 Mtetra
.697 .847 .955 r
.50287 .55329 .5037 .55377 .5052 .55321 .50437 .55268 Mtetra
.526 .782 .991 r
.50437 .55268 .5052 .55321 .50669 .55295 .50587 .55251 Mtetra
.533 .812 .997 r
.50587 .55251 .50669 .55295 .50819 .55265 .50736 .55227 Mtetra
.607 .859 .991 r
.50736 .55227 .50819 .55265 .50969 .55221 .50886 .55185 Mtetra
.602 .862 .992 r
.50886 .55185 .50969 .55221 .51119 .55178 .51037 .55143 Mtetra
.613 .869 .991 r
.51037 .55143 .51119 .55178 .51269 .55135 .51187 .55099 Mtetra
.63 .868 .987 r
.51187 .55099 .51269 .55135 .51419 .55092 .51337 .55051 Mtetra
.639 .857 .982 r
.51337 .55051 .51419 .55092 .5157 .55049 .51487 .55004 Mtetra
.639 .843 .979 r
.51487 .55004 .5157 .55049 .5172 .55005 .51638 .54958 Mtetra
.633 .836 .978 r
.51638 .54958 .5172 .55005 .5187 .54961 .51788 .54914 Mtetra
.629 .838 .98 r
.51788 .54914 .5187 .54961 .52021 .54916 .51939 .54871 Mtetra
.629 .843 .982 r
.51939 .54871 .52021 .54916 .52171 .54871 .5209 .54828 Mtetra
.63 .847 .983 r
.5209 .54828 .52171 .54871 .52322 .54826 .5224 .54784 Mtetra
.63 .849 .983 r
.5224 .54784 .52322 .54826 .52473 .54781 .52391 .54739 Mtetra
.63 .851 .984 r
.52391 .54739 .52473 .54781 .52624 .54736 .52542 .54694 Mtetra
.631 .852 .984 r
.52542 .54694 .52624 .54736 .52775 .5469 .52693 .54648 Mtetra
.632 .853 .984 r
.52693 .54648 .52775 .5469 .52926 .54644 .52844 .54602 Mtetra
.633 .854 .984 r
.52844 .54602 .52926 .54644 .53077 .54598 .52995 .54556 Mtetra
.634 .855 .983 r
.52995 .54556 .53077 .54598 .53228 .54551 .53147 .5451 Mtetra
.635 .855 .983 r
.53147 .5451 .53228 .54551 .53379 .54504 .53298 .54463 Mtetra
.637 .856 .983 r
.53298 .54463 .53379 .54504 .53531 .54457 .5345 .54415 Mtetra
.639 .857 .982 r
.5345 .54415 .53531 .54457 .53682 .54408 .53601 .54367 Mtetra
.64 .858 .982 r
.53601 .54367 .53682 .54408 .53834 .5436 .53753 .54319 Mtetra
.647 .86 .98 r
.53753 .54319 .53834 .5436 .53985 .54304 .53904 .54269 Mtetra
.641 .876 .985 r
.53904 .54269 .53985 .54304 .54137 .54243 .54056 .54217 Mtetra
.604 .892 .989 r
.54056 .54217 .54137 .54243 .54289 .54201 .54208 .54168 Mtetra
.583 .868 .995 r
.54208 .54168 .54289 .54201 .54441 .54216 .5436 .54127 Mtetra
.625 .722 .916 r
.5436 .54127 .54441 .54216 .54594 .54324 .54512 .54096 Mtetra
.618 .542 .747 r
.54512 .54096 .54594 .54324 .54747 .54509 .54664 .54066 Mtetra
.605 .464 .663 r
.54664 .54066 .54747 .54509 .54902 .547 .54816 .54029 Mtetra
.599 .435 .63 r
.54816 .54029 .54902 .547 .55054 .54695 .54969 .53982 Mtetra
.599 .431 .626 r
.54969 .53982 .55054 .54695 .55207 .54604 .55121 .53931 Mtetra
.6 .435 .63 r
.55121 .53931 .55207 .54604 .55359 .54515 .55273 .53882 Mtetra
.6 .438 .634 r
.55273 .53882 .55359 .54515 .55512 .5447 .55426 .53836 Mtetra
.55426 .53836 .55512 .5447 .55664 .54426 .55579 .5379 Mtetra
.599 .438 .634 r
.55579 .5379 .55664 .54426 .55817 .54383 .55731 .53745 Mtetra
.599 .437 .634 r
.55731 .53745 .55817 .54383 .5597 .54343 .55884 .537 Mtetra
.599 .437 .633 r
.55884 .537 .5597 .54343 .56124 .54303 .56037 .53656 Mtetra
.56037 .53656 .56124 .54303 .56277 .5426 .5619 .5361 Mtetra
.6 .437 .633 r
.5619 .5361 .56277 .5426 .5643 .54212 .56343 .53564 Mtetra
.599 .437 .633 r
.56343 .53564 .5643 .54212 .56583 .54165 .56496 .53517 Mtetra
.606 .442 .633 r
.56496 .53517 .56583 .54165 .56736 .54083 .56649 .53456 Mtetra
.615 .449 .635 r
.56649 .53456 .56736 .54083 .56889 .53964 .56802 .53376 Mtetra
.597 .44 .64 r
.56802 .53376 .56889 .53964 .57043 .53938 .56956 .5334 Mtetra
.516 .383 .637 r
.56956 .5334 .57043 .53938 .57202 .54297 .57111 .53448 Mtetra
0 0 .455 r
.57111 .53448 .57202 .54297 .57628 .7305 .57279 .54391 Mtetra
.006 0 .418 r
.57279 .54391 .57628 .7305 .57797 .73476 .5771 .73226 Mtetra
0 .112 .643 r
.5771 .73226 .57797 .73476 .57963 .73619 .57878 .73494 Mtetra
.564 .636 .881 r
.57878 .73494 .57963 .73619 .58127 .73601 .58042 .7349 Mtetra
.686 .709 .865 r
.58042 .7349 .58127 .73601 .5829 .73545 .58205 .73427 Mtetra
.704 .704 .847 r
.58205 .73427 .5829 .73545 .58453 .73486 .58368 .73352 Mtetra
.642 .657 .849 r
.58368 .73352 .58453 .73486 .58617 .73458 .58531 .73312 Mtetra
.642 .64 .832 r
.58531 .73312 .58617 .73458 .58781 .7343 .58695 .73271 Mtetra
.641 .624 .817 r
.58695 .73271 .58781 .7343 .58944 .73398 .58859 .7323 Mtetra
.64 .613 .807 r
.58859 .7323 .58944 .73398 .59108 .73357 .59022 .73188 Mtetra
.641 .611 .805 r
.59022 .73188 .59108 .73357 .59272 .73315 .59186 .73146 Mtetra
.641 .612 .805 r
.59186 .73146 .59272 .73315 .59436 .73271 .5935 .73103 Mtetra
.642 .613 .806 r
.5935 .73103 .59436 .73271 .596 .73228 .59514 .7306 Mtetra
.59514 .7306 .596 .73228 .59764 .73185 .59679 .73017 Mtetra
.642 .614 .806 r
.59679 .73017 .59764 .73185 .59929 .73142 .59843 .72973 Mtetra
.643 .614 .806 r
.59843 .72973 .59929 .73142 .60093 .73098 .60007 .7293 Mtetra
.60007 .7293 .60093 .73098 .60257 .73054 .60172 .72886 Mtetra
.60172 .72886 .60257 .73054 .60422 .7301 .60336 .72842 Mtetra
.643 .615 .806 r
.60336 .72842 .60422 .7301 .60587 .72966 .60501 .72798 Mtetra
.643 .615 .807 r
.60501 .72798 .60587 .72966 .60751 .72922 .60666 .72754 Mtetra
.642 .615 .807 r
.60666 .72754 .60751 .72922 .60916 .72878 .60831 .72711 Mtetra
.641 .615 .808 r
.60831 .72711 .60916 .72878 .61081 .72836 .60996 .72669 Mtetra
.60996 .72669 .61081 .72836 .61246 .72792 .61161 .72626 Mtetra
.63 .611 .812 r
.61161 .72626 .61246 .72792 .61411 .72749 .61326 .72591 Mtetra
.581 .596 .832 r
.61326 .72591 .61411 .72749 .61577 .72718 .61492 .72583 Mtetra
.65 .66 .846 r
.61492 .72583 .61577 .72718 .61742 .72661 .61658 .72538 Mtetra
.778 .72 .798 r
.61658 .72538 .61742 .72661 .61905 .72546 .61821 .72396 Mtetra
.899 .713 .642 r
.61821 .72396 .61905 .72546 .62064 .72256 .61973 .71856 Mtetra
.958 .686 .478 r
.61973 .71856 .62064 .72256 .62214 .71658 .61613 .5255 Mtetra
.581 .373 .564 r
.61613 .5255 .62214 .71658 .61852 .52719 .61755 .51996 Mtetra
.622 .448 .625 r
.61755 .51996 .61852 .52719 .61996 .52257 .6191 .51882 Mtetra
.615 .485 .681 r
.6191 .51882 .61996 .52257 .62147 .52035 .62066 .51837 Mtetra
.595 .552 .777 r
.62066 .51837 .62147 .52035 .62301 .51906 .62223 .51825 Mtetra
.626 .747 .934 r
.62223 .51825 .62301 .51906 .62458 .51851 .6238 .51791 Mtetra
.586 .792 .977 r
.6238 .51791 .62458 .51851 .62615 .51824 .62537 .51761 Mtetra
.594 .788 .973 r
.62537 .51761 .62615 .51824 .62772 .51806 .62694 .51731 Mtetra
.648 .769 .937 r
.62694 .51731 .62772 .51806 .62929 .51763 .62851 .51688 Mtetra
.663 .774 .932 r
.62851 .51688 .62929 .51763 .63086 .51715 .63008 .5164 Mtetra
.677 .776 .925 r
.63008 .5164 .63086 .51715 .63242 .51663 .63165 .51586 Mtetra
.691 .778 .918 r
.63165 .51586 .63242 .51663 .63399 .51604 .63321 .51527 Mtetra
.698 .779 .914 r
.63321 .51527 .63399 .51604 .63555 .5154 .63478 .51464 Mtetra
.703 .783 .914 r
.63478 .51464 .63555 .5154 .63711 .5147 .63634 .514 Mtetra
.71 .798 .919 r
.63634 .514 .63711 .5147 .63867 .51376 .63791 .51332 Mtetra
.691 .871 .966 r
.63791 .51332 .63867 .51376 .64023 .513 .63948 .51267 Mtetra
.647 .895 .983 r
.63948 .51267 .64023 .513 .64181 .5126 .64105 .51209 Mtetra
.615 .83 .982 r
.64105 .51209 .64181 .5126 .64343 .51344 .64262 .51169 Mtetra
.632 .593 .792 r
.64262 .51169 .64343 .51344 .64508 .51509 .6442 .51132 Mtetra
.61 .482 .681 r
.6442 .51132 .64508 .51509 .64677 .51778 .64578 .51093 Mtetra
.617 .447 .629 r
.64578 .51093 .64677 .51778 .64834 .51686 .64734 .50997 Mtetra
.603 .437 .629 r
.64734 .50997 .64834 .51686 .6499 .51593 .64892 .50936 Mtetra
.571 .417 .633 r
.64892 .50936 .6499 .51593 .65151 .51634 .65052 .50951 Mtetra
.242 .183 .588 r
.65052 .50951 .65151 .51634 .66037 .70525 .65231 .51456 Mtetra
.052 0 .445 r
.65231 .51456 .66037 .70525 .6623 .71124 .66138 .70771 Mtetra
0 .008 .556 r
.66138 .70771 .6623 .71124 .66408 .71345 .66325 .71206 Mtetra
.52 .596 .871 r
.66325 .71206 .66408 .71345 .66578 .71341 .66495 .71222 Mtetra
.667 .693 .865 r
.66495 .71222 .66578 .71341 .66746 .71291 .66663 .71168 Mtetra
.721 .706 .836 r
.66663 .71168 .66746 .71291 .66913 .71216 .6683 .71078 Mtetra
.635 .651 .849 r
.6683 .71078 .66913 .71216 .67082 .71189 .66999 .71041 Mtetra
.637 .638 .834 r
.66999 .71041 .67082 .71189 .67251 .71148 .67167 .71002 Mtetra
.646 .645 .834 r
.67167 .71002 .67251 .71148 .67419 .71078 .67336 .70957 Mtetra
.592 .66 .886 r
.67336 .70957 .67419 .71078 .67583 .70931 .67506 .7094 Mtetra
.35 .826 .821 r
.67506 .7094 .67583 .70931 .67744 .70699 .67675 .70887 Mtetra
.254 0 .18 r
.67675 .70887 .67744 .70699 .67896 .70271 .6784 .70763 Mtetra
0 0 .274 r
.6784 .70763 .67896 .70271 .67223 .51183 .67987 .70208 Mtetra
.056 0 .441 r
.67987 .70208 .67223 .51183 .67355 .50517 .67294 .50775 Mtetra
0 0 0 r
.67294 .50775 .67355 .50517 .67504 .50242 .67431 .50218 Mtetra
.813 .94 .911 r
.67431 .50218 .67504 .50242 .67662 .50166 .67587 .50099 Mtetra
.624 .788 .96 r
.67587 .50099 .67662 .50166 .67822 .50145 .67747 .50061 Mtetra
.502 .69 .952 r
.67747 .50061 .67822 .50145 .67985 .50154 .67908 .50063 Mtetra
.616 .72 .92 r
.67908 .50063 .67985 .50154 .68145 .50127 .68069 .50033 Mtetra
.62 .716 .914 r
.68069 .50033 .68145 .50127 .68305 .50094 .68229 .50002 Mtetra
.619 .72 .918 r
.68229 .50002 .68305 .50094 .68466 .50058 .6839 .49971 Mtetra
.63 .736 .924 r
.6839 .49971 .68466 .50058 .68626 .50021 .68551 .49936 Mtetra
.641 .744 .923 r
.68551 .49936 .68626 .50021 .68787 .49981 .68711 .49896 Mtetra
.656 .75 .919 r
.68711 .49896 .68787 .49981 .68947 .49935 .68871 .4985 Mtetra
.682 .757 .908 r
.68871 .4985 .68947 .49935 .69106 .4988 .69031 .49793 Mtetra
.694 .758 .901 r
.69031 .49793 .69106 .4988 .69266 .49819 .69191 .49731 Mtetra
.698 .756 .897 r
.69191 .49731 .69266 .49819 .69426 .49756 .6935 .49666 Mtetra
.773 .771 .852 r
.6935 .49666 .69426 .49756 .69583 .49646 .69507 .49556 Mtetra
.727 .761 .88 r
.69507 .49556 .69583 .49646 .69742 .49567 .69666 .49476 Mtetra
.56 .7 .934 r
.69666 .49476 .69742 .49567 .69904 .49558 .69829 .49465 Mtetra
.826 .39 0 r
.69829 .49465 .69904 .49558 .70089 .49962 .70011 .49831 Mtetra
.97 .683 .427 r
.70011 .49831 .70089 .49962 .71294 .69437 .7121 .69258 Mtetra
.809 .437 0 r
.7121 .69258 .71294 .69437 .71494 .69944 .71413 .69814 Mtetra
.384 .54 .887 r
.71413 .69814 .71494 .69944 .7167 .69986 .7159 .6987 Mtetra
.663 .701 .875 r
.7159 .6987 .7167 .69986 .71841 .69921 .71761 .69818 Mtetra
.738 .75 .862 r
.71761 .69818 .71841 .69921 .72009 .69812 .71929 .69723 Mtetra
.555 .715 .947 r
.71929 .69723 .72009 .69812 .72182 .69794 .72103 .6971 Mtetra
.581 .74 .951 r
.72103 .6971 .72182 .69794 .72354 .6977 .72276 .69686 Mtetra
.735 .792 .898 r
.72276 .69686 .72354 .6977 .72524 .69683 .72445 .69599 Mtetra
.932 .78 .67 r
.72445 .69599 .72524 .69683 .72674 .69264 .72596 .6918 Mtetra
.971 .689 .436 r
.72596 .6918 .72674 .69264 .71723 .49825 .71648 .49739 Mtetra
.958 .745 .572 r
.71648 .49739 .71723 .49825 .71842 .49038 .71767 .48949 Mtetra
.83 .783 .808 r
.71767 .48949 .71842 .49038 .71997 .48877 .71922 .48787 Mtetra
.642 .735 .916 r
.71922 .48787 .71997 .48877 .72159 .48838 .72085 .48747 Mtetra
.5 .672 .941 r
.72085 .48747 .72159 .48838 .72324 .48844 .7225 .48752 Mtetra
.601 .714 .924 r
.7225 .48752 .72324 .48844 .72488 .48821 .72413 .48727 Mtetra
.642 .726 .91 r
.72413 .48727 .72488 .48821 .72651 .48783 .72576 .48687 Mtetra
.649 .725 .905 r
.72576 .48687 .72651 .48783 .72813 .48741 .72739 .48644 Mtetra
.663 .728 .897 r
.72739 .48644 .72813 .48741 .72976 .48692 .72901 .48595 Mtetra
.673 .731 .894 r
.72901 .48595 .72976 .48692 .73138 .48638 .73063 .48541 Mtetra
.678 .734 .893 r
.73063 .48541 .73138 .48638 .733 .48581 .73225 .48485 Mtetra
.68 .737 .894 r
.73225 .48485 .733 .48581 .73462 .48524 .73388 .48428 Mtetra
.681 .739 .895 r
.73388 .48428 .73462 .48524 .73624 .48465 .7355 .48371 Mtetra
.681 .742 .897 r
.7355 .48371 .73624 .48465 .73786 .48404 .73712 .48314 Mtetra
.682 .751 .903 r
.73712 .48314 .73786 .48404 .73947 .48335 .73874 .48256 Mtetra
.681 .778 .924 r
.73874 .48256 .73947 .48335 .74109 .48263 .74037 .48198 Mtetra
.674 .814 .95 r
.74037 .48198 .74109 .48263 .7427 .48194 .742 .48142 Mtetra
.655 .846 .973 r
.742 .48142 .7427 .48194 .74433 .48134 .74362 .48088 Mtetra
.64 .859 .983 r
.74362 .48088 .74433 .48134 .74596 .48081 .74525 .48035 Mtetra
.632 .861 .985 r
.74525 .48035 .74596 .48081 .74759 .4803 .74689 .47985 Mtetra
.627 .859 .986 r
.74689 .47985 .74759 .4803 .74922 .4798 .74852 .47935 Mtetra
.622 .859 .988 r
.74852 .47935 .74922 .4798 .75086 .47931 .75016 .47887 Mtetra
.616 .86 .989 r
.75016 .47887 .75086 .47931 .75249 .47882 .7518 .47839 Mtetra
.609 .86 .991 r
.7518 .47839 .75249 .47882 .75413 .47835 .75344 .47793 Mtetra
.603 .861 .992 r
.75344 .47793 .75413 .47835 .75577 .47789 .75508 .47747 Mtetra
.598 .862 .993 r
.75508 .47747 .75577 .47789 .75741 .47743 .75672 .47702 Mtetra
.594 .864 .994 r
.75672 .47702 .75741 .47743 .75905 .47696 .75836 .47657 Mtetra
.59 .866 .994 r
.75836 .47657 .75905 .47696 .7607 .4765 .76001 .47612 Mtetra
.586 .869 .994 r
.76001 .47612 .7607 .4765 .76234 .47603 .76165 .47567 Mtetra
.583 .873 .994 r
.76165 .47567 .76234 .47603 .76398 .47556 .7633 .47522 Mtetra
.58 .877 .994 r
.7633 .47522 .76398 .47556 .76563 .47509 .76495 .47475 Mtetra
.578 .88 .993 r
.76495 .47475 .76563 .47509 .76727 .47461 .76659 .47429 Mtetra
.578 .883 .992 r
.76659 .47429 .76727 .47461 .76892 .47413 .76824 .47381 Mtetra
.578 .885 .991 r
.76824 .47381 .76892 .47413 .77057 .47364 .76989 .47333 Mtetra
.58 .888 .99 r
.76989 .47333 .77057 .47364 .77221 .47314 .77154 .47283 Mtetra
.584 .89 .99 r
.77154 .47283 .77221 .47314 .77386 .47264 .77319 .47233 Mtetra
.589 .892 .989 r
.77319 .47233 .77386 .47264 .77551 .47213 .77483 .47182 Mtetra
.596 .893 .989 r
.77483 .47182 .77551 .47213 .77716 .47161 .77648 .47129 Mtetra
.605 .894 .989 r
.77648 .47129 .77716 .47161 .77881 .47109 .77813 .47075 Mtetra
.614 .893 .988 r
.77813 .47075 .77881 .47109 .78046 .47056 .77978 .4702 Mtetra
.622 .891 .988 r
.77978 .4702 .78046 .47056 .78211 .47002 .78143 .46965 Mtetra
.63 .888 .987 r
.78143 .46965 .78211 .47002 .78376 .46948 .78308 .46908 Mtetra
.636 .885 .986 r
.78308 .46908 .78376 .46948 .78541 .46892 .78473 .46852 Mtetra
.639 .881 .985 r
.78473 .46852 .78541 .46892 .78706 .46837 .78638 .46795 Mtetra
.641 .877 .985 r
.78638 .46795 .78706 .46837 .78871 .46783 .78803 .46739 Mtetra
.641 .872 .984 r
.78803 .46739 .78871 .46783 .79036 .46729 .78969 .46684 Mtetra
.642 .867 .983 r
.78969 .46684 .79036 .46729 .79202 .46676 .79134 .46629 Mtetra
.642 .863 .983 r
.79134 .46629 .79202 .46676 .79368 .46623 .793 .46575 Mtetra
.642 .859 .982 r
.793 .46575 .79368 .46623 .79533 .4657 .79466 .46521 Mtetra
.641 .857 .982 r
.79466 .46521 .79533 .4657 .79699 .46518 .79632 .46468 Mtetra
.641 .854 .981 r
.79632 .46468 .79699 .46518 .79865 .46466 .79798 .46416 Mtetra
.64 .853 .981 r
.79798 .46416 .79865 .46466 .80032 .46414 .79964 .46363 Mtetra
.639 .851 .981 r
.79964 .46363 .80032 .46414 .80198 .46363 .8013 .46312 Mtetra
.639 .85 .981 r
.8013 .46312 .80198 .46363 .80364 .46312 .80297 .4626 Mtetra
.638 .849 .981 r
.80297 .4626 .80364 .46312 .80531 .46261 .80463 .46209 Mtetra
.637 .848 .981 r
.80463 .46209 .80531 .46261 .80697 .4621 .8063 .46158 Mtetra
.636 .848 .981 r
.8063 .46158 .80697 .4621 .80864 .46159 .80797 .46107 Mtetra
.636 .847 .981 r
.80797 .46107 .80864 .46159 .81031 .46109 .80964 .46057 Mtetra
.634 .847 .981 r
.80964 .46057 .81031 .46109 .81198 .46058 .81131 .46006 Mtetra
.633 .847 .982 r
.81131 .46006 .81198 .46058 .81365 .46008 .81298 .45956 Mtetra
.631 .847 .982 r
.81298 .45956 .81365 .46008 .81532 .45958 .81466 .45907 Mtetra
.629 .847 .983 r
.81466 .45907 .81532 .45958 .817 .45909 .81633 .45858 Mtetra
.627 .847 .984 r
.81633 .45858 .817 .45909 .81867 .45859 .81801 .45809 Mtetra
.624 .848 .985 r
.81801 .45809 .81867 .45859 .82035 .4581 .81968 .45761 Mtetra
.621 .85 .986 r
.81968 .45761 .82035 .4581 .82202 .45762 .82136 .45713 Mtetra
.617 .851 .988 r
.82136 .45713 .82202 .45762 .8237 .45714 .82304 .45665 Mtetra
.613 .852 .989 r
.82304 .45665 .8237 .45714 .82538 .45666 .82472 .45619 Mtetra
.611 .854 .99 r
.82472 .45619 .82538 .45666 .82707 .45619 .82641 .45572 Mtetra
.61 .856 .99 r
.82641 .45572 .82707 .45619 .82875 .45571 .82809 .45525 Mtetra
.609 .858 .991 r
.82809 .45525 .82875 .45571 .83043 .45522 .82978 .45478 Mtetra
.608 .861 .991 r
.82978 .45478 .83043 .45522 .83211 .45474 .83146 .4543 Mtetra
.607 .864 .992 r
.83146 .4543 .83211 .45474 .8338 .45425 .83315 .45382 Mtetra
.607 .867 .992 r
.83315 .45382 .8338 .45425 .83548 .45375 .83483 .45333 Mtetra
.606 .869 .992 r
.83483 .45333 .83548 .45375 .83717 .45326 .83652 .45284 Mtetra
.607 .871 .992 r
.83652 .45284 .83717 .45326 .83885 .45275 .83821 .45234 Mtetra
.607 .872 .992 r
.83821 .45234 .83885 .45275 .84054 .45225 .8399 .45184 Mtetra
.608 .874 .992 r
.8399 .45184 .84054 .45225 .84223 .45174 .84159 .45133 Mtetra
.608 .875 .991 r
.84159 .45133 .84223 .45174 .84392 .45123 .84328 .45083 Mtetra
.609 .876 .991 r
.84328 .45083 .84392 .45123 .84561 .45072 .84497 .45031 Mtetra
.61 .877 .991 r
.84497 .45031 .84561 .45072 .8473 .4502 .84666 .4498 Mtetra
.612 .877 .991 r
.84666 .4498 .8473 .4502 .84899 .44968 .84835 .44928 Mtetra
.613 .878 .991 r
.84835 .44928 .84899 .44968 .85068 .44916 .85004 .44875 Mtetra
.615 .879 .99 r
.85004 .44875 .85068 .44916 .85237 .44863 .85173 .44822 Mtetra
.618 .88 .99 r
.85173 .44822 .85237 .44863 .85406 .44809 .85342 .44768 Mtetra
.621 .881 .989 r
.85342 .44768 .85406 .44809 .85575 .44754 .85512 .44714 Mtetra
.623 .883 .989 r
.85512 .44714 .85575 .44754 .85744 .44699 .85681 .44658 Mtetra
.631 .885 .987 r
.85681 .44658 .85744 .44699 .85913 .44638 .8585 .44601 Mtetra
.628 .897 .986 r
.8585 .44601 .85913 .44638 .86081 .44568 .86019 .44542 Mtetra
.578 .906 .979 r
.86019 .44542 .86081 .44568 .86251 .44516 .86189 .44485 Mtetra
.562 .886 .989 r
.86189 .44485 .86251 .44516 .86426 .44517 .86359 .44436 Mtetra
.619 .76 .946 r
.86359 .44436 .86426 .44517 .86613 .44623 .86531 .44399 Mtetra
.621 .555 .759 r
.86531 .44399 .86613 .44623 .86809 .44816 .86703 .44364 Mtetra
.605 .467 .666 r
.86703 .44364 .86809 .44816 .8701 .45058 .86874 .44323 Mtetra
.599 .432 .627 r
.86874 .44323 .8701 .45058 .87187 .4506 .87044 .44268 Mtetra
.598 .428 .622 r
.87044 .44268 .87187 .4506 .87351 .44952 .87214 .44209 Mtetra
.6 .432 .626 r
.87214 .44209 .87351 .44952 .87515 .44832 .87384 .4415 Mtetra
.6 .437 .632 r
.87384 .4415 .87515 .44832 .87685 .4477 .87555 .44095 Mtetra
.87555 .44095 .87685 .4477 .87855 .4471 .87725 .44041 Mtetra
.6 .438 .633 r
.87725 .44041 .87855 .4471 .88026 .44652 .87896 .43988 Mtetra
.6 .438 .634 r
.87896 .43988 .88026 .44652 .88197 .44598 .88067 .43935 Mtetra
.88067 .43935 .88197 .44598 .88368 .44546 .88238 .43883 Mtetra
.88238 .43883 .88368 .44546 .8854 .44498 .8841 .43832 Mtetra
.599 .437 .634 r
.8841 .43832 .8854 .44498 .88713 .44453 .88581 .43781 Mtetra
.599 .436 .633 r
.88581 .43781 .88713 .44453 .88885 .44409 .88753 .43732 Mtetra
.598 .435 .633 r
.88753 .43732 .88885 .44409 .8906 .44384 .88925 .43684 Mtetra
.596 .432 .63 r
.88925 .43684 .8906 .44384 .89241 .44413 .89098 .43639 Mtetra
.594 .426 .624 r
.89098 .43639 .89241 .44413 .89414 .44371 .8927 .43593 Mtetra
.597 .428 .623 r
.8927 .43593 .89414 .44371 .89568 .44154 .89442 .43539 Mtetra
.609 .448 .639 r
.89442 .43539 .89568 .44154 .89705 .43797 .89612 .43471 Mtetra
.637 .516 .7 r
.89612 .43471 .89705 .43797 .89855 .43546 .89782 .43402 Mtetra
.676 .661 .828 r
.89782 .43402 .89855 .43546 .90014 .4338 .89953 .43337 Mtetra
.606 .873 .992 r
.89953 .43337 .90014 .4338 .90184 .43311 .90125 .43286 Mtetra
.52 .887 .975 r
.90125 .43286 .90184 .43311 .90357 .43267 .90298 .43238 Mtetra
.545 .889 .983 r
.90298 .43238 .90357 .43267 .90531 .43226 .90471 .43189 Mtetra
.615 .893 .988 r
.90471 .43189 .90531 .43226 .90701 .43156 .90643 .43131 Mtetra
.564 .906 .975 r
.90643 .43131 .90701 .43156 .90874 .43102 .90815 .43074 Mtetra
.556 .897 .98 r
.90815 .43074 .90874 .43102 .9105 .43085 .90988 .43021 Mtetra
.616 .812 .976 r
.90988 .43021 .9105 .43085 .9124 .43173 .91162 .42979 Mtetra
.632 .585 .783 r
.91162 .42979 .9124 .43173 .91438 .43334 .91336 .42937 Mtetra
.617 .485 .679 r
.91336 .42937 .91438 .43334 .91643 .4354 .91509 .42884 Mtetra
.62 .452 .633 r
.91509 .42884 .91643 .4354 .91811 .43441 .91676 .42782 Mtetra
.605 .442 .634 r
.91676 .42782 .91811 .43441 .91978 .4334 .91848 .42716 Mtetra
.567 .42 .641 r
.91848 .42716 .91978 .4334 .92164 .43384 .92031 .42742 Mtetra
.308 .246 .623 r
.92031 .42742 .92164 .43384 .94688 .62534 .92269 .43217 Mtetra
.174 .089 .512 r
.92269 .43217 .94688 .62534 .94975 .63316 .94879 .63006 Mtetra
0 .087 .617 r
.94879 .63006 .94975 .63316 .95195 .63547 .95126 .63458 Mtetra
.463 .681 .959 r
.95126 .63458 .95195 .63547 .95385 .63538 .9532 .63469 Mtetra
.665 .828 .962 r
.9532 .63469 .95385 .63538 .9557 .63481 .95504 .63406 Mtetra
.728 .837 .932 r
.95504 .63406 .9557 .63481 .95753 .63409 .95685 .63319 Mtetra
.468 .681 .958 r
.95685 .63319 .95753 .63409 .95947 .6342 .95879 .63329 Mtetra
.608 .748 .944 r
.95879 .63329 .95947 .6342 .96135 .63386 .96067 .63294 Mtetra
.794 .812 .866 r
.96067 .63294 .96135 .63386 .96312 .63256 .96243 .63163 Mtetra
.979 .775 .559 r
.96243 .63163 .96312 .63256 .96419 .62588 .96351 .62491 Mtetra
.975 .669 .323 r
.96351 .62491 .96419 .62588 .94061 .4265 .93995 .42548 Mtetra
.961 .78 .613 r
.93995 .42548 .94061 .4265 .94179 .42156 .94113 .42057 Mtetra
.754 .772 .868 r
.94113 .42057 .94179 .42156 .94347 .42054 .94282 .41955 Mtetra
.625 .721 .915 r
.94282 .41955 .94347 .42054 .94524 .42018 .94459 .41918 Mtetra
.543 .681 .928 r
.94459 .41918 .94524 .42018 .94705 .42013 .9464 .41913 Mtetra
.746 .768 .871 r
.9464 .41913 .94705 .42013 .94874 .41915 .94809 .41815 Mtetra
.68 .746 .901 r
.94809 .41815 .94874 .41915 .95048 .41854 .94983 .41754 Mtetra
.487 .652 .932 r
.94983 .41754 .95048 .41854 .95233 .4187 .95167 .41767 Mtetra
.739 .327 0 r
.95167 .41767 .95233 .4187 .95488 .42421 .95415 .42262 Mtetra
.97 .655 .288 r
.95415 .42262 .95488 .42421 .9832 .62344 .98243 .62174 Mtetra
0 0 .45 r
.98243 .62174 .9832 .62344 .98571 .6277 .98499 .62635 Mtetra
.086 .482 .895 r
.3781 .78735 .37902 .78815 .3805 .7887 .37958 .78796 Mtetra
.65 .765 .933 r
.37958 .78796 .3805 .7887 .38202 .78825 .3811 .78754 Mtetra
.817 .784 .822 r
.3811 .78754 .38202 .78825 .38358 .78681 .38266 .78607 Mtetra
.912 .734 .649 r
.38266 .78607 .38358 .78681 .38527 .7819 .38439 .78031 Mtetra
.936 .685 .534 r
.38439 .78031 .38527 .7819 .39401 .59311 .39322 .59035 Mtetra
.823 .632 .645 r
.39322 .59035 .39401 .59311 .39567 .587 .39484 .58528 Mtetra
.702 .62 .762 r
.39484 .58528 .39567 .587 .39714 .58579 .3963 .58438 Mtetra
.6 .609 .832 r
.3963 .58438 .39714 .58579 .39858 .58533 .39773 .58423 Mtetra
.454 .594 .902 r
.39773 .58423 .39858 .58533 .40001 .58526 .39914 .58448 Mtetra
.606 .731 .934 r
.39914 .58448 .40001 .58526 .40144 .58494 .40058 .58423 Mtetra
.623 .757 .942 r
.40058 .58423 .40144 .58494 .40288 .58463 .40202 .58392 Mtetra
.636 .759 .936 r
.40202 .58392 .40288 .58463 .40432 .58433 .40346 .58356 Mtetra
.651 .748 .921 r
.40346 .58356 .40432 .58433 .40576 .58395 .4049 .58317 Mtetra
.664 .75 .914 r
.4049 .58317 .40576 .58395 .40721 .58352 .40635 .58273 Mtetra
.677 .748 .905 r
.40635 .58273 .40721 .58352 .40866 .58307 .4078 .58223 Mtetra
.701 .744 .885 r
.4078 .58223 .40866 .58307 .4101 .58259 .40925 .58162 Mtetra
.699 .717 .863 r
.40925 .58162 .4101 .58259 .41155 .5821 .41071 .581 Mtetra
.689 .691 .847 r
.41071 .581 .41155 .5821 .413 .58158 .41216 .58041 Mtetra
.657 .668 .849 r
.41216 .58041 .413 .58158 .41446 .58106 .41361 .57999 Mtetra
.648 .681 .867 r
.41361 .57999 .41446 .58106 .41591 .58054 .41506 .57961 Mtetra
.647 .71 .894 r
.41506 .57961 .41591 .58054 .41736 .58001 .41651 .57923 Mtetra
.664 .75 .914 r
.41651 .57923 .41736 .58001 .41882 .57948 .41796 .57879 Mtetra
.675 .777 .927 r
.41796 .57879 .41882 .57948 .42027 .57896 .41941 .5783 Mtetra
.686 .786 .927 r
.41941 .5783 .42027 .57896 .42173 .57848 .42087 .57777 Mtetra
.707 .775 .905 r
.42087 .57777 .42173 .57848 .42318 .57813 .42233 .57714 Mtetra
.701 .715 .859 r
.42233 .57714 .42318 .57813 .42463 .57782 .42379 .5765 Mtetra
.684 .656 .817 r
.42379 .5765 .42463 .57782 .42608 .57752 .42525 .57589 Mtetra
.693 .625 .776 r
.42525 .57589 .42608 .57752 .42755 .57671 .42672 .57511 Mtetra
.669 .618 .789 r
.42672 .57511 .42755 .57671 .42901 .57607 .42818 .57453 Mtetra
.598 .591 .816 r
.42818 .57453 .42901 .57607 .43045 .57604 .42963 .57439 Mtetra
0 .105 .659 r
.42963 .57439 .43045 .57604 .43181 .57945 .43102 .57619 Mtetra
.824 .536 0 r
.43102 .57619 .43181 .57945 .42817 .76814 .4323 .58257 Mtetra
0 0 .358 r
.4323 .58257 .42817 .76814 .42955 .77387 .42878 .7683 Mtetra
.49 .37 .643 r
.42878 .7683 .42955 .77387 .43107 .77458 .43028 .76961 Mtetra
.611 .463 .656 r
.43028 .76961 .43107 .77458 .43262 .77418 .43183 .76909 Mtetra
.624 .47 .653 r
.43183 .76909 .43262 .77418 .43417 .77338 .43338 .76831 Mtetra
.496 .381 .653 r
.43338 .76831 .43417 .77338 .43572 .77292 .43489 .76943 Mtetra
.428 .373 .694 r
.43489 .76943 .43572 .77292 .43727 .77257 .4364 .77069 Mtetra
.371 .442 .804 r
.4364 .77069 .43727 .77257 .43882 .77217 .43792 .77153 Mtetra
.393 .701 .983 r
.43792 .77153 .43882 .77217 .44037 .77164 .43946 .77163 Mtetra
.251 .762 .852 r
.43946 .77163 .44037 .77164 .44193 .77105 .441 .77139 Mtetra
0 0 0 r
.441 .77139 .44193 .77105 .44349 .77045 .44256 .77099 Mtetra
.209 0 0 r
.44256 .77099 .44349 .77045 .44503 .77036 .44411 .77076 Mtetra
0 0 0 r
.44411 .77076 .44503 .77036 .44658 .77018 .44566 .77039 Mtetra
.554 .933 .855 r
.44566 .77039 .44658 .77018 .44814 .76939 .44723 .76957 Mtetra
.938 .924 .77 r
.44723 .76957 .44814 .76939 .44977 .76549 .44883 .76712 Mtetra
.988 .883 .548 r
.44883 .76712 .44977 .76549 .4552 .57647 .4505 .76137 Mtetra
0 0 .353 r
.4505 .76137 .4552 .57647 .45682 .56878 .45587 .57321 Mtetra
0 0 .194 r
.45587 .57321 .45682 .56878 .45832 .56702 .45742 .56867 Mtetra
0 0 0 r
.45742 .56867 .45832 .56702 .45979 .5665 .45893 .56669 Mtetra
.796 .994 .872 r
.45893 .56669 .45979 .5665 .46126 .56639 .46042 .56544 Mtetra
.719 .73 .859 r
.46042 .56544 .46126 .56639 .46273 .5661 .4619 .5647 Mtetra
.654 .637 .82 r
.4619 .5647 .46273 .5661 .46421 .56568 .46338 .56426 Mtetra
.626 .621 .825 r
.46338 .56426 .46421 .56568 .46568 .56526 .46485 .56397 Mtetra
.628 .64 .843 r
.46485 .56397 .46568 .56526 .46716 .56478 .46633 .56367 Mtetra
.634 .674 .87 r
.46633 .56367 .46716 .56478 .46864 .56428 .4678 .56335 Mtetra
.642 .713 .899 r
.4678 .56335 .46864 .56428 .47012 .5638 .46928 .56299 Mtetra
.68 .752 .905 r
.46928 .56299 .47012 .5638 .4716 .56343 .47076 .56247 Mtetra
.697 .723 .87 r
.47076 .56247 .4716 .56343 .47308 .56313 .47225 .56186 Mtetra
.686 .667 .825 r
.47225 .56186 .47308 .56313 .47456 .56283 .47373 .56124 Mtetra
.692 .63 .782 r
.47373 .56124 .47456 .56283 .47604 .56211 .47522 .56047 Mtetra
.677 .62 .784 r
.47522 .56047 .47604 .56211 .47753 .56139 .47671 .55981 Mtetra
.618 .599 .809 r
.47671 .55981 .47753 .56139 .47901 .5612 .47819 .55956 Mtetra
.182 .345 .793 r
.47819 .55956 .47901 .5612 .48046 .56361 .47965 .56075 Mtetra
0 0 .324 r
.47965 .56075 .48046 .56361 .47956 .75151 .48107 .5651 Mtetra
0 0 .379 r
.48107 .5651 .47956 .75151 .48102 .75949 .48021 .75302 Mtetra
.252 .189 .59 r
.48021 .75302 .48102 .75949 .48258 .76083 .48173 .75723 Mtetra
.435 .375 .692 r
.48173 .75723 .48258 .76083 .48415 .76059 .48328 .75851 Mtetra
.482 .487 .786 r
.48328 .75851 .48415 .76059 .48573 .75987 .48485 .75902 Mtetra
.484 .684 .955 r
.48485 .75902 .48573 .75987 .48731 .75916 .48642 .75907 Mtetra
.308 .791 .905 r
.48642 .75907 .48731 .75916 .48889 .75854 .488 .75884 Mtetra
0 0 0 r
.488 .75884 .48889 .75854 .49047 .75789 .48958 .75842 Mtetra
.157 0 0 r
.48958 .75842 .49047 .75789 .49205 .75767 .49116 .75812 Mtetra
.069 0 0 r
.49116 .75812 .49205 .75767 .49363 .75751 .49274 .75777 Mtetra
.459 .884 .797 r
.49274 .75777 .49363 .75751 .49522 .75681 .49433 .75701 Mtetra
.929 .948 .782 r
.49433 .75701 .49522 .75681 .49682 .75357 .49593 .75474 Mtetra
.995 .87 .576 r
.49593 .75474 .49682 .75357 .4998 .56536 .49755 .74903 Mtetra
0 0 .37 r
.49755 .74903 .4998 .56536 .50136 .55552 .5005 .56014 Mtetra
.079 0 .286 r
.5005 .56014 .50136 .55552 .50287 .55329 .50202 .55612 Mtetra
.448 .144 .357 r
.50202 .55612 .50287 .55329 .50437 .55268 .50352 .5554 Mtetra
.543 .23 .387 r
.50352 .5554 .50437 .55268 .50587 .55251 .50502 .55543 Mtetra
.555 .248 .403 r
.50502 .55543 .50587 .55251 .50736 .55227 .50652 .55556 Mtetra
.529 .234 .41 r
.50652 .55556 .50736 .55227 .50886 .55185 .50802 .55539 Mtetra
.492 .206 .407 r
.50802 .55539 .50886 .55185 .51037 .55143 .50952 .55481 Mtetra
.329 .057 .34 r
.50952 .55481 .51037 .55143 .51187 .55099 .51103 .55309 Mtetra
0 0 .075 r
.51103 .55309 .51187 .55099 .51337 .55051 .51254 .55099 Mtetra
.813 .993 .752 r
.51254 .55099 .51337 .55051 .51487 .55004 .51405 .5493 Mtetra
.773 .788 .865 r
.51405 .5493 .51487 .55004 .51638 .54958 .51556 .54828 Mtetra
.666 .657 .832 r
.51556 .54828 .51638 .54958 .51788 .54914 .51706 .54778 Mtetra
.637 .636 .832 r
.51706 .54778 .51788 .54914 .51939 .54871 .51857 .54743 Mtetra
.641 .649 .843 r
.51857 .54743 .51939 .54871 .5209 .54828 .52008 .54706 Mtetra
.656 .666 .848 r
.52008 .54706 .5209 .54828 .5224 .54784 .52159 .54662 Mtetra
.657 .667 .848 r
.52159 .54662 .5224 .54784 .52391 .54739 .52309 .54618 Mtetra
.658 .668 .848 r
.52309 .54618 .52391 .54739 .52542 .54694 .5246 .54573 Mtetra
.659 .669 .849 r
.5246 .54573 .52542 .54694 .52693 .54648 .52611 .54528 Mtetra
.659 .67 .849 r
.52611 .54528 .52693 .54648 .52844 .54602 .52763 .54482 Mtetra
.66 .67 .849 r
.52763 .54482 .52844 .54602 .52995 .54556 .52914 .54436 Mtetra
.52914 .54436 .52995 .54556 .53147 .5451 .53065 .54389 Mtetra
.661 .671 .849 r
.53065 .54389 .53147 .5451 .53298 .54463 .53217 .54343 Mtetra
.662 .672 .849 r
.53217 .54343 .53298 .54463 .5345 .54415 .53368 .54296 Mtetra
.663 .672 .849 r
.53368 .54296 .5345 .54415 .53601 .54367 .5352 .54248 Mtetra
.664 .673 .849 r
.5352 .54248 .53601 .54367 .53753 .54319 .53671 .542 Mtetra
.663 .674 .85 r
.53671 .542 .53753 .54319 .53904 .54269 .53823 .54152 Mtetra
.664 .678 .854 r
.53823 .54152 .53904 .54269 .54056 .54217 .53975 .54104 Mtetra
.669 .686 .857 r
.53975 .54104 .54056 .54217 .54208 .54168 .54127 .54054 Mtetra
.679 .688 .851 r
.54127 .54054 .54208 .54168 .5436 .54127 .54278 .53998 Mtetra
.684 .666 .826 r
.54278 .53998 .5436 .54127 .54512 .54096 .5443 .53936 Mtetra
.672 .624 .792 r
.5443 .53936 .54512 .54096 .54664 .54066 .54582 .53874 Mtetra
.656 .588 .766 r
.54582 .53874 .54664 .54066 .54816 .54029 .54735 .53818 Mtetra
.643 .567 .753 r
.54735 .53818 .54816 .54029 .54969 .53982 .54887 .53768 Mtetra
.64 .563 .753 r
.54887 .53768 .54969 .53982 .55121 .53931 .55039 .53721 Mtetra
.64 .565 .755 r
.55039 .53721 .55121 .53931 .55273 .53882 .55192 .53674 Mtetra
.641 .568 .757 r
.55192 .53674 .55273 .53882 .55426 .53836 .55344 .53627 Mtetra
.638 .566 .757 r
.55344 .53627 .55426 .53836 .55579 .5379 .55497 .53582 Mtetra
.633 .564 .759 r
.55497 .53582 .55579 .5379 .55731 .53745 .5565 .53542 Mtetra
.626 .564 .765 r
.5565 .53542 .55731 .53745 .55884 .537 .55802 .53508 Mtetra
.626 .572 .774 r
.55802 .53508 .55884 .537 .56037 .53656 .55956 .53475 Mtetra
.634 .585 .782 r
.55956 .53475 .56037 .53656 .5619 .5361 .56109 .53437 Mtetra
.645 .599 .787 r
.56109 .53437 .5619 .5361 .56343 .53564 .56262 .53392 Mtetra
.648 .602 .789 r
.56262 .53392 .56343 .53564 .56496 .53517 .56415 .53346 Mtetra
.663 .609 .784 r
.56415 .53346 .56496 .53517 .56649 .53456 .56568 .53288 Mtetra
.679 .621 .783 r
.56568 .53288 .56649 .53456 .56802 .53376 .56721 .53219 Mtetra
.64 .614 .808 r
.56721 .53219 .56802 .53376 .56956 .5334 .56874 .5318 Mtetra
.432 .502 .831 r
.56874 .5318 .56956 .5334 .57111 .53448 .57029 .53235 Mtetra
0 0 .461 r
.57029 .53235 .57111 .53448 .57279 .54391 .57188 .53561 Mtetra
.969 .696 .459 r
.57188 .53561 .57279 .54391 .5771 .73226 .57614 .72316 Mtetra
.203 .137 .555 r
.57614 .72316 .5771 .73226 .57878 .73494 .57787 .73006 Mtetra
.567 .436 .662 r
.57787 .73006 .57878 .73494 .58042 .7349 .57951 .73025 Mtetra
.625 .479 .663 r
.57951 .73025 .58042 .7349 .58205 .73427 .58114 .72951 Mtetra
.636 .484 .66 r
.58114 .72951 .58205 .73427 .58368 .73352 .58277 .72855 Mtetra
.603 .459 .658 r
.58277 .72855 .58368 .73352 .58531 .73312 .5844 .72815 Mtetra
.604 .46 .658 r
.5844 .72815 .58531 .73312 .58695 .73271 .58603 .72773 Mtetra
.58603 .72773 .58695 .73271 .58859 .7323 .58767 .72732 Mtetra
.58767 .72732 .58859 .7323 .59022 .73188 .58931 .72691 Mtetra
.604 .46 .659 r
.58931 .72691 .59022 .73188 .59186 .73146 .59095 .7265 Mtetra
.59095 .7265 .59186 .73146 .5935 .73103 .59258 .72608 Mtetra
.605 .461 .659 r
.59258 .72608 .5935 .73103 .59514 .7306 .59422 .72566 Mtetra
.59422 .72566 .59514 .7306 .59679 .73017 .59587 .72524 Mtetra
.59587 .72524 .59679 .73017 .59843 .72973 .59751 .72481 Mtetra
.605 .462 .66 r
.59751 .72481 .59843 .72973 .60007 .7293 .59915 .72438 Mtetra
.606 .462 .66 r
.59915 .72438 .60007 .7293 .60172 .72886 .60079 .72394 Mtetra
.60079 .72394 .60172 .72886 .60336 .72842 .60244 .72351 Mtetra
.60244 .72351 .60336 .72842 .60501 .72798 .60408 .72307 Mtetra
.605 .462 .66 r
.60408 .72307 .60501 .72798 .60666 .72754 .60573 .72264 Mtetra
.60573 .72264 .60666 .72754 .60831 .72711 .60738 .72222 Mtetra
.604 .461 .661 r
.60738 .72222 .60831 .72711 .60996 .72669 .60903 .72182 Mtetra
.604 .462 .661 r
.60903 .72182 .60996 .72669 .61161 .72626 .61068 .72142 Mtetra
.596 .457 .662 r
.61068 .72142 .61161 .72626 .61326 .72591 .61233 .72116 Mtetra
.567 .439 .665 r
.61233 .72116 .61326 .72591 .61492 .72583 .614 .72135 Mtetra
.606 .469 .669 r
.614 .72135 .61492 .72583 .61658 .72538 .61565 .72095 Mtetra
.688 .523 .659 r
.61565 .72095 .61658 .72538 .61821 .72396 .61727 .71899 Mtetra
.956 .685 .481 r
.61727 .71899 .61821 .72396 .61973 .71856 .614 .53342 Mtetra
.592 .382 .565 r
.614 .53342 .61973 .71856 .61613 .5255 .61525 .52123 Mtetra
.732 .551 .647 r
.61525 .52123 .61613 .5255 .61755 .51996 .61675 .51818 Mtetra
.669 .607 .777 r
.61675 .51818 .61755 .51996 .6191 .51882 .6183 .51753 Mtetra
.587 .63 .861 r
.6183 .51753 .6191 .51882 .62066 .51837 .61988 .51741 Mtetra
.489 .65 .93 r
.61988 .51741 .62066 .51837 .62223 .51825 .62146 .51752 Mtetra
.602 .758 .953 r
.62146 .51752 .62223 .51825 .6238 .51791 .62303 .51723 Mtetra
.607 .777 .962 r
.62303 .51723 .6238 .51791 .62537 .51761 .6246 .51692 Mtetra
.626 .776 .952 r
.6246 .51692 .62537 .51761 .62694 .51731 .62617 .51655 Mtetra
.654 .767 .932 r
.62617 .51655 .62694 .51731 .62851 .51688 .62774 .5161 Mtetra
.669 .766 .923 r
.62774 .5161 .62851 .51688 .63008 .5164 .6293 .51559 Mtetra
.681 .765 .914 r
.6293 .51559 .63008 .5164 .63165 .51586 .63087 .51504 Mtetra
.692 .764 .907 r
.63087 .51504 .63165 .51586 .63321 .51527 .63244 .51444 Mtetra
.697 .764 .903 r
.63244 .51444 .63321 .51527 .63478 .51464 .634 .51381 Mtetra
.699 .764 .902 r
.634 .51381 .63478 .51464 .63634 .514 .63557 .51318 Mtetra
.693 .766 .907 r
.63557 .51318 .63634 .514 .63791 .51332 .63714 .51257 Mtetra
.697 .784 .918 r
.63714 .51257 .63791 .51332 .63948 .51267 .63871 .51195 Mtetra
.703 .792 .92 r
.63871 .51195 .63948 .51267 .64105 .51209 .64027 .5113 Mtetra
.72 .779 .9 r
.64027 .5113 .64105 .51209 .64262 .51169 .64184 .51057 Mtetra
.705 .708 .851 r
.64184 .51057 .64262 .51169 .6442 .51132 .64341 .50985 Mtetra
.686 .65 .808 r
.64341 .50985 .6442 .51132 .64578 .51093 .64498 .50917 Mtetra
.695 .623 .772 r
.64498 .50917 .64578 .51093 .64734 .50997 .64654 .5083 Mtetra
.662 .617 .793 r
.64654 .5083 .64734 .50997 .64892 .50936 .64812 .50773 Mtetra
.575 .578 .818 r
.64812 .50773 .64892 .50936 .65052 .50951 .64971 .50771 Mtetra
0 .069 .63 r
.64971 .50771 .65052 .50951 .65231 .51456 .6514 .51013 Mtetra
.821 .548 0 r
.6514 .51013 .65231 .51456 .66138 .70771 .65345 .5218 Mtetra
.065 0 .449 r
.65345 .5218 .66138 .70771 .66325 .71206 .66226 .70686 Mtetra
.565 .431 .657 r
.66226 .70686 .66325 .71206 .66495 .71222 .66397 .7071 Mtetra
.618 .468 .656 r
.66397 .7071 .66495 .71222 .66663 .71168 .66564 .70641 Mtetra
.622 .468 .653 r
.66564 .70641 .66663 .71168 .6683 .71078 .66731 .70562 Mtetra
.473 .37 .656 r
.66731 .70562 .6683 .71078 .66999 .71041 .66908 .70715 Mtetra
.446 .4 .713 r
.66908 .70715 .66999 .71041 .67167 .71002 .67083 .70833 Mtetra
.405 .49 .833 r
.67083 .70833 .67167 .71002 .67336 .70957 .67257 .70903 Mtetra
.335 .706 .983 r
.67257 .70903 .67336 .70957 .67506 .7094 .67428 .70915 Mtetra
.48 .859 .982 r
.67428 .70915 .67506 .7094 .67675 .70887 .67597 .70878 Mtetra
.707 .968 .934 r
.67597 .70878 .67675 .70887 .6784 .70763 .67764 .70781 Mtetra
.965 .929 .703 r
.67764 .70781 .6784 .70763 .67987 .70208 .67922 .70475 Mtetra
.848 .774 .268 r
.67922 .70475 .67987 .70208 .67294 .50775 .6806 .69727 Mtetra
.065 0 .445 r
.6806 .69727 .67294 .50775 .67431 .50218 .67375 .50592 Mtetra
.139 0 .303 r
.67375 .50592 .67431 .50218 .67587 .50099 .67522 .50257 Mtetra
.011 0 .039 r
.67522 .50257 .67587 .50099 .67747 .50061 .67676 .50086 Mtetra
.585 .938 .782 r
.67676 .50086 .67747 .50061 .67908 .50063 .67833 .49981 Mtetra
.681 .766 .915 r
.67833 .49981 .67908 .50063 .68069 .50033 .67992 .49925 Mtetra
.623 .686 .889 r
.67992 .49925 .68069 .50033 .68229 .50002 .68153 .49894 Mtetra
.59 .673 .898 r
.68153 .49894 .68229 .50002 .6839 .49971 .68314 .49877 Mtetra
.626 .718 .913 r
.68314 .49877 .6839 .49971 .68551 .49936 .68475 .49844 Mtetra
.64 .729 .913 r
.68475 .49844 .68551 .49936 .68711 .49896 .68635 .49805 Mtetra
.654 .736 .91 r
.68635 .49805 .68711 .49896 .68871 .4985 .68796 .4976 Mtetra
.682 .749 .902 r
.68796 .4976 .68871 .4985 .69031 .49793 .68955 .49703 Mtetra
.694 .752 .896 r
.68955 .49703 .69031 .49793 .69191 .49731 .69115 .49641 Mtetra
.699 .753 .894 r
.69115 .49641 .69191 .49731 .6935 .49666 .69275 .49575 Mtetra
.773 .771 .851 r
.69275 .49575 .6935 .49666 .69507 .49556 .69432 .49465 Mtetra
.727 .759 .878 r
.69432 .49465 .69507 .49556 .69666 .49476 .69591 .49385 Mtetra
.564 .699 .932 r
.69591 .49385 .69666 .49476 .69829 .49465 .69753 .49372 Mtetra
.823 .385 0 r
.69753 .49372 .69829 .49465 .70011 .49831 .69936 .49732 Mtetra
.97 .683 .428 r
.69936 .49732 .70011 .49831 .7121 .69258 .7113 .69155 Mtetra
.907 .511 .103 r
.7113 .69155 .7121 .69258 .71413 .69814 .71333 .69722 Mtetra
.256 .553 .93 r
.71333 .69722 .71413 .69814 .7159 .6987 .7151 .6978 Mtetra
.66 .753 .919 r
.7151 .6978 .7159 .6987 .71761 .69818 .71681 .69729 Mtetra
.738 .78 .886 r
.71681 .69729 .71761 .69818 .71929 .69723 .7185 .69639 Mtetra
.501 .703 .961 r
.7185 .69639 .71929 .69723 .72103 .6971 .72025 .69638 Mtetra
.512 .745 .979 r
.72025 .69638 .72103 .6971 .72276 .69686 .72198 .69628 Mtetra
.709 .85 .95 r
.72198 .69628 .72276 .69686 .72445 .69599 .72369 .69553 Mtetra
.955 .824 .676 r
.72369 .69553 .72445 .69599 .72596 .6918 .72521 .69158 Mtetra
.972 .69 .435 r
.72521 .69158 .72596 .6918 .71648 .49739 .71581 .49775 Mtetra
.994 .785 .512 r
.71581 .49775 .71648 .49739 .71767 .48949 .71693 .48865 Mtetra
.841 .795 .807 r
.71693 .48865 .71767 .48949 .71922 .48787 .71848 .48696 Mtetra
.647 .735 .913 r
.71848 .48696 .71922 .48787 .72085 .48747 .7201 .48654 Mtetra
.507 .671 .937 r
.7201 .48654 .72085 .48747 .7225 .48752 .72175 .48658 Mtetra
.606 .713 .92 r
.72175 .48658 .7225 .48752 .72413 .48727 .72339 .48632 Mtetra
.648 .726 .906 r
.72339 .48632 .72413 .48727 .72576 .48687 .72501 .48589 Mtetra
.66 .725 .897 r
.72501 .48589 .72576 .48687 .72739 .48644 .72664 .48542 Mtetra
.687 .724 .878 r
.72664 .48542 .72739 .48644 .72901 .48595 .72826 .48481 Mtetra
.695 .705 .856 r
.72826 .48481 .72901 .48595 .73063 .48541 .72987 .48413 Mtetra
.69 .681 .836 r
.72987 .48413 .73063 .48541 .73225 .48485 .73148 .48345 Mtetra
.675 .658 .825 r
.73148 .48345 .73225 .48485 .73388 .48428 .7331 .48284 Mtetra
.667 .649 .823 r
.7331 .48284 .73388 .48428 .7355 .48371 .73473 .48228 Mtetra
.665 .649 .824 r
.73473 .48228 .7355 .48371 .73712 .48314 .73635 .48173 Mtetra
.666 .653 .828 r
.73635 .48173 .73712 .48314 .73874 .48256 .73798 .48118 Mtetra
.666 .657 .832 r
.73798 .48118 .73874 .48256 .74037 .48198 .7396 .48063 Mtetra
.665 .661 .836 r
.7396 .48063 .74037 .48198 .742 .48142 .74123 .48009 Mtetra
.663 .664 .841 r
.74123 .48009 .742 .48142 .74362 .48088 .74286 .47957 Mtetra
.662 .666 .844 r
.74286 .47957 .74362 .48088 .74525 .48035 .74449 .47906 Mtetra
.66 .667 .846 r
.74449 .47906 .74525 .48035 .74689 .47985 .74613 .47856 Mtetra
.66 .669 .848 r
.74613 .47856 .74689 .47985 .74852 .47935 .74776 .47806 Mtetra
.657 .668 .848 r
.74776 .47806 .74852 .47935 .75016 .47887 .7494 .47758 Mtetra
.652 .666 .851 r
.7494 .47758 .75016 .47887 .7518 .47839 .75104 .47713 Mtetra
.637 .663 .859 r
.75104 .47713 .7518 .47839 .75344 .47793 .75269 .47675 Mtetra
.626 .674 .876 r
.75269 .47675 .75344 .47793 .75508 .47747 .75434 .47643 Mtetra
.621 .699 .9 r
.75434 .47643 .75508 .47747 .75672 .47702 .75599 .47612 Mtetra
.631 .734 .922 r
.75599 .47612 .75672 .47702 .75836 .47657 .75764 .47575 Mtetra
.64 .758 .934 r
.75764 .47575 .75836 .47657 .76001 .47612 .75929 .47533 Mtetra
.644 .768 .938 r
.75929 .47533 .76001 .47612 .76165 .47567 .76093 .4749 Mtetra
.644 .771 .941 r
.76093 .4749 .76165 .47567 .7633 .47522 .76258 .47446 Mtetra
.644 .776 .943 r
.76258 .47446 .7633 .47522 .76495 .47475 .76423 .47401 Mtetra
.645 .781 .946 r
.76423 .47401 .76495 .47475 .76659 .47429 .76588 .47356 Mtetra
.647 .787 .949 r
.76588 .47356 .76659 .47429 .76824 .47381 .76753 .4731 Mtetra
.649 .791 .95 r
.76753 .4731 .76824 .47381 .76989 .47333 .76918 .47263 Mtetra
.653 .796 .951 r
.76918 .47263 .76989 .47333 .77154 .47283 .77083 .47214 Mtetra
.657 .799 .95 r
.77083 .47214 .77154 .47283 .77319 .47233 .77248 .47163 Mtetra
.662 .8 .949 r
.77248 .47163 .77319 .47233 .77483 .47182 .77413 .47111 Mtetra
.667 .8 .946 r
.77413 .47111 .77483 .47182 .77648 .47129 .77578 .47057 Mtetra
.67 .797 .943 r
.77578 .47057 .77648 .47129 .77813 .47075 .77742 .47002 Mtetra
.675 .796 .939 r
.77742 .47002 .77813 .47075 .77978 .4702 .77907 .46946 Mtetra
.684 .794 .933 r
.77907 .46946 .77978 .4702 .78143 .46965 .78072 .46886 Mtetra
.702 .789 .919 r
.78072 .46886 .78143 .46965 .78308 .46908 .78236 .46819 Mtetra
.71 .765 .896 r
.78236 .46819 .78308 .46908 .78473 .46852 .784 .46747 Mtetra
.703 .73 .872 r
.784 .46747 .78473 .46852 .78638 .46795 .78564 .46676 Mtetra
.686 .698 .856 r
.78564 .46676 .78638 .46795 .78803 .46739 .78729 .46612 Mtetra
.673 .68 .848 r
.78729 .46612 .78803 .46739 .78969 .46684 .78894 .46554 Mtetra
.668 .674 .846 r
.78894 .46554 .78969 .46684 .79134 .46629 .7906 .46499 Mtetra
.667 .673 .846 r
.7906 .46499 .79134 .46629 .793 .46575 .79225 .46445 Mtetra
.666 .672 .846 r
.79225 .46445 .793 .46575 .79466 .46521 .79391 .4639 Mtetra
.665 .67 .845 r
.79391 .4639 .79466 .46521 .79632 .46468 .79557 .46337 Mtetra
.663 .669 .845 r
.79557 .46337 .79632 .46468 .79798 .46416 .79723 .46284 Mtetra
.663 .668 .845 r
.79723 .46284 .79798 .46416 .79964 .46363 .79889 .46232 Mtetra
.662 .668 .845 r
.79889 .46232 .79964 .46363 .8013 .46312 .80056 .4618 Mtetra
.661 .667 .845 r
.80056 .4618 .8013 .46312 .80297 .4626 .80222 .46128 Mtetra
.80222 .46128 .80297 .4626 .80463 .46209 .80389 .46077 Mtetra
.66 .666 .845 r
.80389 .46077 .80463 .46209 .8063 .46158 .80556 .46025 Mtetra
.659 .666 .845 r
.80556 .46025 .8063 .46158 .80797 .46107 .80723 .45975 Mtetra
.659 .666 .846 r
.80723 .45975 .80797 .46107 .80964 .46057 .8089 .45924 Mtetra
.658 .666 .846 r
.8089 .45924 .80964 .46057 .81131 .46006 .81057 .45874 Mtetra
.81057 .45874 .81131 .46006 .81298 .45956 .81224 .45824 Mtetra
.657 .665 .846 r
.81224 .45824 .81298 .45956 .81466 .45907 .81391 .45774 Mtetra
.656 .665 .847 r
.81391 .45774 .81466 .45907 .81633 .45858 .81559 .45725 Mtetra
.81559 .45725 .81633 .45858 .81801 .45809 .81727 .45676 Mtetra
.81727 .45676 .81801 .45809 .81968 .45761 .81894 .45627 Mtetra
.651 .662 .847 r
.81894 .45627 .81968 .45761 .82136 .45713 .82062 .45581 Mtetra
.641 .659 .853 r
.82062 .45581 .82136 .45713 .82304 .45665 .82231 .45541 Mtetra
.628 .665 .866 r
.82231 .45541 .82304 .45665 .82472 .45619 .82401 .45506 Mtetra
.625 .687 .888 r
.82401 .45506 .82472 .45619 .82641 .45572 .8257 .45473 Mtetra
.633 .72 .91 r
.8257 .45473 .82641 .45572 .82809 .45525 .8274 .45436 Mtetra
.648 .747 .922 r
.8274 .45436 .82809 .45525 .82978 .45478 .82908 .45391 Mtetra
.654 .755 .924 r
.82908 .45391 .82978 .45478 .83146 .4543 .83077 .45343 Mtetra
.656 .756 .924 r
.83077 .45343 .83146 .4543 .83315 .45382 .83246 .45295 Mtetra
.655 .756 .924 r
.83246 .45295 .83315 .45382 .83483 .45333 .83414 .45246 Mtetra
.656 .758 .925 r
.83414 .45246 .83483 .45333 .83652 .45284 .83583 .45198 Mtetra
.657 .76 .925 r
.83583 .45198 .83652 .45284 .83821 .45234 .83752 .45148 Mtetra
.658 .761 .926 r
.83752 .45148 .83821 .45234 .8399 .45184 .83921 .45099 Mtetra
.659 .763 .926 r
.83921 .45099 .8399 .45184 .84159 .45133 .8409 .45048 Mtetra
.66 .764 .926 r
.8409 .45048 .84159 .45133 .84328 .45083 .84259 .44998 Mtetra
.661 .765 .927 r
.84259 .44998 .84328 .45083 .84497 .45031 .84428 .44947 Mtetra
.662 .765 .927 r
.84428 .44947 .84497 .45031 .84666 .4498 .84597 .44895 Mtetra
.663 .766 .926 r
.84597 .44895 .84666 .4498 .84835 .44928 .84766 .44843 Mtetra
.664 .767 .926 r
.84766 .44843 .84835 .44928 .85004 .44875 .84936 .44791 Mtetra
.665 .768 .926 r
.84936 .44791 .85004 .44875 .85173 .44822 .85105 .44738 Mtetra
.667 .769 .926 r
.85105 .44738 .85173 .44822 .85342 .44768 .85274 .44684 Mtetra
.668 .77 .926 r
.85274 .44684 .85342 .44768 .85512 .44714 .85444 .4463 Mtetra
.67 .772 .926 r
.85444 .4463 .85512 .44714 .85681 .44658 .85613 .44575 Mtetra
.67 .773 .927 r
.85613 .44575 .85681 .44658 .8585 .44601 .85783 .4452 Mtetra
.67 .778 .93 r
.85783 .4452 .8585 .44601 .86019 .44542 .85952 .44464 Mtetra
.676 .79 .935 r
.85952 .44464 .86019 .44542 .86189 .44485 .86122 .44406 Mtetra
.69 .792 .929 r
.86122 .44406 .86189 .44485 .86359 .44436 .86291 .44342 Mtetra
.705 .761 .896 r
.86291 .44342 .86359 .44436 .86531 .44399 .86459 .44271 Mtetra
.693 .691 .843 r
.86459 .44271 .86531 .44399 .86703 .44364 .86627 .442 Mtetra
.673 .634 .803 r
.86627 .442 .86703 .44364 .86874 .44323 .86796 .44134 Mtetra
.655 .6 .781 r
.86796 .44134 .86874 .44323 .87044 .44268 .86966 .44075 Mtetra
.651 .595 .78 r
.86966 .44075 .87044 .44268 .87214 .44209 .87136 .4402 Mtetra
.65 .598 .783 r
.87136 .4402 .87214 .44209 .87384 .4415 .87307 .43966 Mtetra
.651 .603 .787 r
.87307 .43966 .87384 .4415 .87555 .44095 .87477 .43911 Mtetra
.65 .603 .788 r
.87477 .43911 .87555 .44095 .87725 .44041 .87648 .43858 Mtetra
.65 .603 .789 r
.87648 .43858 .87725 .44041 .87896 .43988 .87819 .43805 Mtetra
.649 .603 .789 r
.87819 .43805 .87896 .43988 .88067 .43935 .8799 .43752 Mtetra
.648 .603 .79 r
.8799 .43752 .88067 .43935 .88238 .43883 .88161 .437 Mtetra
.88161 .437 .88238 .43883 .8841 .43832 .88332 .43649 Mtetra
.647 .602 .79 r
.88332 .43649 .8841 .43832 .88581 .43781 .88504 .43598 Mtetra
.646 .601 .79 r
.88504 .43598 .88581 .43781 .88753 .43732 .88676 .43547 Mtetra
.645 .6 .789 r
.88676 .43547 .88753 .43732 .88925 .43684 .88847 .43498 Mtetra
.644 .598 .788 r
.88847 .43498 .88925 .43684 .89098 .43639 .89019 .43448 Mtetra
.64 .591 .784 r
.89019 .43448 .89098 .43639 .8927 .43593 .89192 .43401 Mtetra
.634 .588 .784 r
.89192 .43401 .8927 .43593 .89442 .43539 .89365 .43358 Mtetra
.624 .593 .798 r
.89365 .43358 .89442 .43539 .89612 .43471 .89539 .43324 Mtetra
.624 .633 .839 r
.89539 .43324 .89612 .43471 .89782 .43402 .89713 .43292 Mtetra
.626 .697 .895 r
.89713 .43292 .89782 .43402 .89953 .43337 .89888 .43257 Mtetra
.638 .772 .944 r
.89888 .43257 .89953 .43337 .90125 .43286 .90061 .43213 Mtetra
.646 .794 .953 r
.90061 .43213 .90125 .43286 .90298 .43238 .90234 .43164 Mtetra
.655 .797 .951 r
.90234 .43164 .90298 .43238 .90471 .43189 .90407 .43112 Mtetra
.658 .792 .946 r
.90407 .43112 .90471 .43189 .90643 .43131 .90579 .4306 Mtetra
.669 .809 .951 r
.90579 .4306 .90643 .43131 .90815 .43074 .90751 .43002 Mtetra
.688 .815 .944 r
.90751 .43002 .90815 .43074 .90988 .43021 .90923 .42938 Mtetra
.717 .794 .912 r
.90923 .42938 .90988 .43021 .91162 .42979 .91093 .42861 Mtetra
.707 .717 .857 r
.91093 .42861 .91162 .42979 .91336 .42937 .91263 .42783 Mtetra
.695 .658 .809 r
.91263 .42783 .91336 .42937 .91509 .42884 .91433 .42702 Mtetra
.708 .635 .773 r
.91433 .42702 .91509 .42884 .91676 .42782 .916 .42598 Mtetra
.662 .611 .787 r
.916 .42598 .91676 .42782 .91848 .42716 .91772 .42535 Mtetra
.531 .542 .811 r
.91772 .42535 .91848 .42716 .92031 .42742 .91954 .42559 Mtetra
0 0 .5 r
.91954 .42559 .92031 .42742 .92269 .43217 .92185 .42974 Mtetra
.973 .661 .305 r
.92185 .42974 .92269 .43217 .94879 .63006 .94802 .62848 Mtetra
0 0 .312 r
.94802 .62848 .94879 .63006 .95126 .63458 .95058 .63373 Mtetra
.439 .679 .965 r
.95058 .63373 .95126 .63458 .9532 .63469 .95252 .63388 Mtetra
.678 .802 .941 r
.95252 .63388 .9532 .63469 .95504 .63406 .95436 .63323 Mtetra
.738 .815 .912 r
.95436 .63323 .95504 .63406 .95685 .63319 .95617 .63229 Mtetra
.472 .683 .958 r
.95617 .63229 .95685 .63319 .95879 .63329 .95811 .63238 Mtetra
.611 .749 .943 r
.95811 .63238 .95879 .63329 .96067 .63294 .95999 .63202 Mtetra
.795 .813 .866 r
.95999 .63202 .96067 .63294 .96243 .63163 .96175 .6307 Mtetra
.98 .775 .558 r
.96175 .6307 .96243 .63163 .96351 .62491 .96282 .62395 Mtetra
.975 .669 .322 r
.96282 .62395 .96351 .62491 .93995 .42548 .93929 .42448 Mtetra
.961 .781 .613 r
.93929 .42448 .93995 .42548 .94113 .42057 .94048 .41957 Mtetra
.754 .773 .869 r
.94048 .41957 .94113 .42057 .94282 .41955 .94216 .41855 Mtetra
.625 .722 .916 r
.94216 .41855 .94282 .41955 .94459 .41918 .94393 .41819 Mtetra
.544 .682 .929 r
.94393 .41819 .94459 .41918 .9464 .41913 .94575 .41813 Mtetra
.746 .77 .872 r
.94575 .41813 .9464 .41913 .94809 .41815 .94744 .41715 Mtetra
.68 .745 .9 r
.94744 .41715 .94809 .41815 .94983 .41754 .94918 .41654 Mtetra
.49 .652 .931 r
.94918 .41654 .94983 .41754 .95167 .41767 .95102 .41666 Mtetra
.738 .323 0 r
.95102 .41666 .95167 .41767 .95415 .42262 .95349 .42153 Mtetra
.97 .655 .291 r
.95349 .42153 .95415 .42262 .98243 .62174 .98174 .62069 Mtetra
.7 .28 0 r
.98174 .62069 .98243 .62174 .98499 .62635 .98431 .62536 Mtetra
.04 .466 .88 r
.37718 .78659 .3781 .78735 .37958 .78796 .37866 .78721 Mtetra
.648 .764 .934 r
.37866 .78721 .37958 .78796 .3811 .78754 .38018 .7868 Mtetra
.814 .78 .821 r
.38018 .7868 .3811 .78754 .38266 .78607 .38174 .78534 Mtetra
.912 .735 .649 r
.38174 .78534 .38266 .78607 .38439 .78031 .38347 .77962 Mtetra
.937 .686 .534 r
.38347 .77962 .38439 .78031 .39322 .59035 .39235 .58959 Mtetra
.907 .733 .655 r
.39235 .58959 .39322 .59035 .39484 .58528 .39397 .58449 Mtetra
.753 .761 .859 r
.39397 .58449 .39484 .58528 .3963 .58438 .39543 .58359 Mtetra
.567 .718 .944 r
.39543 .58359 .3963 .58438 .39773 .58423 .39686 .58345 Mtetra
.35 .629 .957 r
.39686 .58345 .39773 .58423 .39914 .58448 .39828 .58372 Mtetra
.607 .738 .938 r
.39828 .58372 .39914 .58448 .40058 .58423 .39972 .58346 Mtetra
.632 .743 .928 r
.39972 .58346 .40058 .58423 .40202 .58392 .40116 .58313 Mtetra
.646 .743 .92 r
.40116 .58313 .40202 .58392 .40346 .58356 .4026 .58276 Mtetra
.657 .741 .911 r
.4026 .58276 .40346 .58356 .4049 .58317 .40404 .58234 Mtetra
.67 .739 .902 r
.40404 .58234 .4049 .58317 .40635 .58273 .40549 .58187 Mtetra
.682 .737 .892 r
.40549 .58187 .40635 .58273 .4078 .58223 .40694 .58135 Mtetra
.706 .737 .875 r
.40694 .58135 .4078 .58223 .40925 .58162 .4084 .58071 Mtetra
.706 .73 .869 r
.4084 .58071 .40925 .58162 .41071 .581 .40985 .58007 Mtetra
.697 .723 .87 r
.40985 .58007 .41071 .581 .41216 .58041 .41131 .57947 Mtetra
.655 .709 .887 r
.41131 .57947 .41216 .58041 .41361 .57999 .41275 .57906 Mtetra
.639 .709 .897 r
.41275 .57906 .41361 .57999 .41506 .57961 .4142 .57872 Mtetra
.636 .716 .905 r
.4142 .57872 .41506 .57961 .41651 .57923 .41565 .57838 Mtetra
.658 .732 .904 r
.41565 .57838 .41651 .57923 .41796 .57879 .4171 .57797 Mtetra
.671 .741 .903 r
.4171 .57797 .41796 .57879 .41941 .5783 .41856 .5775 Mtetra
.682 .749 .902 r
.41856 .5775 .41941 .5783 .42087 .57777 .42001 .57698 Mtetra
.703 .757 .894 r
.42001 .57698 .42087 .57777 .42233 .57714 .42147 .57636 Mtetra
.708 .76 .893 r
.42147 .57636 .42233 .57714 .42379 .5765 .42293 .57573 Mtetra
.703 .761 .896 r
.42293 .57573 .42379 .5765 .42525 .57589 .4244 .57512 Mtetra
.714 .763 .891 r
.4244 .57512 .42525 .57589 .42672 .57511 .42586 .57445 Mtetra
.686 .787 .927 r
.42586 .57445 .42672 .57511 .42818 .57453 .42732 .57391 Mtetra
.597 .779 .967 r
.42732 .57391 .42818 .57453 .42963 .57439 .42877 .57364 Mtetra
.024 .443 .87 r
.42877 .57364 .42963 .57439 .43102 .57619 .4302 .5743 Mtetra
.125 .273 .746 r
.4302 .5743 .43102 .57619 .4323 .58257 .43161 .57576 Mtetra
.423 .304 .613 r
.43161 .57576 .4323 .58257 .42878 .7683 .43299 .57826 Mtetra
.571 .365 .563 r
.43299 .57826 .42878 .7683 .43028 .76961 .43444 .5784 Mtetra
.573 .367 .563 r
.43444 .5784 .43028 .76961 .43183 .76909 .43592 .57753 Mtetra
.571 .366 .563 r
.43592 .57753 .43183 .76909 .43338 .76831 .43737 .57753 Mtetra
0 0 .38 r
.43737 .57753 .43338 .76831 .43489 .76943 .43422 .75959 Mtetra
.061 .02 .492 r
.43422 .75959 .43489 .76943 .4364 .77069 .43555 .768 Mtetra
0 .081 .616 r
.43555 .768 .4364 .77069 .43792 .77153 .43702 .77064 Mtetra
.234 .55 .93 r
.43702 .77064 .43792 .77153 .43946 .77163 .43855 .77115 Mtetra
.534 .807 .996 r
.43855 .77115 .43946 .77163 .441 .77139 .4401 .77092 Mtetra
.663 .844 .97 r
.4401 .77092 .441 .77139 .44256 .77099 .44166 .77038 Mtetra
.631 .801 .964 r
.44166 .77038 .44256 .77099 .44411 .77076 .44321 .76998 Mtetra
.663 .763 .924 r
.44321 .76998 .44411 .77076 .44566 .77039 .44477 .7695 Mtetra
.717 .751 .879 r
.44477 .7695 .44566 .77039 .44723 .76957 .44633 .76877 Mtetra
.796 .776 .834 r
.44633 .76877 .44723 .76957 .44883 .76712 .44791 .76746 Mtetra
.91 .975 .791 r
.44791 .76746 .44883 .76712 .4505 .76137 .4495 .7654 Mtetra
.034 0 .228 r
.4495 .7654 .4505 .76137 .45587 .57321 .45112 .76182 Mtetra
0 0 .373 r
.45112 .76182 .45587 .57321 .45742 .56867 .45638 .5778 Mtetra
0 0 .249 r
.45638 .5778 .45742 .56867 .45893 .56669 .45805 .56792 Mtetra
.884 .933 .554 r
.45805 .56792 .45893 .56669 .46042 .56544 .45957 .56481 Mtetra
.806 .804 .849 r
.45957 .56481 .46042 .56544 .4619 .5647 .46107 .56358 Mtetra
.666 .682 .855 r
.46107 .56358 .4619 .5647 .46338 .56426 .46254 .5631 Mtetra
.6 .651 .873 r
.46254 .5631 .46338 .56426 .46485 .56397 .46402 .56292 Mtetra
.607 .676 .89 r
.46402 .56292 .46485 .56397 .46633 .56367 .46549 .56271 Mtetra
.618 .697 .9 r
.46549 .56271 .46633 .56367 .4678 .56335 .46697 .56244 Mtetra
.625 .711 .908 r
.46697 .56244 .4678 .56335 .46928 .56299 .46844 .56214 Mtetra
.67 .739 .902 r
.46844 .56214 .46928 .56299 .47076 .56247 .46992 .56166 Mtetra
.697 .755 .897 r
.46992 .56166 .47076 .56247 .47225 .56186 .47141 .56107 Mtetra
.701 .761 .898 r
.47141 .56107 .47225 .56186 .47373 .56124 .47289 .56046 Mtetra
.713 .766 .893 r
.47289 .56046 .47373 .56124 .47522 .56047 .47438 .55979 Mtetra
.697 .787 .92 r
.47438 .55979 .47522 .56047 .47671 .55981 .47587 .5592 Mtetra
.622 .787 .961 r
.47587 .5592 .47671 .55981 .47819 .55956 .47735 .55885 Mtetra
.35 .647 .966 r
.47735 .55885 .47819 .55956 .47965 .56075 .47883 .55908 Mtetra
.265 .392 .805 r
.47883 .55908 .47965 .56075 .48107 .5651 .48029 .56011 Mtetra
.349 .276 .632 r
.48029 .56011 .48107 .5651 .48021 .75302 .48174 .56264 Mtetra
0 0 .396 r
.48174 .56264 .48021 .75302 .48173 .75723 .48097 .74606 Mtetra
.11 .053 .505 r
.48097 .74606 .48173 .75723 .48328 .75851 .48243 .75529 Mtetra
.13 .185 .653 r
.48243 .75529 .48328 .75851 .48485 .75902 .48397 .75788 Mtetra
.25 .495 .894 r
.48397 .75788 .48485 .75902 .48642 .75907 .48554 .75856 Mtetra
.517 .795 .996 r
.48554 .75856 .48642 .75907 .488 .75884 .48712 .75837 Mtetra
.654 .848 .974 r
.48712 .75837 .488 .75884 .48958 .75842 .4887 .75784 Mtetra
.65 .816 .963 r
.4887 .75784 .48958 .75842 .49116 .75812 .49028 .75737 Mtetra
.66 .772 .932 r
.49028 .75737 .49116 .75812 .49274 .75777 .49186 .75689 Mtetra
.712 .755 .886 r
.49186 .75689 .49274 .75777 .49433 .75701 .49345 .75617 Mtetra
.808 .775 .822 r
.49345 .75617 .49433 .75701 .49593 .75474 .49504 .75473 Mtetra
.928 .904 .78 r
.49504 .75473 .49593 .75474 .49755 .74903 .49664 .75236 Mtetra
0 0 .168 r
.49664 .75236 .49755 .74903 .5005 .56014 .49825 .74904 Mtetra
.566 .358 .557 r
.49825 .74904 .5005 .56014 .50202 .55612 .49985 .74616 Mtetra
.569 .361 .558 r
.49985 .74616 .50202 .55612 .50352 .5554 .50144 .74542 Mtetra
.571 .362 .558 r
.50144 .74542 .50352 .5554 .50502 .55543 .50302 .74563 Mtetra
.572 .362 .558 r
.50302 .74563 .50502 .55543 .50652 .55556 .5046 .74627 Mtetra
.571 .362 .558 r
.5046 .74627 .50652 .55556 .50802 .55539 .50619 .74652 Mtetra
.569 .36 .558 r
.50619 .74652 .50802 .55539 .50952 .55481 .50778 .7456 Mtetra
.555 .349 .556 r
.50778 .7456 .50952 .55481 .51103 .55309 .50941 .73587 Mtetra
0 0 .386 r
.50941 .73587 .51103 .55309 .51254 .55099 .51171 .55276 Mtetra
.81 .851 .394 r
.51171 .55276 .51254 .55099 .51405 .5493 .51323 .54885 Mtetra
.863 .844 .823 r
.51323 .54885 .51405 .5493 .51556 .54828 .51474 .54718 Mtetra
.684 .695 .854 r
.51474 .54718 .51556 .54828 .51706 .54778 .51624 .5466 Mtetra
.621 .659 .866 r
.51624 .5466 .51706 .54778 .51857 .54743 .51775 .54633 Mtetra
.627 .676 .877 r
.51775 .54633 .51857 .54743 .52008 .54706 .51926 .54604 Mtetra
.659 .701 .878 r
.51926 .54604 .52008 .54706 .52159 .54662 .52077 .5456 Mtetra
.658 .701 .878 r
.52077 .5456 .52159 .54662 .52309 .54618 .52227 .54516 Mtetra
.66 .703 .879 r
.52227 .54516 .52309 .54618 .5246 .54573 .52379 .54471 Mtetra
.661 .704 .879 r
.52379 .54471 .5246 .54573 .52611 .54528 .5253 .54426 Mtetra
.662 .705 .879 r
.5253 .54426 .52611 .54528 .52763 .54482 .52681 .5438 Mtetra
.663 .705 .879 r
.52681 .5438 .52763 .54482 .52914 .54436 .52832 .54334 Mtetra
.663 .705 .878 r
.52832 .54334 .52914 .54436 .53065 .54389 .52983 .54288 Mtetra
.664 .706 .878 r
.52983 .54288 .53065 .54389 .53217 .54343 .53135 .54241 Mtetra
.665 .706 .878 r
.53135 .54241 .53217 .54343 .53368 .54296 .53286 .54194 Mtetra
.665 .707 .879 r
.53286 .54194 .53368 .54296 .5352 .54248 .53438 .54147 Mtetra
.666 .708 .879 r
.53438 .54147 .5352 .54248 .53671 .542 .5359 .54099 Mtetra
.666 .708 .88 r
.5359 .54099 .53671 .542 .53823 .54152 .53741 .54052 Mtetra
.666 .71 .88 r
.53741 .54052 .53823 .54152 .53975 .54104 .53893 .54005 Mtetra
.67 .712 .88 r
.53893 .54005 .53975 .54104 .54127 .54054 .54045 .53955 Mtetra
.683 .718 .876 r
.54045 .53955 .54127 .54054 .54278 .53998 .54197 .53899 Mtetra
.694 .722 .871 r
.54197 .53899 .54278 .53998 .5443 .53936 .54349 .53838 Mtetra
.694 .723 .872 r
.54349 .53838 .5443 .53936 .54582 .53874 .54501 .53776 Mtetra
.684 .72 .877 r
.54501 .53776 .54582 .53874 .54735 .53818 .54653 .5372 Mtetra
.669 .716 .884 r
.54653 .5372 .54735 .53818 .54887 .53768 .54806 .53671 Mtetra
.664 .716 .887 r
.54806 .53671 .54887 .53768 .55039 .53721 .54958 .53624 Mtetra
.663 .717 .889 r
.54958 .53624 .55039 .53721 .55192 .53674 .55111 .53578 Mtetra
.664 .718 .889 r
.55111 .53578 .55192 .53674 .55344 .53627 .55263 .53531 Mtetra
.658 .717 .892 r
.55263 .53531 .55344 .53627 .55497 .53582 .55416 .53487 Mtetra
.644 .714 .898 r
.55416 .53487 .55497 .53582 .5565 .53542 .55569 .53449 Mtetra
.625 .711 .908 r
.55569 .53449 .5565 .53542 .55802 .53508 .55722 .53418 Mtetra
.621 .717 .915 r
.55722 .53418 .55802 .53508 .55956 .53475 .55875 .53388 Mtetra
.632 .73 .918 r
.55875 .53388 .55956 .53475 .56109 .53437 .56028 .53354 Mtetra
.655 .745 .916 r
.56028 .53354 .56109 .53437 .56262 .53392 .56181 .5331 Mtetra
.661 .751 .916 r
.56181 .5331 .56262 .53392 .56415 .53346 .56334 .53265 Mtetra
.678 .757 .911 r
.56334 .53265 .56415 .53346 .56568 .53288 .56488 .53212 Mtetra
.694 .773 .912 r
.56488 .53212 .56568 .53288 .56721 .53219 .56641 .53152 Mtetra
.645 .787 .95 r
.56641 .53152 .56721 .53219 .56874 .5318 .56794 .5311 Mtetra
.433 .695 .975 r
.56794 .5311 .56874 .5318 .57029 .53235 .56949 .53119 Mtetra
.03 .335 .817 r
.56949 .53119 .57029 .53235 .57188 .53561 .57104 .53232 Mtetra
.297 .29 .682 r
.57104 .53232 .57188 .53561 .57614 .72316 .57262 .53435 Mtetra
.567 .362 .563 r
.57262 .53435 .57614 .72316 .57787 .73006 .5742 .53701 Mtetra
.571 .365 .563 r
.5742 .53701 .57787 .73006 .57951 .73025 .57576 .53735 Mtetra
.573 .367 .563 r
.57576 .53735 .57951 .73025 .58114 .72951 .5773 .53646 Mtetra
.5773 .53646 .58114 .72951 .58277 .72855 .57883 .53541 Mtetra
.572 .366 .563 r
.57883 .53541 .58277 .72855 .5844 .72815 .58038 .53501 Mtetra
.58038 .53501 .5844 .72815 .58603 .72773 .58192 .53461 Mtetra
.58192 .53461 .58603 .72773 .58767 .72732 .58347 .5342 Mtetra
.58347 .5342 .58767 .72732 .58931 .72691 .58502 .5338 Mtetra
.58502 .5338 .58931 .72691 .59095 .7265 .58657 .53339 Mtetra
.58657 .53339 .59095 .7265 .59258 .72608 .58812 .53298 Mtetra
.58812 .53298 .59258 .72608 .59422 .72566 .58967 .53256 Mtetra
.58967 .53256 .59422 .72566 .59587 .72524 .59122 .53213 Mtetra
.59122 .53213 .59587 .72524 .59751 .72481 .59278 .53169 Mtetra
.59278 .53169 .59751 .72481 .59915 .72438 .59433 .53124 Mtetra
.59433 .53124 .59915 .72438 .60079 .72394 .59588 .53079 Mtetra
.59588 .53079 .60079 .72394 .60244 .72351 .59744 .53034 Mtetra
.59744 .53034 .60244 .72351 .60408 .72307 .59899 .52989 Mtetra
.59899 .52989 .60408 .72307 .60573 .72264 .60055 .52946 Mtetra
.60055 .52946 .60573 .72264 .60738 .72222 .60211 .52904 Mtetra
.60211 .52904 .60738 .72222 .60903 .72182 .60367 .52867 Mtetra
.60367 .52867 .60903 .72182 .61068 .72142 .60523 .52831 Mtetra
.60523 .52831 .61068 .72142 .61233 .72116 .6068 .52819 Mtetra
.57 .365 .563 r
.6068 .52819 .61233 .72116 .614 .72135 .60839 .52903 Mtetra
.572 .366 .563 r
.60839 .52903 .614 .72135 .61565 .72095 .60997 .52889 Mtetra
.576 .369 .564 r
.60997 .52889 .61565 .72095 .61727 .71899 .61147 .52616 Mtetra
.579 .371 .564 r
.61147 .52616 .61727 .71899 .614 .53342 .61293 .52175 Mtetra
.638 .442 .602 r
.61293 .52175 .614 .53342 .61525 .52123 .61443 .51904 Mtetra
.742 .615 .718 r
.61443 .51904 .61525 .52123 .61675 .51818 .61596 .51737 Mtetra
.653 .755 .924 r
.61596 .51737 .61675 .51818 .6183 .51753 .61753 .51693 Mtetra
.51 .761 .987 r
.61753 .51693 .6183 .51753 .61988 .51741 .6191 .51681 Mtetra
.446 .733 .988 r
.6191 .51681 .61988 .51741 .62146 .51752 .62068 .51681 Mtetra
.604 .765 .956 r
.62068 .51681 .62146 .51752 .62303 .51723 .62225 .51651 Mtetra
.623 .768 .949 r
.62225 .51651 .62303 .51723 .6246 .51692 .62382 .51616 Mtetra
.643 .765 .937 r
.62382 .51616 .6246 .51692 .62617 .51655 .62539 .51575 Mtetra
.664 .761 .923 r
.62539 .51575 .62617 .51655 .62774 .5161 .62696 .51527 Mtetra
.676 .757 .912 r
.62696 .51527 .62774 .5161 .6293 .51559 .62852 .51473 Mtetra
.685 .753 .903 r
.62852 .51473 .6293 .51559 .63087 .51504 .63009 .51416 Mtetra
.692 .751 .897 r
.63009 .51416 .63087 .51504 .63244 .51444 .63166 .51356 Mtetra
.695 .751 .894 r
.63166 .51356 .63244 .51444 .634 .51381 .63322 .51293 Mtetra
.696 .752 .895 r
.63322 .51293 .634 .51381 .63557 .51318 .63479 .51231 Mtetra
.689 .752 .9 r
.63479 .51231 .63557 .51318 .63714 .51257 .63636 .51172 Mtetra
.692 .757 .902 r
.63636 .51172 .63714 .51257 .63871 .51195 .63793 .51111 Mtetra
.699 .763 .902 r
.63793 .51111 .63871 .51195 .64027 .5113 .6395 .51048 Mtetra
.718 .771 .895 r
.6395 .51048 .64027 .5113 .64184 .51057 .64107 .50975 Mtetra
.716 .772 .897 r
.64107 .50975 .64184 .51057 .64341 .50985 .64264 .50903 Mtetra
.71 .77 .9 r
.64264 .50903 .64341 .50985 .64498 .50917 .64421 .50835 Mtetra
.719 .774 .895 r
.64421 .50835 .64498 .50917 .64654 .5083 .64577 .50761 Mtetra
.678 .797 .938 r
.64577 .50761 .64654 .5083 .64812 .50773 .64735 .50706 Mtetra
.575 .768 .97 r
.64735 .50706 .64812 .50773 .64971 .50771 .64894 .50682 Mtetra
.049 .416 .864 r
.64894 .50682 .64971 .50771 .6514 .51013 .65057 .5077 Mtetra
.271 .323 .733 r
.65057 .5077 .6514 .51013 .65345 .5218 .65224 .50936 Mtetra
.498 .338 .595 r
.65224 .50936 .65345 .5218 .66226 .70686 .65395 .51219 Mtetra
.573 .367 .563 r
.65395 .51219 .66226 .70686 .66397 .7071 .65552 .51143 Mtetra
.65552 .51143 .66397 .7071 .66564 .70641 .65709 .51053 Mtetra
.571 .365 .563 r
.65709 .51053 .66564 .70641 .66731 .70562 .65871 .51082 Mtetra
.084 .003 .456 r
.65871 .51082 .66731 .70562 .66908 .70715 .66801 .69994 Mtetra
.178 .138 .573 r
.66801 .69994 .66908 .70715 .67083 .70833 .66996 .70601 Mtetra
.088 .222 .708 r
.66996 .70601 .67083 .70833 .67257 .70903 .67176 .70825 Mtetra
.404 .672 .97 r
.67176 .70825 .67257 .70903 .67428 .70915 .67347 .70843 Mtetra
.638 .789 .954 r
.67347 .70843 .67428 .70915 .67597 .70878 .67517 .70798 Mtetra
.752 .797 .889 r
.67517 .70798 .67597 .70878 .67764 .70781 .67684 .70702 Mtetra
.82 .808 .84 r
.67684 .70702 .67764 .70781 .67922 .70475 .67848 .70554 Mtetra
.723 .911 .548 r
.67848 .70554 .67922 .70475 .6806 .69727 .6801 .70327 Mtetra
.279 .069 .405 r
.6801 .70327 .6806 .69727 .67375 .50592 .68163 .69926 Mtetra
.088 .002 .453 r
.68163 .69926 .67375 .50592 .67522 .50257 .67483 .51009 Mtetra
.013 0 .343 r
.67483 .51009 .67522 .50257 .67676 .50086 .67609 .50195 Mtetra
.751 .862 .43 r
.67609 .50195 .67676 .50086 .67833 .49981 .67757 .49902 Mtetra
.747 .79 .887 r
.67757 .49902 .67833 .49981 .67992 .49925 .67915 .49813 Mtetra
.625 .68 .882 r
.67915 .49813 .67992 .49925 .68153 .49894 .68076 .49782 Mtetra
.552 .647 .897 r
.68076 .49782 .68153 .49894 .68314 .49877 .68238 .4978 Mtetra
.621 .709 .908 r
.68238 .4978 .68314 .49877 .68475 .49844 .68399 .49749 Mtetra
.638 .72 .907 r
.68399 .49749 .68475 .49844 .68635 .49805 .68559 .49711 Mtetra
.65 .728 .906 r
.68559 .49711 .68635 .49805 .68796 .4976 .6872 .49668 Mtetra
.68 .742 .898 r
.6872 .49668 .68796 .4976 .68955 .49703 .6888 .49612 Mtetra
.693 .748 .894 r
.6888 .49612 .68955 .49703 .69115 .49641 .69039 .4955 Mtetra
.699 .75 .892 r
.69039 .4955 .69115 .49641 .69275 .49575 .69199 .49484 Mtetra
.772 .77 .85 r
.69199 .49484 .69275 .49575 .69432 .49465 .69356 .49374 Mtetra
.727 .759 .878 r
.69356 .49374 .69432 .49465 .69591 .49385 .69515 .49294 Mtetra
.564 .7 .932 r
.69515 .49294 .69591 .49385 .69753 .49372 .69678 .49281 Mtetra
.823 .384 0 r
.69678 .49281 .69753 .49372 .69936 .49732 .6986 .49639 Mtetra
.97 .683 .428 r
.6986 .49639 .69936 .49732 .7113 .69155 .7105 .69067 Mtetra
.914 .518 .132 r
.7105 .69067 .7113 .69155 .71333 .69722 .71254 .69637 Mtetra
.225 .551 .931 r
.71254 .69637 .71333 .69722 .7151 .6978 .71431 .69695 Mtetra
.657 .765 .929 r
.71431 .69695 .7151 .6978 .71681 .69729 .71602 .69645 Mtetra
.737 .789 .894 r
.71602 .69645 .71681 .69729 .7185 .69639 .71771 .69556 Mtetra
.481 .698 .964 r
.71771 .69556 .7185 .69639 .72025 .69638 .71946 .6956 Mtetra
.512 .724 .968 r
.71946 .6956 .72025 .69638 .72198 .69628 .7212 .69553 Mtetra
.704 .804 .927 r
.7212 .69553 .72198 .69628 .72369 .69553 .72291 .69482 Mtetra
.936 .798 .683 r
.72291 .69482 .72369 .69553 .72521 .69158 .72443 .69095 Mtetra
.971 .689 .436 r
.72443 .69095 .72521 .69158 .71581 .49775 .71509 .49749 Mtetra
.98 .758 .532 r
.71509 .49749 .71581 .49775 .71693 .48865 .71619 .48778 Mtetra
.841 .79 .802 r
.71619 .48778 .71693 .48865 .71848 .48696 .71773 .48606 Mtetra
.651 .738 .913 r
.71773 .48606 .71848 .48696 .7201 .48654 .71936 .48561 Mtetra
.514 .676 .938 r
.71936 .48561 .7201 .48654 .72175 .48658 .72101 .48563 Mtetra
.614 .714 .916 r
.72101 .48563 .72175 .48658 .72339 .48632 .72264 .48534 Mtetra
.656 .724 .899 r
.72264 .48534 .72339 .48632 .72501 .48589 .72427 .48488 Mtetra
.667 .721 .889 r
.72427 .48488 .72501 .48589 .72664 .48542 .72589 .48437 Mtetra
.693 .723 .873 r
.72589 .48437 .72664 .48542 .72826 .48481 .7275 .48372 Mtetra
.703 .719 .862 r
.7275 .48372 .72826 .48481 .72987 .48413 .72912 .48301 Mtetra
.701 .712 .857 r
.72912 .48301 .72987 .48413 .73148 .48345 .73073 .48231 Mtetra
.685 .702 .86 r
.73073 .48231 .73148 .48345 .7331 .48284 .73235 .48169 Mtetra
.675 .697 .863 r
.73235 .48169 .7331 .48284 .73473 .48228 .73397 .48113 Mtetra
.671 .695 .865 r
.73397 .48113 .73473 .48228 .73635 .48173 .7356 .48058 Mtetra
.671 .697 .866 r
.7356 .48058 .73635 .48173 .73798 .48118 .73723 .48004 Mtetra
.67 .698 .867 r
.73723 .48004 .73798 .48118 .7396 .48063 .73885 .4795 Mtetra
.668 .699 .87 r
.73885 .4795 .7396 .48063 .74123 .48009 .74048 .47898 Mtetra
.666 .7 .872 r
.74048 .47898 .74123 .48009 .74286 .47957 .74211 .47846 Mtetra
.664 .701 .874 r
.74211 .47846 .74286 .47957 .74449 .47906 .74375 .47796 Mtetra
.662 .702 .877 r
.74375 .47796 .74449 .47906 .74613 .47856 .74538 .47747 Mtetra
.661 .703 .878 r
.74538 .47747 .74613 .47856 .74776 .47806 .74702 .47698 Mtetra
.658 .703 .88 r
.74702 .47698 .74776 .47806 .7494 .47758 .74866 .4765 Mtetra
.651 .702 .884 r
.74866 .4765 .7494 .47758 .75104 .47713 .7503 .47606 Mtetra
.63 .696 .893 r
.7503 .47606 .75104 .47713 .75269 .47675 .75195 .47572 Mtetra
.614 .695 .902 r
.75195 .47572 .75269 .47675 .75434 .47643 .7536 .47543 Mtetra
.609 .702 .91 r
.7536 .47543 .75434 .47643 .75599 .47612 .75526 .47516 Mtetra
.624 .718 .914 r
.75526 .47516 .75599 .47612 .75764 .47575 .75691 .47483 Mtetra
.638 .731 .916 r
.75691 .47483 .75764 .47575 .75929 .47533 .75856 .47443 Mtetra
.643 .739 .919 r
.75856 .47443 .75929 .47533 .76093 .4749 .76021 .47401 Mtetra
.643 .744 .922 r
.76021 .47401 .76093 .4749 .76258 .47446 .76186 .4736 Mtetra
.643 .749 .926 r
.76186 .4736 .76258 .47446 .76423 .47401 .76351 .47317 Mtetra
.645 .755 .929 r
.76351 .47317 .76423 .47401 .76588 .47356 .76516 .47274 Mtetra
.647 .761 .932 r
.76516 .47274 .76588 .47356 .76753 .4731 .76681 .4723 Mtetra
.65 .767 .934 r
.76681 .4723 .76753 .4731 .76918 .47263 .76846 .47184 Mtetra
.655 .772 .935 r
.76846 .47184 .76918 .47263 .77083 .47214 .77011 .47136 Mtetra
.661 .777 .935 r
.77011 .47136 .77083 .47214 .77248 .47163 .77177 .47085 Mtetra
.668 .779 .932 r
.77177 .47085 .77248 .47163 .77413 .47111 .77341 .47032 Mtetra
.674 .779 .929 r
.77341 .47032 .77413 .47111 .77578 .47057 .77506 .46977 Mtetra
.677 .777 .925 r
.77506 .46977 .77578 .47057 .77742 .47002 .77671 .4692 Mtetra
.683 .774 .92 r
.77671 .4692 .77742 .47002 .77907 .46946 .77836 .46861 Mtetra
.692 .77 .912 r
.77836 .46861 .77907 .46946 .78072 .46886 .78 .46798 Mtetra
.71 .768 .898 r
.78 .46798 .78072 .46886 .78236 .46819 .78164 .46726 Mtetra
.719 .761 .886 r
.78164 .46726 .78236 .46819 .784 .46747 .78328 .46649 Mtetra
.714 .747 .879 r
.78328 .46649 .784 .46747 .78564 .46676 .78491 .46573 Mtetra
.697 .732 .878 r
.78491 .46573 .78564 .46676 .78729 .46612 .78656 .46506 Mtetra
.682 .72 .878 r
.78656 .46506 .78729 .46612 .78894 .46554 .78821 .46446 Mtetra
.675 .713 .877 r
.78821 .46446 .78894 .46554 .7906 .46499 .78987 .46389 Mtetra
.673 .71 .876 r
.78987 .46389 .7906 .46499 .79225 .46445 .79152 .46334 Mtetra
.672 .707 .874 r
.79152 .46334 .79225 .46445 .79391 .4639 .79318 .46279 Mtetra
.669 .705 .874 r
.79318 .46279 .79391 .4639 .79557 .46337 .79484 .46225 Mtetra
.668 .703 .873 r
.79484 .46225 .79557 .46337 .79723 .46284 .7965 .46171 Mtetra
.667 .702 .873 r
.7965 .46171 .79723 .46284 .79889 .46232 .79817 .46118 Mtetra
.666 .701 .873 r
.79817 .46118 .79889 .46232 .80056 .4618 .79983 .46066 Mtetra
.665 .7 .873 r
.79983 .46066 .80056 .4618 .80222 .46128 .80149 .46014 Mtetra
.664 .7 .873 r
.80149 .46014 .80222 .46128 .80389 .46077 .80316 .45963 Mtetra
.663 .699 .873 r
.80316 .45963 .80389 .46077 .80556 .46025 .80483 .45911 Mtetra
.80483 .45911 .80556 .46025 .80723 .45975 .8065 .4586 Mtetra
.662 .698 .873 r
.8065 .4586 .80723 .45975 .8089 .45924 .80817 .4581 Mtetra
.661 .698 .874 r
.80817 .4581 .8089 .45924 .81057 .45874 .80984 .4576 Mtetra
.66 .698 .874 r
.80984 .4576 .81057 .45874 .81224 .45824 .81152 .4571 Mtetra
.81152 .4571 .81224 .45824 .81391 .45774 .81319 .4566 Mtetra
.658 .698 .875 r
.81319 .4566 .81391 .45774 .81559 .45725 .81487 .45612 Mtetra
.658 .698 .876 r
.81487 .45612 .81559 .45725 .81727 .45676 .81654 .45563 Mtetra
.657 .698 .876 r
.81654 .45563 .81727 .45676 .81894 .45627 .81822 .45514 Mtetra
.652 .697 .879 r
.81822 .45514 .81894 .45627 .82062 .45581 .8199 .45469 Mtetra
.637 .692 .885 r
.8199 .45469 .82062 .45581 .82231 .45541 .82159 .45431 Mtetra
.618 .689 .893 r
.82159 .45431 .82231 .45541 .82401 .45506 .82329 .454 Mtetra
.614 .694 .901 r
.82329 .454 .82401 .45506 .8257 .45473 .82499 .45371 Mtetra
.627 .708 .905 r
.82499 .45371 .8257 .45473 .8274 .45436 .82669 .45336 Mtetra
.647 .724 .905 r
.82669 .45336 .8274 .45436 .82908 .45391 .82838 .45293 Mtetra
.654 .73 .905 r
.82838 .45293 .82908 .45391 .83077 .45343 .83007 .45246 Mtetra
.656 .732 .905 r
.83007 .45246 .83077 .45343 .83246 .45295 .83175 .45198 Mtetra
.655 .733 .907 r
.83175 .45198 .83246 .45295 .83414 .45246 .83344 .4515 Mtetra
.657 .735 .907 r
.83344 .4515 .83414 .45246 .83583 .45198 .83513 .45102 Mtetra
.658 .737 .908 r
.83513 .45102 .83583 .45198 .83752 .45148 .83682 .45053 Mtetra
.659 .738 .908 r
.83682 .45053 .83752 .45148 .83921 .45099 .83851 .45004 Mtetra
.66 .74 .909 r
.83851 .45004 .83921 .45099 .8409 .45048 .8402 .44953 Mtetra
.661 .741 .909 r
.8402 .44953 .8409 .45048 .84259 .44998 .84189 .44903 Mtetra
.662 .741 .909 r
.84189 .44903 .84259 .44998 .84428 .44947 .84359 .44852 Mtetra
.663 .742 .909 r
.84359 .44852 .84428 .44947 .84597 .44895 .84528 .44801 Mtetra
.664 .743 .909 r
.84528 .44801 .84597 .44895 .84766 .44843 .84697 .44749 Mtetra
.665 .744 .909 r
.84697 .44749 .84766 .44843 .84936 .44791 .84867 .44696 Mtetra
.666 .745 .909 r
.84867 .44696 .84936 .44791 .85105 .44738 .85036 .44644 Mtetra
.667 .746 .909 r
.85036 .44644 .85105 .44738 .85274 .44684 .85205 .4459 Mtetra
.668 .747 .909 r
.85205 .4459 .85274 .44684 .85444 .4463 .85375 .44536 Mtetra
.67 .748 .909 r
.85375 .44536 .85444 .4463 .85613 .44575 .85545 .44482 Mtetra
.67 .75 .91 r
.85545 .44482 .85613 .44575 .85783 .4452 .85714 .44427 Mtetra
.67 .751 .912 r
.85714 .44427 .85783 .4452 .85952 .44464 .85884 .44373 Mtetra
.676 .756 .911 r
.85884 .44373 .85952 .44464 .86122 .44406 .86053 .44315 Mtetra
.689 .763 .908 r
.86053 .44315 .86122 .44406 .86291 .44342 .86222 .44252 Mtetra
.706 .769 .901 r
.86222 .44252 .86291 .44342 .86459 .44271 .86391 .4418 Mtetra
.706 .768 .9 r
.86391 .4418 .86459 .44271 .86627 .442 .86559 .44108 Mtetra
.696 .762 .903 r
.86559 .44108 .86627 .442 .86796 .44134 .86728 .44041 Mtetra
.676 .755 .91 r
.86728 .44041 .86796 .44134 .86966 .44075 .86898 .43984 Mtetra
.67 .754 .913 r
.86898 .43984 .86966 .44075 .87136 .4402 .87068 .43929 Mtetra
.667 .754 .916 r
.87068 .43929 .87136 .4402 .87307 .43966 .87239 .43875 Mtetra
.668 .756 .916 r
.87239 .43875 .87307 .43966 .87477 .43911 .8741 .43821 Mtetra
.666 .756 .917 r
.8741 .43821 .87477 .43911 .87648 .43858 .8758 .43768 Mtetra
.665 .756 .918 r
.8758 .43768 .87648 .43858 .87819 .43805 .87751 .43714 Mtetra
.664 .756 .918 r
.87751 .43714 .87819 .43805 .8799 .43752 .87922 .43662 Mtetra
.663 .755 .919 r
.87922 .43662 .8799 .43752 .88161 .437 .88094 .4361 Mtetra
.662 .754 .919 r
.88094 .4361 .88161 .437 .88332 .43649 .88265 .43558 Mtetra
.661 .754 .919 r
.88265 .43558 .88332 .43649 .88504 .43598 .88437 .43507 Mtetra
.659 .753 .919 r
.88437 .43507 .88504 .43598 .88676 .43547 .88609 .43456 Mtetra
.658 .752 .919 r
.88609 .43456 .88676 .43547 .88847 .43498 .8878 .43406 Mtetra
.658 .751 .919 r
.8878 .43406 .88847 .43498 .89019 .43448 .88952 .43356 Mtetra
.652 .747 .919 r
.88952 .43356 .89019 .43448 .89192 .43401 .89125 .43308 Mtetra
.639 .741 .922 r
.89125 .43308 .89192 .43401 .89365 .43358 .89298 .43266 Mtetra
.614 .731 .929 r
.89298 .43266 .89365 .43358 .89539 .43324 .89472 .43233 Mtetra
.608 .731 .932 r
.89472 .43233 .89539 .43324 .89713 .43292 .89647 .43203 Mtetra
.614 .738 .934 r
.89647 .43203 .89713 .43292 .89888 .43257 .89822 .43169 Mtetra
.639 .753 .931 r
.89822 .43169 .89888 .43257 .90061 .43213 .89995 .43126 Mtetra
.65 .761 .93 r
.89995 .43126 .90061 .43213 .90234 .43164 .90168 .43079 Mtetra
.657 .767 .93 r
.90168 .43079 .90234 .43164 .90407 .43112 .90341 .43028 Mtetra
.659 .77 .931 r
.90341 .43028 .90407 .43112 .90579 .4306 .90514 .42976 Mtetra
.671 .778 .93 r
.90514 .42976 .90579 .4306 .90751 .43002 .90686 .42919 Mtetra
.69 .787 .924 r
.90686 .42919 .90751 .43002 .90923 .42938 .90858 .42855 Mtetra
.72 .797 .912 r
.90858 .42855 .90923 .42938 .91093 .42861 .91028 .42776 Mtetra
.722 .793 .908 r
.91028 .42776 .91093 .42861 .91263 .42783 .91197 .42696 Mtetra
.727 .79 .902 r
.91197 .42696 .91263 .42783 .91433 .42702 .91367 .42613 Mtetra
.765 .797 .879 r
.91367 .42613 .91433 .42702 .916 .42598 .91534 .42508 Mtetra
.688 .767 .912 r
.91534 .42508 .916 .42598 .91772 .42535 .91706 .42444 Mtetra
.428 .64 .945 r
.91706 .42444 .91772 .42535 .91954 .42559 .91889 .42468 Mtetra
.739 .307 0 r
.91889 .42468 .91954 .42559 .92185 .42974 .92121 .42893 Mtetra
.973 .661 .313 r
.92121 .42893 .92185 .42974 .94802 .62848 .94736 .6278 Mtetra
.826 .391 0 r
.94736 .6278 .94802 .62848 .95058 .63373 .94991 .6329 Mtetra
.445 .687 .968 r
.94991 .6329 .95058 .63373 .95252 .63388 .95184 .63302 Mtetra
.684 .792 .932 r
.95184 .63302 .95252 .63388 .95436 .63323 .95368 .63235 Mtetra
.741 .807 .905 r
.95368 .63235 .95436 .63323 .95617 .63229 .95549 .6314 Mtetra
.476 .686 .959 r
.95549 .6314 .95617 .63229 .95811 .63238 .95742 .63147 Mtetra
.612 .75 .943 r
.95742 .63147 .95811 .63238 .95999 .63202 .9593 .63111 Mtetra
.796 .814 .865 r
.9593 .63111 .95999 .63202 .96175 .6307 .96107 .62978 Mtetra
.98 .776 .558 r
.96107 .62978 .96175 .6307 .96282 .62395 .96214 .62301 Mtetra
.975 .669 .322 r
.96214 .62301 .96282 .62395 .93929 .42448 .93863 .42348 Mtetra
.962 .782 .613 r
.93863 .42348 .93929 .42448 .94048 .41957 .93982 .41859 Mtetra
.754 .774 .869 r
.93982 .41859 .94048 .41957 .94216 .41855 .94151 .41756 Mtetra
.626 .723 .917 r
.94151 .41756 .94216 .41855 .94393 .41819 .94328 .4172 Mtetra
.544 .683 .929 r
.94328 .4172 .94393 .41819 .94575 .41813 .94509 .41713 Mtetra
.747 .771 .873 r
.94509 .41713 .94575 .41813 .94744 .41715 .94679 .41616 Mtetra
.681 .746 .9 r
.94679 .41616 .94744 .41715 .94918 .41654 .94853 .41554 Mtetra
.489 .653 .932 r
.94853 .41554 .94918 .41654 .95102 .41666 .95037 .41566 Mtetra
.739 .322 0 r
.95037 .41566 .95102 .41666 .95349 .42153 .95283 .4205 Mtetra
.97 .655 .291 r
.95283 .4205 .95349 .42153 .98174 .62069 .98106 .61973 Mtetra
.728 .3 0 r
.98106 .61973 .98174 .62069 .98431 .62536 .98363 .62443 Mtetra
.047 .47 .883 r
.37626 .78583 .37718 .78659 .37866 .78721 .37774 .78645 Mtetra
.646 .758 .931 r
.37774 .78645 .37866 .78721 .38018 .7868 .37926 .78605 Mtetra
.81 .777 .822 r
.37926 .78605 .38018 .7868 .38174 .78534 .38082 .78462 Mtetra
.91 .739 .657 r
.38082 .78462 .38174 .78534 .38347 .77962 .38253 .77932 Mtetra
.937 .687 .533 r
.38253 .77932 .38347 .77962 .39235 .58959 .39146 .58961 Mtetra
.948 .781 .642 r
.39146 .58961 .39235 .58959 .39397 .58449 .39309 .58408 Mtetra
.792 .855 .897 r
.39309 .58408 .39397 .58449 .39543 .58359 .39456 .58307 Mtetra
.574 .796 .983 r
.39456 .58307 .39543 .58359 .39686 .58345 .39599 .58281 Mtetra
.377 .683 .978 r
.39599 .58281 .39686 .58345 .39828 .58372 .39741 .58295 Mtetra
.624 .743 .932 r
.39741 .58295 .39828 .58372 .39972 .58346 .39885 .58265 Mtetra
.64 .735 .917 r
.39885 .58265 .39972 .58346 .40116 .58313 .40029 .58229 Mtetra
.649 .732 .91 r
.40029 .58229 .40116 .58313 .4026 .58276 .40174 .58191 Mtetra
.668 .735 .9 r
.40174 .58191 .4026 .58276 .40404 .58234 .40318 .58145 Mtetra
.674 .727 .889 r
.40318 .58145 .40404 .58234 .40549 .58187 .40463 .58096 Mtetra
.676 .723 .885 r
.40463 .58096 .40549 .58187 .40694 .58135 .40608 .58047 Mtetra
.664 .725 .895 r
.40608 .58047 .40694 .58135 .4084 .58071 .40753 .58003 Mtetra
.661 .772 .932 r
.40753 .58003 .4084 .58071 .40985 .58007 .40898 .57958 Mtetra
.651 .829 .969 r
.40898 .57958 .40985 .58007 .41131 .57947 .41043 .57913 Mtetra
.655 .874 .981 r
.41043 .57913 .41131 .57947 .41275 .57906 .41188 .57861 Mtetra
.675 .845 .964 r
.41188 .57861 .41275 .57906 .4142 .57872 .41334 .57808 Mtetra
.684 .792 .932 r
.41334 .57808 .4142 .57872 .41565 .57838 .41479 .57755 Mtetra
.671 .74 .902 r
.41479 .57755 .41565 .57838 .4171 .57797 .41625 .57708 Mtetra
.667 .726 .893 r
.41625 .57708 .4171 .57797 .41856 .5775 .4177 .57662 Mtetra
.667 .729 .896 r
.4177 .57662 .41856 .5775 .42001 .57698 .41916 .57616 Mtetra
.673 .745 .905 r
.41916 .57616 .42001 .57698 .42147 .57636 .42061 .57568 Mtetra
.674 .778 .928 r
.42061 .57568 .42147 .57636 .42293 .57573 .42207 .57519 Mtetra
.668 .817 .955 r
.42207 .57519 .42293 .57573 .4244 .57512 .42353 .5747 Mtetra
.661 .852 .973 r
.42353 .5747 .4244 .57512 .42586 .57445 .42499 .57419 Mtetra
.62 .89 .988 r
.42499 .57419 .42586 .57445 .42732 .57391 .42645 .57371 Mtetra
.58 .891 .989 r
.42645 .57371 .42732 .57391 .42877 .57364 .42791 .57326 Mtetra
.567 .84 .996 r
.42791 .57326 .42877 .57364 .4302 .5743 .42936 .57294 Mtetra
.623 .628 .835 r
.42936 .57294 .4302 .5743 .43161 .57576 .43082 .57268 Mtetra
.606 .496 .702 r
.43082 .57268 .43161 .57576 .43299 .57826 .43228 .57241 Mtetra
.617 .454 .638 r
.43228 .57241 .43299 .57826 .43444 .5784 .43375 .57164 Mtetra
.606 .438 .629 r
.43375 .57164 .43444 .5784 .43592 .57753 .43522 .571 Mtetra
.58 .421 .631 r
.43522 .571 .43592 .57753 .43737 .57753 .43667 .57096 Mtetra
.343 .248 .601 r
.43667 .57096 .43737 .57753 .43422 .75959 .43804 .57427 Mtetra
0 0 .352 r
.43804 .57427 .43422 .75959 .43555 .768 .43474 .76326 Mtetra
0 0 .388 r
.43474 .76326 .43555 .768 .43702 .77064 .43614 .76909 Mtetra
.312 .451 .84 r
.43614 .76909 .43702 .77064 .43855 .77115 .43766 .7699 Mtetra
.636 .662 .858 r
.43766 .7699 .43855 .77115 .4401 .77092 .43921 .76955 Mtetra
.7 .668 .816 r
.43921 .76955 .4401 .77092 .44166 .77038 .44078 .76879 Mtetra
.653 .623 .807 r
.44078 .76879 .44166 .77038 .44321 .76998 .44233 .76831 Mtetra
.637 .607 .803 r
.44233 .76831 .44321 .76998 .44477 .7695 .44389 .76793 Mtetra
.647 .622 .811 r
.44389 .76793 .44477 .7695 .44633 .76877 .44544 .76749 Mtetra
.612 .648 .861 r
.44544 .76749 .44633 .76877 .44791 .76746 .447 .76726 Mtetra
.544 .884 .987 r
.447 .76726 .44791 .76746 .4495 .7654 .44856 .76683 Mtetra
.142 0 .013 r
.44856 .76683 .4495 .7654 .45112 .76182 .45013 .76579 Mtetra
0 0 .162 r
.45013 .76579 .45112 .76182 .45638 .5778 .45177 .7617 Mtetra
0 0 .346 r
.45177 .7617 .45638 .5778 .45805 .56792 .4571 .57202 Mtetra
.718 .709 .178 r
.4571 .57202 .45805 .56792 .45957 .56481 .45872 .56483 Mtetra
.897 .937 .832 r
.45872 .56483 .45957 .56481 .46107 .56358 .46022 .56309 Mtetra
.662 .835 .966 r
.46022 .56309 .46107 .56358 .46254 .5631 .4617 .56259 Mtetra
.469 .767 .995 r
.4617 .56259 .46254 .5631 .46402 .56292 .46317 .56251 Mtetra
.555 .828 .997 r
.46317 .56251 .46402 .56292 .46549 .56271 .46464 .56222 Mtetra
.637 .83 .975 r
.46464 .56222 .46549 .56271 .46697 .56244 .46612 .56179 Mtetra
.653 .787 .946 r
.46612 .56179 .46697 .56244 .46844 .56214 .4676 .56136 Mtetra
.66 .753 .919 r
.4676 .56136 .46844 .56214 .46992 .56166 .46908 .56092 Mtetra
.662 .763 .925 r
.46908 .56092 .46992 .56166 .47141 .56107 .47057 .56047 Mtetra
.659 .802 .951 r
.47057 .56047 .47141 .56107 .47289 .56046 .47205 .56001 Mtetra
.659 .847 .972 r
.47205 .56001 .47289 .56046 .47438 .55979 .47354 .55951 Mtetra
.629 .889 .987 r
.47354 .55951 .47438 .55979 .47587 .5592 .47502 .559 Mtetra
.579 .896 .986 r
.47502 .559 .47587 .5592 .47735 .55885 .47651 .55853 Mtetra
.686 .89 .972 r
.47651 .55853 .47735 .55885 .47883 .55908 .478 .55791 Mtetra
.668 .675 .848 r
.478 .55791 .47883 .55908 .48029 .56011 .47948 .55741 Mtetra
.573 .492 .725 r
.47948 .55741 .48029 .56011 .48174 .56264 .48096 .55746 Mtetra
.348 .272 .628 r
.48096 .55746 .48174 .56264 .48097 .74606 .48242 .56009 Mtetra
0 0 .376 r
.48242 .56009 .48097 .74606 .48243 .75529 .48161 .74885 Mtetra
0 0 .44 r
.48161 .74885 .48243 .75529 .48397 .75788 .4831 .75604 Mtetra
.212 .35 .787 r
.4831 .75604 .48397 .75788 .48554 .75856 .48466 .75731 Mtetra
.621 .657 .864 r
.48466 .75731 .48554 .75856 .48712 .75837 .48624 .75703 Mtetra
.697 .673 .822 r
.48624 .75703 .48712 .75837 .4887 .75784 .48782 .75629 Mtetra
.67 .636 .807 r
.48782 .75629 .4887 .75784 .49028 .75737 .48941 .75569 Mtetra
.641 .61 .803 r
.48941 .75569 .49028 .75737 .49186 .75689 .49099 .75528 Mtetra
.648 .62 .808 r
.49099 .75528 .49186 .75689 .49345 .75617 .49258 .75482 Mtetra
.673 .663 .832 r
.49258 .75482 .49345 .75617 .49504 .75473 .49416 .75425 Mtetra
.7 .855 .956 r
.49416 .75425 .49504 .75473 .49664 .75236 .49575 .75358 Mtetra
.247 0 .028 r
.49575 .75358 .49664 .75236 .49825 .74904 .49734 .75291 Mtetra
.5 .216 .414 r
.49734 .75291 .49825 .74904 .49985 .74616 .49893 .75236 Mtetra
.536 .279 .473 r
.49893 .75236 .49985 .74616 .50144 .74542 .50052 .75194 Mtetra
.54 .285 .478 r
.50052 .75194 .50144 .74542 .50302 .74563 .5021 .75156 Mtetra
.552 .291 .473 r
.5021 .75156 .50302 .74563 .5046 .74627 .50369 .75145 Mtetra
.548 .279 .461 r
.50369 .75145 .5046 .74627 .50619 .74652 .50528 .75133 Mtetra
.505 .236 .441 r
.50528 .75133 .50619 .74652 .50778 .7456 .50688 .75064 Mtetra
.277 .045 .37 r
.50688 .75064 .50778 .7456 .50941 .73587 .50848 .7476 Mtetra
.968 .708 .485 r
.50848 .7476 .50941 .73587 .51171 .55276 .51085 .5605 Mtetra
0 0 .077 r
.51085 .5605 .51171 .55276 .51323 .54885 .5124 .54908 Mtetra
.944 .941 .755 r
.5124 .54908 .51323 .54885 .51474 .54718 .51391 .54669 Mtetra
.706 .845 .949 r
.51391 .54669 .51474 .54718 .51624 .5466 .51542 .54604 Mtetra
.54 .781 .987 r
.51542 .54604 .51624 .5466 .51775 .54633 .51693 .54585 Mtetra
.537 .804 .995 r
.51693 .54585 .51775 .54633 .51926 .54604 .51844 .54563 Mtetra
.622 .853 .987 r
.51844 .54563 .51926 .54604 .52077 .5456 .51994 .54519 Mtetra
.619 .853 .987 r
.51994 .54519 .52077 .5456 .52227 .54516 .52145 .54475 Mtetra
.621 .855 .987 r
.52145 .54475 .52227 .54516 .52379 .54471 .52297 .54431 Mtetra
.625 .858 .987 r
.52297 .54431 .52379 .54471 .5253 .54426 .52448 .54386 Mtetra
.626 .859 .987 r
.52448 .54386 .5253 .54426 .52681 .5438 .52599 .54341 Mtetra
.627 .859 .986 r
.52599 .54341 .52681 .5438 .52832 .54334 .5275 .54295 Mtetra
.628 .86 .986 r
.5275 .54295 .52832 .54334 .52983 .54288 .52902 .54248 Mtetra
.629 .86 .986 r
.52902 .54248 .52983 .54288 .53135 .54241 .53053 .54202 Mtetra
.63 .861 .986 r
.53053 .54202 .53135 .54241 .53286 .54194 .53205 .54155 Mtetra
.631 .861 .986 r
.53205 .54155 .53286 .54194 .53438 .54147 .53357 .54108 Mtetra
.632 .862 .985 r
.53357 .54108 .53438 .54147 .5359 .54099 .53508 .5406 Mtetra
.633 .863 .985 r
.53508 .5406 .5359 .54099 .53741 .54052 .5366 .54012 Mtetra
.635 .862 .985 r
.5366 .54012 .53741 .54052 .53893 .54005 .53812 .53964 Mtetra
.638 .861 .983 r
.53812 .53964 .53893 .54005 .54045 .53955 .53964 .53916 Mtetra
.641 .865 .983 r
.53964 .53916 .54045 .53955 .54197 .53899 .54116 .53866 Mtetra
.632 .88 .987 r
.54116 .53866 .54197 .53899 .54349 .53838 .54268 .53815 Mtetra
.597 .9 .986 r
.54268 .53815 .54349 .53838 .54501 .53776 .54421 .53764 Mtetra
.539 .903 .965 r
.54421 .53764 .54501 .53776 .54653 .5372 .54573 .53715 Mtetra
.483 .89 .936 r
.54573 .53715 .54653 .5372 .54806 .53671 .54725 .53667 Mtetra
.465 .883 .927 r
.54725 .53667 .54806 .53671 .54958 .53624 .54878 .53621 Mtetra
.458 .879 .926 r
.54878 .53621 .54958 .53624 .55111 .53578 .5503 .53575 Mtetra
.446 .874 .922 r
.5503 .53575 .55111 .53578 .55263 .53531 .55183 .5353 Mtetra
.426 .865 .908 r
.55183 .5353 .55263 .53531 .55416 .53487 .55336 .53486 Mtetra
.427 .866 .908 r
.55336 .53486 .55416 .53487 .55569 .53449 .55489 .53441 Mtetra
.478 .884 .943 r
.55489 .53441 .55569 .53449 .55722 .53418 .55642 .53396 Mtetra
.559 .89 .986 r
.55642 .53396 .55722 .53418 .55875 .53388 .55795 .53351 Mtetra
.61 .865 .991 r
.55795 .53351 .55875 .53388 .56028 .53354 .55948 .53307 Mtetra
.628 .84 .982 r
.55948 .53307 .56028 .53354 .56181 .5331 .56101 .53263 Mtetra
.629 .839 .981 r
.56101 .53263 .56181 .5331 .56334 .53265 .56254 .53219 Mtetra
.632 .846 .982 r
.56254 .53219 .56334 .53265 .56488 .53212 .56408 .53174 Mtetra
.629 .867 .987 r
.56408 .53174 .56488 .53212 .56641 .53152 .56561 .53125 Mtetra
.584 .885 .991 r
.56561 .53125 .56641 .53152 .56794 .5311 .56715 .5308 Mtetra
.551 .865 .996 r
.56715 .5308 .56794 .5311 .56949 .53119 .56868 .53042 Mtetra
.594 .743 .947 r
.56868 .53042 .56949 .53119 .57104 .53232 .57022 .53018 Mtetra
.609 .547 .76 r
.57022 .53018 .57104 .53232 .57262 .53435 .57177 .52995 Mtetra
.599 .461 .665 r
.57177 .52995 .57262 .53435 .5742 .53701 .57331 .52966 Mtetra
.595 .427 .625 r
.57331 .52966 .5742 .53701 .57576 .53735 .57485 .52923 Mtetra
.594 .423 .619 r
.57485 .52923 .57576 .53735 .5773 .53646 .57639 .52875 Mtetra
.596 .426 .622 r
.57639 .52875 .5773 .53646 .57883 .53541 .57793 .52827 Mtetra
.596 .43 .626 r
.57793 .52827 .57883 .53541 .58038 .53501 .57947 .52782 Mtetra
.596 .429 .626 r
.57947 .52782 .58038 .53501 .58192 .53461 .58102 .52738 Mtetra
.58102 .52738 .58192 .53461 .58347 .5342 .58256 .52693 Mtetra
.596 .428 .625 r
.58256 .52693 .58347 .5342 .58502 .5338 .58411 .52648 Mtetra
.58411 .52648 .58502 .5338 .58657 .53339 .58565 .52603 Mtetra
.58565 .52603 .58657 .53339 .58812 .53298 .5872 .52558 Mtetra
.596 .428 .624 r
.5872 .52558 .58812 .53298 .58967 .53256 .58875 .52513 Mtetra
.596 .427 .624 r
.58875 .52513 .58967 .53256 .59122 .53213 .5903 .52467 Mtetra
.5903 .52467 .59122 .53213 .59278 .53169 .59185 .52421 Mtetra
.59185 .52421 .59278 .53169 .59433 .53124 .5934 .52374 Mtetra
.5934 .52374 .59433 .53124 .59588 .53079 .59495 .52328 Mtetra
.596 .427 .623 r
.59495 .52328 .59588 .53079 .59744 .53034 .5965 .52281 Mtetra
.5965 .52281 .59744 .53034 .59899 .52989 .59805 .52235 Mtetra
.595 .427 .623 r
.59805 .52235 .59899 .52989 .60055 .52946 .59961 .52188 Mtetra
.595 .426 .623 r
.59961 .52188 .60055 .52946 .60211 .52904 .60116 .52143 Mtetra
.60116 .52143 .60211 .52904 .60367 .52867 .60272 .52098 Mtetra
.594 .425 .622 r
.60272 .52098 .60367 .52867 .60523 .52831 .60428 .52053 Mtetra
.593 .424 .621 r
.60428 .52053 .60523 .52831 .6068 .52819 .60584 .52011 Mtetra
.591 .42 .619 r
.60584 .52011 .6068 .52819 .60839 .52903 .6074 .51974 Mtetra
.589 .414 .612 r
.6074 .51974 .60839 .52903 .60997 .52889 .60896 .51935 Mtetra
.591 .414 .611 r
.60896 .51935 .60997 .52889 .61147 .52616 .61052 .51888 Mtetra
.604 .434 .625 r
.61052 .51888 .61147 .52616 .61293 .52175 .61207 .51823 Mtetra
.632 .502 .686 r
.61207 .51823 .61293 .52175 .61443 .51904 .61363 .51757 Mtetra
.67 .641 .813 r
.61363 .51757 .61443 .51904 .61596 .51737 .61519 .51699 Mtetra
.554 .849 .998 r
.61519 .51699 .61596 .51737 .61753 .51693 .61676 .51665 Mtetra
.476 .844 .99 r
.61676 .51665 .61753 .51693 .6191 .51681 .61833 .51636 Mtetra
.539 .823 .998 r
.61833 .51636 .6191 .51681 .62068 .51681 .6199 .51609 Mtetra
.623 .77 .95 r
.6199 .51609 .62068 .51681 .62225 .51651 .62147 .51573 Mtetra
.638 .76 .936 r
.62147 .51573 .62225 .51651 .62382 .51616 .62304 .51534 Mtetra
.654 .754 .923 r
.62304 .51534 .62382 .51616 .62539 .51575 .62461 .5149 Mtetra
.674 .752 .91 r
.62461 .5149 .62539 .51575 .62696 .51527 .62617 .51438 Mtetra
.683 .746 .899 r
.62617 .51438 .62696 .51527 .62852 .51473 .62774 .51381 Mtetra
.688 .741 .891 r
.62774 .51381 .62852 .51473 .63009 .51416 .62931 .51322 Mtetra
.69 .738 .887 r
.62931 .51322 .63009 .51416 .63166 .51356 .63088 .51262 Mtetra
.691 .739 .887 r
.63088 .51262 .63166 .51356 .63322 .51293 .63244 .51201 Mtetra
.691 .742 .89 r
.63244 .51201 .63322 .51293 .63479 .51231 .63401 .51141 Mtetra
.688 .745 .895 r
.63401 .51141 .63479 .51231 .63636 .51172 .63558 .51082 Mtetra
.686 .745 .896 r
.63558 .51082 .63636 .51172 .63793 .51111 .63715 .51024 Mtetra
.686 .75 .9 r
.63715 .51024 .63793 .51111 .6395 .51048 .63873 .50966 Mtetra
.687 .764 .91 r
.63873 .50966 .6395 .51048 .64107 .50975 .6403 .50908 Mtetra
.684 .801 .937 r
.6403 .50908 .64107 .50975 .64264 .50903 .64187 .5085 Mtetra
.674 .839 .963 r
.64187 .5085 .64264 .50903 .64421 .50835 .64345 .50793 Mtetra
.662 .872 .978 r
.64345 .50793 .64421 .50835 .64577 .50761 .64502 .50736 Mtetra
.607 .902 .985 r
.64502 .50736 .64577 .50761 .64735 .50706 .6466 .50682 Mtetra
.576 .894 .987 r
.6466 .50682 .64735 .50706 .64894 .50682 .64818 .50633 Mtetra
.582 .824 .99 r
.64818 .50633 .64894 .50682 .65057 .5077 .64977 .50599 Mtetra
.623 .594 .8 r
.64977 .50599 .65057 .5077 .65224 .50936 .65136 .50568 Mtetra
.605 .482 .685 r
.65136 .50568 .65224 .50936 .65395 .51219 .65295 .50536 Mtetra
.616 .446 .629 r
.65295 .50536 .65395 .51219 .65552 .51143 .65451 .50443 Mtetra
.603 .436 .628 r
.65451 .50443 .65552 .51143 .65709 .51053 .65609 .50382 Mtetra
.574 .418 .632 r
.65609 .50382 .65709 .51053 .65871 .51082 .6577 .5039 Mtetra
.273 .205 .595 r
.6577 .5039 .65871 .51082 .66801 .69994 .6595 .50867 Mtetra
.056 0 .447 r
.6595 .50867 .66801 .69994 .66996 .70601 .66903 .70221 Mtetra
0 .016 .556 r
.66903 .70221 .66996 .70601 .67176 .70825 .67092 .70679 Mtetra
.481 .565 .863 r
.67092 .70679 .67176 .70825 .67347 .70843 .67264 .70711 Mtetra
.648 .667 .855 r
.67264 .70711 .67347 .70843 .67517 .70798 .67434 .70667 Mtetra
.711 .692 .831 r
.67434 .70667 .67517 .70798 .67684 .70702 .67601 .70582 Mtetra
.595 .664 .886 r
.67601 .70582 .67684 .70702 .67848 .70554 .67772 .70562 Mtetra
.351 .827 .827 r
.67772 .70562 .67848 .70554 .6801 .70327 .67941 .7051 Mtetra
.251 0 .171 r
.67941 .7051 .6801 .70327 .68163 .69926 .68107 .70389 Mtetra
0 0 .262 r
.68107 .70389 .68163 .69926 .67483 .51009 .68255 .69862 Mtetra
.048 0 .439 r
.68255 .69862 .67483 .51009 .67609 .50195 .67546 .50414 Mtetra
.818 .779 .273 r
.67546 .50414 .67609 .50195 .67757 .49902 .67681 .49823 Mtetra
.792 .796 .856 r
.67681 .49823 .67757 .49902 .67915 .49813 .67838 .49704 Mtetra
.627 .685 .885 r
.67838 .49704 .67915 .49813 .68076 .49782 .67998 .49671 Mtetra
.515 .632 .904 r
.67998 .49671 .68076 .49782 .68238 .4978 .68161 .49681 Mtetra
.617 .703 .906 r
.68161 .49681 .68238 .4978 .68399 .49749 .68322 .49651 Mtetra
.635 .714 .904 r
.68322 .49651 .68399 .49749 .68559 .49711 .68483 .49615 Mtetra
.646 .721 .903 r
.68483 .49615 .68559 .49711 .6872 .49668 .68644 .49574 Mtetra
.677 .737 .895 r
.68644 .49574 .6872 .49668 .6888 .49612 .68804 .49519 Mtetra
.691 .744 .892 r
.68804 .49519 .6888 .49612 .69039 .4955 .68963 .49457 Mtetra
.697 .748 .891 r
.68963 .49457 .69039 .4955 .69199 .49484 .69123 .49393 Mtetra
.772 .769 .85 r
.69123 .49393 .69199 .49484 .69356 .49374 .69281 .49283 Mtetra
.727 .759 .878 r
.69281 .49283 .69356 .49374 .69515 .49294 .6944 .49203 Mtetra
.564 .701 .933 r
.6944 .49203 .69515 .49294 .69678 .49281 .69602 .4919 Mtetra
.823 .384 0 r
.69602 .4919 .69678 .49281 .6986 .49639 .69784 .49547 Mtetra
.97 .683 .428 r
.69784 .49547 .6986 .49639 .7105 .69067 .70971 .68979 Mtetra
.915 .519 .135 r
.70971 .68979 .7105 .69067 .71254 .69637 .71175 .69551 Mtetra
.208 .54 .927 r
.71175 .69551 .71254 .69637 .71431 .69695 .71352 .69612 Mtetra
.651 .769 .935 r
.71352 .69612 .71431 .69695 .71602 .69645 .71523 .69564 Mtetra
.741 .799 .898 r
.71523 .69564 .71602 .69645 .71771 .69556 .71692 .69474 Mtetra
.543 .728 .96 r
.71692 .69474 .71771 .69556 .71946 .6956 .71866 .69461 Mtetra
.596 .71 .923 r
.71866 .69461 .71946 .6956 .7212 .69553 .72039 .69436 Mtetra
.722 .722 .85 r
.72039 .69436 .7212 .69553 .72291 .69482 .72209 .69348 Mtetra
.898 .735 .671 r
.72209 .69348 .72291 .69482 .72443 .69095 .7236 .68934 Mtetra
.97 .688 .438 r
.7236 .68934 .72443 .69095 .71509 .49749 .71426 .49502 Mtetra
.9 .676 .591 r
.71426 .49502 .71509 .49749 .71619 .48778 .71544 .48684 Mtetra
.829 .775 .8 r
.71544 .48684 .71619 .48778 .71773 .48606 .71699 .48517 Mtetra
.655 .744 .915 r
.71699 .48517 .71773 .48606 .71936 .48561 .71861 .48471 Mtetra
.527 .687 .94 r
.71861 .48471 .71936 .48561 .72101 .48563 .72026 .48468 Mtetra
.629 .72 .912 r
.72026 .48468 .72101 .48563 .72264 .48534 .72189 .48433 Mtetra
.664 .721 .891 r
.72189 .48433 .72264 .48534 .72427 .48488 .72351 .48384 Mtetra
.666 .713 .884 r
.72351 .48384 .72427 .48488 .72589 .48437 .72514 .48333 Mtetra
.666 .714 .885 r
.72514 .48333 .72589 .48437 .7275 .48372 .72676 .48282 Mtetra
.667 .746 .909 r
.72676 .48282 .7275 .48372 .72912 .48301 .72839 .48231 Mtetra
.666 .796 .945 r
.72839 .48231 .72912 .48301 .73073 .48231 .73001 .48178 Mtetra
.659 .848 .972 r
.73001 .48178 .73073 .48231 .73235 .48169 .73164 .48123 Mtetra
.654 .866 .979 r
.73164 .48123 .73235 .48169 .73397 .48113 .73326 .48067 Mtetra
.654 .866 .98 r
.73326 .48067 .73397 .48113 .7356 .48058 .73489 .4801 Mtetra
.651 .859 .979 r
.73489 .4801 .7356 .48058 .73723 .48004 .73651 .47956 Mtetra
.646 .856 .98 r
.73651 .47956 .73723 .48004 .73885 .4795 .73814 .47903 Mtetra
.64 .857 .982 r
.73814 .47903 .73885 .4795 .74048 .47898 .73977 .47851 Mtetra
.635 .858 .984 r
.73977 .47851 .74048 .47898 .74211 .47846 .74141 .478 Mtetra
.629 .858 .986 r
.74141 .478 .74211 .47846 .74375 .47796 .74304 .4775 Mtetra
.623 .858 .987 r
.74304 .4775 .74375 .47796 .74538 .47747 .74468 .47702 Mtetra
.613 .857 .99 r
.74468 .47702 .74538 .47747 .74702 .47698 .74632 .47655 Mtetra
.601 .86 .993 r
.74632 .47655 .74702 .47698 .74866 .4765 .74796 .4761 Mtetra
.592 .864 .994 r
.74796 .4761 .74866 .4765 .7503 .47606 .7496 .47565 Mtetra
.599 .865 .993 r
.7496 .47565 .7503 .47606 .75195 .47572 .75124 .47519 Mtetra
.626 .839 .982 r
.75124 .47519 .75195 .47572 .7536 .47543 .75288 .47473 Mtetra
.644 .791 .953 r
.75288 .47473 .7536 .47543 .75526 .47516 .75453 .47428 Mtetra
.643 .743 .921 r
.75453 .47428 .75526 .47516 .75691 .47483 .75618 .47386 Mtetra
.639 .722 .908 r
.75618 .47386 .75691 .47483 .75856 .47443 .75783 .47347 Mtetra
.637 .721 .909 r
.75783 .47347 .75856 .47443 .76021 .47401 .75948 .47308 Mtetra
.637 .729 .915 r
.75948 .47308 .76021 .47401 .76186 .4736 .76113 .47269 Mtetra
.639 .737 .919 r
.76113 .47269 .76186 .4736 .76351 .47317 .76278 .47229 Mtetra
.641 .742 .922 r
.76278 .47229 .76351 .47317 .76516 .47274 .76444 .47187 Mtetra
.644 .748 .925 r
.76444 .47187 .76516 .47274 .76681 .4723 .76609 .47145 Mtetra
.648 .755 .927 r
.76609 .47145 .76681 .4723 .76846 .47184 .76774 .471 Mtetra
.654 .761 .928 r
.76774 .471 .76846 .47184 .77011 .47136 .7694 .47053 Mtetra
.662 .766 .927 r
.7694 .47053 .77011 .47136 .77177 .47085 .77105 .47003 Mtetra
.67 .77 .925 r
.77105 .47003 .77177 .47085 .77341 .47032 .7727 .46949 Mtetra
.677 .77 .921 r
.7727 .46949 .77341 .47032 .77506 .46977 .77435 .46893 Mtetra
.686 .771 .916 r
.77435 .46893 .77506 .46977 .77671 .4692 .77599 .46832 Mtetra
.692 .764 .907 r
.77599 .46832 .77671 .4692 .77836 .46861 .77764 .46769 Mtetra
.692 .755 .9 r
.77764 .46769 .77836 .46861 .78 .46798 .77928 .46706 Mtetra
.687 .753 .902 r
.77928 .46706 .78 .46798 .78164 .46726 .78093 .46645 Mtetra
.682 .778 .923 r
.78093 .46645 .78164 .46726 .78328 .46649 .78258 .46586 Mtetra
.675 .827 .956 r
.78258 .46586 .78328 .46649 .78491 .46573 .78423 .46528 Mtetra
.661 .874 .979 r
.78423 .46528 .78491 .46573 .78656 .46506 .78588 .46467 Mtetra
.652 .893 .983 r
.78588 .46467 .78656 .46506 .78821 .46446 .78753 .46406 Mtetra
.653 .888 .982 r
.78753 .46406 .78821 .46446 .78987 .46389 .78919 .46345 Mtetra
.653 .876 .981 r
.78919 .46345 .78987 .46389 .79152 .46334 .79084 .46286 Mtetra
.65 .865 .98 r
.79084 .46286 .79152 .46334 .79318 .46279 .7925 .4623 Mtetra
.648 .86 .98 r
.7925 .4623 .79318 .46279 .79484 .46225 .79416 .46174 Mtetra
.647 .856 .98 r
.79416 .46174 .79484 .46225 .7965 .46171 .79582 .4612 Mtetra
.645 .853 .979 r
.79582 .4612 .7965 .46171 .79817 .46118 .79749 .46066 Mtetra
.644 .85 .979 r
.79749 .46066 .79817 .46118 .79983 .46066 .79915 .46014 Mtetra
.643 .848 .979 r
.79915 .46014 .79983 .46066 .80149 .46014 .80082 .45961 Mtetra
.642 .847 .979 r
.80082 .45961 .80149 .46014 .80316 .45963 .80248 .45909 Mtetra
.64 .845 .979 r
.80248 .45909 .80316 .45963 .80483 .45911 .80415 .45858 Mtetra
.639 .844 .979 r
.80415 .45858 .80483 .45911 .8065 .4586 .80582 .45807 Mtetra
.638 .844 .979 r
.80582 .45807 .8065 .4586 .80817 .4581 .80749 .45756 Mtetra
.636 .843 .98 r
.80749 .45756 .80817 .4581 .80984 .4576 .80917 .45706 Mtetra
.634 .843 .98 r
.80917 .45706 .80984 .4576 .81152 .4571 .81084 .45657 Mtetra
.631 .843 .981 r
.81084 .45657 .81152 .4571 .81319 .4566 .81252 .45608 Mtetra
.627 .843 .983 r
.81252 .45608 .81319 .4566 .81487 .45612 .8142 .45559 Mtetra
.621 .843 .984 r
.8142 .45559 .81487 .45612 .81654 .45563 .81588 .45512 Mtetra
.613 .846 .988 r
.81588 .45512 .81654 .45563 .81822 .45514 .81756 .45467 Mtetra
.606 .852 .991 r
.81756 .45467 .81822 .45514 .8199 .45469 .81924 .45421 Mtetra
.609 .853 .99 r
.81924 .45421 .8199 .45469 .82159 .45431 .82092 .45375 Mtetra
.628 .836 .98 r
.82092 .45375 .82159 .45431 .82329 .454 .82261 .45328 Mtetra
.646 .791 .952 r
.82261 .45328 .82329 .454 .82499 .45371 .82429 .4528 Mtetra
.651 .745 .918 r
.82429 .4528 .82499 .45371 .82669 .45336 .82598 .45234 Mtetra
.65 .719 .899 r
.82598 .45234 .82669 .45336 .82838 .45293 .82767 .45189 Mtetra
.65 .716 .897 r
.82767 .45189 .82838 .45293 .83007 .45246 .82936 .45144 Mtetra
.651 .721 .9 r
.82936 .45144 .83007 .45246 .83175 .45198 .83105 .45099 Mtetra
.654 .728 .903 r
.83105 .45099 .83175 .45198 .83344 .4515 .83274 .45052 Mtetra
.656 .729 .904 r
.83274 .45052 .83344 .4515 .83513 .45102 .83443 .45004 Mtetra
.657 .731 .904 r
.83443 .45004 .83513 .45102 .83682 .45053 .83612 .44955 Mtetra
.659 .733 .904 r
.83612 .44955 .83682 .45053 .83851 .45004 .83781 .44906 Mtetra
.66 .734 .904 r
.83781 .44906 .83851 .45004 .8402 .44953 .8395 .44856 Mtetra
.661 .735 .905 r
.8395 .44856 .8402 .44953 .84189 .44903 .8412 .44806 Mtetra
.662 .736 .905 r
.8412 .44806 .84189 .44903 .84359 .44852 .84289 .44755 Mtetra
.663 .737 .905 r
.84289 .44755 .84359 .44852 .84528 .44801 .84458 .44704 Mtetra
.664 .737 .905 r
.84458 .44704 .84528 .44801 .84697 .44749 .84628 .44652 Mtetra
.665 .738 .905 r
.84628 .44652 .84697 .44749 .84867 .44696 .84797 .446 Mtetra
.666 .739 .905 r
.84797 .446 .84867 .44696 .85036 .44644 .84967 .44547 Mtetra
.667 .74 .905 r
.84967 .44547 .85036 .44644 .85205 .4459 .85136 .44494 Mtetra
.668 .741 .905 r
.85136 .44494 .85205 .4459 .85375 .44536 .85306 .44441 Mtetra
.669 .742 .905 r
.85306 .44441 .85375 .44536 .85545 .44482 .85475 .44386 Mtetra
.67 .744 .906 r
.85475 .44386 .85545 .44482 .85714 .44427 .85645 .44332 Mtetra
.671 .745 .906 r
.85645 .44332 .85714 .44427 .85884 .44373 .85815 .44277 Mtetra
.672 .744 .905 r
.85815 .44277 .85884 .44373 .86053 .44315 .85985 .44221 Mtetra
.675 .749 .906 r
.85985 .44221 .86053 .44315 .86222 .44252 .86155 .44164 Mtetra
.678 .766 .917 r
.86155 .44164 .86222 .44252 .86391 .4418 .86324 .44105 Mtetra
.675 .8 .941 r
.86324 .44105 .86391 .4418 .86559 .44108 .86494 .44047 Mtetra
.664 .834 .965 r
.86494 .44047 .86559 .44108 .86728 .44041 .86664 .43989 Mtetra
.647 .856 .979 r
.86664 .43989 .86728 .44041 .86898 .43984 .86834 .43933 Mtetra
.641 .86 .982 r
.86834 .43933 .86898 .43984 .87068 .43929 .87005 .43878 Mtetra
.64 .859 .983 r
.87005 .43878 .87068 .43929 .87239 .43875 .87175 .43824 Mtetra
.64 .856 .982 r
.87175 .43824 .87239 .43875 .8741 .43821 .87346 .43769 Mtetra
.638 .856 .982 r
.87346 .43769 .8741 .43821 .8758 .43768 .87517 .43716 Mtetra
.636 .855 .983 r
.87517 .43716 .8758 .43768 .87751 .43714 .87688 .43663 Mtetra
.635 .854 .983 r
.87688 .43663 .87751 .43714 .87922 .43662 .87859 .4361 Mtetra
.633 .853 .983 r
.87859 .4361 .87922 .43662 .88094 .4361 .88031 .43557 Mtetra
.631 .852 .984 r
.88031 .43557 .88094 .4361 .88265 .43558 .88202 .43506 Mtetra
.63 .851 .984 r
.88202 .43506 .88265 .43558 .88437 .43507 .88374 .43454 Mtetra
.627 .85 .984 r
.88374 .43454 .88437 .43507 .88609 .43456 .88546 .43404 Mtetra
.625 .849 .985 r
.88546 .43404 .88609 .43456 .8878 .43406 .88718 .43354 Mtetra
.622 .849 .986 r
.88718 .43354 .8878 .43406 .88952 .43356 .8889 .43304 Mtetra
.615 .849 .988 r
.8889 .43304 .88952 .43356 .89125 .43308 .89062 .43256 Mtetra
.61 .846 .989 r
.89062 .43256 .89125 .43308 .89298 .43266 .89235 .4321 Mtetra
.608 .833 .986 r
.89235 .4321 .89298 .43266 .89472 .43233 .89408 .43166 Mtetra
.623 .805 .97 r
.89408 .43166 .89472 .43233 .89647 .43203 .89582 .43123 Mtetra
.635 .774 .947 r
.89582 .43123 .89647 .43203 .89822 .43169 .89755 .4308 Mtetra
.643 .751 .927 r
.89755 .4308 .89822 .43169 .89995 .43126 .89929 .43035 Mtetra
.648 .749 .923 r
.89929 .43035 .89995 .43126 .90168 .43079 .90102 .42989 Mtetra
.653 .754 .924 r
.90102 .42989 .90168 .43079 .90341 .43028 .90275 .4294 Mtetra
.66 .762 .925 r
.90275 .4294 .90341 .43028 .90514 .42976 .90448 .42888 Mtetra
.669 .765 .922 r
.90448 .42888 .90514 .42976 .90686 .42919 .90621 .42833 Mtetra
.679 .773 .922 r
.90621 .42833 .90686 .42919 .90858 .42855 .90793 .42773 Mtetra
.693 .792 .926 r
.90793 .42773 .90858 .42855 .91028 .42776 .90964 .42707 Mtetra
.694 .827 .946 r
.90964 .42707 .91028 .42776 .91197 .42696 .91136 .42639 Mtetra
.706 .866 .958 r
.91136 .42639 .91197 .42696 .91367 .42613 .91306 .42564 Mtetra
.78 .908 .929 r
.91306 .42564 .91367 .42613 .91534 .42508 .91473 .42457 Mtetra
.673 .874 .974 r
.91473 .42457 .91534 .42508 .91706 .42444 .91645 .42391 Mtetra
.266 .66 .967 r
.91645 .42391 .91706 .42444 .91889 .42468 .91828 .42417 Mtetra
.839 .398 0 r
.91828 .42417 .91889 .42468 .92121 .42893 .92065 .42885 Mtetra
.973 .661 .316 r
.92065 .42885 .92121 .42893 .94736 .6278 .94674 .62746 Mtetra
.845 .394 0 r
.94674 .62746 .94736 .6278 .94991 .6329 .94923 .63206 Mtetra
.463 .696 .968 r
.94923 .63206 .94991 .6329 .95184 .63302 .95116 .63214 Mtetra
.687 .787 .927 r
.95116 .63214 .95184 .63302 .95368 .63235 .953 .63145 Mtetra
.74 .802 .902 r
.953 .63145 .95368 .63235 .95549 .6314 .95481 .6305 Mtetra
.48 .689 .959 r
.95481 .6305 .95549 .6314 .95742 .63147 .95674 .63057 Mtetra
.614 .752 .943 r
.95674 .63057 .95742 .63147 .9593 .63111 .95862 .63019 Mtetra
.797 .814 .865 r
.95862 .63019 .9593 .63111 .96107 .62978 .96038 .62886 Mtetra
.98 .776 .557 r
.96038 .62886 .96107 .62978 .96214 .62301 .96145 .62208 Mtetra
.975 .669 .322 r
.96145 .62208 .96214 .62301 .93863 .42348 .93798 .42249 Mtetra
.962 .783 .613 r
.93798 .42249 .93863 .42348 .93982 .41859 .93917 .4176 Mtetra
.755 .775 .869 r
.93917 .4176 .93982 .41859 .94151 .41756 .94086 .41657 Mtetra
.626 .723 .917 r
.94086 .41657 .94151 .41756 .94328 .4172 .94263 .4162 Mtetra
.544 .684 .93 r
.94263 .4162 .94328 .4172 .94509 .41713 .94444 .41614 Mtetra
.747 .772 .873 r
.94444 .41614 .94509 .41713 .94679 .41616 .94613 .41516 Mtetra
.681 .747 .901 r
.94613 .41516 .94679 .41616 .94853 .41554 .94788 .41455 Mtetra
.489 .654 .933 r
.94788 .41455 .94853 .41554 .95037 .41566 .94972 .41467 Mtetra
.738 .321 0 r
.94972 .41467 .95037 .41566 .95283 .4205 .95218 .41948 Mtetra
.97 .655 .291 r
.95218 .41948 .95283 .4205 .98106 .61973 .98038 .61876 Mtetra
.728 .301 0 r
.98038 .61876 .98106 .61973 .98363 .62443 .98296 .62349 Mtetra
.038 .466 .88 r
.37534 .78508 .37626 .78583 .37774 .78645 .37681 .7857 Mtetra
.644 .762 .934 r
.37681 .7857 .37774 .78645 .37926 .78605 .37833 .7853 Mtetra
.81 .779 .824 r
.37833 .7853 .37926 .78605 .38082 .78462 .3799 .78388 Mtetra
.909 .738 .658 r
.3799 .78388 .38082 .78462 .38253 .77932 .38161 .77866 Mtetra
.937 .687 .534 r
.38161 .77866 .38253 .77932 .39146 .58961 .39058 .58898 Mtetra
.917 .738 .645 r
.39058 .58898 .39146 .58961 .39309 .58408 .39223 .58334 Mtetra
.775 .775 .853 r
.39223 .58334 .39309 .58408 .39456 .58307 .39369 .58231 Mtetra
.612 .741 .937 r
.39369 .58231 .39456 .58307 .39599 .58281 .39513 .58204 Mtetra
.445 .673 .96 r
.39513 .58204 .39599 .58281 .39741 .58295 .39655 .58215 Mtetra
.631 .734 .922 r
.39655 .58215 .39741 .58295 .39885 .58265 .39799 .58183 Mtetra
.647 .735 .913 r
.39799 .58183 .39885 .58265 .40029 .58229 .39943 .58145 Mtetra
.66 .733 .903 r
.39943 .58145 .40029 .58229 .40174 .58191 .40088 .58102 Mtetra
.719 .737 .865 r
.40088 .58102 .40174 .58191 .40318 .58145 .40233 .5803 Mtetra
.696 .685 .835 r
.40233 .5803 .40318 .58145 .40463 .58096 .40379 .57966 Mtetra
.654 .646 .83 r
.40379 .57966 .40463 .58096 .40608 .58047 .40524 .57923 Mtetra
.276 .472 .871 r
.40524 .57923 .40608 .58047 .40753 .58003 .40665 .57991 Mtetra
.717 .194 0 r
.40665 .57991 .40753 .58003 .40898 .57958 .40804 .58113 Mtetra
.688 .334 .37 r
.40804 .58113 .40898 .57958 .41043 .57913 .40943 .58243 Mtetra
.254 0 .296 r
.40943 .58243 .41043 .57913 .41188 .57861 .41094 .58048 Mtetra
0 0 0 r
.41094 .58048 .41188 .57861 .41334 .57808 .41245 .57822 Mtetra
.903 .949 .823 r
.41245 .57822 .41334 .57808 .41479 .57755 .41395 .57643 Mtetra
.715 .695 .83 r
.41395 .57643 .41479 .57755 .41625 .57708 .41541 .57566 Mtetra
.656 .633 .815 r
.41541 .57566 .41625 .57708 .4177 .57662 .41686 .57521 Mtetra
.635 .625 .823 r
.41686 .57521 .4177 .57662 .41916 .57616 .41832 .57488 Mtetra
.658 .652 .832 r
.41832 .57488 .41916 .57616 .42061 .57568 .41977 .57443 Mtetra
.66 .658 .837 r
.41977 .57443 .42061 .57568 .42207 .57519 .42123 .57398 Mtetra
.657 .662 .843 r
.42123 .57398 .42207 .57519 .42353 .5747 .42268 .57354 Mtetra
.64 .666 .859 r
.42268 .57354 .42353 .5747 .42499 .57419 .42414 .5732 Mtetra
.637 .694 .887 r
.42414 .5732 .42499 .57419 .42645 .57371 .4256 .57286 Mtetra
.644 .731 .912 r
.4256 .57286 .42645 .57371 .42791 .57326 .42705 .57249 Mtetra
.688 .76 .907 r
.42705 .57249 .42791 .57326 .42936 .57294 .42852 .57195 Mtetra
.695 .713 .862 r
.42852 .57195 .42936 .57294 .43082 .57268 .42998 .57134 Mtetra
.681 .654 .817 r
.42998 .57134 .43082 .57268 .43228 .57241 .43145 .57074 Mtetra
.689 .62 .774 r
.43145 .57074 .43228 .57241 .43375 .57164 .43292 .56998 Mtetra
.666 .611 .784 r
.43292 .56998 .43375 .57164 .43522 .571 .43439 .5694 Mtetra
.598 .585 .809 r
.43439 .5694 .43522 .571 .43667 .57096 .43584 .56926 Mtetra
0 .141 .683 r
.43584 .56926 .43667 .57096 .43804 .57427 .43725 .57101 Mtetra
.822 .533 0 r
.43725 .57101 .43804 .57427 .43474 .76326 .43854 .57741 Mtetra
0 0 .36 r
.43854 .57741 .43474 .76326 .43614 .76909 .43535 .76362 Mtetra
.474 .36 .644 r
.43535 .76362 .43614 .76909 .43766 .7699 .43686 .76508 Mtetra
.609 .464 .659 r
.43686 .76508 .43766 .7699 .43921 .76955 .43841 .76461 Mtetra
.624 .473 .656 r
.43841 .76461 .43921 .76955 .44078 .76879 .43997 .76384 Mtetra
.506 .391 .656 r
.43997 .76384 .44078 .76879 .44233 .76831 .4415 .76481 Mtetra
.44 .381 .695 r
.4415 .76481 .44233 .76831 .44389 .76793 .44301 .76599 Mtetra
.401 .454 .8 r
.44301 .76599 .44389 .76793 .44544 .76749 .44455 .76676 Mtetra
.341 .649 .968 r
.44455 .76676 .44544 .76749 .447 .76726 .44609 .767 Mtetra
.437 .829 .984 r
.44609 .767 .447 .76726 .44856 .76683 .44765 .76676 Mtetra
.681 .951 .955 r
.44765 .76676 .44856 .76683 .45013 .76579 .44921 .76597 Mtetra
.943 .914 .759 r
.44921 .76597 .45013 .76579 .45177 .7617 .45082 .76337 Mtetra
.995 .868 .546 r
.45082 .76337 .45177 .7617 .4571 .57202 .4525 .75692 Mtetra
0 0 .353 r
.4525 .75692 .4571 .57202 .45872 .56483 .45778 .56892 Mtetra
.21 0 .317 r
.45778 .56892 .45872 .56483 .46022 .56309 .4593 .56615 Mtetra
.499 .199 .388 r
.4593 .56615 .46022 .56309 .4617 .56259 .46078 .56576 Mtetra
.541 .242 .409 r
.46078 .56576 .4617 .56259 .46317 .56251 .46225 .56572 Mtetra
.31 .033 .32 r
.46225 .56572 .46317 .56251 .46464 .56222 .46375 .56405 Mtetra
0 0 0 r
.46375 .56405 .46464 .56222 .46612 .56179 .46526 .56203 Mtetra
.863 .99 .835 r
.46526 .56203 .46612 .56179 .4676 .56136 .46676 .56046 Mtetra
.728 .741 .862 r
.46676 .56046 .4676 .56136 .46908 .56092 .46825 .55967 Mtetra
.638 .652 .847 r
.46825 .55967 .46908 .56092 .47057 .56047 .46973 .55933 Mtetra
.606 .658 .874 r
.46973 .55933 .47057 .56047 .47205 .56001 .47121 .55912 Mtetra
.633 .72 .91 r
.47121 .55912 .47205 .56001 .47354 .55951 .4727 .55879 Mtetra
.66 .771 .931 r
.4727 .55879 .47354 .55951 .47502 .559 .47418 .55834 Mtetra
.671 .789 .938 r
.47418 .55834 .47502 .559 .47651 .55853 .47567 .55785 Mtetra
.742 .795 .895 r
.47567 .55785 .47651 .55853 .478 .55791 .47716 .55705 Mtetra
.73 .752 .87 r
.47716 .55705 .478 .55791 .47948 .55741 .47865 .55626 Mtetra
.644 .672 .861 r
.47865 .55626 .47948 .55741 .48096 .55746 .48014 .55589 Mtetra
.116 .314 .785 r
.48014 .55589 .48096 .55746 .48242 .56009 .48161 .55716 Mtetra
0 0 .193 r
.48161 .55716 .48242 .56009 .48161 .74885 .48303 .56228 Mtetra
0 0 .379 r
.48303 .56228 .48161 .74885 .4831 .75604 .48228 .75008 Mtetra
.404 .305 .628 r
.48228 .75008 .4831 .75604 .48466 .75731 .48382 .75254 Mtetra
.605 .462 .661 r
.48382 .75254 .48466 .75731 .48624 .75703 .4854 .75214 Mtetra
.627 .475 .657 r
.4854 .75214 .48624 .75703 .48782 .75629 .48698 .75133 Mtetra
.541 .415 .658 r
.48698 .75133 .48782 .75629 .48941 .75569 .48856 .75188 Mtetra
.454 .381 .685 r
.48856 .75188 .48941 .75569 .49099 .75528 .49012 .75309 Mtetra
.415 .439 .776 r
.49012 .75309 .49099 .75528 .49258 .75482 .4917 .75393 Mtetra
.424 .647 .95 r
.4917 .75393 .49258 .75482 .49416 .75425 .49328 .75413 Mtetra
.338 .804 .926 r
.49328 .75413 .49416 .75425 .49575 .75358 .49486 .75389 Mtetra
0 0 0 r
.49486 .75389 .49575 .75358 .49734 .75291 .49645 .75347 Mtetra
.04 0 0 r
.49645 .75347 .49734 .75291 .49893 .75236 .49804 .75298 Mtetra
.047 0 0 r
.49804 .75298 .49893 .75236 .50052 .75194 .49963 .75245 Mtetra
0 0 0 r
.49963 .75245 .50052 .75194 .5021 .75156 .50122 .75189 Mtetra
.015 0 0 r
.50122 .75189 .5021 .75156 .50369 .75145 .50281 .75159 Mtetra
0 0 0 r
.50281 .75159 .50369 .75145 .50528 .75133 .5044 .75136 Mtetra
.505 .907 .912 r
.5044 .75136 .50528 .75133 .50688 .75064 .506 .75076 Mtetra
.916 .951 .804 r
.506 .75076 .50688 .75064 .50848 .7476 .5076 .74869 Mtetra
.994 .874 .581 r
.5076 .74869 .50848 .7476 .51085 .5605 .50921 .74321 Mtetra
0 0 .371 r
.50921 .74321 .51085 .5605 .5124 .54908 .51155 .55388 Mtetra
.038 0 .275 r
.51155 .55388 .5124 .54908 .51391 .54669 .51308 .54945 Mtetra
.438 .132 .348 r
.51308 .54945 .51391 .54669 .51542 .54604 .51459 .5487 Mtetra
.538 .222 .38 r
.51459 .5487 .51542 .54604 .51693 .54585 .5161 .5487 Mtetra
.536 .227 .39 r
.5161 .5487 .51693 .54585 .51844 .54563 .5176 .54867 Mtetra
.496 .196 .386 r
.5176 .54867 .51844 .54563 .51994 .54519 .51912 .54825 Mtetra
.498 .198 .388 r
.51912 .54825 .51994 .54519 .52145 .54475 .52063 .54784 Mtetra
.497 .198 .389 r
.52063 .54784 .52145 .54475 .52297 .54431 .52214 .54742 Mtetra
.495 .197 .389 r
.52214 .54742 .52297 .54431 .52448 .54386 .52366 .54698 Mtetra
.494 .196 .389 r
.52366 .54698 .52448 .54386 .52599 .54341 .52517 .54653 Mtetra
.52517 .54653 .52599 .54341 .5275 .54295 .52669 .54608 Mtetra
.493 .196 .389 r
.52669 .54608 .5275 .54295 .52902 .54248 .5282 .54561 Mtetra
.493 .195 .389 r
.5282 .54561 .52902 .54248 .53053 .54202 .52972 .54514 Mtetra
.492 .194 .388 r
.52972 .54514 .53053 .54202 .53205 .54155 .53124 .54467 Mtetra
.491 .193 .388 r
.53124 .54467 .53205 .54155 .53357 .54108 .53276 .54419 Mtetra
.49 .192 .387 r
.53276 .54419 .53357 .54108 .53508 .5406 .53428 .5437 Mtetra
.489 .191 .386 r
.53428 .5437 .53508 .5406 .5366 .54012 .5358 .54321 Mtetra
.488 .19 .385 r
.5358 .54321 .5366 .54012 .53812 .53964 .53732 .54272 Mtetra
.487 .188 .384 r
.53732 .54272 .53812 .53964 .53964 .53916 .53884 .54221 Mtetra
.486 .186 .383 r
.53884 .54221 .53964 .53916 .54116 .53866 .54037 .5417 Mtetra
.485 .185 .382 r
.54037 .5417 .54116 .53866 .54268 .53815 .54189 .54119 Mtetra
.54189 .54119 .54268 .53815 .54421 .53764 .54341 .54068 Mtetra
.487 .187 .382 r
.54341 .54068 .54421 .53764 .54573 .53715 .54494 .54019 Mtetra
.489 .189 .383 r
.54494 .54019 .54573 .53715 .54725 .53667 .54647 .53971 Mtetra
.49 .19 .384 r
.54647 .53971 .54725 .53667 .54878 .53621 .54799 .53924 Mtetra
.506 .205 .389 r
.54799 .53924 .54878 .53621 .5503 .53575 .54952 .53891 Mtetra
.523 .224 .401 r
.54952 .53891 .5503 .53575 .55183 .5353 .55105 .53871 Mtetra
.493 .203 .401 r
.55105 .53871 .55183 .5353 .55336 .53486 .55258 .53817 Mtetra
.375 .096 .356 r
.55258 .53817 .55336 .53486 .55489 .53441 .55411 .53675 Mtetra
.085 0 .162 r
.55411 .53675 .55489 .53441 .55642 .53396 .55562 .53468 Mtetra
.658 .912 .597 r
.55562 .53468 .55642 .53396 .55795 .53351 .55714 .53297 Mtetra
.803 .843 .881 r
.55714 .53297 .55795 .53351 .55948 .53307 .55867 .53183 Mtetra
.673 .672 .841 r
.55867 .53183 .55948 .53307 .56101 .53263 .5602 .53129 Mtetra
.641 .644 .838 r
.5602 .53129 .56101 .53263 .56254 .53219 .56173 .53092 Mtetra
.637 .652 .848 r
.56173 .53092 .56254 .53219 .56408 .53174 .56327 .53057 Mtetra
.657 .677 .858 r
.56327 .53057 .56408 .53174 .56561 .53125 .5648 .53012 Mtetra
.658 .684 .863 r
.5648 .53012 .56561 .53125 .56715 .5308 .56634 .52967 Mtetra
.659 .685 .864 r
.56634 .52967 .56715 .5308 .56868 .53042 .56788 .52921 Mtetra
.659 .672 .851 r
.56788 .52921 .56868 .53042 .57022 .53018 .56941 .52875 Mtetra
.655 .638 .821 r
.56941 .52875 .57022 .53018 .57177 .52995 .57095 .52828 Mtetra
.648 .607 .794 r
.57095 .52828 .57177 .52995 .57331 .52966 .57249 .52782 Mtetra
.642 .588 .779 r
.57249 .52782 .57331 .52966 .57485 .52923 .57403 .52738 Mtetra
.642 .587 .778 r
.57403 .52738 .57485 .52923 .57639 .52875 .57557 .52694 Mtetra
.642 .59 .781 r
.57557 .52694 .57639 .52875 .57793 .52827 .57712 .5265 Mtetra
.643 .595 .785 r
.57712 .5265 .57793 .52827 .57947 .52782 .57866 .52606 Mtetra
.643 .596 .786 r
.57866 .52606 .57947 .52782 .58102 .52738 .5802 .52562 Mtetra
.5802 .52562 .58102 .52738 .58256 .52693 .58175 .52517 Mtetra
.644 .597 .787 r
.58175 .52517 .58256 .52693 .58411 .52648 .58329 .52473 Mtetra
.644 .598 .787 r
.58329 .52473 .58411 .52648 .58565 .52603 .58484 .52428 Mtetra
.645 .598 .787 r
.58484 .52428 .58565 .52603 .5872 .52558 .58639 .52383 Mtetra
.58639 .52383 .5872 .52558 .58875 .52513 .58794 .52337 Mtetra
.646 .598 .787 r
.58794 .52337 .58875 .52513 .5903 .52467 .58948 .52291 Mtetra
.646 .599 .787 r
.58948 .52291 .5903 .52467 .59185 .52421 .59103 .52245 Mtetra
.647 .599 .786 r
.59103 .52245 .59185 .52421 .5934 .52374 .59258 .52198 Mtetra
.59258 .52198 .5934 .52374 .59495 .52328 .59414 .52152 Mtetra
.59414 .52152 .59495 .52328 .5965 .52281 .59569 .52105 Mtetra
.646 .599 .786 r
.59569 .52105 .5965 .52281 .59805 .52235 .59724 .52059 Mtetra
.646 .598 .786 r
.59724 .52059 .59805 .52235 .59961 .52188 .5988 .52012 Mtetra
.646 .598 .787 r
.5988 .52012 .59961 .52188 .60116 .52143 .60035 .51966 Mtetra
.645 .598 .787 r
.60035 .51966 .60116 .52143 .60272 .52098 .60191 .51921 Mtetra
.644 .597 .787 r
.60191 .51921 .60272 .52098 .60428 .52053 .60346 .51876 Mtetra
.642 .595 .786 r
.60346 .51876 .60428 .52053 .60584 .52011 .60502 .51832 Mtetra
.641 .593 .785 r
.60502 .51832 .60584 .52011 .6074 .51974 .60658 .51789 Mtetra
.636 .585 .78 r
.60658 .51789 .6074 .51974 .60896 .51935 .60814 .51749 Mtetra
.63 .581 .781 r
.60814 .51749 .60896 .51935 .61052 .51888 .60971 .51713 Mtetra
.618 .585 .794 r
.60971 .51713 .61052 .51888 .61207 .51823 .61127 .51685 Mtetra
.615 .63 .843 r
.61127 .51685 .61207 .51823 .61363 .51757 .61284 .51661 Mtetra
.607 .703 .912 r
.61284 .51661 .61363 .51757 .61519 .51699 .61441 .51636 Mtetra
.6 .785 .969 r
.61441 .51636 .61519 .51699 .61676 .51665 .61598 .51604 Mtetra
.607 .798 .973 r
.61598 .51604 .61676 .51665 .61833 .51636 .61755 .5157 Mtetra
.626 .786 .959 r
.61755 .5157 .61833 .51636 .6199 .51609 .61912 .51532 Mtetra
.644 .763 .935 r
.61912 .51532 .6199 .51609 .62147 .51573 .62068 .51491 Mtetra
.657 .752 .92 r
.62068 .51491 .62147 .51573 .62304 .51534 .62225 .51445 Mtetra
.668 .742 .905 r
.62225 .51445 .62304 .51534 .62461 .5149 .62382 .51395 Mtetra
.679 .733 .891 r
.62382 .51395 .62461 .5149 .62617 .51438 .62539 .51341 Mtetra
.688 .73 .882 r
.62539 .51341 .62617 .51438 .62774 .51381 .62695 .51281 Mtetra
.697 .726 .873 r
.62695 .51281 .62774 .51381 .62931 .51322 .62852 .51217 Mtetra
.708 .719 .858 r
.62852 .51217 .62931 .51322 .63088 .51262 .63009 .51144 Mtetra
.703 .696 .841 r
.63009 .51144 .63088 .51262 .63244 .51201 .63165 .51071 Mtetra
.693 .675 .828 r
.63165 .51071 .63244 .51201 .63401 .51141 .63322 .51002 Mtetra
.675 .655 .823 r
.63322 .51002 .63401 .51141 .63558 .51082 .63479 .50943 Mtetra
.669 .653 .825 r
.63479 .50943 .63558 .51082 .63715 .51024 .63636 .50887 Mtetra
.667 .655 .829 r
.63636 .50887 .63715 .51024 .63873 .50966 .63793 .50833 Mtetra
.67 .662 .833 r
.63793 .50833 .63873 .50966 .6403 .50908 .63951 .50778 Mtetra
.668 .665 .838 r
.63951 .50778 .6403 .50908 .64187 .5085 .64108 .50724 Mtetra
.663 .67 .846 r
.64108 .50724 .64187 .5085 .64345 .50793 .64266 .50674 Mtetra
.644 .674 .863 r
.64266 .50674 .64345 .50793 .64502 .50736 .64424 .50635 Mtetra
.644 .708 .893 r
.64424 .50635 .64502 .50736 .6466 .50682 .64583 .50595 Mtetra
.653 .744 .917 r
.64583 .50595 .6466 .50682 .64818 .50633 .64741 .50551 Mtetra
.698 .77 .907 r
.64741 .50551 .64818 .50633 .64977 .50599 .64899 .50488 Mtetra
.696 .707 .857 r
.64899 .50488 .64977 .50599 .65136 .50568 .65056 .50422 Mtetra
.681 .648 .811 r
.65056 .50422 .65136 .50568 .65295 .50536 .65214 .50356 Mtetra
.692 .619 .77 r
.65214 .50356 .65295 .50536 .65451 .50443 .65371 .5027 Mtetra
.662 .612 .788 r
.65371 .5027 .65451 .50443 .65609 .50382 .65529 .50212 Mtetra
.585 .576 .81 r
.65529 .50212 .65609 .50382 .6577 .5039 .65689 .50205 Mtetra
0 .165 .693 r
.65689 .50205 .6577 .5039 .6595 .50867 .65859 .50418 Mtetra
0 0 .267 r
.65859 .50418 .6595 .50867 .66903 .70221 .66053 .51253 Mtetra
.066 0 .45 r
.66053 .51253 .66903 .70221 .67092 .70679 .66993 .70159 Mtetra
.417 .331 .651 r
.66993 .70159 .67092 .70679 .67264 .70711 .67173 .70379 Mtetra
.492 .427 .712 r
.67173 .70379 .67264 .70711 .67434 .70667 .67347 .70462 Mtetra
.537 .527 .792 r
.67347 .70462 .67434 .70667 .67601 .70582 .6752 .70485 Mtetra
.375 .608 .94 r
.6752 .70485 .67601 .70582 .67772 .70562 .67693 .70521 Mtetra
.461 .809 .998 r
.67693 .70521 .67772 .70562 .67941 .7051 .67863 .70502 Mtetra
.716 .969 .933 r
.67863 .70502 .67941 .7051 .68107 .70389 .6803 .70402 Mtetra
.987 .85 .62 r
.6803 .70402 .68107 .70389 .68255 .69862 .6818 .69913 Mtetra
.97 .691 .448 r
.6818 .69913 .68255 .69862 .67546 .50414 .67471 .50351 Mtetra
.958 .762 .595 r
.67471 .50351 .67546 .50414 .67681 .49823 .67603 .49691 Mtetra
.749 .695 .8 r
.67603 .49691 .67681 .49823 .67838 .49704 .6776 .49576 Mtetra
.606 .643 .861 r
.6776 .49576 .67838 .49704 .67998 .49671 .67921 .49554 Mtetra
.471 .598 .897 r
.67921 .49554 .67998 .49671 .68161 .49681 .68084 .49579 Mtetra
.605 .694 .906 r
.68084 .49579 .68161 .49681 .68322 .49651 .68246 .49555 Mtetra
.631 .715 .908 r
.68246 .49555 .68322 .49651 .68483 .49615 .68407 .4952 Mtetra
.646 .724 .905 r
.68407 .4952 .68483 .49615 .68644 .49574 .68567 .49479 Mtetra
.674 .734 .895 r
.68567 .49479 .68644 .49574 .68804 .49519 .68728 .49425 Mtetra
.688 .741 .892 r
.68728 .49425 .68804 .49519 .68963 .49457 .68887 .49365 Mtetra
.695 .746 .891 r
.68887 .49365 .68963 .49457 .69123 .49393 .69047 .49301 Mtetra
.771 .768 .851 r
.69047 .49301 .69123 .49393 .69281 .49283 .69205 .49192 Mtetra
.726 .759 .879 r
.69205 .49192 .69281 .49283 .6944 .49203 .69364 .49112 Mtetra
.563 .701 .934 r
.69364 .49112 .6944 .49203 .69602 .4919 .69527 .49099 Mtetra
.824 .385 0 r
.69527 .49099 .69602 .4919 .69784 .49547 .69709 .49457 Mtetra
.97 .683 .428 r
.69709 .49457 .69784 .49547 .70971 .68979 .70891 .68896 Mtetra
.916 .52 .144 r
.70891 .68896 .70971 .68979 .71175 .69551 .71095 .69467 Mtetra
.137 .5 .908 r
.71095 .69467 .71175 .69551 .71352 .69612 .71273 .69539 Mtetra
.633 .787 .956 r
.71273 .69539 .71352 .69612 .71523 .69564 .71445 .69495 Mtetra
.768 .832 .902 r
.71445 .69495 .71523 .69564 .71692 .69474 .71613 .69392 Mtetra
.769 .801 .879 r
.71613 .69392 .71692 .69474 .71866 .69461 .71782 .69284 Mtetra
.753 .661 .759 r
.71782 .69284 .71866 .69461 .72039 .69436 .71948 .69133 Mtetra
.751 .594 .682 r
.71948 .69133 .72039 .69436 .72209 .69348 .72109 .68884 Mtetra
.852 .623 .592 r
.72109 .68884 .72209 .69348 .7236 .68934 .72229 .67929 Mtetra
.96 .677 .456 r
.72229 .67929 .7236 .68934 .71426 .49502 .71325 .48959 Mtetra
.734 .538 .627 r
.71325 .48959 .71426 .49502 .71544 .48684 .71467 .48564 Mtetra
.771 .721 .806 r
.71467 .48564 .71544 .48684 .71699 .48517 .71625 .48437 Mtetra
.652 .764 .931 r
.71625 .48437 .71699 .48517 .71861 .48471 .71787 .48391 Mtetra
.562 .73 .954 r
.71787 .48391 .71861 .48471 .72026 .48468 .71951 .48374 Mtetra
.69 .744 .892 r
.71951 .48374 .72026 .48468 .72189 .48433 .72113 .48312 Mtetra
.696 .695 .845 r
.72113 .48312 .72189 .48433 .72351 .48384 .72274 .48242 Mtetra
.657 .649 .83 r
.72274 .48242 .72351 .48384 .72514 .48333 .72436 .48193 Mtetra
.485 .565 .862 r
.72436 .48193 .72514 .48333 .72676 .48282 .72604 .48223 Mtetra
0 .32 .759 r
.72604 .48223 .72676 .48282 .72839 .48231 .72775 .48318 Mtetra
.708 .273 .214 r
.72775 .48318 .72839 .48231 .73001 .48178 .7295 .48462 Mtetra
.581 .263 .395 r
.7295 .48462 .73001 .48178 .73164 .48123 .73119 .48507 Mtetra
.503 .222 .42 r
.73119 .48507 .73164 .48123 .73326 .48067 .73282 .48451 Mtetra
.47 .194 .413 r
.73282 .48451 .73326 .48067 .73489 .4801 .73442 .48357 Mtetra
.483 .196 .402 r
.73442 .48357 .73489 .4801 .73651 .47956 .73605 .48288 Mtetra
.492 .2 .398 r
.73605 .48288 .73651 .47956 .73814 .47903 .73768 .48232 Mtetra
.493 .2 .397 r
.73768 .48232 .73814 .47903 .73977 .47851 .73931 .48178 Mtetra
.496 .202 .396 r
.73931 .48178 .73977 .47851 .74141 .478 .74094 .48127 Mtetra
.498 .204 .397 r
.74094 .48127 .74141 .478 .74304 .4775 .74258 .48079 Mtetra
.501 .206 .398 r
.74258 .48079 .74304 .4775 .74468 .47702 .74422 .48032 Mtetra
.528 .23 .405 r
.74422 .48032 .74468 .47702 .74632 .47655 .74588 .48014 Mtetra
.529 .239 .417 r
.74588 .48014 .74632 .47655 .74796 .4761 .74754 .47993 Mtetra
.492 .212 .418 r
.74754 .47993 .74796 .4761 .7496 .47565 .74917 .47923 Mtetra
.33 .074 .367 r
.74917 .47923 .7496 .47565 .75124 .47519 .7507 .47715 Mtetra
.03 0 .129 r
.7507 .47715 .75124 .47519 .75288 .47473 .75223 .47496 Mtetra
.811 .995 .766 r
.75223 .47496 .75288 .47473 .75453 .47428 .75379 .47327 Mtetra
.727 .745 .866 r
.75379 .47327 .75453 .47428 .75618 .47386 .75541 .47243 Mtetra
.628 .635 .838 r
.75541 .47243 .75618 .47386 .75783 .47347 .75706 .4721 Mtetra
.593 .627 .855 r
.75706 .4721 .75783 .47347 .75948 .47308 .75873 .47195 Mtetra
.612 .676 .887 r
.75873 .47195 .75948 .47308 .76113 .47269 .7604 .47168 Mtetra
.637 .713 .902 r
.7604 .47168 .76113 .47269 .76278 .47229 .76205 .4713 Mtetra
.642 .719 .904 r
.76205 .4713 .76278 .47229 .76444 .47187 .7637 .47089 Mtetra
.643 .721 .905 r
.7637 .47089 .76444 .47187 .76609 .47145 .76536 .47048 Mtetra
.646 .725 .906 r
.76536 .47048 .76609 .47145 .76774 .471 .76702 .47005 Mtetra
.652 .732 .908 r
.76702 .47005 .76774 .471 .7694 .47053 .76867 .4696 Mtetra
.662 .74 .907 r
.76867 .4696 .7694 .47053 .77105 .47003 .77032 .4691 Mtetra
.671 .744 .905 r
.77032 .4691 .77105 .47003 .7727 .46949 .77197 .46856 Mtetra
.678 .746 .903 r
.77197 .46856 .7727 .46949 .77435 .46893 .77362 .468 Mtetra
.704 .755 .892 r
.77362 .468 .77435 .46893 .77599 .46832 .77526 .4673 Mtetra
.704 .736 .876 r
.77526 .4673 .77599 .46832 .77764 .46769 .7769 .46659 Mtetra
.669 .707 .876 r
.7769 .46659 .77764 .46769 .77928 .46706 .77855 .46606 Mtetra
.504 .654 .926 r
.77855 .46606 .77928 .46706 .78093 .46645 .78026 .46614 Mtetra
0 .322 .676 r
.78026 .46614 .78093 .46645 .78258 .46586 .78201 .46688 Mtetra
.665 .232 .211 r
.78201 .46688 .78258 .46586 .78423 .46528 .7838 .46802 Mtetra
.583 .26 .388 r
.7838 .46802 .78423 .46528 .78588 .46467 .78554 .46851 Mtetra
.497 .217 .419 r
.78554 .46851 .78588 .46467 .78753 .46406 .78719 .46787 Mtetra
.465 .19 .412 r
.78719 .46787 .78753 .46406 .78919 .46345 .78882 .46687 Mtetra
.466 .182 .396 r
.78882 .46687 .78919 .46345 .79084 .46286 .79045 .46601 Mtetra
.478 .183 .386 r
.79045 .46601 .79084 .46286 .7925 .4623 .79211 .46535 Mtetra
.478 .18 .381 r
.79211 .46535 .7925 .4623 .79416 .46174 .79376 .46472 Mtetra
.478 .178 .377 r
.79376 .46472 .79416 .46174 .79582 .4612 .79542 .46412 Mtetra
.479 .176 .374 r
.79542 .46412 .79582 .4612 .79749 .46066 .79709 .46354 Mtetra
.479 .175 .371 r
.79709 .46354 .79749 .46066 .79915 .46014 .79875 .46297 Mtetra
.479 .174 .369 r
.79875 .46297 .79915 .46014 .80082 .45961 .80042 .46242 Mtetra
.48 .173 .367 r
.80042 .46242 .80082 .45961 .80248 .45909 .80209 .46188 Mtetra
.481 .173 .367 r
.80209 .46188 .80248 .45909 .80415 .45858 .80376 .46136 Mtetra
.482 .173 .366 r
.80376 .46136 .80415 .45858 .80582 .45807 .80543 .46084 Mtetra
.483 .174 .366 r
.80543 .46084 .80582 .45807 .80749 .45756 .8071 .46034 Mtetra
.484 .176 .367 r
.8071 .46034 .80749 .45756 .80917 .45706 .80878 .45985 Mtetra
.487 .178 .368 r
.80878 .45985 .80917 .45706 .81084 .45657 .81046 .45938 Mtetra
.49 .182 .37 r
.81046 .45938 .81084 .45657 .81252 .45608 .81214 .45893 Mtetra
.492 .185 .373 r
.81214 .45893 .81252 .45608 .8142 .45559 .81383 .45849 Mtetra
.512 .203 .38 r
.81383 .45849 .8142 .45559 .81588 .45512 .81553 .45822 Mtetra
.526 .222 .394 r
.81553 .45822 .81588 .45512 .81756 .45467 .81724 .45805 Mtetra
.497 .206 .402 r
.81724 .45805 .81756 .45467 .81924 .45421 .81892 .45752 Mtetra
.38 .109 .372 r
.81892 .45752 .81924 .45421 .82092 .45375 .8205 .45592 Mtetra
.129 0 .209 r
.8205 .45592 .82092 .45375 .82261 .45328 .82203 .45375 Mtetra
.66 .911 .593 r
.82203 .45375 .82261 .45328 .82429 .4528 .8236 .45197 Mtetra
.783 .804 .87 r
.8236 .45197 .82429 .4528 .82598 .45234 .82522 .45083 Mtetra
.661 .643 .821 r
.82522 .45083 .82598 .45234 .82767 .45189 .8269 .45028 Mtetra
.633 .616 .816 r
.8269 .45028 .82767 .45189 .82936 .45144 .8286 .4499 Mtetra
.633 .625 .824 r
.8286 .4499 .82936 .45144 .83105 .45099 .8303 .44952 Mtetra
.65 .643 .83 r
.8303 .44952 .83105 .45099 .83274 .45052 .83199 .44905 Mtetra
.83199 .44905 .83274 .45052 .83443 .45004 .83368 .44857 Mtetra
.652 .644 .83 r
.83368 .44857 .83443 .45004 .83612 .44955 .83537 .44809 Mtetra
.653 .645 .83 r
.83537 .44809 .83612 .44955 .83781 .44906 .83706 .44759 Mtetra
.654 .646 .829 r
.83706 .44759 .83781 .44906 .8395 .44856 .83876 .4471 Mtetra
.655 .646 .829 r
.83876 .4471 .8395 .44856 .8412 .44806 .84045 .44659 Mtetra
.84045 .44659 .8412 .44806 .84289 .44755 .84214 .44608 Mtetra
.656 .647 .829 r
.84214 .44608 .84289 .44755 .84458 .44704 .84384 .44557 Mtetra
.657 .647 .829 r
.84384 .44557 .84458 .44704 .84628 .44652 .84553 .44505 Mtetra
.657 .648 .829 r
.84553 .44505 .84628 .44652 .84797 .446 .84723 .44454 Mtetra
.658 .648 .829 r
.84723 .44454 .84797 .446 .84967 .44547 .84892 .44401 Mtetra
.658 .649 .83 r
.84892 .44401 .84967 .44547 .85136 .44494 .85062 .44348 Mtetra
.659 .65 .83 r
.85062 .44348 .85136 .44494 .85306 .44441 .85232 .44295 Mtetra
.66 .651 .83 r
.85232 .44295 .85306 .44441 .85475 .44386 .85401 .44242 Mtetra
.66 .652 .831 r
.85401 .44242 .85475 .44386 .85645 .44332 .85571 .44188 Mtetra
.661 .653 .832 r
.85571 .44188 .85645 .44332 .85815 .44277 .85741 .44133 Mtetra
.662 .655 .832 r
.85741 .44133 .85815 .44277 .85985 .44221 .85911 .44079 Mtetra
.663 .657 .834 r
.85911 .44079 .85985 .44221 .86155 .44164 .86081 .44023 Mtetra
.664 .66 .836 r
.86081 .44023 .86155 .44164 .86324 .44105 .86251 .43968 Mtetra
.665 .664 .839 r
.86251 .43968 .86324 .44105 .86494 .44047 .86421 .43912 Mtetra
.665 .669 .843 r
.86421 .43912 .86494 .44047 .86664 .43989 .86591 .43856 Mtetra
.665 .672 .847 r
.86591 .43856 .86664 .43989 .86834 .43933 .86762 .43801 Mtetra
.664 .673 .848 r
.86762 .43801 .86834 .43933 .87005 .43878 .86932 .43746 Mtetra
.664 .673 .849 r
.86932 .43746 .87005 .43878 .87175 .43824 .87103 .43692 Mtetra
.663 .674 .85 r
.87103 .43692 .87175 .43824 .87346 .43769 .87274 .43638 Mtetra
.87274 .43638 .87346 .43769 .87517 .43716 .87445 .43584 Mtetra
.662 .674 .851 r
.87445 .43584 .87517 .43716 .87688 .43663 .87616 .43531 Mtetra
.661 .673 .851 r
.87616 .43531 .87688 .43663 .87859 .4361 .87787 .43478 Mtetra
.66 .673 .851 r
.87787 .43478 .87859 .4361 .88031 .43557 .87959 .43426 Mtetra
.66 .672 .851 r
.87959 .43426 .88031 .43557 .88202 .43506 .8813 .43374 Mtetra
.659 .672 .851 r
.8813 .43374 .88202 .43506 .88374 .43454 .88302 .43322 Mtetra
.658 .671 .851 r
.88302 .43322 .88374 .43454 .88546 .43404 .88474 .43271 Mtetra
.656 .67 .851 r
.88474 .43271 .88546 .43404 .88718 .43354 .88646 .43221 Mtetra
.655 .669 .851 r
.88646 .43221 .88718 .43354 .8889 .43304 .88818 .43171 Mtetra
.653 .667 .851 r
.88818 .43171 .8889 .43304 .89062 .43256 .88991 .43123 Mtetra
.651 .666 .851 r
.88991 .43123 .89062 .43256 .89235 .4321 .89163 .43075 Mtetra
.65 .663 .85 r
.89163 .43075 .89235 .4321 .89408 .43166 .89336 .43029 Mtetra
.645 .657 .847 r
.89336 .43029 .89408 .43166 .89582 .43123 .89509 .42984 Mtetra
.638 .651 .847 r
.89509 .42984 .89582 .43123 .89755 .4308 .89683 .42944 Mtetra
.623 .649 .855 r
.89683 .42944 .89755 .4308 .89929 .43035 .89858 .42912 Mtetra
.621 .669 .875 r
.89858 .42912 .89929 .43035 .90102 .42989 .90033 .4288 Mtetra
.627 .7 .898 r
.90033 .4288 .90102 .42989 .90275 .4294 .90208 .42844 Mtetra
.652 .74 .914 r
.90208 .42844 .90275 .4294 .90448 .42888 .90382 .42797 Mtetra
.665 .755 .918 r
.90382 .42797 .90448 .42888 .90621 .42833 .90554 .42743 Mtetra
.677 .764 .917 r
.90554 .42743 .90621 .42833 .90793 .42773 .90727 .42684 Mtetra
.688 .771 .915 r
.90727 .42684 .90793 .42773 .90964 .42707 .90899 .4262 Mtetra
.693 .779 .917 r
.90899 .4262 .90964 .42707 .91136 .42639 .9107 .42554 Mtetra
.71 .79 .914 r
.9107 .42554 .91136 .42639 .91306 .42564 .91241 .4248 Mtetra
.774 .811 .883 r
.91241 .4248 .91306 .42564 .91473 .42457 .91408 .42372 Mtetra
.694 .783 .919 r
.91408 .42372 .91473 .42457 .91645 .42391 .9158 .42305 Mtetra
.406 .642 .953 r
.9158 .42305 .91645 .42391 .91828 .42417 .91763 .42331 Mtetra
.794 .368 0 r
.91763 .42331 .91828 .42417 .92065 .42885 .92002 .42815 Mtetra
.973 .661 .313 r
.92002 .42815 .92065 .42885 .94674 .62746 .94608 .62674 Mtetra
.785 .338 0 r
.94608 .62674 .94674 .62746 .94923 .63206 .94854 .6312 Mtetra
.477 .696 .964 r
.94854 .6312 .94923 .63206 .95116 .63214 .95047 .63125 Mtetra
.689 .788 .926 r
.95047 .63125 .95116 .63214 .953 .63145 .95231 .63056 Mtetra
.741 .804 .902 r
.95231 .63056 .953 .63145 .95481 .6305 .95412 .6296 Mtetra
.484 .69 .958 r
.95412 .6296 .95481 .6305 .95674 .63057 .95605 .62966 Mtetra
.616 .752 .943 r
.95605 .62966 .95674 .63057 .95862 .63019 .95794 .62927 Mtetra
.798 .814 .865 r
.95794 .62927 .95862 .63019 .96038 .62886 .9597 .62794 Mtetra
.98 .776 .557 r
.9597 .62794 .96038 .62886 .96145 .62208 .96077 .62115 Mtetra
.975 .669 .322 r
.96077 .62115 .96145 .62208 .93798 .42249 .93732 .42151 Mtetra
.962 .783 .613 r
.93732 .42151 .93798 .42249 .93917 .4176 .93851 .41661 Mtetra
.755 .775 .87 r
.93851 .41661 .93917 .4176 .94086 .41657 .9402 .41559 Mtetra
.626 .724 .917 r
.9402 .41559 .94086 .41657 .94263 .4162 .94197 .41521 Mtetra
.544 .684 .93 r
.94197 .41521 .94263 .4162 .94444 .41614 .94379 .41515 Mtetra
.747 .772 .873 r
.94379 .41515 .94444 .41614 .94613 .41516 .94548 .41417 Mtetra
.681 .747 .901 r
.94548 .41417 .94613 .41516 .94788 .41455 .94722 .41356 Mtetra
.489 .655 .933 r
.94722 .41356 .94788 .41455 .94972 .41467 .94906 .41367 Mtetra
.737 .32 0 r
.94906 .41367 .94972 .41467 .95218 .41948 .95152 .41847 Mtetra
.97 .655 .291 r
.95152 .41847 .95218 .41948 .98038 .61876 .97971 .61781 Mtetra
.735 .305 0 r
.97971 .61781 .98038 .61876 .98296 .62349 .98228 .62256 Mtetra
.033 .464 .878 r
.37441 .78433 .37534 .78508 .37681 .7857 .37589 .78495 Mtetra
.643 .762 .935 r
.37589 .78495 .37681 .7857 .37833 .7853 .37741 .78455 Mtetra
.809 .779 .825 r
.37741 .78455 .37833 .7853 .3799 .78388 .37897 .78314 Mtetra
.908 .738 .659 r
.37897 .78314 .3799 .78388 .38161 .77866 .38069 .77794 Mtetra
.937 .686 .534 r
.38069 .77794 .38161 .77866 .39058 .58898 .38971 .58822 Mtetra
.911 .73 .645 r
.38971 .58822 .39058 .58898 .39223 .58334 .39136 .58255 Mtetra
.772 .763 .845 r
.39136 .58255 .39223 .58334 .39369 .58231 .39283 .58151 Mtetra
.618 .732 .927 r
.39283 .58151 .39369 .58231 .39513 .58204 .39426 .58123 Mtetra
.463 .672 .954 r
.39426 .58123 .39513 .58204 .39655 .58215 .39569 .58132 Mtetra
.639 .732 .916 r
.39569 .58132 .39655 .58215 .39799 .58183 .39713 .58097 Mtetra
.655 .73 .904 r
.39713 .58097 .39799 .58183 .39943 .58145 .39857 .58057 Mtetra
.667 .727 .894 r
.39857 .58057 .39943 .58145 .40088 .58102 .40002 .58011 Mtetra
.745 .738 .845 r
.40002 .58011 .40088 .58102 .40233 .5803 .40148 .57922 Mtetra
.708 .698 .839 r
.40148 .57922 .40233 .5803 .40379 .57966 .40294 .57851 Mtetra
.623 .66 .866 r
.40294 .57851 .40379 .57966 .40524 .57923 .40438 .57824 Mtetra
.792 .33 0 r
.40438 .57824 .40524 .57923 .40665 .57991 .40573 .58053 Mtetra
.904 .603 .465 r
.40573 .58053 .40665 .57991 .40804 .58113 .40687 .58919 Mtetra
.926 .669 .53 r
.40687 .58919 .40804 .58113 .40943 .58243 .40212 .77043 Mtetra
.033 0 .4 r
.40212 .77043 .40943 .58243 .41094 .58048 .40915 .60709 Mtetra
0 0 .29 r
.40915 .60709 .41094 .58048 .41245 .57822 .41153 .57929 Mtetra
.974 .925 .626 r
.41153 .57929 .41245 .57822 .41395 .57643 .41309 .57556 Mtetra
.77 .749 .834 r
.41309 .57556 .41395 .57643 .41541 .57566 .41456 .57448 Mtetra
.662 .669 .846 r
.41456 .57448 .41541 .57566 .41686 .57521 .41602 .57403 Mtetra
.61 .649 .864 r
.41602 .57403 .41686 .57521 .41832 .57488 .41747 .57382 Mtetra
.657 .688 .867 r
.41747 .57382 .41832 .57488 .41977 .57443 .41892 .5734 Mtetra
.661 .694 .87 r
.41892 .5734 .41977 .57443 .42123 .57398 .42038 .57296 Mtetra
.654 .696 .876 r
.42038 .57296 .42123 .57398 .42268 .57354 .42183 .57255 Mtetra
.628 .693 .891 r
.42183 .57255 .42268 .57354 .42414 .5732 .42329 .57225 Mtetra
.621 .701 .902 r
.42329 .57225 .42414 .5732 .4256 .57286 .42474 .57197 Mtetra
.63 .716 .909 r
.42474 .57197 .4256 .57286 .42705 .57249 .4262 .57166 Mtetra
.681 .743 .898 r
.4262 .57166 .42705 .57249 .42852 .57195 .42766 .57114 Mtetra
.699 .753 .894 r
.42766 .57114 .42852 .57195 .42998 .57134 .42913 .57054 Mtetra
.7 .756 .895 r
.42913 .57054 .42998 .57134 .43145 .57074 .43059 .56994 Mtetra
.709 .758 .89 r
.43059 .56994 .43145 .57074 .43292 .56998 .43206 .56929 Mtetra
.683 .781 .925 r
.43206 .56929 .43292 .56998 .43439 .5694 .43353 .56877 Mtetra
.596 .774 .965 r
.43353 .56877 .43439 .5694 .43584 .56926 .43499 .56849 Mtetra
.037 .449 .875 r
.43499 .56849 .43584 .56926 .43725 .57101 .43643 .56915 Mtetra
.091 .256 .74 r
.43643 .56915 .43725 .57101 .43854 .57741 .43784 .57067 Mtetra
.408 .294 .611 r
.43784 .57067 .43854 .57741 .43535 .76362 .43923 .57332 Mtetra
.57 .364 .563 r
.43923 .57332 .43535 .76362 .43686 .76508 .44068 .57372 Mtetra
.572 .366 .563 r
.44068 .57372 .43686 .76508 .43841 .76461 .44217 .57282 Mtetra
.571 .365 .563 r
.44217 .57282 .43841 .76461 .43997 .76384 .44363 .5728 Mtetra
0 0 .382 r
.44363 .5728 .43997 .76384 .4415 .76481 .4408 .75517 Mtetra
.082 .037 .501 r
.4408 .75517 .4415 .76481 .44301 .76599 .44216 .76321 Mtetra
0 .112 .632 r
.44216 .76321 .44301 .76599 .44455 .76676 .44365 .7658 Mtetra
.24 .535 .922 r
.44365 .7658 .44455 .76676 .44609 .767 .44519 .76635 Mtetra
.6 .782 .968 r
.44519 .76635 .44609 .767 .44765 .76676 .44675 .76604 Mtetra
.737 .792 .897 r
.44675 .76604 .44765 .76676 .44921 .76597 .44832 .76523 Mtetra
.827 .788 .815 r
.44832 .76523 .44921 .76597 .45082 .76337 .4499 .76364 Mtetra
.937 .94 .77 r
.4499 .76364 .45082 .76337 .4525 .75692 .4515 .76123 Mtetra
.123 0 .279 r
.4515 .76123 .4525 .75692 .45778 .56892 .45313 .75784 Mtetra
.568 .359 .557 r
.45313 .75784 .45778 .56892 .4593 .56615 .45471 .75638 Mtetra
.57 .361 .558 r
.45471 .75638 .4593 .56615 .46078 .56576 .45626 .7564 Mtetra
.569 .36 .557 r
.45626 .7564 .46078 .56576 .46225 .56572 .45783 .75574 Mtetra
.011 0 .397 r
.45783 .75574 .46225 .56572 .46375 .56405 .4626 .58029 Mtetra
0 0 .305 r
.4626 .58029 .46375 .56405 .46526 .56203 .46438 .56335 Mtetra
.911 .925 .544 r
.46438 .56335 .46526 .56203 .46676 .56046 .46592 .55984 Mtetra
.811 .81 .85 r
.46592 .55984 .46676 .56046 .46825 .55967 .46742 .55859 Mtetra
.64 .681 .873 r
.46742 .55859 .46825 .55967 .46973 .55933 .4689 .55824 Mtetra
.561 .649 .894 r
.4689 .55824 .46973 .55933 .47121 .55912 .47038 .55819 Mtetra
.606 .7 .91 r
.47038 .55819 .47121 .55912 .4727 .55879 .47186 .55795 Mtetra
.653 .738 .912 r
.47186 .55795 .4727 .55879 .47418 .55834 .47334 .55754 Mtetra
.666 .751 .913 r
.47334 .55754 .47418 .55834 .47567 .55785 .47483 .55708 Mtetra
.719 .769 .892 r
.47483 .55708 .47567 .55785 .47716 .55705 .47632 .55638 Mtetra
.727 .795 .906 r
.47632 .55638 .47716 .55705 .47865 .55626 .47781 .55565 Mtetra
.668 .801 .946 r
.47781 .55565 .47865 .55626 .48014 .55589 .4793 .55516 Mtetra
.251 .59 .948 r
.4793 .55516 .48014 .55589 .48161 .55716 .48078 .55554 Mtetra
.073 .279 .766 r
.48078 .55554 .48161 .55716 .48303 .56228 .48225 .55693 Mtetra
.369 .284 .628 r
.48225 .55693 .48303 .56228 .48228 .75008 .4837 .55946 Mtetra
.569 .363 .562 r
.4837 .55946 .48228 .75008 .48382 .75254 .48518 .56061 Mtetra
.573 .366 .563 r
.48518 .56061 .48382 .75254 .4854 .75214 .48668 .55959 Mtetra
.571 .365 .563 r
.48668 .55959 .4854 .75214 .48698 .75133 .48818 .55927 Mtetra
.018 0 .411 r
.48818 .55927 .48698 .75133 .48856 .75188 .48782 .73733 Mtetra
.086 .024 .483 r
.48782 .73733 .48856 .75188 .49012 .75309 .48927 .74979 Mtetra
.038 .118 .619 r
.48927 .74979 .49012 .75309 .4917 .75393 .49082 .75279 Mtetra
.163 .445 .876 r
.49082 .75279 .4917 .75393 .49328 .75413 .49239 .75362 Mtetra
.51 .794 .997 r
.49239 .75362 .49328 .75413 .49486 .75389 .49398 .75343 Mtetra
.648 .853 .978 r
.49398 .75343 .49486 .75389 .49645 .75347 .49557 .75292 Mtetra
.682 .83 .955 r
.49557 .75292 .49645 .75347 .49804 .75298 .49716 .75233 Mtetra
.685 .804 .939 r
.49716 .75233 .49804 .75298 .49963 .75245 .49875 .75174 Mtetra
.693 .792 .926 r
.49875 .75174 .49963 .75245 .50122 .75189 .50034 .75112 Mtetra
.645 .766 .937 r
.50034 .75112 .50122 .75189 .50281 .75159 .50193 .7507 Mtetra
.621 .731 .925 r
.50193 .7507 .50281 .75159 .5044 .75136 .50352 .75038 Mtetra
.67 .725 .89 r
.50352 .75038 .5044 .75136 .506 .75076 .50512 .74986 Mtetra
.789 .765 .832 r
.50512 .74986 .506 .75076 .5076 .74869 .50672 .74857 Mtetra
.922 .892 .783 r
.50672 .74857 .5076 .74869 .50921 .74321 .50832 .74624 Mtetra
0 0 .106 r
.50832 .74624 .50921 .74321 .51155 .55388 .50993 .7429 Mtetra
.565 .357 .557 r
.50993 .7429 .51155 .55388 .51308 .54945 .51154 .73981 Mtetra
.569 .36 .557 r
.51154 .73981 .51308 .54945 .51459 .5487 .51313 .73903 Mtetra
.571 .361 .558 r
.51313 .73903 .51459 .5487 .5161 .5487 .51472 .73928 Mtetra
.57 .361 .558 r
.51472 .73928 .5161 .5487 .5176 .54867 .51632 .73935 Mtetra
.57 .36 .557 r
.51632 .73935 .5176 .54867 .51912 .54825 .51792 .739 Mtetra
.51792 .739 .51912 .54825 .52063 .54784 .51952 .73864 Mtetra
.51952 .73864 .52063 .54784 .52214 .54742 .52112 .73826 Mtetra
.52112 .73826 .52214 .54742 .52366 .54698 .52272 .73786 Mtetra
.52272 .73786 .52366 .54698 .52517 .54653 .52432 .73744 Mtetra
.52432 .73744 .52517 .54653 .52669 .54608 .52592 .73702 Mtetra
.52592 .73702 .52669 .54608 .5282 .54561 .52753 .73658 Mtetra
.52753 .73658 .5282 .54561 .52972 .54514 .52913 .73614 Mtetra
.52913 .73614 .52972 .54514 .53124 .54467 .53074 .73569 Mtetra
.53074 .73569 .53124 .54467 .53276 .54419 .53234 .73524 Mtetra
.53234 .73524 .53276 .54419 .53428 .5437 .53395 .73477 Mtetra
.569 .36 .557 r
.53395 .73477 .53428 .5437 .5358 .54321 .53556 .7343 Mtetra
.53556 .7343 .5358 .54321 .53732 .54272 .53717 .73382 Mtetra
.53717 .73382 .53732 .54272 .53884 .54221 .53878 .73333 Mtetra
.53878 .73333 .53884 .54221 .54037 .5417 .54039 .73284 Mtetra
.54039 .73284 .54037 .5417 .54189 .54119 .542 .73233 Mtetra
.542 .73233 .54189 .54119 .54341 .54068 .54361 .73182 Mtetra
.54361 .73182 .54341 .54068 .54494 .54019 .54523 .73135 Mtetra
.57 .36 .557 r
.54523 .73135 .54494 .54019 .54647 .53971 .54684 .73092 Mtetra
.54684 .73092 .54647 .53971 .54799 .53924 .54846 .73048 Mtetra
.57 .361 .557 r
.54846 .73048 .54799 .53924 .54952 .53891 .55008 .73051 Mtetra
.571 .361 .558 r
.55008 .73051 .54952 .53891 .55105 .53871 .5517 .73087 Mtetra
.569 .36 .557 r
.5517 .73087 .55105 .53871 .55258 .53817 .55332 .73011 Mtetra
.561 .353 .556 r
.55332 .73011 .55258 .53817 .55411 .53675 .55489 .72387 Mtetra
0 0 .405 r
.55489 .72387 .55411 .53675 .55562 .53468 .55484 .53709 Mtetra
0 0 0 r
.55484 .53709 .55562 .53468 .55714 .53297 .55634 .53275 Mtetra
.906 .89 .804 r
.55634 .53275 .55714 .53297 .55867 .53183 .55786 .53076 Mtetra
.697 .708 .857 r
.55786 .53076 .55867 .53183 .5602 .53129 .55939 .53011 Mtetra
.629 .664 .866 r
.55939 .53011 .5602 .53129 .56173 .53092 .56092 .5298 Mtetra
.615 .671 .88 r
.56092 .5298 .56173 .53092 .56327 .53057 .56246 .52955 Mtetra
.657 .705 .883 r
.56246 .52955 .56327 .53057 .5648 .53012 .564 .52911 Mtetra
.655 .707 .885 r
.564 .52911 .5648 .53012 .56634 .52967 .56553 .52868 Mtetra
.654 .71 .889 r
.56553 .52868 .56634 .52967 .56788 .52921 .56707 .52825 Mtetra
.654 .716 .894 r
.56707 .52825 .56788 .52921 .56941 .52875 .56861 .52782 Mtetra
.653 .724 .901 r
.56861 .52782 .56941 .52875 .57095 .52828 .57015 .5274 Mtetra
.652 .733 .909 r
.57015 .5274 .57095 .52828 .57249 .52782 .57169 .52697 Mtetra
.651 .742 .916 r
.57169 .52697 .57249 .52782 .57403 .52738 .57323 .52655 Mtetra
.65 .748 .921 r
.57323 .52655 .57403 .52738 .57557 .52694 .57477 .52614 Mtetra
.649 .753 .925 r
.57477 .52614 .57557 .52694 .57712 .5265 .57632 .52572 Mtetra
.649 .758 .929 r
.57632 .52572 .57712 .5265 .57866 .52606 .57786 .52529 Mtetra
.65 .763 .932 r
.57786 .52529 .57866 .52606 .5802 .52562 .5794 .52487 Mtetra
.65 .767 .935 r
.5794 .52487 .5802 .52562 .58175 .52517 .58095 .52444 Mtetra
.651 .771 .937 r
.58095 .52444 .58175 .52517 .58329 .52473 .5825 .524 Mtetra
.652 .774 .938 r
.5825 .524 .58329 .52473 .58484 .52428 .58404 .52356 Mtetra
.653 .776 .939 r
.58404 .52356 .58484 .52428 .58639 .52383 .58559 .52311 Mtetra
.654 .779 .94 r
.58559 .52311 .58639 .52383 .58794 .52337 .58714 .52266 Mtetra
.655 .781 .941 r
.58714 .52266 .58794 .52337 .58948 .52291 .58869 .52221 Mtetra
.656 .782 .941 r
.58869 .52221 .58948 .52291 .59103 .52245 .59024 .52175 Mtetra
.657 .783 .941 r
.59024 .52175 .59103 .52245 .59258 .52198 .59179 .52128 Mtetra
.657 .784 .942 r
.59179 .52128 .59258 .52198 .59414 .52152 .59335 .52082 Mtetra
.59335 .52082 .59414 .52152 .59569 .52105 .5949 .52035 Mtetra
.5949 .52035 .59569 .52105 .59724 .52059 .59645 .51989 Mtetra
.656 .784 .943 r
.59645 .51989 .59724 .52059 .5988 .52012 .59801 .51943 Mtetra
.655 .784 .943 r
.59801 .51943 .5988 .52012 .60035 .51966 .59956 .51897 Mtetra
.654 .784 .943 r
.59956 .51897 .60035 .51966 .60191 .51921 .60112 .51851 Mtetra
.652 .783 .944 r
.60112 .51851 .60191 .51921 .60346 .51876 .60268 .51806 Mtetra
.65 .782 .945 r
.60268 .51806 .60346 .51876 .60502 .51832 .60424 .51762 Mtetra
.65 .781 .944 r
.60424 .51762 .60502 .51832 .60658 .51789 .6058 .51718 Mtetra
.642 .776 .945 r
.6058 .51718 .60658 .51789 .60814 .51749 .60736 .51676 Mtetra
.626 .769 .948 r
.60736 .51676 .60814 .51749 .60971 .51713 .60892 .5164 Mtetra
.589 .756 .958 r
.60892 .5164 .60971 .51713 .61127 .51685 .61049 .51615 Mtetra
.577 .757 .964 r
.61049 .51615 .61127 .51685 .61284 .51661 .61206 .51592 Mtetra
.581 .764 .966 r
.61206 .51592 .61284 .51661 .61441 .51636 .61363 .51568 Mtetra
.616 .779 .959 r
.61363 .51568 .61441 .51636 .61598 .51604 .6152 .51533 Mtetra
.635 .776 .948 r
.6152 .51533 .61598 .51604 .61755 .5157 .61676 .51494 Mtetra
.651 .768 .935 r
.61676 .51494 .61755 .5157 .61912 .51532 .61833 .5145 Mtetra
.663 .756 .92 r
.61833 .5145 .61912 .51532 .62068 .51491 .6199 .51402 Mtetra
.673 .744 .904 r
.6199 .51402 .62068 .51491 .62225 .51445 .62147 .51351 Mtetra
.68 .732 .89 r
.62147 .51351 .62225 .51445 .62382 .51395 .62303 .51295 Mtetra
.684 .722 .878 r
.62303 .51295 .62382 .51395 .62539 .51341 .6246 .51237 Mtetra
.69 .718 .87 r
.6246 .51237 .62539 .51341 .62695 .51281 .62617 .51175 Mtetra
.698 .716 .863 r
.62617 .51175 .62695 .51281 .62852 .51217 .62773 .51109 Mtetra
.711 .717 .854 r
.62773 .51109 .62852 .51217 .63009 .51144 .6293 .51034 Mtetra
.709 .712 .851 r
.6293 .51034 .63009 .51144 .63165 .51071 .63086 .5096 Mtetra
.702 .707 .852 r
.63086 .5096 .63165 .51071 .63322 .51002 .63243 .5089 Mtetra
.682 .699 .859 r
.63243 .5089 .63322 .51002 .63479 .50943 .634 .50831 Mtetra
.675 .697 .863 r
.634 .50831 .63479 .50943 .63636 .50887 .63557 .50776 Mtetra
.67 .698 .867 r
.63557 .50776 .63636 .50887 .63793 .50833 .63715 .50724 Mtetra
.674 .702 .868 r
.63715 .50724 .63793 .50833 .63951 .50778 .63872 .5067 Mtetra
.669 .703 .873 r
.63872 .5067 .63951 .50778 .64108 .50724 .6403 .50619 Mtetra
.66 .705 .88 r
.6403 .50619 .64108 .50724 .64266 .50674 .64188 .50572 Mtetra
.632 .7 .895 r
.64188 .50572 .64266 .50674 .64424 .50635 .64346 .50538 Mtetra
.63 .711 .905 r
.64346 .50538 .64424 .50635 .64583 .50595 .64505 .50504 Mtetra
.641 .728 .912 r
.64505 .50504 .64583 .50595 .64741 .50551 .64664 .50465 Mtetra
.693 .757 .901 r
.64664 .50465 .64741 .50551 .64899 .50488 .64821 .50404 Mtetra
.703 .765 .9 r
.64821 .50404 .64899 .50488 .65056 .50422 .64979 .50338 Mtetra
.703 .767 .902 r
.64979 .50338 .65056 .50422 .65214 .50356 .65137 .50272 Mtetra
.718 .77 .894 r
.65137 .50272 .65214 .50356 .65371 .5027 .65294 .50199 Mtetra
.681 .792 .934 r
.65294 .50199 .65371 .5027 .65529 .50212 .65453 .50143 Mtetra
.59 .767 .964 r
.65453 .50143 .65529 .50212 .65689 .50205 .65612 .50116 Mtetra
.268 .554 .929 r
.65612 .50116 .65689 .50205 .65859 .50418 .65775 .50168 Mtetra
.346 .367 .74 r
.65775 .50168 .65859 .50418 .66053 .51253 .65942 .50306 Mtetra
.434 .302 .601 r
.65942 .50306 .66053 .51253 .66993 .70159 .66117 .50667 Mtetra
.082 .001 .456 r
.66117 .50667 .66993 .70159 .67173 .70379 .67065 .69647 Mtetra
.24 .182 .588 r
.67065 .69647 .67173 .70379 .67347 .70462 .67259 .70191 Mtetra
.242 .296 .719 r
.67259 .70191 .67347 .70462 .6752 .70485 .67438 .70391 Mtetra
.238 .535 .922 r
.67438 .70391 .6752 .70485 .67693 .70521 .67612 .70453 Mtetra
.556 .769 .977 r
.67612 .70453 .67693 .70521 .67863 .70502 .67783 .7043 Mtetra
.784 .824 .884 r
.67783 .7043 .67863 .70502 .6803 .70402 .6795 .70316 Mtetra
.937 .766 .644 r
.6795 .70316 .6803 .70402 .6818 .69913 .68099 .69812 Mtetra
.968 .69 .451 r
.68099 .69812 .6818 .69913 .67471 .50351 .67392 .50213 Mtetra
.922 .72 .613 r
.67392 .50213 .67471 .50351 .67603 .49691 .67526 .49581 Mtetra
.76 .732 .827 r
.67526 .49581 .67603 .49691 .6776 .49576 .67683 .4947 Mtetra
.591 .679 .902 r
.67683 .4947 .6776 .49576 .67921 .49554 .67844 .49452 Mtetra
.434 .61 .923 r
.67844 .49452 .67921 .49554 .68084 .49579 .68008 .4948 Mtetra
.599 .695 .91 r
.68008 .4948 .68084 .49579 .68246 .49555 .68169 .49457 Mtetra
.628 .711 .906 r
.68169 .49457 .68246 .49555 .68407 .4952 .6833 .49423 Mtetra
.644 .719 .903 r
.6833 .49423 .68407 .4952 .68567 .49479 .68491 .49383 Mtetra
.671 .731 .895 r
.68491 .49383 .68567 .49479 .68728 .49425 .68651 .4933 Mtetra
.685 .739 .892 r
.68651 .4933 .68728 .49425 .68887 .49365 .68811 .49271 Mtetra
.692 .744 .891 r
.68811 .49271 .68887 .49365 .69047 .49301 .68971 .49209 Mtetra
.769 .768 .851 r
.68971 .49209 .69047 .49301 .69205 .49192 .69129 .49101 Mtetra
.725 .759 .879 r
.69129 .49101 .69205 .49192 .69364 .49112 .69288 .49021 Mtetra
.561 .701 .934 r
.69288 .49021 .69364 .49112 .69527 .49099 .69451 .49009 Mtetra
.827 .388 0 r
.69451 .49009 .69527 .49099 .69709 .49457 .69633 .49368 Mtetra
.97 .683 .428 r
.69633 .49368 .69709 .49457 .70891 .68896 .70812 .68816 Mtetra
.916 .52 .146 r
.70812 .68816 .70891 .68896 .71095 .69467 .71016 .69384 Mtetra
.059 .449 .879 r
.71016 .69384 .71095 .69467 .71273 .69539 .71194 .69468 Mtetra
.615 .788 .964 r
.71194 .69468 .71273 .69539 .71445 .69495 .71366 .69429 Mtetra
.794 .843 .888 r
.71366 .69429 .71445 .69495 .71613 .69392 .71534 .6931 Mtetra
.889 .802 .758 r
.71534 .6931 .71613 .69392 .71782 .69284 .71695 .69059 Mtetra
.866 .676 .643 r
.71695 .69059 .71782 .69284 .71948 .69133 .71842 .68554 Mtetra
.965 .683 .448 r
.71842 .68554 .71948 .69133 .72109 .68884 .70953 .49454 Mtetra
.58 .372 .563 r
.70953 .49454 .72109 .68884 .72229 .67929 .71084 .48848 Mtetra
.575 .368 .563 r
.71084 .48848 .72229 .67929 .71325 .48959 .71234 .48595 Mtetra
.686 .534 .674 r
.71234 .48595 .71325 .48959 .71467 .48564 .7139 .48438 Mtetra
.71 .692 .831 r
.7139 .48438 .71467 .48564 .71625 .48437 .71551 .48357 Mtetra
.65 .766 .934 r
.71551 .48357 .71625 .48437 .71787 .48391 .71713 .48312 Mtetra
.611 .754 .946 r
.71713 .48312 .71787 .48391 .71951 .48374 .71876 .4828 Mtetra
.728 .756 .875 r
.71876 .4828 .71951 .48374 .72113 .48312 .72037 .48198 Mtetra
.714 .713 .847 r
.72037 .48198 .72113 .48312 .72274 .48242 .72197 .48118 Mtetra
.64 .667 .86 r
.72197 .48118 .72274 .48242 .72436 .48193 .7236 .48079 Mtetra
0 .293 .791 r
.7236 .48079 .72436 .48193 .72604 .48223 .72534 .48216 Mtetra
.902 .495 .209 r
.72534 .48216 .72604 .48223 .72775 .48318 .72728 .48677 Mtetra
.966 .676 .427 r
.72728 .48677 .72775 .48318 .7295 .48462 .74072 .67774 Mtetra
.574 .364 .558 r
.74072 .67774 .7295 .48462 .73119 .48507 .74264 .68031 Mtetra
.57 .36 .557 r
.74264 .68031 .73119 .48507 .73282 .48451 .74438 .67991 Mtetra
.568 .359 .557 r
.74438 .67991 .73282 .48451 .73442 .48357 .74606 .67861 Mtetra
.569 .36 .557 r
.74606 .67861 .73442 .48357 .73605 .48288 .74777 .67777 Mtetra
.74777 .67777 .73605 .48288 .73768 .48232 .7495 .67723 Mtetra
.7495 .67723 .73768 .48232 .73931 .48178 .75124 .67671 Mtetra
.57 .36 .557 r
.75124 .67671 .73931 .48178 .74094 .48127 .75297 .67624 Mtetra
.75297 .67624 .74094 .48127 .74258 .48079 .75472 .67581 Mtetra
.75472 .67581 .74258 .48079 .74422 .48032 .75646 .67538 Mtetra
.571 .361 .557 r
.75646 .67538 .74422 .48032 .74588 .48014 .75825 .67567 Mtetra
.57 .361 .557 r
.75825 .67567 .74588 .48014 .74754 .47993 .76003 .67571 Mtetra
.569 .36 .557 r
.76003 .67571 .74754 .47993 .74917 .47923 .76173 .6746 Mtetra
.552 .347 .556 r
.76173 .6746 .74917 .47923 .7507 .47715 .76263 .66184 Mtetra
.107 .022 .468 r
.76263 .66184 .7507 .47715 .75223 .47496 .75166 .4764 Mtetra
.707 .774 .284 r
.75166 .4764 .75223 .47496 .75379 .47327 .75307 .47257 Mtetra
.823 .832 .855 r
.75307 .47257 .75379 .47327 .75541 .47243 .75465 .4712 Mtetra
.635 .668 .865 r
.75465 .4712 .75541 .47243 .75706 .4721 .75631 .47083 Mtetra
.559 .627 .875 r
.75631 .47083 .75706 .4721 .75873 .47195 .75799 .47081 Mtetra
.594 .667 .89 r
.75799 .47081 .75873 .47195 .7604 .47168 .75965 .47062 Mtetra
.636 .701 .893 r
.75965 .47062 .7604 .47168 .76205 .4713 .76131 .47025 Mtetra
.64 .705 .893 r
.76131 .47025 .76205 .4713 .7637 .47089 .76297 .46985 Mtetra
.641 .707 .895 r
.76297 .46985 .7637 .47089 .76536 .47048 .76462 .46945 Mtetra
.643 .711 .896 r
.76462 .46945 .76536 .47048 .76702 .47005 .76628 .46904 Mtetra
.649 .717 .897 r
.76628 .46904 .76702 .47005 .76867 .4696 .76794 .4686 Mtetra
.661 .724 .896 r
.76794 .4686 .76867 .4696 .77032 .4691 .76959 .46811 Mtetra
.671 .729 .894 r
.76959 .46811 .77032 .4691 .77197 .46856 .77124 .46757 Mtetra
.676 .732 .892 r
.77124 .46757 .77197 .46856 .77362 .468 .77289 .46701 Mtetra
.72 .748 .875 r
.77289 .46701 .77362 .468 .77526 .4673 .77452 .46621 Mtetra
.715 .728 .86 r
.77452 .46621 .77526 .4673 .7769 .46659 .77616 .46542 Mtetra
.643 .685 .874 r
.77616 .46542 .7769 .46659 .77855 .46606 .77782 .46502 Mtetra
.097 .403 .856 r
.77782 .46502 .77855 .46606 .78026 .46614 .7796 .46607 Mtetra
.89 .466 .161 r
.7796 .46607 .78026 .46614 .78201 .46688 .78164 .4704 Mtetra
.97 .673 .404 r
.78164 .4704 .78201 .46688 .7838 .46802 .79833 .66137 Mtetra
.575 .364 .558 r
.79833 .66137 .7838 .46802 .78554 .46851 .8004 .66477 Mtetra
.57 .36 .557 r
.8004 .66477 .78554 .46851 .78719 .46787 .80217 .66436 Mtetra
.568 .359 .557 r
.80217 .66436 .78719 .46787 .78882 .46687 .80387 .66299 Mtetra
.568 .36 .557 r
.80387 .66299 .78882 .46687 .79045 .46601 .80558 .66173 Mtetra
.569 .36 .557 r
.80558 .66173 .79045 .46601 .79211 .46535 .80733 .66097 Mtetra
.80733 .66097 .79211 .46535 .79376 .46472 .80907 .66021 Mtetra
.80907 .66021 .79376 .46472 .79542 .46412 .81083 .6595 Mtetra
.81083 .6595 .79542 .46412 .79709 .46354 .81259 .65883 Mtetra
.81259 .65883 .79709 .46354 .79875 .46297 .81435 .65819 Mtetra
.81435 .65819 .79875 .46297 .80042 .46242 .81611 .65759 Mtetra
.81611 .65759 .80042 .46242 .80209 .46188 .81788 .65702 Mtetra
.81788 .65702 .80209 .46188 .80376 .46136 .81965 .65648 Mtetra
.57 .36 .557 r
.81965 .65648 .80376 .46136 .80543 .46084 .82143 .65598 Mtetra
.82143 .65598 .80543 .46084 .8071 .46034 .82321 .65552 Mtetra
.82321 .65552 .8071 .46034 .80878 .45985 .825 .65509 Mtetra
.825 .65509 .80878 .45985 .81046 .45938 .82679 .65473 Mtetra
.57 .361 .557 r
.82679 .65473 .81046 .45938 .81214 .45893 .82859 .65441 Mtetra
.82859 .65441 .81214 .45893 .81383 .45849 .83039 .6541 Mtetra
.571 .361 .557 r
.83039 .6541 .81383 .45849 .81553 .45822 .83224 .6544 Mtetra
.83224 .6544 .81553 .45822 .81724 .45805 .83411 .65485 Mtetra
.569 .36 .557 r
.83411 .65485 .81724 .45805 .81892 .45752 .83587 .65406 Mtetra
.56 .353 .557 r
.83587 .65406 .81892 .45752 .8205 .45592 .83703 .64652 Mtetra
.142 .053 .486 r
.83703 .64652 .8205 .45592 .82203 .45375 .8216 .45579 Mtetra
0 0 0 r
.8216 .45579 .82203 .45375 .8236 .45197 .82294 .45149 Mtetra
.897 .891 .815 r
.82294 .45149 .8236 .45197 .82522 .45083 .82449 .44957 Mtetra
.684 .689 .848 r
.82449 .44957 .82522 .45083 .8269 .45028 .82616 .44892 Mtetra
.623 .646 .852 r
.82616 .44892 .8269 .45028 .8286 .4499 .82787 .4486 Mtetra
.619 .655 .863 r
.82787 .4486 .8286 .4499 .8303 .44952 .82957 .44831 Mtetra
.654 .684 .866 r
.82957 .44831 .8303 .44952 .83199 .44905 .83126 .44783 Mtetra
.83126 .44783 .83199 .44905 .83368 .44857 .83296 .44736 Mtetra
.655 .685 .866 r
.83296 .44736 .83368 .44857 .83537 .44809 .83465 .44688 Mtetra
.657 .687 .866 r
.83465 .44688 .83537 .44809 .83706 .44759 .83634 .44638 Mtetra
.659 .687 .866 r
.83634 .44638 .83706 .44759 .83876 .4471 .83803 .44589 Mtetra
.659 .688 .865 r
.83803 .44589 .83876 .4471 .84045 .44659 .83973 .44538 Mtetra
.66 .688 .865 r
.83973 .44538 .84045 .44659 .84214 .44608 .84142 .44487 Mtetra
.661 .688 .865 r
.84142 .44487 .84214 .44608 .84384 .44557 .84312 .44436 Mtetra
.661 .689 .865 r
.84312 .44436 .84384 .44557 .84553 .44505 .84481 .44385 Mtetra
.662 .689 .865 r
.84481 .44385 .84553 .44505 .84723 .44454 .84651 .44333 Mtetra
.663 .69 .865 r
.84651 .44333 .84723 .44454 .84892 .44401 .8482 .4428 Mtetra
.8482 .4428 .84892 .44401 .85062 .44348 .8499 .44228 Mtetra
.664 .691 .866 r
.8499 .44228 .85062 .44348 .85232 .44295 .8516 .44175 Mtetra
.664 .692 .866 r
.8516 .44175 .85232 .44295 .85401 .44242 .8533 .44122 Mtetra
.665 .693 .866 r
.8533 .44122 .85401 .44242 .85571 .44188 .855 .44068 Mtetra
.666 .694 .867 r
.855 .44068 .85571 .44188 .85741 .44133 .8567 .44015 Mtetra
.666 .696 .868 r
.8567 .44015 .85741 .44133 .85911 .44079 .8584 .4396 Mtetra
.667 .697 .869 r
.8584 .4396 .85911 .44079 .86081 .44023 .8601 .43906 Mtetra
.668 .699 .869 r
.8601 .43906 .86081 .44023 .86251 .43968 .8618 .43851 Mtetra
.668 .7 .871 r
.8618 .43851 .86251 .43968 .86421 .43912 .8635 .43795 Mtetra
.668 .702 .872 r
.8635 .43795 .86421 .43912 .86591 .43856 .86521 .4374 Mtetra
.667 .702 .873 r
.86521 .4374 .86591 .43856 .86762 .43801 .86691 .43686 Mtetra
.667 .703 .874 r
.86691 .43686 .86762 .43801 .86932 .43746 .86862 .43631 Mtetra
.86862 .43631 .86932 .43746 .87103 .43692 .87033 .43577 Mtetra
.666 .703 .875 r
.87033 .43577 .87103 .43692 .87274 .43638 .87204 .43523 Mtetra
.87204 .43523 .87274 .43638 .87445 .43584 .87375 .43469 Mtetra
.665 .703 .875 r
.87375 .43469 .87445 .43584 .87616 .43531 .87546 .43416 Mtetra
.664 .702 .875 r
.87546 .43416 .87616 .43531 .87787 .43478 .87717 .43363 Mtetra
.663 .702 .875 r
.87717 .43363 .87787 .43478 .87959 .43426 .87888 .4331 Mtetra
.663 .701 .875 r
.87888 .4331 .87959 .43426 .8813 .43374 .8806 .43258 Mtetra
.662 .7 .875 r
.8806 .43258 .8813 .43374 .88302 .43322 .88232 .43206 Mtetra
.66 .699 .875 r
.88232 .43206 .88302 .43322 .88474 .43271 .88404 .43155 Mtetra
.659 .698 .875 r
.88404 .43155 .88474 .43271 .88646 .43221 .88576 .43104 Mtetra
.657 .697 .876 r
.88576 .43104 .88646 .43221 .88818 .43171 .88748 .43054 Mtetra
.655 .696 .876 r
.88748 .43054 .88818 .43171 .88991 .43123 .88921 .43006 Mtetra
.653 .695 .877 r
.88921 .43006 .88991 .43123 .89163 .43075 .89093 .42958 Mtetra
.651 .694 .877 r
.89093 .42958 .89163 .43075 .89336 .43029 .89266 .42912 Mtetra
.646 .692 .879 r
.89266 .42912 .89336 .43029 .89509 .42984 .8944 .42868 Mtetra
.634 .688 .883 r
.8944 .42868 .89509 .42984 .89683 .42944 .89614 .42829 Mtetra
.611 .681 .891 r
.89614 .42829 .89683 .42944 .89858 .42912 .89789 .42801 Mtetra
.607 .687 .899 r
.89789 .42801 .89858 .42912 .90033 .4288 .89965 .42774 Mtetra
.615 .702 .906 r
.89965 .42774 .90033 .4288 .90208 .42844 .90141 .42744 Mtetra
.645 .726 .908 r
.90141 .42744 .90208 .42844 .90382 .42797 .90314 .42699 Mtetra
.66 .74 .909 r
.90314 .42699 .90382 .42797 .90554 .42743 .90488 .42648 Mtetra
.673 .751 .909 r
.90488 .42648 .90554 .42743 .90727 .42684 .9066 .42591 Mtetra
.685 .76 .909 r
.9066 .42591 .90727 .42684 .90899 .4262 .90832 .42528 Mtetra
.691 .765 .909 r
.90832 .42528 .90899 .4262 .9107 .42554 .91004 .42463 Mtetra
.709 .774 .903 r
.91004 .42463 .9107 .42554 .91241 .4248 .91175 .42389 Mtetra
.77 .794 .872 r
.91175 .42389 .91241 .4248 .91408 .42372 .91342 .42279 Mtetra
.695 .767 .907 r
.91342 .42279 .91408 .42372 .9158 .42305 .91514 .42212 Mtetra
.423 .634 .943 r
.91514 .42212 .9158 .42305 .91763 .42331 .91697 .42238 Mtetra
.786 .365 0 r
.91697 .42238 .91763 .42331 .92002 .42815 .91937 .42731 Mtetra
.973 .661 .313 r
.91937 .42731 .92002 .42815 .94608 .62674 .9454 .62593 Mtetra
.763 .319 0 r
.9454 .62593 .94608 .62674 .94854 .6312 .94786 .63032 Mtetra
.484 .695 .962 r
.94786 .63032 .94854 .6312 .95047 .63125 .94979 .63036 Mtetra
.691 .787 .924 r
.94979 .63036 .95047 .63125 .95231 .63056 .95163 .62966 Mtetra
.742 .803 .901 r
.95163 .62966 .95231 .63056 .95412 .6296 .95343 .6287 Mtetra
.487 .691 .958 r
.95343 .6287 .95412 .6296 .95605 .62966 .95537 .62874 Mtetra
.617 .752 .942 r
.95537 .62874 .95605 .62966 .95794 .62927 .95725 .62836 Mtetra
.798 .815 .865 r
.95725 .62836 .95794 .62927 .9597 .62794 .95901 .62702 Mtetra
.98 .776 .557 r
.95901 .62702 .9597 .62794 .96077 .62115 .96009 .62022 Mtetra
.975 .669 .322 r
.96009 .62022 .96077 .62115 .93732 .42151 .93666 .42052 Mtetra
.963 .783 .613 r
.93666 .42052 .93732 .42151 .93851 .41661 .93786 .41562 Mtetra
.755 .776 .87 r
.93786 .41562 .93851 .41661 .9402 .41559 .93955 .4146 Mtetra
.626 .724 .918 r
.93955 .4146 .9402 .41559 .94197 .41521 .94132 .41423 Mtetra
.544 .685 .931 r
.94132 .41423 .94197 .41521 .94379 .41515 .94313 .41416 Mtetra
.747 .773 .874 r
.94313 .41416 .94379 .41515 .94548 .41417 .94483 .41318 Mtetra
.681 .748 .902 r
.94483 .41318 .94548 .41417 .94722 .41356 .94657 .41256 Mtetra
.489 .655 .933 r
.94657 .41256 .94722 .41356 .94906 .41367 .94841 .41268 Mtetra
.738 .32 0 r
.94841 .41268 .94906 .41367 .95152 .41847 .95087 .41747 Mtetra
.97 .655 .291 r
.95087 .41747 .95152 .41847 .97971 .61781 .97903 .61688 Mtetra
.737 .307 0 r
.97903 .61688 .97971 .61781 .98228 .62256 .98161 .62162 Mtetra
.032 .463 .877 r
.37349 .78357 .37441 .78433 .37589 .78495 .37497 .7842 Mtetra
.643 .762 .935 r
.37497 .7842 .37589 .78495 .37741 .78455 .37649 .7838 Mtetra
.809 .779 .825 r
.37649 .7838 .37741 .78455 .37897 .78314 .37805 .78239 Mtetra
.908 .738 .659 r
.37805 .78239 .37897 .78314 .38069 .77794 .37976 .77721 Mtetra
.937 .686 .534 r
.37976 .77721 .38069 .77794 .38971 .58822 .38884 .58746 Mtetra
.911 .73 .644 r
.38884 .58746 .38971 .58822 .39136 .58255 .39049 .58176 Mtetra
.773 .763 .844 r
.39049 .58176 .39136 .58255 .39283 .58151 .39196 .5807 Mtetra
.623 .732 .925 r
.39196 .5807 .39283 .58151 .39426 .58123 .3934 .58041 Mtetra
.475 .675 .952 r
.3934 .58041 .39426 .58123 .39569 .58132 .39482 .58048 Mtetra
.653 .733 .908 r
.39482 .58048 .39569 .58132 .39713 .58097 .39626 .58008 Mtetra
.663 .723 .894 r
.39626 .58008 .39713 .58097 .39857 .58057 .39771 .57964 Mtetra
.663 .716 .888 r
.39771 .57964 .39857 .58057 .40002 .58011 .39916 .5792 Mtetra
.737 .736 .851 r
.39916 .5792 .40002 .58011 .40148 .57922 .40062 .57836 Mtetra
.689 .738 .889 r
.40062 .57836 .40148 .57922 .40294 .57851 .40207 .57781 Mtetra
.448 .697 .973 r
.40207 .57781 .40294 .57851 .40438 .57824 .4035 .57788 Mtetra
.921 .574 .361 r
.4035 .57788 .40438 .57824 .40573 .58053 .40476 .58284 Mtetra
.935 .678 .524 r
.40476 .58284 .40573 .58053 .40687 .58919 .39962 .77173 Mtetra
.576 .366 .558 r
.39962 .77173 .40687 .58919 .40212 .77043 .40101 .77544 Mtetra
.183 0 .321 r
.40101 .77544 .40212 .77043 .40915 .60709 .40265 .77198 Mtetra
0 0 .25 r
.40265 .77198 .40915 .60709 .41153 .57929 .41052 .58276 Mtetra
.906 .829 .365 r
.41052 .58276 .41153 .57929 .41309 .57556 .41221 .57529 Mtetra
.849 .882 .863 r
.41221 .57529 .41309 .57556 .41456 .57448 .4137 .5739 Mtetra
.66 .804 .952 r
.4137 .5739 .41456 .57448 .41602 .57403 .41515 .57345 Mtetra
.505 .757 .986 r
.41515 .57345 .41602 .57403 .41747 .57382 .4166 .57335 Mtetra
.613 .826 .982 r
.4166 .57335 .41747 .57382 .41892 .5734 .41805 .57298 Mtetra
.623 .844 .984 r
.41805 .57298 .41892 .5734 .42038 .57296 .41951 .57257 Mtetra
.614 .85 .988 r
.41951 .57257 .42038 .57296 .42183 .57255 .42096 .57216 Mtetra
.623 .852 .986 r
.42096 .57216 .42183 .57255 .42329 .57225 .42242 .57174 Mtetra
.647 .82 .966 r
.42242 .57174 .42329 .57225 .42474 .57197 .42388 .5713 Mtetra
.66 .778 .936 r
.42388 .5713 .42474 .57197 .4262 .57166 .42534 .57086 Mtetra
.664 .746 .911 r
.42534 .57086 .4262 .57166 .42766 .57114 .4268 .57041 Mtetra
.665 .763 .924 r
.4268 .57041 .42766 .57114 .42913 .57054 .42827 .56995 Mtetra
.66 .801 .951 r
.42827 .56995 .42913 .57054 .43059 .56994 .42973 .56949 Mtetra
.654 .843 .973 r
.42973 .56949 .43059 .56994 .43206 .56929 .4312 .56901 Mtetra
.614 .883 .99 r
.4312 .56901 .43206 .56929 .43353 .56877 .43266 .56855 Mtetra
.572 .886 .99 r
.43266 .56855 .43353 .56877 .43499 .56849 .43413 .56812 Mtetra
.551 .836 .998 r
.43413 .56812 .43499 .56849 .43643 .56915 .43559 .56782 Mtetra
.616 .63 .842 r
.43559 .56782 .43643 .56915 .43784 .57067 .43705 .56759 Mtetra
.603 .495 .703 r
.43705 .56759 .43784 .57067 .43923 .57332 .43851 .56735 Mtetra
.615 .452 .637 r
.43851 .56735 .43923 .57332 .44068 .57372 .43999 .5666 Mtetra
.605 .435 .626 r
.43999 .5666 .44068 .57372 .44217 .57282 .44146 .56594 Mtetra
.581 .419 .627 r
.44146 .56594 .44217 .57282 .44363 .5728 .44292 .56587 Mtetra
.373 .267 .603 r
.44292 .56587 .44363 .5728 .4408 .75517 .44431 .56902 Mtetra
0 0 .356 r
.44431 .56902 .4408 .75517 .44216 .76321 .44136 .75814 Mtetra
0 0 .406 r
.44136 .75814 .44216 .76321 .44365 .7658 .44277 .76418 Mtetra
.277 .421 .827 r
.44277 .76418 .44365 .7658 .44519 .76635 .4443 .76512 Mtetra
.626 .661 .864 r
.4443 .76512 .44519 .76635 .44675 .76604 .44586 .76481 Mtetra
.705 .689 .832 r
.44586 .76481 .44675 .76604 .44832 .76523 .44742 .76406 Mtetra
.697 .696 .844 r
.44742 .76406 .44832 .76523 .4499 .76364 .44899 .76337 Mtetra
.674 .904 .977 r
.44899 .76337 .4499 .76364 .4515 .76123 .45056 .76271 Mtetra
.308 0 .12 r
.45056 .76271 .4515 .76123 .45313 .75784 .45213 .76204 Mtetra
.538 .257 .436 r
.45213 .76204 .45313 .75784 .45471 .75638 .45369 .76189 Mtetra
.545 .281 .465 r
.45369 .76189 .45471 .75638 .45626 .7564 .45525 .76171 Mtetra
.505 .242 .45 r
.45525 .76171 .45626 .7564 .45783 .75574 .45682 .76095 Mtetra
.189 0 .334 r
.45682 .76095 .45783 .75574 .4626 .58029 .45845 .75726 Mtetra
0 0 .33 r
.45845 .75726 .4626 .58029 .46438 .56335 .46344 .56816 Mtetra
.694 .678 .137 r
.46344 .56816 .46438 .56335 .46592 .55984 .46506 .55989 Mtetra
.91 .935 .814 r
.46506 .55989 .46592 .55984 .46742 .55859 .46657 .558 Mtetra
.683 .809 .943 r
.46657 .558 .46742 .55859 .4689 .55824 .46806 .55745 Mtetra
.552 .719 .951 r
.46806 .55745 .4689 .55824 .47038 .55819 .46954 .55734 Mtetra
.61 .722 .925 r
.46954 .55734 .47038 .55819 .47186 .55795 .47102 .55708 Mtetra
.651 .729 .906 r
.47102 .55708 .47186 .55795 .47334 .55754 .4725 .55667 Mtetra
.653 .731 .907 r
.4725 .55667 .47334 .55754 .47483 .55708 .47399 .55626 Mtetra
.671 .75 .91 r
.47399 .55626 .47483 .55708 .47632 .55638 .47548 .55578 Mtetra
.675 .808 .946 r
.47548 .55578 .47632 .55638 .47781 .55565 .47697 .55526 Mtetra
.643 .863 .982 r
.47697 .55526 .47781 .55565 .4793 .55516 .47846 .55477 Mtetra
.58 .847 .995 r
.47846 .55477 .4793 .55516 .48078 .55554 .47995 .55442 Mtetra
.619 .667 .874 r
.47995 .55442 .48078 .55554 .48225 .55693 .48144 .55416 Mtetra
.607 .509 .717 r
.48144 .55416 .48225 .55693 .4837 .55946 .48293 .55391 Mtetra
.614 .455 .643 r
.48293 .55391 .4837 .55946 .48518 .56061 .48442 .55322 Mtetra
.607 .435 .624 r
.48442 .55322 .48518 .56061 .48668 .55959 .48592 .55248 Mtetra
.586 .422 .626 r
.48592 .55248 .48668 .55959 .48818 .55927 .48741 .55227 Mtetra
.447 .322 .616 r
.48741 .55227 .48818 .55927 .48782 .73733 .48888 .55456 Mtetra
0 0 .372 r
.48888 .55456 .48782 .73733 .48927 .74979 .48844 .74293 Mtetra
0 0 .409 r
.48844 .74293 .48927 .74979 .49082 .75279 .48994 .75097 Mtetra
.149 .313 .775 r
.48994 .75097 .49082 .75279 .49239 .75362 .49151 .75238 Mtetra
.616 .658 .868 r
.49151 .75238 .49239 .75362 .49398 .75343 .4931 .75212 Mtetra
.697 .677 .827 r
.4931 .75212 .49398 .75343 .49557 .75292 .49469 .75138 Mtetra
.677 .642 .808 r
.49469 .75138 .49557 .75292 .49716 .75233 .49628 .75074 Mtetra
.647 .623 .812 r
.49628 .75074 .49716 .75233 .49875 .75174 .49787 .75029 Mtetra
.651 .642 .828 r
.49787 .75029 .49875 .75174 .50034 .75112 .49946 .74984 Mtetra
.649 .664 .851 r
.49946 .74984 .50034 .75112 .50193 .7507 .50106 .74941 Mtetra
.646 .662 .851 r
.50106 .74941 .50193 .7507 .50352 .75038 .50265 .749 Mtetra
.651 .651 .837 r
.50265 .749 .50352 .75038 .50512 .74986 .50424 .74855 Mtetra
.671 .669 .839 r
.50424 .74855 .50512 .74986 .50672 .74857 .50584 .74799 Mtetra
.702 .829 .943 r
.50584 .74799 .50672 .74857 .50832 .74624 .50744 .74733 Mtetra
.207 0 0 r
.50744 .74733 .50832 .74624 .50993 .7429 .50904 .74666 Mtetra
.497 .21 .408 r
.50904 .74666 .50993 .7429 .51154 .73981 .51063 .74612 Mtetra
.537 .28 .474 r
.51063 .74612 .51154 .73981 .51313 .73903 .51223 .7457 Mtetra
.541 .287 .479 r
.51223 .7457 .51313 .73903 .51472 .73928 .51383 .74534 Mtetra
.537 .278 .471 r
.51383 .74534 .51472 .73928 .51632 .73935 .51543 .74495 Mtetra
.532 .27 .463 r
.51543 .74495 .51632 .73935 .51792 .739 .51703 .74454 Mtetra
.531 .268 .462 r
.51703 .74454 .51792 .739 .51952 .73864 .51864 .74413 Mtetra
.531 .267 .46 r
.51864 .74413 .51952 .73864 .52112 .73826 .52024 .74371 Mtetra
.53 .266 .46 r
.52024 .74371 .52112 .73826 .52272 .73786 .52184 .74329 Mtetra
.53 .266 .459 r
.52184 .74329 .52272 .73786 .52432 .73744 .52345 .74286 Mtetra
.53 .265 .459 r
.52345 .74286 .52432 .73744 .52592 .73702 .52505 .74243 Mtetra
.529 .265 .459 r
.52505 .74243 .52592 .73702 .52753 .73658 .52666 .742 Mtetra
.52666 .742 .52753 .73658 .52913 .73614 .52827 .74157 Mtetra
.52827 .74157 .52913 .73614 .53074 .73569 .52988 .74113 Mtetra
.52988 .74113 .53074 .73569 .53234 .73524 .53149 .7407 Mtetra
.53149 .7407 .53234 .73524 .53395 .73477 .5331 .74026 Mtetra
.529 .266 .46 r
.5331 .74026 .53395 .73477 .53556 .7343 .53471 .73981 Mtetra
.53471 .73981 .53556 .7343 .53717 .73382 .53632 .73937 Mtetra
.53 .267 .461 r
.53632 .73937 .53717 .73382 .53878 .73333 .53794 .73892 Mtetra
.53 .267 .462 r
.53794 .73892 .53878 .73333 .54039 .73284 .53955 .73847 Mtetra
.53 .268 .463 r
.53955 .73847 .54039 .73284 .542 .73233 .54117 .73803 Mtetra
.531 .269 .464 r
.54117 .73803 .542 .73233 .54361 .73182 .54278 .73758 Mtetra
.532 .271 .465 r
.54278 .73758 .54361 .73182 .54523 .73135 .5444 .73714 Mtetra
.532 .272 .465 r
.5444 .73714 .54523 .73135 .54684 .73092 .54602 .73671 Mtetra
.532 .271 .465 r
.54602 .73671 .54684 .73092 .54846 .73048 .54764 .73627 Mtetra
.543 .281 .468 r
.54764 .73627 .54846 .73048 .55008 .73051 .54926 .73603 Mtetra
.551 .285 .466 r
.54926 .73603 .55008 .73051 .5517 .73087 .55088 .73595 Mtetra
.515 .249 .449 r
.55088 .73595 .5517 .73087 .55332 .73011 .5525 .73536 Mtetra
.371 .128 .409 r
.5525 .73536 .55332 .73011 .55489 .72387 .55411 .73298 Mtetra
0 0 .083 r
.55411 .73298 .55489 .72387 .55484 .53709 .55562 .71873 Mtetra
0 0 .396 r
.55562 .71873 .55484 .53709 .55634 .53275 .55554 .5333 Mtetra
.962 .944 .674 r
.55554 .5333 .55634 .53275 .55786 .53076 .55705 .53029 Mtetra
.73 .86 .942 r
.55705 .53029 .55786 .53076 .55939 .53011 .55858 .52953 Mtetra
.566 .788 .983 r
.55858 .52953 .55939 .53011 .56092 .5298 .56012 .52929 Mtetra
.502 .784 .996 r
.56012 .52929 .56092 .5298 .56246 .52955 .56166 .52914 Mtetra
.606 .853 .991 r
.56166 .52914 .56246 .52955 .564 .52911 .5632 .52872 Mtetra
.598 .856 .993 r
.5632 .52872 .564 .52911 .56553 .52868 .56473 .52831 Mtetra
.6 .863 .993 r
.56473 .52831 .56553 .52868 .56707 .52825 .56627 .52788 Mtetra
.615 .867 .99 r
.56627 .52788 .56707 .52825 .56861 .52782 .56781 .52742 Mtetra
.622 .86 .988 r
.56781 .52742 .56861 .52782 .57015 .5274 .56935 .52696 Mtetra
.62 .849 .986 r
.56935 .52696 .57015 .5274 .57169 .52697 .57089 .52652 Mtetra
.608 .841 .988 r
.57089 .52652 .57169 .52697 .57323 .52655 .57243 .52612 Mtetra
.599 .843 .991 r
.57243 .52612 .57323 .52655 .57477 .52614 .57398 .52573 Mtetra
.591 .849 .993 r
.57398 .52573 .57477 .52614 .57632 .52572 .57552 .52534 Mtetra
.586 .857 .995 r
.57552 .52534 .57632 .52572 .57786 .52529 .57707 .52494 Mtetra
.58 .862 .995 r
.57707 .52494 .57786 .52529 .5794 .52487 .57861 .52454 Mtetra
.574 .868 .995 r
.57861 .52454 .5794 .52487 .58095 .52444 .58016 .52413 Mtetra
.57 .873 .994 r
.58016 .52413 .58095 .52444 .5825 .524 .58171 .52372 Mtetra
.567 .877 .993 r
.58171 .52372 .5825 .524 .58404 .52356 .58326 .52329 Mtetra
.564 .881 .992 r
.58326 .52329 .58404 .52356 .58559 .52311 .5848 .52286 Mtetra
.562 .884 .99 r
.5848 .52286 .58559 .52311 .58714 .52266 .58635 .52242 Mtetra
.56 .887 .988 r
.58635 .52242 .58714 .52266 .58869 .52221 .58791 .52198 Mtetra
.559 .889 .987 r
.58791 .52198 .58869 .52221 .59024 .52175 .58946 .52153 Mtetra
.558 .891 .986 r
.58946 .52153 .59024 .52175 .59179 .52128 .59101 .52107 Mtetra
.556 .892 .985 r
.59101 .52107 .59179 .52128 .59335 .52082 .59256 .52061 Mtetra
.555 .892 .984 r
.59256 .52061 .59335 .52082 .5949 .52035 .59412 .52015 Mtetra
.554 .893 .983 r
.59412 .52015 .5949 .52035 .59645 .51989 .59567 .51968 Mtetra
.553 .893 .983 r
.59567 .51968 .59645 .51989 .59801 .51943 .59723 .51922 Mtetra
.552 .892 .983 r
.59723 .51922 .59801 .51943 .59956 .51897 .59878 .51876 Mtetra
.55 .891 .983 r
.59878 .51876 .59956 .51897 .60112 .51851 .60034 .5183 Mtetra
.547 .89 .983 r
.60034 .5183 .60112 .51851 .60268 .51806 .6019 .51785 Mtetra
.544 .888 .984 r
.6019 .51785 .60268 .51806 .60424 .51762 .60346 .5174 Mtetra
.54 .886 .984 r
.60346 .5174 .60424 .51762 .6058 .51718 .60502 .51696 Mtetra
.531 .883 .983 r
.60502 .51696 .6058 .51718 .60736 .51676 .60658 .51654 Mtetra
.526 .879 .985 r
.60658 .51654 .60736 .51676 .60892 .5164 .60815 .51613 Mtetra
.531 .869 .992 r
.60815 .51613 .60892 .5164 .61049 .51615 .60971 .51575 Mtetra
.577 .85 .996 r
.60971 .51575 .61049 .51615 .61206 .51592 .61128 .51537 Mtetra
.615 .817 .978 r
.61128 .51537 .61206 .51592 .61363 .51568 .61284 .51499 Mtetra
.642 .783 .949 r
.61284 .51499 .61363 .51568 .6152 .51533 .61441 .51456 Mtetra
.654 .766 .932 r
.61441 .51456 .6152 .51533 .61676 .51494 .61598 .51411 Mtetra
.666 .755 .917 r
.61598 .51411 .61676 .51494 .61833 .5145 .61755 .51362 Mtetra
.679 .747 .903 r
.61755 .51362 .61833 .5145 .6199 .51402 .61911 .51308 Mtetra
.685 .734 .889 r
.61911 .51308 .6199 .51402 .62147 .51351 .62068 .5125 Mtetra
.688 .724 .877 r
.62068 .5125 .62147 .51351 .62303 .51295 .62224 .5119 Mtetra
.691 .716 .868 r
.62224 .5119 .62303 .51295 .6246 .51237 .62381 .51128 Mtetra
.689 .707 .861 r
.62381 .51128 .6246 .51237 .62617 .51175 .62538 .51066 Mtetra
.686 .705 .862 r
.62538 .51066 .62617 .51175 .62773 .51109 .62695 .51005 Mtetra
.677 .713 .876 r
.62695 .51005 .62773 .51109 .6293 .51034 .62852 .5095 Mtetra
.676 .757 .912 r
.62852 .5095 .6293 .51034 .63086 .5096 .63009 .50897 Mtetra
.669 .812 .951 r
.63009 .50897 .63086 .5096 .63243 .5089 .63166 .50844 Mtetra
.661 .86 .976 r
.63166 .50844 .63243 .5089 .634 .50831 .63323 .50789 Mtetra
.654 .868 .98 r
.63323 .50789 .634 .50831 .63557 .50776 .63481 .50734 Mtetra
.649 .866 .981 r
.63481 .50734 .63557 .50776 .63715 .50724 .63638 .5068 Mtetra
.637 .859 .983 r
.63638 .5068 .63715 .50724 .63872 .5067 .63796 .5063 Mtetra
.625 .867 .988 r
.63796 .5063 .63872 .5067 .6403 .50619 .63954 .50581 Mtetra
.618 .872 .99 r
.63954 .50581 .6403 .50619 .64188 .50572 .64112 .50532 Mtetra
.629 .87 .987 r
.64112 .50532 .64188 .50572 .64346 .50538 .6427 .50482 Mtetra
.655 .829 .967 r
.6427 .50482 .64346 .50538 .64505 .50504 .64428 .50431 Mtetra
.667 .784 .937 r
.64428 .50431 .64505 .50504 .64664 .50465 .64586 .50381 Mtetra
.668 .754 .915 r
.64586 .50381 .64664 .50465 .64821 .50404 .64744 .5033 Mtetra
.667 .781 .934 r
.64744 .5033 .64821 .50404 .64979 .50338 .64903 .50279 Mtetra
.661 .821 .96 r
.64903 .50279 .64979 .50338 .65137 .50272 .65061 .50228 Mtetra
.664 .864 .975 r
.65061 .50228 .65137 .50272 .65294 .50199 .65219 .5017 Mtetra
.618 .899 .987 r
.65219 .5017 .65294 .50199 .65453 .50143 .65378 .50116 Mtetra
.586 .892 .989 r
.65378 .50116 .65453 .50143 .65612 .50116 .65537 .50066 Mtetra
.72 .863 .949 r
.65537 .50066 .65612 .50116 .65775 .50168 .65694 .49992 Mtetra
.635 .595 .792 r
.65694 .49992 .65775 .50168 .65942 .50306 .65854 .49953 Mtetra
.552 .452 .694 r
.65854 .49953 .65942 .50306 .66117 .50667 .66016 .49983 Mtetra
.253 .191 .591 r
.66016 .49983 .66117 .50667 .67065 .69647 .66198 .50476 Mtetra
.057 0 .447 r
.66198 .50476 .67065 .69647 .67259 .70191 .67167 .69849 Mtetra
0 0 .541 r
.67167 .69849 .67259 .70191 .67438 .70391 .67357 .70295 Mtetra
.192 .504 .909 r
.67357 .70295 .67438 .70391 .67612 .70453 .67531 .70366 Mtetra
.623 .748 .936 r
.67531 .70366 .67612 .70453 .67783 .7043 .67701 .70329 Mtetra
.792 .764 .827 r
.67701 .70329 .67783 .7043 .6795 .70316 .67867 .70192 Mtetra
.914 .736 .648 r
.67867 .70192 .6795 .70316 .68099 .69812 .68017 .69693 Mtetra
.968 .689 .452 r
.68017 .69693 .68099 .69812 .67392 .50213 .67318 .50182 Mtetra
.972 .782 .59 r
.67318 .50182 .67392 .50213 .67526 .49581 .67451 .49537 Mtetra
.823 .887 .89 r
.67451 .49537 .67526 .49581 .67683 .4947 .67608 .49412 Mtetra
.6 .808 .98 r
.67608 .49412 .67683 .4947 .67844 .49452 .67769 .49377 Mtetra
.453 .695 .97 r
.67769 .49377 .67844 .49452 .68008 .4948 .67931 .49384 Mtetra
.612 .711 .915 r
.67931 .49384 .68008 .4948 .68169 .49457 .68093 .49356 Mtetra
.628 .704 .901 r
.68093 .49356 .68169 .49457 .6833 .49423 .68254 .49323 Mtetra
.636 .709 .899 r
.68254 .49323 .6833 .49423 .68491 .49383 .68415 .49286 Mtetra
.667 .728 .895 r
.68415 .49286 .68491 .49383 .68651 .4933 .68575 .49235 Mtetra
.681 .737 .892 r
.68575 .49235 .68651 .4933 .68811 .49271 .68735 .49178 Mtetra
.689 .743 .892 r
.68735 .49178 .68811 .49271 .68971 .49209 .68895 .49117 Mtetra
.768 .767 .852 r
.68895 .49117 .68971 .49209 .69129 .49101 .69053 .49009 Mtetra
.724 .759 .88 r
.69053 .49009 .69129 .49101 .69288 .49021 .69213 .4893 Mtetra
.56 .701 .935 r
.69213 .4893 .69288 .49021 .69451 .49009 .69375 .48918 Mtetra
.829 .39 0 r
.69375 .48918 .69451 .49009 .69633 .49368 .69558 .4928 Mtetra
.97 .683 .428 r
.69558 .4928 .69633 .49368 .70812 .68816 .70733 .68736 Mtetra
.916 .519 .146 r
.70733 .68736 .70812 .68816 .71016 .69384 .70936 .69301 Mtetra
0 .401 .849 r
.70936 .69301 .71016 .69384 .71194 .69468 .71115 .69396 Mtetra
.602 .781 .966 r
.71115 .69396 .71194 .69468 .71366 .69429 .71288 .69362 Mtetra
.813 .84 .87 r
.71288 .69362 .71366 .69429 .71534 .6931 .71455 .69228 Mtetra
.934 .782 .669 r
.71455 .69228 .71534 .6931 .71695 .69059 .71607 .68805 Mtetra
.969 .687 .442 r
.71607 .68805 .71695 .69059 .71842 .68554 .70716 .49428 Mtetra
.584 .375 .563 r
.70716 .49428 .71842 .68554 .70953 .49454 .70834 .48583 Mtetra
.632 .447 .614 r
.70834 .48583 .70953 .49454 .71084 .48848 .70989 .48404 Mtetra
.62 .476 .664 r
.70989 .48404 .71084 .48848 .71234 .48595 .7115 .48339 Mtetra
.605 .523 .736 r
.7115 .48339 .71234 .48595 .7139 .48438 .71314 .48316 Mtetra
.646 .674 .862 r
.71314 .48316 .7139 .48438 .71551 .48357 .71476 .48275 Mtetra
.653 .759 .927 r
.71476 .48275 .71551 .48357 .71713 .48312 .71639 .48229 Mtetra
.646 .755 .928 r
.71639 .48229 .71713 .48312 .71876 .4828 .71801 .48186 Mtetra
.727 .755 .874 r
.71801 .48186 .71876 .4828 .72037 .48198 .71962 .48104 Mtetra
.701 .748 .888 r
.71962 .48104 .72037 .48198 .72197 .48118 .72123 .48037 Mtetra
.538 .717 .955 r
.72123 .48037 .72197 .48118 .7236 .48079 .72288 .48027 Mtetra
.808 .331 0 r
.72288 .48027 .7236 .48079 .72534 .48216 .72471 .48313 Mtetra
.97 .679 .421 r
.72471 .48313 .72534 .48216 .72728 .48677 .73816 .67659 Mtetra
.58 .368 .558 r
.73816 .67659 .72728 .48677 .74072 .67774 .74037 .68383 Mtetra
.6 .329 .479 r
.74037 .68383 .74072 .67774 .74264 .68031 .74219 .6848 Mtetra
.523 .246 .436 r
.74219 .6848 .74264 .68031 .74438 .67991 .74393 .68439 Mtetra
.489 .218 .429 r
.74393 .68439 .74438 .67991 .74606 .67861 .74564 .68352 Mtetra
.513 .245 .444 r
.74564 .68352 .74606 .67861 .74777 .67777 .74737 .68289 Mtetra
.525 .257 .451 r
.74737 .68289 .74777 .67777 .7495 .67723 .74911 .68241 Mtetra
.526 .258 .452 r
.74911 .68241 .7495 .67723 .75124 .67671 .75085 .68193 Mtetra
.527 .26 .453 r
.75085 .68193 .75124 .67671 .75297 .67624 .75259 .68146 Mtetra
.528 .261 .454 r
.75259 .68146 .75297 .67624 .75472 .67581 .75434 .68101 Mtetra
.528 .26 .453 r
.75434 .68101 .75472 .67581 .75646 .67538 .75608 .68055 Mtetra
.548 .276 .456 r
.75608 .68055 .75646 .67538 .75825 .67567 .75785 .68045 Mtetra
.539 .263 .446 r
.75785 .68045 .75825 .67567 .76003 .67571 .75961 .68023 Mtetra
.494 .222 .431 r
.75961 .68023 .76003 .67571 .76173 .6746 .76134 .6794 Mtetra
.244 .029 .375 r
.76134 .6794 .76173 .6746 .76263 .66184 .76287 .67576 Mtetra
.984 .701 .374 r
.76287 .67576 .76263 .66184 .75166 .4764 .75139 .48225 Mtetra
0 0 .193 r
.75139 .48225 .75166 .4764 .75307 .47257 .7524 .47258 Mtetra
.92 .969 .78 r
.7524 .47258 .75307 .47257 .75465 .4712 .75394 .47049 Mtetra
.683 .804 .94 r
.75394 .47049 .75465 .4712 .75631 .47083 .75557 .4699 Mtetra
.563 .698 .932 r
.75557 .4699 .75631 .47083 .75799 .47081 .75725 .46977 Mtetra
.603 .692 .906 r
.75725 .46977 .75799 .47081 .75965 .47062 .75891 .46953 Mtetra
.638 .696 .887 r
.75891 .46953 .75965 .47062 .76131 .47025 .76057 .46914 Mtetra
.635 .693 .887 r
.76057 .46914 .76131 .47025 .76297 .46985 .76223 .46877 Mtetra
.638 .7 .891 r
.76223 .46877 .76297 .46985 .76462 .46945 .76388 .46839 Mtetra
.643 .705 .892 r
.76388 .46839 .76462 .46945 .76628 .46904 .76554 .46798 Mtetra
.648 .708 .891 r
.76554 .46798 .76628 .46904 .76794 .4686 .7672 .46755 Mtetra
.659 .714 .889 r
.7672 .46755 .76794 .4686 .76959 .46811 .76885 .46706 Mtetra
.669 .719 .887 r
.76885 .46706 .76959 .46811 .77124 .46757 .77051 .46653 Mtetra
.673 .722 .886 r
.77051 .46653 .77124 .46757 .77289 .46701 .77216 .46598 Mtetra
.731 .745 .863 r
.77216 .46598 .77289 .46701 .77452 .46621 .77379 .46511 Mtetra
.724 .728 .854 r
.77379 .46511 .77452 .46621 .77616 .46542 .77542 .46426 Mtetra
.618 .675 .881 r
.77542 .46426 .77616 .46542 .77782 .46502 .77709 .46396 Mtetra
0 .036 .585 r
.77709 .46396 .77782 .46502 .7796 .46607 .77895 .46607 Mtetra
.974 .677 .393 r
.77895 .46607 .7796 .46607 .78164 .4704 .7956 .65835 Mtetra
.583 .37 .558 r
.7956 .65835 .78164 .4704 .79833 .66137 .79814 .66781 Mtetra
.617 .346 .483 r
.79814 .66781 .79833 .66137 .8004 .66477 .80007 .66931 Mtetra
.527 .249 .437 r
.80007 .66931 .8004 .66477 .80217 .66436 .80185 .66894 Mtetra
.49 .22 .432 r
.80185 .66894 .80217 .66436 .80387 .66299 .80359 .66803 Mtetra
.503 .238 .445 r
.80359 .66803 .80387 .66299 .80558 .66173 .80533 .6672 Mtetra
.523 .26 .457 r
.80533 .6672 .80558 .66173 .80733 .66097 .8071 .66663 Mtetra
.525 .263 .461 r
.8071 .66663 .80733 .66097 .80907 .66021 .80887 .66605 Mtetra
.527 .267 .464 r
.80887 .66605 .80907 .66021 .81083 .6595 .81064 .66548 Mtetra
.529 .27 .467 r
.81064 .66548 .81083 .6595 .81259 .65883 .81241 .66494 Mtetra
.531 .273 .469 r
.81241 .66494 .81259 .65883 .81435 .65819 .81419 .66441 Mtetra
.532 .275 .47 r
.81419 .66441 .81435 .65819 .81611 .65759 .81596 .66388 Mtetra
.533 .276 .471 r
.81596 .66388 .81611 .65759 .81788 .65702 .81774 .66337 Mtetra
.534 .277 .472 r
.81774 .66337 .81788 .65702 .81965 .65648 .81952 .66287 Mtetra
.535 .278 .473 r
.81952 .66287 .81965 .65648 .82143 .65598 .8213 .66239 Mtetra
.536 .279 .473 r
.8213 .66239 .82143 .65598 .82321 .65552 .82309 .66191 Mtetra
.82309 .66191 .82321 .65552 .825 .65509 .82488 .66145 Mtetra
.537 .28 .473 r
.82488 .66145 .825 .65509 .82679 .65473 .82667 .66101 Mtetra
.537 .279 .472 r
.82667 .66101 .82679 .65473 .82859 .65441 .82846 .66058 Mtetra
.537 .278 .47 r
.82846 .66058 .82859 .65441 .83039 .6541 .83025 .66016 Mtetra
.549 .286 .47 r
.83025 .66016 .83039 .6541 .83224 .6544 .83207 .65999 Mtetra
.551 .283 .463 r
.83207 .65999 .83224 .6544 .83411 .65485 .8339 .65992 Mtetra
.515 .248 .448 r
.8339 .65992 .83411 .65485 .83587 .65406 .83568 .65927 Mtetra
.367 .134 .423 r
.83568 .65927 .83587 .65406 .83703 .64652 .83726 .6565 Mtetra
.981 .691 .347 r
.83726 .6565 .83703 .64652 .8216 .45579 .82231 .47056 Mtetra
0 0 .395 r
.82231 .47056 .8216 .45579 .82294 .45149 .82234 .45174 Mtetra
.941 .957 .656 r
.82234 .45174 .82294 .45149 .82449 .44957 .82382 .44893 Mtetra
.713 .84 .942 r
.82382 .44893 .82449 .44957 .82616 .44892 .82548 .44819 Mtetra
.571 .763 .969 r
.82548 .44819 .82616 .44892 .82787 .4486 .82719 .44795 Mtetra
.546 .773 .982 r
.82719 .44795 .82787 .4486 .82957 .44831 .82891 .44774 Mtetra
.628 .833 .979 r
.82891 .44774 .82957 .44831 .83126 .44783 .8306 .44727 Mtetra
.626 .833 .98 r
.8306 .44727 .83126 .44783 .83296 .44736 .83229 .4468 Mtetra
.627 .835 .98 r
.83229 .4468 .83296 .44736 .83465 .44688 .83399 .44632 Mtetra
.632 .839 .98 r
.83399 .44632 .83465 .44688 .83634 .44638 .83568 .44583 Mtetra
.633 .84 .98 r
.83568 .44583 .83634 .44638 .83803 .44589 .83737 .44533 Mtetra
.635 .841 .979 r
.83737 .44533 .83803 .44589 .83973 .44538 .83907 .44483 Mtetra
.636 .842 .979 r
.83907 .44483 .83973 .44538 .84142 .44487 .84076 .44432 Mtetra
.637 .843 .979 r
.84076 .44432 .84142 .44487 .84312 .44436 .84246 .44381 Mtetra
.638 .844 .979 r
.84246 .44381 .84312 .44436 .84481 .44385 .84415 .4433 Mtetra
.639 .844 .979 r
.84415 .4433 .84481 .44385 .84651 .44333 .84585 .44278 Mtetra
.64 .845 .979 r
.84585 .44278 .84651 .44333 .8482 .4428 .84755 .44226 Mtetra
.64 .846 .979 r
.84755 .44226 .8482 .4428 .8499 .44228 .84925 .44173 Mtetra
.641 .846 .979 r
.84925 .44173 .8499 .44228 .8516 .44175 .85095 .44121 Mtetra
.642 .847 .979 r
.85095 .44121 .8516 .44175 .8533 .44122 .85265 .44068 Mtetra
.642 .848 .979 r
.85265 .44068 .8533 .44122 .855 .44068 .85435 .44014 Mtetra
.643 .849 .979 r
.85435 .44014 .855 .44068 .8567 .44015 .85605 .43961 Mtetra
.643 .85 .979 r
.85605 .43961 .8567 .44015 .8584 .4396 .85775 .43907 Mtetra
.644 .851 .979 r
.85775 .43907 .8584 .4396 .8601 .43906 .85945 .43852 Mtetra
.644 .852 .979 r
.85945 .43852 .8601 .43906 .8618 .43851 .86116 .43798 Mtetra
.644 .854 .98 r
.86116 .43798 .8618 .43851 .8635 .43795 .86286 .43743 Mtetra
.643 .856 .981 r
.86286 .43743 .8635 .43795 .86521 .4374 .86457 .43688 Mtetra
.642 .856 .981 r
.86457 .43688 .86521 .4374 .86691 .43686 .86627 .43634 Mtetra
.641 .856 .981 r
.86627 .43634 .86691 .43686 .86862 .43631 .86798 .43579 Mtetra
.86798 .43579 .86862 .43631 .87033 .43577 .86969 .43525 Mtetra
.641 .855 .981 r
.86969 .43525 .87033 .43577 .87204 .43523 .8714 .4347 Mtetra
.641 .854 .981 r
.8714 .4347 .87204 .43523 .87375 .43469 .87311 .43416 Mtetra
.64 .852 .981 r
.87311 .43416 .87375 .43469 .87546 .43416 .87482 .43362 Mtetra
.64 .851 .981 r
.87482 .43362 .87546 .43416 .87717 .43363 .87653 .43309 Mtetra
.639 .849 .981 r
.87653 .43309 .87717 .43363 .87888 .4331 .87825 .43255 Mtetra
.637 .848 .981 r
.87825 .43255 .87888 .4331 .8806 .43258 .87997 .43203 Mtetra
.636 .846 .981 r
.87997 .43203 .8806 .43258 .88232 .43206 .88168 .43151 Mtetra
.634 .845 .981 r
.88168 .43151 .88232 .43206 .88404 .43155 .8834 .43099 Mtetra
.631 .844 .982 r
.8834 .43099 .88404 .43155 .88576 .43104 .88513 .43049 Mtetra
.627 .842 .983 r
.88513 .43049 .88576 .43104 .88748 .43054 .88685 .43 Mtetra
.622 .842 .984 r
.88685 .43 .88748 .43054 .88921 .43006 .88858 .42951 Mtetra
.614 .84 .986 r
.88858 .42951 .88921 .43006 .89093 .42958 .89031 .42905 Mtetra
.602 .839 .989 r
.89031 .42905 .89093 .42958 .89266 .42912 .89204 .42861 Mtetra
.591 .844 .993 r
.89204 .42861 .89266 .42912 .8944 .42868 .89378 .42818 Mtetra
.589 .847 .993 r
.89378 .42818 .8944 .42868 .89614 .42829 .89551 .42775 Mtetra
.605 .84 .988 r
.89551 .42775 .89614 .42829 .89789 .42801 .89725 .42731 Mtetra
.632 .8 .963 r
.89725 .42731 .89789 .42801 .89965 .42774 .89899 .42686 Mtetra
.645 .754 .928 r
.89899 .42686 .89965 .42774 .90141 .42744 .90073 .4264 Mtetra
.647 .72 .902 r
.90073 .4264 .90141 .42744 .90314 .42699 .90246 .42595 Mtetra
.653 .721 .899 r
.90246 .42595 .90314 .42699 .90488 .42648 .9042 .42547 Mtetra
.662 .733 .902 r
.9042 .42547 .90488 .42648 .9066 .42591 .90593 .42495 Mtetra
.68 .751 .905 r
.90593 .42495 .9066 .42591 .90832 .42528 .90766 .42434 Mtetra
.687 .758 .906 r
.90766 .42434 .90832 .42528 .91004 .42463 .90938 .4237 Mtetra
.707 .769 .901 r
.90938 .4237 .91004 .42463 .91175 .42389 .91109 .42297 Mtetra
.771 .792 .87 r
.91109 .42297 .91175 .42389 .91342 .42279 .91276 .42187 Mtetra
.696 .766 .906 r
.91276 .42187 .91342 .42279 .91514 .42212 .91448 .42119 Mtetra
.423 .633 .942 r
.91448 .42119 .91514 .42212 .91697 .42238 .91631 .42145 Mtetra
.79 .37 0 r
.91631 .42145 .91697 .42238 .91937 .42731 .91872 .42646 Mtetra
.973 .661 .312 r
.91872 .42646 .91937 .42731 .9454 .62593 .94472 .62509 Mtetra
.754 .31 0 r
.94472 .62509 .9454 .62593 .94786 .63032 .94717 .62943 Mtetra
.489 .695 .96 r
.94717 .62943 .94786 .63032 .94979 .63036 .9491 .62946 Mtetra
.691 .786 .923 r
.9491 .62946 .94979 .63036 .95163 .62966 .95094 .62876 Mtetra
.742 .802 .9 r
.95094 .62876 .95163 .62966 .95343 .6287 .95275 .62779 Mtetra
.489 .691 .957 r
.95275 .62779 .95343 .6287 .95537 .62874 .95468 .62783 Mtetra
.618 .753 .942 r
.95468 .62783 .95537 .62874 .95725 .62836 .95656 .62744 Mtetra
.798 .815 .865 r
.95656 .62744 .95725 .62836 .95901 .62702 .95833 .6261 Mtetra
.98 .776 .557 r
.95833 .6261 .95901 .62702 .96009 .62022 .9594 .6193 Mtetra
.975 .669 .322 r
.9594 .6193 .96009 .62022 .93666 .42052 .936 .41954 Mtetra
.963 .783 .613 r
.936 .41954 .93666 .42052 .93786 .41562 .9372 .41464 Mtetra
.755 .776 .87 r
.9372 .41464 .93786 .41562 .93955 .4146 .93889 .41361 Mtetra
.626 .725 .918 r
.93889 .41361 .93955 .4146 .94132 .41423 .94066 .41324 Mtetra
.544 .685 .931 r
.94066 .41324 .94132 .41423 .94313 .41416 .94248 .41317 Mtetra
.747 .773 .874 r
.94248 .41317 .94313 .41416 .94483 .41318 .94417 .41219 Mtetra
.681 .748 .902 r
.94417 .41219 .94483 .41318 .94657 .41256 .94592 .41157 Mtetra
.489 .655 .934 r
.94592 .41157 .94657 .41256 .94841 .41268 .94776 .41169 Mtetra
.738 .32 0 r
.94776 .41169 .94841 .41268 .95087 .41747 .95022 .41647 Mtetra
.97 .655 .291 r
.95022 .41647 .95087 .41747 .97903 .61688 .97836 .61594 Mtetra
.738 .308 0 r
.97836 .61594 .97903 .61688 .98161 .62162 .98093 .62069 Mtetra
.031 .462 .877 r
.37256 .78282 .37349 .78357 .37497 .7842 .37404 .78345 Mtetra
.642 .762 .935 r
.37404 .78345 .37497 .7842 .37649 .7838 .37556 .78305 Mtetra
.809 .779 .825 r
.37556 .78305 .37649 .7838 .37805 .78239 .37712 .78164 Mtetra
.908 .738 .66 r
.37712 .78164 .37805 .78239 .37976 .77721 .37884 .77647 Mtetra
.937 .686 .534 r
.37884 .77647 .37976 .77721 .38884 .58746 .38797 .58666 Mtetra
.909 .727 .644 r
.38797 .58666 .38884 .58746 .39049 .58176 .38962 .58094 Mtetra
.773 .759 .84 r
.38962 .58094 .39049 .58176 .39196 .5807 .39109 .57988 Mtetra
.627 .729 .92 r
.39109 .57988 .39196 .5807 .3934 .58041 .39253 .57957 Mtetra
.486 .675 .948 r
.39253 .57957 .3934 .58041 .39482 .58048 .39396 .57963 Mtetra
.684 .738 .892 r
.39396 .57963 .39482 .58048 .39626 .58008 .3954 .5791 Mtetra
.671 .707 .875 r
.3954 .5791 .39626 .58008 .39771 .57964 .39685 .57862 Mtetra
.627 .685 .885 r
.39685 .57862 .39771 .57964 .39916 .5792 .39829 .57833 Mtetra
.478 .664 .944 r
.39829 .57833 .39916 .5792 .40062 .57836 .39972 .57842 Mtetra
.555 0 0 r
.39972 .57842 .40062 .57836 .40207 .57781 .40113 .57908 Mtetra
.745 .389 .377 r
.40113 .57908 .40207 .57781 .4035 .57788 .4025 .58097 Mtetra
.934 .677 .525 r
.4025 .58097 .4035 .57788 .40476 .58284 .39732 .76718 Mtetra
.581 .37 .559 r
.39732 .76718 .40476 .58284 .39962 .77173 .39859 .77398 Mtetra
.699 .373 .422 r
.39859 .77398 .39962 .77173 .40101 .77544 .40005 .77577 Mtetra
.931 .949 .778 r
.40005 .77577 .40101 .77544 .40265 .77198 .40165 .77347 Mtetra
.995 .844 .575 r
.40165 .77347 .40265 .77198 .41052 .58276 .40341 .7664 Mtetra
0 0 .324 r
.40341 .7664 .41052 .58276 .41221 .57529 .41122 .57849 Mtetra
.215 0 .272 r
.41122 .57849 .41221 .57529 .4137 .5739 .41273 .57643 Mtetra
.47 .151 .343 r
.41273 .57643 .4137 .5739 .41515 .57345 .41418 .57598 Mtetra
.554 .235 .382 r
.41418 .57598 .41515 .57345 .4166 .57335 .41562 .57613 Mtetra
.535 .224 .388 r
.41562 .57613 .4166 .57335 .41805 .57298 .41707 .57609 Mtetra
.514 .215 .396 r
.41707 .57609 .41805 .57298 .41951 .57257 .41852 .57583 Mtetra
.464 .171 .383 r
.41852 .57583 .41951 .57257 .42096 .57216 .41999 .57512 Mtetra
.199 0 .25 r
.41999 .57512 .42096 .57216 .42242 .57174 .4215 .57315 Mtetra
0 0 0 r
.4215 .57315 .42242 .57174 .42388 .5713 .423 .57128 Mtetra
.869 .94 .863 r
.423 .57128 .42388 .5713 .42534 .57086 .42449 .56979 Mtetra
.714 .706 .841 r
.42449 .56979 .42534 .57086 .4268 .57041 .42596 .56905 Mtetra
.654 .642 .825 r
.42596 .56905 .4268 .57041 .42827 .56995 .42743 .56862 Mtetra
.629 .634 .837 r
.42743 .56862 .42827 .56995 .42973 .56949 .42889 .56832 Mtetra
.63 .66 .86 r
.42889 .56832 .42973 .56949 .4312 .56901 .43035 .56802 Mtetra
.631 .694 .89 r
.43035 .56802 .4312 .56901 .43266 .56855 .43181 .5677 Mtetra
.637 .73 .915 r
.43181 .5677 .43266 .56855 .43413 .56812 .43327 .56736 Mtetra
.681 .761 .912 r
.43327 .56736 .43413 .56812 .43559 .56782 .43474 .56684 Mtetra
.692 .715 .866 r
.43474 .56684 .43559 .56782 .43705 .56759 .43621 .56624 Mtetra
.68 .653 .816 r
.43621 .56624 .43705 .56759 .43851 .56735 .43768 .56564 Mtetra
.688 .617 .771 r
.43768 .56564 .43851 .56735 .43999 .5666 .43916 .56487 Mtetra
.668 .606 .777 r
.43916 .56487 .43999 .5666 .44146 .56594 .44063 .56427 Mtetra
.603 .58 .801 r
.44063 .56427 .44146 .56594 .44292 .56587 .4421 .5641 Mtetra
.049 .24 .738 r
.4421 .5641 .44292 .56587 .44431 .56902 .44352 .56563 Mtetra
0 0 .196 r
.44352 .56563 .44431 .56902 .44136 .75814 .44485 .57112 Mtetra
0 0 .361 r
.44485 .57112 .44136 .75814 .44277 .76418 .44198 .75863 Mtetra
.293 .23 .613 r
.44198 .75863 .44277 .76418 .4443 .76512 .44345 .76184 Mtetra
.445 .393 .705 r
.44345 .76184 .4443 .76512 .44586 .76481 .44498 .76291 Mtetra
.493 .51 .803 r
.44498 .76291 .44586 .76481 .44742 .76406 .44652 .7633 Mtetra
.486 .712 .971 r
.44652 .7633 .44742 .76406 .44899 .76337 .44808 .7633 Mtetra
.309 .794 .897 r
.44808 .7633 .44899 .76337 .45056 .76271 .44964 .76305 Mtetra
0 0 0 r
.44964 .76305 .45056 .76271 .45213 .76204 .4512 .76263 Mtetra
.217 0 0 r
.4512 .76263 .45213 .76204 .45369 .76189 .45277 .76238 Mtetra
.075 0 0 r
.45277 .76238 .45369 .76189 .45525 .76171 .45433 .76202 Mtetra
.46 .882 .778 r
.45433 .76202 .45525 .76171 .45682 .76095 .45591 .76122 Mtetra
.935 .945 .771 r
.45591 .76122 .45682 .76095 .45845 .75726 .45751 .75885 Mtetra
.987 .885 .548 r
.45751 .75885 .45845 .75726 .46344 .56816 .45918 .7532 Mtetra
0 0 .354 r
.45918 .7532 .46344 .56816 .46506 .55989 .46413 .56434 Mtetra
0 0 .181 r
.46413 .56434 .46506 .55989 .46657 .558 .46569 .55963 Mtetra
0 0 0 r
.46569 .55963 .46657 .558 .46806 .55745 .4672 .55766 Mtetra
.771 .995 .867 r
.4672 .55766 .46806 .55745 .46954 .55734 .4687 .55646 Mtetra
.707 .742 .879 r
.4687 .55646 .46954 .55734 .47102 .55708 .47018 .5558 Mtetra
.634 .647 .845 r
.47018 .5558 .47102 .55708 .4725 .55667 .47167 .55548 Mtetra
.6 .646 .867 r
.47167 .55548 .4725 .55667 .47399 .55626 .47315 .5553 Mtetra
.628 .701 .898 r
.47315 .5553 .47399 .55626 .47548 .55578 .47464 .55499 Mtetra
.659 .752 .918 r
.47464 .55499 .47548 .55578 .47697 .55526 .47613 .55455 Mtetra
.673 .775 .927 r
.47613 .55455 .47697 .55526 .47846 .55477 .47762 .55405 Mtetra
.694 .778 .916 r
.47762 .55405 .47846 .55477 .47995 .55442 .47911 .55347 Mtetra
.699 .728 .873 r
.47911 .55347 .47995 .55442 .48144 .55416 .48061 .55284 Mtetra
.684 .662 .822 r
.48061 .55284 .48144 .55416 .48293 .55391 .4821 .55223 Mtetra
.688 .622 .777 r
.4821 .55223 .48293 .55391 .48442 .55322 .4836 .55147 Mtetra
.675 .609 .774 r
.4836 .55147 .48442 .55322 .48592 .55248 .48509 .55079 Mtetra
.62 .589 .797 r
.48509 .55079 .48592 .55248 .48741 .55227 .48659 .55052 Mtetra
.194 .338 .783 r
.48659 .55052 .48741 .55227 .48888 .55456 .48806 .55176 Mtetra
0 0 .199 r
.48806 .55176 .48888 .55456 .48844 .74293 .4895 .5567 Mtetra
0 0 .38 r
.4895 .5567 .48844 .74293 .48994 .75097 .48911 .74497 Mtetra
.382 .289 .625 r
.48911 .74497 .48994 .75097 .49151 .75238 .49067 .74768 Mtetra
.603 .462 .662 r
.49067 .74768 .49151 .75238 .4931 .75212 .49225 .7473 Mtetra
.628 .477 .659 r
.49225 .7473 .4931 .75212 .49469 .75138 .49384 .74647 Mtetra
.547 .421 .66 r
.49384 .74647 .49469 .75138 .49628 .75074 .49543 .74693 Mtetra
.456 .383 .686 r
.49543 .74693 .49628 .75074 .49787 .75029 .497 .74812 Mtetra
.419 .443 .779 r
.497 .74812 .49787 .75029 .49946 .74984 .49859 .74893 Mtetra
.465 .663 .948 r
.49859 .74893 .49946 .74984 .50106 .74941 .50017 .74905 Mtetra
.566 .856 .997 r
.50017 .74905 .50106 .74941 .50265 .749 .50177 .74866 Mtetra
.62 .881 .989 r
.50177 .74866 .50265 .749 .50424 .74855 .50336 .74815 Mtetra
.59 .853 .994 r
.50336 .74815 .50424 .74855 .50584 .74799 .50496 .74774 Mtetra
.45 .839 .983 r
.50496 .74774 .50584 .74799 .50744 .74733 .50656 .74747 Mtetra
.135 .679 .713 r
.50656 .74747 .50744 .74733 .50904 .74666 .50815 .74719 Mtetra
.129 0 0 r
.50815 .74719 .50904 .74666 .51063 .74612 .50975 .74685 Mtetra
.205 0 0 r
.50975 .74685 .51063 .74612 .51223 .7457 .51135 .74646 Mtetra
.2 0 0 r
.51135 .74646 .51223 .7457 .51383 .74534 .51295 .74604 Mtetra
.175 0 0 r
.51295 .74604 .51383 .74534 .51543 .74495 .51455 .74562 Mtetra
.157 0 0 r
.51455 .74562 .51543 .74495 .51703 .74454 .51616 .7452 Mtetra
.15 0 0 r
.51616 .7452 .51703 .74454 .51864 .74413 .51776 .74478 Mtetra
.145 0 0 r
.51776 .74478 .51864 .74413 .52024 .74371 .51936 .74436 Mtetra
.141 0 0 r
.51936 .74436 .52024 .74371 .52184 .74329 .52097 .74393 Mtetra
.138 0 0 r
.52097 .74393 .52184 .74329 .52345 .74286 .52258 .7435 Mtetra
.136 0 0 r
.52258 .7435 .52345 .74286 .52505 .74243 .52418 .74307 Mtetra
.135 0 0 r
.52418 .74307 .52505 .74243 .52666 .742 .52579 .74264 Mtetra
.134 0 0 r
.52579 .74264 .52666 .742 .52827 .74157 .5274 .74221 Mtetra
.5274 .74221 .52827 .74157 .52988 .74113 .52901 .74178 Mtetra
.52901 .74178 .52988 .74113 .53149 .7407 .53062 .74134 Mtetra
.53062 .74134 .53149 .7407 .5331 .74026 .53223 .7409 Mtetra
.135 0 0 r
.53223 .7409 .5331 .74026 .53471 .73981 .53385 .74046 Mtetra
.136 0 0 r
.53385 .74046 .53471 .73981 .53632 .73937 .53546 .74002 Mtetra
.137 0 0 r
.53546 .74002 .53632 .73937 .53794 .73892 .53708 .73958 Mtetra
.139 0 0 r
.53708 .73958 .53794 .73892 .53955 .73847 .53869 .73914 Mtetra
.141 0 0 r
.53869 .73914 .53955 .73847 .54117 .73803 .54031 .73869 Mtetra
.144 0 0 r
.54031 .73869 .54117 .73803 .54278 .73758 .54193 .73825 Mtetra
.152 0 0 r
.54193 .73825 .54278 .73758 .5444 .73714 .54355 .73781 Mtetra
.16 0 0 r
.54355 .73781 .5444 .73714 .54602 .73671 .54516 .73739 Mtetra
.149 0 0 r
.54516 .73739 .54602 .73671 .54764 .73627 .54679 .73694 Mtetra
.193 0 0 r
.54679 .73694 .54764 .73627 .54926 .73603 .54841 .73657 Mtetra
.158 0 0 r
.54841 .73657 .54926 .73603 .55088 .73595 .55003 .73626 Mtetra
.306 .785 .699 r
.55003 .73626 .55088 .73595 .5525 .73536 .55165 .7356 Mtetra
.867 .993 .816 r
.55165 .7356 .5525 .73536 .55411 .73298 .55327 .73382 Mtetra
.991 .887 .598 r
.55327 .73382 .55411 .73298 .55562 .71873 .55485 .72898 Mtetra
.971 .706 .472 r
.55485 .72898 .55562 .71873 .55554 .5333 .55479 .53925 Mtetra
0 0 .276 r
.55479 .53925 .55554 .5333 .55705 .53029 .55628 .53303 Mtetra
.411 .107 .336 r
.55628 .53303 .55705 .53029 .55858 .52953 .55781 .5321 Mtetra
.525 .205 .367 r
.55781 .5321 .55858 .52953 .56012 .52929 .55935 .53202 Mtetra
.559 .244 .39 r
.55935 .53202 .56012 .52929 .56166 .52914 .56089 .53222 Mtetra
.53 .227 .398 r
.56089 .53222 .56166 .52914 .5632 .52872 .56244 .5321 Mtetra
.504 .211 .403 r
.56244 .5321 .5632 .52872 .56473 .52831 .56398 .53168 Mtetra
.394 .113 .365 r
.56398 .53168 .56473 .52831 .56627 .52788 .56551 .53035 Mtetra
.108 0 .188 r
.56551 .53035 .56627 .52788 .56781 .52742 .56703 .52822 Mtetra
.599 .867 .532 r
.56703 .52822 .56781 .52742 .56935 .52696 .56855 .52649 Mtetra
.805 .863 .892 r
.56855 .52649 .56935 .52696 .57089 .52652 .57008 .52536 Mtetra
.649 .676 .862 r
.57008 .52536 .57089 .52652 .57243 .52612 .57163 .52495 Mtetra
.604 .656 .875 r
.57163 .52495 .57243 .52612 .57398 .52573 .57317 .52474 Mtetra
.589 .688 .91 r
.57317 .52474 .57398 .52573 .57552 .52534 .57472 .52456 Mtetra
.628 .754 .938 r
.57472 .52456 .57552 .52534 .57707 .52494 .57627 .52421 Mtetra
.631 .768 .945 r
.57627 .52421 .57707 .52494 .57861 .52454 .57781 .52384 Mtetra
.632 .777 .95 r
.57781 .52384 .57861 .52454 .58016 .52413 .57936 .52346 Mtetra
.631 .783 .955 r
.57936 .52346 .58016 .52413 .58171 .52372 .58091 .52307 Mtetra
.631 .792 .959 r
.58091 .52307 .58171 .52372 .58326 .52329 .58246 .52268 Mtetra
.632 .801 .963 r
.58246 .52268 .58326 .52329 .5848 .52286 .58401 .52227 Mtetra
.633 .808 .967 r
.58401 .52227 .5848 .52286 .58635 .52242 .58556 .52186 Mtetra
.634 .815 .97 r
.58556 .52186 .58635 .52242 .58791 .52198 .58711 .52143 Mtetra
.634 .822 .972 r
.58711 .52143 .58791 .52198 .58946 .52153 .58867 .52099 Mtetra
.635 .827 .974 r
.58867 .52099 .58946 .52153 .59101 .52107 .59022 .52055 Mtetra
.636 .831 .975 r
.59022 .52055 .59101 .52107 .59256 .52061 .59177 .5201 Mtetra
.636 .834 .976 r
.59177 .5201 .59256 .52061 .59412 .52015 .59333 .51964 Mtetra
.637 .836 .977 r
.59333 .51964 .59412 .52015 .59567 .51968 .59488 .51918 Mtetra
.637 .838 .977 r
.59488 .51918 .59567 .51968 .59723 .51922 .59644 .51872 Mtetra
.638 .838 .977 r
.59644 .51872 .59723 .51922 .59878 .51876 .598 .51826 Mtetra
.638 .837 .977 r
.598 .51826 .59878 .51876 .60034 .5183 .59956 .51779 Mtetra
.638 .835 .976 r
.59956 .51779 .60034 .5183 .6019 .51785 .60112 .51733 Mtetra
.638 .833 .975 r
.60112 .51733 .6019 .51785 .60346 .5174 .60268 .51687 Mtetra
.638 .828 .974 r
.60268 .51687 .60346 .5174 .60502 .51696 .60424 .51641 Mtetra
.639 .823 .971 r
.60424 .51641 .60502 .51696 .60658 .51654 .6058 .51596 Mtetra
.64 .816 .968 r
.6058 .51596 .60658 .51654 .60815 .51613 .60736 .51552 Mtetra
.64 .805 .963 r
.60736 .51552 .60815 .51613 .60971 .51575 .60893 .51508 Mtetra
.646 .791 .952 r
.60893 .51508 .60971 .51575 .61128 .51537 .61049 .51464 Mtetra
.654 .776 .938 r
.61049 .51464 .61128 .51537 .61284 .51499 .61206 .51419 Mtetra
.663 .762 .923 r
.61206 .51419 .61284 .51499 .61441 .51456 .61362 .5137 Mtetra
.671 .749 .909 r
.61362 .5137 .61441 .51456 .61598 .51411 .61519 .51319 Mtetra
.678 .738 .896 r
.61519 .51319 .61598 .51411 .61755 .51362 .61676 .51265 Mtetra
.685 .729 .883 r
.61676 .51265 .61755 .51362 .61911 .51308 .61832 .51207 Mtetra
.691 .723 .874 r
.61832 .51207 .61911 .51308 .62068 .5125 .61989 .51145 Mtetra
.701 .718 .863 r
.61989 .51145 .62068 .5125 .62224 .5119 .62145 .51077 Mtetra
.729 .713 .836 r
.62145 .51077 .62224 .5119 .62381 .51128 .62301 .50989 Mtetra
.694 .663 .815 r
.62301 .50989 .62381 .51128 .62538 .51066 .62457 .50916 Mtetra
.641 .627 .821 r
.62457 .50916 .62538 .51066 .62695 .51005 .62615 .50877 Mtetra
.365 .518 .876 r
.62615 .50877 .62695 .51005 .62852 .5095 .62776 .50936 Mtetra
.601 .029 0 r
.62776 .50936 .62852 .5095 .63009 .50897 .62938 .51047 Mtetra
.696 .321 .333 r
.62938 .51047 .63009 .50897 .63166 .50844 .63102 .51194 Mtetra
.536 .243 .416 r
.63102 .51194 .63166 .50844 .63323 .50789 .63261 .51183 Mtetra
.491 .213 .419 r
.63261 .51183 .63323 .50789 .63481 .50734 .63418 .51113 Mtetra
.468 .19 .408 r
.63418 .51113 .63481 .50734 .63638 .5068 .63575 .51023 Mtetra
.532 .238 .412 r
.63575 .51023 .63638 .5068 .63796 .5063 .63734 .51008 Mtetra
.511 .227 .42 r
.63734 .51008 .63796 .5063 .63954 .50581 .63892 .50964 Mtetra
.45 .175 .404 r
.63892 .50964 .63954 .50581 .64112 .50532 .64048 .50855 Mtetra
.204 0 .295 r
.64048 .50855 .64112 .50532 .6427 .50482 .642 .50608 Mtetra
0 0 0 r
.642 .50608 .6427 .50482 .64428 .50431 .64353 .50408 Mtetra
.864 .929 .867 r
.64353 .50408 .64428 .50431 .64586 .50381 .64507 .50258 Mtetra
.674 .68 .848 r
.64507 .50258 .64586 .50381 .64744 .5033 .64665 .50202 Mtetra
.632 .654 .854 r
.64665 .50202 .64744 .5033 .64903 .50279 .64824 .50169 Mtetra
.608 .675 .888 r
.64824 .50169 .64903 .50279 .65061 .50228 .64984 .50145 Mtetra
.661 .756 .921 r
.64984 .50145 .65061 .50228 .65219 .5017 .65143 .50097 Mtetra
.67 .783 .934 r
.65143 .50097 .65219 .5017 .65378 .50116 .65301 .50045 Mtetra
.68 .793 .935 r
.65301 .50045 .65378 .50116 .65537 .50066 .6546 .49989 Mtetra
.784 .798 .864 r
.6546 .49989 .65537 .50066 .65694 .49992 .65616 .49877 Mtetra
.707 .705 .846 r
.65616 .49877 .65694 .49992 .65854 .49953 .65774 .49802 Mtetra
.575 .595 .835 r
.65774 .49802 .65854 .49953 .66016 .49983 .65935 .49797 Mtetra
.678 .324 0 r
.65935 .49797 .66016 .49983 .66198 .50476 .66114 .50221 Mtetra
.969 .686 .437 r
.66114 .50221 .66198 .50476 .67167 .69849 .67084 .69738 Mtetra
.895 .494 .072 r
.67084 .69738 .67167 .69849 .67357 .70295 .67277 .70249 Mtetra
0 .505 .853 r
.67277 .70249 .67357 .70295 .67531 .70366 .67451 .703 Mtetra
.66 .813 .957 r
.67451 .703 .67531 .70366 .67701 .70329 .6762 .70246 Mtetra
.81 .799 .841 r
.6762 .70246 .67701 .70329 .67867 .70192 .67786 .70104 Mtetra
.905 .781 .714 r
.67786 .70104 .67867 .70192 .68017 .69693 .67944 .69783 Mtetra
1 .816 .509 r
.67944 .69783 .68017 .69693 .67318 .50182 .68078 .68948 Mtetra
.057 0 .441 r
.68078 .68948 .67318 .50182 .67451 .49537 .67394 .49883 Mtetra
.127 0 .284 r
.67394 .49883 .67451 .49537 .67608 .49412 .67543 .49569 Mtetra
.034 0 .044 r
.67543 .49569 .67608 .49412 .67769 .49377 .67698 .49406 Mtetra
.533 .909 .747 r
.67698 .49406 .67769 .49377 .67931 .49384 .67855 .49304 Mtetra
.682 .771 .919 r
.67855 .49304 .67931 .49384 .68093 .49356 .68015 .49247 Mtetra
.632 .689 .885 r
.68015 .49247 .68093 .49356 .68254 .49323 .68176 .49212 Mtetra
.609 .678 .89 r
.68176 .49212 .68254 .49323 .68415 .49286 .68338 .49187 Mtetra
.662 .723 .895 r
.68338 .49187 .68415 .49286 .68575 .49235 .68499 .49139 Mtetra
.678 .734 .893 r
.68499 .49139 .68575 .49235 .68735 .49178 .68659 .49084 Mtetra
.685 .74 .893 r
.68659 .49084 .68735 .49178 .68895 .49117 .68819 .49025 Mtetra
.766 .766 .853 r
.68819 .49025 .68895 .49117 .69053 .49009 .68977 .48918 Mtetra
.723 .758 .88 r
.68977 .48918 .69053 .49009 .69213 .4893 .69137 .48839 Mtetra
.558 .7 .935 r
.69137 .48839 .69213 .4893 .69375 .48918 .693 .48828 Mtetra
.83 .392 0 r
.693 .48828 .69375 .48918 .69558 .4928 .69482 .49191 Mtetra
.97 .683 .428 r
.69482 .49191 .69558 .4928 .70733 .68736 .70653 .68654 Mtetra
.915 .518 .142 r
.70653 .68654 .70733 .68736 .70936 .69301 .70857 .69218 Mtetra
0 .385 .838 r
.70857 .69218 .70936 .69301 .71115 .69396 .71036 .69316 Mtetra
.604 .761 .954 r
.71036 .69316 .71115 .69396 .71288 .69362 .71209 .69284 Mtetra
.81 .816 .855 r
.71209 .69284 .71288 .69362 .71455 .69228 .71376 .69146 Mtetra
.942 .775 .646 r
.71376 .69146 .71455 .69228 .71607 .68805 .71524 .68658 Mtetra
.97 .688 .439 r
.71524 .68658 .71607 .68805 .70716 .49428 .70623 .49023 Mtetra
.824 .61 .613 r
.70623 .49023 .70716 .49428 .70834 .48583 .70753 .48381 Mtetra
.734 .625 .737 r
.70753 .48381 .70834 .48583 .70989 .48404 .7091 .48238 Mtetra
.625 .603 .808 r
.7091 .48238 .70989 .48404 .7115 .48339 .71072 .48205 Mtetra
.531 .599 .867 r
.71072 .48205 .7115 .48339 .71314 .48316 .71238 .48216 Mtetra
.64 .713 .9 r
.71238 .48216 .71314 .48316 .71476 .48275 .71401 .48177 Mtetra
.668 .728 .895 r
.71401 .48177 .71476 .48275 .71639 .48229 .71563 .48125 Mtetra
.633 .703 .896 r
.71563 .48125 .71639 .48229 .71801 .48186 .71726 .48089 Mtetra
.532 .676 .93 r
.71726 .48089 .71801 .48186 .71962 .48104 .71891 .48087 Mtetra
.243 0 0 r
.71891 .48087 .71962 .48104 .72123 .48037 .7206 .48138 Mtetra
.719 .3 .252 r
.7206 .48138 .72123 .48037 .72288 .48027 .72235 .48297 Mtetra
.967 .677 .426 r
.72235 .48297 .72288 .48027 .72471 .48313 .7349 .66375 Mtetra
.596 .38 .558 r
.7349 .66375 .72471 .48313 .73816 .67659 .73772 .68137 Mtetra
.689 .393 .468 r
.73772 .68137 .73816 .67659 .74037 .68383 .73967 .68435 Mtetra
.527 .003 0 r
.73967 .68435 .74037 .68383 .74219 .6848 .74147 .6849 Mtetra
.156 .696 .733 r
.74147 .6849 .74219 .6848 .74393 .68439 .74322 .68458 Mtetra
.306 .792 .735 r
.74322 .68458 .74393 .68439 .74564 .68352 .74494 .68395 Mtetra
0 0 0 r
.74494 .68395 .74564 .68352 .74737 .68289 .74668 .68343 Mtetra
.094 0 0 r
.74668 .68343 .74737 .68289 .74911 .68241 .74842 .68296 Mtetra
.74842 .68296 .74911 .68241 .75085 .68193 .75016 .68248 Mtetra
.109 0 0 r
.75016 .68248 .75085 .68193 .75259 .68146 .75191 .68202 Mtetra
.116 0 0 r
.75191 .68202 .75259 .68146 .75434 .68101 .75365 .68157 Mtetra
.103 0 0 r
.75365 .68157 .75434 .68101 .75608 .68055 .7554 .68109 Mtetra
.185 0 0 r
.7554 .68109 .75608 .68055 .75785 .68045 .75715 .68079 Mtetra
0 0 0 r
.75715 .68079 .75785 .68045 .75961 .68023 .75891 .68038 Mtetra
.468 .889 .807 r
.75891 .68038 .75961 .68023 .76134 .6794 .76063 .67955 Mtetra
.923 .975 .746 r
.76063 .67955 .76134 .6794 .76287 .67576 .76225 .67716 Mtetra
.912 .846 .395 r
.76225 .67716 .76287 .67576 .75139 .48225 .76365 .67161 Mtetra
.092 .011 .463 r
.76365 .67161 .75139 .48225 .7524 .47258 .75206 .47742 Mtetra
.054 0 .322 r
.75206 .47742 .7524 .47258 .75394 .47049 .75338 .47217 Mtetra
0 0 .05 r
.75338 .47217 .75394 .47049 .75557 .4699 .75492 .47006 Mtetra
.72 .986 .811 r
.75492 .47006 .75557 .4699 .75725 .46977 .75651 .46875 Mtetra
.718 .741 .87 r
.75651 .46875 .75725 .46977 .75891 .46953 .75813 .46797 Mtetra
.647 .627 .816 r
.75813 .46797 .75891 .46953 .76057 .46914 .75979 .46751 Mtetra
.617 .603 .814 r
.75979 .46751 .76057 .46914 .76223 .46877 .76145 .46723 Mtetra
.614 .613 .827 r
.76145 .46723 .76223 .46877 .76388 .46839 .76312 .46697 Mtetra
.618 .632 .842 r
.76312 .46697 .76388 .46839 .76554 .46798 .76479 .46669 Mtetra
.62 .652 .86 r
.76479 .46669 .76554 .46798 .7672 .46755 .76645 .46639 Mtetra
.642 .686 .876 r
.76645 .46639 .7672 .46755 .76885 .46706 .76812 .46599 Mtetra
.662 .711 .884 r
.76812 .46599 .76885 .46706 .77051 .46653 .76977 .46549 Mtetra
.67 .72 .886 r
.76977 .46549 .77051 .46653 .77216 .46598 .77142 .46495 Mtetra
.735 .745 .86 r
.77142 .46495 .77216 .46598 .77379 .46511 .77305 .46406 Mtetra
.729 .738 .859 r
.77305 .46406 .77379 .46511 .77542 .46426 .77468 .46319 Mtetra
.605 .687 .9 r
.77468 .46319 .77542 .46426 .77709 .46396 .77636 .46294 Mtetra
0 0 .426 r
.77636 .46294 .77709 .46396 .77895 .46607 .77826 .46555 Mtetra
.974 .678 .391 r
.77826 .46555 .77895 .46607 .7956 .65835 .79518 .66176 Mtetra
.818 .492 .437 r
.79518 .66176 .7956 .65835 .79814 .66781 .7975 .66847 Mtetra
.67 .189 .1 r
.7975 .66847 .79814 .66781 .80007 .66931 .79941 .66972 Mtetra
.006 0 0 r
.79941 .66972 .80007 .66931 .80185 .66894 .80119 .66924 Mtetra
.415 .84 .684 r
.80119 .66924 .80185 .66894 .80359 .66803 .80292 .66825 Mtetra
.417 .853 .738 r
.80292 .66825 .80359 .66803 .80533 .6672 .80466 .66738 Mtetra
.27 .768 .724 r
.80466 .66738 .80533 .6672 .8071 .66663 .80643 .66679 Mtetra
.267 .767 .729 r
.80643 .66679 .8071 .66663 .80887 .66605 .8082 .66622 Mtetra
.252 .756 .718 r
.8082 .66622 .80887 .66605 .81064 .66548 .80997 .66566 Mtetra
.24 .748 .71 r
.80997 .66566 .81064 .66548 .81241 .66494 .81175 .66511 Mtetra
.234 .744 .71 r
.81175 .66511 .81241 .66494 .81419 .66441 .81352 .66457 Mtetra
.229 .741 .711 r
.81352 .66457 .81419 .66441 .81596 .66388 .8153 .66404 Mtetra
.225 .739 .711 r
.8153 .66404 .81596 .66388 .81774 .66337 .81708 .66353 Mtetra
.22 .736 .712 r
.81708 .66353 .81774 .66337 .81952 .66287 .81886 .66303 Mtetra
.215 .732 .713 r
.81886 .66303 .81952 .66287 .8213 .66239 .82064 .66253 Mtetra
.209 .728 .712 r
.82064 .66253 .8213 .66239 .82309 .66191 .82243 .66206 Mtetra
.201 .723 .711 r
.82243 .66206 .82309 .66191 .82488 .66145 .82422 .66159 Mtetra
.189 .715 .707 r
.82422 .66159 .82488 .66145 .82667 .66101 .82601 .66115 Mtetra
.18 .709 .706 r
.82601 .66115 .82667 .66101 .82846 .66058 .8278 .66072 Mtetra
.182 .711 .71 r
.8278 .66072 .82846 .66058 .83025 .66016 .8296 .66029 Mtetra
0 0 0 r
.8296 .66029 .83025 .66016 .83207 .65999 .83141 .66005 Mtetra
.068 .63 .707 r
.83141 .66005 .83207 .65999 .8339 .65992 .83323 .65988 Mtetra
.428 .87 .888 r
.83323 .65988 .8339 .65992 .83568 .65927 .83502 .65931 Mtetra
.876 .993 .796 r
.83502 .65931 .83568 .65927 .83726 .6565 .83668 .65736 Mtetra
.959 .865 .458 r
.83668 .65736 .83726 .6565 .82231 .47056 .83803 .65198 Mtetra
.095 .02 .472 r
.83803 .65198 .82231 .47056 .82234 .45174 .82218 .45685 Mtetra
.121 0 .363 r
.82218 .45685 .82234 .45174 .82382 .44893 .82344 .45158 Mtetra
.432 .126 .344 r
.82344 .45158 .82382 .44893 .82548 .44819 .82509 .45072 Mtetra
.527 .201 .358 r
.82509 .45072 .82548 .44819 .82719 .44795 .82683 .45068 Mtetra
.539 .219 .374 r
.82683 .45068 .82719 .44795 .82891 .44774 .82857 .45071 Mtetra
.497 .193 .38 r
.82857 .45071 .82891 .44774 .8306 .44727 .83027 .45029 Mtetra
.499 .196 .383 r
.83027 .45029 .8306 .44727 .83229 .4468 .83197 .44987 Mtetra
.499 .197 .386 r
.83197 .44987 .83229 .4468 .83399 .44632 .83367 .44943 Mtetra
.497 .197 .388 r
.83367 .44943 .83399 .44632 .83568 .44583 .83537 .44897 Mtetra
.497 .198 .389 r
.83537 .44897 .83568 .44583 .83737 .44533 .83707 .44849 Mtetra
.496 .198 .39 r
.83707 .44849 .83737 .44533 .83907 .44483 .83876 .44801 Mtetra
.496 .198 .391 r
.83876 .44801 .83907 .44483 .84076 .44432 .84046 .44751 Mtetra
.495 .198 .391 r
.84046 .44751 .84076 .44432 .84246 .44381 .84216 .44701 Mtetra
.84216 .44701 .84246 .44381 .84415 .4433 .84386 .4465 Mtetra
.494 .198 .391 r
.84386 .4465 .84415 .4433 .84585 .44278 .84556 .44598 Mtetra
.494 .197 .391 r
.84556 .44598 .84585 .44278 .84755 .44226 .84726 .44546 Mtetra
.493 .197 .391 r
.84726 .44546 .84755 .44226 .84925 .44173 .84896 .44493 Mtetra
.493 .196 .391 r
.84896 .44493 .84925 .44173 .85095 .44121 .85067 .4444 Mtetra
.492 .195 .39 r
.85067 .4444 .85095 .44121 .85265 .44068 .85237 .44386 Mtetra
.491 .195 .39 r
.85237 .44386 .85265 .44068 .85435 .44014 .85407 .44331 Mtetra
.49 .193 .389 r
.85407 .44331 .85435 .44014 .85605 .43961 .85577 .44276 Mtetra
.489 .192 .388 r
.85577 .44276 .85605 .43961 .85775 .43907 .85748 .44221 Mtetra
.488 .191 .387 r
.85748 .44221 .85775 .43907 .85945 .43852 .85918 .44164 Mtetra
.487 .19 .386 r
.85918 .44164 .85945 .43852 .86116 .43798 .86088 .44108 Mtetra
.486 .188 .385 r
.86088 .44108 .86116 .43798 .86286 .43743 .86259 .44051 Mtetra
.485 .187 .383 r
.86259 .44051 .86286 .43743 .86457 .43688 .86429 .43993 Mtetra
.485 .185 .382 r
.86429 .43993 .86457 .43688 .86627 .43634 .866 .43936 Mtetra
.484 .183 .38 r
.866 .43936 .86627 .43634 .86798 .43579 .86771 .43878 Mtetra
.482 .181 .378 r
.86771 .43878 .86798 .43579 .86969 .43525 .86942 .4382 Mtetra
.481 .179 .376 r
.86942 .4382 .86969 .43525 .8714 .4347 .87112 .43762 Mtetra
.48 .176 .373 r
.87112 .43762 .8714 .4347 .87311 .43416 .87283 .43704 Mtetra
.479 .175 .371 r
.87283 .43704 .87311 .43416 .87482 .43362 .87455 .43647 Mtetra
.48 .174 .369 r
.87455 .43647 .87482 .43362 .87653 .43309 .87626 .43591 Mtetra
.48 .173 .368 r
.87626 .43591 .87653 .43309 .87825 .43255 .87797 .43536 Mtetra
.481 .173 .367 r
.87797 .43536 .87825 .43255 .87997 .43203 .87969 .43482 Mtetra
.482 .174 .366 r
.87969 .43482 .87997 .43203 .88168 .43151 .88141 .4343 Mtetra
.484 .175 .366 r
.88141 .4343 .88168 .43151 .8834 .43099 .88314 .4338 Mtetra
.487 .178 .368 r
.88314 .4338 .8834 .43099 .88513 .43049 .88487 .43332 Mtetra
.491 .182 .37 r
.88487 .43332 .88513 .43049 .88685 .43 .8866 .43286 Mtetra
.495 .187 .373 r
.8866 .43286 .88685 .43 .88858 .42951 .88833 .43244 Mtetra
.506 .198 .378 r
.88833 .43244 .88858 .42951 .89031 .42905 .89008 .43211 Mtetra
.534 .225 .39 r
.89008 .43211 .89031 .42905 .89204 .42861 .89186 .43204 Mtetra
.518 .223 .406 r
.89186 .43204 .89204 .42861 .89378 .42818 .89361 .43172 Mtetra
.454 .176 .4 r
.89361 .43172 .89378 .42818 .89551 .42775 .89528 .43066 Mtetra
.282 .022 .33 r
.89528 .43066 .89551 .42775 .89725 .42731 .89683 .42852 Mtetra
0 0 0 r
.89683 .42852 .89725 .42731 .89899 .42686 .89841 .42669 Mtetra
.808 .986 .887 r
.89841 .42669 .89899 .42686 .90073 .4264 .90004 .42534 Mtetra
.677 .728 .889 r
.90004 .42534 .90073 .4264 .90246 .42595 .90177 .42475 Mtetra
.64 .685 .876 r
.90177 .42475 .90246 .42595 .9042 .42547 .90351 .42433 Mtetra
.634 .693 .888 r
.90351 .42433 .9042 .42547 .90593 .42495 .90526 .42394 Mtetra
.676 .741 .899 r
.90526 .42394 .90593 .42495 .90766 .42434 .90699 .42335 Mtetra
.683 .748 .9 r
.90699 .42335 .90766 .42434 .90938 .4237 .90871 .42273 Mtetra
.703 .76 .896 r
.90871 .42273 .90938 .4237 .91109 .42297 .91043 .42201 Mtetra
.768 .785 .866 r
.91043 .42201 .91109 .42297 .91276 .42187 .9121 .42092 Mtetra
.696 .76 .902 r
.9121 .42092 .91276 .42187 .91448 .42119 .91382 .42023 Mtetra
.427 .63 .939 r
.91382 .42023 .91448 .42119 .91631 .42145 .91565 .4205 Mtetra
.789 .371 0 r
.91565 .4205 .91631 .42145 .91872 .42646 .91807 .42556 Mtetra
.973 .661 .312 r
.91807 .42556 .91872 .42646 .94472 .62509 .94404 .62423 Mtetra
.744 .301 0 r
.94404 .62423 .94472 .62509 .94717 .62943 .94648 .62853 Mtetra
.492 .695 .959 r
.94648 .62853 .94717 .62943 .9491 .62946 .94841 .62856 Mtetra
.692 .785 .922 r
.94841 .62856 .9491 .62946 .95094 .62876 .95025 .62785 Mtetra
.742 .801 .899 r
.95025 .62785 .95094 .62876 .95275 .62779 .95206 .62688 Mtetra
.491 .691 .957 r
.95206 .62688 .95275 .62779 .95468 .62783 .95399 .62691 Mtetra
.619 .752 .941 r
.95399 .62691 .95468 .62783 .95656 .62744 .95588 .62652 Mtetra
.799 .814 .864 r
.95588 .62652 .95656 .62744 .95833 .6261 .95764 .62517 Mtetra
.98 .776 .557 r
.95764 .62517 .95833 .6261 .9594 .6193 .95872 .61838 Mtetra
.975 .669 .322 r
.95872 .61838 .9594 .6193 .936 .41954 .93535 .41855 Mtetra
.963 .783 .613 r
.93535 .41855 .936 .41954 .9372 .41464 .93654 .41365 Mtetra
.755 .776 .87 r
.93654 .41365 .9372 .41464 .93889 .41361 .93823 .41262 Mtetra
.626 .725 .918 r
.93823 .41262 .93889 .41361 .94066 .41324 .94001 .41225 Mtetra
.544 .685 .931 r
.94001 .41225 .94066 .41324 .94248 .41317 .94182 .41218 Mtetra
.747 .773 .874 r
.94182 .41218 .94248 .41317 .94417 .41219 .94352 .4112 Mtetra
.681 .748 .902 r
.94352 .4112 .94417 .41219 .94592 .41157 .94527 .41058 Mtetra
.489 .655 .934 r
.94527 .41058 .94592 .41157 .94776 .41169 .94711 .41069 Mtetra
.738 .32 0 r
.94711 .41069 .94776 .41169 .95022 .41647 .94956 .41548 Mtetra
.97 .655 .291 r
.94956 .41548 .95022 .41647 .97836 .61594 .97768 .615 Mtetra
.738 .308 0 r
.97768 .615 .97836 .61594 .98093 .62069 .98026 .61976 Mtetra
.031 .462 .877 r
.37164 .78207 .37256 .78282 .37404 .78345 .37311 .78269 Mtetra
.642 .761 .935 r
.37311 .78269 .37404 .78345 .37556 .78305 .37463 .7823 Mtetra
.809 .779 .825 r
.37463 .7823 .37556 .78305 .37712 .78164 .3762 .78089 Mtetra
.908 .738 .659 r
.3762 .78089 .37712 .78164 .37884 .77647 .37792 .77571 Mtetra
.937 .686 .534 r
.37792 .77571 .37884 .77647 .38797 .58666 .3871 .58584 Mtetra
.908 .726 .644 r
.3871 .58584 .38797 .58666 .38962 .58094 .38876 .58012 Mtetra
.774 .758 .838 r
.38876 .58012 .38962 .58094 .39109 .57988 .39022 .57905 Mtetra
.631 .728 .918 r
.39022 .57905 .39109 .57988 .39253 .57957 .39166 .57873 Mtetra
.493 .676 .946 r
.39166 .57873 .39253 .57957 .39396 .57963 .39309 .57877 Mtetra
.714 .743 .875 r
.39309 .57877 .39396 .57963 .3954 .5791 .39455 .5781 Mtetra
.678 .705 .868 r
.39455 .5781 .3954 .5791 .39685 .57862 .39599 .57758 Mtetra
.574 .662 .897 r
.39599 .57758 .39685 .57862 .39829 .57833 .39743 .57748 Mtetra
.635 .132 0 r
.39743 .57748 .39829 .57833 .39972 .57842 .3988 .57909 Mtetra
.874 .548 .43 r
.3988 .57909 .39972 .57842 .40113 .57908 .40005 .58413 Mtetra
.93 .674 .528 r
.40005 .58413 .40113 .57908 .4025 .58097 .39479 .76897 Mtetra
.576 .366 .558 r
.39479 .76897 .4025 .58097 .39732 .76718 .39616 .77311 Mtetra
.629 .362 .495 r
.39616 .77311 .39732 .76718 .39859 .77398 .39763 .77466 Mtetra
.55 .077 .084 r
.39763 .77466 .39859 .77398 .40005 .77577 .39913 .77509 Mtetra
.817 .795 .832 r
.39913 .77509 .40005 .77577 .40165 .77347 .4007 .77366 Mtetra
.941 .904 .758 r
.4007 .77366 .40165 .77347 .40341 .7664 .40232 .77103 Mtetra
0 0 .199 r
.40232 .77103 .40341 .7664 .41122 .57849 .40399 .76663 Mtetra
.566 .357 .556 r
.40399 .76663 .41122 .57849 .41273 .57643 .40559 .76432 Mtetra
.569 .36 .557 r
.40559 .76432 .41273 .57643 .41418 .57598 .40712 .76398 Mtetra
.571 .361 .557 r
.40712 .76398 .41418 .57598 .41562 .57613 .40863 .7645 Mtetra
.40863 .7645 .41562 .57613 .41707 .57609 .41013 .76533 Mtetra
.57 .36 .557 r
.41013 .76533 .41707 .57609 .41852 .57583 .41165 .76535 Mtetra
.567 .358 .557 r
.41165 .76535 .41852 .57583 .41999 .57512 .41323 .76383 Mtetra
0 0 .353 r
.41323 .76383 .41999 .57512 .4215 .57315 .42042 .57956 Mtetra
0 0 .136 r
.42042 .57956 .4215 .57315 .423 .57128 .4221 .57201 Mtetra
.963 .941 .683 r
.4221 .57201 .423 .57128 .42449 .56979 .42364 .56896 Mtetra
.772 .759 .841 r
.42364 .56896 .42449 .56979 .42596 .56905 .42512 .5679 Mtetra
.658 .673 .853 r
.42512 .5679 .42596 .56905 .42743 .56862 .42658 .56746 Mtetra
.597 .65 .873 r
.42658 .56746 .42743 .56862 .42889 .56832 .42804 .56729 Mtetra
.611 .68 .891 r
.42804 .56729 .42889 .56832 .43035 .56802 .42949 .56706 Mtetra
.614 .697 .903 r
.42949 .56706 .43035 .56802 .43181 .5677 .43095 .56681 Mtetra
.621 .713 .911 r
.43095 .56681 .43181 .5677 .43327 .56736 .43242 .56652 Mtetra
.674 .742 .902 r
.43242 .56652 .43327 .56736 .43474 .56684 .43389 .56603 Mtetra
.696 .754 .897 r
.43389 .56603 .43474 .56684 .43621 .56624 .43536 .56544 Mtetra
.699 .757 .897 r
.43536 .56544 .43621 .56624 .43768 .56564 .43683 .56484 Mtetra
.712 .759 .889 r
.43683 .56484 .43768 .56564 .43916 .56487 .4383 .56418 Mtetra
.689 .78 .92 r
.4383 .56418 .43916 .56487 .44063 .56427 .43978 .56362 Mtetra
.606 .774 .96 r
.43978 .56362 .44063 .56427 .4421 .5641 .44124 .56333 Mtetra
.274 .591 .948 r
.44124 .56333 .4421 .5641 .44352 .56563 .4427 .5637 Mtetra
.242 .346 .77 r
.4427 .5637 .44352 .56563 .44485 .57112 .44413 .56492 Mtetra
.346 .255 .608 r
.44413 .56492 .44485 .57112 .44198 .75863 .44552 .56801 Mtetra
0 0 .374 r
.44552 .56801 .44198 .75863 .44345 .76184 .44273 .75352 Mtetra
.124 .076 .527 r
.44273 .75352 .44345 .76184 .44498 .76291 .44413 .76008 Mtetra
.117 .197 .672 r
.44413 .76008 .44498 .76291 .44652 .7633 .44563 .76233 Mtetra
.287 .557 .927 r
.44563 .76233 .44652 .7633 .44808 .7633 .44717 .76282 Mtetra
.531 .807 .997 r
.44717 .76282 .44808 .7633 .44964 .76305 .44873 .76259 Mtetra
.659 .849 .973 r
.44873 .76259 .44964 .76305 .4512 .76263 .4503 .76205 Mtetra
.633 .811 .968 r
.4503 .76205 .4512 .76263 .45277 .76238 .45187 .76163 Mtetra
.661 .771 .931 r
.45187 .76163 .45277 .76238 .45433 .76202 .45344 .76115 Mtetra
.716 .757 .885 r
.45344 .76115 .45433 .76202 .45591 .76122 .45501 .76042 Mtetra
.797 .778 .836 r
.45501 .76042 .45591 .76122 .45751 .75885 .4566 .75911 Mtetra
.915 .964 .796 r
.4566 .75911 .45751 .75885 .45918 .7532 .4582 .75702 Mtetra
0 0 .194 r
.4582 .75702 .45918 .7532 .46413 .56434 .45983 .75341 Mtetra
0 0 .376 r
.45983 .75341 .46413 .56434 .46569 .55963 .46465 .5695 Mtetra
0 0 .267 r
.46465 .5695 .46569 .55963 .4672 .55766 .46632 .55902 Mtetra
.841 .91 .506 r
.46632 .55902 .4672 .55766 .4687 .55646 .46785 .55589 Mtetra
.807 .823 .863 r
.46785 .55589 .4687 .55646 .47018 .5558 .46935 .5547 Mtetra
.637 .677 .871 r
.46935 .5547 .47018 .5558 .47167 .55548 .47083 .55436 Mtetra
.557 .642 .891 r
.47083 .55436 .47167 .55548 .47315 .5553 .47231 .55433 Mtetra
.602 .691 .905 r
.47231 .55433 .47315 .5553 .47464 .55499 .4738 .55411 Mtetra
.653 .729 .905 r
.4738 .55411 .47464 .55499 .47613 .55455 .47529 .5537 Mtetra
.667 .74 .905 r
.47529 .5537 .47613 .55455 .47762 .55405 .47678 .55323 Mtetra
.689 .753 .9 r
.47678 .55323 .47762 .55405 .47911 .55347 .47827 .55267 Mtetra
.701 .76 .897 r
.47827 .55267 .47911 .55347 .48061 .55284 .47977 .55205 Mtetra
.701 .762 .899 r
.47977 .55205 .48061 .55284 .4821 .55223 .48126 .55143 Mtetra
.712 .764 .893 r
.48126 .55143 .4821 .55223 .4836 .55147 .48276 .55076 Mtetra
.699 .783 .917 r
.48276 .55076 .4836 .55147 .48509 .55079 .48426 .55016 Mtetra
.626 .787 .959 r
.48426 .55016 .48509 .55079 .48659 .55052 .48575 .5498 Mtetra
.215 .572 .94 r
.48575 .5498 .48659 .55052 .48806 .55176 .48724 .55022 Mtetra
.031 .263 .762 r
.48724 .55022 .48806 .55176 .4895 .5567 .48871 .55163 Mtetra
.352 .277 .631 r
.48871 .55163 .4895 .5567 .48911 .74497 .49018 .55417 Mtetra
.568 .362 .562 r
.49018 .55417 .48911 .74497 .49067 .74768 .49167 .55553 Mtetra
.572 .366 .562 r
.49167 .55553 .49067 .74768 .49225 .7473 .49317 .55449 Mtetra
.571 .365 .562 r
.49317 .55449 .49225 .7473 .49384 .74647 .49468 .5541 Mtetra
.027 0 .415 r
.49468 .5541 .49384 .74647 .49543 .74693 .49467 .73096 Mtetra
.083 .018 .478 r
.49467 .73096 .49543 .74693 .497 .74812 .49614 .74473 Mtetra
.051 .123 .62 r
.49614 .74473 .497 .74812 .49859 .74893 .49771 .74777 Mtetra
.198 .462 .882 r
.49771 .74777 .49859 .74893 .50017 .74905 .49929 .74856 Mtetra
.568 .822 .993 r
.49929 .74856 .50017 .74905 .50177 .74866 .50089 .74824 Mtetra
.676 .869 .972 r
.50089 .74824 .50177 .74866 .50336 .74815 .50248 .74763 Mtetra
.643 .833 .974 r
.50248 .74763 .50336 .74815 .50496 .74774 .50408 .74714 Mtetra
.574 .792 .982 r
.50408 .74714 .50496 .74774 .50656 .74747 .50568 .74687 Mtetra
.576 .793 .981 r
.50568 .74687 .50656 .74747 .50815 .74719 .50727 .74659 Mtetra
.601 .8 .976 r
.50727 .74659 .50815 .74719 .50975 .74685 .50887 .74624 Mtetra
.624 .805 .969 r
.50887 .74624 .50975 .74685 .51135 .74646 .51047 .74584 Mtetra
.633 .805 .965 r
.51047 .74584 .51135 .74646 .51295 .74604 .51207 .74541 Mtetra
.634 .803 .964 r
.51207 .74541 .51295 .74604 .51455 .74562 .51368 .74499 Mtetra
.632 .801 .964 r
.51368 .74499 .51455 .74562 .51616 .7452 .51528 .74457 Mtetra
.634 .8 .963 r
.51528 .74457 .51616 .7452 .51776 .74478 .51688 .74414 Mtetra
.634 .8 .962 r
.51688 .74414 .51776 .74478 .51936 .74436 .51849 .74372 Mtetra
.635 .8 .962 r
.51849 .74372 .51936 .74436 .52097 .74393 .5201 .74329 Mtetra
.636 .799 .961 r
.5201 .74329 .52097 .74393 .52258 .7435 .5217 .74286 Mtetra
.5217 .74286 .52258 .7435 .52418 .74307 .52331 .74243 Mtetra
.52331 .74243 .52418 .74307 .52579 .74264 .52492 .742 Mtetra
.637 .8 .961 r
.52492 .742 .52579 .74264 .5274 .74221 .52653 .74156 Mtetra
.52653 .74156 .5274 .74221 .52901 .74178 .52814 .74113 Mtetra
.52814 .74113 .52901 .74178 .53062 .74134 .52975 .74069 Mtetra
.638 .8 .961 r
.52975 .74069 .53062 .74134 .53223 .7409 .53137 .74026 Mtetra
.53137 .74026 .53223 .7409 .53385 .74046 .53298 .73982 Mtetra
.638 .801 .961 r
.53298 .73982 .53385 .74046 .53546 .74002 .53459 .73938 Mtetra
.639 .801 .961 r
.53459 .73938 .53546 .74002 .53708 .73958 .53621 .73894 Mtetra
.53621 .73894 .53708 .73958 .53869 .73914 .53783 .73849 Mtetra
.64 .801 .96 r
.53783 .73849 .53869 .73914 .54031 .73869 .53944 .73805 Mtetra
.53944 .73805 .54031 .73869 .54193 .73825 .54106 .7376 Mtetra
.638 .8 .961 r
.54106 .7376 .54193 .73825 .54355 .73781 .54268 .73716 Mtetra
.636 .799 .961 r
.54268 .73716 .54355 .73781 .54516 .73739 .5443 .73673 Mtetra
.644 .799 .957 r
.5443 .73673 .54516 .73739 .54679 .73694 .54592 .73627 Mtetra
.642 .796 .957 r
.54592 .73627 .54679 .73694 .54841 .73657 .54755 .73582 Mtetra
.65 .778 .942 r
.54755 .73582 .54841 .73657 .55003 .73626 .54917 .73537 Mtetra
.698 .756 .896 r
.54917 .73537 .55003 .73626 .55165 .7356 .55079 .73471 Mtetra
.784 .772 .842 r
.55079 .73471 .55165 .7356 .55327 .73382 .55241 .73348 Mtetra
.907 .862 .785 r
.55241 .73348 .55327 .73382 .55485 .72898 .55402 .73119 Mtetra
0 0 0 r
.55402 .73119 .55485 .72898 .55479 .53925 .55562 .72793 Mtetra
.564 .356 .556 r
.55562 .72793 .55479 .53925 .55628 .53303 .55722 .7243 Mtetra
.568 .359 .557 r
.55722 .7243 .55628 .53303 .55781 .5321 .55884 .72328 Mtetra
.57 .36 .557 r
.55884 .72328 .55781 .5321 .55935 .53202 .56047 .72351 Mtetra
.571 .361 .557 r
.56047 .72351 .55935 .53202 .56089 .53222 .56211 .7242 Mtetra
.56211 .7242 .56089 .53222 .56244 .5321 .56375 .72468 Mtetra
.569 .36 .557 r
.56375 .72468 .56244 .5321 .56398 .53168 .56537 .72413 Mtetra
.563 .355 .556 r
.56537 .72413 .56398 .53168 .56551 .53035 .56696 .71958 Mtetra
.008 0 .409 r
.56696 .71958 .56551 .53035 .56703 .52822 .56627 .53117 Mtetra
0 0 0 r
.56627 .53117 .56703 .52822 .56855 .52649 .56775 .5264 Mtetra
.92 .916 .796 r
.56775 .5264 .56855 .52649 .57008 .52536 .56928 .52432 Mtetra
.671 .708 .876 r
.56928 .52432 .57008 .52536 .57163 .52495 .57082 .52381 Mtetra
.576 .652 .887 r
.57082 .52381 .57163 .52495 .57317 .52474 .57237 .5237 Mtetra
.543 .658 .911 r
.57237 .5237 .57317 .52474 .57472 .52456 .57392 .52369 Mtetra
.624 .727 .921 r
.57392 .52369 .57472 .52456 .57627 .52421 .57546 .52337 Mtetra
.627 .736 .925 r
.57546 .52337 .57627 .52421 .57781 .52384 .57701 .52303 Mtetra
.629 .745 .931 r
.57701 .52303 .57781 .52384 .57936 .52346 .57856 .52268 Mtetra
.628 .753 .938 r
.57856 .52268 .57936 .52346 .58091 .52307 .58011 .52233 Mtetra
.629 .763 .943 r
.58011 .52233 .58091 .52307 .58246 .52268 .58166 .52197 Mtetra
.63 .772 .949 r
.58166 .52197 .58246 .52268 .58401 .52227 .58321 .52159 Mtetra
.631 .782 .954 r
.58321 .52159 .58401 .52227 .58556 .52186 .58477 .52121 Mtetra
.633 .791 .958 r
.58477 .52121 .58556 .52186 .58711 .52143 .58632 .52081 Mtetra
.634 .799 .962 r
.58632 .52081 .58711 .52143 .58867 .52099 .58787 .5204 Mtetra
.636 .807 .965 r
.58787 .5204 .58867 .52099 .59022 .52055 .58943 .51997 Mtetra
.638 .813 .967 r
.58943 .51997 .59022 .52055 .59177 .5201 .59098 .51954 Mtetra
.64 .819 .969 r
.59098 .51954 .59177 .5201 .59333 .51964 .59254 .51909 Mtetra
.643 .822 .969 r
.59254 .51909 .59333 .51964 .59488 .51918 .59409 .51863 Mtetra
.646 .823 .968 r
.59409 .51863 .59488 .51918 .59644 .51872 .59565 .51816 Mtetra
.648 .823 .967 r
.59565 .51816 .59644 .51872 .598 .51826 .59721 .51769 Mtetra
.65 .821 .965 r
.59721 .51769 .598 .51826 .59956 .51779 .59877 .51721 Mtetra
.652 .818 .963 r
.59877 .51721 .59956 .51779 .60112 .51733 .60033 .51673 Mtetra
.654 .813 .96 r
.60033 .51673 .60112 .51733 .60268 .51687 .60189 .51625 Mtetra
.656 .807 .956 r
.60189 .51625 .60268 .51687 .60424 .51641 .60345 .51577 Mtetra
.658 .8 .951 r
.60345 .51577 .60424 .51641 .6058 .51596 .60501 .51528 Mtetra
.66 .792 .945 r
.60501 .51528 .6058 .51596 .60736 .51552 .60657 .5148 Mtetra
.661 .782 .938 r
.60657 .5148 .60736 .51552 .60893 .51508 .60814 .51431 Mtetra
.666 .77 .928 r
.60814 .51431 .60893 .51508 .61049 .51464 .6097 .51382 Mtetra
.671 .758 .916 r
.6097 .51382 .61049 .51464 .61206 .51419 .61127 .51331 Mtetra
.677 .747 .904 r
.61127 .51331 .61206 .51419 .61362 .5137 .61283 .51277 Mtetra
.682 .736 .892 r
.61283 .51277 .61362 .5137 .61519 .51319 .6144 .51221 Mtetra
.686 .726 .881 r
.6144 .51221 .61519 .51319 .61676 .51265 .61596 .51162 Mtetra
.69 .719 .871 r
.61596 .51162 .61676 .51265 .61832 .51207 .61753 .51101 Mtetra
.693 .714 .864 r
.61753 .51101 .61832 .51207 .61989 .51145 .61909 .51037 Mtetra
.705 .713 .855 r
.61909 .51037 .61989 .51145 .62145 .51077 .62066 .50966 Mtetra
.75 .721 .826 r
.62066 .50966 .62145 .51077 .62301 .50989 .62221 .50862 Mtetra
.7 .681 .828 r
.62221 .50862 .62301 .50989 .62457 .50916 .62378 .50788 Mtetra
.581 .63 .865 r
.62378 .50788 .62457 .50916 .62615 .50877 .62536 .50778 Mtetra
.621 .158 0 r
.62536 .50778 .62615 .50877 .62776 .50936 .62702 .51005 Mtetra
.919 .588 .398 r
.62702 .51005 .62776 .50936 .62938 .51047 .62889 .51891 Mtetra
.95 .671 .472 r
.62889 .51891 .62938 .51047 .63102 .51194 .63636 .70497 Mtetra
.571 .361 .557 r
.63636 .70497 .63102 .51194 .63261 .51183 .63807 .70554 Mtetra
.569 .359 .557 r
.63807 .70554 .63261 .51183 .63418 .51113 .63973 .70484 Mtetra
.568 .359 .557 r
.63973 .70484 .63418 .51113 .63575 .51023 .64138 .70356 Mtetra
.57 .361 .557 r
.64138 .70356 .63575 .51023 .63734 .51008 .64309 .70395 Mtetra
.569 .36 .557 r
.64309 .70395 .63734 .51008 .63892 .50964 .64477 .70358 Mtetra
.567 .358 .557 r
.64477 .70358 .63892 .50964 .64048 .50855 .64639 .70158 Mtetra
.063 0 .439 r
.64639 .70158 .64048 .50855 .642 .50608 .64144 .51164 Mtetra
0 0 .228 r
.64144 .51164 .642 .50608 .64353 .50408 .6428 .5045 Mtetra
.957 .949 .673 r
.6428 .5045 .64353 .50408 .64507 .50258 .64429 .50158 Mtetra
.711 .733 .868 r
.64429 .50158 .64507 .50258 .64665 .50202 .64587 .50085 Mtetra
.618 .667 .875 r
.64587 .50085 .64665 .50202 .64824 .50169 .64746 .50058 Mtetra
.556 .652 .899 r
.64746 .50058 .64824 .50169 .64984 .50145 .64906 .50053 Mtetra
.654 .734 .908 r
.64906 .50053 .64984 .50145 .65143 .50097 .65065 .50009 Mtetra
.665 .745 .91 r
.65065 .50009 .65143 .50097 .65301 .50045 .65224 .49959 Mtetra
.677 .755 .91 r
.65224 .49959 .65301 .50045 .6546 .49989 .65383 .49905 Mtetra
.782 .784 .855 r
.65383 .49905 .6546 .49989 .65616 .49877 .65539 .49792 Mtetra
.721 .769 .89 r
.65539 .49792 .65616 .49877 .65774 .49802 .65697 .49716 Mtetra
.531 .698 .946 r
.65697 .49716 .65774 .49802 .65935 .49797 .65858 .49711 Mtetra
.894 .481 .079 r
.65858 .49711 .65935 .49797 .66114 .50221 .66037 .50151 Mtetra
.967 .684 .442 r
.66037 .50151 .66114 .50221 .67084 .69738 .67005 .69689 Mtetra
.912 .508 .184 r
.67005 .69689 .67084 .69738 .67277 .70249 .67196 .70182 Mtetra
.271 .633 .963 r
.67196 .70182 .67277 .70249 .67451 .703 .67369 .70214 Mtetra
.687 .771 .915 r
.67369 .70214 .67451 .703 .6762 .70246 .67538 .70152 Mtetra
.788 .776 .842 r
.67538 .70152 .6762 .70246 .67786 .70104 .67705 .70023 Mtetra
.821 .805 .836 r
.67705 .70023 .67786 .70104 .67944 .69783 .6787 .69872 Mtetra
.65 .864 .487 r
.6787 .69872 .67944 .69783 .68078 .68948 .68032 .69648 Mtetra
.337 .124 .435 r
.68032 .69648 .68078 .68948 .67394 .49883 .68187 .69256 Mtetra
.087 .001 .452 r
.68187 .69256 .67394 .49883 .67543 .49569 .67505 .50339 Mtetra
.028 0 .349 r
.67505 .50339 .67543 .49569 .67698 .49406 .67631 .49524 Mtetra
.704 .829 .384 r
.67631 .49524 .67698 .49406 .67855 .49304 .6778 .49229 Mtetra
.756 .803 .89 r
.6778 .49229 .67855 .49304 .68015 .49247 .67938 .49136 Mtetra
.635 .687 .882 r
.67938 .49136 .68015 .49247 .68176 .49212 .68099 .491 Mtetra
.574 .658 .894 r
.68099 .491 .68176 .49212 .68338 .49187 .68261 .49089 Mtetra
.656 .721 .897 r
.68261 .49089 .68338 .49187 .68499 .49139 .68422 .49043 Mtetra
.675 .733 .894 r
.68422 .49043 .68499 .49139 .68659 .49084 .68583 .48989 Mtetra
.681 .739 .894 r
.68583 .48989 .68659 .49084 .68819 .49025 .68743 .48932 Mtetra
.765 .766 .854 r
.68743 .48932 .68819 .49025 .68977 .48918 .68901 .48826 Mtetra
.722 .758 .881 r
.68901 .48826 .68977 .48918 .69137 .48839 .69061 .48748 Mtetra
.557 .699 .935 r
.69061 .48748 .69137 .48839 .693 .48828 .69224 .48737 Mtetra
.831 .393 0 r
.69224 .48737 .693 .48828 .69482 .49191 .69406 .49101 Mtetra
.97 .683 .428 r
.69406 .49101 .69482 .49191 .70653 .68654 .70574 .68572 Mtetra
.914 .517 .14 r
.70574 .68572 .70653 .68654 .70857 .69218 .70777 .69134 Mtetra
0 .384 .838 r
.70777 .69134 .70857 .69218 .71036 .69316 .70956 .69233 Mtetra
.605 .752 .948 r
.70956 .69233 .71036 .69316 .71209 .69284 .71129 .69201 Mtetra
.805 .805 .851 r
.71129 .69201 .71209 .69284 .71376 .69146 .71296 .69064 Mtetra
.942 .775 .646 r
.71296 .69064 .71376 .69146 .71524 .68658 .71445 .68577 Mtetra
.971 .689 .438 r
.71445 .68577 .71524 .68658 .70623 .49023 .70548 .48933 Mtetra
.95 .751 .599 r
.70548 .48933 .70623 .49023 .70753 .48381 .70677 .48289 Mtetra
.81 .777 .822 r
.70677 .48289 .70753 .48381 .7091 .48238 .70834 .48145 Mtetra
.62 .723 .92 r
.70834 .48145 .7091 .48238 .71072 .48205 .70997 .48113 Mtetra
.475 .66 .942 r
.70997 .48113 .71072 .48205 .71238 .48216 .71163 .48125 Mtetra
.669 .744 .907 r
.71163 .48125 .71238 .48216 .71401 .48177 .71325 .48073 Mtetra
.681 .721 .879 r
.71325 .48073 .71401 .48177 .71563 .48125 .71487 .48014 Mtetra
.601 .675 .893 r
.71487 .48014 .71563 .48125 .71726 .48089 .71651 .47992 Mtetra
0 .293 .788 r
.71651 .47992 .71726 .48089 .71891 .48087 .71824 .48118 Mtetra
.88 .475 .251 r
.71824 .48118 .71891 .48087 .7206 .48138 .72014 .48526 Mtetra
.966 .675 .43 r
.72014 .48526 .7206 .48138 .72235 .48297 .73316 .67614 Mtetra
.577 .366 .557 r
.73316 .67614 .72235 .48297 .7349 .66375 .73521 .68113 Mtetra
.595 .361 .532 r
.73521 .68113 .7349 .66375 .73772 .68137 .73709 .68295 Mtetra
.62 .231 .284 r
.73709 .68295 .73772 .68137 .73967 .68435 .7389 .6838 Mtetra
.349 .715 .986 r
.7389 .6838 .73967 .68435 .74147 .6849 .74067 .68389 Mtetra
.608 .714 .92 r
.74067 .68389 .74147 .6849 .74322 .68458 .74242 .6836 Mtetra
.652 .736 .911 r
.74242 .6836 .74322 .68458 .74494 .68395 .74416 .68312 Mtetra
.643 .769 .939 r
.74416 .68312 .74494 .68395 .74668 .68343 .7459 .68266 Mtetra
.639 .783 .951 r
.7459 .68266 .74668 .68343 .74842 .68296 .74765 .6822 Mtetra
.644 .788 .951 r
.74765 .6822 .74842 .68296 .75016 .68248 .74939 .68172 Mtetra
.636 .786 .954 r
.74939 .68172 .75016 .68248 .75191 .68202 .75113 .68127 Mtetra
.636 .787 .954 r
.75113 .68127 .75191 .68202 .75365 .68157 .75288 .68081 Mtetra
.644 .789 .952 r
.75288 .68081 .75365 .68157 .7554 .68109 .75462 .68033 Mtetra
.632 .783 .954 r
.75462 .68033 .7554 .68109 .75715 .68079 .75637 .67989 Mtetra
.659 .761 .925 r
.75637 .67989 .75715 .68079 .75891 .68038 .75812 .67938 Mtetra
.708 .753 .887 r
.75812 .67938 .75891 .68038 .76063 .67955 .75985 .67862 Mtetra
.796 .788 .846 r
.75985 .67862 .76063 .67955 .76225 .67716 .76154 .67727 Mtetra
.902 .985 .774 r
.76154 .67727 .76225 .67716 .76365 .67161 .76318 .67513 Mtetra
.085 0 .273 r
.76318 .67513 .76365 .67161 .75206 .47742 .76471 .6715 Mtetra
.134 .041 .476 r
.76471 .6715 .75206 .47742 .75338 .47217 .75357 .48458 Mtetra
.073 0 .409 r
.75357 .48458 .75338 .47217 .75492 .47006 .75435 .47146 Mtetra
0 0 0 r
.75435 .47146 .75492 .47006 .75651 .46875 .75579 .46808 Mtetra
.829 .839 .855 r
.75579 .46808 .75651 .46875 .75813 .46797 .75738 .46668 Mtetra
.664 .673 .848 r
.75738 .46668 .75813 .46797 .75979 .46751 .75902 .46615 Mtetra
.599 .633 .856 r
.75902 .46615 .75979 .46751 .76145 .46723 .7607 .46596 Mtetra
.598 .647 .87 r
.7607 .46596 .76145 .46723 .76312 .46697 .76237 .46577 Mtetra
.61 .664 .878 r
.76237 .46577 .76312 .46697 .76479 .46669 .76404 .46552 Mtetra
.609 .669 .883 r
.76404 .46552 .76479 .46669 .76645 .46639 .76571 .46526 Mtetra
.634 .688 .883 r
.76571 .46526 .76645 .46639 .76812 .46599 .76737 .4649 Mtetra
.657 .704 .882 r
.76737 .4649 .76812 .46599 .76977 .46549 .76903 .46442 Mtetra
.665 .713 .884 r
.76903 .46442 .76977 .46549 .77142 .46495 .77069 .46391 Mtetra
.731 .741 .859 r
.77069 .46391 .77142 .46495 .77305 .46406 .77232 .46303 Mtetra
.729 .743 .864 r
.77232 .46303 .77305 .46406 .77468 .46319 .77395 .46217 Mtetra
.6 .697 .911 r
.77395 .46217 .77468 .46319 .77636 .46294 .77563 .46193 Mtetra
.577 .134 0 r
.77563 .46193 .77636 .46294 .77826 .46555 .77753 .46457 Mtetra
.975 .678 .39 r
.77753 .46457 .77826 .46555 .79518 .66176 .79443 .66106 Mtetra
.917 .524 .144 r
.79443 .66106 .79518 .66176 .7975 .66847 .79675 .66771 Mtetra
0 .292 .764 r
.79675 .66771 .7975 .66847 .79941 .66972 .79866 .66893 Mtetra
.654 .787 .946 r
.79866 .66893 .79941 .66972 .80119 .66924 .80043 .66841 Mtetra
.761 .808 .89 r
.80043 .66841 .80119 .66924 .80292 .66825 .80216 .66736 Mtetra
.738 .79 .894 r
.80216 .66736 .80292 .66825 .80466 .66738 .8039 .66645 Mtetra
.678 .762 .914 r
.8039 .66645 .80466 .66738 .80643 .66679 .80567 .66584 Mtetra
.673 .755 .913 r
.80567 .66584 .80643 .66679 .8082 .66622 .80744 .66525 Mtetra
.671 .751 .911 r
.80744 .66525 .8082 .66622 .80997 .66566 .80921 .66467 Mtetra
.669 .747 .909 r
.80921 .66467 .80997 .66566 .81175 .66511 .81098 .6641 Mtetra
.666 .742 .907 r
.81098 .6641 .81175 .66511 .81352 .66457 .81276 .66355 Mtetra
.663 .737 .905 r
.81276 .66355 .81352 .66457 .8153 .66404 .81453 .66301 Mtetra
.661 .733 .903 r
.81453 .66301 .8153 .66404 .81708 .66353 .81631 .66248 Mtetra
.658 .729 .902 r
.81631 .66248 .81708 .66353 .81886 .66303 .81809 .66196 Mtetra
.654 .726 .901 r
.81809 .66196 .81886 .66303 .82064 .66253 .81988 .66147 Mtetra
.651 .723 .901 r
.81988 .66147 .82064 .66253 .82243 .66206 .82166 .66098 Mtetra
.647 .721 .902 r
.82166 .66098 .82243 .66206 .82422 .66159 .82345 .66052 Mtetra
.642 .719 .903 r
.82345 .66052 .82422 .66159 .82601 .66115 .82525 .66007 Mtetra
.638 .717 .905 r
.82525 .66007 .82601 .66115 .8278 .66072 .82704 .65965 Mtetra
.635 .717 .907 r
.82704 .65965 .8278 .66072 .8296 .66029 .82884 .65924 Mtetra
.608 .708 .916 r
.82884 .65924 .8296 .66029 .83141 .66005 .83065 .65894 Mtetra
.598 .692 .909 r
.83065 .65894 .83141 .66005 .83323 .65988 .83246 .65869 Mtetra
.651 .7 .883 r
.83246 .65869 .83323 .65988 .83502 .65931 .83425 .65821 Mtetra
.771 .76 .842 r
.83425 .65821 .83502 .65931 .83668 .65736 .83598 .65697 Mtetra
.929 .904 .779 r
.83598 .65697 .83668 .65736 .83803 .65198 .83761 .65456 Mtetra
0 0 .167 r
.83761 .65456 .83803 .65198 .82218 .45685 .83913 .65107 Mtetra
.565 .356 .557 r
.83913 .65107 .82218 .45685 .82344 .45158 .84064 .64744 Mtetra
.569 .359 .557 r
.84064 .64744 .82344 .45158 .82509 .45072 .8424 .64658 Mtetra
.57 .361 .557 r
.8424 .64658 .82509 .45072 .82683 .45068 .84427 .64694 Mtetra
.57 .36 .557 r
.84427 .64694 .82683 .45068 .82857 .45071 .84614 .64719 Mtetra
.569 .36 .557 r
.84614 .64719 .82857 .45071 .83027 .45029 .84795 .64686 Mtetra
.84795 .64686 .83027 .45029 .83197 .44987 .84977 .64652 Mtetra
.84977 .64652 .83197 .44987 .83367 .44943 .85158 .64615 Mtetra
.85158 .64615 .83367 .44943 .83537 .44897 .85339 .64574 Mtetra
.85339 .64574 .83537 .44897 .83707 .44849 .8552 .6453 Mtetra
.8552 .6453 .83707 .44849 .83876 .44801 .85701 .64486 Mtetra
.85701 .64486 .83876 .44801 .84046 .44751 .85882 .6444 Mtetra
.85882 .6444 .84046 .44751 .84216 .44701 .86063 .64393 Mtetra
.86063 .64393 .84216 .44701 .84386 .4465 .86244 .64345 Mtetra
.86244 .64345 .84386 .4465 .84556 .44598 .86425 .64297 Mtetra
.86425 .64297 .84556 .44598 .84726 .44546 .86606 .64247 Mtetra
.86606 .64247 .84726 .44546 .84896 .44493 .86787 .64197 Mtetra
.86787 .64197 .84896 .44493 .85067 .4444 .86968 .64147 Mtetra
.86968 .64147 .85067 .4444 .85237 .44386 .87149 .64096 Mtetra
.87149 .64096 .85237 .44386 .85407 .44331 .87331 .64043 Mtetra
.87331 .64043 .85407 .44331 .85577 .44276 .87512 .63991 Mtetra
.87512 .63991 .85577 .44276 .85748 .44221 .87693 .63937 Mtetra
.87693 .63937 .85748 .44221 .85918 .44164 .87874 .63882 Mtetra
.87874 .63882 .85918 .44164 .86088 .44108 .88056 .63827 Mtetra
.88056 .63827 .86088 .44108 .86259 .44051 .88237 .6377 Mtetra
.88237 .6377 .86259 .44051 .86429 .43993 .88418 .63712 Mtetra
.88418 .63712 .86429 .43993 .866 .43936 .886 .63654 Mtetra
.886 .63654 .866 .43936 .86771 .43878 .88781 .63594 Mtetra
.88781 .63594 .86771 .43878 .86942 .4382 .88962 .63532 Mtetra
.88962 .63532 .86942 .4382 .87112 .43762 .89143 .63469 Mtetra
.89143 .63469 .87112 .43762 .87283 .43704 .89324 .63405 Mtetra
.89324 .63405 .87283 .43704 .87455 .43647 .89506 .63342 Mtetra
.89506 .63342 .87455 .43647 .87626 .43591 .89688 .63282 Mtetra
.89688 .63282 .87626 .43591 .87797 .43536 .8987 .63224 Mtetra
.8987 .63224 .87797 .43536 .87969 .43482 .90052 .6317 Mtetra
.90052 .6317 .87969 .43482 .88141 .4343 .90236 .63119 Mtetra
.90236 .63119 .88141 .4343 .88314 .4338 .90419 .63072 Mtetra
.90419 .63072 .88314 .4338 .88487 .43332 .90604 .63032 Mtetra
.90604 .63032 .88487 .43332 .8866 .43286 .90789 .63 Mtetra
.90789 .63 .8866 .43286 .88833 .43244 .90976 .62972 Mtetra
.57 .36 .557 r
.90976 .62972 .88833 .43244 .89008 .43211 .91165 .62971 Mtetra
.571 .361 .557 r
.91165 .62971 .89008 .43211 .89186 .43204 .91362 .63035 Mtetra
.569 .36 .557 r
.91362 .63035 .89186 .43204 .89361 .43172 .91548 .63005 Mtetra
.566 .358 .557 r
.91548 .63005 .89361 .43172 .89528 .43066 .91707 .62733 Mtetra
.179 .085 .503 r
.91707 .62733 .89528 .43066 .89683 .42852 .89682 .43344 Mtetra
.005 0 .335 r
.89682 .43344 .89683 .42852 .89841 .42669 .89788 .42696 Mtetra
.903 .958 .624 r
.89788 .42696 .89841 .42669 .90004 .42534 .89936 .42427 Mtetra
.709 .74 .875 r
.89936 .42427 .90004 .42534 .90177 .42475 .90106 .4235 Mtetra
.628 .672 .873 r
.90106 .4235 .90177 .42475 .90351 .42433 .90281 .42315 Mtetra
.6 .67 .889 r
.90281 .42315 .90351 .42433 .90526 .42394 .90458 .42292 Mtetra
.672 .734 .896 r
.90458 .42292 .90526 .42394 .90699 .42335 .90631 .42234 Mtetra
.678 .741 .898 r
.90631 .42234 .90699 .42335 .90871 .42273 .90804 .42174 Mtetra
.699 .753 .894 r
.90804 .42174 .90871 .42273 .91043 .42201 .90976 .42104 Mtetra
.767 .78 .864 r
.90976 .42104 .91043 .42201 .9121 .42092 .91143 .41995 Mtetra
.695 .757 .899 r
.91143 .41995 .9121 .42092 .91382 .42023 .91315 .41927 Mtetra
.429 .628 .937 r
.91315 .41927 .91382 .42023 .91565 .4205 .91499 .41954 Mtetra
.789 .372 0 r
.91499 .41954 .91565 .4205 .91807 .42556 .91741 .42464 Mtetra
.973 .661 .312 r
.91741 .42464 .91807 .42556 .94404 .62423 .94335 .62335 Mtetra
.737 .295 0 r
.94335 .62335 .94404 .62423 .94648 .62853 .94579 .62762 Mtetra
.495 .694 .957 r
.94579 .62762 .94648 .62853 .94841 .62856 .94772 .62764 Mtetra
.693 .784 .921 r
.94772 .62764 .94841 .62856 .95025 .62785 .94956 .62693 Mtetra
.743 .8 .899 r
.94956 .62693 .95025 .62785 .95206 .62688 .95137 .62596 Mtetra
.493 .691 .956 r
.95137 .62596 .95206 .62688 .95399 .62691 .95331 .62599 Mtetra
.619 .752 .941 r
.95331 .62599 .95399 .62691 .95588 .62652 .95519 .6256 Mtetra
.799 .814 .864 r
.95519 .6256 .95588 .62652 .95764 .62517 .95695 .62425 Mtetra
.98 .776 .557 r
.95695 .62425 .95764 .62517 .95872 .61838 .95803 .61746 Mtetra
.975 .669 .322 r
.95803 .61746 .95872 .61838 .93535 .41855 .93469 .41757 Mtetra
.963 .784 .613 r
.93469 .41757 .93535 .41855 .93654 .41365 .93589 .41266 Mtetra
.756 .776 .87 r
.93589 .41266 .93654 .41365 .93823 .41262 .93758 .41163 Mtetra
.626 .725 .918 r
.93758 .41163 .93823 .41262 .94001 .41225 .93935 .41126 Mtetra
.545 .685 .931 r
.93935 .41126 .94001 .41225 .94182 .41218 .94117 .41119 Mtetra
.747 .773 .874 r
.94117 .41119 .94182 .41218 .94352 .4112 .94286 .41021 Mtetra
.681 .748 .902 r
.94286 .41021 .94352 .4112 .94527 .41058 .94461 .40959 Mtetra
.488 .656 .934 r
.94461 .40959 .94527 .41058 .94711 .41069 .94645 .4097 Mtetra
.738 .32 0 r
.94645 .4097 .94711 .41069 .94956 .41548 .94891 .41449 Mtetra
.97 .655 .291 r
.94891 .41449 .94956 .41548 .97768 .615 .977 .61406 Mtetra
.739 .309 0 r
.977 .61406 .97768 .615 .98026 .61976 .97958 .61882 Mtetra
.031 .462 .877 r
.37071 .78131 .37164 .78207 .37311 .78269 .37218 .78194 Mtetra
.642 .761 .935 r
.37218 .78194 .37311 .78269 .37463 .7823 .37371 .78154 Mtetra
.809 .778 .825 r
.37371 .78154 .37463 .7823 .3762 .78089 .37527 .78013 Mtetra
.908 .738 .659 r
.37527 .78013 .3762 .78089 .37792 .77571 .37699 .77494 Mtetra
.937 .686 .534 r
.37699 .77494 .37792 .77571 .3871 .58584 .38623 .58501 Mtetra
.908 .726 .644 r
.38623 .58501 .3871 .58584 .38876 .58012 .38789 .5793 Mtetra
.775 .757 .837 r
.38789 .5793 .38876 .58012 .39022 .57905 .38936 .57821 Mtetra
.635 .729 .916 r
.38936 .57821 .39022 .57905 .39166 .57873 .3908 .57788 Mtetra
.499 .678 .945 r
.3908 .57788 .39166 .57873 .39309 .57877 .39222 .57791 Mtetra
.735 .746 .861 r
.39222 .57791 .39309 .57877 .39455 .5781 .39368 .57711 Mtetra
.685 .71 .867 r
.39368 .57711 .39455 .5781 .39599 .57758 .39514 .57656 Mtetra
.515 .642 .912 r
.39514 .57656 .39599 .57758 .39743 .57748 .39656 .57662 Mtetra
.921 .53 .214 r
.39656 .57662 .39743 .57748 .3988 .57909 .39786 .58029 Mtetra
.936 .68 .524 r
.39786 .58029 .3988 .57909 .40005 .58413 .39234 .7687 Mtetra
.579 .368 .558 r
.39234 .7687 .40005 .58413 .39479 .76897 .39365 .77428 Mtetra
.593 .322 .476 r
.39365 .77428 .39479 .76897 .39616 .77311 .39515 .77494 Mtetra
.463 .1 .262 r
.39515 .77494 .39616 .77311 .39763 .77466 .39668 .77469 Mtetra
.604 .942 .94 r
.39668 .77469 .39763 .77466 .39913 .77509 .39822 .77399 Mtetra
.7 .706 .852 r
.39822 .77399 .39913 .77509 .4007 .77366 .39977 .77331 Mtetra
.724 .885 .955 r
.39977 .77331 .4007 .77366 .40232 .77103 .40132 .77255 Mtetra
.271 0 .103 r
.40132 .77255 .40232 .77103 .40399 .76663 .40287 .77178 Mtetra
.521 .255 .451 r
.40287 .77178 .40399 .76663 .40559 .76432 .40441 .77129 Mtetra
.541 .289 .483 r
.40441 .77129 .40559 .76432 .40712 .76398 .40595 .77092 Mtetra
.543 .29 .483 r
.40595 .77092 .40712 .76398 .40863 .7645 .40749 .77058 Mtetra
.56 .3 .478 r
.40749 .77058 .40863 .7645 .41013 .76533 .40902 .77064 Mtetra
.541 .274 .46 r
.40902 .77064 .41013 .76533 .41165 .76535 .41056 .77041 Mtetra
.486 .221 .438 r
.41056 .77041 .41165 .76535 .41323 .76383 .41212 .76948 Mtetra
.014 0 .262 r
.41212 .76948 .41323 .76383 .42042 .57956 .4138 .76448 Mtetra
0 0 .326 r
.4138 .76448 .42042 .57956 .4221 .57201 .42114 .57435 Mtetra
.933 .872 .449 r
.42114 .57435 .4221 .57201 .42364 .56896 .42276 .56872 Mtetra
.849 .892 .868 r
.42276 .56872 .42364 .56896 .42512 .5679 .42425 .56735 Mtetra
.646 .812 .963 r
.42425 .56735 .42512 .5679 .42658 .56746 .42572 .56692 Mtetra
.465 .756 .993 r
.42572 .56692 .42658 .56746 .42804 .56729 .42717 .56686 Mtetra
.581 .83 .992 r
.42717 .56686 .42804 .56729 .42949 .56706 .42863 .56654 Mtetra
.633 .817 .971 r
.42863 .56654 .42949 .56706 .43095 .56681 .4301 .56614 Mtetra
.647 .777 .943 r
.4301 .56614 .43095 .56681 .43242 .56652 .43156 .56573 Mtetra
.658 .749 .917 r
.43156 .56573 .43242 .56652 .43389 .56603 .43303 .5653 Mtetra
.661 .765 .926 r
.43303 .5653 .43389 .56603 .43536 .56544 .4345 .56485 Mtetra
.659 .802 .952 r
.4345 .56485 .43536 .56544 .43683 .56484 .43597 .56439 Mtetra
.661 .845 .97 r
.43597 .56439 .43683 .56484 .4383 .56418 .43744 .56389 Mtetra
.628 .886 .988 r
.43744 .56389 .4383 .56418 .43978 .56362 .43891 .5634 Mtetra
.581 .889 .99 r
.43891 .5634 .43978 .56362 .44124 .56333 .44038 .56295 Mtetra
.69 .872 .967 r
.44038 .56295 .44124 .56333 .4427 .5637 .44186 .56234 Mtetra
.647 .639 .828 r
.44186 .56234 .4427 .5637 .44413 .56492 .44333 .56194 Mtetra
.557 .469 .711 r
.44333 .56194 .44413 .56492 .44552 .56801 .44479 .56214 Mtetra
.292 .22 .601 r
.44479 .56214 .44552 .56801 .44273 .75352 .44618 .56552 Mtetra
0 0 .359 r
.44618 .56552 .44273 .75352 .44413 .76008 .44332 .75504 Mtetra
0 0 .444 r
.44332 .75504 .44413 .76008 .44563 .76233 .44475 .7607 Mtetra
.296 .431 .828 r
.44475 .7607 .44563 .76233 .44717 .76282 .44628 .76159 Mtetra
.632 .665 .864 r
.44628 .76159 .44717 .76282 .44873 .76259 .44784 .76126 Mtetra
.7 .674 .821 r
.44784 .76126 .44873 .76259 .4503 .76205 .44942 .7605 Mtetra
.659 .631 .811 r
.44942 .7605 .4503 .76205 .45187 .76163 .45099 .75998 Mtetra
.64 .612 .807 r
.45099 .75998 .45187 .76163 .45344 .76115 .45255 .75958 Mtetra
.65 .625 .812 r
.45255 .75958 .45344 .76115 .45501 .76042 .45412 .75912 Mtetra
.622 .651 .857 r
.45412 .75912 .45501 .76042 .4566 .75911 .45569 .75884 Mtetra
.578 .881 .992 r
.45569 .75884 .4566 .75911 .4582 .75702 .45726 .75838 Mtetra
.121 0 0 r
.45726 .75838 .4582 .75702 .45983 .75341 .45884 .75735 Mtetra
0 0 .187 r
.45884 .75735 .45983 .75341 .46465 .5695 .46048 .7535 Mtetra
0 0 .349 r
.46048 .7535 .46465 .5695 .46632 .55902 .46537 .56388 Mtetra
0 0 0 r
.46537 .56388 .46632 .55902 .46785 .55589 .46699 .55599 Mtetra
.911 .945 .812 r
.46699 .55599 .46785 .55589 .46935 .5547 .4685 .55409 Mtetra
.682 .804 .94 r
.4685 .55409 .46935 .5547 .47083 .55436 .46999 .55355 Mtetra
.553 .712 .946 r
.46999 .55355 .47083 .55436 .47231 .55433 .47147 .55344 Mtetra
.608 .712 .919 r
.47147 .55344 .47231 .55433 .4738 .55411 .47296 .55319 Mtetra
.65 .719 .898 r
.47296 .55319 .4738 .55411 .47529 .5537 .47445 .55279 Mtetra
.651 .721 .9 r
.47445 .55279 .47529 .5537 .47678 .55323 .47594 .55238 Mtetra
.66 .739 .908 r
.47594 .55238 .47678 .55323 .47827 .55267 .47743 .55194 Mtetra
.666 .771 .928 r
.47743 .55194 .47827 .55267 .47977 .55205 .47893 .55147 Mtetra
.663 .811 .954 r
.47893 .55147 .47977 .55205 .48126 .55143 .48042 .55099 Mtetra
.659 .849 .973 r
.48042 .55099 .48126 .55143 .48276 .55076 .48192 .55047 Mtetra
.628 .889 .987 r
.48192 .55047 .48276 .55076 .48426 .55016 .48341 .54996 Mtetra
.576 .897 .985 r
.48341 .54996 .48426 .55016 .48575 .5498 .48491 .54949 Mtetra
.545 .858 .997 r
.48491 .54949 .48575 .5498 .48724 .55022 .4864 .54915 Mtetra
.613 .675 .885 r
.4864 .54915 .48724 .55022 .48871 .55163 .4879 .5489 Mtetra
.605 .511 .721 r
.4879 .5489 .48871 .55163 .49018 .55417 .48939 .54866 Mtetra
.613 .455 .643 r
.48939 .54866 .49018 .55417 .49167 .55553 .4909 .54801 Mtetra
.607 .434 .622 r
.4909 .54801 .49167 .55553 .49317 .55449 .4924 .54724 Mtetra
.587 .422 .624 r
.4924 .54724 .49317 .55449 .49468 .5541 .4939 .547 Mtetra
.459 .33 .617 r
.4939 .547 .49468 .5541 .49467 .73096 .49538 .54913 Mtetra
0 0 .373 r
.49538 .54913 .49467 .73096 .49614 .74473 .49532 .73728 Mtetra
0 0 .41 r
.49532 .73728 .49614 .74473 .49771 .74777 .49683 .74591 Mtetra
.115 .287 .762 r
.49683 .74591 .49771 .74777 .49929 .74856 .49841 .74744 Mtetra
.61 .677 .889 r
.49841 .74744 .49929 .74856 .50089 .74824 .50001 .74719 Mtetra
.706 .722 .862 r
.50001 .74719 .50089 .74824 .50248 .74763 .5016 .74646 Mtetra
.688 .698 .854 r
.5016 .74646 .50248 .74763 .50408 .74714 .5032 .74583 Mtetra
.643 .658 .85 r
.5032 .74583 .50408 .74714 .50568 .74687 .5048 .74543 Mtetra
.642 .64 .833 r
.5048 .74543 .50568 .74687 .50727 .74659 .5064 .74502 Mtetra
.642 .625 .818 r
.5064 .74502 .50727 .74659 .50887 .74624 .508 .74461 Mtetra
.641 .616 .809 r
.508 .74461 .50887 .74624 .51047 .74584 .5096 .74419 Mtetra
.642 .615 .808 r
.5096 .74419 .51047 .74584 .51207 .74541 .5112 .74377 Mtetra
.642 .616 .808 r
.5112 .74377 .51207 .74541 .51368 .74499 .5128 .74334 Mtetra
.5128 .74334 .51368 .74499 .51528 .74457 .51441 .74292 Mtetra
.51441 .74292 .51528 .74457 .51688 .74414 .51601 .7425 Mtetra
.51601 .7425 .51688 .74414 .51849 .74372 .51762 .74207 Mtetra
.643 .616 .808 r
.51762 .74207 .51849 .74372 .5201 .74329 .51922 .74164 Mtetra
.51922 .74164 .5201 .74329 .5217 .74286 .52083 .74121 Mtetra
.52083 .74121 .5217 .74286 .52331 .74243 .52244 .74078 Mtetra
.52244 .74078 .52331 .74243 .52492 .742 .52405 .74035 Mtetra
.643 .616 .807 r
.52405 .74035 .52492 .742 .52653 .74156 .52566 .73991 Mtetra
.52566 .73991 .52653 .74156 .52814 .74113 .52727 .73948 Mtetra
.52727 .73948 .52814 .74113 .52975 .74069 .52888 .73904 Mtetra
.644 .616 .807 r
.52888 .73904 .52975 .74069 .53137 .74026 .53049 .7386 Mtetra
.53049 .7386 .53137 .74026 .53298 .73982 .53211 .73816 Mtetra
.53211 .73816 .53298 .73982 .53459 .73938 .53372 .73772 Mtetra
.53372 .73772 .53459 .73938 .53621 .73894 .53534 .73727 Mtetra
.645 .616 .806 r
.53534 .73727 .53621 .73894 .53783 .73849 .53696 .73683 Mtetra
.53696 .73683 .53783 .73849 .53944 .73805 .53857 .73638 Mtetra
.645 .616 .805 r
.53857 .73638 .53944 .73805 .54106 .7376 .54019 .73592 Mtetra
.646 .615 .805 r
.54019 .73592 .54106 .7376 .54268 .73716 .54181 .73547 Mtetra
.646 .614 .803 r
.54181 .73547 .54268 .73716 .5443 .73673 .54343 .735 Mtetra
.645 .61 .8 r
.54343 .735 .5443 .73673 .54592 .73627 .54505 .73454 Mtetra
.642 .608 .801 r
.54505 .73454 .54592 .73627 .54755 .73582 .54668 .73411 Mtetra
.639 .608 .803 r
.54668 .73411 .54755 .73582 .54917 .73537 .5483 .73369 Mtetra
.644 .615 .806 r
.5483 .73369 .54917 .73537 .55079 .73471 .54992 .73325 Mtetra
.665 .649 .824 r
.54992 .73325 .55079 .73471 .55241 .73348 .55155 .73269 Mtetra
.709 .783 .91 r
.55155 .73269 .55241 .73348 .55402 .73119 .55317 .73199 Mtetra
.051 0 0 r
.55317 .73199 .55402 .73119 .55562 .72793 .5548 .73127 Mtetra
.479 .183 .384 r
.5548 .73127 .55562 .72793 .55722 .7243 .55642 .73066 Mtetra
.536 .279 .473 r
.55642 .73066 .55722 .7243 .55884 .72328 .55805 .73024 Mtetra
.542 .289 .482 r
.55805 .73024 .55884 .72328 .56047 .72351 .55968 .72987 Mtetra
.548 .29 .476 r
.55968 .72987 .56047 .72351 .56211 .7242 .56132 .72967 Mtetra
.553 .286 .465 r
.56132 .72967 .56211 .7242 .56375 .72468 .56295 .72965 Mtetra
.519 .25 .446 r
.56295 .72965 .56375 .72468 .56537 .72413 .56458 .72913 Mtetra
.39 .14 .409 r
.56458 .72913 .56537 .72413 .56696 .71958 .5662 .72706 Mtetra
0 0 .198 r
.5662 .72706 .56696 .71958 .56627 .53117 .56772 .71738 Mtetra
0 0 .4 r
.56772 .71738 .56627 .53117 .56775 .5264 .56697 .52724 Mtetra
.951 .937 .605 r
.56697 .52724 .56775 .5264 .56928 .52432 .56847 .52385 Mtetra
.735 .864 .941 r
.56847 .52385 .56928 .52432 .57082 .52381 .57001 .52307 Mtetra
.579 .746 .957 r
.57001 .52307 .57082 .52381 .57237 .5237 .57156 .52285 Mtetra
.531 .698 .946 r
.57156 .52285 .57237 .5237 .57392 .52369 .57311 .5228 Mtetra
.627 .727 .919 r
.57311 .5228 .57392 .52369 .57546 .52337 .57466 .52247 Mtetra
.62 .722 .919 r
.57466 .52247 .57546 .52337 .57701 .52303 .57621 .52217 Mtetra
.617 .729 .926 r
.57621 .52217 .57701 .52303 .57856 .52268 .57776 .52187 Mtetra
.62 .743 .934 r
.57776 .52187 .57856 .52268 .58011 .52233 .57931 .52155 Mtetra
.62 .751 .94 r
.57931 .52155 .58011 .52233 .58166 .52197 .58086 .52122 Mtetra
.62 .761 .946 r
.58086 .52122 .58166 .52197 .58321 .52159 .58241 .52089 Mtetra
.622 .772 .952 r
.58241 .52089 .58321 .52159 .58477 .52121 .58397 .52054 Mtetra
.623 .782 .958 r
.58397 .52054 .58477 .52121 .58632 .52081 .58552 .52017 Mtetra
.625 .793 .963 r
.58552 .52017 .58632 .52081 .58787 .5204 .58708 .51979 Mtetra
.627 .802 .967 r
.58708 .51979 .58787 .5204 .58943 .51997 .58863 .51939 Mtetra
.63 .812 .97 r
.58863 .51939 .58943 .51997 .59098 .51954 .59019 .51898 Mtetra
.636 .819 .971 r
.59019 .51898 .59098 .51954 .59254 .51909 .59175 .51854 Mtetra
.644 .825 .97 r
.59175 .51854 .59254 .51909 .59409 .51863 .5933 .51808 Mtetra
.65 .825 .967 r
.5933 .51808 .59409 .51863 .59565 .51816 .59486 .51759 Mtetra
.655 .822 .964 r
.59486 .51759 .59565 .51816 .59721 .51769 .59642 .5171 Mtetra
.659 .818 .96 r
.59642 .5171 .59721 .51769 .59877 .51721 .59798 .5166 Mtetra
.663 .813 .955 r
.59798 .5166 .59877 .51721 .60033 .51673 .59954 .5161 Mtetra
.666 .806 .95 r
.59954 .5161 .60033 .51673 .60189 .51625 .6011 .51559 Mtetra
.668 .799 .945 r
.6011 .51559 .60189 .51625 .60345 .51577 .60266 .51507 Mtetra
.671 .791 .938 r
.60266 .51507 .60345 .51577 .60501 .51528 .60422 .51455 Mtetra
.674 .782 .931 r
.60422 .51455 .60501 .51528 .60657 .5148 .60578 .51402 Mtetra
.677 .771 .922 r
.60578 .51402 .60657 .5148 .60814 .51431 .60735 .51348 Mtetra
.681 .759 .91 r
.60735 .51348 .60814 .51431 .6097 .51382 .60891 .51293 Mtetra
.684 .746 .899 r
.60891 .51293 .6097 .51382 .61127 .51331 .61047 .51236 Mtetra
.687 .735 .887 r
.61047 .51236 .61127 .51331 .61283 .51277 .61204 .51178 Mtetra
.689 .725 .878 r
.61204 .51178 .61283 .51277 .6144 .51221 .6136 .51117 Mtetra
.691 .718 .87 r
.6136 .51117 .6144 .51221 .61596 .51162 .61517 .51055 Mtetra
.696 .713 .862 r
.61517 .51055 .61596 .51162 .61753 .51101 .61673 .5099 Mtetra
.692 .705 .858 r
.61673 .5099 .61753 .51101 .61909 .51037 .6183 .50926 Mtetra
.695 .706 .856 r
.6183 .50926 .61909 .51037 .62066 .50966 .61987 .5086 Mtetra
.742 .73 .841 r
.61987 .5086 .62066 .50966 .62221 .50862 .62142 .50765 Mtetra
.676 .728 .889 r
.62142 .50765 .62221 .50862 .62378 .50788 .62299 .50711 Mtetra
.307 .611 .954 r
.62299 .50711 .62378 .50788 .62536 .50778 .62459 .50747 Mtetra
.923 .543 .263 r
.62459 .50747 .62536 .50778 .62702 .51005 .62634 .51275 Mtetra
.959 .68 .462 r
.62634 .51275 .62702 .51005 .62889 .51891 .6339 .70568 Mtetra
.576 .365 .557 r
.6339 .70568 .62889 .51891 .63636 .70497 .63571 .70976 Mtetra
.56 .283 .452 r
.63571 .70976 .63636 .70497 .63807 .70554 .63741 .70988 Mtetra
.508 .23 .428 r
.63741 .70988 .63807 .70554 .63973 .70484 .63908 .70932 Mtetra
.487 .214 .426 r
.63908 .70932 .63973 .70484 .64138 .70356 .64075 .70846 Mtetra
.552 .277 .452 r
.64075 .70846 .64138 .70356 .64309 .70395 .64244 .70845 Mtetra
.522 .245 .436 r
.64244 .70845 .64309 .70395 .64477 .70358 .64412 .70804 Mtetra
.454 .186 .417 r
.64412 .70804 .64477 .70358 .64639 .70158 .64577 .7068 Mtetra
0 0 .257 r
.64577 .7068 .64639 .70158 .64144 .51164 .64726 .70079 Mtetra
.028 0 .427 r
.64726 .70079 .64144 .51164 .6428 .5045 .64211 .50636 Mtetra
.853 .824 .346 r
.64211 .50636 .6428 .5045 .64429 .50158 .64353 .5012 Mtetra
.794 .9 .917 r
.64353 .5012 .64429 .50158 .64587 .50085 .6451 .50013 Mtetra
.639 .776 .946 r
.6451 .50013 .64587 .50085 .64746 .50058 .64669 .49971 Mtetra
.541 .702 .944 r
.64669 .49971 .64746 .50058 .64906 .50053 .64829 .49963 Mtetra
.662 .74 .908 r
.64829 .49963 .64906 .50053 .65065 .50009 .64988 .49916 Mtetra
.66 .732 .903 r
.64988 .49916 .65065 .50009 .65224 .49959 .65146 .49869 Mtetra
.661 .738 .907 r
.65146 .49869 .65224 .49959 .65383 .49905 .65305 .49821 Mtetra
.761 .781 .869 r
.65305 .49821 .65383 .49905 .65539 .49792 .65463 .49722 Mtetra
.699 .803 .93 r
.65463 .49722 .65539 .49792 .65697 .49716 .65621 .49659 Mtetra
.406 .725 .989 r
.65621 .49659 .65697 .49716 .65858 .49711 .65782 .49663 Mtetra
.906 .496 .166 r
.65782 .49663 .65858 .49711 .66037 .50151 .65961 .50101 Mtetra
.967 .683 .442 r
.65961 .50101 .66037 .50151 .67005 .69689 .66921 .69556 Mtetra
.865 .465 0 r
.66921 .69556 .67005 .69689 .67196 .70182 .67113 .7005 Mtetra
.46 .578 .886 r
.67113 .7005 .67196 .70182 .67369 .70214 .67286 .70083 Mtetra
.658 .673 .853 r
.67286 .70083 .67369 .70214 .67538 .70152 .67456 .70032 Mtetra
.728 .717 .84 r
.67456 .70032 .67538 .70152 .67705 .70023 .67624 .69938 Mtetra
.581 .739 .951 r
.67624 .69938 .67705 .70023 .6787 .69872 .67795 .69915 Mtetra
0 0 0 r
.67795 .69915 .6787 .69872 .68032 .69648 .67964 .69863 Mtetra
.308 0 .235 r
.67964 .69863 .68032 .69648 .68187 .69256 .68131 .69743 Mtetra
.033 0 .293 r
.68131 .69743 .68187 .69256 .67505 .50339 .68281 .69233 Mtetra
.046 0 .438 r
.68281 .69233 .67505 .50339 .67631 .49524 .67569 .4977 Mtetra
.776 .745 .225 r
.67569 .4977 .67631 .49524 .6778 .49229 .67704 .49153 Mtetra
.804 .807 .854 r
.67704 .49153 .6778 .49229 .67938 .49136 .67861 .49027 Mtetra
.637 .692 .885 r
.67861 .49027 .67938 .49136 .68099 .491 .68022 .4899 Mtetra
.537 .646 .904 r
.68022 .4899 .68099 .491 .68261 .49089 .68185 .48991 Mtetra
.651 .721 .9 r
.68185 .48991 .68261 .49089 .68422 .49043 .68346 .48948 Mtetra
.672 .733 .896 r
.68346 .48948 .68422 .49043 .68583 .48989 .68506 .48895 Mtetra
.677 .738 .896 r
.68506 .48895 .68583 .48989 .68743 .48932 .68667 .48839 Mtetra
.764 .766 .855 r
.68667 .48839 .68743 .48932 .68901 .48826 .68825 .48735 Mtetra
.721 .758 .881 r
.68825 .48735 .68901 .48826 .69061 .48748 .68985 .48657 Mtetra
.555 .698 .935 r
.68985 .48657 .69061 .48748 .69224 .48737 .69148 .48647 Mtetra
.831 .394 0 r
.69148 .48647 .69224 .48737 .69406 .49101 .6933 .49012 Mtetra
.97 .683 .428 r
.6933 .49012 .69406 .49101 .70574 .68572 .70494 .68489 Mtetra
.914 .516 .138 r
.70494 .68489 .70574 .68572 .70777 .69134 .70697 .6905 Mtetra
0 .389 .841 r
.70697 .6905 .70777 .69134 .70956 .69233 .70876 .69148 Mtetra
.607 .749 .945 r
.70876 .69148 .70956 .69233 .71129 .69201 .71049 .69116 Mtetra
.801 .8 .851 r
.71049 .69116 .71129 .69201 .71296 .69064 .71217 .68982 Mtetra
.938 .778 .656 r
.71217 .68982 .71296 .69064 .71445 .68577 .71367 .68524 Mtetra
.971 .689 .437 r
.71367 .68524 .71445 .68577 .70548 .48933 .70478 .48952 Mtetra
.993 .804 .547 r
.70478 .48952 .70548 .48933 .70677 .48289 .70604 .48239 Mtetra
.859 .873 .848 r
.70604 .48239 .70677 .48289 .70834 .48145 .70761 .48082 Mtetra
.634 .807 .966 r
.70761 .48082 .70834 .48145 .70997 .48113 .70923 .48038 Mtetra
.49 .714 .97 r
.70923 .48038 .70997 .48113 .71163 .48125 .71088 .48037 Mtetra
.706 .764 .898 r
.71088 .48037 .71163 .48125 .71325 .48073 .71249 .47968 Mtetra
.693 .724 .874 r
.71249 .47968 .71325 .48073 .71487 .48014 .71411 .47903 Mtetra
.565 .659 .9 r
.71411 .47903 .71487 .48014 .71651 .47992 .71576 .47895 Mtetra
.691 .237 0 r
.71576 .47895 .71651 .47992 .71824 .48118 .71758 .48179 Mtetra
.97 .68 .422 r
.71758 .48179 .71824 .48118 .72014 .48526 .7306 .67509 Mtetra
.58 .368 .557 r
.7306 .67509 .72014 .48526 .73316 .67614 .7328 .68258 Mtetra
.603 .335 .483 r
.7328 .68258 .73316 .67614 .73521 .68113 .73463 .68369 Mtetra
.506 .179 .345 r
.73463 .68369 .73521 .68113 .73709 .68295 .73638 .68349 Mtetra
0 0 0 r
.73638 .68349 .73709 .68295 .7389 .6838 .73811 .68284 Mtetra
.665 .746 .911 r
.73811 .68284 .7389 .6838 .74067 .68389 .73984 .68231 Mtetra
.649 .636 .823 r
.73984 .68231 .74067 .68389 .74242 .6836 .74158 .68181 Mtetra
.649 .614 .8 r
.74158 .68181 .74242 .6836 .74416 .68312 .74332 .68129 Mtetra
.643 .606 .798 r
.74332 .68129 .74416 .68312 .7459 .68266 .74506 .68081 Mtetra
.639 .603 .797 r
.74506 .68081 .7459 .68266 .74765 .6822 .7468 .68036 Mtetra
.7468 .68036 .74765 .6822 .74939 .68172 .74855 .6799 Mtetra
.64 .607 .8 r
.74855 .6799 .74939 .68172 .75113 .68127 .75029 .67944 Mtetra
.641 .606 .799 r
.75029 .67944 .75113 .68127 .75288 .68081 .75204 .67898 Mtetra
.641 .605 .798 r
.75204 .67898 .75288 .68081 .75462 .68033 .75378 .67851 Mtetra
.635 .604 .801 r
.75378 .67851 .75462 .68033 .75637 .67989 .75553 .67809 Mtetra
.636 .606 .803 r
.75553 .67809 .75637 .67989 .75812 .67938 .75729 .67766 Mtetra
.645 .62 .81 r
.75729 .67766 .75812 .67938 .75985 .67862 .75903 .67718 Mtetra
.622 .644 .851 r
.75903 .67718 .75985 .67862 .76154 .67727 .7608 .67686 Mtetra
.588 .868 .994 r
.7608 .67686 .76154 .67727 .76318 .67513 .76255 .67638 Mtetra
.152 0 .011 r
.76255 .67638 .76318 .67513 .76471 .6715 .76426 .67531 Mtetra
.094 0 .29 r
.76426 .67531 .76471 .6715 .75357 .48458 .76578 .67144 Mtetra
.081 .003 .459 r
.76578 .67144 .75357 .48458 .75435 .47146 .75404 .47671 Mtetra
0 0 .186 r
.75404 .47671 .75435 .47146 .75579 .46808 .75512 .46811 Mtetra
.914 .975 .783 r
.75512 .46811 .75579 .46808 .75738 .46668 .75666 .46606 Mtetra
.67 .826 .958 r
.75666 .46606 .75738 .46668 .75902 .46615 .75831 .46549 Mtetra
.511 .752 .983 r
.75831 .46549 .75902 .46615 .7607 .46596 .75999 .46538 Mtetra
.553 .794 .988 r
.75999 .46538 .7607 .46596 .76237 .46577 .76166 .46512 Mtetra
.631 .806 .966 r
.76166 .46512 .76237 .46577 .76404 .46552 .76332 .46469 Mtetra
.645 .759 .932 r
.76332 .46469 .76404 .46552 .76571 .46526 .76497 .46425 Mtetra
.652 .718 .897 r
.76497 .46425 .76571 .46526 .76737 .4649 .76663 .46379 Mtetra
.656 .702 .881 r
.76663 .46379 .76737 .4649 .76903 .46442 .76829 .46332 Mtetra
.658 .704 .881 r
.76829 .46332 .76903 .46442 .77069 .46391 .76995 .46284 Mtetra
.721 .734 .861 r
.76995 .46284 .77069 .46391 .77232 .46303 .77158 .46202 Mtetra
.723 .746 .87 r
.77158 .46202 .77232 .46303 .77395 .46217 .77322 .46119 Mtetra
.602 .709 .919 r
.77322 .46119 .77395 .46217 .77563 .46193 .77489 .46094 Mtetra
0 0 .516 r
.77489 .46094 .77563 .46193 .77753 .46457 .77677 .46318 Mtetra
.975 .678 .388 r
.77677 .46318 .77753 .46457 .79443 .66106 .79345 .65731 Mtetra
0 0 .276 r
.79345 .65731 .79443 .66106 .79675 .66771 .79591 .6658 Mtetra
.253 .374 .793 r
.79591 .6658 .79675 .66771 .79866 .66893 .79784 .66724 Mtetra
.631 .618 .819 r
.79784 .66724 .79866 .66893 .80043 .66841 .79962 .66686 Mtetra
.707 .669 .81 r
.79962 .66686 .80043 .66841 .80216 .66736 .80136 .66594 Mtetra
.704 .684 .828 r
.80136 .66594 .80216 .66736 .8039 .66645 .80311 .66509 Mtetra
.673 .681 .849 r
.80311 .66509 .8039 .66645 .80567 .66584 .80487 .66447 Mtetra
.674 .68 .848 r
.80487 .66447 .80567 .66584 .80744 .66525 .80664 .66384 Mtetra
.671 .673 .843 r
.80664 .66384 .80744 .66525 .80921 .66467 .80841 .66323 Mtetra
.667 .666 .84 r
.80841 .66323 .80921 .66467 .81098 .6641 .81018 .66264 Mtetra
.664 .661 .837 r
.81018 .66264 .81098 .6641 .81276 .66355 .81195 .66205 Mtetra
.661 .656 .834 r
.81195 .66205 .81276 .66355 .81453 .66301 .81373 .66149 Mtetra
.658 .651 .832 r
.81373 .66149 .81453 .66301 .81631 .66248 .81551 .66093 Mtetra
.655 .647 .83 r
.81551 .66093 .81631 .66248 .81809 .66196 .81729 .6604 Mtetra
.651 .643 .829 r
.81729 .6604 .81809 .66196 .81988 .66147 .81907 .65989 Mtetra
.648 .639 .828 r
.81907 .65989 .81988 .66147 .82166 .66098 .82085 .6594 Mtetra
.644 .637 .828 r
.82085 .6594 .82166 .66098 .82345 .66052 .82264 .65893 Mtetra
.639 .635 .83 r
.82264 .65893 .82345 .66052 .82525 .66007 .82444 .65849 Mtetra
.635 .634 .831 r
.82444 .65849 .82525 .66007 .82704 .65965 .82623 .65808 Mtetra
.632 .634 .834 r
.82623 .65808 .82704 .65965 .82884 .65924 .82803 .65769 Mtetra
.626 .634 .838 r
.82803 .65769 .82884 .65924 .83065 .65894 .82984 .65734 Mtetra
.623 .625 .832 r
.82984 .65734 .83065 .65894 .83246 .65869 .83164 .657 Mtetra
.629 .618 .82 r
.83164 .657 .83246 .65869 .83425 .65821 .83345 .65662 Mtetra
.652 .641 .827 r
.83345 .65662 .83425 .65821 .83598 .65697 .83524 .6561 Mtetra
.691 .783 .921 r
.83524 .6561 .83598 .65697 .83761 .65456 .83702 .65543 Mtetra
.168 0 0 r
.83702 .65543 .83761 .65456 .83913 .65107 .8388 .65473 Mtetra
.496 .206 .402 r
.8388 .65473 .83913 .65107 .84064 .64744 .84059 .65414 Mtetra
.539 .284 .477 r
.84059 .65414 .84064 .64744 .8424 .64658 .8424 .65372 Mtetra
.543 .29 .482 r
.8424 .65372 .8424 .64658 .84427 .64694 .84421 .65335 Mtetra
.539 .281 .473 r
.84421 .65335 .84427 .64694 .84614 .64719 .84602 .65295 Mtetra
.533 .27 .463 r
.84602 .65295 .84614 .64719 .84795 .64686 .84783 .65252 Mtetra
.532 .268 .46 r
.84783 .65252 .84795 .64686 .84977 .64652 .84964 .65207 Mtetra
.531 .266 .459 r
.84964 .65207 .84977 .64652 .85158 .64615 .85144 .65162 Mtetra
.529 .264 .457 r
.85144 .65162 .85158 .64615 .85339 .64574 .85325 .65115 Mtetra
.529 .263 .456 r
.85325 .65115 .85339 .64574 .8552 .6453 .85506 .65068 Mtetra
.528 .262 .455 r
.85506 .65068 .8552 .6453 .85701 .64486 .85687 .65021 Mtetra
.528 .261 .454 r
.85687 .65021 .85701 .64486 .85882 .6444 .85869 .64973 Mtetra
.527 .261 .454 r
.85869 .64973 .85882 .6444 .86063 .64393 .8605 .64925 Mtetra
.527 .26 .454 r
.8605 .64925 .86063 .64393 .86244 .64345 .86231 .64877 Mtetra
.86231 .64877 .86244 .64345 .86425 .64297 .86413 .64828 Mtetra
.527 .26 .453 r
.86413 .64828 .86425 .64297 .86606 .64247 .86594 .64779 Mtetra
.527 .26 .454 r
.86594 .64779 .86606 .64247 .86787 .64197 .86776 .6473 Mtetra
.86776 .6473 .86787 .64197 .86968 .64147 .86957 .64681 Mtetra
.86957 .64681 .86968 .64147 .87149 .64096 .87139 .64631 Mtetra
.87139 .64631 .87149 .64096 .87331 .64043 .87321 .64581 Mtetra
.527 .261 .455 r
.87321 .64581 .87331 .64043 .87512 .63991 .87503 .64531 Mtetra
.87503 .64531 .87512 .63991 .87693 .63937 .87685 .64481 Mtetra
.527 .262 .456 r
.87685 .64481 .87693 .63937 .87874 .63882 .87867 .6443 Mtetra
.527 .262 .457 r
.87867 .6443 .87874 .63882 .88056 .63827 .88049 .64379 Mtetra
.527 .263 .458 r
.88049 .64379 .88056 .63827 .88237 .6377 .88232 .64328 Mtetra
.528 .264 .458 r
.88232 .64328 .88237 .6377 .88418 .63712 .88414 .64276 Mtetra
.528 .264 .46 r
.88414 .64276 .88418 .63712 .886 .63654 .88597 .64224 Mtetra
.528 .265 .461 r
.88597 .64224 .886 .63654 .88781 .63594 .88779 .64171 Mtetra
.528 .266 .462 r
.88779 .64171 .88781 .63594 .88962 .63532 .88962 .64117 Mtetra
.529 .267 .463 r
.88962 .64117 .88962 .63532 .89143 .63469 .89144 .64064 Mtetra
.529 .269 .465 r
.89144 .64064 .89143 .63469 .89324 .63405 .89327 .64009 Mtetra
.53 .271 .466 r
.89327 .64009 .89324 .63405 .89506 .63342 .8951 .63956 Mtetra
.531 .272 .468 r
.8951 .63956 .89506 .63342 .89688 .63282 .89693 .63902 Mtetra
.532 .273 .469 r
.89693 .63902 .89688 .63282 .8987 .63224 .89876 .63849 Mtetra
.533 .274 .47 r
.89876 .63849 .8987 .63224 .90052 .6317 .90059 .63797 Mtetra
.533 .275 .47 r
.90059 .63797 .90052 .6317 .90236 .63119 .90243 .63747 Mtetra
.534 .276 .47 r
.90243 .63747 .90236 .63119 .90419 .63072 .90427 .63698 Mtetra
.535 .276 .47 r
.90427 .63698 .90419 .63072 .90604 .63032 .90611 .63651 Mtetra
.536 .276 .469 r
.90611 .63651 .90604 .63032 .90789 .63 .90796 .63607 Mtetra
.536 .275 .467 r
.90796 .63607 .90789 .63 .90976 .62972 .90981 .63564 Mtetra
.541 .278 .465 r
.90981 .63564 .90976 .62972 .91165 .62971 .91167 .63533 Mtetra
.556 .286 .462 r
.91167 .63533 .91165 .62971 .91362 .63035 .91358 .63536 Mtetra
.527 .256 .447 r
.91358 .63536 .91362 .63035 .91548 .63005 .91543 .63492 Mtetra
.445 .19 .432 r
.91543 .63492 .91548 .63005 .91707 .62733 .91714 .63325 Mtetra
.027 0 .355 r
.91714 .63325 .91707 .62733 .89682 .43344 .91819 .62573 Mtetra
.155 .068 .497 r
.91819 .62573 .89682 .43344 .89788 .42696 .89737 .42751 Mtetra
.944 .883 .476 r
.89737 .42751 .89788 .42696 .89936 .42427 .89867 .42321 Mtetra
.736 .751 .865 r
.89867 .42321 .89936 .42427 .90106 .4235 .90036 .42228 Mtetra
.619 .672 .879 r
.90036 .42228 .90106 .4235 .90281 .42315 .90212 .42197 Mtetra
.568 .656 .895 r
.90212 .42197 .90281 .42315 .90458 .42292 .9039 .42188 Mtetra
.669 .73 .895 r
.9039 .42188 .90458 .42292 .90631 .42234 .90564 .42132 Mtetra
.674 .735 .897 r
.90564 .42132 .90631 .42234 .90804 .42174 .90737 .42074 Mtetra
.695 .749 .893 r
.90737 .42074 .90804 .42174 .90976 .42104 .90909 .42006 Mtetra
.765 .777 .863 r
.90909 .42006 .90976 .42104 .91143 .41995 .91076 .41897 Mtetra
.694 .754 .898 r
.91076 .41897 .91143 .41995 .91315 .41927 .91248 .41829 Mtetra
.429 .627 .936 r
.91248 .41829 .91315 .41927 .91499 .41954 .91432 .41857 Mtetra
.789 .373 0 r
.91432 .41857 .91499 .41954 .91741 .42464 .91674 .42369 Mtetra
.973 .661 .312 r
.91674 .42369 .91741 .42464 .94335 .62335 .94266 .62245 Mtetra
.732 .291 0 r
.94266 .62245 .94335 .62335 .94579 .62762 .9451 .62671 Mtetra
.496 .694 .957 r
.9451 .62671 .94579 .62762 .94772 .62764 .94703 .62673 Mtetra
.693 .783 .92 r
.94703 .62673 .94772 .62764 .94956 .62693 .94887 .62602 Mtetra
.743 .8 .898 r
.94887 .62602 .94956 .62693 .95137 .62596 .95068 .62504 Mtetra
.494 .691 .956 r
.95068 .62504 .95137 .62596 .95331 .62599 .95262 .62507 Mtetra
.62 .752 .941 r
.95262 .62507 .95331 .62599 .95519 .6256 .9545 .62467 Mtetra
.799 .814 .864 r
.9545 .62467 .95519 .6256 .95695 .62425 .95627 .62332 Mtetra
.98 .776 .557 r
.95627 .62332 .95695 .62425 .95803 .61746 .95735 .61653 Mtetra
.975 .669 .322 r
.95735 .61653 .95803 .61746 .93469 .41757 .93403 .41659 Mtetra
.963 .784 .613 r
.93403 .41659 .93469 .41757 .93589 .41266 .93523 .41168 Mtetra
.756 .776 .87 r
.93523 .41168 .93589 .41266 .93758 .41163 .93692 .41064 Mtetra
.626 .725 .918 r
.93692 .41064 .93758 .41163 .93935 .41126 .93869 .41027 Mtetra
.545 .686 .931 r
.93869 .41027 .93935 .41126 .94117 .41119 .94051 .4102 Mtetra
.748 .774 .874 r
.94051 .4102 .94117 .41119 .94286 .41021 .94221 .40922 Mtetra
.681 .749 .902 r
.94221 .40922 .94286 .41021 .94461 .40959 .94396 .4086 Mtetra
.488 .656 .934 r
.94396 .4086 .94461 .40959 .94645 .4097 .9458 .40871 Mtetra
.738 .32 0 r
.9458 .40871 .94645 .4097 .94891 .41449 .94826 .41349 Mtetra
.97 .655 .291 r
.94826 .41349 .94891 .41449 .977 .61406 .97632 .61313 Mtetra
.739 .309 0 r
.97632 .61313 .977 .61406 .97958 .61882 .9789 .61789 Mtetra
.031 .462 .877 r
.36978 .78056 .37071 .78131 .37218 .78194 .37126 .78118 Mtetra
.643 .761 .935 r
.37126 .78118 .37218 .78194 .37371 .78154 .37278 .78079 Mtetra
.809 .778 .824 r
.37278 .78079 .37371 .78154 .37527 .78013 .37434 .77937 Mtetra
.908 .738 .659 r
.37434 .77937 .37527 .78013 .37699 .77494 .37607 .77417 Mtetra
.937 .686 .534 r
.37607 .77417 .37699 .77494 .38623 .58501 .38536 .58418 Mtetra
.908 .726 .644 r
.38536 .58418 .38623 .58501 .38789 .5793 .38702 .57847 Mtetra
.775 .757 .837 r
.38702 .57847 .38789 .5793 .38936 .57821 .38849 .57738 Mtetra
.637 .73 .916 r
.38849 .57738 .38936 .57821 .3908 .57788 .38993 .57704 Mtetra
.503 .681 .946 r
.38993 .57704 .3908 .57788 .39222 .57791 .39136 .57706 Mtetra
.743 .749 .857 r
.39136 .57706 .39222 .57791 .39368 .57711 .39282 .5762 Mtetra
.691 .729 .879 r
.39282 .5762 .39368 .57711 .39514 .57656 .39427 .57563 Mtetra
.482 .652 .934 r
.39427 .57563 .39514 .57656 .39656 .57662 .3957 .57574 Mtetra
.936 .57 .281 r
.3957 .57574 .39656 .57662 .39786 .58029 .39696 .58022 Mtetra
.938 .682 .523 r
.39696 .58022 .39786 .58029 .39234 .7687 .39135 .76997 Mtetra
.839 .515 .44 r
.39135 .76997 .39234 .7687 .39365 .77428 .39269 .77456 Mtetra
.38 0 0 r
.39269 .77456 .39365 .77428 .39515 .77494 .39421 .77478 Mtetra
.658 .924 .974 r
.39421 .77478 .39515 .77494 .39668 .77469 .39575 .77412 Mtetra
.782 .826 .886 r
.39575 .77412 .39668 .77469 .39822 .77399 .39731 .77307 Mtetra
.659 .728 .9 r
.39731 .77307 .39822 .77399 .39977 .77331 .39885 .77262 Mtetra
.611 .771 .957 r
.39885 .77262 .39977 .77331 .40132 .77255 .40039 .7723 Mtetra
.484 .849 .99 r
.40039 .7723 .40132 .77255 .40287 .77178 .40192 .772 Mtetra
0 0 0 r
.40192 .772 .40287 .77178 .40441 .77129 .40346 .77165 Mtetra
.40346 .77165 .40441 .77129 .40595 .77092 .405 .77128 Mtetra
.405 .77128 .40595 .77092 .40749 .77058 .40654 .77089 Mtetra
.178 0 0 r
.40654 .77089 .40749 .77058 .40902 .77064 .40807 .77081 Mtetra
0 0 0 r
.40807 .77081 .40902 .77064 .41056 .77041 .40961 .77054 Mtetra
.588 .945 .903 r
.40961 .77054 .41056 .77041 .41212 .76948 .41117 .76977 Mtetra
.956 .897 .726 r
.41117 .76977 .41212 .76948 .4138 .76448 .4128 .76671 Mtetra
.999 .834 .53 r
.4128 .76671 .4138 .76448 .42114 .57435 .41461 .75767 Mtetra
0 0 .334 r
.41461 .75767 .42114 .57435 .42276 .56872 .42178 .57181 Mtetra
.257 0 .284 r
.42178 .57181 .42276 .56872 .42425 .56735 .42329 .57 Mtetra
.497 .182 .363 r
.42329 .57 .42425 .56735 .42572 .56692 .42475 .5697 Mtetra
.535 .224 .387 r
.42475 .5697 .42572 .56692 .42717 .56686 .42621 .56967 Mtetra
.241 0 .259 r
.42621 .56967 .42717 .56686 .42863 .56654 .42771 .56797 Mtetra
0 0 0 r
.42771 .56797 .42863 .56654 .4301 .56614 .42922 .56615 Mtetra
.861 .954 .87 r
.42922 .56615 .4301 .56614 .43156 .56573 .43071 .56472 Mtetra
.702 .714 .858 r
.43071 .56472 .43156 .56573 .43303 .5653 .43218 .56407 Mtetra
.632 .652 .852 r
.43218 .56407 .43303 .5653 .4345 .56485 .43365 .56375 Mtetra
.603 .664 .882 r
.43365 .56375 .4345 .56485 .43597 .56439 .43511 .56355 Mtetra
.64 .733 .916 r
.43511 .56355 .43597 .56439 .43744 .56389 .43658 .56319 Mtetra
.661 .774 .933 r
.43658 .56319 .43744 .56389 .43891 .5634 .43805 .56274 Mtetra
.671 .789 .937 r
.43805 .56274 .43891 .5634 .44038 .56295 .43953 .56225 Mtetra
.747 .788 .886 r
.43953 .56225 .44038 .56295 .44186 .56234 .44101 .56142 Mtetra
.718 .734 .864 r
.44101 .56142 .44186 .56234 .44333 .56194 .44249 .56069 Mtetra
.626 .646 .85 r
.44249 .56069 .44333 .56194 .44479 .56214 .44396 .5604 Mtetra
0 .194 .715 r
.44396 .5604 .44479 .56214 .44618 .56552 .44539 .56204 Mtetra
.783 .509 0 r
.44539 .56204 .44618 .56552 .44332 .75504 .4467 .56858 Mtetra
0 0 .362 r
.4467 .56858 .44332 .75504 .44475 .7607 .44395 .75539 Mtetra
.455 .349 .645 r
.44395 .75539 .44475 .7607 .44628 .76159 .44546 .75701 Mtetra
.609 .468 .664 r
.44546 .75701 .44628 .76159 .44784 .76126 .44703 .75654 Mtetra
.627 .478 .66 r
.44703 .75654 .44784 .76126 .44942 .7605 .4486 .75575 Mtetra
.523 .406 .661 r
.4486 .75575 .44942 .7605 .45099 .75998 .45014 .75649 Mtetra
.452 .389 .697 r
.45014 .75649 .45099 .75998 .45255 .75958 .45168 .75758 Mtetra
.419 .459 .795 r
.45168 .75758 .45255 .75958 .45412 .75912 .45322 .7583 Mtetra
.366 .64 .96 r
.45322 .7583 .45412 .75912 .45569 .75884 .45478 .75856 Mtetra
.426 .82 .985 r
.45478 .75856 .45569 .75884 .45726 .75838 .45635 .75835 Mtetra
.652 .95 .952 r
.45635 .75835 .45726 .75838 .45884 .75735 .45793 .75758 Mtetra
.934 .942 .776 r
.45793 .75758 .45884 .75735 .46048 .7535 .45953 .75523 Mtetra
.98 .886 .53 r
.45953 .75523 .46048 .7535 .46537 .56388 .4612 .74953 Mtetra
0 0 .354 r
.4612 .74953 .46537 .56388 .46699 .55599 .46606 .5603 Mtetra
0 0 .168 r
.46606 .5603 .46699 .55599 .4685 .55409 .46762 .55567 Mtetra
0 0 0 r
.46762 .55567 .4685 .55409 .46999 .55355 .46913 .55374 Mtetra
.773 .995 .871 r
.46913 .55374 .46999 .55355 .47147 .55344 .47063 .55254 Mtetra
.72 .743 .869 r
.47063 .55254 .47147 .55344 .47296 .55319 .47213 .5518 Mtetra
.654 .64 .823 r
.47213 .5518 .47296 .55319 .47445 .55279 .47362 .55135 Mtetra
.625 .621 .826 r
.47362 .55135 .47445 .55279 .47594 .55238 .47511 .55107 Mtetra
.625 .637 .843 r
.47511 .55107 .47594 .55238 .47743 .55194 .4766 .55078 Mtetra
.63 .665 .865 r
.4766 .55078 .47743 .55194 .47893 .55147 .47809 .55047 Mtetra
.631 .696 .892 r
.47809 .55047 .47893 .55147 .48042 .55099 .47958 .55015 Mtetra
.643 .738 .918 r
.47958 .55015 .48042 .55099 .48192 .55047 .48108 .54977 Mtetra
.657 .776 .936 r
.48108 .54977 .48192 .55047 .48341 .54996 .48257 .54933 Mtetra
.67 .797 .942 r
.48257 .54933 .48341 .54996 .48491 .54949 .48407 .54883 Mtetra
.695 .795 .927 r
.48407 .54883 .48491 .54949 .4864 .54915 .48557 .54824 Mtetra
.702 .738 .879 r
.48557 .54824 .4864 .54915 .4879 .5489 .48707 .5476 Mtetra
.686 .665 .824 r
.48707 .5476 .4879 .5489 .48939 .54866 .48857 .54697 Mtetra
.687 .62 .776 r
.48857 .54697 .48939 .54866 .4909 .54801 .49007 .5462 Mtetra
.675 .605 .77 r
.49007 .5462 .4909 .54801 .4924 .54724 .49157 .5455 Mtetra
.623 .586 .792 r
.49157 .5455 .4924 .54724 .4939 .547 .49307 .54521 Mtetra
.238 .362 .787 r
.49307 .54521 .4939 .547 .49538 .54913 .49456 .54638 Mtetra
0 0 .224 r
.49456 .54638 .49538 .54913 .49532 .73728 .49602 .55117 Mtetra
0 0 .381 r
.49602 .55117 .49532 .73728 .49683 .74591 .49599 .73991 Mtetra
.343 .262 .618 r
.49599 .73991 .49683 .74591 .49841 .74744 .49756 .74301 Mtetra
.59 .459 .67 r
.49756 .74301 .49841 .74744 .50001 .74719 .49915 .74285 Mtetra
.639 .492 .668 r
.49915 .74285 .50001 .74719 .5016 .74646 .50075 .74192 Mtetra
.63 .483 .664 r
.50075 .74192 .5016 .74646 .5032 .74583 .50235 .74111 Mtetra
.607 .465 .662 r
.50235 .74111 .5032 .74583 .5048 .74543 .50394 .74068 Mtetra
.606 .464 .662 r
.50394 .74068 .5048 .74543 .5064 .74502 .50554 .74024 Mtetra
.606 .463 .661 r
.50554 .74024 .5064 .74502 .508 .74461 .50714 .7398 Mtetra
.605 .462 .661 r
.50714 .7398 .508 .74461 .5096 .74419 .50874 .73938 Mtetra
.50874 .73938 .5096 .74419 .5112 .74377 .51034 .73896 Mtetra
.51034 .73896 .5112 .74377 .5128 .74334 .51194 .73854 Mtetra
.51194 .73854 .5128 .74334 .51441 .74292 .51354 .73811 Mtetra
.51354 .73811 .51441 .74292 .51601 .7425 .51515 .73769 Mtetra
.51515 .73769 .51601 .7425 .51762 .74207 .51675 .73726 Mtetra
.51675 .73726 .51762 .74207 .51922 .74164 .51836 .73683 Mtetra
.605 .463 .661 r
.51836 .73683 .51922 .74164 .52083 .74121 .51996 .7364 Mtetra
.606 .463 .661 r
.51996 .7364 .52083 .74121 .52244 .74078 .52157 .73597 Mtetra
.52157 .73597 .52244 .74078 .52405 .74035 .52318 .73554 Mtetra
.52318 .73554 .52405 .74035 .52566 .73991 .52479 .7351 Mtetra
.52479 .7351 .52566 .73991 .52727 .73948 .5264 .73466 Mtetra
.5264 .73466 .52727 .73948 .52888 .73904 .52801 .73422 Mtetra
.52801 .73422 .52888 .73904 .53049 .7386 .52962 .73377 Mtetra
.606 .463 .66 r
.52962 .73377 .53049 .7386 .53211 .73816 .53123 .73332 Mtetra
.607 .463 .66 r
.53123 .73332 .53211 .73816 .53372 .73772 .53285 .73287 Mtetra
.53285 .73287 .53372 .73772 .53534 .73727 .53446 .73241 Mtetra
.53446 .73241 .53534 .73727 .53696 .73683 .53608 .73194 Mtetra
.608 .463 .659 r
.53608 .73194 .53696 .73683 .53857 .73638 .53769 .73146 Mtetra
.53769 .73146 .53857 .73638 .54019 .73592 .53931 .73098 Mtetra
.615 .467 .658 r
.53931 .73098 .54019 .73592 .54181 .73547 .54093 .73037 Mtetra
.62 .469 .655 r
.54093 .73037 .54181 .73547 .54343 .735 .54254 .72963 Mtetra
.599 .45 .651 r
.54254 .72963 .54343 .735 .54505 .73454 .54416 .72926 Mtetra
.541 .412 .653 r
.54416 .72926 .54505 .73454 .54668 .73411 .54579 .72984 Mtetra
.466 .379 .674 r
.54579 .72984 .54668 .73411 .5483 .73369 .54742 .7311 Mtetra
.434 .423 .748 r
.54742 .7311 .5483 .73369 .54992 .73325 .54906 .73203 Mtetra
.424 .576 .9 r
.54906 .73203 .54992 .73325 .55155 .73269 .55069 .7324 Mtetra
.412 .812 .983 r
.55069 .7324 .55155 .73269 .55317 .73199 .55232 .7322 Mtetra
0 0 0 r
.55232 .7322 .55317 .73199 .5548 .73127 .55395 .73184 Mtetra
.104 0 0 r
.55395 .73184 .5548 .73127 .55642 .73066 .55558 .73142 Mtetra
.226 0 0 r
.55558 .73142 .55642 .73066 .55805 .73024 .55721 .73104 Mtetra
.219 0 0 r
.55721 .73104 .55805 .73024 .55968 .72987 .55884 .73061 Mtetra
.23 0 0 r
.55884 .73061 .55968 .72987 .56132 .72967 .56047 .73025 Mtetra
.204 0 0 r
.56047 .73025 .56132 .72967 .56295 .72965 .56211 .72998 Mtetra
0 0 0 r
.56211 .72998 .56295 .72965 .56458 .72913 .56374 .72938 Mtetra
.812 1 .829 r
.56374 .72938 .56458 .72913 .5662 .72706 .56536 .72783 Mtetra
.979 .915 .618 r
.56536 .72783 .5662 .72706 .56772 .71738 .56695 .72378 Mtetra
.968 .701 .474 r
.56695 .72378 .56772 .71738 .56697 .52724 .56631 .53848 Mtetra
0 0 .319 r
.56631 .53848 .56697 .52724 .56847 .52385 .56771 .52627 Mtetra
0 0 .128 r
.56771 .52627 .56847 .52385 .57001 .52307 .56923 .5238 Mtetra
0 0 0 r
.56923 .5238 .57001 .52307 .57156 .52285 .57076 .52238 Mtetra
.747 .863 .933 r
.57076 .52238 .57156 .52285 .57311 .5228 .5723 .52155 Mtetra
.637 .657 .853 r
.5723 .52155 .57311 .5228 .57466 .52247 .57385 .52119 Mtetra
.587 .631 .862 r
.57385 .52119 .57466 .52247 .57621 .52217 .5754 .52106 Mtetra
.568 .654 .895 r
.5754 .52106 .57621 .52217 .57776 .52187 .57695 .52098 Mtetra
.612 .72 .922 r
.57695 .52098 .57776 .52187 .57931 .52155 .57851 .5207 Mtetra
.615 .732 .929 r
.57851 .5207 .57931 .52155 .58086 .52122 .58006 .5204 Mtetra
.617 .739 .934 r
.58006 .5204 .58086 .52122 .58241 .52089 .58161 .52009 Mtetra
.615 .746 .939 r
.58161 .52009 .58241 .52089 .58397 .52054 .58317 .51978 Mtetra
.616 .758 .946 r
.58317 .51978 .58397 .52054 .58552 .52017 .58472 .51946 Mtetra
.616 .77 .953 r
.58472 .51946 .58552 .52017 .58708 .51979 .58628 .51913 Mtetra
.616 .782 .961 r
.58628 .51913 .58708 .51979 .58863 .51939 .58784 .51878 Mtetra
.621 .798 .967 r
.58784 .51878 .58863 .51939 .59019 .51898 .5894 .5184 Mtetra
.633 .813 .969 r
.5894 .5184 .59019 .51898 .59175 .51854 .59095 .51798 Mtetra
.656 .823 .964 r
.59095 .51798 .59175 .51854 .5933 .51808 .59251 .51748 Mtetra
.668 .818 .955 r
.59251 .51748 .5933 .51808 .59486 .51759 .59407 .51695 Mtetra
.676 .807 .945 r
.59407 .51695 .59486 .51759 .59642 .5171 .59563 .51641 Mtetra
.677 .793 .936 r
.59563 .51641 .59642 .5171 .59798 .5166 .59718 .51587 Mtetra
.68 .782 .927 r
.59718 .51587 .59798 .5166 .59954 .5161 .59874 .51532 Mtetra
.681 .771 .919 r
.59874 .51532 .59954 .5161 .6011 .51559 .6003 .51476 Mtetra
.681 .761 .912 r
.6003 .51476 .6011 .51559 .60266 .51507 .60187 .51421 Mtetra
.682 .752 .905 r
.60187 .51421 .60266 .51507 .60422 .51455 .60343 .51366 Mtetra
.683 .745 .898 r
.60343 .51366 .60422 .51455 .60578 .51402 .60499 .51309 Mtetra
.685 .737 .89 r
.60499 .51309 .60578 .51402 .60735 .51348 .60655 .51251 Mtetra
.687 .729 .882 r
.60655 .51251 .60735 .51348 .60891 .51293 .60812 .51192 Mtetra
.687 .722 .876 r
.60812 .51192 .60891 .51293 .61047 .51236 .60968 .51132 Mtetra
.687 .715 .871 r
.60968 .51132 .61047 .51236 .61204 .51178 .61124 .51072 Mtetra
.69 .715 .867 r
.61124 .51072 .61204 .51178 .6136 .51117 .61281 .5101 Mtetra
.701 .715 .86 r
.61281 .5101 .6136 .51117 .61517 .51055 .61437 .50942 Mtetra
.729 .713 .835 r
.61437 .50942 .61517 .51055 .61673 .5099 .61593 .50853 Mtetra
.696 .666 .817 r
.61593 .50853 .61673 .5099 .6183 .50926 .61749 .50779 Mtetra
.648 .633 .822 r
.61749 .50779 .6183 .50926 .61987 .5086 .61907 .50735 Mtetra
.511 .603 .882 r
.61907 .50735 .61987 .5086 .62142 .50765 .62066 .5075 Mtetra
.496 0 0 r
.62066 .5075 .62142 .50765 .62299 .50711 .62227 .50836 Mtetra
.786 .413 .35 r
.62227 .50836 .62299 .50711 .62459 .50747 .62394 .51104 Mtetra
.958 .678 .464 r
.62394 .51104 .62459 .50747 .62634 .51275 .63129 .70166 Mtetra
.579 .367 .557 r
.63129 .70166 .62634 .51275 .6339 .70568 .63316 .7079 Mtetra
.711 .367 .393 r
.63316 .7079 .6339 .70568 .63571 .70976 .63492 .70998 Mtetra
.218 0 0 r
.63492 .70998 .63571 .70976 .63741 .70988 .63661 .71004 Mtetra
.208 .73 .729 r
.63661 .71004 .63741 .70988 .63908 .70932 .63829 .70962 Mtetra
0 0 0 r
.63829 .70962 .63908 .70932 .64075 .70846 .63996 .709 Mtetra
.278 0 0 r
.63996 .709 .64075 .70846 .64244 .70845 .64165 .70888 Mtetra
.027 0 0 r
.64165 .70888 .64244 .70845 .64412 .70804 .64334 .70846 Mtetra
.405 .827 .653 r
.64334 .70846 .64412 .70804 .64577 .7068 .645 .70747 Mtetra
.944 .947 .627 r
.645 .70747 .64577 .7068 .64726 .70079 .64659 .70419 Mtetra
.81 .739 .215 r
.64659 .70419 .64726 .70079 .64211 .50636 .64799 .69573 Mtetra
.042 0 .432 r
.64799 .69573 .64211 .50636 .64353 .5012 .6429 .50431 Mtetra
.044 0 .224 r
.6429 .50431 .64353 .5012 .6451 .50013 .64439 .50118 Mtetra
0 0 0 r
.64439 .50118 .6451 .50013 .64669 .49971 .64593 .49947 Mtetra
.786 .94 .928 r
.64593 .49947 .64669 .49971 .64829 .49963 .6475 .49841 Mtetra
.672 .68 .849 r
.6475 .49841 .64829 .49963 .64988 .49916 .64908 .49786 Mtetra
.628 .65 .852 r
.64908 .49786 .64988 .49916 .65146 .49869 .65068 .49754 Mtetra
.603 .665 .883 r
.65068 .49754 .65146 .49869 .65305 .49821 .65228 .49732 Mtetra
.731 .762 .877 r
.65228 .49732 .65305 .49821 .65463 .49722 .65386 .4965 Mtetra
.688 .791 .929 r
.65386 .4965 .65463 .49722 .65621 .49659 .65545 .4959 Mtetra
.516 .742 .977 r
.65545 .4959 .65621 .49659 .65782 .49663 .65705 .4958 Mtetra
.68 .197 0 r
.65705 .4958 .65782 .49663 .65961 .50101 .65876 .49812 Mtetra
.953 .637 .215 r
.65876 .49812 .65961 .50101 .66921 .69556 .66092 .51152 Mtetra
.061 0 .448 r
.66092 .51152 .66921 .69556 .67113 .7005 .67015 .69561 Mtetra
.428 .344 .659 r
.67015 .69561 .67113 .7005 .67286 .70083 .67194 .69755 Mtetra
.503 .436 .714 r
.67194 .69755 .67286 .70083 .67456 .70032 .67369 .69826 Mtetra
.545 .532 .791 r
.67369 .69826 .67456 .70032 .67624 .69938 .67542 .69844 Mtetra
.376 .616 .945 r
.67542 .69844 .67624 .69938 .67795 .69915 .67715 .69878 Mtetra
.425 .804 .992 r
.67715 .69878 .67795 .69915 .67964 .69863 .67887 .6986 Mtetra
.665 .966 .922 r
.67887 .6986 .67964 .69863 .68131 .69743 .68055 .69767 Mtetra
.988 .875 .629 r
.68055 .69767 .68131 .69743 .68281 .69233 .68208 .69325 Mtetra
.971 .692 .445 r
.68208 .69325 .68281 .69233 .67569 .4977 .67501 .49861 Mtetra
1 .817 .501 r
.67501 .49861 .67569 .4977 .67704 .49153 .67627 .49063 Mtetra
.804 .778 .828 r
.67627 .49063 .67704 .49153 .67861 .49027 .67784 .48927 Mtetra
.636 .71 .9 r
.67784 .48927 .67861 .49027 .68022 .4899 .67945 .4889 Mtetra
.51 .656 .925 r
.67945 .4889 .68022 .4899 .68185 .48991 .68108 .48896 Mtetra
.647 .724 .905 r
.68108 .48896 .68185 .48991 .68346 .48948 .68269 .48853 Mtetra
.67 .735 .899 r
.68269 .48853 .68346 .48948 .68506 .48895 .6843 .48802 Mtetra
.675 .74 .899 r
.6843 .48802 .68506 .48895 .68667 .48839 .68591 .48747 Mtetra
.763 .767 .856 r
.68591 .48747 .68667 .48839 .68825 .48735 .68749 .48643 Mtetra
.72 .758 .882 r
.68749 .48643 .68825 .48735 .68985 .48657 .68909 .48566 Mtetra
.554 .698 .936 r
.68909 .48566 .68985 .48657 .69148 .48647 .69072 .48556 Mtetra
.832 .395 0 r
.69072 .48556 .69148 .48647 .6933 .49012 .69254 .48922 Mtetra
.97 .683 .428 r
.69254 .48922 .6933 .49012 .70494 .68489 .70414 .68406 Mtetra
.914 .515 .136 r
.70414 .68406 .70494 .68489 .70697 .6905 .70617 .68966 Mtetra
0 .39 .842 r
.70617 .68966 .70697 .6905 .70876 .69148 .70797 .69064 Mtetra
.605 .75 .946 r
.70797 .69064 .70876 .69148 .71049 .69116 .70969 .69032 Mtetra
.8 .802 .853 r
.70969 .69032 .71049 .69116 .71217 .68982 .71137 .68899 Mtetra
.937 .778 .659 r
.71137 .68899 .71217 .68982 .71367 .68524 .71288 .68448 Mtetra
.971 .689 .438 r
.71288 .68448 .71367 .68524 .70478 .48952 .70404 .48892 Mtetra
.966 .761 .575 r
.70404 .48892 .70478 .48952 .70604 .48239 .70529 .48158 Mtetra
.835 .8 .818 r
.70529 .48158 .70604 .48239 .70761 .48082 .70685 .47997 Mtetra
.656 .755 .923 r
.70685 .47997 .70761 .48082 .70923 .48038 .70848 .47951 Mtetra
.527 .695 .946 r
.70848 .47951 .70923 .48038 .71088 .48037 .71013 .47946 Mtetra
.716 .76 .887 r
.71013 .47946 .71088 .48037 .71249 .47968 .71174 .47872 Mtetra
.701 .743 .884 r
.71174 .47872 .71249 .47968 .71411 .47903 .71335 .47804 Mtetra
.545 .674 .923 r
.71335 .47804 .71411 .47903 .71576 .47895 .715 .47799 Mtetra
.785 .343 0 r
.715 .47799 .71576 .47895 .71758 .48179 .71686 .48143 Mtetra
.971 .681 .419 r
.71686 .48143 .71758 .48179 .7306 .67509 .72999 .67714 Mtetra
.842 .498 .404 r
.72999 .67714 .7306 .67509 .7328 .68258 .73209 .68291 Mtetra
.564 .019 0 r
.73209 .68291 .7328 .68258 .73463 .68369 .7339 .6837 Mtetra
.403 .857 .872 r
.7339 .6837 .73463 .68369 .73638 .68349 .73563 .68316 Mtetra
.791 .932 .925 r
.73563 .68316 .73638 .68349 .73811 .68284 .73732 .68199 Mtetra
.82 .806 .838 r
.73732 .68199 .73811 .68284 .73984 .68231 .739 .68048 Mtetra
.775 .667 .744 r
.739 .68048 .73984 .68231 .74158 .68181 .74065 .67864 Mtetra
.729 .578 .685 r
.74065 .67864 .74158 .68181 .74332 .68129 .74229 .6765 Mtetra
.65 .494 .659 r
.74229 .6765 .74332 .68129 .74506 .68081 .74398 .6752 Mtetra
.603 .452 .65 r
.74398 .6752 .74506 .68081 .7468 .68036 .74572 .67472 Mtetra
.586 .441 .65 r
.74572 .67472 .7468 .68036 .74855 .6799 .74748 .67455 Mtetra
.609 .46 .654 r
.74748 .67455 .74855 .6799 .75029 .67944 .74921 .67397 Mtetra
.61 .459 .651 r
.74921 .67397 .75029 .67944 .75204 .67898 .75095 .67336 Mtetra
.586 .441 .651 r
.75095 .67336 .75204 .67898 .75378 .67851 .75271 .6732 Mtetra
.513 .396 .657 r
.75271 .6732 .75378 .67851 .75553 .67809 .75456 .67426 Mtetra
.47 .399 .694 r
.75456 .67426 .75553 .67809 .75729 .67766 .75642 .67545 Mtetra
.448 .465 .784 r
.75642 .67545 .75729 .67766 .75903 .67718 .75825 .67622 Mtetra
.418 .635 .945 r
.75825 .67622 .75903 .67718 .7608 .67686 .76005 .67648 Mtetra
.453 .818 .995 r
.76005 .67648 .7608 .67686 .76255 .67638 .76182 .67625 Mtetra
.627 .945 .948 r
.76182 .67625 .76255 .67638 .76426 .67531 .76355 .67545 Mtetra
.934 .968 .734 r
.76355 .67545 .76426 .67531 .76578 .67144 .76517 .67293 Mtetra
.928 .836 .387 r
.76517 .67293 .76578 .67144 .75404 .47671 .76652 .66671 Mtetra
.094 .013 .463 r
.76652 .66671 .75404 .47671 .75512 .46811 .75475 .47242 Mtetra
.223 .008 .362 r
.75475 .47242 .75512 .46811 .75666 .46606 .7562 .46898 Mtetra
.489 .183 .374 r
.7562 .46898 .75666 .46606 .75831 .46549 .75786 .46851 Mtetra
.538 .229 .392 r
.75786 .46851 .75831 .46549 .75999 .46538 .75954 .4685 Mtetra
.369 .09 .353 r
.75954 .4685 .75999 .46538 .76166 .46512 .76113 .46698 Mtetra
.028 0 .113 r
.76113 .46698 .76166 .46512 .76332 .46469 .76267 .46489 Mtetra
.81 .997 .776 r
.76267 .46489 .76332 .46469 .76497 .46425 .76424 .46322 Mtetra
.736 .746 .86 r
.76424 .46322 .76497 .46425 .76663 .46379 .76586 .46232 Mtetra
.64 .635 .83 r
.76586 .46232 .76663 .46379 .76829 .46332 .76752 .46191 Mtetra
.612 .631 .846 r
.76752 .46191 .76829 .46332 .76995 .46284 .7692 .46166 Mtetra
.679 .697 .86 r
.7692 .46166 .76995 .46284 .77158 .46202 .77085 .46106 Mtetra
.709 .752 .886 r
.77085 .46106 .77158 .46202 .77322 .46119 .77249 .46033 Mtetra
.617 .741 .934 r
.77249 .46033 .77322 .46119 .77489 .46094 .77417 .45999 Mtetra
0 .338 .818 r
.77417 .45999 .77489 .46094 .77677 .46318 .77596 .46118 Mtetra
.664 .326 0 r
.77596 .46118 .77677 .46318 .79345 .65731 .77806 .46644 Mtetra
.114 .034 .479 r
.77806 .46644 .79345 .65731 .79591 .6658 .79475 .65971 Mtetra
.339 .269 .63 r
.79475 .65971 .79591 .6658 .79784 .66724 .79685 .66343 Mtetra
.484 .409 .696 r
.79685 .66343 .79784 .66724 .79962 .66686 .79874 .66449 Mtetra
.535 .506 .77 r
.79874 .66449 .79962 .66686 .80136 .66594 .80058 .6648 Mtetra
.604 .688 .901 r
.80058 .6648 .80136 .66594 .80311 .66509 .80237 .66453 Mtetra
.676 .859 .969 r
.80237 .66453 .80311 .66509 .80487 .66447 .80414 .66387 Mtetra
.73 .86 .942 r
.80414 .66387 .80487 .66447 .80664 .66384 .80589 .663 Mtetra
.714 .795 .915 r
.80589 .663 .80664 .66384 .80841 .66323 .80764 .66222 Mtetra
.681 .746 .901 r
.80764 .66222 .80841 .66323 .81018 .66264 .80941 .66159 Mtetra
.674 .737 .898 r
.80941 .66159 .81018 .66264 .81195 .66205 .81118 .661 Mtetra
.673 .734 .896 r
.81118 .661 .81195 .66205 .81373 .66149 .81296 .66041 Mtetra
.672 .729 .893 r
.81296 .66041 .81373 .66149 .81551 .66093 .81473 .65982 Mtetra
.667 .721 .889 r
.81473 .65982 .81551 .66093 .81729 .6604 .81651 .65926 Mtetra
.661 .713 .887 r
.81651 .65926 .81729 .6604 .81907 .65989 .81829 .65873 Mtetra
.655 .707 .885 r
.81829 .65873 .81907 .65989 .82085 .6594 .82008 .65822 Mtetra
.648 .702 .886 r
.82008 .65822 .82085 .6594 .82264 .65893 .82187 .65775 Mtetra
.642 .699 .887 r
.82187 .65775 .82264 .65893 .82444 .65849 .82366 .65732 Mtetra
.635 .696 .889 r
.82366 .65732 .82444 .65849 .82623 .65808 .82546 .65691 Mtetra
.625 .692 .892 r
.82546 .65691 .82623 .65808 .82803 .65769 .82726 .65655 Mtetra
.608 .691 .902 r
.82726 .65655 .82803 .65769 .82984 .65734 .82907 .65627 Mtetra
.588 .697 .918 r
.82907 .65627 .82984 .65734 .83164 .657 .83089 .65605 Mtetra
.574 .717 .94 r
.83089 .65605 .83164 .657 .83345 .65662 .83271 .65585 Mtetra
.55 .753 .972 r
.83271 .65585 .83345 .65662 .83524 .6561 .83454 .65565 Mtetra
.466 .809 .999 r
.83454 .65565 .83524 .6561 .83702 .65543 .83636 .65544 Mtetra
.164 .703 .777 r
.83636 .65544 .83702 .65543 .8388 .65473 .83818 .65519 Mtetra
.142 0 0 r
.83818 .65519 .8388 .65473 .84059 .65414 .83999 .65487 Mtetra
.236 0 0 r
.83999 .65487 .84059 .65414 .8424 .65372 .8418 .65447 Mtetra
.231 0 0 r
.8418 .65447 .8424 .65372 .84421 .65335 .84361 .65404 Mtetra
.203 0 0 r
.84361 .65404 .84421 .65335 .84602 .65295 .84542 .65359 Mtetra
.177 0 0 r
.84542 .65359 .84602 .65295 .84783 .65252 .84723 .65315 Mtetra
.167 0 0 r
.84723 .65315 .84783 .65252 .84964 .65207 .84904 .65269 Mtetra
.158 0 0 r
.84904 .65269 .84964 .65207 .85144 .65162 .85085 .65223 Mtetra
.151 0 0 r
.85085 .65223 .85144 .65162 .85325 .65115 .85266 .65176 Mtetra
.146 0 0 r
.85266 .65176 .85325 .65115 .85506 .65068 .85447 .65128 Mtetra
.142 0 0 r
.85447 .65128 .85506 .65068 .85687 .65021 .85628 .6508 Mtetra
.139 0 0 r
.85628 .6508 .85687 .65021 .85869 .64973 .8581 .65032 Mtetra
.137 0 0 r
.8581 .65032 .85869 .64973 .8605 .64925 .85991 .64984 Mtetra
.135 0 0 r
.85991 .64984 .8605 .64925 .86231 .64877 .86172 .64936 Mtetra
.134 0 0 r
.86172 .64936 .86231 .64877 .86413 .64828 .86354 .64887 Mtetra
.133 0 0 r
.86354 .64887 .86413 .64828 .86594 .64779 .86536 .64838 Mtetra
.86536 .64838 .86594 .64779 .86776 .6473 .86717 .64789 Mtetra
.86717 .64789 .86776 .6473 .86957 .64681 .86899 .6474 Mtetra
.86899 .6474 .86957 .64681 .87139 .64631 .87081 .64691 Mtetra
.87081 .64691 .87139 .64631 .87321 .64581 .87263 .64641 Mtetra
.134 0 0 r
.87263 .64641 .87321 .64581 .87503 .64531 .87446 .64591 Mtetra
.135 0 0 r
.87446 .64591 .87503 .64531 .87685 .64481 .87628 .64541 Mtetra
.87628 .64541 .87685 .64481 .87867 .6443 .8781 .64491 Mtetra
.136 0 0 r
.8781 .64491 .87867 .6443 .88049 .64379 .87993 .6444 Mtetra
.137 0 0 r
.87993 .6444 .88049 .64379 .88232 .64328 .88175 .64389 Mtetra
.138 0 0 r
.88175 .64389 .88232 .64328 .88414 .64276 .88358 .64338 Mtetra
.143 0 0 r
.88358 .64338 .88414 .64276 .88597 .64224 .8854 .64287 Mtetra
.141 0 0 r
.8854 .64287 .88597 .64224 .88779 .64171 .88723 .64234 Mtetra
.118 0 0 r
.88723 .64234 .88779 .64171 .88962 .64117 .88905 .64176 Mtetra
.056 0 0 r
.88905 .64176 .88962 .64117 .89144 .64064 .89087 .64111 Mtetra
0 0 0 r
.89087 .64111 .89144 .64064 .89327 .64009 .89268 .64045 Mtetra
.89268 .64045 .89327 .64009 .8951 .63956 .8945 .63981 Mtetra
.8945 .63981 .8951 .63956 .89693 .63902 .89633 .63926 Mtetra
.89633 .63926 .89693 .63902 .89876 .63849 .89817 .63873 Mtetra
.89817 .63873 .89876 .63849 .90059 .63797 .9 .63821 Mtetra
.9 .63821 .90059 .63797 .90243 .63747 .90184 .63769 Mtetra
.90184 .63769 .90243 .63747 .90427 .63698 .90368 .63718 Mtetra
.90368 .63718 .90427 .63698 .90611 .63651 .90552 .6367 Mtetra
.90552 .6367 .90611 .63651 .90796 .63607 .90737 .63625 Mtetra
.90737 .63625 .90796 .63607 .90981 .63564 .90922 .63581 Mtetra
.90922 .63581 .90981 .63564 .91167 .63533 .91108 .63549 Mtetra
.128 0 0 r
.91108 .63549 .91167 .63533 .91358 .63536 .91298 .63549 Mtetra
.179 .707 .7 r
.91298 .63549 .91358 .63536 .91543 .63492 .91484 .63504 Mtetra
.761 .991 .779 r
.91484 .63504 .91543 .63492 .91714 .63325 .91656 .6334 Mtetra
.999 .821 .488 r
.91656 .6334 .91714 .63325 .91819 .62573 .91767 .62642 Mtetra
.977 .675 .338 r
.91767 .62642 .91819 .62573 .89737 .42751 .89668 .42634 Mtetra
.941 .765 .636 r
.89668 .42634 .89737 .42751 .89867 .42321 .89795 .42179 Mtetra
.706 .68 .823 r
.89795 .42179 .89867 .42321 .90036 .42228 .89964 .42094 Mtetra
.593 .639 .865 r
.89964 .42094 .90036 .42228 .90212 .42197 .90142 .42076 Mtetra
.53 .63 .894 r
.90142 .42076 .90212 .42197 .9039 .42188 .90322 .42082 Mtetra
.66 .725 .897 r
.90322 .42082 .9039 .42188 .90564 .42132 .90496 .42031 Mtetra
.671 .737 .9 r
.90496 .42031 .90564 .42132 .90737 .42074 .90669 .41974 Mtetra
.694 .75 .895 r
.90669 .41974 .90737 .42074 .90909 .42006 .90841 .41906 Mtetra
.763 .775 .863 r
.90841 .41906 .90909 .42006 .91076 .41897 .91009 .41799 Mtetra
.693 .753 .897 r
.91009 .41799 .91076 .41897 .91248 .41829 .91181 .41731 Mtetra
.429 .625 .935 r
.91181 .41731 .91248 .41829 .91432 .41857 .91365 .41759 Mtetra
.789 .373 0 r
.91365 .41759 .91432 .41857 .91674 .42369 .91608 .42273 Mtetra
.973 .661 .312 r
.91608 .42273 .91674 .42369 .94266 .62245 .94196 .62154 Mtetra
.729 .289 0 r
.94196 .62154 .94266 .62245 .9451 .62671 .9444 .62579 Mtetra
.497 .693 .956 r
.9444 .62579 .9451 .62671 .94703 .62673 .94634 .62581 Mtetra
.693 .782 .92 r
.94634 .62581 .94703 .62673 .94887 .62602 .94818 .6251 Mtetra
.743 .799 .898 r
.94818 .6251 .94887 .62602 .95068 .62504 .94999 .62412 Mtetra
.494 .691 .956 r
.94999 .62412 .95068 .62504 .95262 .62507 .95193 .62415 Mtetra
.62 .752 .941 r
.95193 .62415 .95262 .62507 .9545 .62467 .95381 .62375 Mtetra
.799 .814 .864 r
.95381 .62375 .9545 .62467 .95627 .62332 .95558 .6224 Mtetra
.98 .776 .557 r
.95558 .6224 .95627 .62332 .95735 .61653 .95666 .61561 Mtetra
.975 .669 .322 r
.95666 .61561 .95735 .61653 .93403 .41659 .93337 .4156 Mtetra
.963 .784 .613 r
.93337 .4156 .93403 .41659 .93523 .41168 .93457 .41069 Mtetra
.756 .777 .87 r
.93457 .41069 .93523 .41168 .93692 .41064 .93626 .40965 Mtetra
.626 .725 .918 r
.93626 .40965 .93692 .41064 .93869 .41027 .93804 .40928 Mtetra
.545 .686 .931 r
.93804 .40928 .93869 .41027 .94051 .4102 .93985 .40921 Mtetra
.748 .774 .874 r
.93985 .40921 .94051 .4102 .94221 .40922 .94155 .40822 Mtetra
.681 .749 .902 r
.94155 .40822 .94221 .40922 .94396 .4086 .9433 .4076 Mtetra
.488 .656 .934 r
.9433 .4076 .94396 .4086 .9458 .40871 .94514 .40772 Mtetra
.738 .32 0 r
.94514 .40772 .9458 .40871 .94826 .41349 .9476 .4125 Mtetra
.97 .655 .291 r
.9476 .4125 .94826 .41349 .97632 .61313 .97564 .61219 Mtetra
.739 .309 0 r
.97564 .61219 .97632 .61313 .9789 .61789 .97822 .61695 Mtetra
.031 .462 .877 r
.36885 .7798 .36978 .78056 .37126 .78118 .37033 .78043 Mtetra
.643 .761 .935 r
.37033 .78043 .37126 .78118 .37278 .78079 .37185 .78003 Mtetra
.809 .778 .824 r
.37185 .78003 .37278 .78079 .37434 .77937 .37342 .77861 Mtetra
.908 .737 .659 r
.37342 .77861 .37434 .77937 .37607 .77417 .37514 .7734 Mtetra
.937 .686 .534 r
.37514 .7734 .37607 .77417 .38536 .58418 .38448 .58334 Mtetra
.908 .726 .645 r
.38448 .58334 .38536 .58418 .38702 .57847 .38614 .57764 Mtetra
.776 .757 .836 r
.38614 .57764 .38702 .57847 .38849 .57738 .38762 .57655 Mtetra
.639 .731 .915 r
.38762 .57655 .38849 .57738 .38993 .57704 .38906 .5762 Mtetra
.508 .684 .946 r
.38906 .5762 .38993 .57704 .39136 .57706 .39049 .57621 Mtetra
.745 .75 .856 r
.39049 .57621 .39136 .57706 .39282 .5762 .39195 .57534 Mtetra
.695 .738 .885 r
.39195 .57534 .39282 .5762 .39427 .57563 .3934 .57476 Mtetra
.48 .663 .943 r
.3934 .57476 .39427 .57563 .3957 .57574 .39483 .57484 Mtetra
.935 .566 .272 r
.39483 .57484 .3957 .57574 .39696 .58022 .3961 .57923 Mtetra
.94 .683 .522 r
.3961 .57923 .39696 .58022 .39135 .76997 .39043 .76907 Mtetra
.934 .567 .279 r
.39043 .76907 .39135 .76997 .39269 .77456 .39177 .77375 Mtetra
.388 .652 .963 r
.39177 .77375 .39269 .77456 .39421 .77478 .39329 .77395 Mtetra
.712 .76 .89 r
.39329 .77395 .39421 .77478 .39575 .77412 .39483 .77326 Mtetra
.769 .761 .845 r
.39483 .77326 .39575 .77412 .39731 .77307 .3964 .77216 Mtetra
.658 .732 .904 r
.3964 .77216 .39731 .77307 .39885 .77262 .39794 .77171 Mtetra
.62 .721 .919 r
.39794 .77171 .39885 .77262 .40039 .7723 .39947 .77141 Mtetra
.611 .723 .924 r
.39947 .77141 .40039 .7723 .40192 .772 .40101 .77114 Mtetra
.631 .734 .921 r
.40101 .77114 .40192 .772 .40346 .77165 .40254 .77079 Mtetra
.638 .736 .92 r
.40254 .77079 .40346 .77165 .405 .77128 .40408 .77041 Mtetra
.64 .738 .919 r
.40408 .77041 .405 .77128 .40654 .77089 .40563 .77003 Mtetra
.582 .721 .938 r
.40563 .77003 .40654 .77089 .40807 .77081 .40716 .76984 Mtetra
.622 .708 .907 r
.40716 .76984 .40807 .77081 .40961 .77054 .4087 .76954 Mtetra
.687 .72 .875 r
.4087 .76954 .40961 .77054 .41117 .76977 .41026 .76894 Mtetra
.828 .768 .795 r
.41026 .76894 .41117 .76977 .4128 .76671 .41184 .76721 Mtetra
.95 .945 .734 r
.41184 .76721 .4128 .76671 .41461 .75767 .41346 .76449 Mtetra
.255 .042 .386 r
.41346 .76449 .41461 .75767 .42178 .57181 .41512 .76037 Mtetra
.568 .358 .556 r
.41512 .76037 .42178 .57181 .42329 .57 .41669 .75929 Mtetra
.57 .36 .557 r
.41669 .75929 .42329 .57 .42475 .5697 .41821 .75951 Mtetra
.568 .359 .556 r
.41821 .75951 .42475 .5697 .42621 .56967 .41977 .75873 Mtetra
0 0 .357 r
.41977 .75873 .42621 .56967 .42771 .56797 .42663 .5748 Mtetra
0 0 .168 r
.42663 .5748 .42771 .56797 .42922 .56615 .42831 .56701 Mtetra
.955 .949 .662 r
.42831 .56701 .42922 .56615 .43071 .56472 .42985 .56395 Mtetra
.767 .772 .857 r
.42985 .56395 .43071 .56472 .43218 .56407 .43134 .56296 Mtetra
.627 .67 .872 r
.43134 .56296 .43218 .56407 .43365 .56375 .4328 .56266 Mtetra
.553 .645 .895 r
.4328 .56266 .43365 .56375 .43511 .56355 .43426 .56263 Mtetra
.621 .708 .908 r
.43426 .56263 .43511 .56355 .43658 .56319 .43573 .56235 Mtetra
.656 .736 .909 r
.43573 .56235 .43658 .56319 .43805 .56274 .4372 .56193 Mtetra
.669 .747 .908 r
.4372 .56193 .43805 .56274 .43953 .56225 .43867 .56145 Mtetra
.723 .762 .884 r
.43867 .56145 .43953 .56225 .44101 .56142 .44015 .56073 Mtetra
.72 .788 .906 r
.44015 .56073 .44101 .56142 .44249 .56069 .44163 .56004 Mtetra
.654 .786 .945 r
.44163 .56004 .44249 .56069 .44396 .5604 .44311 .5596 Mtetra
.131 .501 .908 r
.44311 .5596 .44396 .5604 .44539 .56204 .44456 .56018 Mtetra
.068 .241 .734 r
.44456 .56018 .44539 .56204 .4467 .56858 .44599 .56175 Mtetra
.388 .279 .607 r
.44599 .56175 .4467 .56858 .44395 .75539 .44739 .56466 Mtetra
.569 .362 .561 r
.44739 .56466 .44395 .75539 .44546 .75701 .44884 .56548 Mtetra
.572 .365 .562 r
.44884 .56548 .44546 .75701 .44703 .75654 .45034 .56446 Mtetra
.57 .364 .562 r
.45034 .56446 .44703 .75654 .4486 .75575 .45181 .56433 Mtetra
0 0 .384 r
.45181 .56433 .4486 .75575 .45014 .75649 .44943 .74676 Mtetra
.101 .051 .508 r
.44943 .74676 .45014 .75649 .45168 .75758 .45082 .75469 Mtetra
.02 .128 .637 r
.45082 .75469 .45168 .75758 .45322 .7583 .45233 .7573 Mtetra
.217 .51 .91 r
.45233 .7573 .45322 .7583 .45478 .75856 .45388 .75792 Mtetra
.584 .782 .974 r
.45388 .75792 .45478 .75856 .45635 .75835 .45545 .75764 Mtetra
.732 .798 .904 r
.45545 .75764 .45635 .75835 .45793 .75758 .45703 .75685 Mtetra
.806 .793 .84 r
.45703 .75685 .45793 .75758 .45953 .75523 .45862 .7555 Mtetra
.917 .964 .793 r
.45862 .7555 .45953 .75523 .4612 .74953 .46022 .75338 Mtetra
0 0 .184 r
.46022 .75338 .4612 .74953 .46606 .5603 .46186 .74963 Mtetra
0 0 .375 r
.46186 .74963 .46606 .5603 .46762 .55567 .4666 .56489 Mtetra
0 0 .261 r
.4666 .56489 .46762 .55567 .46913 .55374 .46825 .55508 Mtetra
.846 .914 .513 r
.46825 .55508 .46913 .55374 .47063 .55254 .46979 .55195 Mtetra
.818 .817 .848 r
.46979 .55195 .47063 .55254 .47213 .5518 .47129 .55064 Mtetra
.668 .679 .851 r
.47129 .55064 .47213 .5518 .47362 .55135 .47278 .55014 Mtetra
.602 .645 .865 r
.47278 .55014 .47362 .55135 .47511 .55107 .47427 .54995 Mtetra
.602 .664 .882 r
.47427 .54995 .47511 .55107 .4766 .55078 .47576 .54976 Mtetra
.614 .686 .893 r
.47576 .54976 .4766 .55078 .47809 .55047 .47725 .5495 Mtetra
.612 .697 .904 r
.47725 .5495 .47809 .55047 .47958 .55015 .47874 .54925 Mtetra
.63 .718 .91 r
.47874 .54925 .47958 .55015 .48108 .54977 .48024 .54892 Mtetra
.651 .737 .912 r
.48024 .54892 .48108 .54977 .48257 .54933 .48173 .54851 Mtetra
.668 .75 .912 r
.48173 .54851 .48257 .54933 .48407 .54883 .48323 .54804 Mtetra
.692 .762 .905 r
.48323 .54804 .48407 .54883 .48557 .54824 .48473 .54746 Mtetra
.706 .767 .9 r
.48473 .54746 .48557 .54824 .48707 .5476 .48623 .54682 Mtetra
.706 .767 .899 r
.48623 .54682 .48707 .5476 .48857 .54697 .48773 .54617 Mtetra
.715 .766 .893 r
.48773 .54617 .48857 .54697 .49007 .5462 .48923 .54548 Mtetra
.703 .783 .914 r
.48923 .54548 .49007 .5462 .49157 .5455 .49074 .54486 Mtetra
.632 .786 .956 r
.49074 .54486 .49157 .5455 .49307 .54521 .49224 .54448 Mtetra
.239 .585 .946 r
.49224 .54448 .49307 .54521 .49456 .54638 .49373 .54488 Mtetra
.001 .251 .758 r
.49373 .54488 .49456 .54638 .49602 .55117 .49522 .5463 Mtetra
.329 .265 .632 r
.49522 .5463 .49602 .55117 .49599 .73991 .4967 .54892 Mtetra
.565 .36 .561 r
.4967 .54892 .49599 .73991 .49756 .74301 .49818 .55151 Mtetra
.57 .364 .562 r
.49818 .55151 .49756 .74301 .49915 .74285 .49969 .5514 Mtetra
.572 .366 .562 r
.49969 .5514 .49915 .74285 .50075 .74192 .50121 .55001 Mtetra
.572 .365 .562 r
.50121 .55001 .50075 .74192 .50235 .74111 .50272 .54899 Mtetra
.571 .364 .562 r
.50272 .54899 .50235 .74111 .50394 .74068 .50424 .54849 Mtetra
.50424 .54849 .50394 .74068 .50554 .74024 .50575 .548 Mtetra
.50575 .548 .50554 .74024 .50714 .7398 .50726 .54753 Mtetra
.50726 .54753 .50714 .7398 .50874 .73938 .50878 .54707 Mtetra
.50878 .54707 .50874 .73938 .51034 .73896 .51029 .54661 Mtetra
.51029 .54661 .51034 .73896 .51194 .73854 .51181 .54616 Mtetra
.51181 .54616 .51194 .73854 .51354 .73811 .51332 .54571 Mtetra
.51332 .54571 .51354 .73811 .51515 .73769 .51484 .54526 Mtetra
.51484 .54526 .51515 .73769 .51675 .73726 .51636 .5448 Mtetra
.51636 .5448 .51675 .73726 .51836 .73683 .51788 .54435 Mtetra
.51788 .54435 .51836 .73683 .51996 .7364 .5194 .54388 Mtetra
.5194 .54388 .51996 .7364 .52157 .73597 .52092 .54342 Mtetra
.52092 .54342 .52157 .73597 .52318 .73554 .52244 .54295 Mtetra
.52244 .54295 .52318 .73554 .52479 .7351 .52397 .54248 Mtetra
.52397 .54248 .52479 .7351 .5264 .73466 .52549 .542 Mtetra
.52549 .542 .5264 .73466 .52801 .73422 .52701 .54152 Mtetra
.52701 .54152 .52801 .73422 .52962 .73377 .52854 .54103 Mtetra
.52854 .54103 .52962 .73377 .53123 .73332 .53007 .54053 Mtetra
.53007 .54053 .53123 .73332 .53285 .73287 .53159 .54003 Mtetra
.53159 .54003 .53285 .73287 .53446 .73241 .53312 .53951 Mtetra
.53312 .53951 .53446 .73241 .53608 .73194 .53465 .53896 Mtetra
.53465 .53896 .53608 .73194 .53769 .73146 .53618 .53839 Mtetra
.53618 .53839 .53769 .73146 .53931 .73098 .53771 .53783 Mtetra
.572 .365 .562 r
.53771 .53783 .53931 .73098 .54093 .73037 .53924 .5368 Mtetra
.53924 .5368 .54093 .73037 .54254 .72963 .54076 .53552 Mtetra
.57 .364 .562 r
.54076 .53552 .54254 .72963 .54416 .72926 .5423 .53533 Mtetra
.56 .356 .561 r
.5423 .53533 .54416 .72926 .54579 .72984 .54386 .54081 Mtetra
.003 0 .411 r
.54386 .54081 .54579 .72984 .54742 .7311 .54654 .72673 Mtetra
.103 .126 .6 r
.54654 .72673 .54742 .7311 .54906 .73203 .54819 .73052 Mtetra
.096 .329 .802 r
.54819 .73052 .54906 .73203 .55069 .7324 .54983 .73182 Mtetra
.468 .76 .994 r
.54983 .73182 .55069 .7324 .55232 .7322 .55146 .73174 Mtetra
.607 .846 .989 r
.55146 .73174 .55232 .7322 .55395 .73184 .55309 .73131 Mtetra
.648 .838 .973 r
.55309 .73131 .55395 .73184 .55558 .73142 .55472 .7308 Mtetra
.619 .803 .97 r
.55472 .7308 .55558 .73142 .55721 .73104 .55635 .7304 Mtetra
.637 .805 .964 r
.55635 .7304 .55721 .73104 .55884 .73061 .55798 .72995 Mtetra
.637 .8 .961 r
.55798 .72995 .55884 .73061 .56047 .73025 .55961 .72951 Mtetra
.637 .779 .949 r
.55961 .72951 .56047 .73025 .56211 .72998 .56125 .72909 Mtetra
.688 .757 .904 r
.56125 .72909 .56211 .72998 .56374 .72938 .56288 .72848 Mtetra
.758 .77 .862 r
.56288 .72848 .56374 .72938 .56536 .72783 .56451 .72745 Mtetra
.876 .877 .832 r
.56451 .72745 .56536 .72783 .56695 .72378 .56613 .72566 Mtetra
0 0 0 r
.56613 .72566 .56695 .72378 .56631 .53848 .56774 .72281 Mtetra
.558 .351 .555 r
.56774 .72281 .56631 .53848 .56771 .52627 .56929 .71584 Mtetra
.007 0 .409 r
.56929 .71584 .56771 .52627 .56923 .5238 .56847 .52682 Mtetra
0 0 .009 r
.56847 .52682 .56923 .5238 .57076 .52238 .56997 .52243 Mtetra
.912 .954 .808 r
.56997 .52243 .57076 .52238 .5723 .52155 .57149 .5205 Mtetra
.664 .703 .877 r
.57149 .5205 .5723 .52155 .57385 .52119 .57304 .52002 Mtetra
.561 .639 .886 r
.57304 .52002 .57385 .52119 .5754 .52106 .57459 .51997 Mtetra
.519 .637 .906 r
.57459 .51997 .5754 .52106 .57695 .52098 .57615 .52004 Mtetra
.608 .708 .915 r
.57615 .52004 .57695 .52098 .57851 .5207 .5777 .51979 Mtetra
.611 .714 .918 r
.5777 .51979 .57851 .5207 .58006 .5204 .57926 .51951 Mtetra
.611 .721 .923 r
.57926 .51951 .58006 .5204 .58161 .52009 .58081 .51924 Mtetra
.608 .727 .93 r
.58081 .51924 .58161 .52009 .58317 .51978 .58237 .51896 Mtetra
.608 .737 .936 r
.58237 .51896 .58317 .51978 .58472 .51946 .58392 .51868 Mtetra
.608 .747 .944 r
.58392 .51868 .58472 .51946 .58628 .51913 .58548 .51839 Mtetra
.606 .759 .952 r
.58548 .51839 .58628 .51913 .58784 .51878 .58704 .51809 Mtetra
.615 .776 .958 r
.58704 .51809 .58784 .51878 .5894 .5184 .5886 .51775 Mtetra
.637 .794 .958 r
.5886 .51775 .5894 .5184 .59095 .51798 .59016 .51734 Mtetra
.673 .807 .947 r
.59016 .51734 .59095 .51798 .59251 .51748 .59172 .5168 Mtetra
.688 .8 .934 r
.59172 .5168 .59251 .51748 .59407 .51695 .59327 .51622 Mtetra
.694 .786 .921 r
.59327 .51622 .59407 .51695 .59563 .51641 .59483 .51561 Mtetra
.69 .77 .912 r
.59483 .51561 .59563 .51641 .59718 .51587 .59639 .51502 Mtetra
.691 .758 .903 r
.59639 .51502 .59718 .51587 .59874 .51532 .59795 .51443 Mtetra
.69 .747 .895 r
.59795 .51443 .59874 .51532 .6003 .51476 .59951 .51383 Mtetra
.687 .737 .889 r
.59951 .51383 .6003 .51476 .60187 .51421 .60107 .51324 Mtetra
.687 .73 .883 r
.60107 .51324 .60187 .51421 .60343 .51366 .60263 .51266 Mtetra
.687 .724 .878 r
.60263 .51266 .60343 .51366 .60499 .51309 .60419 .51206 Mtetra
.688 .719 .873 r
.60419 .51206 .60499 .51309 .60655 .51251 .60575 .51146 Mtetra
.688 .714 .868 r
.60575 .51146 .60655 .51251 .60812 .51192 .60732 .51085 Mtetra
.688 .71 .865 r
.60732 .51085 .60812 .51192 .60968 .51132 .60888 .51024 Mtetra
.687 .707 .863 r
.60888 .51024 .60968 .51132 .61124 .51072 .61045 .50963 Mtetra
.69 .707 .861 r
.61045 .50963 .61124 .51072 .61281 .5101 .61201 .509 Mtetra
.704 .711 .854 r
.61201 .509 .61281 .5101 .61437 .50942 .61358 .5083 Mtetra
.749 .721 .826 r
.61358 .5083 .61437 .50942 .61593 .50853 .61513 .50726 Mtetra
.701 .683 .83 r
.61513 .50726 .61593 .50853 .61749 .50779 .61669 .50652 Mtetra
.585 .634 .867 r
.61669 .50652 .61749 .50779 .61907 .50735 .61828 .5064 Mtetra
0 0 .508 r
.61828 .5064 .61907 .50735 .62066 .5075 .61992 .50825 Mtetra
.896 .548 .378 r
.61992 .50825 .62066 .5075 .62227 .50836 .62168 .51441 Mtetra
.954 .674 .469 r
.62168 .51441 .62227 .50836 .62394 .51104 .62886 .70375 Mtetra
.574 .363 .557 r
.62886 .70375 .62394 .51104 .63129 .70166 .63064 .70707 Mtetra
.625 .346 .476 r
.63064 .70707 .63129 .70166 .63316 .7079 .63238 .70852 Mtetra
.571 .078 .045 r
.63238 .70852 .63316 .7079 .63492 .70998 .63409 .70915 Mtetra
.526 .716 .959 r
.63409 .70915 .63492 .70998 .63661 .71004 .63578 .70907 Mtetra
.623 .722 .918 r
.63578 .70907 .63661 .71004 .63829 .70962 .63746 .70873 Mtetra
.653 .75 .921 r
.63746 .70873 .63829 .70962 .63996 .709 .63914 .70826 Mtetra
.568 .759 .968 r
.63914 .70826 .63996 .709 .64165 .70888 .64083 .70803 Mtetra
.639 .756 .933 r
.64083 .70803 .64165 .70888 .64334 .70846 .64251 .7076 Mtetra
.716 .777 .9 r
.64251 .7076 .64334 .70846 .645 .70747 .64418 .70684 Mtetra
.85 .839 .834 r
.64418 .70684 .645 .70747 .64659 .70419 .64582 .70516 Mtetra
.753 .9 .509 r
.64582 .70516 .64659 .70419 .64799 .69573 .64743 .70253 Mtetra
.219 .028 .394 r
.64743 .70253 .64799 .69573 .6429 .50431 .64895 .69743 Mtetra
.057 0 .437 r
.64895 .69743 .6429 .50431 .64439 .50118 .64381 .50579 Mtetra
0 0 .213 r
.64381 .50579 .64439 .50118 .64593 .49947 .6452 .49998 Mtetra
.917 .969 .67 r
.6452 .49998 .64593 .49947 .6475 .49841 .64672 .49741 Mtetra
.708 .734 .871 r
.64672 .49741 .6475 .49841 .64908 .49786 .6483 .49669 Mtetra
.614 .667 .878 r
.6483 .49669 .64908 .49786 .65068 .49754 .64989 .49643 Mtetra
.55 .651 .902 r
.64989 .49643 .65068 .49754 .65228 .49732 .6515 .49641 Mtetra
.7 .75 .89 r
.6515 .49641 .65228 .49732 .65386 .4965 .65309 .49575 Mtetra
.68 .784 .928 r
.65309 .49575 .65386 .4965 .65545 .4959 .65468 .49519 Mtetra
.602 .767 .959 r
.65468 .49519 .65545 .4959 .65705 .4958 .65628 .49488 Mtetra
.293 .561 .929 r
.65628 .49488 .65705 .4958 .65876 .49812 .65791 .49538 Mtetra
.372 .369 .727 r
.65791 .49538 .65876 .49812 .66092 .51152 .65958 .49676 Mtetra
.485 .323 .586 r
.65958 .49676 .66092 .51152 .67015 .69561 .66136 .50052 Mtetra
.08 0 .454 r
.66136 .50052 .67015 .69561 .67194 .69755 .67087 .69036 Mtetra
.256 .194 .593 r
.67087 .69036 .67194 .69755 .67369 .69826 .6728 .6955 Mtetra
.256 .302 .719 r
.6728 .6955 .67369 .69826 .67542 .69844 .6746 .69746 Mtetra
.246 .532 .92 r
.6746 .69746 .67542 .69844 .67715 .69878 .67635 .69809 Mtetra
.54 .764 .98 r
.67635 .69809 .67715 .69878 .67887 .6986 .67806 .6979 Mtetra
.771 .828 .896 r
.67806 .6979 .67887 .6986 .68055 .69767 .67974 .69685 Mtetra
.933 .776 .663 r
.67974 .69685 .68055 .69767 .68208 .69325 .68127 .6924 Mtetra
.968 .69 .449 r
.68127 .6924 .68208 .69325 .67501 .49861 .67423 .49758 Mtetra
.947 .734 .582 r
.67423 .49758 .67501 .49861 .67627 .49063 .6755 .48967 Mtetra
.798 .765 .823 r
.6755 .48967 .67627 .49063 .67784 .48927 .67707 .48831 Mtetra
.634 .72 .909 r
.67707 .48831 .67784 .48927 .67945 .4889 .67868 .48795 Mtetra
.5 .663 .935 r
.67868 .48795 .67945 .4889 .68108 .48896 .68031 .48801 Mtetra
.645 .727 .908 r
.68031 .48801 .68108 .48896 .68269 .48853 .68193 .4876 Mtetra
.668 .737 .901 r
.68193 .4876 .68269 .48853 .6843 .48802 .68353 .48709 Mtetra
.673 .74 .901 r
.68353 .48709 .6843 .48802 .68591 .48747 .68514 .48655 Mtetra
.762 .767 .857 r
.68514 .48655 .68591 .48747 .68749 .48643 .68673 .48552 Mtetra
.72 .758 .883 r
.68673 .48552 .68749 .48643 .68909 .48566 .68833 .48475 Mtetra
.553 .698 .936 r
.68833 .48475 .68909 .48566 .69072 .48556 .68996 .48465 Mtetra
.833 .396 0 r
.68996 .48465 .69072 .48556 .69254 .48922 .69178 .48832 Mtetra
.97 .683 .428 r
.69178 .48832 .69254 .48922 .70414 .68406 .70334 .68322 Mtetra
.913 .515 .135 r
.70334 .68322 .70414 .68406 .70617 .68966 .70537 .68881 Mtetra
0 .39 .843 r
.70537 .68881 .70617 .68966 .70797 .69064 .70717 .68979 Mtetra
.605 .749 .946 r
.70717 .68979 .70797 .69064 .70969 .69032 .7089 .68947 Mtetra
.8 .802 .853 r
.7089 .68947 .70969 .69032 .71137 .68899 .71057 .68814 Mtetra
.936 .777 .659 r
.71057 .68814 .71137 .68899 .71288 .68448 .71208 .68365 Mtetra
.971 .689 .438 r
.71208 .68365 .71288 .68448 .70404 .48892 .70329 .48809 Mtetra
.957 .749 .58 r
.70329 .48809 .70404 .48892 .70529 .48158 .70454 .48068 Mtetra
.829 .784 .81 r
.70454 .48068 .70529 .48158 .70685 .47997 .7061 .47907 Mtetra
.658 .743 .912 r
.7061 .47907 .70685 .47997 .70848 .47951 .70772 .4786 Mtetra
.535 .691 .939 r
.70772 .4786 .70848 .47951 .71013 .47946 .70937 .47855 Mtetra
.718 .759 .884 r
.70937 .47855 .71013 .47946 .71174 .47872 .71098 .47778 Mtetra
.704 .751 .888 r
.71098 .47778 .71174 .47872 .71335 .47804 .7126 .47709 Mtetra
.543 .686 .932 r
.7126 .47709 .71335 .47804 .715 .47799 .71425 .47703 Mtetra
.784 .341 0 r
.71425 .47703 .715 .47799 .71686 .48143 .7161 .48045 Mtetra
.972 .682 .417 r
.7161 .48045 .71686 .48143 .72999 .67714 .7292 .67624 Mtetra
.91 .512 .116 r
.7292 .67624 .72999 .67714 .73209 .68291 .7313 .68205 Mtetra
.051 .436 .873 r
.7313 .68205 .73209 .68291 .7339 .6837 .73311 .68294 Mtetra
.649 .789 .949 r
.73311 .68294 .7339 .6837 .73563 .68316 .73485 .68245 Mtetra
.808 .835 .871 r
.73485 .68245 .73563 .68316 .73732 .68199 .73654 .68112 Mtetra
.896 .797 .743 r
.73654 .68112 .73732 .68199 .739 .68048 .73814 .6784 Mtetra
.887 .69 .631 r
.73814 .6784 .739 .68048 .74065 .67864 .73956 .67277 Mtetra
.967 .682 .439 r
.73956 .67277 .74065 .67864 .74229 .6765 .72947 .48124 Mtetra
.576 .368 .562 r
.72947 .48124 .74229 .6765 .74398 .6752 .7309 .47735 Mtetra
.571 .364 .562 r
.7309 .47735 .74398 .6752 .74572 .67472 .73253 .47674 Mtetra
.569 .363 .562 r
.73253 .47674 .74572 .67472 .74748 .67455 .73422 .47707 Mtetra
.571 .365 .562 r
.73422 .47707 .74748 .67455 .74921 .67397 .73584 .47621 Mtetra
.73584 .47621 .74921 .67397 .75095 .67336 .73746 .47533 Mtetra
.569 .363 .562 r
.73746 .47533 .75095 .67336 .75271 .6732 .73916 .47573 Mtetra
.136 .047 .481 r
.73916 .47573 .75271 .6732 .75456 .67426 .75304 .66212 Mtetra
.208 .136 .551 r
.75304 .66212 .75456 .67426 .75642 .67545 .75548 .67222 Mtetra
.178 .228 .678 r
.75548 .67222 .75642 .67545 .75825 .67622 .75745 .67506 Mtetra
.302 .525 .903 r
.75745 .67506 .75825 .67622 .76005 .67648 .75928 .67574 Mtetra
.584 .773 .969 r
.75928 .67574 .76005 .67648 .76182 .67625 .76105 .67545 Mtetra
.726 .803 .912 r
.76105 .67545 .76182 .67625 .76355 .67545 .76278 .67461 Mtetra
.832 .812 .831 r
.76278 .67461 .76355 .67545 .76517 .67293 .76445 .67299 Mtetra
.939 .96 .747 r
.76445 .67299 .76517 .67293 .76652 .66671 .76607 .67047 Mtetra
.135 0 .302 r
.76607 .67047 .76652 .66671 .75475 .47242 .76761 .66691 Mtetra
.567 .357 .556 r
.76761 .66691 .75475 .47242 .7562 .46898 .76926 .66497 Mtetra
.569 .36 .556 r
.76926 .66497 .7562 .46898 .75786 .46851 .77106 .66501 Mtetra
.569 .359 .556 r
.77106 .66501 .75786 .46851 .75954 .4685 .77281 .66445 Mtetra
.552 .346 .556 r
.77281 .66445 .75954 .4685 .76113 .46698 .77372 .65221 Mtetra
.111 .025 .469 r
.77372 .65221 .76113 .46698 .76267 .46489 .76211 .46641 Mtetra
.665 .741 .243 r
.76211 .46641 .76267 .46489 .76424 .46322 .76352 .46254 Mtetra
.837 .839 .847 r
.76352 .46254 .76424 .46322 .76586 .46232 .76511 .46105 Mtetra
.647 .671 .859 r
.76511 .46105 .76586 .46232 .76752 .46191 .76677 .46062 Mtetra
.58 .635 .87 r
.76677 .46062 .76752 .46191 .7692 .46166 .76846 .46051 Mtetra
.64 .688 .879 r
.76846 .46051 .7692 .46166 .77085 .46106 .77012 .46011 Mtetra
.688 .748 .897 r
.77012 .46011 .77085 .46106 .77249 .46033 .77177 .45949 Mtetra
.641 .756 .933 r
.77177 .45949 .77249 .46033 .77417 .45999 .77344 .45906 Mtetra
.468 .656 .942 r
.77344 .45906 .77417 .45999 .77596 .46118 .77515 .4592 Mtetra
.385 .437 .792 r
.77515 .4592 .77596 .46118 .77806 .46644 .77693 .46017 Mtetra
.434 .328 .634 r
.77693 .46017 .77806 .46644 .79475 .65971 .77883 .46269 Mtetra
.145 .056 .488 r
.77883 .46269 .79475 .65971 .79685 .66343 .79523 .65157 Mtetra
.25 .17 .566 r
.79523 .65157 .79685 .66343 .79874 .66449 .79776 .66081 Mtetra
.294 .289 .683 r
.79776 .66081 .79874 .66449 .80058 .6648 .79978 .66338 Mtetra
.425 .547 .875 r
.79978 .66338 .80058 .6648 .80237 .66453 .80163 .66389 Mtetra
.67 .833 .962 r
.80163 .66389 .80237 .66453 .80414 .66387 .8034 .66327 Mtetra
.761 .869 .927 r
.8034 .66327 .80414 .66387 .80589 .663 .80514 .66226 Mtetra
.74 .827 .918 r
.80514 .66226 .80589 .663 .80764 .66222 .80689 .66136 Mtetra
.685 .78 .923 r
.80689 .66136 .80764 .66222 .80941 .66159 .80865 .66071 Mtetra
.678 .774 .923 r
.80865 .66071 .80941 .66159 .81118 .661 .81043 .66009 Mtetra
.678 .769 .92 r
.81043 .66009 .81118 .661 .81296 .66041 .8122 .65948 Mtetra
.678 .764 .916 r
.8122 .65948 .81296 .66041 .81473 .65982 .81397 .65887 Mtetra
.673 .756 .913 r
.81397 .65887 .81473 .65982 .81651 .65926 .81575 .65828 Mtetra
.666 .747 .911 r
.81575 .65828 .81651 .65926 .81829 .65873 .81753 .65772 Mtetra
.657 .739 .91 r
.81753 .65772 .81829 .65873 .82008 .65822 .81932 .6572 Mtetra
.648 .732 .91 r
.81932 .6572 .82008 .65822 .82187 .65775 .82111 .65673 Mtetra
.64 .728 .912 r
.82111 .65673 .82187 .65775 .82366 .65732 .8229 .65629 Mtetra
.629 .724 .915 r
.8229 .65629 .82366 .65732 .82546 .65691 .8247 .6559 Mtetra
.614 .72 .921 r
.8247 .6559 .82546 .65691 .82726 .65655 .82651 .65556 Mtetra
.588 .715 .931 r
.82651 .65556 .82726 .65655 .82907 .65627 .82832 .65532 Mtetra
.56 .713 .943 r
.82832 .65532 .82907 .65627 .83089 .65605 .83015 .65517 Mtetra
.548 .723 .955 r
.83015 .65517 .83089 .65605 .83271 .65585 .83197 .65503 Mtetra
.543 .735 .964 r
.83197 .65503 .83271 .65585 .83454 .65565 .8338 .65487 Mtetra
.546 .75 .971 r
.8338 .65487 .83454 .65565 .83636 .65544 .83563 .65469 Mtetra
.556 .763 .975 r
.83563 .65469 .83636 .65544 .83818 .65519 .83745 .65446 Mtetra
.581 .78 .974 r
.83745 .65446 .83818 .65519 .83999 .65487 .83927 .65415 Mtetra
.607 .794 .971 r
.83927 .65415 .83999 .65487 .8418 .65447 .84108 .65376 Mtetra
.619 .799 .968 r
.84108 .65376 .8418 .65447 .84361 .65404 .84289 .65332 Mtetra
.624 .8 .967 r
.84289 .65332 .84361 .65404 .84542 .65359 .8447 .65287 Mtetra
.624 .799 .966 r
.8447 .65287 .84542 .65359 .84723 .65315 .84651 .65242 Mtetra
.627 .8 .965 r
.84651 .65242 .84723 .65315 .84904 .65269 .84832 .65196 Mtetra
.629 .8 .965 r
.84832 .65196 .84904 .65269 .85085 .65223 .85013 .6515 Mtetra
.63 .801 .964 r
.85013 .6515 .85085 .65223 .85266 .65176 .85194 .65103 Mtetra
.632 .801 .964 r
.85194 .65103 .85266 .65176 .85447 .65128 .85375 .65055 Mtetra
.633 .802 .964 r
.85375 .65055 .85447 .65128 .85628 .6508 .85556 .65008 Mtetra
.85556 .65008 .85628 .6508 .8581 .65032 .85738 .6496 Mtetra
.634 .802 .963 r
.85738 .6496 .8581 .65032 .85991 .64984 .85919 .64911 Mtetra
.85919 .64911 .85991 .64984 .86172 .64936 .86101 .64863 Mtetra
.635 .802 .963 r
.86101 .64863 .86172 .64936 .86354 .64887 .86282 .64814 Mtetra
.635 .803 .963 r
.86282 .64814 .86354 .64887 .86536 .64838 .86464 .64765 Mtetra
.636 .803 .963 r
.86464 .64765 .86536 .64838 .86717 .64789 .86646 .64716 Mtetra
.86646 .64716 .86717 .64789 .86899 .6474 .86828 .64667 Mtetra
.86828 .64667 .86899 .6474 .87081 .64691 .8701 .64617 Mtetra
.637 .803 .963 r
.8701 .64617 .87081 .64691 .87263 .64641 .87192 .64568 Mtetra
.637 .804 .963 r
.87192 .64568 .87263 .64641 .87446 .64591 .87374 .64518 Mtetra
.638 .804 .963 r
.87374 .64518 .87446 .64591 .87628 .64541 .87557 .64468 Mtetra
.639 .804 .962 r
.87557 .64468 .87628 .64541 .8781 .64491 .87739 .64418 Mtetra
.64 .804 .962 r
.87739 .64418 .8781 .64491 .87993 .6444 .87922 .64367 Mtetra
.641 .805 .962 r
.87922 .64367 .87993 .6444 .88175 .64389 .88104 .64316 Mtetra
.642 .805 .961 r
.88104 .64316 .88175 .64389 .88358 .64338 .88287 .64264 Mtetra
.642 .804 .961 r
.88287 .64264 .88358 .64338 .8854 .64287 .8847 .64213 Mtetra
.649 .806 .959 r
.8847 .64213 .8854 .64287 .88723 .64234 .88652 .64159 Mtetra
.666 .81 .952 r
.88652 .64159 .88723 .64234 .88905 .64176 .88835 .64099 Mtetra
.692 .813 .94 r
.88835 .64099 .88905 .64176 .89087 .64111 .89016 .64029 Mtetra
.697 .802 .93 r
.89016 .64029 .89087 .64111 .89268 .64045 .89197 .63957 Mtetra
.689 .785 .924 r
.89197 .63957 .89268 .64045 .8945 .63981 .89378 .63888 Mtetra
.667 .766 .924 r
.89378 .63888 .8945 .63981 .89633 .63926 .89561 .6383 Mtetra
.659 .758 .923 r
.89561 .6383 .89633 .63926 .89817 .63873 .89744 .63776 Mtetra
.656 .753 .922 r
.89744 .63776 .89817 .63873 .9 .63821 .89928 .63723 Mtetra
.658 .751 .919 r
.89928 .63723 .9 .63821 .90184 .63769 .90111 .63669 Mtetra
.655 .746 .917 r
.90111 .63669 .90184 .63769 .90368 .63718 .90295 .63617 Mtetra
.649 .74 .916 r
.90295 .63617 .90368 .63718 .90552 .6367 .90479 .63567 Mtetra
.64 .734 .917 r
.90479 .63567 .90552 .6367 .90737 .63625 .90664 .63522 Mtetra
.636 .732 .917 r
.90664 .63522 .90737 .63625 .90922 .63581 .90849 .63478 Mtetra
.606 .719 .924 r
.90849 .63478 .90922 .63581 .91108 .63549 .91036 .63447 Mtetra
.513 .676 .938 r
.91036 .63447 .91108 .63549 .91298 .63549 .91226 .63449 Mtetra
.637 .739 .922 r
.91226 .63449 .91298 .63549 .91484 .63504 .91412 .63405 Mtetra
.829 .802 .826 r
.91412 .63405 .91484 .63504 .91656 .6334 .91584 .63238 Mtetra
.974 .762 .554 r
.91584 .63238 .91656 .6334 .91767 .62642 .9169 .62496 Mtetra
.977 .674 .346 r
.9169 .62496 .91767 .62642 .89668 .42634 .89595 .42496 Mtetra
.922 .746 .646 r
.89595 .42496 .89668 .42634 .89795 .42179 .89725 .4206 Mtetra
.709 .717 .855 r
.89725 .4206 .89795 .42179 .89964 .42094 .89895 .4198 Mtetra
.575 .666 .9 r
.89895 .4198 .89964 .42094 .90142 .42076 .90073 .41967 Mtetra
.505 .64 .915 r
.90073 .41967 .90142 .42076 .90322 .42082 .90254 .41978 Mtetra
.655 .723 .899 r
.90254 .41978 .90322 .42082 .90496 .42031 .90428 .41928 Mtetra
.667 .734 .899 r
.90428 .41928 .90496 .42031 .90669 .41974 .90602 .41873 Mtetra
.692 .747 .894 r
.90602 .41873 .90669 .41974 .90841 .41906 .90774 .41806 Mtetra
.761 .773 .863 r
.90774 .41806 .90841 .41906 .91009 .41799 .90942 .41699 Mtetra
.692 .751 .897 r
.90942 .41699 .91009 .41799 .91181 .41731 .91114 .41633 Mtetra
.429 .624 .934 r
.91114 .41633 .91181 .41731 .91365 .41759 .91298 .41661 Mtetra
.789 .373 0 r
.91298 .41661 .91365 .41759 .91608 .42273 .91541 .42176 Mtetra
.973 .661 .312 r
.91541 .42176 .91608 .42273 .94196 .62154 .94127 .62062 Mtetra
.726 .287 0 r
.94127 .62062 .94196 .62154 .9444 .62579 .94371 .62487 Mtetra
.498 .693 .956 r
.94371 .62487 .9444 .62579 .94634 .62581 .94564 .62488 Mtetra
.693 .782 .919 r
.94564 .62488 .94634 .62581 .94818 .6251 .94748 .62417 Mtetra
.743 .799 .898 r
.94748 .62417 .94818 .6251 .94999 .62412 .9493 .6232 Mtetra
.495 .691 .956 r
.9493 .6232 .94999 .62412 .95193 .62415 .95123 .62322 Mtetra
.62 .752 .94 r
.95123 .62322 .95193 .62415 .95381 .62375 .95312 .62282 Mtetra
.799 .814 .864 r
.95312 .62282 .95381 .62375 .95558 .6224 .95489 .62147 Mtetra
.98 .776 .557 r
.95489 .62147 .95558 .6224 .95666 .61561 .95597 .61468 Mtetra
.975 .669 .322 r
.95597 .61468 .95666 .61561 .93337 .4156 .93271 .41462 Mtetra
.963 .784 .612 r
.93271 .41462 .93337 .4156 .93457 .41069 .93391 .4097 Mtetra
.756 .777 .87 r
.93391 .4097 .93457 .41069 .93626 .40965 .9356 .40866 Mtetra
.627 .726 .918 r
.9356 .40866 .93626 .40965 .93804 .40928 .93738 .40829 Mtetra
.545 .686 .931 r
.93738 .40829 .93804 .40928 .93985 .40921 .93919 .40821 Mtetra
.748 .774 .874 r
.93919 .40821 .93985 .40921 .94155 .40822 .9409 .40723 Mtetra
.681 .749 .902 r
.9409 .40723 .94155 .40822 .9433 .4076 .94264 .40661 Mtetra
.488 .656 .934 r
.94264 .40661 .9433 .4076 .94514 .40772 .94449 .40672 Mtetra
.738 .32 0 r
.94449 .40672 .94514 .40772 .9476 .4125 .94695 .4115 Mtetra
.97 .655 .291 r
.94695 .4115 .9476 .4125 .97564 .61219 .97496 .61125 Mtetra
.739 .309 0 r
.97496 .61125 .97564 .61219 .97822 .61695 .97754 .61601 Mtetra
.031 .462 .877 r
.36792 .77904 .36885 .7798 .37033 .78043 .3694 .77967 Mtetra
.643 .761 .935 r
.3694 .77967 .37033 .78043 .37185 .78003 .37092 .77927 Mtetra
.809 .778 .824 r
.37092 .77927 .37185 .78003 .37342 .77861 .37249 .77785 Mtetra
.908 .737 .659 r
.37249 .77785 .37342 .77861 .37514 .7734 .37421 .77263 Mtetra
.937 .686 .534 r
.37421 .77263 .37514 .7734 .38448 .58334 .38361 .5825 Mtetra
.908 .726 .645 r
.38361 .5825 .38448 .58334 .38614 .57764 .38527 .57682 Mtetra
.776 .757 .836 r
.38527 .57682 .38614 .57764 .38762 .57655 .38675 .57572 Mtetra
.641 .732 .915 r
.38675 .57572 .38762 .57655 .38906 .5762 .38819 .57536 Mtetra
.512 .687 .946 r
.38819 .57536 .38906 .5762 .39049 .57621 .38962 .57536 Mtetra
.745 .751 .857 r
.38962 .57536 .39049 .57621 .39195 .57534 .39108 .5745 Mtetra
.697 .744 .888 r
.39108 .5745 .39195 .57534 .3934 .57476 .39254 .57391 Mtetra
.493 .675 .946 r
.39254 .57391 .3934 .57476 .39483 .57484 .39397 .57395 Mtetra
.928 .545 .235 r
.39397 .57395 .39483 .57484 .3961 .57923 .39525 .57789 Mtetra
.94 .684 .521 r
.39525 .57789 .3961 .57923 .39043 .76907 .38954 .76733 Mtetra
.939 .58 .184 r
.38954 .76733 .39043 .76907 .39177 .77375 .39087 .77251 Mtetra
.434 .573 .894 r
.39087 .77251 .39177 .77375 .39329 .77395 .39238 .77284 Mtetra
.684 .7 .858 r
.39238 .77284 .39329 .77395 .39483 .77326 .39392 .77225 Mtetra
.751 .733 .836 r
.39392 .77225 .39483 .77326 .3964 .77216 .39548 .77124 Mtetra
.678 .733 .892 r
.39548 .77124 .3964 .77216 .39794 .77171 .39702 .7707 Mtetra
.657 .71 .887 r
.39702 .7707 .39794 .77171 .39947 .77141 .39856 .77026 Mtetra
.651 .682 .866 r
.39856 .77026 .39947 .77141 .40101 .77114 .4001 .76984 Mtetra
.644 .656 .847 r
.4001 .76984 .40101 .77114 .40254 .77079 .40164 .76945 Mtetra
.64 .649 .843 r
.40164 .76945 .40254 .77079 .40408 .77041 .40319 .76907 Mtetra
.638 .647 .843 r
.40319 .76907 .40408 .77041 .40563 .77003 .40473 .76871 Mtetra
.629 .647 .849 r
.40473 .76871 .40563 .77003 .40716 .76984 .40627 .76839 Mtetra
.632 .631 .831 r
.40627 .76839 .40716 .76984 .4087 .76954 .40781 .76806 Mtetra
.641 .631 .824 r
.40781 .76806 .4087 .76954 .41026 .76894 .40936 .76766 Mtetra
.679 .672 .837 r
.40936 .76766 .41026 .76894 .41184 .76721 .41091 .76707 Mtetra
.652 .929 .972 r
.41091 .76707 .41184 .76721 .41346 .76449 .41246 .7664 Mtetra
.372 .014 .222 r
.41246 .7664 .41346 .76449 .41512 .76037 .41402 .76573 Mtetra
.553 .286 .464 r
.41402 .76573 .41512 .76037 .41669 .75929 .41556 .76571 Mtetra
.548 .291 .478 r
.41556 .76571 .41669 .75929 .41821 .75951 .4171 .76553 Mtetra
.507 .25 .46 r
.4171 .76553 .41821 .75951 .41977 .75873 .41866 .76469 Mtetra
.115 0 .315 r
.41866 .76469 .41977 .75873 .42663 .5748 .42034 .76005 Mtetra
0 0 .329 r
.42034 .76005 .42663 .5748 .42831 .56701 .42735 .56982 Mtetra
.885 .84 .376 r
.42735 .56982 .42831 .56701 .42985 .56395 .42898 .56378 Mtetra
.865 .906 .859 r
.42898 .56378 .42985 .56395 .43134 .56296 .43047 .56229 Mtetra
.661 .784 .94 r
.43047 .56229 .43134 .56296 .4328 .56266 .43194 .56184 Mtetra
.54 .704 .946 r
.43194 .56184 .4328 .56266 .43426 .56263 .4334 .56177 Mtetra
.626 .723 .916 r
.4334 .56177 .43426 .56263 .43573 .56235 .43487 .56146 Mtetra
.652 .725 .902 r
.43487 .56146 .43573 .56235 .4372 .56193 .43634 .56105 Mtetra
.655 .73 .904 r
.43634 .56105 .4372 .56193 .43867 .56145 .43782 .56064 Mtetra
.673 .749 .907 r
.43782 .56064 .43867 .56145 .44015 .56073 .43929 .56015 Mtetra
.672 .809 .949 r
.43929 .56015 .44015 .56073 .44163 .56004 .44077 .55964 Mtetra
.639 .856 .982 r
.44077 .55964 .44163 .56004 .44311 .5596 .44224 .55917 Mtetra
.565 .826 .995 r
.44224 .55917 .44311 .5596 .44456 .56018 .44372 .55888 Mtetra
.608 .632 .849 r
.44372 .55888 .44456 .56018 .44599 .56175 .44519 .55867 Mtetra
.599 .492 .704 r
.44519 .55867 .44599 .56175 .44739 .56466 .44666 .55847 Mtetra
.612 .447 .634 r
.44666 .55847 .44739 .56466 .44884 .56548 .44815 .55774 Mtetra
.603 .43 .62 r
.44815 .55774 .44884 .56548 .45034 .56446 .44963 .55704 Mtetra
.581 .416 .622 r
.44963 .55704 .45034 .56446 .45181 .56433 .4511 .55692 Mtetra
.405 .287 .604 r
.4511 .55692 .45181 .56433 .44943 .74676 .45251 .55987 Mtetra
0 0 .359 r
.45251 .55987 .44943 .74676 .45082 .75469 .45002 .74931 Mtetra
0 0 .412 r
.45002 .74931 .45082 .75469 .45233 .7573 .45145 .75562 Mtetra
.234 .388 .814 r
.45145 .75562 .45233 .7573 .45388 .75792 .45299 .75669 Mtetra
.619 .661 .869 r
.45299 .75669 .45388 .75792 .45545 .75764 .45456 .75642 Mtetra
.704 .691 .835 r
.45456 .75642 .45545 .75764 .45703 .75685 .45614 .75566 Mtetra
.654 .681 .863 r
.45614 .75566 .45703 .75685 .45862 .7555 .45771 .75522 Mtetra
.595 .884 .992 r
.45771 .75522 .45862 .7555 .46022 .75338 .45929 .75474 Mtetra
.095 0 0 r
.45929 .75474 .46022 .75338 .46186 .74963 .46087 .75366 Mtetra
0 0 .193 r
.46087 .75366 .46186 .74963 .4666 .56489 .46251 .74975 Mtetra
0 0 .35 r
.46251 .74975 .4666 .56489 .46825 .55508 .46732 .55961 Mtetra
0 0 0 r
.46732 .55961 .46825 .55508 .46979 .55195 .46893 .552 Mtetra
.911 .936 .813 r
.46893 .552 .46979 .55195 .47129 .55064 .47044 .55009 Mtetra
.675 .823 .954 r
.47044 .55009 .47129 .55064 .47278 .55014 .47194 .54956 Mtetra
.499 .76 .989 r
.47194 .54956 .47278 .55014 .47427 .54995 .47342 .54946 Mtetra
.547 .804 .993 r
.47342 .54946 .47427 .54995 .47576 .54976 .47491 .54922 Mtetra
.629 .817 .973 r
.47491 .54922 .47576 .54976 .47725 .5495 .47641 .54882 Mtetra
.641 .778 .946 r
.47641 .54882 .47725 .5495 .47874 .54925 .4779 .54843 Mtetra
.647 .742 .919 r
.4779 .54843 .47874 .54925 .48024 .54892 .4794 .54803 Mtetra
.65 .726 .905 r
.4794 .54803 .48024 .54892 .48173 .54851 .48089 .54762 Mtetra
.655 .729 .904 r
.48089 .54762 .48173 .54851 .48323 .54804 .48239 .5472 Mtetra
.665 .744 .91 r
.48239 .5472 .48323 .54804 .48473 .54746 .48389 .54674 Mtetra
.672 .775 .927 r
.48389 .54674 .48473 .54746 .48623 .54682 .48539 .54624 Mtetra
.671 .815 .952 r
.48539 .54624 .48623 .54682 .48773 .54617 .48689 .54573 Mtetra
.667 .852 .971 r
.48689 .54573 .48773 .54617 .48923 .54548 .48839 .54519 Mtetra
.639 .891 .985 r
.48839 .54519 .48923 .54548 .49074 .54486 .48989 .54465 Mtetra
.587 .899 .986 r
.48989 .54465 .49074 .54486 .49224 .54448 .4914 .54417 Mtetra
.543 .857 .997 r
.4914 .54417 .49224 .54448 .49373 .54488 .4929 .54383 Mtetra
.604 .678 .893 r
.4929 .54383 .49373 .54488 .49522 .5463 .4944 .54361 Mtetra
.602 .511 .723 r
.4944 .54361 .49522 .5463 .4967 .54892 .4959 .5434 Mtetra
.597 .443 .644 r
.4959 .5434 .4967 .54892 .49818 .55151 .49741 .54306 Mtetra
.593 .419 .616 r
.49741 .54306 .49818 .55151 .49969 .5514 .49892 .54257 Mtetra
.594 .418 .613 r
.49892 .54257 .49969 .5514 .50121 .55001 .50043 .54203 Mtetra
.595 .423 .619 r
.50043 .54203 .50121 .55001 .50272 .54899 .50193 .54152 Mtetra
.596 .426 .623 r
.50193 .54152 .50272 .54899 .50424 .54849 .50344 .54104 Mtetra
.595 .426 .623 r
.50344 .54104 .50424 .54849 .50575 .548 .50495 .54057 Mtetra
.50495 .54057 .50575 .548 .50726 .54753 .50647 .5401 Mtetra
.50647 .5401 .50726 .54753 .50878 .54707 .50798 .53963 Mtetra
.50798 .53963 .50878 .54707 .51029 .54661 .50949 .53917 Mtetra
.50949 .53917 .51029 .54661 .51181 .54616 .511 .53871 Mtetra
.511 .53871 .51181 .54616 .51332 .54571 .51252 .53824 Mtetra
.51252 .53824 .51332 .54571 .51484 .54526 .51403 .53778 Mtetra
.51403 .53778 .51484 .54526 .51636 .5448 .51555 .53732 Mtetra
.51555 .53732 .51636 .5448 .51788 .54435 .51707 .53685 Mtetra
.51707 .53685 .51788 .54435 .5194 .54388 .51859 .53639 Mtetra
.51859 .53639 .5194 .54388 .52092 .54342 .5201 .53592 Mtetra
.5201 .53592 .52092 .54342 .52244 .54295 .52162 .53546 Mtetra
.52162 .53546 .52244 .54295 .52397 .54248 .52314 .53499 Mtetra
.52314 .53499 .52397 .54248 .52549 .542 .52466 .53452 Mtetra
.52466 .53452 .52549 .542 .52701 .54152 .52619 .53405 Mtetra
.52619 .53405 .52701 .54152 .52854 .54103 .52771 .53358 Mtetra
.52771 .53358 .52854 .54103 .53007 .54053 .52923 .5331 Mtetra
.596 .427 .623 r
.52923 .5331 .53007 .54053 .53159 .54003 .53076 .53262 Mtetra
.53076 .53262 .53159 .54003 .53312 .53951 .53228 .53214 Mtetra
.596 .428 .624 r
.53228 .53214 .53312 .53951 .53465 .53896 .53381 .53165 Mtetra
.597 .428 .624 r
.53381 .53165 .53465 .53896 .53618 .53839 .53534 .53115 Mtetra
.597 .429 .625 r
.53534 .53115 .53618 .53839 .53771 .53783 .53686 .53066 Mtetra
.605 .435 .625 r
.53686 .53066 .53771 .53783 .53924 .5368 .53839 .52998 Mtetra
.611 .442 .628 r
.53839 .52998 .53924 .5368 .54076 .53552 .53992 .52917 Mtetra
.593 .433 .634 r
.53992 .52917 .54076 .53552 .5423 .53533 .54145 .52883 Mtetra
.504 .368 .629 r
.54145 .52883 .5423 .53533 .54386 .54081 .54299 .53016 Mtetra
0 0 .327 r
.54299 .53016 .54386 .54081 .54654 .72673 .54461 .54432 Mtetra
0 0 .403 r
.54461 .54432 .54654 .72673 .54819 .73052 .54732 .72819 Mtetra
0 .149 .67 r
.54732 .72819 .54819 .73052 .54983 .73182 .54896 .73054 Mtetra
.572 .636 .876 r
.54896 .73054 .54983 .73182 .55146 .73174 .55059 .73046 Mtetra
.681 .68 .843 r
.55059 .73046 .55146 .73174 .55309 .73131 .55222 .72983 Mtetra
.687 .657 .814 r
.55222 .72983 .55309 .73131 .55472 .7308 .55385 .72912 Mtetra
.642 .614 .806 r
.55385 .72912 .55472 .7308 .55635 .7304 .55548 .72868 Mtetra
.643 .61 .802 r
.55548 .72868 .55635 .7304 .55798 .72995 .55711 .72823 Mtetra
.64 .609 .803 r
.55711 .72823 .55798 .72995 .55961 .72951 .55874 .72781 Mtetra
.634 .608 .806 r
.55874 .72781 .55961 .72951 .56125 .72909 .56038 .72742 Mtetra
.64 .615 .809 r
.56038 .72742 .56125 .72909 .56288 .72848 .56201 .72701 Mtetra
.635 .636 .834 r
.56201 .72701 .56288 .72848 .56451 .72745 .56365 .72663 Mtetra
.611 .749 .943 r
.56365 .72663 .56451 .72745 .56613 .72566 .56529 .72631 Mtetra
0 0 0 r
.56529 .72631 .56613 .72566 .56774 .72281 .56692 .72555 Mtetra
.151 0 .215 r
.56692 .72555 .56774 .72281 .56929 .71584 .56854 .72337 Mtetra
0 0 .235 r
.56854 .72337 .56929 .71584 .56847 .52682 .57007 .71427 Mtetra
0 0 .401 r
.57007 .71427 .56847 .52682 .56997 .52243 .56918 .52351 Mtetra
.914 .924 .543 r
.56918 .52351 .56997 .52243 .57149 .5205 .57069 .52003 Mtetra
.733 .865 .943 r
.57069 .52003 .57149 .5205 .57304 .52002 .57223 .51925 Mtetra
.568 .737 .955 r
.57223 .51925 .57304 .52002 .57459 .51997 .57379 .51907 Mtetra
.514 .678 .94 r
.57379 .51907 .57459 .51997 .57615 .52004 .57534 .51908 Mtetra
.615 .706 .91 r
.57534 .51908 .57615 .52004 .5777 .51979 .5769 .5188 Mtetra
.607 .698 .908 r
.5769 .5188 .5777 .51979 .57926 .51951 .57845 .51856 Mtetra
.602 .702 .914 r
.57845 .51856 .57926 .51951 .58081 .51924 .58001 .51832 Mtetra
.604 .713 .921 r
.58001 .51832 .58081 .51924 .58237 .51896 .58156 .51807 Mtetra
.604 .719 .926 r
.58156 .51807 .58237 .51896 .58392 .51868 .58312 .51782 Mtetra
.604 .726 .931 r
.58312 .51782 .58392 .51868 .58548 .51839 .58468 .51756 Mtetra
.603 .733 .937 r
.58468 .51756 .58548 .51839 .58704 .51809 .58624 .5173 Mtetra
.616 .747 .939 r
.58624 .5173 .58704 .51809 .5886 .51775 .5878 .51698 Mtetra
.644 .762 .935 r
.5878 .51698 .5886 .51775 .59016 .51734 .58936 .51657 Mtetra
.686 .775 .919 r
.58936 .51657 .59016 .51734 .59172 .5168 .59092 .516 Mtetra
.7 .769 .906 r
.59092 .516 .59172 .5168 .59327 .51622 .59247 .51536 Mtetra
.703 .758 .895 r
.59247 .51536 .59327 .51622 .59483 .51561 .59403 .51471 Mtetra
.697 .746 .889 r
.59403 .51471 .59483 .51561 .59639 .51502 .59559 .51407 Mtetra
.696 .737 .882 r
.59559 .51407 .59639 .51502 .59795 .51443 .59715 .51344 Mtetra
.694 .728 .877 r
.59715 .51344 .59795 .51443 .59951 .51383 .59871 .51281 Mtetra
.69 .721 .873 r
.59871 .51281 .59951 .51383 .60107 .51324 .60027 .5122 Mtetra
.689 .715 .869 r
.60027 .5122 .60107 .51324 .60263 .51266 .60183 .51159 Mtetra
.688 .711 .866 r
.60183 .51159 .60263 .51266 .60419 .51206 .60339 .51098 Mtetra
.688 .709 .864 r
.60339 .51098 .60419 .51206 .60575 .51146 .60495 .51037 Mtetra
.688 .707 .863 r
.60495 .51037 .60575 .51146 .60732 .51085 .60652 .50976 Mtetra
.688 .707 .862 r
.60652 .50976 .60732 .51085 .60888 .51024 .60808 .50914 Mtetra
.691 .707 .86 r
.60808 .50914 .60888 .51024 .61045 .50963 .60965 .50851 Mtetra
.687 .702 .858 r
.60965 .50851 .61045 .50963 .61201 .509 .61121 .50789 Mtetra
.694 .706 .857 r
.61121 .50789 .61201 .509 .61358 .5083 .61278 .50724 Mtetra
.742 .73 .841 r
.61278 .50724 .61358 .5083 .61513 .50726 .61434 .5063 Mtetra
.677 .729 .889 r
.61434 .5063 .61513 .50726 .61669 .50652 .61591 .50575 Mtetra
.309 .612 .954 r
.61591 .50575 .61669 .50652 .61828 .5064 .6175 .5061 Mtetra
.917 .53 .25 r
.6175 .5061 .61828 .5064 .61992 .50825 .61923 .51097 Mtetra
.959 .68 .463 r
.61923 .51097 .61992 .50825 .62168 .51441 .62638 .70409 Mtetra
.576 .364 .557 r
.62638 .70409 .62168 .51441 .62886 .70375 .62819 .70845 Mtetra
.574 .293 .452 r
.62819 .70845 .62886 .70375 .63064 .70707 .62989 .70881 Mtetra
.446 .073 .236 r
.62989 .70881 .63064 .70707 .63238 .70852 .63157 .7085 Mtetra
.517 .91 .923 r
.63157 .7085 .63238 .70852 .63409 .70915 .63324 .70787 Mtetra
.642 .671 .862 r
.63324 .70787 .63409 .70915 .63578 .70907 .63492 .70746 Mtetra
.647 .627 .816 r
.63492 .70746 .63578 .70907 .63746 .70873 .6366 .70699 Mtetra
.647 .614 .802 r
.6366 .70699 .63746 .70873 .63914 .70826 .63828 .7065 Mtetra
.634 .606 .805 r
.63828 .7065 .63914 .70826 .64083 .70803 .63996 .70611 Mtetra
.635 .591 .787 r
.63996 .70611 .64083 .70803 .64251 .7076 .64165 .70568 Mtetra
.642 .594 .786 r
.64165 .70568 .64251 .7076 .64418 .70684 .64333 .70521 Mtetra
.616 .611 .823 r
.64333 .70521 .64418 .70684 .64582 .70516 .64502 .70493 Mtetra
.631 .919 .978 r
.64502 .70493 .64582 .70516 .64743 .70253 .6467 .70427 Mtetra
.145 0 .1 r
.6467 .70427 .64743 .70253 .64895 .69743 .64835 .70283 Mtetra
0 0 .26 r
.64835 .70283 .64895 .69743 .64381 .50579 .64983 .69659 Mtetra
.035 0 .429 r
.64983 .69659 .64381 .50579 .6452 .49998 .64453 .50207 Mtetra
.767 .773 .268 r
.64453 .50207 .6452 .49998 .64672 .49741 .64596 .49703 Mtetra
.79 .902 .921 r
.64596 .49703 .64672 .49741 .6483 .49669 .64753 .49597 Mtetra
.635 .777 .949 r
.64753 .49597 .6483 .49669 .64989 .49643 .64912 .49557 Mtetra
.538 .701 .945 r
.64912 .49557 .64989 .49643 .6515 .49641 .65073 .4955 Mtetra
.676 .743 .902 r
.65073 .4955 .6515 .49641 .65309 .49575 .65232 .49496 Mtetra
.67 .77 .925 r
.65232 .49496 .65309 .49575 .65468 .49519 .65391 .49443 Mtetra
.656 .776 .937 r
.65391 .49443 .65468 .49519 .65628 .49488 .6555 .49396 Mtetra
.716 .754 .882 r
.6555 .49396 .65628 .49488 .65791 .49538 .65709 .49322 Mtetra
.629 .56 .758 r
.65709 .49322 .65791 .49538 .65958 .49676 .65869 .49281 Mtetra
.556 .443 .681 r
.65869 .49281 .65958 .49676 .66136 .50052 .66032 .4931 Mtetra
.286 .209 .592 r
.66032 .4931 .66136 .50052 .67087 .69036 .66214 .49802 Mtetra
.055 0 .446 r
.66214 .49802 .67087 .69036 .6728 .6955 .67187 .69202 Mtetra
0 0 .544 r
.67187 .69202 .6728 .6955 .6746 .69746 .67378 .69648 Mtetra
.166 .485 .9 r
.67378 .69648 .6746 .69746 .67635 .69809 .67554 .69726 Mtetra
.606 .751 .947 r
.67554 .69726 .67635 .69809 .67806 .6979 .67725 .69694 Mtetra
.788 .772 .839 r
.67725 .69694 .67806 .6979 .67974 .69685 .67891 .69563 Mtetra
.912 .74 .655 r
.67891 .69563 .67974 .69685 .68127 .6924 .68043 .69091 Mtetra
.968 .689 .451 r
.68043 .69091 .68127 .6924 .67423 .49758 .67342 .49574 Mtetra
.909 .698 .605 r
.67342 .49574 .67423 .49758 .6755 .48967 .67473 .48869 Mtetra
.791 .76 .825 r
.67473 .48869 .6755 .48967 .67707 .48831 .6763 .48738 Mtetra
.631 .724 .914 r
.6763 .48738 .67707 .48831 .67868 .48795 .67791 .48702 Mtetra
.499 .669 .939 r
.67791 .48702 .67868 .48795 .68031 .48801 .67955 .48707 Mtetra
.643 .728 .91 r
.67955 .48707 .68031 .48801 .68193 .4876 .68116 .48667 Mtetra
.666 .737 .903 r
.68116 .48667 .68193 .4876 .68353 .48709 .68277 .48616 Mtetra
.672 .741 .902 r
.68277 .48616 .68353 .48709 .68514 .48655 .68438 .48563 Mtetra
.762 .767 .858 r
.68438 .48563 .68514 .48655 .68673 .48552 .68596 .4846 Mtetra
.719 .758 .883 r
.68596 .4846 .68673 .48552 .68833 .48475 .68756 .48384 Mtetra
.552 .697 .936 r
.68756 .48384 .68833 .48475 .68996 .48465 .6892 .48374 Mtetra
.833 .396 0 r
.6892 .48374 .68996 .48465 .69178 .48832 .69102 .48741 Mtetra
.97 .683 .428 r
.69102 .48741 .69178 .48832 .70334 .68322 .70254 .68238 Mtetra
.913 .514 .134 r
.70254 .68238 .70334 .68322 .70537 .68881 .70457 .68796 Mtetra
0 .391 .843 r
.70457 .68796 .70537 .68881 .70717 .68979 .70637 .68894 Mtetra
.605 .749 .946 r
.70637 .68894 .70717 .68979 .7089 .68947 .7081 .68862 Mtetra
.799 .801 .853 r
.7081 .68862 .7089 .68947 .71057 .68814 .70977 .6873 Mtetra
.935 .777 .66 r
.70977 .6873 .71057 .68814 .71208 .68365 .71129 .68282 Mtetra
.971 .689 .438 r
.71129 .68282 .71208 .68365 .70329 .48809 .70254 .48727 Mtetra
.958 .749 .579 r
.70254 .48727 .70329 .48809 .70454 .48068 .70378 .47979 Mtetra
.83 .785 .81 r
.70378 .47979 .70454 .48068 .7061 .47907 .70535 .47817 Mtetra
.66 .744 .912 r
.70535 .47817 .7061 .47907 .70772 .4786 .70697 .47769 Mtetra
.538 .693 .939 r
.70697 .47769 .70772 .4786 .70937 .47855 .70862 .47762 Mtetra
.718 .758 .884 r
.70862 .47762 .70937 .47855 .71098 .47778 .71023 .47686 Mtetra
.706 .755 .89 r
.71023 .47686 .71098 .47778 .7126 .47709 .71184 .47617 Mtetra
.55 .694 .935 r
.71184 .47617 .7126 .47709 .71425 .47703 .71349 .47608 Mtetra
.751 .301 0 r
.71349 .47608 .71425 .47703 .7161 .48045 .71533 .47923 Mtetra
.972 .682 .417 r
.71533 .47923 .7161 .48045 .7292 .67624 .72834 .67431 Mtetra
.832 .469 0 r
.72834 .67431 .7292 .67624 .7313 .68205 .73048 .68074 Mtetra
.159 .403 .848 r
.73048 .68074 .7313 .68205 .73311 .68294 .73231 .68187 Mtetra
.618 .705 .907 r
.73231 .68187 .73311 .68294 .73485 .68245 .73406 .68155 Mtetra
.797 .793 .849 r
.73406 .68155 .73485 .68245 .73654 .68112 .73575 .68021 Mtetra
.928 .778 .674 r
.73575 .68021 .73654 .68112 .73814 .6784 .73727 .67613 Mtetra
.971 .687 .431 r
.73727 .67613 .73814 .6784 .73956 .67277 .72713 .48171 Mtetra
.584 .374 .562 r
.72713 .48171 .73956 .67277 .72947 .48124 .72826 .47284 Mtetra
.637 .451 .615 r
.72826 .47284 .72947 .48124 .7309 .47735 .72981 .47092 Mtetra
.602 .44 .634 r
.72981 .47092 .7309 .47735 .73253 .47674 .73144 .47036 Mtetra
.582 .427 .636 r
.73144 .47036 .73253 .47674 .73422 .47707 .7331 .47024 Mtetra
.604 .438 .63 r
.7331 .47024 .73422 .47707 .73584 .47621 .73473 .46959 Mtetra
.606 .441 .632 r
.73473 .46959 .73584 .47621 .73746 .47533 .73636 .46892 Mtetra
.581 .426 .635 r
.73636 .46892 .73746 .47533 .73916 .47573 .73803 .46882 Mtetra
.433 .319 .624 r
.73803 .46882 .73916 .47573 .75304 .66212 .73988 .47156 Mtetra
.09 .014 .467 r
.73988 .47156 .75304 .66212 .75548 .67222 .75435 .66593 Mtetra
.001 .031 .536 r
.75435 .66593 .75548 .67222 .75745 .67506 .75661 .6732 Mtetra
.303 .411 .807 r
.75661 .6732 .75745 .67506 .75928 .67574 .75847 .6744 Mtetra
.615 .655 .866 r
.75847 .6744 .75928 .67574 .76105 .67545 .76024 .67411 Mtetra
.7 .692 .839 r
.76024 .67411 .76105 .67545 .76278 .67461 .76197 .67332 Mtetra
.701 .699 .845 r
.76197 .67332 .76278 .67461 .76445 .67299 .76371 .67253 Mtetra
.692 .887 .97 r
.76371 .67253 .76445 .67299 .76607 .67047 .76544 .67178 Mtetra
.275 0 .079 r
.76544 .67178 .76607 .67047 .76761 .66691 .76718 .67102 Mtetra
.529 .242 .424 r
.76718 .67102 .76761 .66691 .76926 .66497 .76896 .67076 Mtetra
.545 .28 .464 r
.76896 .67076 .76926 .66497 .77106 .66501 .77074 .67058 Mtetra
.513 .251 .455 r
.77074 .67058 .77106 .66501 .77281 .66445 .77248 .66982 Mtetra
.307 .086 .406 r
.77248 .66982 .77281 .66445 .77372 .65221 .77403 .66639 Mtetra
.984 .699 .365 r
.77403 .66639 .77372 .65221 .76211 .46641 .76192 .4731 Mtetra
0 0 .235 r
.76192 .4731 .76211 .46641 .76352 .46254 .76286 .46259 Mtetra
.929 .968 .757 r
.76286 .46259 .76352 .46254 .76511 .46105 .76439 .46034 Mtetra
.695 .807 .935 r
.76439 .46034 .76511 .46105 .76677 .46062 .76604 .45969 Mtetra
.581 .709 .93 r
.76604 .45969 .76677 .46062 .76846 .46051 .76772 .45949 Mtetra
.625 .709 .906 r
.76772 .45949 .76846 .46051 .77012 .46011 .76939 .45915 Mtetra
.67 .739 .902 r
.76939 .45915 .77012 .46011 .77177 .45949 .77105 .45861 Mtetra
.66 .756 .921 r
.77105 .45861 .77177 .45949 .77344 .45906 .77271 .45812 Mtetra
.694 .751 .896 r
.77271 .45812 .77344 .45906 .77515 .4592 .77436 .45747 Mtetra
.66 .616 .794 r
.77436 .45747 .77515 .4592 .77693 .46017 .77602 .45688 Mtetra
.584 .482 .704 r
.77602 .45688 .77693 .46017 .77883 .46269 .77772 .45683 Mtetra
.441 .336 .64 r
.77772 .45683 .77883 .46269 .79523 .65157 .7796 .45909 Mtetra
.119 .038 .48 r
.7796 .45909 .79523 .65157 .79776 .66081 .79641 .6524 Mtetra
.096 .079 .546 r
.79641 .6524 .79776 .66081 .79978 .66338 .79891 .66118 Mtetra
.296 .373 .773 r
.79891 .66118 .79978 .66338 .80163 .66389 .80085 .66268 Mtetra
.629 .686 .885 r
.80085 .66268 .80163 .66389 .8034 .66327 .80263 .66231 Mtetra
.733 .773 .885 r
.80263 .66231 .8034 .66327 .80514 .66226 .80438 .6614 Mtetra
.73 .794 .903 r
.80438 .6614 .80514 .66226 .80689 .66136 .80613 .66053 Mtetra
.683 .789 .93 r
.80613 .66053 .80689 .66136 .80865 .66071 .8079 .65989 Mtetra
.685 .792 .93 r
.8079 .65989 .80865 .66071 .81043 .66009 .80967 .65924 Mtetra
.685 .783 .925 r
.80967 .65924 .81043 .66009 .8122 .65948 .81144 .65859 Mtetra
.681 .774 .921 r
.81144 .65859 .8122 .65948 .81397 .65887 .81322 .65796 Mtetra
.676 .768 .92 r
.81322 .65796 .81397 .65887 .81575 .65828 .81499 .65735 Mtetra
.669 .762 .92 r
.81499 .65735 .81575 .65828 .81753 .65772 .81677 .65678 Mtetra
.66 .754 .92 r
.81677 .65678 .81753 .65772 .81932 .6572 .81856 .65624 Mtetra
.65 .747 .921 r
.81856 .65624 .81932 .6572 .82111 .65673 .82035 .65576 Mtetra
.634 .739 .924 r
.82035 .65576 .82111 .65673 .8229 .65629 .82215 .65533 Mtetra
.619 .736 .93 r
.82215 .65533 .8229 .65629 .8247 .6559 .82395 .65497 Mtetra
.61 .74 .937 r
.82395 .65497 .8247 .6559 .82651 .65556 .82575 .65463 Mtetra
.61 .739 .937 r
.82575 .65463 .82651 .65556 .82832 .65532 .82756 .6543 Mtetra
.618 .719 .918 r
.82756 .6543 .82832 .65532 .83015 .65517 .82937 .65395 Mtetra
.621 .683 .887 r
.82937 .65395 .83015 .65517 .83197 .65503 .83118 .65361 Mtetra
.619 .649 .858 r
.83118 .65361 .83197 .65503 .8338 .65487 .83299 .6533 Mtetra
.615 .625 .837 r
.83299 .6533 .8338 .65487 .83563 .65469 .83481 .653 Mtetra
.617 .613 .824 r
.83481 .653 .83563 .65469 .83745 .65446 .83663 .6527 Mtetra
.623 .607 .814 r
.83663 .6527 .83745 .65446 .83927 .65415 .83844 .65235 Mtetra
.63 .607 .808 r
.83844 .65235 .83927 .65415 .84108 .65376 .84025 .65196 Mtetra
.633 .609 .808 r
.84025 .65196 .84108 .65376 .84289 .65332 .84206 .65154 Mtetra
.635 .612 .809 r
.84206 .65154 .84289 .65332 .8447 .65287 .84387 .65111 Mtetra
.637 .615 .811 r
.84387 .65111 .8447 .65287 .84651 .65242 .84569 .65066 Mtetra
.638 .616 .811 r
.84569 .65066 .84651 .65242 .84832 .65196 .8475 .65021 Mtetra
.64 .617 .812 r
.8475 .65021 .84832 .65196 .85013 .6515 .84931 .64975 Mtetra
.641 .618 .812 r
.84931 .64975 .85013 .6515 .85194 .65103 .85112 .64928 Mtetra
.641 .619 .812 r
.85112 .64928 .85194 .65103 .85375 .65055 .85293 .64881 Mtetra
.642 .62 .813 r
.85293 .64881 .85375 .65055 .85556 .65008 .85475 .64834 Mtetra
.85475 .64834 .85556 .65008 .85738 .6496 .85656 .64786 Mtetra
.643 .621 .813 r
.85656 .64786 .85738 .6496 .85919 .64911 .85838 .64737 Mtetra
.85838 .64737 .85919 .64911 .86101 .64863 .86019 .64689 Mtetra
.644 .621 .813 r
.86019 .64689 .86101 .64863 .86282 .64814 .86201 .6464 Mtetra
.86201 .6464 .86282 .64814 .86464 .64765 .86383 .64591 Mtetra
.644 .621 .812 r
.86383 .64591 .86464 .64765 .86646 .64716 .86565 .64541 Mtetra
.86565 .64541 .86646 .64716 .86828 .64667 .86747 .64492 Mtetra
.86747 .64492 .86828 .64667 .8701 .64617 .86929 .64443 Mtetra
.645 .621 .812 r
.86929 .64443 .8701 .64617 .87192 .64568 .87111 .64393 Mtetra
.87111 .64393 .87192 .64568 .87374 .64518 .87293 .64343 Mtetra
.87293 .64343 .87374 .64518 .87557 .64468 .87476 .64293 Mtetra
.646 .621 .811 r
.87476 .64293 .87557 .64468 .87739 .64418 .87658 .64242 Mtetra
.87658 .64242 .87739 .64418 .87922 .64367 .8784 .64191 Mtetra
.647 .621 .81 r
.8784 .64191 .87922 .64367 .88104 .64316 .88023 .64139 Mtetra
.648 .621 .809 r
.88023 .64139 .88104 .64316 .88287 .64264 .88206 .64085 Mtetra
.65 .62 .807 r
.88206 .64085 .88287 .64264 .8847 .64213 .88388 .64031 Mtetra
.65 .617 .803 r
.88388 .64031 .8847 .64213 .88652 .64159 .88571 .63976 Mtetra
.651 .616 .802 r
.88571 .63976 .88652 .64159 .88835 .64099 .88753 .6392 Mtetra
.652 .622 .806 r
.88753 .6392 .88835 .64099 .89016 .64029 .88936 .63864 Mtetra
.656 .639 .821 r
.88936 .63864 .89016 .64029 .89197 .63957 .89119 .63807 Mtetra
.66 .661 .84 r
.89119 .63807 .89197 .63957 .89378 .63888 .89301 .6375 Mtetra
.664 .678 .854 r
.89301 .6375 .89378 .63888 .89561 .6383 .89484 .63692 Mtetra
.663 .678 .854 r
.89484 .63692 .89561 .6383 .89744 .63776 .89667 .63634 Mtetra
.661 .672 .85 r
.89667 .63634 .89744 .63776 .89928 .63723 .8985 .63577 Mtetra
.659 .665 .845 r
.8985 .63577 .89928 .63723 .90111 .63669 .90034 .63521 Mtetra
.655 .661 .843 r
.90034 .63521 .90111 .63669 .90295 .63617 .90217 .63467 Mtetra
.65 .656 .843 r
.90217 .63467 .90295 .63617 .90479 .63567 .90401 .63417 Mtetra
.642 .65 .843 r
.90401 .63417 .90479 .63567 .90664 .63522 .90586 .63371 Mtetra
.638 .648 .844 r
.90586 .63371 .90664 .63522 .90849 .63478 .90771 .63327 Mtetra
.615 .637 .849 r
.90771 .63327 .90849 .63478 .91036 .63447 .90958 .63297 Mtetra
.549 .605 .862 r
.90958 .63297 .91036 .63447 .91226 .63449 .91149 .63302 Mtetra
.636 .653 .849 r
.91149 .63302 .91226 .63449 .91412 .63405 .91335 .63259 Mtetra
.789 .72 .787 r
.91335 .63259 .91412 .63405 .91584 .63238 .91507 .63094 Mtetra
.957 .74 .569 r
.91507 .63094 .91584 .63238 .9169 .62496 .91614 .62356 Mtetra
.977 .674 .346 r
.91614 .62356 .9169 .62496 .89595 .42496 .89532 .42439 Mtetra
.978 .826 .625 r
.89532 .42439 .89595 .42496 .89725 .4206 .89661 .42001 Mtetra
.749 .871 .936 r
.89661 .42001 .89725 .4206 .89895 .4198 .8983 .41908 Mtetra
.579 .775 .972 r
.8983 .41908 .89895 .4198 .90073 .41967 .90007 .41879 Mtetra
.524 .704 .953 r
.90007 .41879 .90073 .41967 .90254 .41978 .90186 .41874 Mtetra
.659 .727 .9 r
.90186 .41874 .90254 .41978 .90428 .41928 .9036 .41823 Mtetra
.663 .726 .896 r
.9036 .41823 .90428 .41928 .90602 .41873 .90534 .4177 Mtetra
.685 .739 .892 r
.90534 .4177 .90602 .41873 .90774 .41806 .90707 .41706 Mtetra
.76 .772 .863 r
.90707 .41706 .90774 .41806 .90942 .41699 .90874 .416 Mtetra
.691 .75 .897 r
.90874 .416 .90942 .41699 .91114 .41633 .91047 .41534 Mtetra
.429 .623 .934 r
.91047 .41534 .91114 .41633 .91298 .41661 .91231 .41562 Mtetra
.788 .373 0 r
.91231 .41562 .91298 .41661 .91541 .42176 .91474 .42077 Mtetra
.973 .661 .312 r
.91474 .42077 .91541 .42176 .94127 .62062 .94057 .61969 Mtetra
.724 .285 0 r
.94057 .61969 .94127 .62062 .94371 .62487 .94301 .62394 Mtetra
.498 .693 .955 r
.94301 .62394 .94371 .62487 .94564 .62488 .94495 .62396 Mtetra
.693 .781 .919 r
.94495 .62396 .94564 .62488 .94748 .62417 .94679 .62325 Mtetra
.742 .799 .897 r
.94679 .62325 .94748 .62417 .9493 .6232 .9486 .62227 Mtetra
.495 .691 .955 r
.9486 .62227 .9493 .6232 .95123 .62322 .95054 .6223 Mtetra
.62 .752 .94 r
.95054 .6223 .95123 .62322 .95312 .62282 .95243 .6219 Mtetra
.799 .814 .864 r
.95243 .6219 .95312 .62282 .95489 .62147 .9542 .62054 Mtetra
.98 .776 .558 r
.9542 .62054 .95489 .62147 .95597 .61468 .95529 .61376 Mtetra
.975 .669 .322 r
.95529 .61376 .95597 .61468 .93271 .41462 .93204 .41363 Mtetra
.963 .784 .612 r
.93204 .41363 .93271 .41462 .93391 .4097 .93325 .40871 Mtetra
.756 .777 .87 r
.93325 .40871 .93391 .4097 .9356 .40866 .93494 .40767 Mtetra
.627 .726 .918 r
.93494 .40767 .9356 .40866 .93738 .40829 .93672 .40729 Mtetra
.544 .686 .931 r
.93672 .40729 .93738 .40829 .93919 .40821 .93854 .40722 Mtetra
.748 .774 .874 r
.93854 .40722 .93919 .40821 .9409 .40723 .94024 .40624 Mtetra
.681 .749 .903 r
.94024 .40624 .9409 .40723 .94264 .40661 .94199 .40561 Mtetra
.488 .656 .934 r
.94199 .40561 .94264 .40661 .94449 .40672 .94383 .40573 Mtetra
.738 .32 0 r
.94383 .40573 .94449 .40672 .94695 .4115 .94629 .41051 Mtetra
.97 .655 .291 r
.94629 .41051 .94695 .4115 .97496 .61125 .97428 .61031 Mtetra
.739 .309 0 r
.97428 .61031 .97496 .61125 .97754 .61601 .97686 .61507 Mtetra
.031 .462 .877 r
.36698 .77829 .36792 .77904 .3694 .77967 .36846 .77891 Mtetra
.643 .761 .935 r
.36846 .77891 .3694 .77967 .37092 .77927 .36999 .77851 Mtetra
.809 .778 .824 r
.36999 .77851 .37092 .77927 .37249 .77785 .37156 .77709 Mtetra
.908 .737 .659 r
.37156 .77709 .37249 .77785 .37421 .77263 .37329 .77186 Mtetra
.937 .686 .534 r
.37329 .77186 .37421 .77263 .38361 .5825 .38274 .58167 Mtetra
.908 .726 .645 r
.38274 .58167 .38361 .5825 .38527 .57682 .3844 .57599 Mtetra
.776 .758 .836 r
.3844 .57599 .38527 .57682 .38675 .57572 .38587 .57489 Mtetra
.642 .733 .915 r
.38587 .57489 .38675 .57572 .38819 .57536 .38732 .57453 Mtetra
.514 .689 .946 r
.38732 .57453 .38819 .57536 .38962 .57536 .38875 .57452 Mtetra
.745 .752 .858 r
.38875 .57452 .38962 .57536 .39108 .5745 .39021 .57365 Mtetra
.698 .744 .887 r
.39021 .57365 .39108 .5745 .39254 .57391 .39167 .57306 Mtetra
.5 .679 .946 r
.39167 .57306 .39254 .57391 .39397 .57395 .3931 .57309 Mtetra
.924 .537 .226 r
.3931 .57309 .39397 .57395 .39525 .57789 .39439 .57688 Mtetra
.94 .683 .522 r
.39439 .57688 .39525 .57789 .38954 .76733 .38863 .7662 Mtetra
.946 .591 .293 r
.38863 .7662 .38954 .76733 .39087 .77251 .38995 .77159 Mtetra
.33 .595 .942 r
.38995 .77159 .39087 .77251 .39238 .77284 .39146 .77195 Mtetra
.686 .743 .894 r
.39146 .77195 .39238 .77284 .39392 .77225 .393 .77138 Mtetra
.758 .759 .853 r
.393 .77138 .39392 .77225 .39548 .77124 .39456 .77037 Mtetra
.685 .749 .9 r
.39456 .77037 .39548 .77124 .39702 .7707 .39611 .76981 Mtetra
.664 .737 .904 r
.39611 .76981 .39702 .7707 .39856 .77026 .39765 .76933 Mtetra
.651 .727 .904 r
.39765 .76933 .39856 .77026 .4001 .76984 .39919 .76891 Mtetra
.615 .715 .917 r
.39919 .76891 .4001 .76984 .40164 .76945 .40073 .76863 Mtetra
.593 .734 .942 r
.40073 .76863 .40164 .76945 .40319 .76907 .40226 .76839 Mtetra
.576 .765 .968 r
.40226 .76839 .40319 .76907 .40473 .76871 .4038 .76816 Mtetra
.59 .805 .982 r
.4038 .76816 .40473 .76871 .40627 .76839 .40534 .76784 Mtetra
.603 .809 .979 r
.40534 .76784 .40627 .76839 .40781 .76806 .40689 .76749 Mtetra
.609 .807 .976 r
.40689 .76749 .40781 .76806 .40936 .76766 .40843 .76713 Mtetra
.594 .813 .983 r
.40843 .76713 .40936 .76766 .41091 .76707 .40997 .7668 Mtetra
.518 .858 .994 r
.40997 .7668 .41091 .76707 .41246 .7664 .41152 .76646 Mtetra
.299 .794 .843 r
.41152 .76646 .41246 .7664 .41402 .76573 .41307 .76611 Mtetra
.231 0 0 r
.41307 .76611 .41402 .76573 .41556 .76571 .41461 .76605 Mtetra
.054 0 0 r
.41461 .76605 .41556 .76571 .4171 .76553 .41615 .76581 Mtetra
.455 .882 .801 r
.41615 .76581 .4171 .76553 .41866 .76469 .41771 .76507 Mtetra
.951 .931 .742 r
.41771 .76507 .41866 .76469 .42034 .76005 .41934 .76234 Mtetra
.989 .864 .508 r
.41934 .76234 .42034 .76005 .42735 .56982 .42109 .7551 Mtetra
0 0 .336 r
.42109 .7551 .42735 .56982 .42898 .56378 .428 .56709 Mtetra
0 0 .099 r
.428 .56709 .42898 .56378 .43047 .56229 .42956 .56356 Mtetra
0 0 0 r
.42956 .56356 .43047 .56229 .43194 .56184 .43106 .56185 Mtetra
.79 .97 .915 r
.43106 .56185 .43194 .56184 .4334 .56177 .43255 .56076 Mtetra
.705 .715 .857 r
.43255 .56076 .4334 .56177 .43487 .56146 .43403 .56009 Mtetra
.651 .64 .826 r
.43403 .56009 .43487 .56146 .43634 .56105 .4355 .55967 Mtetra
.625 .626 .832 r
.4355 .55967 .43634 .56105 .43782 .56064 .43697 .55938 Mtetra
.629 .648 .85 r
.43697 .55938 .43782 .56064 .43929 .56015 .43844 .55908 Mtetra
.634 .683 .879 r
.43844 .55908 .43929 .56015 .44077 .55964 .43991 .55876 Mtetra
.641 .724 .909 r
.43991 .55876 .44077 .55964 .44224 .55917 .44139 .5584 Mtetra
.681 .76 .911 r
.44139 .5584 .44224 .55917 .44372 .55888 .44287 .55787 Mtetra
.693 .714 .865 r
.44287 .55787 .44372 .55888 .44519 .55867 .44435 .55727 Mtetra
.679 .647 .812 r
.44435 .55727 .44519 .55867 .44666 .55847 .44583 .55666 Mtetra
.685 .608 .765 r
.44583 .55666 .44666 .55847 .44815 .55774 .44732 .55588 Mtetra
.667 .596 .767 r
.44732 .55588 .44815 .55774 .44963 .55704 .4488 .55525 Mtetra
.608 .572 .788 r
.4488 .55525 .44963 .55704 .4511 .55692 .45028 .55504 Mtetra
.136 .284 .752 r
.45028 .55504 .4511 .55692 .45251 .55987 .45172 .55648 Mtetra
0 0 .226 r
.45172 .55648 .45251 .55987 .45002 .74931 .45308 .56185 Mtetra
0 0 .363 r
.45308 .56185 .45002 .74931 .45145 .75562 .45064 .75008 Mtetra
.275 .218 .61 r
.45064 .75008 .45145 .75562 .45299 .75669 .45214 .75342 Mtetra
.448 .395 .707 r
.45214 .75342 .45299 .75669 .45456 .75642 .45368 .75447 Mtetra
.507 .514 .799 r
.45368 .75447 .45456 .75642 .45614 .75566 .45524 .7548 Mtetra
.447 .67 .958 r
.45524 .7548 .45614 .75566 .45771 .75522 .4568 .75493 Mtetra
.437 .823 .988 r
.4568 .75493 .45771 .75522 .45929 .75474 .45837 .75471 Mtetra
.654 .952 .949 r
.45837 .75471 .45929 .75474 .46087 .75366 .45996 .75393 Mtetra
.941 .938 .761 r
.45996 .75393 .46087 .75366 .46251 .74975 .46157 .75142 Mtetra
.994 .869 .541 r
.46157 .75142 .46251 .74975 .46732 .55961 .46325 .74498 Mtetra
0 0 .354 r
.46325 .74498 .46732 .55961 .46893 .552 .468 .55584 Mtetra
.117 0 .266 r
.468 .55584 .46893 .552 .47044 .55009 .46954 .55278 Mtetra
.478 .165 .356 r
.46954 .55278 .47044 .55009 .47194 .54956 .47103 .55235 Mtetra
.535 .223 .385 r
.47103 .55235 .47194 .54956 .47342 .54946 .47252 .55233 Mtetra
.331 .037 .305 r
.47252 .55233 .47342 .54946 .47491 .54922 .47403 .55096 Mtetra
0 0 0 r
.47403 .55096 .47491 .54922 .47641 .54882 .47555 .54906 Mtetra
.848 .994 .838 r
.47555 .54906 .47641 .54882 .4779 .54843 .47706 .54754 Mtetra
.732 .748 .865 r
.47706 .54754 .4779 .54843 .4794 .54803 .47856 .54673 Mtetra
.635 .645 .843 r
.47856 .54673 .4794 .54803 .48089 .54762 .48006 .54639 Mtetra
.604 .643 .862 r
.48006 .54639 .48089 .54762 .48239 .5472 .48155 .54619 Mtetra
.628 .694 .892 r
.48155 .54619 .48239 .5472 .48389 .54674 .48305 .54588 Mtetra
.659 .738 .908 r
.48305 .54588 .48389 .54674 .48539 .54624 .48455 .54544 Mtetra
.667 .753 .915 r
.48455 .54544 .48539 .54624 .48689 .54573 .48605 .54496 Mtetra
.667 .763 .922 r
.48605 .54496 .48689 .54573 .48839 .54519 .48755 .54448 Mtetra
.668 .779 .932 r
.48755 .54448 .48839 .54519 .48989 .54465 .48905 .544 Mtetra
.675 .793 .937 r
.48905 .544 .48989 .54465 .4914 .54417 .49056 .54348 Mtetra
.694 .789 .923 r
.49056 .54348 .4914 .54417 .4929 .54383 .49206 .54289 Mtetra
.7 .732 .876 r
.49206 .54289 .4929 .54383 .4944 .54361 .49357 .54225 Mtetra
.683 .657 .818 r
.49357 .54225 .4944 .54361 .4959 .5434 .49508 .54162 Mtetra
.66 .601 .778 r
.49508 .54162 .4959 .5434 .49741 .54306 .49658 .54106 Mtetra
.647 .577 .762 r
.49658 .54106 .49741 .54306 .49892 .54257 .49809 .54055 Mtetra
.644 .574 .761 r
.49809 .54055 .49892 .54257 .50043 .54203 .4996 .54006 Mtetra
.644 .578 .765 r
.4996 .54006 .50043 .54203 .50193 .54152 .50111 .53958 Mtetra
.645 .581 .768 r
.50111 .53958 .50193 .54152 .50344 .54104 .50262 .53911 Mtetra
.644 .581 .769 r
.50262 .53911 .50344 .54104 .50495 .54057 .50413 .53864 Mtetra
.644 .58 .769 r
.50413 .53864 .50495 .54057 .50647 .5401 .50564 .53817 Mtetra
.643 .58 .769 r
.50564 .53817 .50647 .5401 .50798 .53963 .50715 .5377 Mtetra
.50715 .5377 .50798 .53963 .50949 .53917 .50867 .53723 Mtetra
.50867 .53723 .50949 .53917 .511 .53871 .51018 .53677 Mtetra
.51018 .53677 .511 .53871 .51252 .53824 .51169 .53631 Mtetra
.51169 .53631 .51252 .53824 .51403 .53778 .51321 .53584 Mtetra
.643 .58 .768 r
.51321 .53584 .51403 .53778 .51555 .53732 .51473 .53538 Mtetra
.643 .579 .768 r
.51473 .53538 .51555 .53732 .51707 .53685 .51624 .53491 Mtetra
.51624 .53491 .51707 .53685 .51859 .53639 .51776 .53445 Mtetra
.51776 .53445 .51859 .53639 .5201 .53592 .51928 .53398 Mtetra
.51928 .53398 .5201 .53592 .52162 .53546 .5208 .53351 Mtetra
.5208 .53351 .52162 .53546 .52314 .53499 .52232 .53304 Mtetra
.643 .58 .768 r
.52232 .53304 .52314 .53499 .52466 .53452 .52384 .53257 Mtetra
.52384 .53257 .52466 .53452 .52619 .53405 .52536 .5321 Mtetra
.52536 .5321 .52619 .53405 .52771 .53358 .52689 .53163 Mtetra
.644 .58 .768 r
.52689 .53163 .52771 .53358 .52923 .5331 .52841 .53116 Mtetra
.52841 .53116 .52923 .5331 .53076 .53262 .52993 .53068 Mtetra
.644 .581 .769 r
.52993 .53068 .53076 .53262 .53228 .53214 .53146 .5302 Mtetra
.645 .582 .769 r
.53146 .5302 .53228 .53214 .53381 .53165 .53299 .52972 Mtetra
.646 .582 .769 r
.53299 .52972 .53381 .53165 .53534 .53115 .53451 .52923 Mtetra
.646 .583 .77 r
.53451 .52923 .53534 .53115 .53686 .53066 .53604 .52874 Mtetra
.662 .591 .766 r
.53604 .52874 .53686 .53066 .53839 .52998 .53757 .52812 Mtetra
.674 .603 .767 r
.53757 .52812 .53839 .52998 .53992 .52917 .5391 .52741 Mtetra
.635 .592 .789 r
.5391 .52741 .53992 .52917 .54145 .52883 .54063 .52702 Mtetra
.413 .466 .806 r
.54063 .52702 .54145 .52883 .54299 .53016 .54217 .52772 Mtetra
0 0 .45 r
.54217 .52772 .54299 .53016 .54461 .54432 .54372 .53126 Mtetra
.974 .703 .456 r
.54372 .53126 .54461 .54432 .54732 .72819 .54641 .72023 Mtetra
.227 .161 .569 r
.54641 .72023 .54732 .72819 .54896 .73054 .54807 .72583 Mtetra
.572 .442 .665 r
.54807 .72583 .54896 .73054 .55059 .73046 .5497 .72592 Mtetra
.629 .483 .665 r
.5497 .72592 .55059 .73046 .55222 .72983 .55133 .72511 Mtetra
.641 .488 .66 r
.55133 .72511 .55222 .72983 .55385 .72912 .55295 .72404 Mtetra
.618 .467 .655 r
.55295 .72404 .55385 .72912 .55548 .72868 .55458 .72335 Mtetra
.598 .451 .652 r
.55458 .72335 .55548 .72868 .55711 .72823 .55621 .72299 Mtetra
.545 .415 .655 r
.55621 .72299 .55711 .72823 .55874 .72781 .55785 .7235 Mtetra
.467 .379 .673 r
.55785 .7235 .55874 .72781 .56038 .72742 .5595 .72476 Mtetra
.437 .422 .744 r
.5595 .72476 .56038 .72742 .56201 .72701 .56115 .7257 Mtetra
.379 .536 .886 r
.56115 .7257 .56201 .72701 .56365 .72663 .56279 .72623 Mtetra
.255 .701 .958 r
.56279 .72623 .56365 .72663 .56529 .72631 .56444 .72633 Mtetra
.346 .823 .869 r
.56444 .72633 .56529 .72631 .56692 .72555 .56608 .72592 Mtetra
.709 .979 .78 r
.56608 .72592 .56692 .72555 .56854 .72337 .56771 .72452 Mtetra
.924 .924 .546 r
.56771 .72452 .56854 .72337 .57007 .71427 .5693 .72072 Mtetra
.902 .749 .251 r
.5693 .72072 .57007 .71427 .56918 .52351 .57073 .70383 Mtetra
0 0 .406 r
.57073 .70383 .56918 .52351 .57069 .52003 .56993 .52265 Mtetra
.067 0 .182 r
.56993 .52265 .57069 .52003 .57223 .51925 .57145 .52024 Mtetra
0 0 0 r
.57145 .52024 .57223 .51925 .57379 .51907 .57299 .51892 Mtetra
.694 .944 .96 r
.57299 .51892 .57379 .51907 .57534 .51908 .57454 .51813 Mtetra
.652 .721 .899 r
.57454 .51813 .57534 .51908 .5769 .5188 .57609 .51771 Mtetra
.602 .672 .89 r
.57609 .51771 .5769 .5188 .57845 .51856 .57764 .5175 Mtetra
.581 .671 .901 r
.57764 .5175 .57845 .51856 .58001 .51832 .5792 .51736 Mtetra
.609 .703 .91 r
.5792 .51736 .58001 .51832 .58156 .51807 .58076 .5171 Mtetra
.611 .701 .908 r
.58076 .5171 .58156 .51807 .58312 .51782 .58232 .51684 Mtetra
.614 .7 .906 r
.58232 .51684 .58312 .51782 .58468 .51756 .58388 .51656 Mtetra
.62 .7 .901 r
.58388 .51656 .58468 .51756 .58624 .5173 .58544 .51627 Mtetra
.634 .698 .892 r
.58544 .51627 .58624 .5173 .5878 .51698 .587 .51592 Mtetra
.654 .699 .879 r
.587 .51592 .5878 .51698 .58936 .51657 .58855 .51548 Mtetra
.681 .704 .865 r
.58855 .51548 .58936 .51657 .59092 .516 .59011 .51491 Mtetra
.691 .707 .86 r
.59011 .51491 .59092 .516 .59247 .51536 .59167 .51427 Mtetra
.695 .709 .859 r
.59167 .51427 .59247 .51536 .59403 .51471 .59323 .51362 Mtetra
.693 .709 .86 r
.59323 .51362 .59403 .51471 .59559 .51407 .59479 .51298 Mtetra
.693 .708 .859 r
.59479 .51298 .59559 .51407 .59715 .51344 .59634 .51234 Mtetra
.691 .706 .859 r
.59634 .51234 .59715 .51344 .59871 .51281 .5979 .51171 Mtetra
.686 .703 .861 r
.5979 .51171 .59871 .51281 .60027 .5122 .59947 .5111 Mtetra
.688 .706 .861 r
.59947 .5111 .60027 .5122 .60183 .51159 .60103 .51049 Mtetra
.695 .707 .857 r
.60103 .51049 .60183 .51159 .60339 .51098 .60259 .50983 Mtetra
.706 .703 .845 r
.60259 .50983 .60339 .51098 .60495 .51037 .60415 .5091 Mtetra
.7 .681 .829 r
.60415 .5091 .60495 .51037 .60652 .50976 .60571 .50836 Mtetra
.693 .662 .815 r
.60571 .50836 .60652 .50976 .60808 .50914 .60727 .50765 Mtetra
.692 .649 .803 r
.60727 .50765 .60808 .50914 .60965 .50851 .60884 .5069 Mtetra
.666 .625 .799 r
.60884 .5069 .60965 .50851 .61121 .50789 .6104 .50632 Mtetra
.626 .61 .815 r
.6104 .50632 .61121 .50789 .61278 .50724 .61198 .506 Mtetra
.512 .605 .883 r
.61198 .506 .61278 .50724 .61434 .5063 .61357 .50614 Mtetra
.464 0 0 r
.61357 .50614 .61434 .5063 .61591 .50575 .61517 .50693 Mtetra
.78 .402 .339 r
.61517 .50693 .61591 .50575 .6175 .5061 .61683 .50943 Mtetra
.958 .679 .465 r
.61683 .50943 .6175 .5061 .61923 .51097 .62377 .70002 Mtetra
.579 .367 .557 r
.62377 .70002 .61923 .51097 .62638 .70409 .62564 .70665 Mtetra
.701 .368 .41 r
.62564 .70665 .62638 .70409 .62819 .70845 .62739 .70874 Mtetra
.243 0 0 r
.62739 .70874 .62819 .70845 .62989 .70881 .62908 .70877 Mtetra
.484 .894 .922 r
.62908 .70877 .62989 .70881 .63157 .7085 .63075 .70821 Mtetra
.769 .929 .938 r
.63075 .70821 .63157 .7085 .63324 .70787 .63241 .70717 Mtetra
.832 .824 .841 r
.63241 .70717 .63324 .70787 .63492 .70746 .63406 .70563 Mtetra
.778 .663 .737 r
.63406 .70563 .63492 .70746 .6366 .70699 .63569 .7037 Mtetra
.725 .571 .681 r
.63569 .7037 .6366 .70699 .63828 .7065 .63732 .70157 Mtetra
.641 .485 .657 r
.63732 .70157 .63828 .7065 .63996 .70611 .63898 .70044 Mtetra
.597 .447 .648 r
.63898 .70044 .63996 .70611 .64165 .70568 .64066 .70007 Mtetra
.554 .418 .65 r
.64066 .70007 .64165 .70568 .64333 .70521 .64237 .70048 Mtetra
.436 .352 .663 r
.64237 .70048 .64333 .70521 .64502 .70493 .64413 .70223 Mtetra
.445 .427 .745 r
.64413 .70223 .64502 .70493 .6467 .70427 .64586 .70317 Mtetra
.537 .66 .916 r
.64586 .70317 .6467 .70427 .64835 .70283 .64756 .70316 Mtetra
.961 .942 .692 r
.64756 .70316 .64835 .70283 .64983 .69659 .64916 .7001 Mtetra
.786 .724 .193 r
.64916 .7001 .64983 .69659 .64453 .50207 .65056 .69167 Mtetra
.042 0 .432 r
.65056 .69167 .64453 .50207 .64596 .49703 .64532 .5001 Mtetra
.097 0 .243 r
.64532 .5001 .64596 .49703 .64753 .49597 .64683 .49725 Mtetra
0 0 0 r
.64683 .49725 .64753 .49597 .64912 .49557 .64838 .49566 Mtetra
.678 .977 .878 r
.64838 .49566 .64912 .49557 .65073 .4955 .64995 .49464 Mtetra
.703 .764 .899 r
.64995 .49464 .65073 .4955 .65232 .49496 .65154 .49397 Mtetra
.664 .724 .894 r
.65154 .49397 .65232 .49496 .65391 .49443 .65313 .49349 Mtetra
.648 .725 .905 r
.65313 .49349 .65391 .49443 .6555 .49396 .65473 .49306 Mtetra
.774 .772 .85 r
.65473 .49306 .6555 .49396 .65709 .49322 .6563 .49195 Mtetra
.705 .688 .831 r
.6563 .49195 .65709 .49322 .65869 .49281 .65788 .49119 Mtetra
.586 .586 .819 r
.65788 .49119 .65869 .49281 .66032 .4931 .6595 .49109 Mtetra
0 0 .387 r
.6595 .49109 .66032 .4931 .66214 .49802 .66127 .49489 Mtetra
.971 .687 .434 r
.66127 .49489 .66214 .49802 .67187 .69202 .67101 .6899 Mtetra
.784 .432 0 r
.67101 .6899 .67187 .69202 .67378 .69648 .67296 .69561 Mtetra
.076 .451 .882 r
.67296 .69561 .67378 .69648 .67554 .69726 .67472 .69644 Mtetra
.615 .758 .947 r
.67472 .69644 .67554 .69726 .67725 .69694 .67643 .69608 Mtetra
.805 .796 .844 r
.67643 .69608 .67725 .69694 .67891 .69563 .6781 .69469 Mtetra
.93 .762 .652 r
.6781 .69469 .67891 .69563 .68043 .69091 .67961 .68988 Mtetra
.968 .689 .45 r
.67961 .68988 .68043 .69091 .67342 .49574 .67264 .49458 Mtetra
.937 .732 .6 r
.67264 .49458 .67342 .49574 .67473 .48869 .67396 .48775 Mtetra
.793 .767 .83 r
.67396 .48775 .67473 .48869 .6763 .48738 .67553 .48645 Mtetra
.631 .724 .915 r
.67553 .48645 .6763 .48738 .67791 .48702 .67715 .48609 Mtetra
.5 .669 .939 r
.67715 .48609 .67791 .48702 .67955 .48707 .67878 .48614 Mtetra
.642 .729 .912 r
.67878 .48614 .67955 .48707 .68116 .48667 .68039 .48574 Mtetra
.665 .738 .905 r
.68039 .48574 .68116 .48667 .68277 .48616 .682 .48524 Mtetra
.671 .742 .903 r
.682 .48524 .68277 .48616 .68438 .48563 .68361 .48471 Mtetra
.761 .768 .858 r
.68361 .48471 .68438 .48563 .68596 .4846 .6852 .48369 Mtetra
.719 .758 .884 r
.6852 .48369 .68596 .4846 .68756 .48384 .6868 .48292 Mtetra
.552 .697 .936 r
.6868 .48292 .68756 .48384 .6892 .48374 .68843 .48283 Mtetra
.833 .397 0 r
.68843 .48283 .6892 .48374 .69102 .48741 .69026 .4865 Mtetra
.97 .683 .428 r
.69026 .4865 .69102 .48741 .70254 .68238 .70174 .68153 Mtetra
.913 .514 .133 r
.70174 .68153 .70254 .68238 .70457 .68796 .70377 .68711 Mtetra
0 .391 .844 r
.70377 .68711 .70457 .68796 .70637 .68894 .70556 .68809 Mtetra
.605 .748 .946 r
.70556 .68809 .70637 .68894 .7081 .68862 .70729 .68777 Mtetra
.799 .8 .853 r
.70729 .68777 .7081 .68862 .70977 .6873 .70897 .68645 Mtetra
.935 .777 .661 r
.70897 .68645 .70977 .6873 .71129 .68282 .71049 .68198 Mtetra
.971 .689 .438 r
.71049 .68198 .71129 .68282 .70254 .48727 .70178 .48639 Mtetra
.956 .746 .58 r
.70178 .48639 .70254 .48727 .70378 .47979 .70303 .47888 Mtetra
.829 .783 .808 r
.70303 .47888 .70378 .47979 .70535 .47817 .70459 .47726 Mtetra
.661 .742 .91 r
.70459 .47726 .70535 .47817 .70697 .47769 .70621 .47677 Mtetra
.541 .693 .938 r
.70621 .47677 .70697 .47769 .70862 .47762 .70786 .4767 Mtetra
.718 .759 .884 r
.70786 .4767 .70862 .47762 .71023 .47686 .70947 .47594 Mtetra
.706 .754 .889 r
.70947 .47594 .71023 .47686 .71184 .47617 .71109 .47524 Mtetra
.553 .695 .934 r
.71109 .47524 .71184 .47617 .71349 .47608 .71274 .47514 Mtetra
.746 .293 0 r
.71274 .47514 .71349 .47608 .71533 .47923 .71457 .47822 Mtetra
.972 .682 .417 r
.71457 .47822 .71533 .47923 .72834 .67431 .72754 .67317 Mtetra
.915 .531 .119 r
.72754 .67317 .72834 .67431 .73048 .68074 .72968 .67977 Mtetra
0 .326 .807 r
.72968 .67977 .73048 .68074 .73231 .68187 .73152 .68099 Mtetra
.596 .738 .943 r
.73152 .68099 .73231 .68187 .73406 .68155 .73327 .68071 Mtetra
.805 .807 .853 r
.73327 .68071 .73406 .68155 .73575 .68021 .73496 .67934 Mtetra
.942 .774 .645 r
.73496 .67934 .73575 .68021 .73727 .67613 .73643 .67446 Mtetra
.972 .687 .43 r
.73643 .67446 .73727 .67613 .72713 .48171 .72614 .47671 Mtetra
.798 .583 .611 r
.72614 .47671 .72713 .48171 .72826 .47284 .72742 .47041 Mtetra
.732 .602 .712 r
.72742 .47041 .72826 .47284 .72981 .47092 .72898 .46874 Mtetra
.635 .564 .757 r
.72898 .46874 .72981 .47092 .73144 .47036 .73062 .46828 Mtetra
.582 .542 .776 r
.73062 .46828 .73144 .47036 .7331 .47024 .73229 .46823 Mtetra
.645 .582 .769 r
.73229 .46823 .7331 .47024 .73473 .46959 .73393 .46771 Mtetra
.66 .6 .777 r
.73393 .46771 .73473 .46959 .73636 .46892 .73556 .4671 Mtetra
.607 .579 .796 r
.73556 .4671 .73636 .46892 .73803 .46882 .73722 .46687 Mtetra
.276 .372 .781 r
.73722 .46687 .73803 .46882 .73988 .47156 .73898 .46823 Mtetra
0 0 .511 r
.73898 .46823 .73988 .47156 .75435 .66593 .74099 .47318 Mtetra
.099 .02 .47 r
.74099 .47318 .75435 .66593 .75661 .6732 .75548 .66711 Mtetra
.329 .261 .627 r
.75548 .66711 .75661 .6732 .75847 .6744 .75751 .67086 Mtetra
.468 .407 .706 r
.75751 .67086 .75847 .6744 .76024 .67411 .75937 .67197 Mtetra
.514 .511 .79 r
.75937 .67197 .76024 .67411 .76197 .67332 .76119 .67235 Mtetra
.522 .688 .943 r
.76119 .67235 .76197 .67332 .76371 .67253 .76297 .67233 Mtetra
.371 .817 .947 r
.76297 .67233 .76371 .67253 .76544 .67178 .76475 .67205 Mtetra
0 0 0 r
.76475 .67205 .76544 .67178 .76718 .67102 .76651 .6716 Mtetra
.205 0 0 r
.76651 .6716 .76718 .67102 .76896 .67076 .76828 .67129 Mtetra
.14 0 0 r
.76828 .67129 .76896 .67076 .77074 .67058 .77005 .67091 Mtetra
0 0 0 r
.77005 .67091 .77074 .67058 .77248 .66982 .77179 .6701 Mtetra
.891 .985 .72 r
.77179 .6701 .77248 .66982 .77403 .66639 .77342 .66778 Mtetra
.903 .842 .385 r
.77342 .66778 .77403 .66639 .76192 .4731 .77482 .66229 Mtetra
.092 .011 .463 r
.77482 .66229 .76192 .4731 .76286 .46259 .76254 .46739 Mtetra
.029 0 .313 r
.76254 .46739 .76286 .46259 .76439 .46034 .76384 .46196 Mtetra
0 0 .033 r
.76384 .46196 .76439 .46034 .76604 .45969 .76539 .45985 Mtetra
.71 .983 .806 r
.76539 .45985 .76604 .45969 .76772 .45949 .76699 .45855 Mtetra
.717 .758 .885 r
.76699 .45855 .76772 .45949 .76939 .45915 .76863 .45778 Mtetra
.646 .653 .843 r
.76863 .45778 .76939 .45915 .77105 .45861 .77029 .45734 Mtetra
.622 .658 .864 r
.77029 .45734 .77105 .45861 .77271 .45812 .77197 .45703 Mtetra
.7 .724 .868 r
.77197 .45703 .77271 .45812 .77436 .45747 .77362 .45632 Mtetra
.725 .723 .848 r
.77362 .45632 .77436 .45747 .77602 .45688 .77525 .45545 Mtetra
.653 .648 .832 r
.77525 .45545 .77602 .45688 .77772 .45683 .77692 .45496 Mtetra
.383 .447 .803 r
.77692 .45496 .77772 .45683 .7796 .45909 .7787 .45588 Mtetra
0 .067 .597 r
.7787 .45588 .7796 .45909 .79641 .6524 .78072 .45996 Mtetra
.116 .036 .48 r
.78072 .45996 .79641 .6524 .79891 .66118 .79766 .65406 Mtetra
.307 .236 .611 r
.79766 .65406 .79891 .66118 .80085 .66268 .79985 .65886 Mtetra
.47 .4 .696 r
.79985 .65886 .80085 .66268 .80263 .66231 .80177 .66006 Mtetra
.522 .508 .781 r
.80177 .66006 .80263 .66231 .80438 .6614 .80361 .66042 Mtetra
.569 .709 .936 r
.80361 .66042 .80438 .6614 .80613 .66053 .80542 .66025 Mtetra
.554 .893 .983 r
.80542 .66025 .80613 .66053 .8079 .65989 .8072 .65972 Mtetra
.606 .935 .956 r
.8072 .65972 .8079 .65989 .80967 .65924 .80897 .65897 Mtetra
.66 .935 .968 r
.80897 .65897 .80967 .65924 .81144 .65859 .81073 .65818 Mtetra
.685 .905 .974 r
.81073 .65818 .81144 .65859 .81322 .65796 .81249 .65742 Mtetra
.701 .872 .962 r
.81249 .65742 .81322 .65796 .81499 .65735 .81425 .65665 Mtetra
.687 .825 .949 r
.81425 .65665 .81499 .65735 .81677 .65678 .81603 .65598 Mtetra
.663 .791 .943 r
.81603 .65598 .81677 .65678 .81856 .65624 .81781 .65541 Mtetra
.647 .777 .943 r
.81781 .65541 .81856 .65624 .82035 .65576 .8196 .65491 Mtetra
.609 .76 .951 r
.8196 .65491 .82035 .65576 .82215 .65533 .8214 .65456 Mtetra
.578 .765 .967 r
.8214 .65456 .82215 .65533 .82395 .65497 .82321 .65428 Mtetra
.617 .804 .971 r
.82321 .65428 .82395 .65497 .82575 .65463 .82501 .65384 Mtetra
.753 .82 .905 r
.82501 .65384 .82575 .65463 .82756 .6543 .82676 .65285 Mtetra
.795 .717 .778 r
.82676 .65285 .82756 .6543 .82937 .65395 .82845 .65111 Mtetra
.741 .598 .697 r
.82845 .65111 .82937 .65395 .83118 .65361 .83011 .64901 Mtetra
.666 .508 .661 r
.83011 .64901 .83118 .65361 .83299 .6533 .83181 .64742 Mtetra
.593 .444 .648 r
.83181 .64742 .83299 .6533 .83481 .653 .83362 .6471 Mtetra
.575 .431 .648 r
.83362 .6471 .83481 .653 .83663 .6527 .83546 .64714 Mtetra
.58 .439 .653 r
.83546 .64714 .83663 .6527 .83844 .65235 .8373 .6471 Mtetra
.594 .452 .658 r
.8373 .6471 .83844 .65235 .84025 .65196 .83912 .64681 Mtetra
.596 .455 .659 r
.83912 .64681 .84025 .65196 .84206 .65154 .84094 .64648 Mtetra
.598 .458 .661 r
.84094 .64648 .84206 .65154 .84387 .65111 .84276 .64611 Mtetra
.6 .46 .662 r
.84276 .64611 .84387 .65111 .84569 .65066 .84457 .64572 Mtetra
.602 .462 .663 r
.84457 .64572 .84569 .65066 .8475 .65021 .84638 .64531 Mtetra
.603 .463 .664 r
.84638 .64531 .8475 .65021 .84931 .64975 .8482 .64489 Mtetra
.604 .464 .664 r
.8482 .64489 .84931 .64975 .85112 .64928 .85001 .64445 Mtetra
.605 .465 .665 r
.85001 .64445 .85112 .64928 .85293 .64881 .85182 .64399 Mtetra
.605 .466 .665 r
.85182 .64399 .85293 .64881 .85475 .64834 .85364 .64353 Mtetra
.606 .467 .666 r
.85364 .64353 .85475 .64834 .85656 .64786 .85545 .64306 Mtetra
.85545 .64306 .85656 .64786 .85838 .64737 .85727 .64258 Mtetra
.607 .467 .666 r
.85727 .64258 .85838 .64737 .86019 .64689 .85908 .64209 Mtetra
.607 .468 .666 r
.85908 .64209 .86019 .64689 .86201 .6464 .8609 .6416 Mtetra
.8609 .6416 .86201 .6464 .86383 .64591 .86271 .64111 Mtetra
.86271 .64111 .86383 .64591 .86565 .64541 .86453 .64061 Mtetra
.86453 .64061 .86565 .64541 .86747 .64492 .86635 .64012 Mtetra
.608 .468 .666 r
.86635 .64012 .86747 .64492 .86929 .64443 .86817 .63961 Mtetra
.608 .468 .665 r
.86817 .63961 .86929 .64443 .87111 .64393 .86999 .63911 Mtetra
.86999 .63911 .87111 .64393 .87293 .64343 .87181 .6386 Mtetra
.87181 .6386 .87293 .64343 .87476 .64293 .87363 .63808 Mtetra
.609 .468 .665 r
.87363 .63808 .87476 .64293 .87658 .64242 .87545 .63755 Mtetra
.61 .468 .664 r
.87545 .63755 .87658 .64242 .8784 .64191 .87727 .637 Mtetra
.61 .468 .663 r
.87727 .637 .8784 .64191 .88023 .64139 .87909 .63644 Mtetra
.615 .471 .662 r
.87909 .63644 .88023 .64139 .88206 .64085 .8809 .63577 Mtetra
.624 .474 .658 r
.8809 .63577 .88206 .64085 .88388 .64031 .88269 .63492 Mtetra
.607 .459 .655 r
.88269 .63492 .88388 .64031 .88571 .63976 .88452 .63436 Mtetra
.564 .431 .658 r
.88452 .63436 .88571 .63976 .88753 .6392 .88643 .63462 Mtetra
.496 .4 .677 r
.88643 .63462 .88753 .6392 .88936 .63864 .88843 .63579 Mtetra
.478 .445 .743 r
.88843 .63579 .88936 .63864 .89119 .63807 .89041 .63665 Mtetra
.484 .581 .876 r
.89041 .63665 .89119 .63807 .89301 .6375 .89233 .63695 Mtetra
.585 .837 .993 r
.89233 .63695 .89301 .6375 .89484 .63692 .89418 .63652 Mtetra
.631 .898 .986 r
.89418 .63652 .89484 .63692 .89667 .63634 .896 .63587 Mtetra
.68 .894 .975 r
.896 .63587 .89667 .63634 .8985 .63577 .89781 .63512 Mtetra
.687 .845 .959 r
.89781 .63512 .8985 .63577 .90034 .63521 .89963 .63441 Mtetra
.692 .807 .936 r
.89963 .63441 .90034 .63521 .90217 .63467 .90145 .6337 Mtetra
.68 .763 .914 r
.90145 .6337 .90217 .63467 .90401 .63417 .90328 .63306 Mtetra
.651 .722 .9 r
.90328 .63306 .90401 .63417 .90586 .63371 .90512 .63256 Mtetra
.639 .708 .897 r
.90512 .63256 .90586 .63371 .90771 .63327 .90697 .63212 Mtetra
.612 .695 .903 r
.90697 .63212 .90771 .63327 .90958 .63297 .90884 .6318 Mtetra
.55 .662 .911 r
.90884 .6318 .90958 .63297 .91149 .63302 .91074 .63175 Mtetra
.63 .682 .881 r
.91074 .63175 .91149 .63302 .91335 .63259 .9126 .63135 Mtetra
.761 .742 .835 r
.9126 .63135 .91335 .63259 .91507 .63094 .91437 .63013 Mtetra
.952 .82 .677 r
.91437 .63013 .91507 .63094 .91614 .62356 .91585 .62632 Mtetra
.916 .715 .22 r
.91585 .62632 .91614 .62356 .89532 .42439 .91602 .6111 Mtetra
.166 .075 .499 r
.91602 .6111 .89532 .42439 .89661 .42001 .89643 .42331 Mtetra
.233 0 .339 r
.89643 .42331 .89661 .42001 .8983 .41908 .8979 .42051 Mtetra
.07 0 .074 r
.8979 .42051 .8983 .41908 .90007 .41879 .89951 .41884 Mtetra
.633 .962 .834 r
.89951 .41884 .90007 .41879 .90186 .41874 .90118 .41775 Mtetra
.694 .751 .896 r
.90118 .41775 .90186 .41874 .9036 .41823 .9029 .41707 Mtetra
.655 .7 .88 r
.9029 .41707 .9036 .41823 .90534 .4177 .90465 .41657 Mtetra
.66 .71 .885 r
.90465 .41657 .90534 .4177 .90707 .41706 .90639 .41606 Mtetra
.759 .772 .864 r
.90639 .41606 .90707 .41706 .90874 .416 .90807 .415 Mtetra
.689 .748 .896 r
.90807 .415 .90874 .416 .91047 .41534 .9098 .41434 Mtetra
.427 .621 .933 r
.9098 .41434 .91047 .41534 .91231 .41562 .91164 .41463 Mtetra
.788 .373 0 r
.91164 .41463 .91231 .41562 .91474 .42077 .91407 .41978 Mtetra
.973 .661 .312 r
.91407 .41978 .91474 .42077 .94057 .61969 .93988 .61876 Mtetra
.724 .285 0 r
.93988 .61876 .94057 .61969 .94301 .62394 .94232 .62301 Mtetra
.498 .692 .955 r
.94232 .62301 .94301 .62394 .94495 .62396 .94425 .62303 Mtetra
.692 .781 .919 r
.94425 .62303 .94495 .62396 .94679 .62325 .9461 .62232 Mtetra
.742 .798 .897 r
.9461 .62232 .94679 .62325 .9486 .62227 .94791 .62134 Mtetra
.495 .691 .955 r
.94791 .62134 .9486 .62227 .95054 .6223 .94985 .62137 Mtetra
.62 .752 .94 r
.94985 .62137 .95054 .6223 .95243 .6219 .95174 .62097 Mtetra
.799 .814 .864 r
.95174 .62097 .95243 .6219 .9542 .62054 .95351 .61961 Mtetra
.98 .776 .558 r
.95351 .61961 .9542 .62054 .95529 .61376 .9546 .61284 Mtetra
.975 .669 .322 r
.9546 .61284 .95529 .61376 .93204 .41363 .93138 .41265 Mtetra
.964 .784 .612 r
.93138 .41265 .93204 .41363 .93325 .40871 .93259 .40772 Mtetra
.756 .777 .87 r
.93259 .40772 .93325 .40871 .93494 .40767 .93428 .40668 Mtetra
.627 .726 .918 r
.93428 .40668 .93494 .40767 .93672 .40729 .93606 .4063 Mtetra
.544 .686 .932 r
.93606 .4063 .93672 .40729 .93854 .40722 .93788 .40623 Mtetra
.748 .774 .875 r
.93788 .40623 .93854 .40722 .94024 .40624 .93958 .40524 Mtetra
.681 .749 .903 r
.93958 .40524 .94024 .40624 .94199 .40561 .94133 .40462 Mtetra
.488 .656 .935 r
.94133 .40462 .94199 .40561 .94383 .40573 .94318 .40473 Mtetra
.738 .32 0 r
.94318 .40473 .94383 .40573 .94629 .41051 .94563 .40951 Mtetra
.97 .655 .291 r
.94563 .40951 .94629 .41051 .97428 .61031 .9736 .60936 Mtetra
.739 .309 0 r
.9736 .60936 .97428 .61031 .97686 .61507 .97618 .61413 Mtetra
.031 .462 .877 r
.36605 .77753 .36698 .77829 .36846 .77891 .36753 .77815 Mtetra
.643 .761 .935 r
.36753 .77815 .36846 .77891 .36999 .77851 .36906 .77775 Mtetra
.809 .778 .824 r
.36906 .77775 .36999 .77851 .37156 .77709 .37063 .77633 Mtetra
.908 .737 .659 r
.37063 .77633 .37156 .77709 .37329 .77186 .37236 .77109 Mtetra
.937 .686 .534 r
.37236 .77109 .37329 .77186 .38274 .58167 .38186 .58084 Mtetra
.908 .726 .645 r
.38186 .58084 .38274 .58167 .3844 .57599 .38353 .57516 Mtetra
.777 .758 .836 r
.38353 .57516 .3844 .57599 .38587 .57489 .385 .57406 Mtetra
.642 .734 .915 r
.385 .57406 .38587 .57489 .38732 .57453 .38644 .5737 Mtetra
.516 .69 .947 r
.38644 .5737 .38732 .57453 .38875 .57452 .38787 .57369 Mtetra
.746 .753 .858 r
.38787 .57369 .38875 .57452 .39021 .57365 .38934 .57281 Mtetra
.699 .745 .887 r
.38934 .57281 .39021 .57365 .39167 .57306 .3908 .57221 Mtetra
.502 .681 .946 r
.3908 .57221 .39167 .57306 .3931 .57309 .39223 .57224 Mtetra
.923 .534 .223 r
.39223 .57224 .3931 .57309 .39439 .57688 .39352 .57598 Mtetra
.94 .683 .522 r
.39352 .57598 .39439 .57688 .38863 .7662 .38772 .7653 Mtetra
.941 .59 .323 r
.38772 .7653 .38863 .7662 .38995 .77159 .38903 .77077 Mtetra
.282 .597 .95 r
.38903 .77077 .38995 .77159 .39146 .77195 .39054 .77114 Mtetra
.688 .76 .907 r
.39054 .77114 .39146 .77195 .393 .77138 .39208 .77056 Mtetra
.762 .77 .86 r
.39208 .77056 .393 .77138 .39456 .77037 .39364 .76955 Mtetra
.686 .758 .907 r
.39364 .76955 .39456 .77037 .39611 .76981 .39519 .76898 Mtetra
.661 .753 .918 r
.39519 .76898 .39611 .76981 .39765 .76933 .39673 .76852 Mtetra
.644 .75 .927 r
.39673 .76852 .39765 .76933 .39919 .76891 .39827 .76812 Mtetra
.589 .739 .947 r
.39827 .76812 .39919 .76891 .40073 .76863 .3998 .76789 Mtetra
.563 .744 .962 r
.3998 .76789 .40073 .76863 .40226 .76839 .40134 .76771 Mtetra
.558 .758 .971 r
.40134 .76771 .40226 .76839 .4038 .76816 .40288 .76752 Mtetra
.597 .783 .969 r
.40288 .76752 .4038 .76816 .40534 .76784 .40442 .76721 Mtetra
.613 .791 .967 r
.40442 .76721 .40534 .76784 .40689 .76749 .40596 .76687 Mtetra
.622 .793 .964 r
.40596 .76687 .40689 .76749 .40843 .76713 .40751 .76649 Mtetra
.622 .79 .962 r
.40751 .76649 .40843 .76713 .40997 .7668 .40905 .76612 Mtetra
.626 .782 .956 r
.40905 .76612 .40997 .7668 .41152 .76646 .4106 .76575 Mtetra
.631 .774 .949 r
.4106 .76575 .41152 .76646 .41307 .76611 .41215 .76537 Mtetra
.57 .748 .961 r
.41215 .76537 .41307 .76611 .41461 .76605 .41369 .76517 Mtetra
.616 .728 .926 r
.41369 .76517 .41461 .76605 .41615 .76581 .41524 .76487 Mtetra
.687 .736 .888 r
.41524 .76487 .41615 .76581 .41771 .76507 .4168 .76429 Mtetra
.805 .779 .829 r
.4168 .76429 .41771 .76507 .41934 .76234 .41838 .7629 Mtetra
.918 .978 .746 r
.41838 .7629 .41934 .76234 .42109 .7551 .41999 .76057 Mtetra
.086 0 .291 r
.41999 .76057 .42109 .7551 .428 .56709 .42166 .75614 Mtetra
0 0 .349 r
.42166 .75614 .428 .56709 .42956 .56356 .42851 .56933 Mtetra
0 0 .15 r
.42851 .56933 .42956 .56356 .43106 .56185 .43016 .56276 Mtetra
.92 .963 .651 r
.43016 .56276 .43106 .56185 .43255 .56076 .43169 .56 Mtetra
.779 .777 .85 r
.43169 .56 .43255 .56076 .43403 .56009 .43318 .55892 Mtetra
.658 .672 .852 r
.43318 .55892 .43403 .56009 .4355 .55967 .43466 .55848 Mtetra
.596 .645 .869 r
.43466 .55848 .4355 .55967 .43697 .55938 .43612 .55831 Mtetra
.608 .672 .886 r
.43612 .55831 .43697 .55938 .43844 .55908 .43759 .55809 Mtetra
.616 .692 .898 r
.43759 .55809 .43844 .55908 .43991 .55876 .43906 .55783 Mtetra
.623 .708 .907 r
.43906 .55783 .43991 .55876 .44139 .5584 .44053 .55754 Mtetra
.673 .739 .9 r
.44053 .55754 .44139 .5584 .44287 .55787 .44201 .55705 Mtetra
.697 .752 .894 r
.44201 .55705 .44287 .55787 .44435 .55727 .4435 .55645 Mtetra
.701 .754 .893 r
.4435 .55645 .44435 .55727 .44583 .55666 .44498 .55583 Mtetra
.713 .755 .885 r
.44498 .55583 .44583 .55666 .44732 .55588 .44646 .55515 Mtetra
.694 .775 .913 r
.44646 .55515 .44732 .55588 .4488 .55525 .44795 .55457 Mtetra
.616 .771 .954 r
.44795 .55457 .4488 .55525 .45028 .55504 .44942 .55425 Mtetra
.296 .599 .95 r
.44942 .55425 .45028 .55504 .45172 .55648 .45089 .5546 Mtetra
.224 .342 .774 r
.45089 .5546 .45172 .55648 .45308 .56185 .45234 .55584 Mtetra
.334 .248 .608 r
.45234 .55584 .45308 .56185 .45064 .75008 .45375 .55894 Mtetra
0 0 .376 r
.45375 .55894 .45064 .75008 .45214 .75342 .45139 .74483 Mtetra
.136 .084 .529 r
.45139 .74483 .45214 .75342 .45368 .75447 .45282 .75149 Mtetra
.153 .214 .674 r
.45282 .75149 .45368 .75447 .45524 .7548 .45434 .75374 Mtetra
.286 .535 .914 r
.45434 .75374 .45524 .7548 .4568 .75493 .4559 .75429 Mtetra
.587 .783 .973 r
.4559 .75429 .4568 .75493 .45837 .75471 .45747 .754 Mtetra
.734 .798 .903 r
.45747 .754 .45837 .75471 .45996 .75393 .45906 .75319 Mtetra
.829 .792 .817 r
.45906 .75319 .45996 .75393 .46157 .75142 .46065 .75159 Mtetra
.94 .92 .765 r
.46065 .75159 .46157 .75142 .46325 .74498 .46227 .74906 Mtetra
.015 0 .22 r
.46227 .74906 .46325 .74498 .468 .55584 .4639 .74534 Mtetra
.566 .356 .556 r
.4639 .74534 .468 .55584 .46954 .55278 .46551 .74328 Mtetra
.569 .359 .556 r
.46551 .74328 .46954 .55278 .47103 .55235 .46708 .74341 Mtetra
.568 .358 .556 r
.46708 .74341 .47103 .55235 .47252 .55233 .46866 .74289 Mtetra
.01 0 .397 r
.46866 .74289 .47252 .55233 .47403 .55096 .47294 .56627 Mtetra
0 0 .309 r
.47294 .56627 .47403 .55096 .47555 .54906 .47467 .55047 Mtetra
.885 .913 .512 r
.47467 .55047 .47555 .54906 .47706 .54754 .47621 .54693 Mtetra
.822 .815 .843 r
.47621 .54693 .47706 .54754 .47856 .54673 .47772 .54558 Mtetra
.641 .672 .864 r
.47772 .54558 .47856 .54673 .48006 .54639 .47922 .54522 Mtetra
.564 .637 .882 r
.47922 .54522 .48006 .54639 .48155 .54619 .48071 .54517 Mtetra
.601 .682 .898 r
.48071 .54517 .48155 .54619 .48305 .54588 .48221 .54496 Mtetra
.654 .721 .898 r
.48221 .54496 .48305 .54588 .48455 .54544 .48371 .54453 Mtetra
.662 .729 .899 r
.48371 .54453 .48455 .54544 .48605 .54496 .48521 .54408 Mtetra
.663 .734 .902 r
.48521 .54408 .48605 .54496 .48755 .54448 .48671 .54362 Mtetra
.665 .739 .905 r
.48671 .54362 .48755 .54448 .48905 .544 .48822 .54315 Mtetra
.674 .746 .905 r
.48822 .54315 .48905 .544 .49056 .54348 .48972 .54265 Mtetra
.694 .754 .898 r
.48972 .54265 .49056 .54348 .49206 .54289 .49123 .54205 Mtetra
.706 .756 .891 r
.49123 .54205 .49206 .54289 .49357 .54225 .49273 .5414 Mtetra
.704 .752 .889 r
.49273 .5414 .49357 .54225 .49508 .54162 .49424 .54076 Mtetra
.689 .745 .894 r
.49424 .54076 .49508 .54162 .49658 .54106 .49575 .54019 Mtetra
.673 .74 .901 r
.49575 .54019 .49658 .54106 .49809 .54055 .49726 .53968 Mtetra
.667 .74 .904 r
.49726 .53968 .49809 .54055 .4996 .54006 .49877 .5392 Mtetra
.666 .741 .906 r
.49877 .5392 .4996 .54006 .50111 .53958 .50028 .53873 Mtetra
.667 .742 .907 r
.50028 .53873 .50111 .53958 .50262 .53911 .50179 .53825 Mtetra
.666 .742 .907 r
.50179 .53825 .50262 .53911 .50413 .53864 .5033 .53778 Mtetra
.665 .742 .908 r
.5033 .53778 .50413 .53864 .50564 .53817 .50481 .53731 Mtetra
.664 .742 .908 r
.50481 .53731 .50564 .53817 .50715 .5377 .50632 .53684 Mtetra
.50632 .53684 .50715 .5377 .50867 .53723 .50783 .53638 Mtetra
.664 .741 .908 r
.50783 .53638 .50867 .53723 .51018 .53677 .50935 .53591 Mtetra
.50935 .53591 .51018 .53677 .51169 .53631 .51086 .53544 Mtetra
.664 .741 .907 r
.51086 .53544 .51169 .53631 .51321 .53584 .51238 .53498 Mtetra
.51238 .53498 .51321 .53584 .51473 .53538 .5139 .53451 Mtetra
.5139 .53451 .51473 .53538 .51624 .53491 .51541 .53405 Mtetra
.664 .74 .907 r
.51541 .53405 .51624 .53491 .51776 .53445 .51693 .53358 Mtetra
.51693 .53358 .51776 .53445 .51928 .53398 .51845 .53311 Mtetra
.51845 .53311 .51928 .53398 .5208 .53351 .51997 .53265 Mtetra
.51997 .53265 .5208 .53351 .52232 .53304 .52149 .53218 Mtetra
.52149 .53218 .52232 .53304 .52384 .53257 .52302 .53171 Mtetra
.52302 .53171 .52384 .53257 .52536 .5321 .52454 .53124 Mtetra
.665 .741 .907 r
.52454 .53124 .52536 .5321 .52689 .53163 .52606 .53077 Mtetra
.52606 .53077 .52689 .53163 .52841 .53116 .52759 .53029 Mtetra
.52759 .53029 .52841 .53116 .52993 .53068 .52911 .52982 Mtetra
.666 .741 .906 r
.52911 .52982 .52993 .53068 .53146 .5302 .53064 .52934 Mtetra
.667 .742 .906 r
.53064 .52934 .53146 .5302 .53299 .52972 .53216 .52885 Mtetra
.668 .743 .906 r
.53216 .52885 .53299 .52972 .53451 .52923 .53369 .52837 Mtetra
.668 .744 .907 r
.53369 .52837 .53451 .52923 .53604 .52874 .53522 .52788 Mtetra
.686 .749 .899 r
.53522 .52788 .53604 .52874 .53757 .52812 .53675 .52731 Mtetra
.699 .765 .903 r
.53675 .52731 .53757 .52812 .5391 .52741 .53828 .52669 Mtetra
.65 .775 .94 r
.53828 .52669 .5391 .52741 .54063 .52702 .53981 .52626 Mtetra
.417 .669 .965 r
.53981 .52626 .54063 .52702 .54217 .52772 .54134 .52641 Mtetra
.055 .324 .806 r
.54134 .52641 .54217 .52772 .54372 .53126 .54289 .5276 Mtetra
.305 .281 .667 r
.54289 .5276 .54372 .53126 .54641 .72023 .54444 .52975 Mtetra
.565 .359 .561 r
.54444 .52975 .54641 .72023 .54807 .72583 .54599 .53235 Mtetra
.569 .363 .561 r
.54599 .53235 .54807 .72583 .5497 .72592 .54754 .5325 Mtetra
.571 .364 .561 r
.54754 .5325 .5497 .72592 .55133 .72511 .54907 .53146 Mtetra
.572 .365 .561 r
.54907 .53146 .55133 .72511 .55295 .72404 .5506 .52998 Mtetra
.5506 .52998 .55295 .72404 .55458 .72335 .55214 .52873 Mtetra
.57 .363 .561 r
.55214 .52873 .55458 .72335 .55621 .72299 .55368 .52854 Mtetra
.561 .356 .56 r
.55368 .52854 .55621 .72299 .55785 .7235 .55527 .53337 Mtetra
.009 0 .415 r
.55527 .53337 .55785 .7235 .5595 .72476 .5586 .72018 Mtetra
.119 .133 .599 r
.5586 .72018 .5595 .72476 .56115 .7257 .56028 .72409 Mtetra
.06 .288 .777 r
.56028 .72409 .56115 .7257 .56279 .72623 .56194 .72557 Mtetra
.383 .697 .982 r
.56194 .72557 .56279 .72623 .56444 .72633 .56358 .72569 Mtetra
.63 .804 .966 r
.56358 .72569 .56444 .72633 .56608 .72592 .56522 .72526 Mtetra
.768 .825 .897 r
.56522 .72526 .56608 .72592 .56771 .72452 .56685 .72425 Mtetra
.884 .902 .837 r
.56685 .72425 .56771 .72452 .5693 .72072 .56848 .72245 Mtetra
0 0 0 r
.56848 .72245 .5693 .72072 .57073 .70383 .57009 .71956 Mtetra
.41 .21 .496 r
.57009 .71956 .57073 .70383 .56993 .52265 .57165 .71336 Mtetra
.011 0 .411 r
.57165 .71336 .56993 .52265 .57145 .52024 .57071 .52416 Mtetra
0 0 .142 r
.57071 .52416 .57145 .52024 .57299 .51892 .5722 .51926 Mtetra
.904 .985 .757 r
.5722 .51926 .57299 .51892 .57454 .51813 .57373 .51718 Mtetra
.692 .734 .883 r
.57373 .51718 .57454 .51813 .57609 .51771 .57528 .51657 Mtetra
.594 .661 .885 r
.57528 .51657 .57609 .51771 .57764 .5175 .57683 .51639 Mtetra
.554 .651 .899 r
.57683 .51639 .57764 .5175 .5792 .51736 .57839 .51635 Mtetra
.618 .698 .901 r
.57839 .51635 .5792 .51736 .58076 .5171 .57995 .51607 Mtetra
.62 .693 .896 r
.57995 .51607 .58076 .5171 .58232 .51684 .58151 .51578 Mtetra
.625 .689 .89 r
.58151 .51578 .58232 .51684 .58388 .51656 .58307 .51547 Mtetra
.636 .686 .88 r
.58307 .51547 .58388 .51656 .58544 .51627 .58463 .51511 Mtetra
.646 .68 .868 r
.58463 .51511 .58544 .51627 .587 .51592 .58619 .51471 Mtetra
.659 .675 .855 r
.58619 .51471 .587 .51592 .58855 .51548 .58775 .51424 Mtetra
.675 .676 .844 r
.58775 .51424 .58855 .51548 .59011 .51491 .5893 .51368 Mtetra
.682 .681 .843 r
.5893 .51368 .59011 .51491 .59167 .51427 .59086 .51307 Mtetra
.687 .687 .845 r
.59086 .51307 .59167 .51427 .59323 .51362 .59242 .51244 Mtetra
.687 .691 .849 r
.59242 .51244 .59323 .51362 .59479 .51298 .59398 .51182 Mtetra
.688 .694 .85 r
.59398 .51182 .59479 .51298 .59634 .51234 .59554 .51119 Mtetra
.687 .696 .853 r
.59554 .51119 .59634 .51234 .5979 .51171 .5971 .51057 Mtetra
.683 .696 .856 r
.5971 .51057 .5979 .51171 .59947 .5111 .59866 .50997 Mtetra
.686 .699 .856 r
.59866 .50997 .59947 .5111 .60103 .51049 .60023 .50936 Mtetra
.695 .703 .853 r
.60023 .50936 .60103 .51049 .60259 .50983 .60179 .5087 Mtetra
.712 .707 .844 r
.60179 .5087 .60259 .50983 .60415 .5091 .60335 .50793 Mtetra
.709 .7 .84 r
.60335 .50793 .60415 .5091 .60571 .50836 .60491 .50717 Mtetra
.706 .695 .837 r
.60491 .50717 .60571 .50836 .60727 .50765 .60647 .50641 Mtetra
.719 .694 .826 r
.60647 .50641 .60727 .50765 .60884 .5069 .60803 .50556 Mtetra
.67 .661 .832 r
.60803 .50556 .60884 .5069 .6104 .50632 .6096 .505 Mtetra
.548 .61 .867 r
.6096 .505 .6104 .50632 .61198 .506 .61118 .50503 Mtetra
0 0 .52 r
.61118 .50503 .61198 .506 .61357 .50614 .61282 .50685 Mtetra
.891 .539 .371 r
.61282 .50685 .61357 .50614 .61517 .50693 .61456 .51254 Mtetra
.954 .675 .47 r
.61456 .51254 .61517 .50693 .61683 .50943 .62134 .7022 Mtetra
.574 .363 .556 r
.62134 .7022 .61683 .50943 .62377 .70002 .62312 .70581 Mtetra
.624 .349 .481 r
.62312 .70581 .62377 .70002 .62564 .70665 .62485 .70733 Mtetra
.576 .092 .069 r
.62485 .70733 .62564 .70665 .62739 .70874 .62656 .70796 Mtetra
.469 .706 .972 r
.62656 .70796 .62739 .70874 .62908 .70877 .62825 .70799 Mtetra
.654 .777 .939 r
.62825 .70799 .62908 .70877 .63075 .70821 .62992 .7075 Mtetra
.787 .822 .879 r
.62992 .7075 .63075 .70821 .63241 .70717 .63158 .70633 Mtetra
.902 .783 .719 r
.63158 .70633 .63241 .70717 .63406 .70563 .63318 .70319 Mtetra
.879 .672 .619 r
.63318 .70319 .63406 .70563 .63569 .7037 .63466 .69642 Mtetra
.956 .682 .476 r
.63466 .69642 .63569 .7037 .63732 .70157 .63034 .50648 Mtetra
.574 .367 .562 r
.63034 .50648 .63732 .70157 .63898 .70044 .63185 .50372 Mtetra
.57 .364 .561 r
.63185 .50372 .63898 .70044 .64066 .70007 .63344 .50335 Mtetra
.566 .36 .561 r
.63344 .50335 .64066 .70007 .64237 .70048 .63512 .50579 Mtetra
.061 0 .444 r
.63512 .50579 .64237 .70048 .64413 .70223 .64312 .69608 Mtetra
.218 .178 .597 r
.64312 .69608 .64413 .70223 .64586 .70317 .64498 .70075 Mtetra
.27 .335 .746 r
.64498 .70075 .64586 .70317 .64756 .70316 .64674 .70237 Mtetra
.781 .805 .872 r
.64674 .70237 .64756 .70316 .64916 .7001 .6484 .70122 Mtetra
.606 .813 .405 r
.6484 .70122 .64916 .7001 .65056 .69167 .65002 .69877 Mtetra
.229 .038 .401 r
.65002 .69877 .65056 .69167 .64532 .5001 .65154 .69356 Mtetra
.062 0 .439 r
.65154 .69356 .64532 .5001 .64683 .49725 .64629 .5029 Mtetra
0 0 .283 r
.64629 .5029 .64683 .49725 .64838 .49566 .64766 .49652 Mtetra
.828 .926 .543 r
.64766 .49652 .64838 .49566 .64995 .49464 .64917 .4938 Mtetra
.745 .778 .88 r
.64917 .4938 .64995 .49464 .65154 .49397 .65075 .49291 Mtetra
.657 .705 .882 r
.65075 .49291 .65154 .49397 .65313 .49349 .65235 .49245 Mtetra
.613 .693 .901 r
.65235 .49245 .65313 .49349 .65473 .49306 .65395 .49218 Mtetra
.777 .774 .85 r
.65395 .49218 .65473 .49306 .6563 .49195 .65552 .49105 Mtetra
.724 .759 .881 r
.65552 .49105 .6563 .49195 .65788 .49119 .65711 .49026 Mtetra
.558 .696 .933 r
.65711 .49026 .65788 .49119 .6595 .49109 .65872 .49015 Mtetra
.852 .422 0 r
.65872 .49015 .6595 .49109 .66127 .49489 .66049 .49394 Mtetra
.968 .684 .439 r
.66049 .49394 .66127 .49489 .67101 .6899 .67019 .68904 Mtetra
.922 .53 .164 r
.67019 .68904 .67101 .6899 .67296 .69561 .67215 .69477 Mtetra
.048 .446 .876 r
.67215 .69477 .67296 .69561 .67472 .69644 .67391 .6956 Mtetra
.619 .756 .943 r
.67391 .6956 .67472 .69644 .67643 .69608 .67562 .69524 Mtetra
.807 .799 .844 r
.67562 .69524 .67643 .69608 .6781 .69469 .67728 .69384 Mtetra
.936 .769 .65 r
.67728 .69384 .6781 .69469 .67961 .68988 .6788 .689 Mtetra
.968 .69 .449 r
.6788 .689 .67961 .68988 .67264 .49458 .67186 .49361 Mtetra
.945 .742 .599 r
.67186 .49361 .67264 .49458 .67396 .48775 .67319 .48681 Mtetra
.794 .771 .832 r
.67319 .48681 .67396 .48775 .67553 .48645 .67476 .48552 Mtetra
.63 .725 .916 r
.67476 .48552 .67553 .48645 .67715 .48609 .67638 .48516 Mtetra
.499 .669 .94 r
.67638 .48516 .67715 .48609 .67878 .48614 .67801 .48522 Mtetra
.641 .73 .913 r
.67801 .48522 .67878 .48614 .68039 .48574 .67963 .48482 Mtetra
.664 .739 .906 r
.67963 .48482 .68039 .48574 .682 .48524 .68124 .48432 Mtetra
.67 .742 .904 r
.68124 .48432 .682 .48524 .68361 .48471 .68285 .4838 Mtetra
.761 .768 .859 r
.68285 .4838 .68361 .48471 .6852 .48369 .68443 .48277 Mtetra
.718 .758 .884 r
.68443 .48277 .6852 .48369 .6868 .48292 .68604 .48201 Mtetra
.551 .697 .936 r
.68604 .48201 .6868 .48292 .68843 .48283 .68767 .48191 Mtetra
.834 .397 0 r
.68767 .48191 .68843 .48283 .69026 .4865 .68949 .4856 Mtetra
.97 .683 .428 r
.68949 .4856 .69026 .4865 .70174 .68153 .70094 .68068 Mtetra
.913 .514 .132 r
.70094 .68068 .70174 .68153 .70377 .68711 .70296 .68626 Mtetra
0 .392 .844 r
.70296 .68626 .70377 .68711 .70556 .68809 .70476 .68723 Mtetra
.605 .748 .945 r
.70476 .68723 .70556 .68809 .70729 .68777 .70649 .68692 Mtetra
.799 .8 .853 r
.70649 .68692 .70729 .68777 .70897 .68645 .70817 .68559 Mtetra
.935 .777 .661 r
.70817 .68559 .70897 .68645 .71049 .68198 .70969 .68112 Mtetra
.971 .689 .438 r
.70969 .68112 .71049 .68198 .70178 .48639 .70102 .48549 Mtetra
.955 .745 .58 r
.70102 .48549 .70178 .48639 .70303 .47888 .70227 .47797 Mtetra
.828 .781 .807 r
.70227 .47797 .70303 .47888 .70459 .47726 .70383 .47634 Mtetra
.661 .741 .909 r
.70383 .47634 .70459 .47726 .70621 .47677 .70546 .47585 Mtetra
.542 .692 .937 r
.70546 .47585 .70621 .47677 .70786 .4767 .70711 .47578 Mtetra
.719 .759 .884 r
.70711 .47578 .70786 .4767 .70947 .47594 .70872 .47501 Mtetra
.707 .755 .89 r
.70872 .47501 .70947 .47594 .71109 .47524 .71034 .47431 Mtetra
.553 .696 .935 r
.71034 .47431 .71109 .47524 .71274 .47514 .71199 .47421 Mtetra
.748 .295 0 r
.71199 .47421 .71274 .47514 .71457 .47822 .71382 .47729 Mtetra
.972 .682 .417 r
.71382 .47729 .71457 .47822 .72754 .67317 .72674 .67229 Mtetra
.925 .539 .162 r
.72674 .67229 .72754 .67317 .72968 .67977 .72889 .6789 Mtetra
0 .296 .778 r
.72889 .6789 .72968 .67977 .73152 .68099 .73073 .68013 Mtetra
.592 .743 .948 r
.73073 .68013 .73152 .68099 .73327 .68071 .73248 .67985 Mtetra
.805 .803 .85 r
.73248 .67985 .73327 .68071 .73496 .67934 .73417 .67847 Mtetra
.944 .774 .641 r
.73417 .67847 .73496 .67934 .73643 .67446 .73563 .67347 Mtetra
.972 .688 .428 r
.73563 .67347 .73643 .67446 .72614 .47671 .72536 .47543 Mtetra
.932 .732 .61 r
.72536 .47543 .72614 .47671 .72742 .47041 .72666 .46932 Mtetra
.813 .752 .795 r
.72666 .46932 .72742 .47041 .72898 .46874 .72823 .4677 Mtetra
.645 .709 .893 r
.72823 .4677 .72898 .46874 .73062 .46828 .72987 .46728 Mtetra
.529 .668 .925 r
.72987 .46728 .73062 .46828 .73229 .46823 .73154 .46727 Mtetra
.639 .726 .911 r
.73154 .46727 .73229 .46823 .73393 .46771 .73319 .46687 Mtetra
.674 .767 .921 r
.73319 .46687 .73393 .46771 .73556 .4671 .73483 .46632 Mtetra
.611 .761 .951 r
.73483 .46632 .73556 .4671 .73722 .46687 .73648 .46599 Mtetra
.377 .62 .947 r
.73648 .46599 .73722 .46687 .73898 .46823 .73818 .46631 Mtetra
.315 .4 .79 r
.73818 .46631 .73898 .46823 .74099 .47318 .73993 .4675 Mtetra
.375 .293 .635 r
.73993 .4675 .74099 .47318 .75548 .66711 .74181 .47047 Mtetra
.121 .036 .476 r
.74181 .47047 .75548 .66711 .75751 .67086 .75614 .66111 Mtetra
.236 .166 .571 r
.75614 .66111 .75751 .67086 .75937 .67197 .75844 .66875 Mtetra
.254 .279 .695 r
.75844 .66875 .75937 .67197 .76119 .67235 .76039 .67117 Mtetra
.346 .546 .906 r
.76039 .67117 .76119 .67235 .76297 .67233 .76222 .67176 Mtetra
.525 .797 .995 r
.76222 .67176 .76297 .67233 .76475 .67205 .76399 .67152 Mtetra
.642 .854 .981 r
.76399 .67152 .76475 .67205 .76651 .6716 .76575 .67096 Mtetra
.632 .82 .973 r
.76575 .67096 .76651 .6716 .76828 .67129 .76751 .67047 Mtetra
.653 .779 .941 r
.76751 .67047 .76828 .67129 .77005 .67091 .76927 .66996 Mtetra
.711 .767 .896 r
.76927 .66996 .77005 .67091 .77179 .6701 .77101 .66919 Mtetra
.799 .796 .85 r
.77101 .66919 .77179 .6701 .77342 .66778 .77271 .66783 Mtetra
.911 .978 .779 r
.77271 .66783 .77342 .66778 .77482 .66229 .77435 .66565 Mtetra
.045 0 .25 r
.77435 .66565 .77482 .66229 .76254 .46739 .77589 .66195 Mtetra
.136 .043 .477 r
.77589 .66195 .76254 .46739 .76384 .46196 .7641 .47472 Mtetra
.082 0 .414 r
.7641 .47472 .76384 .46196 .76539 .45985 .76483 .46135 Mtetra
0 0 0 r
.76483 .46135 .76539 .45985 .76699 .45855 .76628 .45795 Mtetra
.834 .863 .867 r
.76628 .45795 .76699 .45855 .76863 .45778 .76788 .45656 Mtetra
.65 .68 .865 r
.76788 .45656 .76863 .45778 .77029 .45734 .76954 .45611 Mtetra
.588 .65 .879 r
.76954 .45611 .77029 .45734 .77197 .45703 .77123 .45595 Mtetra
.665 .712 .883 r
.77123 .45595 .77197 .45703 .77362 .45632 .77289 .45543 Mtetra
.724 .772 .891 r
.77289 .45543 .77362 .45632 .77525 .45545 .77453 .45463 Mtetra
.679 .777 .924 r
.77453 .45463 .77525 .45545 .77692 .45496 .77619 .45405 Mtetra
.492 .674 .945 r
.77619 .45405 .77692 .45496 .7787 .45588 .7779 .45411 Mtetra
.356 .442 .812 r
.7779 .45411 .7787 .45588 .78072 .45996 .77969 .45507 Mtetra
.392 .318 .654 r
.77969 .45507 .78072 .45996 .79766 .65406 .78159 .4575 Mtetra
.151 .061 .49 r
.78159 .4575 .79766 .65406 .79985 .65886 .79796 .64356 Mtetra
.221 .14 .547 r
.79796 .64356 .79985 .65886 .80177 .66006 .80078 .65628 Mtetra
.274 .273 .676 r
.80078 .65628 .80177 .66006 .80361 .66042 .80282 .65906 Mtetra
.362 .521 .88 r
.80282 .65906 .80361 .66042 .80542 .66025 .80469 .65974 Mtetra
.586 .843 .993 r
.80469 .65974 .80542 .66025 .8072 .65972 .80648 .65931 Mtetra
.705 .909 .967 r
.80648 .65931 .8072 .65972 .80897 .65897 .80824 .65848 Mtetra
.73 .891 .953 r
.80824 .65848 .80897 .65897 .81073 .65818 .80999 .65759 Mtetra
.714 .861 .952 r
.80999 .65759 .81073 .65818 .81249 .65742 .81176 .65679 Mtetra
.718 .852 .945 r
.81176 .65679 .81249 .65742 .81425 .65665 .81352 .65597 Mtetra
.696 .832 .948 r
.81352 .65597 .81425 .65665 .81603 .65598 .81529 .65526 Mtetra
.663 .812 .955 r
.81529 .65526 .81603 .65598 .81781 .65541 .81707 .65468 Mtetra
.646 .802 .958 r
.81707 .65468 .81781 .65541 .8196 .65491 .81886 .65416 Mtetra
.577 .77 .971 r
.81886 .65416 .8196 .65491 .8214 .65456 .82067 .65388 Mtetra
.529 .769 .985 r
.82067 .65388 .8214 .65456 .82321 .65428 .82249 .65369 Mtetra
.645 .843 .976 r
.82249 .65369 .82321 .65428 .82501 .65384 .82428 .65312 Mtetra
.87 .847 .818 r
.82428 .65312 .82501 .65384 .82676 .65285 .82595 .6512 Mtetra
.911 .724 .637 r
.82595 .6512 .82676 .65285 .82845 .65111 .82734 .64608 Mtetra
.973 .679 .401 r
.82734 .64608 .82845 .65111 .83011 .64901 .81231 .45375 Mtetra
.578 .369 .562 r
.81231 .45375 .83011 .64901 .83181 .64742 .81356 .44823 Mtetra
.571 .364 .561 r
.81356 .44823 .83181 .64742 .83362 .6471 .81524 .44757 Mtetra
.569 .363 .561 r
.81524 .44757 .83362 .6471 .83546 .64714 .817 .44787 Mtetra
.817 .44787 .83546 .64714 .8373 .6471 .81878 .44829 Mtetra
.57 .363 .561 r
.81878 .44829 .8373 .6471 .83912 .64681 .8205 .44811 Mtetra
.8205 .44811 .83912 .64681 .84094 .64648 .82223 .44792 Mtetra
.82223 .44792 .84094 .64648 .84276 .64611 .82395 .4477 Mtetra
.82395 .4477 .84276 .64611 .84457 .64572 .82567 .44744 Mtetra
.82567 .44744 .84457 .64572 .84638 .64531 .82739 .44714 Mtetra
.82739 .44714 .84638 .64531 .8482 .64489 .82911 .4468 Mtetra
.57 .364 .561 r
.82911 .4468 .8482 .64489 .85001 .64445 .83083 .44644 Mtetra
.83083 .44644 .85001 .64445 .85182 .64399 .83254 .44603 Mtetra
.83254 .44603 .85182 .64399 .85364 .64353 .83425 .4456 Mtetra
.83425 .4456 .85364 .64353 .85545 .64306 .83596 .44514 Mtetra
.83596 .44514 .85545 .64306 .85727 .64258 .83767 .44465 Mtetra
.83767 .44465 .85727 .64258 .85908 .64209 .83938 .44414 Mtetra
.83938 .44414 .85908 .64209 .8609 .6416 .84108 .44362 Mtetra
.84108 .44362 .8609 .6416 .86271 .64111 .84279 .44308 Mtetra
.84279 .44308 .86271 .64111 .86453 .64061 .8445 .44253 Mtetra
.8445 .44253 .86453 .64061 .86635 .64012 .84621 .44199 Mtetra
.84621 .44199 .86635 .64012 .86817 .63961 .84791 .44143 Mtetra
.84791 .44143 .86817 .63961 .86999 .63911 .84962 .44086 Mtetra
.84962 .44086 .86999 .63911 .87181 .6386 .85133 .44029 Mtetra
.85133 .44029 .87181 .6386 .87363 .63808 .85304 .43969 Mtetra
.571 .364 .561 r
.85304 .43969 .87363 .63808 .87545 .63755 .85474 .43904 Mtetra
.85474 .43904 .87545 .63755 .87727 .637 .85644 .43833 Mtetra
.85644 .43833 .87727 .637 .87909 .63644 .85814 .43762 Mtetra
.85814 .43762 .87909 .63644 .8809 .63577 .85979 .43648 Mtetra
.572 .365 .561 r
.85979 .43648 .8809 .63577 .88269 .63492 .86139 .43482 Mtetra
.57 .364 .561 r
.86139 .43482 .88269 .63492 .88452 .63436 .86311 .43433 Mtetra
.564 .359 .561 r
.86311 .43433 .88452 .63436 .88643 .63462 .8653 .43827 Mtetra
.167 .078 .503 r
.8653 .43827 .88643 .63462 .88843 .63579 .88727 .63071 Mtetra
.255 .231 .639 r
.88727 .63071 .88843 .63579 .89041 .63665 .8896 .63485 Mtetra
.25 .387 .806 r
.8896 .63485 .89041 .63665 .89233 .63695 .89164 .63628 Mtetra
.554 .79 .987 r
.89164 .63628 .89233 .63695 .89418 .63652 .8935 .636 Mtetra
.677 .882 .974 r
.8935 .636 .89418 .63652 .896 .63587 .89532 .63528 Mtetra
.733 .877 .948 r
.89532 .63528 .896 .63587 .89781 .63512 .89711 .63437 Mtetra
.706 .827 .94 r
.89711 .63437 .89781 .63512 .89963 .63441 .89893 .6336 Mtetra
.71 .811 .928 r
.89893 .6336 .89963 .63441 .90145 .6337 .90074 .63281 Mtetra
.695 .787 .921 r
.90074 .63281 .90145 .6337 .90328 .63306 .90256 .63209 Mtetra
.657 .755 .923 r
.90256 .63209 .90328 .63306 .90512 .63256 .9044 .63156 Mtetra
.639 .74 .922 r
.9044 .63156 .90512 .63256 .90697 .63212 .90625 .6311 Mtetra
.615 .727 .925 r
.90625 .6311 .90697 .63212 .90884 .6318 .90811 .63074 Mtetra
.576 .7 .926 r
.90811 .63074 .90884 .6318 .91074 .63175 .91 .63055 Mtetra
.621 .692 .895 r
.91 .63055 .91074 .63175 .9126 .63135 .91186 .6302 Mtetra
.689 .729 .881 r
.91186 .6302 .9126 .63135 .91437 .63013 .91369 .62949 Mtetra
.825 .882 .886 r
.91369 .62949 .91437 .63013 .91585 .62632 .91544 .62808 Mtetra
.023 0 .105 r
.91544 .62808 .91585 .62632 .91602 .6111 .9171 .62585 Mtetra
.471 .263 .515 r
.9171 .62585 .91602 .6111 .89643 .42331 .91851 .62145 Mtetra
.177 .083 .502 r
.91851 .62145 .89643 .42331 .8979 .42051 .89799 .42619 Mtetra
.073 0 .371 r
.89799 .42619 .8979 .42051 .89951 .41884 .89902 .41947 Mtetra
.754 .881 .467 r
.89902 .41947 .89951 .41884 .90118 .41775 .90051 .41677 Mtetra
.732 .769 .883 r
.90051 .41677 .90118 .41775 .9029 .41707 .90221 .41589 Mtetra
.647 .695 .88 r
.90221 .41589 .9029 .41707 .90465 .41657 .90396 .41544 Mtetra
.632 .695 .89 r
.90396 .41544 .90465 .41657 .90639 .41606 .90571 .41505 Mtetra
.759 .773 .864 r
.90571 .41505 .90639 .41606 .90807 .415 .90739 .41399 Mtetra
.688 .748 .897 r
.90739 .41399 .90807 .415 .9098 .41434 .90912 .41334 Mtetra
.425 .62 .933 r
.90912 .41334 .9098 .41434 .91164 .41463 .91097 .41364 Mtetra
.788 .372 0 r
.91097 .41364 .91164 .41463 .91407 .41978 .91339 .41879 Mtetra
.973 .661 .312 r
.91339 .41879 .91407 .41978 .93988 .61876 .93918 .61783 Mtetra
.723 .285 0 r
.93918 .61783 .93988 .61876 .94232 .62301 .94162 .62208 Mtetra
.497 .692 .955 r
.94162 .62208 .94232 .62301 .94425 .62303 .94355 .6221 Mtetra
.692 .781 .919 r
.94355 .6221 .94425 .62303 .9461 .62232 .9454 .62139 Mtetra
.742 .798 .897 r
.9454 .62139 .9461 .62232 .94791 .62134 .94721 .62041 Mtetra
.495 .691 .955 r
.94721 .62041 .94791 .62134 .94985 .62137 .94915 .62044 Mtetra
.62 .752 .941 r
.94915 .62044 .94985 .62137 .95174 .62097 .95104 .62004 Mtetra
.798 .814 .864 r
.95104 .62004 .95174 .62097 .95351 .61961 .95281 .61869 Mtetra
.98 .776 .558 r
.95281 .61869 .95351 .61961 .9546 .61284 .95391 .61192 Mtetra
.975 .669 .322 r
.95391 .61192 .9546 .61284 .93138 .41265 .93072 .41167 Mtetra
.964 .784 .612 r
.93072 .41167 .93138 .41265 .93259 .40772 .93192 .40673 Mtetra
.756 .777 .87 r
.93192 .40673 .93259 .40772 .93428 .40668 .93362 .40569 Mtetra
.627 .726 .918 r
.93362 .40569 .93428 .40668 .93606 .4063 .9354 .40531 Mtetra
.544 .686 .932 r
.9354 .40531 .93606 .4063 .93788 .40623 .93722 .40524 Mtetra
.748 .775 .875 r
.93722 .40524 .93788 .40623 .93958 .40524 .93892 .40425 Mtetra
.681 .749 .903 r
.93892 .40425 .93958 .40524 .94133 .40462 .94067 .40362 Mtetra
.488 .656 .935 r
.94067 .40362 .94133 .40462 .94318 .40473 .94252 .40373 Mtetra
.738 .32 0 r
.94252 .40373 .94318 .40473 .94563 .40951 .94498 .40852 Mtetra
.97 .655 .291 r
.94498 .40852 .94563 .40951 .9736 .60936 .97292 .60842 Mtetra
.74 .309 0 r
.97292 .60842 .9736 .60936 .97618 .61413 .9755 .61319 Mtetra
.031 .462 .877 r
.36512 .77677 .36605 .77753 .36753 .77815 .3666 .77739 Mtetra
.643 .762 .935 r
.3666 .77739 .36753 .77815 .36906 .77775 .36812 .77699 Mtetra
.809 .778 .824 r
.36812 .77699 .36906 .77775 .37063 .77633 .36969 .77557 Mtetra
.908 .737 .658 r
.36969 .77557 .37063 .77633 .37236 .77109 .37143 .77032 Mtetra
.937 .686 .534 r
.37143 .77032 .37236 .77109 .38186 .58084 .38098 .58001 Mtetra
.908 .727 .645 r
.38098 .58001 .38186 .58084 .38353 .57516 .38265 .57434 Mtetra
.777 .758 .836 r
.38265 .57434 .38353 .57516 .385 .57406 .38413 .57323 Mtetra
.643 .734 .915 r
.38413 .57323 .385 .57406 .38644 .5737 .38557 .57287 Mtetra
.517 .691 .947 r
.38557 .57287 .38644 .5737 .38787 .57369 .387 .57285 Mtetra
.746 .754 .859 r
.387 .57285 .38787 .57369 .38934 .57281 .38847 .57198 Mtetra
.699 .746 .888 r
.38847 .57198 .38934 .57281 .3908 .57221 .38992 .57138 Mtetra
.502 .684 .948 r
.38992 .57138 .3908 .57221 .39223 .57224 .39136 .5714 Mtetra
.922 .532 .221 r
.39136 .5714 .39223 .57224 .39352 .57598 .39265 .5751 Mtetra
.94 .683 .522 r
.39265 .5751 .39352 .57598 .38772 .7653 .3868 .76441 Mtetra
.94 .591 .328 r
.3868 .76441 .38772 .7653 .38903 .77077 .3881 .76996 Mtetra
.271 .594 .949 r
.3881 .76996 .38903 .77077 .39054 .77114 .38961 .77034 Mtetra
.687 .763 .91 r
.38961 .77034 .39054 .77114 .39208 .77056 .39116 .76977 Mtetra
.762 .775 .863 r
.39116 .76977 .39208 .77056 .39364 .76955 .39272 .76876 Mtetra
.678 .764 .916 r
.39272 .76876 .39364 .76955 .39519 .76898 .39426 .76823 Mtetra
.655 .767 .931 r
.39426 .76823 .39519 .76898 .39673 .76852 .3958 .76778 Mtetra
.648 .769 .937 r
.3958 .76778 .39673 .76852 .39827 .76812 .39735 .76735 Mtetra
.64 .761 .936 r
.39735 .76735 .39827 .76812 .3998 .76789 .39889 .76696 Mtetra
.639 .723 .908 r
.39889 .76696 .3998 .76789 .40134 .76771 .40043 .76658 Mtetra
.638 .684 .877 r
.40043 .76658 .40134 .76771 .40288 .76752 .40197 .76622 Mtetra
.636 .655 .851 r
.40197 .76622 .40288 .76752 .40442 .76721 .40352 .76587 Mtetra
.635 .647 .845 r
.40352 .76587 .40442 .76721 .40596 .76687 .40506 .76552 Mtetra
.633 .646 .845 r
.40506 .76552 .40596 .76687 .40751 .76649 .40661 .76518 Mtetra
.631 .65 .85 r
.40661 .76518 .40751 .76649 .40905 .76612 .40815 .76485 Mtetra
.632 .656 .856 r
.40815 .76485 .40905 .76612 .4106 .76575 .4097 .76452 Mtetra
.633 .663 .862 r
.4097 .76452 .4106 .76575 .41215 .76537 .41125 .76418 Mtetra
.629 .669 .869 r
.41125 .76418 .41215 .76537 .41369 .76517 .41279 .76386 Mtetra
.637 .652 .849 r
.41279 .76386 .41369 .76517 .41524 .76487 .41434 .7635 Mtetra
.649 .649 .836 r
.41434 .7635 .41524 .76487 .4168 .76429 .4159 .76307 Mtetra
.616 .659 .869 r
.4159 .76307 .4168 .76429 .41838 .7629 .41745 .76281 Mtetra
.552 .908 .966 r
.41745 .76281 .41838 .7629 .41999 .76057 .419 .76228 Mtetra
.157 0 .071 r
.419 .76228 .41999 .76057 .42166 .75614 .42058 .76109 Mtetra
0 0 .197 r
.42058 .76109 .42166 .75614 .42851 .56933 .42227 .7562 Mtetra
0 0 .333 r
.42227 .7562 .42851 .56933 .43016 .56276 .42919 .56562 Mtetra
.847 .823 .344 r
.42919 .56562 .43016 .56276 .43169 .56 .43082 .55984 Mtetra
.865 .909 .86 r
.43082 .55984 .43169 .56 .43318 .55892 .43232 .55835 Mtetra
.653 .81 .959 r
.43232 .55835 .43318 .55892 .43466 .55848 .43379 .5579 Mtetra
.48 .753 .99 r
.43379 .5579 .43466 .55848 .43612 .55831 .43526 .55784 Mtetra
.575 .816 .99 r
.43526 .55784 .43612 .55831 .43759 .55809 .43673 .55754 Mtetra
.633 .811 .968 r
.43673 .55754 .43759 .55809 .43906 .55783 .4382 .55714 Mtetra
.646 .774 .941 r
.4382 .55714 .43906 .55783 .44053 .55754 .43968 .55674 Mtetra
.659 .748 .916 r
.43968 .55674 .44053 .55754 .44201 .55705 .44116 .5563 Mtetra
.664 .763 .924 r
.44116 .5563 .44201 .55705 .4435 .55645 .44264 .55584 Mtetra
.663 .8 .948 r
.44264 .55584 .4435 .55645 .44498 .55583 .44412 .55536 Mtetra
.666 .842 .967 r
.44412 .55536 .44498 .55583 .44646 .55515 .4456 .55485 Mtetra
.637 .884 .986 r
.4456 .55485 .44646 .55515 .44795 .55457 .44708 .55433 Mtetra
.589 .889 .99 r
.44708 .55433 .44795 .55457 .44942 .55425 .44856 .55388 Mtetra
.681 .873 .971 r
.44856 .55388 .44942 .55425 .45089 .5546 .45005 .55329 Mtetra
.647 .646 .835 r
.45005 .55329 .45089 .5546 .45234 .55584 .45153 .55288 Mtetra
.558 .472 .713 r
.45153 .55288 .45234 .55584 .45375 .55894 .453 .55306 Mtetra
.324 .243 .609 r
.453 .55306 .45375 .55894 .45139 .74483 .45441 .55618 Mtetra
0 0 .362 r
.45441 .55618 .45139 .74483 .45282 .75149 .45202 .74592 Mtetra
0 0 .451 r
.45202 .74592 .45282 .75149 .45434 .75374 .45346 .752 Mtetra
.255 .392 .809 r
.45346 .752 .45434 .75374 .4559 .75429 .455 .75306 Mtetra
.622 .663 .869 r
.455 .75306 .4559 .75429 .45747 .754 .45658 .75277 Mtetra
.706 .691 .834 r
.45658 .75277 .45747 .754 .45906 .75319 .45816 .752 Mtetra
.708 .698 .838 r
.45816 .752 .45906 .75319 .46065 .75159 .45975 .75122 Mtetra
.713 .887 .961 r
.45975 .75122 .46065 .75159 .46227 .74906 .46133 .75048 Mtetra
.258 0 .075 r
.46133 .75048 .46227 .74906 .4639 .74534 .46292 .74972 Mtetra
.533 .253 .436 r
.46292 .74972 .4639 .74534 .46551 .74328 .4645 .7495 Mtetra
.549 .289 .474 r
.4645 .7495 .46551 .74328 .46708 .74341 .46607 .74935 Mtetra
.514 .256 .461 r
.46607 .74935 .46708 .74341 .46866 .74289 .46766 .74864 Mtetra
.265 .041 .375 r
.46766 .74864 .46866 .74289 .47294 .56627 .46929 .74517 Mtetra
0 0 .338 r
.46929 .74517 .47294 .56627 .47467 .55047 .47374 .55577 Mtetra
0 0 0 r
.47374 .55577 .47467 .55047 .47621 .54693 .47536 .54699 Mtetra
.921 .928 .797 r
.47536 .54699 .47621 .54693 .47772 .54558 .47688 .54492 Mtetra
.688 .796 .932 r
.47688 .54492 .47772 .54558 .47922 .54522 .47838 .54436 Mtetra
.562 .706 .937 r
.47838 .54436 .47922 .54522 .48071 .54517 .47987 .54423 Mtetra
.604 .703 .914 r
.47987 .54423 .48071 .54517 .48221 .54496 .48137 .544 Mtetra
.653 .714 .893 r
.48137 .544 .48221 .54496 .48371 .54453 .48287 .54358 Mtetra
.653 .716 .894 r
.48287 .54358 .48371 .54453 .48521 .54408 .48437 .54317 Mtetra
.658 .726 .899 r
.48437 .54317 .48521 .54408 .48671 .54362 .48587 .54273 Mtetra
.664 .732 .901 r
.48587 .54273 .48671 .54362 .48822 .54315 .48738 .54227 Mtetra
.668 .735 .9 r
.48738 .54227 .48822 .54315 .48972 .54265 .48888 .54179 Mtetra
.674 .743 .903 r
.48888 .54179 .48972 .54265 .49123 .54205 .49039 .54128 Mtetra
.678 .765 .916 r
.49039 .54128 .49123 .54205 .49273 .5414 .4919 .54076 Mtetra
.677 .798 .94 r
.4919 .54076 .49273 .5414 .49424 .54076 .4934 .54023 Mtetra
.664 .83 .963 r
.4934 .54023 .49424 .54076 .49575 .54019 .49491 .53972 Mtetra
.651 .845 .975 r
.49491 .53972 .49575 .54019 .49726 .53968 .49642 .53923 Mtetra
.646 .848 .978 r
.49642 .53923 .49726 .53968 .49877 .5392 .49793 .53875 Mtetra
.645 .846 .978 r
.49793 .53875 .49877 .5392 .50028 .53873 .49944 .53827 Mtetra
.644 .845 .977 r
.49944 .53827 .50028 .53873 .50179 .53825 .50095 .53779 Mtetra
.643 .845 .978 r
.50095 .53779 .50179 .53825 .5033 .53778 .50246 .53732 Mtetra
.642 .845 .978 r
.50246 .53732 .5033 .53778 .50481 .53731 .50397 .53685 Mtetra
.641 .844 .978 r
.50397 .53685 .50481 .53731 .50632 .53684 .50549 .53638 Mtetra
.50549 .53638 .50632 .53684 .50783 .53638 .507 .53591 Mtetra
.64 .844 .978 r
.507 .53591 .50783 .53638 .50935 .53591 .50852 .53545 Mtetra
.64 .843 .978 r
.50852 .53545 .50935 .53591 .51086 .53544 .51003 .53498 Mtetra
.51003 .53498 .51086 .53544 .51238 .53498 .51155 .53451 Mtetra
.51155 .53451 .51238 .53498 .5139 .53451 .51307 .53405 Mtetra
.51307 .53405 .5139 .53451 .51541 .53405 .51458 .53358 Mtetra
.51458 .53358 .51541 .53405 .51693 .53358 .5161 .53311 Mtetra
.641 .843 .978 r
.5161 .53311 .51693 .53358 .51845 .53311 .51762 .53264 Mtetra
.51762 .53264 .51845 .53311 .51997 .53265 .51914 .53218 Mtetra
.51914 .53218 .51997 .53265 .52149 .53218 .52067 .53171 Mtetra
.52067 .53171 .52149 .53218 .52302 .53171 .52219 .53124 Mtetra
.641 .843 .977 r
.52219 .53124 .52302 .53171 .52454 .53124 .52371 .53077 Mtetra
.642 .843 .977 r
.52371 .53077 .52454 .53124 .52606 .53077 .52524 .53029 Mtetra
.52524 .53029 .52606 .53077 .52759 .53029 .52676 .52982 Mtetra
.643 .843 .977 r
.52676 .52982 .52759 .53029 .52911 .52982 .52829 .52934 Mtetra
.644 .843 .977 r
.52829 .52934 .52911 .52982 .53064 .52934 .52981 .52887 Mtetra
.645 .844 .977 r
.52981 .52887 .53064 .52934 .53216 .52885 .53134 .52838 Mtetra
.646 .845 .977 r
.53134 .52838 .53216 .52885 .53369 .52837 .53287 .5279 Mtetra
.647 .846 .977 r
.53287 .5279 .53369 .52837 .53522 .52788 .5344 .52741 Mtetra
.654 .848 .974 r
.5344 .52741 .53522 .52788 .53675 .52731 .53593 .5269 Mtetra
.653 .864 .98 r
.53593 .5269 .53675 .52731 .53828 .52669 .53746 .52637 Mtetra
.615 .882 .99 r
.53746 .52637 .53828 .52669 .53981 .52626 .53899 .52588 Mtetra
.575 .854 .996 r
.53899 .52588 .53981 .52626 .54134 .52641 .54052 .52551 Mtetra
.597 .712 .924 r
.54052 .52551 .54134 .52641 .54289 .5276 .54206 .52528 Mtetra
.604 .533 .748 r
.54206 .52528 .54289 .5276 .54444 .52975 .5436 .52508 Mtetra
.597 .455 .659 r
.5436 .52508 .54444 .52975 .54599 .53235 .54513 .52478 Mtetra
.595 .425 .622 r
.54513 .52478 .54599 .53235 .54754 .5325 .54667 .5243 Mtetra
.594 .422 .617 r
.54667 .5243 .54754 .5325 .54907 .53146 .54821 .52378 Mtetra
.602 .43 .621 r
.54821 .52378 .54907 .53146 .5506 .52998 .54974 .5231 Mtetra
.611 .441 .628 r
.54974 .5231 .5506 .52998 .55214 .52873 .55128 .52229 Mtetra
.593 .432 .633 r
.55128 .52229 .55214 .52873 .55368 .52854 .55282 .52195 Mtetra
.514 .374 .629 r
.55282 .52195 .55368 .52854 .55527 .53337 .55437 .52312 Mtetra
0 0 .443 r
.55437 .52312 .55527 .53337 .5586 .72018 .55602 .5342 Mtetra
0 0 .407 r
.55602 .5342 .5586 .72018 .56028 .72409 .5594 .72161 Mtetra
0 .118 .648 r
.5594 .72161 .56028 .72409 .56194 .72557 .56107 .72421 Mtetra
.548 .613 .87 r
.56107 .72421 .56194 .72557 .56358 .72569 .56271 .72423 Mtetra
.666 .652 .826 r
.56271 .72423 .56358 .72569 .56522 .72526 .56435 .72367 Mtetra
.675 .639 .807 r
.56435 .72367 .56522 .72526 .56685 .72425 .56599 .72301 Mtetra
.625 .667 .871 r
.56599 .72301 .56685 .72425 .56848 .72245 .56763 .72269 Mtetra
.433 .868 .781 r
.56763 .72269 .56848 .72245 .57009 .71956 .56927 .72193 Mtetra
.089 0 .151 r
.56927 .72193 .57009 .71956 .57165 .71336 .57089 .71984 Mtetra
0 0 .207 r
.57089 .71984 .57165 .71336 .57071 .52416 .57244 .71182 Mtetra
0 0 .4 r
.57244 .71182 .57071 .52416 .5722 .51926 .57141 .51995 Mtetra
.978 .919 .623 r
.57141 .51995 .5722 .51926 .57373 .51718 .57292 .51622 Mtetra
.721 .74 .866 r
.57292 .51622 .57373 .51718 .57528 .51657 .57447 .51545 Mtetra
.588 .661 .889 r
.57447 .51545 .57528 .51657 .57683 .51639 .57602 .51529 Mtetra
.529 .64 .903 r
.57602 .51529 .57683 .51639 .57839 .51635 .57758 .51533 Mtetra
.628 .698 .895 r
.57758 .51533 .57839 .51635 .57995 .51607 .57914 .51501 Mtetra
.629 .691 .889 r
.57914 .51501 .57995 .51607 .58151 .51578 .5807 .51468 Mtetra
.635 .686 .881 r
.5807 .51468 .58151 .51578 .58307 .51547 .58226 .51433 Mtetra
.648 .684 .87 r
.58226 .51433 .58307 .51547 .58463 .51511 .58382 .51392 Mtetra
.656 .676 .858 r
.58382 .51392 .58463 .51511 .58619 .51471 .58538 .51346 Mtetra
.663 .671 .847 r
.58538 .51346 .58619 .51471 .58775 .51424 .58694 .51297 Mtetra
.671 .669 .84 r
.58694 .51297 .58775 .51424 .5893 .51368 .58849 .51242 Mtetra
.676 .674 .84 r
.58849 .51242 .5893 .51368 .59086 .51307 .59005 .51184 Mtetra
.68 .679 .842 r
.59005 .51184 .59086 .51307 .59242 .51244 .59161 .51124 Mtetra
.682 .685 .847 r
.59161 .51124 .59242 .51244 .59398 .51182 .59317 .51064 Mtetra
.684 .69 .85 r
.59317 .51064 .59398 .51182 .59554 .51119 .59473 .51003 Mtetra
.685 .694 .853 r
.59473 .51003 .59554 .51119 .5971 .51057 .5963 .50942 Mtetra
.685 .697 .855 r
.5963 .50942 .5971 .51057 .59866 .50997 .59786 .50882 Mtetra
.683 .694 .854 r
.59786 .50882 .59866 .50997 .60023 .50936 .59942 .50822 Mtetra
.683 .696 .856 r
.59942 .50822 .60023 .50936 .60179 .5087 .60099 .50762 Mtetra
.683 .709 .868 r
.60099 .50762 .60179 .5087 .60335 .50793 .60255 .50704 Mtetra
.684 .748 .899 r
.60255 .50704 .60335 .50793 .60491 .50717 .60412 .50646 Mtetra
.698 .798 .927 r
.60412 .50646 .60491 .50717 .60647 .50641 .60568 .50584 Mtetra
.766 .842 .91 r
.60568 .50584 .60647 .50641 .60803 .50556 .60724 .5049 Mtetra
.676 .804 .943 r
.60724 .5049 .60803 .50556 .6096 .505 .60881 .50435 Mtetra
.241 .61 .954 r
.60881 .50435 .6096 .505 .61118 .50503 .6104 .50471 Mtetra
.914 .522 .237 r
.6104 .50471 .61118 .50503 .61282 .50685 .61211 .50934 Mtetra
.959 .68 .464 r
.61211 .50934 .61282 .50685 .61456 .51254 .61885 .70265 Mtetra
.576 .364 .556 r
.61885 .70265 .61456 .51254 .62134 .7022 .62066 .70718 Mtetra
.576 .298 .458 r
.62066 .70718 .62134 .7022 .62312 .70581 .62236 .7076 Mtetra
.455 .084 .246 r
.62236 .7076 .62312 .70581 .62485 .70733 .62404 .70731 Mtetra
.473 .891 .911 r
.62404 .70731 .62485 .70733 .62656 .70796 .62571 .70674 Mtetra
.557 .646 .893 r
.62571 .70674 .62656 .70796 .62825 .70799 .6274 .70669 Mtetra
.655 .674 .856 r
.6274 .70669 .62825 .70799 .62992 .7075 .62908 .70621 Mtetra
.769 .715 .801 r
.62908 .70621 .62992 .7075 .63158 .70633 .63073 .70486 Mtetra
.906 .717 .636 r
.63073 .70486 .63158 .70633 .63318 .70319 .63225 .6992 Mtetra
.96 .686 .47 r
.63225 .6992 .63318 .70319 .63466 .69642 .62791 .50449 Mtetra
.579 .37 .562 r
.62791 .50449 .63466 .69642 .63034 .50648 .62934 .49898 Mtetra
.63 .451 .622 r
.62934 .49898 .63034 .50648 .63185 .50372 .63089 .49751 Mtetra
.598 .438 .636 r
.63089 .49751 .63185 .50372 .63344 .50335 .63248 .49707 Mtetra
.542 .398 .635 r
.63248 .49707 .63344 .50335 .63512 .50579 .6341 .49774 Mtetra
.246 .174 .575 r
.6341 .49774 .63512 .50579 .64312 .69608 .6359 .50349 Mtetra
.041 0 .437 r
.6359 .50349 .64312 .69608 .64498 .70075 .64406 .69721 Mtetra
0 .058 .586 r
.64406 .69721 .64498 .70075 .64674 .70237 .6459 .70116 Mtetra
.444 .592 .904 r
.6459 .70116 .64674 .70237 .6484 .70122 .64762 .70148 Mtetra
.33 .802 .718 r
.64762 .70148 .6484 .70122 .65002 .69877 .6493 .70078 Mtetra
.11 0 .127 r
.6493 .70078 .65002 .69877 .65154 .69356 .65094 .69899 Mtetra
0 0 .276 r
.65094 .69899 .65154 .69356 .64629 .5029 .65243 .69297 Mtetra
.031 0 .428 r
.65243 .69297 .64629 .5029 .64766 .49652 .64698 .4982 Mtetra
.899 .847 .392 r
.64698 .4982 .64766 .49652 .64917 .4938 .6484 .49295 Mtetra
.777 .782 .857 r
.6484 .49295 .64917 .4938 .65075 .49291 .64997 .49184 Mtetra
.653 .702 .883 r
.64997 .49184 .65075 .49291 .65235 .49245 .65156 .4914 Mtetra
.569 .672 .908 r
.65156 .4914 .65235 .49245 .65395 .49218 .65317 .49129 Mtetra
.76 .771 .862 r
.65317 .49129 .65395 .49218 .65552 .49105 .65475 .49028 Mtetra
.705 .788 .915 r
.65475 .49028 .65552 .49105 .65711 .49026 .65634 .48961 Mtetra
.454 .726 .984 r
.65634 .48961 .65711 .49026 .65872 .49015 .65796 .48962 Mtetra
.897 .478 .13 r
.65796 .48962 .65872 .49015 .66049 .49394 .65975 .49374 Mtetra
.967 .683 .441 r
.65975 .49374 .66049 .49394 .67019 .68904 .6694 .68874 Mtetra
.915 .52 .226 r
.6694 .68874 .67019 .68904 .67215 .69477 .67133 .69396 Mtetra
.064 .461 .884 r
.67133 .69396 .67215 .69477 .67391 .6956 .67309 .69474 Mtetra
.623 .752 .939 r
.67309 .69474 .67391 .6956 .67562 .69524 .6748 .69437 Mtetra
.805 .795 .842 r
.6748 .69437 .67562 .69524 .67728 .69384 .67647 .69297 Mtetra
.935 .768 .65 r
.67647 .69297 .67728 .69384 .6788 .689 .67798 .68812 Mtetra
.968 .69 .449 r
.67798 .68812 .6788 .689 .67186 .49361 .67109 .49264 Mtetra
.945 .743 .599 r
.67109 .49264 .67186 .49361 .67319 .48681 .67242 .48589 Mtetra
.794 .772 .833 r
.67242 .48589 .67319 .48681 .67476 .48552 .67399 .4846 Mtetra
.629 .727 .917 r
.67399 .4846 .67476 .48552 .67638 .48516 .67561 .48424 Mtetra
.497 .67 .941 r
.67561 .48424 .67638 .48516 .67801 .48522 .67724 .4843 Mtetra
.64 .731 .914 r
.67724 .4843 .67801 .48522 .67963 .48482 .67886 .4839 Mtetra
.664 .74 .907 r
.67886 .4839 .67963 .48482 .68124 .48432 .68047 .4834 Mtetra
.67 .743 .905 r
.68047 .4834 .68124 .48432 .68285 .4838 .68208 .48288 Mtetra
.761 .769 .859 r
.68208 .48288 .68285 .4838 .68443 .48277 .68367 .48186 Mtetra
.718 .759 .884 r
.68367 .48186 .68443 .48277 .68604 .48201 .68527 .4811 Mtetra
.55 .697 .937 r
.68527 .4811 .68604 .48201 .68767 .48191 .6869 .481 Mtetra
.834 .398 0 r
.6869 .481 .68767 .48191 .68949 .4856 .68873 .48469 Mtetra
.97 .683 .428 r
.68873 .48469 .68949 .4856 .70094 .68068 .70014 .67983 Mtetra
.912 .514 .132 r
.70014 .67983 .70094 .68068 .70296 .68626 .70216 .6854 Mtetra
0 .392 .844 r
.70216 .6854 .70296 .68626 .70476 .68723 .70396 .68638 Mtetra
.605 .748 .945 r
.70396 .68638 .70476 .68723 .70649 .68692 .70569 .68606 Mtetra
.799 .8 .852 r
.70569 .68606 .70649 .68692 .70817 .68559 .70737 .68473 Mtetra
.935 .776 .661 r
.70737 .68473 .70817 .68559 .70969 .68112 .70889 .68026 Mtetra
.971 .689 .438 r
.70889 .68026 .70969 .68112 .70102 .48549 .70026 .48455 Mtetra
.954 .743 .581 r
.70026 .48455 .70102 .48549 .70227 .47797 .70151 .47704 Mtetra
.828 .78 .807 r
.70151 .47704 .70227 .47797 .70383 .47634 .70308 .47542 Mtetra
.661 .74 .908 r
.70308 .47542 .70383 .47634 .70546 .47585 .7047 .47493 Mtetra
.542 .692 .937 r
.7047 .47493 .70546 .47585 .70711 .47578 .70635 .47486 Mtetra
.718 .759 .884 r
.70635 .47486 .70711 .47578 .70872 .47501 .70796 .47409 Mtetra
.706 .756 .89 r
.70796 .47409 .70872 .47501 .71034 .47431 .70958 .47339 Mtetra
.552 .697 .936 r
.70958 .47339 .71034 .47431 .71199 .47421 .71123 .47329 Mtetra
.751 .296 0 r
.71123 .47329 .71199 .47421 .71382 .47729 .71307 .47637 Mtetra
.972 .682 .417 r
.71307 .47637 .71382 .47729 .72674 .67229 .72595 .67139 Mtetra
.925 .539 .161 r
.72595 .67139 .72674 .67229 .72889 .6789 .7281 .67802 Mtetra
0 .308 .788 r
.7281 .67802 .72889 .6789 .73073 .68013 .72993 .67923 Mtetra
.598 .736 .941 r
.72993 .67923 .73073 .68013 .73248 .67985 .73168 .67894 Mtetra
.796 .792 .848 r
.73168 .67894 .73248 .67985 .73417 .67847 .73337 .6776 Mtetra
.937 .779 .659 r
.73337 .6776 .73417 .67847 .73563 .67347 .73488 .67313 Mtetra
.973 .689 .427 r
.73488 .67313 .73563 .67347 .72536 .47543 .72473 .47642 Mtetra
.995 .831 .473 r
.72473 .47642 .72536 .47543 .72666 .46932 .72596 .46922 Mtetra
.894 .964 .829 r
.72596 .46922 .72666 .46932 .72823 .4677 .72752 .46743 Mtetra
.587 .9 .985 r
.72752 .46743 .72823 .4677 .72987 .46728 .72916 .46689 Mtetra
.402 .785 .991 r
.72916 .46689 .72987 .46728 .73154 .46727 .73082 .46678 Mtetra
.575 .83 .993 r
.73082 .46678 .73154 .46727 .73319 .46687 .73247 .46642 Mtetra
.62 .86 .988 r
.73247 .46642 .73319 .46687 .73483 .46632 .73412 .46593 Mtetra
.579 .865 .995 r
.73412 .46593 .73483 .46632 .73648 .46599 .73576 .4655 Mtetra
.658 .861 .977 r
.73576 .4655 .73648 .46599 .73818 .46631 .7374 .46493 Mtetra
.642 .649 .842 r
.7374 .46493 .73818 .46631 .73993 .4675 .73905 .46451 Mtetra
.562 .479 .719 r
.73905 .46451 .73993 .4675 .74181 .47047 .74074 .46467 Mtetra
.377 .293 .633 r
.74074 .46467 .74181 .47047 .75614 .66111 .74262 .46767 Mtetra
.097 .019 .469 r
.74262 .46767 .75614 .66111 .75844 .66875 .75731 .66272 Mtetra
.043 .064 .555 r
.75731 .66272 .75844 .66875 .76039 .67117 .75954 .6693 Mtetra
.32 .422 .809 r
.75954 .6693 .76039 .67117 .76222 .67176 .76141 .67044 Mtetra
.621 .663 .869 r
.76141 .67044 .76222 .67176 .76399 .67152 .76318 .67011 Mtetra
.695 .681 .833 r
.76318 .67011 .76399 .67152 .76575 .67096 .76492 .66933 Mtetra
.664 .64 .816 r
.76492 .66933 .76575 .67096 .76751 .67047 .76667 .66873 Mtetra
.64 .616 .81 r
.76667 .66873 .76751 .67047 .76927 .66996 .76843 .66827 Mtetra
.65 .627 .813 r
.76843 .66827 .76927 .66996 .77101 .66919 .7702 .66776 Mtetra
.632 .651 .85 r
.7702 .66776 .77101 .66919 .77271 .66783 .77197 .66737 Mtetra
.61 .864 .991 r
.77197 .66737 .77271 .66783 .77435 .66565 .77373 .66686 Mtetra
.131 0 0 r
.77373 .66686 .77435 .66565 .77589 .66195 .77545 .66577 Mtetra
.126 0 .301 r
.77545 .66577 .77589 .66195 .7641 .47472 .77699 .66208 Mtetra
.086 .007 .461 r
.77699 .66208 .7641 .47472 .76483 .46135 .76461 .46745 Mtetra
0 0 .237 r
.76461 .46745 .76483 .46135 .76628 .45795 .76563 .45808 Mtetra
.919 .978 .746 r
.76563 .45808 .76628 .45795 .76788 .45656 .76716 .45585 Mtetra
.695 .811 .937 r
.76716 .45585 .76788 .45656 .76954 .45611 .76881 .4552 Mtetra
.584 .717 .934 r
.76881 .4552 .76954 .45611 .77123 .45595 .7705 .45498 Mtetra
.63 .723 .914 r
.7705 .45498 .77123 .45595 .77289 .45543 .77217 .45461 Mtetra
.68 .778 .924 r
.77217 .45461 .77289 .45543 .77453 .45463 .77383 .45402 Mtetra
.656 .829 .966 r
.77383 .45402 .77453 .45463 .77619 .45405 .77549 .45348 Mtetra
.682 .85 .963 r
.77549 .45348 .77619 .45405 .7779 .45411 .77715 .45285 Mtetra
.665 .681 .855 r
.77715 .45285 .7779 .45411 .77969 .45507 .77882 .45231 Mtetra
.58 .501 .73 r
.77882 .45231 .77969 .45507 .78159 .4575 .78052 .45229 Mtetra
.428 .337 .65 r
.78052 .45229 .78159 .4575 .79796 .64356 .7824 .45445 Mtetra
.11 .032 .478 r
.7824 .45445 .79796 .64356 .80078 .65628 .79936 .64713 Mtetra
.08 .063 .536 r
.79936 .64713 .80078 .65628 .80282 .65906 .80196 .65692 Mtetra
.261 .357 .773 r
.80196 .65692 .80282 .65906 .80469 .65974 .80391 .65852 Mtetra
.627 .684 .885 r
.80391 .65852 .80469 .65974 .80648 .65931 .8057 .65815 Mtetra
.724 .735 .859 r
.8057 .65815 .80648 .65931 .80824 .65848 .80745 .65724 Mtetra
.714 .718 .852 r
.80745 .65724 .80824 .65848 .80999 .65759 .80921 .65638 Mtetra
.673 .706 .872 r
.80921 .65638 .80999 .65759 .81176 .65679 .81099 .65577 Mtetra
.676 .745 .903 r
.81099 .65577 .81176 .65679 .81352 .65597 .81277 .65516 Mtetra
.669 .791 .94 r
.81277 .65516 .81352 .65597 .81529 .65526 .81455 .65457 Mtetra
.655 .82 .963 r
.81455 .65457 .81529 .65526 .81707 .65468 .81633 .65401 Mtetra
.649 .823 .967 r
.81633 .65401 .81707 .65468 .81886 .65416 .81812 .65346 Mtetra
.551 .776 .982 r
.81812 .65346 .81886 .65416 .82067 .65388 .81994 .65322 Mtetra
.491 .761 .991 r
.81994 .65322 .82067 .65388 .82249 .65369 .82176 .6531 Mtetra
.679 .856 .967 r
.82176 .6531 .82249 .65369 .82428 .65312 .82354 .65243 Mtetra
.925 .836 .739 r
.82354 .65243 .82428 .65312 .82595 .6512 .82513 .64955 Mtetra
.976 .683 .392 r
.82513 .64955 .82595 .6512 .82734 .64608 .81046 .45973 Mtetra
.593 .38 .562 r
.81046 .45973 .82734 .64608 .81231 .45375 .81089 .44483 Mtetra
.653 .459 .61 r
.81089 .44483 .81231 .45375 .81356 .44823 .81239 .44213 Mtetra
.608 .447 .638 r
.81239 .44213 .81356 .44823 .81524 .44757 .81406 .44145 Mtetra
.585 .431 .64 r
.81406 .44145 .81524 .44757 .817 .44787 .81578 .44128 Mtetra
.583 .426 .634 r
.81578 .44128 .817 .44787 .81878 .44829 .81751 .44113 Mtetra
.593 .428 .628 r
.81751 .44113 .81878 .44829 .8205 .44811 .81921 .44071 Mtetra
.592 .426 .626 r
.81921 .44071 .8205 .44811 .82223 .44792 .82091 .44029 Mtetra
.592 .424 .624 r
.82091 .44029 .82223 .44792 .82395 .4477 .82261 .43986 Mtetra
.592 .423 .622 r
.82261 .43986 .82395 .4477 .82567 .44744 .82431 .43941 Mtetra
.592 .422 .621 r
.82431 .43941 .82567 .44744 .82739 .44714 .82602 .43895 Mtetra
.592 .421 .619 r
.82602 .43895 .82739 .44714 .82911 .4468 .82772 .43848 Mtetra
.592 .42 .618 r
.82772 .43848 .82911 .4468 .83083 .44644 .82942 .438 Mtetra
.82942 .438 .83083 .44644 .83254 .44603 .83112 .43751 Mtetra
.592 .419 .617 r
.83112 .43751 .83254 .44603 .83425 .4456 .83282 .43701 Mtetra
.83282 .43701 .83425 .4456 .83596 .44514 .83452 .4365 Mtetra
.592 .419 .616 r
.83452 .4365 .83596 .44514 .83767 .44465 .83623 .43599 Mtetra
.83623 .43599 .83767 .44465 .83938 .44414 .83793 .43546 Mtetra
.83793 .43546 .83938 .44414 .84108 .44362 .83963 .43494 Mtetra
.83963 .43494 .84108 .44362 .84279 .44308 .84134 .43441 Mtetra
.84134 .43441 .84279 .44308 .8445 .44253 .84304 .43388 Mtetra
.84304 .43388 .8445 .44253 .84621 .44199 .84475 .43335 Mtetra
.593 .419 .616 r
.84475 .43335 .84621 .44199 .84791 .44143 .84646 .43282 Mtetra
.593 .42 .617 r
.84646 .43282 .84791 .44143 .84962 .44086 .84817 .43229 Mtetra
.84817 .43229 .84962 .44086 .85133 .44029 .84987 .43175 Mtetra
.84987 .43175 .85133 .44029 .85304 .43969 .85158 .43121 Mtetra
.594 .421 .617 r
.85158 .43121 .85304 .43969 .85474 .43904 .85329 .43066 Mtetra
.595 .422 .618 r
.85329 .43066 .85474 .43904 .85644 .43833 .855 .43008 Mtetra
.595 .423 .619 r
.855 .43008 .85644 .43833 .85814 .43762 .85671 .42951 Mtetra
.6 .427 .62 r
.85671 .42951 .85814 .43762 .85979 .43648 .8584 .42879 Mtetra
.61 .436 .622 r
.8584 .42879 .85979 .43648 .86139 .43482 .86008 .42783 Mtetra
.596 .432 .63 r
.86008 .42783 .86139 .43482 .86311 .43433 .8618 .42734 Mtetra
.536 .392 .632 r
.8618 .42734 .86311 .43433 .8653 .43827 .86366 .42827 Mtetra
.196 .141 .565 r
.86366 .42827 .8653 .43827 .88727 .63071 .86641 .43755 Mtetra
.153 .069 .499 r
.86641 .43755 .88727 .63071 .8896 .63485 .88868 .63211 Mtetra
.14 .233 .7 r
.88868 .63211 .8896 .63485 .89164 .63628 .89087 .63493 Mtetra
.586 .646 .877 r
.89087 .63493 .89164 .63628 .8935 .636 .89274 .63476 Mtetra
.703 .718 .861 r
.89274 .63476 .8935 .636 .89532 .63528 .89455 .63396 Mtetra
.727 .715 .839 r
.89455 .63396 .89532 .63528 .89711 .63437 .89634 .63296 Mtetra
.668 .677 .85 r
.89634 .63296 .89711 .63437 .89893 .6336 .89817 .63235 Mtetra
.671 .704 .872 r
.89817 .63235 .89893 .6336 .90074 .63281 .9 .63174 Mtetra
.667 .736 .902 r
.9 .63174 .90074 .63281 .90256 .63209 .90184 .63116 Mtetra
.655 .761 .928 r
.90184 .63116 .90256 .63209 .9044 .63156 .90368 .63062 Mtetra
.644 .758 .932 r
.90368 .63062 .9044 .63156 .90625 .6311 .90553 .63014 Mtetra
.628 .745 .931 r
.90553 .63014 .90625 .6311 .90811 .63074 .90739 .62972 Mtetra
.604 .72 .927 r
.90739 .62972 .90811 .63074 .91 .63055 .90926 .62941 Mtetra
.613 .7 .906 r
.90926 .62941 .91 .63055 .91186 .6302 .91113 .62909 Mtetra
.609 .704 .912 r
.91113 .62909 .91186 .6302 .91369 .62949 .913 .62878 Mtetra
.526 .764 .984 r
.913 .62878 .91369 .62949 .91544 .62808 .91489 .6286 Mtetra
.022 0 0 r
.91489 .6286 .91544 .62808 .9171 .62585 .91673 .62795 Mtetra
.216 0 .219 r
.91673 .62795 .9171 .62585 .91851 .62145 .91844 .62615 Mtetra
0 0 .268 r
.91844 .62615 .91851 .62145 .89799 .42619 .9195 .61868 Mtetra
.152 .066 .496 r
.9195 .61868 .89799 .42619 .89902 .41947 .89854 .42019 Mtetra
.91 .865 .426 r
.89854 .42019 .89902 .41947 .90051 .41677 .89983 .4158 Mtetra
.756 .777 .87 r
.89983 .4158 .90051 .41677 .90221 .41589 .90151 .41476 Mtetra
.641 .702 .89 r
.90151 .41476 .90221 .41589 .90396 .41544 .90327 .41434 Mtetra
.609 .692 .902 r
.90327 .41434 .90396 .41544 .90571 .41505 .90504 .41405 Mtetra
.759 .773 .865 r
.90504 .41405 .90571 .41505 .90739 .41399 .90672 .41299 Mtetra
.687 .748 .897 r
.90672 .41299 .90739 .41399 .90912 .41334 .90845 .41234 Mtetra
.424 .619 .933 r
.90845 .41234 .90912 .41334 .91097 .41364 .91029 .41264 Mtetra
.787 .372 0 r
.91029 .41264 .91097 .41364 .91339 .41879 .91272 .41779 Mtetra
.973 .661 .312 r
.91272 .41779 .91339 .41879 .93918 .61783 .93848 .61689 Mtetra
.723 .285 0 r
.93848 .61689 .93918 .61783 .94162 .62208 .94092 .62115 Mtetra
.497 .691 .955 r
.94092 .62115 .94162 .62208 .94355 .6221 .94286 .62117 Mtetra
.692 .781 .919 r
.94286 .62117 .94355 .6221 .9454 .62139 .9447 .62046 Mtetra
.742 .798 .898 r
.9447 .62046 .9454 .62139 .94721 .62041 .94652 .61949 Mtetra
.495 .691 .955 r
.94652 .61949 .94721 .62041 .94915 .62044 .94846 .61951 Mtetra
.62 .752 .941 r
.94846 .61951 .94915 .62044 .95104 .62004 .95035 .61911 Mtetra
.798 .815 .865 r
.95035 .61911 .95104 .62004 .95281 .61869 .95212 .61776 Mtetra
.98 .777 .558 r
.95212 .61776 .95281 .61869 .95391 .61192 .95322 .611 Mtetra
.975 .669 .322 r
.95322 .611 .95391 .61192 .93072 .41167 .93006 .41069 Mtetra
.964 .784 .611 r
.93006 .41069 .93072 .41167 .93192 .40673 .93126 .40574 Mtetra
.757 .778 .87 r
.93126 .40574 .93192 .40673 .93362 .40569 .93296 .4047 Mtetra
.627 .726 .919 r
.93296 .4047 .93362 .40569 .9354 .40531 .93474 .40432 Mtetra
.544 .687 .932 r
.93474 .40432 .9354 .40531 .93722 .40524 .93656 .40424 Mtetra
.748 .775 .875 r
.93656 .40424 .93722 .40524 .93892 .40425 .93826 .40325 Mtetra
.681 .75 .903 r
.93826 .40325 .93892 .40425 .94067 .40362 .94001 .40263 Mtetra
.488 .656 .935 r
.94001 .40263 .94067 .40362 .94252 .40373 .94186 .40274 Mtetra
.739 .321 0 r
.94186 .40274 .94252 .40373 .94498 .40852 .94432 .40753 Mtetra
.97 .655 .291 r
.94432 .40753 .94498 .40852 .97292 .60842 .97224 .60748 Mtetra
.74 .309 0 r
.97224 .60748 .97292 .60842 .9755 .61319 .97482 .61225 Mtetra
.031 .462 .877 r
.36418 .77601 .36512 .77677 .3666 .77739 .36566 .77663 Mtetra
.643 .762 .935 r
.36566 .77663 .3666 .77739 .36812 .77699 .36719 .77623 Mtetra
.809 .778 .824 r
.36719 .77623 .36812 .77699 .36969 .77557 .36876 .7748 Mtetra
.908 .737 .658 r
.36876 .7748 .36969 .77557 .37143 .77032 .3705 .76956 Mtetra
.937 .686 .534 r
.3705 .76956 .37143 .77032 .38098 .58001 .38011 .57918 Mtetra
.908 .727 .645 r
.38011 .57918 .38098 .58001 .38265 .57434 .38178 .57352 Mtetra
.777 .759 .836 r
.38178 .57352 .38265 .57434 .38413 .57323 .38325 .57241 Mtetra
.643 .735 .915 r
.38325 .57241 .38413 .57323 .38557 .57287 .3847 .57204 Mtetra
.517 .692 .948 r
.3847 .57204 .38557 .57287 .387 .57285 .38613 .57202 Mtetra
.747 .755 .859 r
.38613 .57202 .387 .57285 .38847 .57198 .38759 .57115 Mtetra
.7 .748 .889 r
.38759 .57115 .38847 .57198 .38992 .57138 .38905 .57054 Mtetra
.502 .685 .949 r
.38905 .57054 .38992 .57138 .39136 .5714 .39048 .57056 Mtetra
.921 .531 .221 r
.39048 .57056 .39136 .5714 .39265 .5751 .39178 .57424 Mtetra
.939 .683 .522 r
.39178 .57424 .39265 .5751 .3868 .76441 .38587 .76359 Mtetra
.939 .591 .336 r
.38587 .76359 .3868 .76441 .3881 .76996 .38718 .76918 Mtetra
.249 .589 .947 r
.38718 .76918 .3881 .76996 .38961 .77034 .38868 .76957 Mtetra
.684 .769 .916 r
.38868 .76957 .38961 .77034 .39116 .76977 .39023 .76901 Mtetra
.763 .782 .868 r
.39023 .76901 .39116 .76977 .39272 .76876 .39179 .76801 Mtetra
.641 .765 .938 r
.39179 .76801 .39272 .76876 .39426 .76823 .39333 .76761 Mtetra
.631 .798 .963 r
.39333 .76761 .39426 .76823 .3958 .76778 .39487 .76721 Mtetra
.686 .823 .948 r
.39487 .76721 .3958 .76778 .39735 .76735 .39642 .76662 Mtetra
.808 .789 .835 r
.39642 .76662 .39735 .76735 .39889 .76696 .398 .76526 Mtetra
.774 .66 .738 r
.398 .76526 .39889 .76696 .40043 .76658 .39959 .76343 Mtetra
.727 .573 .681 r
.39959 .76343 .40043 .76658 .40197 .76622 .40119 .76131 Mtetra
.65 .491 .654 r
.40119 .76131 .40197 .76622 .40352 .76587 .40277 .76001 Mtetra
.597 .442 .642 r
.40277 .76001 .40352 .76587 .40506 .76552 .40431 .75963 Mtetra
.55 .409 .641 r
.40431 .75963 .40506 .76552 .40661 .76518 .40583 .76007 Mtetra
.461 .356 .648 r
.40583 .76007 .40661 .76518 .40815 .76485 .40732 .76153 Mtetra
.416 .372 .701 r
.40732 .76153 .40815 .76485 .4097 .76452 .40881 .76276 Mtetra
.363 .453 .82 r
.40881 .76276 .4097 .76452 .41125 .76418 .41032 .76353 Mtetra
.482 .742 .985 r
.41032 .76353 .41125 .76418 .41279 .76386 .41186 .76348 Mtetra
.579 .852 .996 r
.41186 .76348 .41279 .76386 .41434 .7635 .41341 .7631 Mtetra
.644 .862 .982 r
.41341 .7631 .41434 .7635 .4159 .76307 .41497 .76258 Mtetra
.465 .782 .998 r
.41497 .76258 .4159 .76307 .41745 .76281 .41652 .76246 Mtetra
.493 .832 .998 r
.41652 .76246 .41745 .76281 .419 .76228 .41807 .76221 Mtetra
.66 .944 .96 r
.41807 .76221 .419 .76228 .42058 .76109 .41963 .76147 Mtetra
.956 .92 .731 r
.41963 .76147 .42058 .76109 .42227 .7562 .42126 .75855 Mtetra
.997 .848 .513 r
.42126 .75855 .42227 .7562 .42919 .56562 .42305 .75022 Mtetra
0 0 .336 r
.42305 .75022 .42919 .56562 .43082 .55984 .42984 .56298 Mtetra
.201 0 .261 r
.42984 .56298 .43082 .55984 .43232 .55835 .43137 .5609 Mtetra
.486 .165 .348 r
.43137 .5609 .43232 .55835 .43379 .5579 .43284 .56056 Mtetra
.532 .215 .376 r
.43284 .56056 .43379 .5579 .43526 .55784 .4343 .56053 Mtetra
.26 0 .258 r
.4343 .56053 .43526 .55784 .43673 .55754 .43581 .55898 Mtetra
0 0 0 r
.43581 .55898 .43673 .55754 .4382 .55714 .43732 .55719 Mtetra
.857 .964 .87 r
.43732 .55719 .4382 .55714 .43968 .55674 .43883 .55577 Mtetra
.71 .725 .862 r
.43883 .55577 .43968 .55674 .44116 .5563 .44031 .55507 Mtetra
.635 .656 .853 r
.44031 .55507 .44116 .5563 .44264 .55584 .44179 .55474 Mtetra
.606 .667 .882 r
.44179 .55474 .44264 .55584 .44412 .55536 .44326 .55452 Mtetra
.638 .734 .918 r
.44326 .55452 .44412 .55536 .4456 .55485 .44474 .55417 Mtetra
.661 .781 .937 r
.44474 .55417 .4456 .55485 .44708 .55433 .44622 .55371 Mtetra
.672 .798 .942 r
.44622 .55371 .44708 .55433 .44856 .55388 .4477 .55321 Mtetra
.749 .798 .892 r
.4477 .55321 .44856 .55388 .45005 .55329 .4492 .55236 Mtetra
.725 .738 .862 r
.4492 .55236 .45005 .55329 .45153 .55288 .45069 .55159 Mtetra
.635 .645 .843 r
.45069 .55159 .45153 .55288 .453 .55306 .45217 .55125 Mtetra
.142 .299 .764 r
.45217 .55125 .453 .55306 .45441 .55618 .45362 .55262 Mtetra
0 0 .268 r
.45362 .55262 .45441 .55618 .45202 .74592 .45498 .55797 Mtetra
0 0 .364 r
.45498 .55797 .45202 .74592 .45346 .752 .45265 .74647 Mtetra
.275 .218 .611 r
.45265 .74647 .45346 .752 .455 .75306 .45415 .74979 Mtetra
.453 .399 .707 r
.45415 .74979 .455 .75306 .45658 .75277 .4557 .7508 Mtetra
.512 .516 .797 r
.4557 .7508 .45658 .75277 .45816 .752 .45726 .75111 Mtetra
.553 .708 .943 r
.45726 .75111 .45816 .752 .45975 .75122 .45884 .751 Mtetra
.509 .869 .986 r
.45884 .751 .45975 .75122 .46133 .75048 .46041 .75062 Mtetra
.366 .836 .826 r
.46041 .75062 .46133 .75048 .46292 .74972 .462 .7501 Mtetra
.106 0 0 r
.462 .7501 .46292 .74972 .4645 .7495 .46358 .74988 Mtetra
.46358 .74988 .4645 .7495 .46607 .74935 .46516 .74965 Mtetra
.341 .811 .732 r
.46516 .74965 .46607 .74935 .46766 .74864 .46674 .749 Mtetra
.922 .97 .774 r
.46674 .749 .46766 .74864 .46929 .74517 .46836 .74676 Mtetra
.985 .886 .543 r
.46836 .74676 .46929 .74517 .47374 .55577 .47002 .74111 Mtetra
0 0 .354 r
.47002 .74111 .47374 .55577 .47536 .54699 .47444 .55119 Mtetra
0 0 .14 r
.47444 .55119 .47536 .54699 .47688 .54492 .476 .54644 Mtetra
0 0 0 r
.476 .54644 .47688 .54492 .47838 .54436 .47752 .54454 Mtetra
.769 .994 .875 r
.47752 .54454 .47838 .54436 .47987 .54423 .47903 .54335 Mtetra
.722 .748 .873 r
.47903 .54335 .47987 .54423 .48137 .544 .48054 .5426 Mtetra
.657 .641 .823 r
.48054 .5426 .48137 .544 .48287 .54358 .48204 .54213 Mtetra
.632 .623 .824 r
.48204 .54213 .48287 .54358 .48437 .54317 .48354 .5418 Mtetra
.642 .639 .832 r
.48354 .5418 .48437 .54317 .48587 .54273 .48504 .54142 Mtetra
.656 .653 .835 r
.48504 .54142 .48587 .54273 .48738 .54227 .48654 .54097 Mtetra
.658 .655 .836 r
.48654 .54097 .48738 .54227 .48888 .54179 .48805 .5405 Mtetra
.66 .658 .837 r
.48805 .5405 .48888 .54179 .49039 .54128 .48955 .54002 Mtetra
.663 .663 .84 r
.48955 .54002 .49039 .54128 .4919 .54076 .49106 .53954 Mtetra
.664 .67 .845 r
.49106 .53954 .4919 .54076 .4934 .54023 .49257 .53905 Mtetra
.665 .676 .851 r
.49257 .53905 .4934 .54023 .49491 .53972 .49408 .53856 Mtetra
.664 .679 .854 r
.49408 .53856 .49491 .53972 .49642 .53923 .49559 .53808 Mtetra
.664 .681 .856 r
.49559 .53808 .49642 .53923 .49793 .53875 .49709 .5376 Mtetra
.663 .681 .857 r
.49709 .5376 .49793 .53875 .49944 .53827 .49861 .53712 Mtetra
.49861 .53712 .49944 .53827 .50095 .53779 .50012 .53664 Mtetra
.662 .681 .858 r
.50012 .53664 .50095 .53779 .50246 .53732 .50163 .53617 Mtetra
.50163 .53617 .50246 .53732 .50397 .53685 .50314 .5357 Mtetra
.50314 .5357 .50397 .53685 .50549 .53638 .50466 .53523 Mtetra
.661 .681 .858 r
.50466 .53523 .50549 .53638 .507 .53591 .50617 .53476 Mtetra
.50617 .53476 .507 .53591 .50852 .53545 .50769 .53429 Mtetra
.50769 .53429 .50852 .53545 .51003 .53498 .5092 .53382 Mtetra
.5092 .53382 .51003 .53498 .51155 .53451 .51072 .53336 Mtetra
.51072 .53336 .51155 .53451 .51307 .53405 .51224 .53289 Mtetra
.51224 .53289 .51307 .53405 .51458 .53358 .51376 .53242 Mtetra
.51376 .53242 .51458 .53358 .5161 .53311 .51528 .53195 Mtetra
.51528 .53195 .5161 .53311 .51762 .53264 .5168 .53149 Mtetra
.5168 .53149 .51762 .53264 .51914 .53218 .51832 .53102 Mtetra
.51832 .53102 .51914 .53218 .52067 .53171 .51984 .53055 Mtetra
.51984 .53055 .52067 .53171 .52219 .53124 .52136 .53008 Mtetra
.52136 .53008 .52219 .53124 .52371 .53077 .52289 .52961 Mtetra
.52289 .52961 .52371 .53077 .52524 .53029 .52441 .52913 Mtetra
.662 .681 .858 r
.52441 .52913 .52524 .53029 .52676 .52982 .52594 .52866 Mtetra
.662 .682 .858 r
.52594 .52866 .52676 .52982 .52829 .52934 .52746 .52819 Mtetra
.52746 .52819 .52829 .52934 .52981 .52887 .52899 .52771 Mtetra
.663 .683 .858 r
.52899 .52771 .52981 .52887 .53134 .52838 .53052 .52723 Mtetra
.663 .683 .859 r
.53052 .52723 .53134 .52838 .53287 .5279 .53205 .52675 Mtetra
.664 .684 .859 r
.53205 .52675 .53287 .5279 .5344 .52741 .53358 .52626 Mtetra
.664 .685 .86 r
.53358 .52626 .5344 .52741 .53593 .5269 .53511 .52578 Mtetra
.664 .69 .864 r
.53511 .52578 .53593 .5269 .53746 .52637 .53664 .52529 Mtetra
.669 .699 .869 r
.53664 .52529 .53746 .52637 .53899 .52588 .53817 .52479 Mtetra
.679 .7 .863 r
.53817 .52479 .53899 .52588 .54052 .52551 .5397 .52423 Mtetra
.683 .672 .833 r
.5397 .52423 .54052 .52551 .54206 .52528 .54124 .52362 Mtetra
.669 .618 .789 r
.54124 .52362 .54206 .52528 .5436 .52508 .54277 .523 Mtetra
.652 .576 .756 r
.54277 .523 .5436 .52508 .54513 .52478 .5443 .52243 Mtetra
.64 .551 .739 r
.5443 .52243 .54513 .52478 .54667 .5243 .54584 .52191 Mtetra
.634 .546 .738 r
.54584 .52191 .54667 .5243 .54821 .52378 .54738 .52144 Mtetra
.641 .553 .739 r
.54738 .52144 .54821 .52378 .54974 .5231 .54891 .5209 Mtetra
.652 .567 .747 r
.54891 .5209 .54974 .5231 .55128 .52229 .55045 .5203 Mtetra
.618 .564 .771 r
.55045 .5203 .55128 .52229 .55282 .52195 .55199 .52001 Mtetra
.434 .466 .793 r
.55199 .52001 .55282 .52195 .55437 .52312 .55354 .52068 Mtetra
0 0 .486 r
.55354 .52068 .55437 .52312 .55602 .5342 .55512 .52409 Mtetra
.971 .699 .458 r
.55512 .52409 .55602 .5342 .5594 .72161 .55847 .71323 Mtetra
.203 .14 .559 r
.55847 .71323 .5594 .72161 .56107 .72421 .56017 .71945 Mtetra
.575 .443 .664 r
.56017 .71945 .56107 .72421 .56271 .72423 .56181 .71948 Mtetra
.616 .471 .662 r
.56181 .71948 .56271 .72423 .56435 .72367 .56345 .71886 Mtetra
.563 .435 .663 r
.56345 .71886 .56435 .72367 .56599 .72301 .56509 .71908 Mtetra
.408 .35 .681 r
.56509 .71908 .56599 .72301 .56763 .72269 .56676 .7207 Mtetra
.441 .477 .801 r
.56676 .7207 .56763 .72269 .56927 .72193 .56842 .72136 Mtetra
.777 .849 .905 r
.56842 .72136 .56927 .72193 .57089 .71984 .57005 .72031 Mtetra
.989 .833 .596 r
.57005 .72031 .57089 .71984 .57244 .71182 .57162 .71431 Mtetra
.963 .695 .478 r
.57162 .71431 .57244 .71182 .57141 .51995 .57061 .51986 Mtetra
.966 .819 .646 r
.57061 .51986 .57141 .51995 .57292 .51622 .57211 .51525 Mtetra
.73 .74 .86 r
.57211 .51525 .57292 .51622 .57447 .51545 .57366 .51442 Mtetra
.584 .68 .907 r
.57366 .51442 .57447 .51545 .57602 .51529 .57521 .51426 Mtetra
.518 .651 .917 r
.57521 .51426 .57602 .51529 .57758 .51533 .57678 .51431 Mtetra
.636 .701 .893 r
.57678 .51431 .57758 .51533 .57914 .51501 .57833 .51395 Mtetra
.637 .695 .887 r
.57833 .51395 .57914 .51501 .5807 .51468 .57989 .51359 Mtetra
.643 .69 .879 r
.57989 .51359 .5807 .51468 .58226 .51433 .58145 .5132 Mtetra
.655 .688 .869 r
.58145 .5132 .58226 .51433 .58382 .51392 .58301 .51276 Mtetra
.661 .685 .861 r
.58301 .51276 .58382 .51392 .58538 .51346 .58457 .51228 Mtetra
.666 .682 .855 r
.58457 .51228 .58538 .51346 .58694 .51297 .58613 .51177 Mtetra
.67 .682 .852 r
.58613 .51177 .58694 .51297 .58849 .51242 .58769 .51123 Mtetra
.678 .688 .852 r
.58769 .51123 .58849 .51242 .59005 .51184 .58925 .51066 Mtetra
.688 .692 .849 r
.58925 .51066 .59005 .51184 .59161 .51124 .5908 .51003 Mtetra
.7 .692 .839 r
.5908 .51003 .59161 .51124 .59317 .51064 .59236 .50932 Mtetra
.695 .673 .824 r
.59236 .50932 .59317 .51064 .59473 .51003 .59392 .5086 Mtetra
.69 .656 .812 r
.59392 .5086 .59473 .51003 .5963 .50942 .59548 .5079 Mtetra
.687 .643 .801 r
.59548 .5079 .5963 .50942 .59786 .50882 .59704 .50718 Mtetra
.662 .62 .797 r
.59704 .50718 .59786 .50882 .59942 .50822 .59861 .50661 Mtetra
.614 .601 .815 r
.59861 .50661 .59942 .50822 .60099 .50762 .60018 .50637 Mtetra
.384 .536 .884 r
.60018 .50637 .60099 .50762 .60255 .50704 .60177 .50688 Mtetra
.514 0 0 r
.60177 .50688 .60255 .50704 .60412 .50646 .60337 .50777 Mtetra
.635 .238 .275 r
.60337 .50777 .60412 .50646 .60568 .50584 .60497 .50862 Mtetra
.41 .107 .337 r
.60497 .50862 .60568 .50584 .60724 .5049 .60654 .50767 Mtetra
.452 .143 .35 r
.60654 .50767 .60724 .5049 .60881 .50435 .6081 .507 Mtetra
.611 .287 .396 r
.6081 .507 .60881 .50435 .6104 .50471 .60971 .50778 Mtetra
.958 .679 .466 r
.60971 .50778 .6104 .50471 .61211 .50934 .61621 .69699 Mtetra
.581 .368 .557 r
.61621 .69699 .61211 .50934 .61885 .70265 .6181 .70519 Mtetra
.715 .382 .413 r
.6181 .70519 .61885 .70265 .62066 .70718 .61985 .70754 Mtetra
.288 0 0 r
.61985 .70754 .62066 .70718 .62236 .7076 .62154 .70759 Mtetra
.456 .883 .904 r
.62154 .70759 .62236 .7076 .62404 .70731 .62321 .70704 Mtetra
.758 .932 .944 r
.62321 .70704 .62404 .70731 .62571 .70674 .62488 .70604 Mtetra
.78 .823 .886 r
.62488 .70604 .62571 .70674 .6274 .70669 .62654 .70493 Mtetra
.769 .665 .748 r
.62654 .70493 .6274 .70669 .62908 .70621 .62818 .70319 Mtetra
.779 .609 .669 r
.62818 .70319 .62908 .70621 .63073 .70486 .62977 .69996 Mtetra
.959 .685 .473 r
.62977 .69996 .63073 .70486 .63225 .6992 .6257 .50931 Mtetra
.585 .375 .562 r
.6257 .50931 .63225 .6992 .62791 .50449 .62701 .50001 Mtetra
.728 .545 .644 r
.62701 .50001 .62791 .50449 .62934 .49898 .62852 .49694 Mtetra
.719 .614 .74 r
.62852 .49694 .62934 .49898 .63089 .49751 .63008 .49568 Mtetra
.644 .594 .783 r
.63008 .49568 .63089 .49751 .63248 .49707 .63166 .49521 Mtetra
.481 .503 .803 r
.63166 .49521 .63248 .49707 .6341 .49774 .63328 .49566 Mtetra
0 0 .288 r
.63328 .49566 .6341 .49774 .6359 .50349 .63502 .49992 Mtetra
.969 .688 .443 r
.63502 .49992 .6359 .50349 .64406 .69721 .64319 .69506 Mtetra
.742 .394 0 r
.64319 .69506 .64406 .69721 .6459 .70116 .64507 .70022 Mtetra
.131 .473 .895 r
.64507 .70022 .6459 .70116 .64762 .70148 .6468 .701 Mtetra
.543 .826 .998 r
.6468 .701 .64762 .70148 .6493 .70078 .6485 .70069 Mtetra
.817 .973 .896 r
.6485 .70069 .6493 .70078 .65094 .69899 .65016 .69934 Mtetra
.991 .861 .607 r
.65016 .69934 .65094 .69899 .65243 .69297 .65169 .6943 Mtetra
.969 .693 .454 r
.65169 .6943 .65243 .69297 .64698 .4982 .64624 .49859 Mtetra
.994 .82 .562 r
.64624 .49859 .64698 .4982 .6484 .49295 .64762 .49204 Mtetra
.781 .77 .843 r
.64762 .49204 .6484 .49295 .64997 .49184 .64918 .49087 Mtetra
.649 .72 .9 r
.64918 .49087 .64997 .49184 .65156 .4914 .65078 .49044 Mtetra
.541 .68 .929 r
.65078 .49044 .65156 .4914 .65317 .49129 .6524 .49039 Mtetra
.755 .768 .864 r
.6524 .49039 .65317 .49129 .65475 .49028 .65398 .48942 Mtetra
.697 .761 .901 r
.65398 .48942 .65475 .49028 .65634 .48961 .65557 .48878 Mtetra
.487 .688 .956 r
.65557 .48878 .65634 .48961 .65796 .48962 .65719 .48882 Mtetra
.89 .471 .075 r
.65719 .48882 .65796 .48962 .65975 .49374 .65898 .49305 Mtetra
.967 .684 .44 r
.65898 .49305 .65975 .49374 .6694 .68874 .66858 .68804 Mtetra
.912 .509 .153 r
.66858 .68804 .6694 .68874 .67133 .69396 .67052 .69313 Mtetra
.085 .471 .891 r
.67052 .69313 .67133 .69396 .67309 .69474 .67227 .69389 Mtetra
.623 .755 .941 r
.67227 .69389 .67309 .69474 .6748 .69437 .67398 .69352 Mtetra
.807 .798 .844 r
.67398 .69352 .6748 .69437 .67647 .69297 .67565 .69212 Mtetra
.936 .769 .649 r
.67565 .69212 .67647 .69297 .67798 .68812 .67717 .68725 Mtetra
.968 .69 .449 r
.67717 .68725 .67798 .68812 .67109 .49264 .67031 .4917 Mtetra
.946 .744 .599 r
.67031 .4917 .67109 .49264 .67242 .48589 .67165 .48497 Mtetra
.794 .773 .834 r
.67165 .48497 .67242 .48589 .67399 .4846 .67322 .48368 Mtetra
.629 .727 .918 r
.67322 .48368 .67399 .4846 .67561 .48424 .67484 .48332 Mtetra
.496 .671 .942 r
.67484 .48332 .67561 .48424 .67724 .4843 .67647 .48338 Mtetra
.64 .732 .915 r
.67647 .48338 .67724 .4843 .67886 .4839 .67809 .48298 Mtetra
.663 .74 .908 r
.67809 .48298 .67886 .4839 .68047 .4834 .6797 .48249 Mtetra
.669 .743 .906 r
.6797 .48249 .68047 .4834 .68208 .48288 .68131 .48197 Mtetra
.761 .769 .86 r
.68131 .48197 .68208 .48288 .68367 .48186 .6829 .48094 Mtetra
.718 .759 .885 r
.6829 .48094 .68367 .48186 .68527 .4811 .6845 .48019 Mtetra
.55 .697 .937 r
.6845 .48019 .68527 .4811 .6869 .481 .68614 .48009 Mtetra
.835 .398 0 r
.68614 .48009 .6869 .481 .68873 .48469 .68796 .48378 Mtetra
.97 .683 .428 r
.68796 .48378 .68873 .48469 .70014 .67983 .69933 .67898 Mtetra
.912 .513 .131 r
.69933 .67898 .70014 .67983 .70216 .6854 .70136 .68455 Mtetra
0 .393 .845 r
.70136 .68455 .70216 .6854 .70396 .68638 .70315 .68552 Mtetra
.606 .748 .945 r
.70315 .68552 .70396 .68638 .70569 .68606 .70489 .6852 Mtetra
.799 .799 .852 r
.70489 .6852 .70569 .68606 .70737 .68473 .70657 .68387 Mtetra
.935 .776 .66 r
.70657 .68387 .70737 .68473 .70889 .68026 .70808 .67938 Mtetra
.971 .689 .438 r
.70808 .67938 .70889 .68026 .70026 .48455 .69949 .48357 Mtetra
.951 .741 .583 r
.69949 .48357 .70026 .48455 .70151 .47704 .70075 .4761 Mtetra
.826 .777 .806 r
.70075 .4761 .70151 .47704 .70308 .47542 .70232 .47448 Mtetra
.66 .737 .907 r
.70232 .47448 .70308 .47542 .7047 .47493 .70394 .474 Mtetra
.54 .689 .936 r
.70394 .474 .7047 .47493 .70635 .47486 .70559 .47393 Mtetra
.719 .759 .884 r
.70559 .47393 .70635 .47486 .70796 .47409 .70721 .47316 Mtetra
.706 .754 .889 r
.70721 .47316 .70796 .47409 .70958 .47339 .70882 .47246 Mtetra
.545 .693 .936 r
.70882 .47246 .70958 .47339 .71123 .47329 .71048 .47238 Mtetra
.784 .335 0 r
.71048 .47238 .71123 .47329 .71307 .47637 .71232 .47569 Mtetra
.971 .681 .418 r
.71232 .47569 .71307 .47637 .72595 .67139 .72521 .67151 Mtetra
.914 .532 .274 r
.72521 .67151 .72595 .67139 .7281 .67802 .72733 .67757 Mtetra
0 .255 .655 r
.72733 .67757 .7281 .67802 .72993 .67923 .72915 .67855 Mtetra
.623 .804 .969 r
.72915 .67855 .72993 .67923 .73168 .67894 .73089 .67811 Mtetra
.802 .81 .857 r
.73089 .67811 .73168 .67894 .73337 .6776 .73258 .67678 Mtetra
.911 .8 .724 r
.73258 .67678 .73337 .6776 .73488 .67313 .73417 .6737 Mtetra
.999 .807 .507 r
.73417 .6737 .73488 .67313 .72473 .47642 .73544 .66529 Mtetra
.077 0 .454 r
.73544 .66529 .72473 .47642 .72596 .46922 .72546 .47235 Mtetra
0 0 .223 r
.72546 .47235 .72596 .46922 .72752 .46743 .72691 .46879 Mtetra
0 0 0 r
.72691 .46879 .72752 .46743 .72916 .46689 .72848 .46705 Mtetra
.654 .969 .826 r
.72848 .46705 .72916 .46689 .73082 .46678 .73008 .46593 Mtetra
.697 .771 .909 r
.73008 .46593 .73082 .46678 .73247 .46642 .73171 .46527 Mtetra
.637 .686 .879 r
.73171 .46527 .73247 .46642 .73412 .46593 .73336 .46489 Mtetra
.609 .695 .904 r
.73336 .46489 .73412 .46593 .73576 .4655 .73502 .46462 Mtetra
.709 .768 .899 r
.73502 .46462 .73576 .4655 .7374 .46493 .73665 .46391 Mtetra
.714 .739 .872 r
.73665 .46391 .7374 .46493 .73905 .46451 .73828 .46314 Mtetra
.631 .646 .846 r
.73828 .46314 .73905 .46451 .74074 .46467 .73994 .46278 Mtetra
.237 .354 .781 r
.73994 .46278 .74074 .46467 .74262 .46767 .74171 .46422 Mtetra
0 0 .432 r
.74171 .46422 .74262 .46767 .75731 .66272 .74379 .4701 Mtetra
.099 .02 .47 r
.74379 .4701 .75731 .66272 .75954 .6693 .75844 .66364 Mtetra
.44 .342 .648 r
.75844 .66364 .75954 .6693 .76141 .67044 .76037 .66578 Mtetra
.605 .467 .668 r
.76037 .66578 .76141 .67044 .76318 .67011 .76213 .66535 Mtetra
.627 .48 .663 r
.76213 .66535 .76318 .67011 .76492 .66933 .76387 .66451 Mtetra
.545 .426 .668 r
.76387 .66451 .76492 .66933 .76667 .66873 .7657 .66501 Mtetra
.482 .41 .699 r
.7657 .66501 .76667 .66873 .76843 .66827 .76756 .66604 Mtetra
.465 .474 .783 r
.76756 .66604 .76843 .66827 .7702 .66776 .76941 .66673 Mtetra
.437 .631 .936 r
.76941 .66673 .7702 .66776 .77197 .66737 .77123 .66697 Mtetra
.448 .813 .995 r
.77123 .66697 .77197 .66737 .77373 .66686 .77301 .66676 Mtetra
.596 .94 .938 r
.77301 .66676 .77373 .66686 .77545 .66577 .77476 .66598 Mtetra
.902 .985 .736 r
.77476 .66598 .77545 .66577 .77699 .66208 .77639 .66367 Mtetra
.868 .819 .34 r
.77639 .66367 .77699 .66208 .76461 .46745 .77779 .65804 Mtetra
.095 .014 .464 r
.77779 .65804 .76461 .46745 .76563 .45808 .76529 .46264 Mtetra
.019 0 .302 r
.76529 .46264 .76563 .45808 .76716 .45585 .76661 .45741 Mtetra
0 0 .016 r
.76661 .45741 .76716 .45585 .76881 .4552 .76816 .45537 Mtetra
.695 .979 .805 r
.76816 .45537 .76881 .4552 .7705 .45498 .76977 .45409 Mtetra
.719 .771 .894 r
.76977 .45409 .7705 .45498 .77217 .45461 .77141 .45331 Mtetra
.65 .668 .854 r
.77141 .45331 .77217 .45461 .77383 .45402 .77308 .45285 Mtetra
.624 .679 .881 r
.77308 .45285 .77383 .45402 .77549 .45348 .77476 .45253 Mtetra
.701 .752 .891 r
.77476 .45253 .77549 .45348 .77715 .45285 .77642 .45183 Mtetra
.729 .749 .868 r
.77642 .45183 .77715 .45285 .77882 .45231 .77806 .45097 Mtetra
.654 .663 .847 r
.77806 .45097 .77882 .45231 .78052 .45229 .77973 .45049 Mtetra
.357 .44 .809 r
.77973 .45049 .78052 .45229 .7824 .45445 .78152 .45147 Mtetra
0 0 .553 r
.78152 .45147 .7824 .45445 .79936 .64713 .78358 .45587 Mtetra
.112 .033 .478 r
.78358 .45587 .79936 .64713 .80196 .65692 .80073 .65018 Mtetra
.385 .293 .628 r
.80073 .65018 .80196 .65692 .80391 .65852 .80282 .65363 Mtetra
.606 .465 .663 r
.80282 .65363 .80391 .65852 .8057 .65815 .80461 .65315 Mtetra
.636 .482 .658 r
.80461 .65315 .8057 .65815 .80745 .65724 .80635 .65208 Mtetra
.567 .435 .661 r
.80635 .65208 .80745 .65724 .80921 .65638 .80819 .65226 Mtetra
.478 .398 .687 r
.80819 .65226 .80921 .65638 .81099 .65577 .81011 .65346 Mtetra
.451 .461 .778 r
.81011 .65346 .81099 .65577 .81277 .65516 .81201 .65426 Mtetra
.485 .689 .957 r
.81201 .65426 .81277 .65516 .81455 .65457 .81384 .65431 Mtetra
.573 .905 .979 r
.81384 .65431 .81455 .65457 .81633 .65401 .81563 .65372 Mtetra
.663 .93 .972 r
.81563 .65372 .81633 .65401 .81812 .65346 .8174 .65294 Mtetra
.575 .835 .994 r
.8174 .65294 .81812 .65346 .81994 .65322 .8192 .65254 Mtetra
.498 .755 .987 r
.8192 .65254 .81994 .65322 .82176 .6531 .82103 .65242 Mtetra
.699 .835 .948 r
.82103 .65242 .82176 .6531 .82354 .65243 .8228 .65169 Mtetra
.936 .823 .708 r
.8228 .65169 .82354 .65243 .82513 .64955 .82436 .64836 Mtetra
.977 .683 .39 r
.82436 .64836 .82513 .64955 .81046 .45973 .80904 .45074 Mtetra
.761 .533 .588 r
.80904 .45074 .81046 .45973 .81089 .44483 .81004 .44232 Mtetra
.773 .621 .692 r
.81004 .44232 .81089 .44483 .81239 .44213 .81156 .4399 Mtetra
.648 .571 .755 r
.81156 .4399 .81239 .44213 .81406 .44145 .81325 .43931 Mtetra
.59 .545 .773 r
.81325 .43931 .81406 .44145 .81578 .44128 .81497 .43919 Mtetra
.591 .55 .777 r
.81497 .43919 .81578 .44128 .81751 .44113 .8167 .43908 Mtetra
.631 .575 .773 r
.8167 .43908 .81751 .44113 .81921 .44071 .8184 .43866 Mtetra
.633 .576 .773 r
.8184 .43866 .81921 .44071 .82091 .44029 .8201 .43822 Mtetra
.634 .575 .771 r
.8201 .43822 .82091 .44029 .82261 .43986 .8218 .43778 Mtetra
.634 .575 .77 r
.8218 .43778 .82261 .43986 .82431 .43941 .8235 .43733 Mtetra
.636 .575 .769 r
.8235 .43733 .82431 .43941 .82602 .43895 .8252 .43686 Mtetra
.637 .575 .769 r
.8252 .43686 .82602 .43895 .82772 .43848 .8269 .43639 Mtetra
.638 .576 .768 r
.8269 .43639 .82772 .43848 .82942 .438 .82861 .43591 Mtetra
.639 .576 .768 r
.82861 .43591 .82942 .438 .83112 .43751 .83031 .43541 Mtetra
.64 .576 .767 r
.83031 .43541 .83112 .43751 .83282 .43701 .83201 .43491 Mtetra
.641 .577 .767 r
.83201 .43491 .83282 .43701 .83452 .4365 .83371 .4344 Mtetra
.642 .577 .767 r
.83371 .4344 .83452 .4365 .83623 .43599 .83541 .43388 Mtetra
.643 .577 .766 r
.83541 .43388 .83623 .43599 .83793 .43546 .83712 .43335 Mtetra
.83712 .43335 .83793 .43546 .83963 .43494 .83882 .43282 Mtetra
.643 .577 .765 r
.83882 .43282 .83963 .43494 .84134 .43441 .84052 .43228 Mtetra
.643 .576 .764 r
.84052 .43228 .84134 .43441 .84304 .43388 .84223 .43175 Mtetra
.642 .575 .764 r
.84223 .43175 .84304 .43388 .84475 .43335 .84393 .43121 Mtetra
.84393 .43121 .84475 .43335 .84646 .43282 .84564 .43068 Mtetra
.84564 .43068 .84646 .43282 .84817 .43229 .84735 .43016 Mtetra
.642 .576 .765 r
.84735 .43016 .84817 .43229 .84987 .43175 .84906 .42963 Mtetra
.642 .577 .766 r
.84906 .42963 .84987 .43175 .85158 .43121 .85077 .4291 Mtetra
.644 .579 .766 r
.85077 .4291 .85158 .43121 .85329 .43066 .85248 .42856 Mtetra
.646 .581 .767 r
.85248 .42856 .85329 .43066 .855 .43008 .85419 .428 Mtetra
.647 .582 .768 r
.85419 .428 .855 .43008 .85671 .42951 .8559 .42743 Mtetra
.659 .589 .765 r
.8559 .42743 .85671 .42951 .8584 .42879 .8576 .42676 Mtetra
.679 .604 .764 r
.8576 .42676 .8584 .42879 .86008 .42783 .85928 .42592 Mtetra
.645 .596 .784 r
.85928 .42592 .86008 .42783 .8618 .42734 .861 .42541 Mtetra
.501 .513 .801 r
.861 .42541 .8618 .42734 .86366 .42827 .86282 .42583 Mtetra
0 .125 .651 r
.86282 .42583 .86366 .42827 .86641 .43755 .86494 .42909 Mtetra
.975 .671 .306 r
.86494 .42909 .86641 .43755 .88868 .63211 .88707 .62271 Mtetra
.276 .202 .59 r
.88707 .62271 .88868 .63211 .89087 .63493 .88972 .62995 Mtetra
.589 .454 .664 r
.88972 .62995 .89087 .63493 .89274 .63476 .89159 .62975 Mtetra
.634 .481 .658 r
.89159 .62975 .89274 .63476 .89455 .63396 .89337 .6287 Mtetra
.612 .464 .657 r
.89337 .6287 .89455 .63396 .89634 .63296 .89519 .62805 Mtetra
.509 .403 .669 r
.89519 .62805 .89634 .63296 .89817 .63235 .8972 .62912 Mtetra
.496 .439 .723 r
.8972 .62912 .89817 .63235 .9 .63174 .89919 .62994 Mtetra
.508 .544 .828 r
.89919 .62994 .9 .63174 .90184 .63116 .90112 .63026 Mtetra
.615 .756 .946 r
.90112 .63026 .90184 .63116 .90368 .63062 .90298 .62988 Mtetra
.649 .809 .96 r
.90298 .62988 .90368 .63062 .90553 .63014 .90483 .62933 Mtetra
.647 .792 .952 r
.90483 .62933 .90553 .63014 .90739 .62972 .90667 .62881 Mtetra
.579 .735 .949 r
.90667 .62881 .90739 .62972 .90926 .62941 .90855 .62856 Mtetra
.601 .76 .955 r
.90855 .62856 .90926 .62941 .91113 .62909 .91042 .62821 Mtetra
.651 .775 .939 r
.91042 .62821 .91113 .62909 .913 .62878 .91227 .62768 Mtetra
.707 .749 .885 r
.91227 .62768 .913 .62878 .91489 .6286 .91409 .62688 Mtetra
.744 .674 .783 r
.91409 .62688 .91489 .6286 .91673 .62795 .91585 .62554 Mtetra
.796 .647 .697 r
.91585 .62554 .91673 .62795 .91844 .62615 .91745 .62281 Mtetra
.953 .681 .485 r
.91745 .62281 .91844 .62615 .9195 .61868 .9172 .60387 Mtetra
.968 .663 .39 r
.9172 .60387 .9195 .61868 .89854 .42019 .89774 .41817 Mtetra
.849 .684 .677 r
.89774 .41817 .89854 .42019 .89983 .4158 .89915 .41478 Mtetra
.741 .765 .872 r
.89915 .41478 .89983 .4158 .90151 .41476 .90084 .41384 Mtetra
.64 .745 .925 r
.90084 .41384 .90151 .41476 .90327 .41434 .9026 .41339 Mtetra
.615 .731 .929 r
.9026 .41339 .90327 .41434 .90504 .41405 .90436 .41306 Mtetra
.759 .775 .866 r
.90436 .41306 .90504 .41405 .90672 .41299 .90604 .412 Mtetra
.687 .75 .899 r
.90604 .412 .90672 .41299 .90845 .41234 .90778 .41135 Mtetra
.422 .62 .934 r
.90778 .41135 .90845 .41234 .91029 .41264 .90962 .41165 Mtetra
.787 .372 0 r
.90962 .41165 .91029 .41264 .91272 .41779 .91205 .41679 Mtetra
.973 .661 .312 r
.91205 .41679 .91272 .41779 .93848 .61689 .93778 .61595 Mtetra
.724 .285 0 r
.93778 .61595 .93848 .61689 .94092 .62115 .94022 .62022 Mtetra
.496 .691 .955 r
.94022 .62022 .94092 .62115 .94286 .62117 .94216 .62024 Mtetra
.691 .78 .919 r
.94216 .62024 .94286 .62117 .9447 .62046 .94401 .61953 Mtetra
.741 .798 .898 r
.94401 .61953 .9447 .62046 .94652 .61949 .94582 .61856 Mtetra
.494 .691 .956 r
.94582 .61856 .94652 .61949 .94846 .61951 .94776 .61858 Mtetra
.62 .752 .941 r
.94776 .61858 .94846 .61951 .95035 .61911 .94965 .61818 Mtetra
.798 .815 .865 r
.94965 .61818 .95035 .61911 .95212 .61776 .95143 .61683 Mtetra
.98 .777 .559 r
.95143 .61683 .95212 .61776 .95322 .611 .95253 .61009 Mtetra
.975 .669 .322 r
.95253 .61009 .95322 .611 .93006 .41069 .92939 .40971 Mtetra
.964 .784 .611 r
.92939 .40971 .93006 .41069 .93126 .40574 .9306 .40475 Mtetra
.757 .778 .87 r
.9306 .40475 .93126 .40574 .93296 .4047 .93229 .40371 Mtetra
.627 .727 .919 r
.93229 .40371 .93296 .4047 .93474 .40432 .93407 .40332 Mtetra
.544 .687 .932 r
.93407 .40332 .93474 .40432 .93656 .40424 .9359 .40325 Mtetra
.748 .775 .875 r
.9359 .40325 .93656 .40424 .93826 .40325 .9376 .40226 Mtetra
.682 .75 .903 r
.9376 .40226 .93826 .40325 .94001 .40263 .93935 .40163 Mtetra
.488 .657 .935 r
.93935 .40163 .94001 .40263 .94186 .40274 .9412 .40174 Mtetra
.739 .321 0 r
.9412 .40174 .94186 .40274 .94432 .40753 .94366 .40653 Mtetra
.97 .655 .291 r
.94366 .40653 .94432 .40753 .97224 .60748 .97155 .60654 Mtetra
.74 .309 0 r
.97155 .60654 .97224 .60748 .97482 .61225 .97413 .61131 Mtetra
.031 .463 .877 r
.36325 .77525 .36418 .77601 .36566 .77663 .36473 .77587 Mtetra
.644 .762 .935 r
.36473 .77587 .36566 .77663 .36719 .77623 .36625 .77547 Mtetra
.81 .778 .824 r
.36625 .77547 .36719 .77623 .36876 .7748 .36783 .77404 Mtetra
.908 .737 .658 r
.36783 .77404 .36876 .7748 .3705 .76956 .36956 .76879 Mtetra
.937 .686 .534 r
.36956 .76879 .3705 .76956 .38011 .57918 .37923 .57836 Mtetra
.908 .727 .645 r
.37923 .57836 .38011 .57918 .38178 .57352 .3809 .57269 Mtetra
.777 .759 .836 r
.3809 .57269 .38178 .57352 .38325 .57241 .38238 .57158 Mtetra
.644 .736 .916 r
.38238 .57158 .38325 .57241 .3847 .57204 .38382 .57121 Mtetra
.517 .693 .948 r
.38382 .57121 .3847 .57204 .38613 .57202 .38525 .5712 Mtetra
.747 .756 .86 r
.38525 .5712 .38613 .57202 .38759 .57115 .38672 .57032 Mtetra
.7 .748 .889 r
.38672 .57032 .38759 .57115 .38905 .57054 .38818 .56972 Mtetra
.501 .686 .95 r
.38818 .56972 .38905 .57054 .39048 .57056 .38961 .56973 Mtetra
.921 .53 .221 r
.38961 .56973 .39048 .57056 .39178 .57424 .3909 .57341 Mtetra
.939 .683 .522 r
.3909 .57341 .39178 .57424 .38587 .76359 .38495 .76281 Mtetra
.937 .59 .341 r
.38495 .76281 .38587 .76359 .38718 .76918 .38625 .76841 Mtetra
.229 .583 .945 r
.38625 .76841 .38718 .76918 .38868 .76957 .38776 .76882 Mtetra
.681 .774 .921 r
.38776 .76882 .38868 .76957 .39023 .76901 .3893 .76827 Mtetra
.762 .787 .873 r
.3893 .76827 .39023 .76901 .39179 .76801 .39086 .76729 Mtetra
.582 .755 .96 r
.39086 .76729 .39179 .76801 .39333 .76761 .3924 .76705 Mtetra
.602 .807 .978 r
.3924 .76705 .39333 .76761 .39487 .76721 .39394 .76671 Mtetra
.736 .845 .931 r
.39394 .76671 .39487 .76721 .39642 .76662 .39549 .76592 Mtetra
.885 .769 .73 r
.39549 .76592 .39642 .76662 .398 .76526 .39713 .76299 Mtetra
.87 .668 .628 r
.39713 .76299 .398 .76526 .39959 .76343 .39891 .75572 Mtetra
.93 .677 .534 r
.39891 .75572 .39959 .76343 .40119 .76131 .40687 .57082 Mtetra
.574 .366 .561 r
.40687 .57082 .40119 .76131 .40277 .76001 .40842 .56807 Mtetra
.57 .363 .561 r
.40842 .56807 .40277 .76001 .40431 .75963 .40988 .56752 Mtetra
.567 .361 .56 r
.40988 .56752 .40431 .75963 .40583 .76007 .41129 .56876 Mtetra
0 0 .361 r
.41129 .56876 .40583 .76007 .40732 .76153 .40668 .75211 Mtetra
.034 0 .482 r
.40668 .75211 .40732 .76153 .40881 .76276 .40795 .76019 Mtetra
0 .061 .609 r
.40795 .76019 .40881 .76276 .41032 .76353 .4094 .76275 Mtetra
.305 .622 .959 r
.4094 .76275 .41032 .76353 .41186 .76348 .41093 .76306 Mtetra
.589 .846 .993 r
.41093 .76306 .41186 .76348 .41341 .7631 .41249 .76268 Mtetra
.697 .867 .962 r
.41249 .76268 .41341 .7631 .41497 .76258 .41405 .76202 Mtetra
.587 .803 .982 r
.41405 .76202 .41497 .76258 .41652 .76246 .4156 .76171 Mtetra
.623 .761 .945 r
.4156 .76171 .41652 .76246 .41807 .76221 .41715 .76136 Mtetra
.696 .757 .899 r
.41715 .76136 .41807 .76221 .41963 .76147 .41872 .76073 Mtetra
.834 .787 .806 r
.41872 .76073 .41963 .76147 .42126 .75855 .42031 .75903 Mtetra
.95 .945 .735 r
.42031 .75903 .42126 .75855 .42305 .75022 .42194 .75631 Mtetra
.196 0 .35 r
.42194 .75631 .42305 .75022 .42984 .56298 .4236 .75217 Mtetra
.566 .356 .555 r
.4236 .75217 .42984 .56298 .43137 .5609 .42519 .75067 Mtetra
.569 .359 .556 r
.42519 .75067 .43137 .5609 .43284 .56056 .42673 .75087 Mtetra
.567 .357 .555 r
.42673 .75087 .43284 .56056 .4343 .56053 .42829 .75017 Mtetra
0 0 .361 r
.42829 .75017 .4343 .56053 .43581 .55898 .43473 .5666 Mtetra
0 0 .201 r
.43473 .5666 .43581 .55898 .43732 .55719 .43642 .55818 Mtetra
.944 .949 .633 r
.43642 .55818 .43732 .55719 .43883 .55577 .43797 .55503 Mtetra
.781 .783 .854 r
.43797 .55503 .43883 .55577 .44031 .55507 .43946 .55394 Mtetra
.631 .671 .87 r
.43946 .55394 .44031 .55507 .44179 .55474 .44094 .55363 Mtetra
.557 .645 .892 r
.44094 .55363 .44179 .55474 .44326 .55452 .44241 .55359 Mtetra
.615 .704 .908 r
.44241 .55359 .44326 .55452 .44474 .55417 .44388 .55332 Mtetra
.655 .738 .91 r
.44388 .55332 .44474 .55417 .44622 .55371 .44537 .5529 Mtetra
.67 .75 .911 r
.44537 .5529 .44622 .55371 .4477 .55321 .44685 .55241 Mtetra
.727 .767 .884 r
.44685 .55241 .4477 .55321 .4492 .55236 .44834 .55166 Mtetra
.729 .789 .9 r
.44834 .55166 .4492 .55236 .45069 .55159 .44983 .55092 Mtetra
.667 .786 .938 r
.44983 .55092 .45069 .55159 .45217 .55125 .45132 .55044 Mtetra
.354 .624 .954 r
.45132 .55044 .45217 .55125 .45362 .55262 .45279 .55072 Mtetra
.233 .345 .774 r
.45279 .55072 .45362 .55262 .45498 .55797 .45424 .55194 Mtetra
.331 .246 .608 r
.45424 .55194 .45498 .55797 .45265 .74647 .45565 .55508 Mtetra
0 0 .377 r
.45565 .55508 .45265 .74647 .45415 .74979 .45341 .74108 Mtetra
.141 .087 .53 r
.45341 .74108 .45415 .74979 .4557 .7508 .45484 .74778 Mtetra
.16 .216 .673 r
.45484 .74778 .4557 .7508 .45726 .75111 .45637 .75003 Mtetra
.35 .567 .919 r
.45637 .75003 .45726 .75111 .45884 .751 .45793 .75047 Mtetra
.604 .82 .983 r
.45793 .75047 .45884 .751 .46041 .75062 .45951 .7501 Mtetra
.702 .842 .95 r
.45951 .7501 .46041 .75062 .462 .7501 .46109 .74943 Mtetra
.632 .788 .957 r
.46109 .74943 .462 .7501 .46358 .74988 .46268 .74902 Mtetra
.615 .738 .933 r
.46268 .74902 .46358 .74988 .46516 .74965 .46426 .74871 Mtetra
.679 .738 .895 r
.46426 .74871 .46516 .74965 .46674 .749 .46585 .74815 Mtetra
.787 .775 .842 r
.46585 .74815 .46674 .749 .46836 .74676 .46744 .74691 Mtetra
.921 .946 .796 r
.46744 .74691 .46836 .74676 .47002 .74111 .46906 .74475 Mtetra
0 0 .139 r
.46906 .74475 .47002 .74111 .47444 .55119 .47069 .74091 Mtetra
0 0 .376 r
.47069 .74091 .47444 .55119 .476 .54644 .47501 .55559 Mtetra
0 0 .266 r
.47501 .55559 .476 .54644 .47752 .54454 .47665 .54592 Mtetra
.825 .902 .49 r
.47665 .54592 .47752 .54454 .47903 .54335 .47819 .54277 Mtetra
.827 .823 .845 r
.47819 .54277 .47903 .54335 .48054 .5426 .4797 .5414 Mtetra
.673 .676 .845 r
.4797 .5414 .48054 .5426 .48204 .54213 .4812 .54087 Mtetra
.616 .644 .855 r
.4812 .54087 .48204 .54213 .48354 .5418 .4827 .54062 Mtetra
.632 .665 .863 r
.4827 .54062 .48354 .5418 .48504 .54142 .4842 .5403 Mtetra
.659 .685 .863 r
.4842 .5403 .48504 .54142 .48654 .54097 .48571 .53984 Mtetra
.66 .685 .863 r
.48571 .53984 .48654 .54097 .48805 .5405 .48721 .53939 Mtetra
.663 .688 .863 r
.48721 .53939 .48805 .5405 .48955 .54002 .48872 .53892 Mtetra
.665 .69 .863 r
.48872 .53892 .48955 .54002 .49106 .53954 .49022 .53844 Mtetra
.666 .691 .864 r
.49022 .53844 .49106 .53954 .49257 .53905 .49173 .53795 Mtetra
.666 .692 .865 r
.49173 .53795 .49257 .53905 .49408 .53856 .49324 .53747 Mtetra
.665 .693 .866 r
.49324 .53747 .49408 .53856 .49559 .53808 .49475 .53699 Mtetra
.665 .694 .867 r
.49475 .53699 .49559 .53808 .49709 .5376 .49626 .53651 Mtetra
.664 .694 .868 r
.49626 .53651 .49709 .5376 .49861 .53712 .49777 .53603 Mtetra
.49777 .53603 .49861 .53712 .50012 .53664 .49928 .53556 Mtetra
.49928 .53556 .50012 .53664 .50163 .53617 .5008 .53509 Mtetra
.663 .694 .869 r
.5008 .53509 .50163 .53617 .50314 .5357 .50231 .53461 Mtetra
.50231 .53461 .50314 .5357 .50466 .53523 .50382 .53414 Mtetra
.50382 .53414 .50466 .53523 .50617 .53476 .50534 .53368 Mtetra
.50534 .53368 .50617 .53476 .50769 .53429 .50685 .53321 Mtetra
.662 .694 .869 r
.50685 .53321 .50769 .53429 .5092 .53382 .50837 .53274 Mtetra
.50837 .53274 .5092 .53382 .51072 .53336 .50989 .53227 Mtetra
.50989 .53227 .51072 .53336 .51224 .53289 .51141 .5318 Mtetra
.51141 .5318 .51224 .53289 .51376 .53242 .51293 .53133 Mtetra
.51293 .53133 .51376 .53242 .51528 .53195 .51445 .53087 Mtetra
.51445 .53087 .51528 .53195 .5168 .53149 .51597 .5304 Mtetra
.51597 .5304 .5168 .53149 .51832 .53102 .51749 .52993 Mtetra
.51749 .52993 .51832 .53102 .51984 .53055 .51901 .52946 Mtetra
.51901 .52946 .51984 .53055 .52136 .53008 .52053 .52899 Mtetra
.52053 .52899 .52136 .53008 .52289 .52961 .52206 .52852 Mtetra
.663 .694 .869 r
.52206 .52852 .52289 .52961 .52441 .52913 .52358 .52805 Mtetra
.52358 .52805 .52441 .52913 .52594 .52866 .52511 .52757 Mtetra
.663 .695 .869 r
.52511 .52757 .52594 .52866 .52746 .52819 .52664 .5271 Mtetra
.52664 .5271 .52746 .52819 .52899 .52771 .52816 .52662 Mtetra
.664 .695 .869 r
.52816 .52662 .52899 .52771 .53052 .52723 .52969 .52615 Mtetra
.664 .696 .87 r
.52969 .52615 .53052 .52723 .53205 .52675 .53122 .52567 Mtetra
.665 .697 .87 r
.53122 .52567 .53205 .52675 .53358 .52626 .53275 .52518 Mtetra
.664 .697 .871 r
.53275 .52518 .53358 .52626 .53511 .52578 .53428 .52471 Mtetra
.663 .698 .872 r
.53428 .52471 .53511 .52578 .53664 .52529 .53581 .52423 Mtetra
.668 .701 .872 r
.53581 .52423 .53664 .52529 .53817 .52479 .53735 .52373 Mtetra
.68 .707 .868 r
.53735 .52373 .53817 .52479 .5397 .52423 .53888 .52317 Mtetra
.692 .711 .863 r
.53888 .52317 .5397 .52423 .54124 .52362 .54041 .52255 Mtetra
.691 .709 .862 r
.54041 .52255 .54124 .52362 .54277 .523 .54195 .52193 Mtetra
.683 .705 .864 r
.54195 .52193 .54277 .523 .5443 .52243 .54348 .52135 Mtetra
.67 .701 .87 r
.54348 .52135 .5443 .52243 .54584 .52191 .54502 .52084 Mtetra
.661 .699 .875 r
.54502 .52084 .54584 .52191 .54738 .52144 .54656 .52038 Mtetra
.66 .701 .877 r
.54656 .52038 .54738 .52144 .54891 .5209 .5481 .51992 Mtetra
.662 .716 .889 r
.5481 .51992 .54891 .5209 .55045 .5203 .54964 .51945 Mtetra
.611 .73 .93 r
.54964 .51945 .55045 .5203 .55199 .52001 .55118 .51917 Mtetra
.406 .644 .954 r
.55118 .51917 .55199 .52001 .55354 .52068 .55272 .51938 Mtetra
.046 .322 .806 r
.55272 .51938 .55354 .52068 .55512 .52409 .55428 .52058 Mtetra
.289 .277 .671 r
.55428 .52058 .55512 .52409 .55847 .71323 .55585 .52274 Mtetra
.565 .359 .56 r
.55585 .52274 .55847 .71323 .56017 .71945 .55742 .5252 Mtetra
.57 .363 .561 r
.55742 .5252 .56017 .71945 .56181 .71948 .55897 .52461 Mtetra
.55897 .52461 .56181 .71948 .56345 .71886 .56052 .52416 Mtetra
.555 .351 .559 r
.56052 .52416 .56345 .71886 .56509 .71908 .56217 .53226 Mtetra
.008 0 .416 r
.56217 .53226 .56509 .71908 .56676 .7207 .56586 .7167 Mtetra
.203 .208 .642 r
.56586 .7167 .56676 .7207 .56842 .72136 .56754 .71968 Mtetra
.591 .591 .821 r
.56754 .71968 .56842 .72136 .57005 .72031 .56919 .71955 Mtetra
.934 .757 .638 r
.56919 .71955 .57005 .72031 .57162 .71431 .57077 .71396 Mtetra
.959 .691 .483 r
.57077 .71396 .57162 .71431 .57061 .51986 .5698 .51912 Mtetra
.93 .76 .649 r
.5698 .51912 .57061 .51986 .57211 .51525 .5713 .51427 Mtetra
.729 .739 .859 r
.5713 .51427 .57211 .51525 .57366 .51442 .57284 .51344 Mtetra
.585 .69 .914 r
.57284 .51344 .57366 .51442 .57521 .51426 .5744 .51327 Mtetra
.524 .661 .922 r
.5744 .51327 .57521 .51426 .57678 .51431 .57597 .51328 Mtetra
.642 .703 .89 r
.57597 .51328 .57678 .51431 .57833 .51395 .57752 .5129 Mtetra
.644 .698 .885 r
.57752 .5129 .57833 .51395 .57989 .51359 .57908 .51251 Mtetra
.649 .694 .878 r
.57908 .51251 .57989 .51359 .58145 .5132 .58064 .51209 Mtetra
.659 .692 .87 r
.58064 .51209 .58145 .5132 .58301 .51276 .5822 .51162 Mtetra
.665 .691 .865 r
.5822 .51162 .58301 .51276 .58457 .51228 .58376 .51113 Mtetra
.669 .69 .861 r
.58376 .51113 .58457 .51228 .58613 .51177 .58532 .51061 Mtetra
.67 .689 .859 r
.58532 .51061 .58613 .51177 .58769 .51123 .58688 .51008 Mtetra
.678 .693 .857 r
.58688 .51008 .58769 .51123 .58925 .51066 .58844 .50952 Mtetra
.69 .698 .852 r
.58844 .50952 .58925 .51066 .5908 .51003 .59 .50888 Mtetra
.708 .702 .843 r
.59 .50888 .5908 .51003 .59236 .50932 .59155 .50813 Mtetra
.706 .696 .838 r
.59155 .50813 .59236 .50932 .59392 .5086 .59311 .50738 Mtetra
.705 .691 .834 r
.59311 .50738 .59392 .5086 .59548 .5079 .59467 .50663 Mtetra
.714 .688 .824 r
.59467 .50663 .59548 .5079 .59704 .50718 .59623 .5058 Mtetra
.666 .654 .829 r
.59623 .5058 .59704 .50718 .59861 .50661 .5978 .50527 Mtetra
.528 .595 .865 r
.5978 .50527 .59861 .50661 .60018 .50637 .59938 .50538 Mtetra
.611 .145 0 r
.59938 .50538 .60018 .50637 .60177 .50688 .60101 .50755 Mtetra
.906 .566 .389 r
.60101 .50755 .60177 .50688 .60337 .50777 .60275 .51457 Mtetra
.951 .673 .475 r
.60275 .51457 .60337 .50777 .60497 .50862 .60879 .70147 Mtetra
.568 .358 .556 r
.60879 .70147 .60497 .50862 .60654 .50767 .61047 .70144 Mtetra
.567 .357 .555 r
.61047 .70144 .60654 .50767 .6081 .507 .61212 .70044 Mtetra
.569 .358 .556 r
.61212 .70044 .6081 .507 .60971 .50778 .6138 .70054 Mtetra
.573 .362 .556 r
.6138 .70054 .60971 .50778 .61621 .69699 .61557 .70385 Mtetra
.631 .363 .494 r
.61557 .70385 .61621 .69699 .6181 .70519 .6173 .70577 Mtetra
.648 .166 .094 r
.6173 .70577 .6181 .70519 .61985 .70754 .61901 .70677 Mtetra
.457 .705 .974 r
.61901 .70677 .61985 .70754 .62154 .70759 .6207 .70682 Mtetra
.65 .779 .942 r
.6207 .70682 .62154 .70759 .62321 .70704 .62238 .70634 Mtetra
.785 .825 .883 r
.62238 .70634 .62321 .70704 .62488 .70604 .62404 .7052 Mtetra
.89 .786 .739 r
.62404 .7052 .62488 .70604 .62654 .70493 .62565 .70244 Mtetra
.862 .664 .633 r
.62565 .70244 .62654 .70493 .62818 .70319 .62718 .69666 Mtetra
.957 .683 .476 r
.62718 .69666 .62818 .70319 .62977 .69996 .62321 .50526 Mtetra
.578 .369 .561 r
.62321 .50526 .62977 .69996 .6257 .50931 .62466 .5001 Mtetra
.647 .455 .61 r
.62466 .5001 .6257 .50931 .62701 .50001 .62618 .49759 Mtetra
.726 .597 .712 r
.62618 .49759 .62701 .50001 .62852 .49694 .62773 .49601 Mtetra
.771 .762 .845 r
.62773 .49601 .62852 .49694 .63008 .49568 .62929 .4949 Mtetra
.666 .771 .929 r
.62929 .4949 .63008 .49568 .63166 .49521 .63088 .4944 Mtetra
.329 .614 .953 r
.63088 .4944 .63166 .49521 .63328 .49566 .63249 .49474 Mtetra
.888 .474 .063 r
.63249 .49474 .63328 .49566 .63502 .49992 .63423 .49896 Mtetra
.966 .684 .449 r
.63423 .49896 .63502 .49992 .64319 .69506 .64236 .69417 Mtetra
.914 .516 .141 r
.64236 .69417 .64319 .69506 .64507 .70022 .64424 .69936 Mtetra
.069 .454 .882 r
.64424 .69936 .64507 .70022 .6468 .701 .64597 .70016 Mtetra
.601 .747 .947 r
.64597 .70016 .6468 .701 .6485 .70069 .64767 .69986 Mtetra
.802 .8 .849 r
.64767 .69986 .6485 .70069 .65016 .69934 .64933 .69852 Mtetra
.937 .767 .646 r
.64933 .69852 .65016 .69934 .65169 .6943 .65086 .69347 Mtetra
.966 .69 .458 r
.65086 .69347 .65169 .6943 .64624 .49859 .64546 .49763 Mtetra
.941 .742 .606 r
.64546 .49763 .64624 .49859 .64762 .49204 .64683 .4911 Mtetra
.778 .764 .84 r
.64683 .4911 .64762 .49204 .64918 .49087 .6484 .48993 Mtetra
.646 .729 .91 r
.6484 .48993 .64918 .49087 .65078 .49044 .65 .48952 Mtetra
.531 .686 .937 r
.65 .48952 .65078 .49044 .6524 .49039 .65162 .48948 Mtetra
.753 .766 .864 r
.65162 .48948 .6524 .49039 .65398 .48942 .6532 .48852 Mtetra
.695 .753 .896 r
.6532 .48852 .65398 .48942 .65557 .48878 .65479 .48788 Mtetra
.497 .677 .945 r
.65479 .48788 .65557 .48878 .65719 .48882 .65641 .48793 Mtetra
.884 .467 .054 r
.65641 .48793 .65719 .48882 .65898 .49305 .6582 .49218 Mtetra
.968 .684 .44 r
.6582 .49218 .65898 .49305 .66858 .68804 .66777 .68723 Mtetra
.908 .504 .128 r
.66777 .68723 .66858 .68804 .67052 .69313 .6697 .69229 Mtetra
.093 .474 .893 r
.6697 .69229 .67052 .69313 .67227 .69389 .67145 .69305 Mtetra
.624 .756 .941 r
.67145 .69305 .67227 .69389 .67398 .69352 .67316 .69267 Mtetra
.807 .799 .844 r
.67316 .69267 .67398 .69352 .67565 .69212 .67483 .69126 Mtetra
.936 .769 .649 r
.67483 .69126 .67565 .69212 .67717 .68725 .67635 .68639 Mtetra
.968 .69 .449 r
.67635 .68639 .67717 .68725 .67031 .4917 .66954 .49077 Mtetra
.946 .745 .599 r
.66954 .49077 .67031 .4917 .67165 .48497 .67088 .48405 Mtetra
.794 .774 .834 r
.67088 .48405 .67165 .48497 .67322 .48368 .67245 .48276 Mtetra
.629 .728 .919 r
.67245 .48276 .67322 .48368 .67484 .48332 .67407 .48241 Mtetra
.495 .671 .942 r
.67407 .48241 .67484 .48332 .67647 .48338 .6757 .48246 Mtetra
.639 .732 .916 r
.6757 .48246 .67647 .48338 .67809 .48298 .67732 .48207 Mtetra
.663 .741 .908 r
.67732 .48207 .67809 .48298 .6797 .48249 .67893 .48157 Mtetra
.669 .744 .906 r
.67893 .48157 .6797 .48249 .68131 .48197 .68055 .48105 Mtetra
.761 .77 .86 r
.68055 .48105 .68131 .48197 .6829 .48094 .68214 .48003 Mtetra
.718 .759 .885 r
.68214 .48003 .6829 .48094 .6845 .48019 .68374 .47927 Mtetra
.549 .698 .937 r
.68374 .47927 .6845 .48019 .68614 .48009 .68537 .47918 Mtetra
.835 .399 0 r
.68537 .47918 .68614 .48009 .68796 .48378 .6872 .48288 Mtetra
.97 .683 .428 r
.6872 .48288 .68796 .48378 .69933 .67898 .69853 .67813 Mtetra
.912 .513 .131 r
.69853 .67813 .69933 .67898 .70136 .68455 .70055 .68369 Mtetra
0 .394 .845 r
.70055 .68369 .70136 .68455 .70315 .68552 .70235 .68466 Mtetra
.606 .748 .945 r
.70235 .68466 .70315 .68552 .70489 .6852 .70408 .68434 Mtetra
.799 .799 .851 r
.70408 .68434 .70489 .6852 .70657 .68387 .70576 .683 Mtetra
.935 .775 .66 r
.70576 .683 .70657 .68387 .70808 .67938 .70728 .6785 Mtetra
.971 .689 .438 r
.70728 .6785 .70808 .67938 .69949 .48357 .69873 .48258 Mtetra
.951 .741 .584 r
.69873 .48258 .69949 .48357 .70075 .4761 .69999 .47516 Mtetra
.825 .776 .807 r
.69999 .47516 .70075 .4761 .70232 .47448 .70156 .47354 Mtetra
.659 .736 .907 r
.70156 .47354 .70232 .47448 .70394 .474 .70318 .47306 Mtetra
.538 .688 .936 r
.70318 .47306 .70394 .474 .70559 .47393 .70483 .47301 Mtetra
.718 .758 .884 r
.70483 .47301 .70559 .47393 .70721 .47316 .70645 .47224 Mtetra
.705 .755 .891 r
.70645 .47224 .70721 .47316 .70882 .47246 .70807 .47155 Mtetra
.538 .692 .939 r
.70807 .47155 .70882 .47246 .71048 .47238 .70972 .47148 Mtetra
.8 .354 0 r
.70972 .47148 .71048 .47238 .71232 .47569 .71158 .47492 Mtetra
.971 .682 .418 r
.71158 .47492 .71232 .47569 .72521 .67151 .72444 .6711 Mtetra
.919 .523 .198 r
.72444 .6711 .72521 .67151 .72733 .67757 .72654 .6769 Mtetra
0 .424 .845 r
.72654 .6769 .72733 .67757 .72915 .67855 .72836 .67772 Mtetra
.663 .776 .933 r
.72836 .67772 .72915 .67855 .73089 .67811 .7301 .67717 Mtetra
.784 .784 .853 r
.7301 .67717 .73089 .67811 .73258 .67678 .73179 .67592 Mtetra
.834 .807 .824 r
.73179 .67592 .73258 .67678 .73417 .6737 .73346 .67425 Mtetra
.845 .965 .638 r
.73346 .67425 .73417 .6737 .73544 .66529 .73509 .67179 Mtetra
.261 .062 .41 r
.73509 .67179 .73544 .66529 .72546 .47235 .73658 .66716 Mtetra
.101 .015 .461 r
.73658 .66716 .72546 .47235 .72691 .46879 .72658 .47471 Mtetra
.013 0 .325 r
.72658 .47471 .72691 .46879 .72848 .46705 .72785 .46809 Mtetra
.709 .839 .403 r
.72785 .46809 .72848 .46705 .73008 .46593 .72935 .46523 Mtetra
.788 .83 .884 r
.72935 .46523 .73008 .46593 .73171 .46527 .73095 .46411 Mtetra
.634 .683 .878 r
.73095 .46411 .73171 .46527 .73336 .46489 .7326 .46374 Mtetra
.572 .658 .895 r
.7326 .46374 .73336 .46489 .73502 .46462 .73427 .46364 Mtetra
.673 .733 .895 r
.73427 .46364 .73502 .46462 .73665 .46391 .73591 .46308 Mtetra
.71 .783 .909 r
.73591 .46308 .73665 .46391 .73828 .46314 .73755 .46237 Mtetra
.654 .779 .94 r
.73755 .46237 .73828 .46314 .73994 .46278 .73919 .46188 Mtetra
.305 .575 .935 r
.73919 .46188 .73994 .46278 .74171 .46422 .74091 .46236 Mtetra
.191 .328 .774 r
.74091 .46236 .74171 .46422 .74379 .4701 .74269 .46393 Mtetra
.392 .298 .629 r
.74269 .46393 .74379 .4701 .75844 .66364 .74458 .46693 Mtetra
.567 .361 .561 r
.74458 .46693 .75844 .66364 .76037 .66578 .74637 .46838 Mtetra
.571 .364 .561 r
.74637 .46838 .76037 .66578 .76213 .66535 .74798 .46731 Mtetra
.57 .363 .561 r
.74798 .46731 .76213 .66535 .76387 .66451 .74966 .46705 Mtetra
.136 .047 .482 r
.74966 .46705 .76387 .66451 .7657 .66501 .76423 .65413 Mtetra
.23 .157 .563 r
.76423 .65413 .7657 .66501 .76756 .66604 .76662 .66279 Mtetra
.201 .244 .683 r
.76662 .66279 .76756 .66604 .76941 .66673 .76861 .66553 Mtetra
.295 .514 .897 r
.76861 .66553 .76941 .66673 .77123 .66697 .77046 .66626 Mtetra
.572 .776 .975 r
.77046 .66626 .77123 .66697 .77301 .66676 .77224 .66598 Mtetra
.722 .811 .92 r
.77224 .66598 .77301 .66676 .77476 .66598 .77399 .66516 Mtetra
.811 .817 .855 r
.77399 .66516 .77476 .66598 .77639 .66367 .77569 .66375 Mtetra
.91 .981 .77 r
.77569 .66375 .77639 .66367 .77779 .65804 .77733 .66153 Mtetra
.043 0 .256 r
.77733 .66153 .77779 .65804 .76529 .46264 .77886 .65768 Mtetra
.131 .04 .475 r
.77886 .65768 .76529 .46264 .76661 .45741 .76675 .46841 Mtetra
.08 0 .405 r
.76675 .46841 .76661 .45741 .76816 .45537 .76761 .45687 Mtetra
0 0 0 r
.76761 .45687 .76816 .45537 .76977 .45409 .76906 .45353 Mtetra
.838 .873 .869 r
.76906 .45353 .76977 .45409 .77141 .45331 .77066 .45212 Mtetra
.653 .687 .869 r
.77066 .45212 .77141 .45331 .77308 .45285 .77233 .45165 Mtetra
.59 .657 .884 r
.77233 .45165 .77308 .45285 .77476 .45253 .77403 .45148 Mtetra
.662 .719 .891 r
.77403 .45148 .77476 .45253 .77642 .45183 .77569 .45098 Mtetra
.722 .781 .9 r
.77569 .45098 .77642 .45183 .77806 .45097 .77734 .45019 Mtetra
.676 .787 .933 r
.77734 .45019 .77806 .45097 .77973 .45049 .77901 .44962 Mtetra
.41 .643 .952 r
.77901 .44962 .77973 .45049 .78152 .45147 .78074 .44986 Mtetra
.212 .373 .808 r
.78074 .44986 .78152 .45147 .78358 .45587 .78256 .45118 Mtetra
.381 .314 .657 r
.78256 .45118 .78358 .45587 .80073 .65018 .78446 .45362 Mtetra
.567 .361 .561 r
.78446 .45362 .80073 .65018 .80282 .65363 .7863 .45515 Mtetra
.571 .364 .561 r
.7863 .45515 .80282 .65363 .80461 .65315 .78793 .45396 Mtetra
.57 .363 .561 r
.78793 .45396 .80461 .65315 .80635 .65208 .78959 .45324 Mtetra
.558 .354 .56 r
.78959 .45324 .80635 .65208 .80819 .65226 .79188 .46014 Mtetra
.133 .048 .485 r
.79188 .46014 .80819 .65226 .81011 .65346 .80909 .6494 Mtetra
.198 .213 .65 r
.80909 .6494 .81011 .65346 .81201 .65426 .81122 .65296 Mtetra
.282 .483 .878 r
.81122 .65296 .81201 .65426 .81384 .65431 .81312 .65382 Mtetra
.615 .862 .99 r
.81312 .65382 .81384 .65431 .81563 .65372 .81491 .6533 Mtetra
.732 .914 .956 r
.81491 .6533 .81563 .65372 .8174 .65294 .81667 .65237 Mtetra
.634 .846 .981 r
.81667 .65237 .8174 .65294 .8192 .65254 .81846 .65183 Mtetra
.513 .755 .984 r
.81846 .65183 .8192 .65254 .82103 .65242 .82029 .65169 Mtetra
.705 .823 .938 r
.82029 .65169 .82103 .65242 .8228 .65169 .82206 .65094 Mtetra
.935 .82 .707 r
.82206 .65094 .8228 .65169 .82436 .64836 .82361 .64758 Mtetra
.977 .683 .389 r
.82361 .64758 .82436 .64836 .80904 .45074 .8083 .44956 Mtetra
.962 .737 .553 r
.8083 .44956 .80904 .45074 .81004 .44232 .80931 .44122 Mtetra
.87 .768 .747 r
.80931 .44122 .81004 .44232 .81156 .4399 .81084 .43882 Mtetra
.671 .718 .884 r
.81084 .43882 .81156 .4399 .81325 .43931 .81252 .43827 Mtetra
.55 .673 .919 r
.81252 .43827 .81325 .43931 .81497 .43919 .81425 .4382 Mtetra
.548 .683 .927 r
.81425 .4382 .81497 .43919 .8167 .43908 .81599 .43812 Mtetra
.636 .732 .917 r
.81599 .43812 .8167 .43908 .8184 .43866 .81769 .43772 Mtetra
.64 .737 .919 r
.81769 .43772 .8184 .43866 .8201 .43822 .81939 .43729 Mtetra
.643 .74 .92 r
.81939 .43729 .8201 .43822 .8218 .43778 .82109 .43686 Mtetra
.644 .743 .921 r
.82109 .43686 .8218 .43778 .8235 .43733 .8228 .43642 Mtetra
.646 .747 .923 r
.8228 .43642 .8235 .43733 .8252 .43686 .8245 .43596 Mtetra
.649 .751 .924 r
.8245 .43596 .8252 .43686 .8269 .43639 .8262 .4355 Mtetra
.652 .754 .924 r
.8262 .4355 .8269 .43639 .82861 .43591 .8279 .43502 Mtetra
.654 .757 .925 r
.8279 .43502 .82861 .43591 .83031 .43541 .82961 .43453 Mtetra
.657 .759 .925 r
.82961 .43453 .83031 .43541 .83201 .43491 .83131 .43403 Mtetra
.66 .76 .924 r
.83131 .43403 .83201 .43491 .83371 .4344 .83301 .43352 Mtetra
.662 .761 .923 r
.83301 .43352 .83371 .4344 .83541 .43388 .83472 .433 Mtetra
.665 .761 .922 r
.83472 .433 .83541 .43388 .83712 .43335 .83642 .43246 Mtetra
.667 .761 .92 r
.83642 .43246 .83712 .43335 .83882 .43282 .83812 .43192 Mtetra
.668 .759 .919 r
.83812 .43192 .83882 .43282 .84052 .43228 .83983 .43137 Mtetra
.667 .757 .918 r
.83983 .43137 .84052 .43228 .84223 .43175 .84153 .43083 Mtetra
.665 .755 .917 r
.84153 .43083 .84223 .43175 .84393 .43121 .84324 .4303 Mtetra
.664 .754 .917 r
.84324 .4303 .84393 .43121 .84564 .43068 .84495 .42977 Mtetra
.663 .754 .918 r
.84495 .42977 .84564 .43068 .84735 .43016 .84666 .42925 Mtetra
.661 .754 .919 r
.84666 .42925 .84735 .43016 .84906 .42963 .84837 .42873 Mtetra
.662 .757 .92 r
.84837 .42873 .84906 .42963 .85077 .4291 .85008 .42821 Mtetra
.665 .76 .921 r
.85008 .42821 .85077 .4291 .85248 .42856 .85179 .42767 Mtetra
.669 .764 .921 r
.85179 .42767 .85248 .42856 .85419 .428 .8535 .42712 Mtetra
.671 .766 .922 r
.8535 .42712 .85419 .428 .8559 .42743 .85521 .42655 Mtetra
.687 .773 .916 r
.85521 .42655 .8559 .42743 .8576 .42676 .85692 .42592 Mtetra
.711 .79 .913 r
.85692 .42592 .8576 .42676 .85928 .42592 .85861 .42518 Mtetra
.665 .8 .947 r
.85861 .42518 .85928 .42592 .861 .42541 .86033 .42462 Mtetra
.5 .716 .968 r
.86033 .42462 .861 .42541 .86282 .42583 .8621 .42459 Mtetra
.186 .42 .854 r
.8621 .42459 .86282 .42583 .86494 .42909 .86399 .4257 Mtetra
.35 .331 .698 r
.86399 .4257 .86494 .42909 .88707 .62271 .86598 .42777 Mtetra
.565 .36 .561 r
.86598 .42777 .88707 .62271 .88972 .62995 .86802 .43024 Mtetra
.571 .364 .561 r
.86802 .43024 .88972 .62995 .89159 .62975 .86969 .4291 Mtetra
.86969 .4291 .89159 .62975 .89337 .6287 .87135 .42799 Mtetra
.567 .361 .561 r
.87135 .42799 .89337 .6287 .89519 .62805 .87328 .42937 Mtetra
.174 .083 .505 r
.87328 .42937 .89519 .62805 .8972 .62912 .89583 .62216 Mtetra
.27 .216 .612 r
.89583 .62216 .8972 .62912 .89919 .62994 .89832 .62763 Mtetra
.272 .351 .762 r
.89832 .62763 .89919 .62994 .90112 .63026 .90041 .6294 Mtetra
.554 .737 .961 r
.90041 .6294 .90112 .63026 .90298 .62988 .9023 .62921 Mtetra
.661 .835 .967 r
.9023 .62921 .90298 .62988 .90483 .62933 .90413 .6286 Mtetra
.674 .821 .954 r
.90413 .6286 .90483 .62933 .90667 .62881 .90597 .62795 Mtetra
.529 .727 .964 r
.90597 .62795 .90667 .62881 .90855 .62856 .90786 .62784 Mtetra
.598 .795 .975 r
.90786 .62784 .90855 .62856 .91042 .62821 .90973 .62745 Mtetra
.757 .839 .914 r
.90973 .62745 .91042 .62821 .91227 .62768 .91152 .62642 Mtetra
.877 .767 .737 r
.91152 .62642 .91227 .62768 .91409 .62688 .91313 .6237 Mtetra
.848 .643 .625 r
.91313 .6237 .91409 .62688 .91585 .62554 .91443 .6183 Mtetra
.974 .67 .366 r
.91443 .6183 .91585 .62554 .91745 .62281 .89428 .42445 Mtetra
.578 .369 .561 r
.89428 .42445 .91745 .62281 .9172 .60387 .89538 .41824 Mtetra
.574 .366 .561 r
.89538 .41824 .9172 .60387 .89774 .41817 .89686 .41543 Mtetra
.72 .586 .704 r
.89686 .41543 .89774 .41817 .89915 .41478 .89847 .41376 Mtetra
.708 .751 .885 r
.89847 .41376 .89915 .41478 .90084 .41384 .90018 .413 Mtetra
.645 .771 .94 r
.90018 .413 .90084 .41384 .9026 .41339 .90193 .41253 Mtetra
.643 .762 .935 r
.90193 .41253 .9026 .41339 .90436 .41306 .90369 .41207 Mtetra
.759 .776 .867 r
.90369 .41207 .90436 .41306 .90604 .412 .90537 .41101 Mtetra
.688 .752 .9 r
.90537 .41101 .90604 .412 .90778 .41135 .9071 .41036 Mtetra
.424 .622 .934 r
.9071 .41036 .90778 .41135 .90962 .41165 .90895 .41065 Mtetra
.786 .371 0 r
.90895 .41065 .90962 .41165 .91205 .41679 .91137 .41578 Mtetra
.973 .661 .312 r
.91137 .41578 .91205 .41679 .93778 .61595 .93708 .61501 Mtetra
.723 .286 0 r
.93708 .61501 .93778 .61595 .94022 .62022 .93952 .61928 Mtetra
.496 .69 .955 r
.93952 .61928 .94022 .62022 .94216 .62024 .94146 .61931 Mtetra
.691 .78 .919 r
.94146 .61931 .94216 .62024 .94401 .61953 .94331 .6186 Mtetra
.741 .798 .898 r
.94331 .6186 .94401 .61953 .94582 .61856 .94513 .61763 Mtetra
.493 .691 .956 r
.94513 .61763 .94582 .61856 .94776 .61858 .94707 .61766 Mtetra
.619 .753 .942 r
.94707 .61766 .94776 .61858 .94965 .61818 .94896 .61726 Mtetra
.798 .815 .865 r
.94896 .61726 .94965 .61818 .95143 .61683 .95073 .61591 Mtetra
.98 .777 .559 r
.95073 .61591 .95143 .61683 .95253 .61009 .95184 .60919 Mtetra
.975 .669 .322 r
.95184 .60919 .95253 .61009 .92939 .40971 .92873 .40874 Mtetra
.965 .785 .61 r
.92873 .40874 .92939 .40971 .9306 .40475 .92994 .40376 Mtetra
.757 .779 .871 r
.92994 .40376 .9306 .40475 .93229 .40371 .93163 .40272 Mtetra
.627 .727 .919 r
.93163 .40272 .93229 .40371 .93407 .40332 .93341 .40233 Mtetra
.544 .687 .932 r
.93341 .40233 .93407 .40332 .9359 .40325 .93523 .40226 Mtetra
.749 .776 .875 r
.93523 .40226 .9359 .40325 .9376 .40226 .93694 .40126 Mtetra
.682 .75 .903 r
.93694 .40126 .9376 .40226 .93935 .40163 .93869 .40064 Mtetra
.488 .657 .935 r
.93869 .40064 .93935 .40163 .9412 .40174 .94054 .40074 Mtetra
.74 .322 0 r
.94054 .40074 .9412 .40174 .94366 .40653 .943 .40554 Mtetra
.97 .655 .291 r
.943 .40554 .94366 .40653 .97155 .60654 .97087 .6056 Mtetra
.74 .309 0 r
.97087 .6056 .97155 .60654 .97413 .61131 .97345 .61036 Mtetra
.032 .463 .877 r
.36231 .77449 .36325 .77525 .36473 .77587 .36379 .77511 Mtetra
.644 .762 .935 r
.36379 .77511 .36473 .77587 .36625 .77547 .36532 .77471 Mtetra
.81 .778 .824 r
.36532 .77471 .36625 .77547 .36783 .77404 .36689 .77328 Mtetra
.908 .737 .658 r
.36689 .77328 .36783 .77404 .36956 .76879 .36863 .76802 Mtetra
.937 .686 .534 r
.36863 .76802 .36956 .76879 .37923 .57836 .37835 .57753 Mtetra
.908 .727 .645 r
.37835 .57753 .37923 .57836 .3809 .57269 .38002 .57187 Mtetra
.777 .759 .837 r
.38002 .57187 .3809 .57269 .38238 .57158 .3815 .57076 Mtetra
.644 .736 .916 r
.3815 .57076 .38238 .57158 .38382 .57121 .38294 .57039 Mtetra
.517 .693 .948 r
.38294 .57039 .38382 .57121 .38525 .5712 .38438 .57037 Mtetra
.747 .757 .86 r
.38438 .57037 .38525 .5712 .38672 .57032 .38585 .5695 Mtetra
.7 .749 .89 r
.38585 .5695 .38672 .57032 .38818 .56972 .3873 .56889 Mtetra
.5 .687 .951 r
.3873 .56889 .38818 .56972 .38961 .56973 .38874 .56891 Mtetra
.921 .531 .223 r
.38874 .56891 .38961 .56973 .3909 .57341 .39003 .57259 Mtetra
.939 .683 .522 r
.39003 .57259 .3909 .57341 .38495 .76281 .38402 .76207 Mtetra
.936 .59 .343 r
.38402 .76207 .38495 .76281 .38625 .76841 .38532 .76766 Mtetra
.21 .576 .941 r
.38532 .76766 .38625 .76841 .38776 .76882 .38683 .76808 Mtetra
.677 .776 .925 r
.38683 .76808 .38776 .76882 .3893 .76827 .38837 .76754 Mtetra
.761 .791 .877 r
.38837 .76754 .3893 .76827 .39086 .76729 .38993 .76658 Mtetra
.515 .737 .975 r
.38993 .76658 .39086 .76729 .3924 .76705 .39146 .76649 Mtetra
.583 .802 .983 r
.39146 .76649 .3924 .76705 .39394 .76671 .393 .7662 Mtetra
.771 .842 .905 r
.393 .7662 .39394 .76671 .39549 .76592 .39457 .76522 Mtetra
.912 .748 .665 r
.39457 .76522 .39549 .76592 .39713 .76299 .39627 .76035 Mtetra
.937 .685 .529 r
.39627 .76035 .39713 .76299 .39891 .75572 .40454 .57019 Mtetra
.58 .371 .562 r
.40454 .57019 .39891 .75572 .40687 .57082 .4062 .56427 Mtetra
.647 .469 .629 r
.4062 .56427 .40687 .57082 .40842 .56807 .40771 .5626 Mtetra
.607 .45 .643 r
.40771 .5626 .40842 .56807 .40988 .56752 .40917 .56207 Mtetra
.551 .41 .643 r
.40917 .56207 .40988 .56752 .41129 .56876 .41061 .56247 Mtetra
.28 .204 .59 r
.41061 .56247 .41129 .56876 .40668 .75211 .41194 .5661 Mtetra
0 0 .333 r
.41194 .5661 .40668 .75211 .40795 .76019 .40715 .75575 Mtetra
0 0 .359 r
.40715 .75575 .40795 .76019 .4094 .76275 .4085 .76133 Mtetra
.329 .485 .863 r
.4085 .76133 .4094 .76275 .41093 .76306 .41002 .762 Mtetra
.644 .699 .886 r
.41002 .762 .41093 .76306 .41249 .76268 .41157 .76161 Mtetra
.718 .719 .85 r
.41157 .76161 .41249 .76268 .41405 .76202 .41314 .76082 Mtetra
.655 .678 .86 r
.41314 .76082 .41405 .76202 .4156 .76171 .4147 .76037 Mtetra
.64 .651 .845 r
.4147 .76037 .4156 .76171 .41715 .76136 .41625 .75999 Mtetra
.651 .651 .837 r
.41625 .75999 .41715 .76136 .41872 .76073 .41781 .75955 Mtetra
.691 .692 .846 r
.41781 .75955 .41872 .76073 .42031 .75903 .41938 .75889 Mtetra
.683 .936 .966 r
.41938 .75889 .42031 .75903 .42194 .75631 .42094 .75814 Mtetra
.336 0 .19 r
.42094 .75814 .42194 .75631 .4236 .75217 .42251 .75739 Mtetra
.546 .276 .458 r
.42251 .75739 .4236 .75217 .42519 .75067 .42407 .75728 Mtetra
.547 .291 .478 r
.42407 .75728 .42519 .75067 .42673 .75087 .42562 .75709 Mtetra
.51 .254 .463 r
.42562 .75709 .42673 .75087 .42829 .75017 .42719 .75628 Mtetra
.178 0 .343 r
.42719 .75628 .42829 .75017 .43473 .5666 .42886 .75198 Mtetra
0 0 .331 r
.42886 .75198 .43473 .5666 .43642 .55818 .43545 .56146 Mtetra
.84 .803 .312 r
.43545 .56146 .43642 .55818 .43797 .55503 .43709 .5549 Mtetra
.881 .911 .844 r
.43709 .5549 .43797 .55503 .43946 .55394 .4386 .55328 Mtetra
.666 .786 .938 r
.4386 .55328 .43946 .55394 .44094 .55363 .44008 .5528 Mtetra
.542 .705 .946 r
.44008 .5528 .44094 .55363 .44241 .55359 .44155 .55272 Mtetra
.617 .721 .92 r
.44155 .55272 .44241 .55359 .44388 .55332 .44303 .55243 Mtetra
.652 .728 .904 r
.44303 .55243 .44388 .55332 .44537 .5529 .44451 .55202 Mtetra
.656 .732 .905 r
.44451 .55202 .44537 .5529 .44685 .55241 .44599 .55159 Mtetra
.681 .751 .904 r
.44599 .55159 .44685 .55241 .44834 .55166 .44748 .55106 Mtetra
.686 .809 .941 r
.44748 .55106 .44834 .55166 .44983 .55092 .44897 .55051 Mtetra
.654 .856 .977 r
.44897 .55051 .44983 .55092 .45132 .55044 .45045 .55 Mtetra
.691 .855 .961 r
.45045 .55 .45132 .55044 .45279 .55072 .45194 .5494 Mtetra
.647 .647 .836 r
.45194 .5494 .45279 .55072 .45424 .55194 .45343 .549 Mtetra
.558 .472 .714 r
.45343 .549 .45424 .55194 .45565 .55508 .45491 .54917 Mtetra
.334 .25 .61 r
.45491 .54917 .45565 .55508 .45341 .74108 .45633 .5522 Mtetra
0 0 .363 r
.45633 .5522 .45341 .74108 .45484 .74778 .45403 .74204 Mtetra
0 0 .45 r
.45403 .74204 .45484 .74778 .45637 .75003 .45548 .74827 Mtetra
.252 .388 .807 r
.45548 .74827 .45637 .75003 .45793 .75047 .45703 .74935 Mtetra
.625 .684 .885 r
.45703 .74935 .45793 .75047 .45951 .7501 .45861 .74904 Mtetra
.71 .722 .859 r
.45861 .74904 .45951 .7501 .46109 .74943 .4602 .74829 Mtetra
.675 .698 .864 r
.4602 .74829 .46109 .74943 .46268 .74902 .46178 .74774 Mtetra
.643 .662 .853 r
.46178 .74774 .46268 .74902 .46426 .74871 .46337 .74733 Mtetra
.654 .653 .837 r
.46337 .74733 .46426 .74871 .46585 .74815 .46495 .74687 Mtetra
.632 .659 .858 r
.46495 .74687 .46585 .74815 .46744 .74691 .46654 .74653 Mtetra
.622 .866 .989 r
.46654 .74653 .46744 .74691 .46906 .74475 .46813 .74604 Mtetra
.07 0 0 r
.46813 .74604 .46906 .74475 .47069 .74091 .46972 .74497 Mtetra
.003 0 .213 r
.46972 .74497 .47069 .74091 .47501 .55559 .47136 .7412 Mtetra
0 0 .354 r
.47136 .7412 .47501 .55559 .47665 .54592 .47572 .55071 Mtetra
0 0 0 r
.47572 .55071 .47665 .54592 .47819 .54277 .47733 .54285 Mtetra
.92 .933 .799 r
.47733 .54285 .47819 .54277 .4797 .5414 .47885 .5408 Mtetra
.694 .812 .938 r
.47885 .5408 .4797 .5414 .4812 .54087 .48036 .54021 Mtetra
.55 .756 .973 r
.48036 .54021 .4812 .54087 .4827 .54062 .48186 .54004 Mtetra
.58 .79 .979 r
.48186 .54004 .4827 .54062 .4842 .5403 .48336 .53977 Mtetra
.645 .824 .969 r
.48336 .53977 .4842 .5403 .48571 .53984 .48486 .53932 Mtetra
.644 .824 .969 r
.48486 .53932 .48571 .53984 .48721 .53939 .48637 .53886 Mtetra
.648 .827 .969 r
.48637 .53886 .48721 .53939 .48872 .53892 .48787 .5384 Mtetra
.652 .829 .968 r
.48787 .5384 .48872 .53892 .49022 .53844 .48938 .53792 Mtetra
.653 .831 .969 r
.48938 .53792 .49022 .53844 .49173 .53795 .49089 .53744 Mtetra
.652 .832 .969 r
.49089 .53744 .49173 .53795 .49324 .53747 .4924 .53696 Mtetra
.651 .833 .97 r
.4924 .53696 .49324 .53747 .49475 .53699 .49391 .53648 Mtetra
.49391 .53648 .49475 .53699 .49626 .53651 .49542 .536 Mtetra
.65 .833 .97 r
.49542 .536 .49626 .53651 .49777 .53603 .49693 .53553 Mtetra
.65 .832 .97 r
.49693 .53553 .49777 .53603 .49928 .53556 .49844 .53505 Mtetra
.649 .832 .971 r
.49844 .53505 .49928 .53556 .5008 .53509 .49996 .53458 Mtetra
.49996 .53458 .5008 .53509 .50231 .53461 .50147 .5341 Mtetra
.648 .831 .971 r
.50147 .5341 .50231 .53461 .50382 .53414 .50299 .53363 Mtetra
.50299 .53363 .50382 .53414 .50534 .53368 .5045 .53316 Mtetra
.647 .831 .971 r
.5045 .53316 .50534 .53368 .50685 .53321 .50602 .53269 Mtetra
.50602 .53269 .50685 .53321 .50837 .53274 .50754 .53222 Mtetra
.647 .83 .971 r
.50754 .53222 .50837 .53274 .50989 .53227 .50905 .53175 Mtetra
.50905 .53175 .50989 .53227 .51141 .5318 .51057 .53129 Mtetra
.51057 .53129 .51141 .5318 .51293 .53133 .51209 .53082 Mtetra
.51209 .53082 .51293 .53133 .51445 .53087 .51361 .53035 Mtetra
.51361 .53035 .51445 .53087 .51597 .5304 .51514 .52988 Mtetra
.51514 .52988 .51597 .5304 .51749 .52993 .51666 .52941 Mtetra
.51666 .52941 .51749 .52993 .51901 .52946 .51818 .52894 Mtetra
.51818 .52894 .51901 .52946 .52053 .52899 .5197 .52847 Mtetra
.5197 .52847 .52053 .52899 .52206 .52852 .52123 .528 Mtetra
.52123 .528 .52206 .52852 .52358 .52805 .52276 .52753 Mtetra
.648 .83 .971 r
.52276 .52753 .52358 .52805 .52511 .52757 .52428 .52705 Mtetra
.648 .831 .971 r
.52428 .52705 .52511 .52757 .52664 .5271 .52581 .52658 Mtetra
.52581 .52658 .52664 .5271 .52816 .52662 .52734 .5261 Mtetra
.52734 .5261 .52816 .52662 .52969 .52615 .52887 .52563 Mtetra
.649 .832 .971 r
.52887 .52563 .52969 .52615 .53122 .52567 .5304 .52515 Mtetra
.5304 .52515 .53122 .52567 .53275 .52518 .53193 .52467 Mtetra
.649 .833 .971 r
.53193 .52467 .53275 .52518 .53428 .52471 .53346 .52419 Mtetra
.53346 .52419 .53428 .52471 .53581 .52423 .53499 .52371 Mtetra
.652 .832 .97 r
.53499 .52371 .53581 .52423 .53735 .52373 .53653 .52322 Mtetra
.655 .836 .97 r
.53653 .52322 .53735 .52373 .53888 .52317 .53806 .52272 Mtetra
.654 .853 .976 r
.53806 .52272 .53888 .52317 .54041 .52255 .53959 .5222 Mtetra
.634 .879 .987 r
.53959 .5222 .54041 .52255 .54195 .52193 .54113 .52169 Mtetra
.595 .896 .988 r
.54113 .52169 .54195 .52193 .54348 .52135 .54267 .52119 Mtetra
.547 .898 .976 r
.54267 .52119 .54348 .52135 .54502 .52084 .5442 .52071 Mtetra
.522 .894 .967 r
.5442 .52071 .54502 .52084 .54656 .52038 .54574 .52024 Mtetra
.528 .897 .967 r
.54574 .52024 .54656 .52038 .5481 .51992 .54728 .51977 Mtetra
.543 .9 .971 r
.54728 .51977 .5481 .51992 .54964 .51945 .54882 .51928 Mtetra
.53 .891 .976 r
.54882 .51928 .54964 .51945 .55118 .51917 .55036 .51883 Mtetra
.543 .855 .997 r
.55036 .51883 .55118 .51917 .55272 .51938 .55191 .51849 Mtetra
.586 .71 .929 r
.55191 .51849 .55272 .51938 .55428 .52058 .55345 .51829 Mtetra
.598 .532 .752 r
.55345 .51829 .55428 .52058 .55585 .52274 .555 .51813 Mtetra
.603 .46 .66 r
.555 .51813 .55585 .52274 .55742 .5252 .55654 .51774 Mtetra
.606 .434 .623 r
.55654 .51774 .55742 .5252 .55897 .52461 .55809 .51696 Mtetra
.59 .421 .621 r
.55809 .51696 .55897 .52461 .56052 .52416 .55963 .51659 Mtetra
.515 .367 .619 r
.55963 .51659 .56052 .52416 .56217 .53226 .5612 .5179 Mtetra
.977 .705 .444 r
.5612 .5179 .56217 .53226 .56586 .7167 .56489 .7061 Mtetra
0 0 .453 r
.56489 .7061 .56586 .7167 .56754 .71968 .56667 .7174 Mtetra
.406 .43 .773 r
.56667 .7174 .56754 .71968 .56919 .71955 .56833 .71832 Mtetra
.911 .727 .641 r
.56833 .71832 .56919 .71955 .57077 .71396 .56991 .71276 Mtetra
.958 .69 .484 r
.56991 .71276 .57077 .71396 .5698 .51912 .56899 .51804 Mtetra
.91 .734 .652 r
.56899 .51804 .5698 .51912 .5713 .51427 .57049 .51328 Mtetra
.726 .737 .859 r
.57049 .51328 .5713 .51427 .57284 .51344 .57203 .51247 Mtetra
.591 .695 .915 r
.57203 .51247 .57284 .51344 .5744 .51327 .57359 .51227 Mtetra
.536 .668 .922 r
.57359 .51227 .5744 .51327 .57597 .51328 .57515 .51225 Mtetra
.647 .704 .888 r
.57515 .51225 .57597 .51328 .57752 .5129 .57671 .51185 Mtetra
.648 .7 .884 r
.57671 .51185 .57752 .5129 .57908 .51251 .57827 .51143 Mtetra
.654 .698 .879 r
.57827 .51143 .57908 .51251 .58064 .51209 .57983 .511 Mtetra
.662 .698 .872 r
.57983 .511 .58064 .51209 .5822 .51162 .58139 .51052 Mtetra
.667 .697 .868 r
.58139 .51052 .5822 .51162 .58376 .51113 .58295 .51001 Mtetra
.671 .697 .865 r
.58295 .51001 .58376 .51113 .58532 .51061 .58451 .50949 Mtetra
.675 .696 .862 r
.58451 .50949 .58532 .51061 .58688 .51008 .58607 .50894 Mtetra
.677 .693 .858 r
.58607 .50894 .58688 .51008 .58844 .50952 .58763 .50838 Mtetra
.678 .695 .859 r
.58763 .50838 .58844 .50952 .59 .50888 .58919 .50781 Mtetra
.681 .709 .869 r
.58919 .50781 .59 .50888 .59155 .50813 .59075 .50723 Mtetra
.683 .746 .899 r
.59075 .50723 .59155 .50813 .59311 .50738 .59232 .50667 Mtetra
.701 .795 .923 r
.59232 .50667 .59311 .50738 .59467 .50663 .59388 .50603 Mtetra
.761 .833 .907 r
.59388 .50603 .59467 .50663 .59623 .5058 .59543 .50511 Mtetra
.671 .793 .939 r
.59543 .50511 .59623 .5058 .5978 .50527 .597 .50458 Mtetra
.19 .57 .938 r
.597 .50458 .5978 .50527 .59938 .50538 .59859 .50503 Mtetra
.921 .537 .256 r
.59859 .50503 .59938 .50538 .60101 .50755 .60028 .51001 Mtetra
.958 .68 .467 r
.60028 .51001 .60101 .50755 .60275 .51457 .60633 .70321 Mtetra
.575 .363 .556 r
.60633 .70321 .60275 .51457 .60879 .70147 .6081 .70733 Mtetra
.556 .29 .468 r
.6081 .70733 .60879 .70147 .61047 .70144 .60979 .70736 Mtetra
.519 .259 .461 r
.60979 .70736 .61047 .70144 .61212 .70044 .61145 .70672 Mtetra
.513 .257 .465 r
.61145 .70672 .61212 .70044 .6138 .70054 .61311 .7059 Mtetra
.547 .277 .458 r
.61311 .7059 .6138 .70054 .61557 .70385 .6148 .7058 Mtetra
.496 .135 .284 r
.6148 .7058 .61557 .70385 .6173 .70577 .61648 .7057 Mtetra
.188 .716 .844 r
.61648 .7057 .6173 .70577 .61901 .70677 .61816 .70556 Mtetra
.552 .644 .895 r
.61816 .70556 .61901 .70677 .6207 .70682 .61985 .70553 Mtetra
.65 .673 .859 r
.61985 .70553 .6207 .70682 .62238 .70634 .62153 .70507 Mtetra
.769 .716 .803 r
.62153 .70507 .62238 .70634 .62404 .7052 .62318 .70373 Mtetra
.902 .717 .643 r
.62318 .70373 .62404 .7052 .62565 .70244 .62472 .69836 Mtetra
.96 .686 .472 r
.62472 .69836 .62565 .70244 .62718 .69666 .6208 .50383 Mtetra
.579 .37 .561 r
.6208 .50383 .62718 .69666 .62321 .50526 .62223 .49798 Mtetra
.628 .451 .624 r
.62223 .49798 .62321 .50526 .62466 .5001 .62379 .4966 Mtetra
.635 .505 .687 r
.62379 .4966 .62466 .5001 .62618 .49759 .62536 .4959 Mtetra
.638 .605 .8 r
.62536 .4959 .62618 .49759 .62773 .49601 .62695 .49549 Mtetra
.771 .861 .917 r
.62695 .49549 .62773 .49601 .62929 .4949 .62852 .49453 Mtetra
.636 .88 .986 r
.62852 .49453 .62929 .4949 .63088 .4944 .6301 .49399 Mtetra
.158 .632 .928 r
.6301 .49399 .63088 .4944 .63249 .49474 .63171 .49423 Mtetra
.913 .511 .187 r
.63171 .49423 .63249 .49474 .63423 .49896 .63347 .49881 Mtetra
.965 .683 .45 r
.63347 .49881 .63423 .49896 .64236 .69417 .64154 .69372 Mtetra
.911 .508 .197 r
.64154 .69372 .64236 .69417 .64424 .69936 .64341 .6985 Mtetra
.162 .513 .914 r
.64341 .6985 .64424 .69936 .64597 .70016 .64514 .69915 Mtetra
.639 .723 .909 r
.64514 .69915 .64597 .70016 .64767 .69986 .64683 .69874 Mtetra
.793 .746 .81 r
.64683 .69874 .64767 .69986 .64933 .69852 .64849 .69727 Mtetra
.917 .734 .64 r
.64849 .69727 .64933 .69852 .65086 .69347 .65001 .6919 Mtetra
.965 .689 .459 r
.65001 .6919 .65086 .69347 .64546 .49763 .64465 .49612 Mtetra
.911 .712 .622 r
.64465 .49612 .64546 .49763 .64683 .4911 .64605 .49015 Mtetra
.772 .761 .843 r
.64605 .49015 .64683 .4911 .6484 .48993 .64762 .48902 Mtetra
.643 .732 .914 r
.64762 .48902 .6484 .48993 .65 .48952 .64922 .48861 Mtetra
.53 .689 .94 r
.64922 .48861 .65 .48952 .65162 .48948 .65084 .48857 Mtetra
.751 .765 .864 r
.65084 .48857 .65162 .48948 .6532 .48852 .65242 .48762 Mtetra
.694 .753 .897 r
.65242 .48762 .6532 .48852 .65479 .48788 .65401 .48699 Mtetra
.494 .676 .946 r
.65401 .48699 .65479 .48788 .65641 .48793 .65563 .48704 Mtetra
.886 .469 .059 r
.65563 .48704 .65641 .48793 .6582 .49218 .65743 .49132 Mtetra
.968 .684 .44 r
.65743 .49132 .6582 .49218 .66777 .68723 .66695 .68642 Mtetra
.908 .502 .126 r
.66695 .68642 .66777 .68723 .6697 .69229 .66888 .69144 Mtetra
.097 .476 .894 r
.66888 .69144 .6697 .69229 .67145 .69305 .67063 .6922 Mtetra
.625 .756 .941 r
.67063 .6922 .67145 .69305 .67316 .69267 .67235 .69182 Mtetra
.807 .799 .844 r
.67235 .69182 .67316 .69267 .67483 .69126 .67402 .69041 Mtetra
.936 .769 .649 r
.67402 .69041 .67483 .69126 .67635 .68639 .67554 .68553 Mtetra
.968 .69 .449 r
.67554 .68553 .67635 .68639 .66954 .49077 .66877 .48985 Mtetra
.947 .746 .599 r
.66877 .48985 .66954 .49077 .67088 .48405 .6701 .48314 Mtetra
.795 .775 .835 r
.6701 .48314 .67088 .48405 .67245 .48276 .67168 .48185 Mtetra
.629 .729 .919 r
.67168 .48185 .67245 .48276 .67407 .48241 .6733 .48149 Mtetra
.495 .671 .943 r
.6733 .48149 .67407 .48241 .6757 .48246 .67493 .48155 Mtetra
.639 .733 .917 r
.67493 .48155 .6757 .48246 .67732 .48207 .67655 .48115 Mtetra
.662 .742 .909 r
.67655 .48115 .67732 .48207 .67893 .48157 .67816 .48066 Mtetra
.669 .744 .907 r
.67816 .48066 .67893 .48157 .68055 .48105 .67978 .48014 Mtetra
.761 .77 .861 r
.67978 .48014 .68055 .48105 .68214 .48003 .68137 .47912 Mtetra
.718 .76 .886 r
.68137 .47912 .68214 .48003 .68374 .47927 .68297 .47836 Mtetra
.549 .698 .938 r
.68297 .47836 .68374 .47927 .68537 .47918 .68461 .47827 Mtetra
.837 .401 0 r
.68461 .47827 .68537 .47918 .6872 .48288 .68643 .48198 Mtetra
.97 .683 .428 r
.68643 .48198 .6872 .48288 .69853 .67813 .69772 .67729 Mtetra
.912 .513 .132 r
.69772 .67729 .69853 .67813 .70055 .68369 .69974 .68283 Mtetra
0 .396 .846 r
.69974 .68283 .70055 .68369 .70235 .68466 .70154 .6838 Mtetra
.607 .748 .944 r
.70154 .6838 .70235 .68466 .70408 .68434 .70327 .68347 Mtetra
.8 .799 .851 r
.70327 .68347 .70408 .68434 .70576 .683 .70496 .68213 Mtetra
.935 .775 .659 r
.70496 .68213 .70576 .683 .70728 .6785 .70648 .67761 Mtetra
.971 .689 .438 r
.70648 .67761 .70728 .6785 .69873 .48258 .69796 .48161 Mtetra
.952 .742 .584 r
.69796 .48161 .69873 .48258 .69999 .47516 .69923 .47422 Mtetra
.826 .778 .808 r
.69923 .47422 .69999 .47516 .70156 .47354 .70079 .47261 Mtetra
.658 .738 .908 r
.70079 .47261 .70156 .47354 .70318 .47306 .70242 .47213 Mtetra
.537 .688 .937 r
.70242 .47213 .70318 .47306 .70483 .47301 .70408 .47208 Mtetra
.713 .756 .886 r
.70408 .47208 .70483 .47301 .70645 .47224 .70569 .47134 Mtetra
.702 .759 .896 r
.70569 .47134 .70645 .47224 .70807 .47155 .70731 .47066 Mtetra
.537 .699 .944 r
.70731 .47066 .70807 .47155 .70972 .47148 .70897 .47059 Mtetra
.771 .317 0 r
.70897 .47059 .70972 .47148 .71158 .47492 .71081 .47376 Mtetra
.972 .682 .417 r
.71081 .47376 .71158 .47492 .72444 .6711 .72359 .66915 Mtetra
.829 .466 0 r
.72359 .66915 .72444 .6711 .72654 .6769 .72572 .67554 Mtetra
.28 .472 .87 r
.72572 .67554 .72654 .6769 .72836 .67772 .72754 .67641 Mtetra
.646 .675 .863 r
.72754 .67641 .72836 .67772 .7301 .67717 .72928 .67596 Mtetra
.73 .721 .842 r
.72928 .67596 .7301 .67717 .73179 .67592 .73099 .67499 Mtetra
.663 .753 .917 r
.73099 .67499 .73179 .67592 .73346 .67425 .73274 .67445 Mtetra
.275 .77 .717 r
.73274 .67445 .73346 .67425 .73509 .67179 .73447 .67385 Mtetra
.286 0 .216 r
.73447 .67385 .73509 .67179 .73658 .66716 .73617 .67259 Mtetra
.168 0 .361 r
.73617 .67259 .73658 .66716 .72658 .47471 .73766 .66785 Mtetra
.081 0 .455 r
.73766 .66785 .72658 .47471 .72785 .46809 .72736 .47148 Mtetra
0 0 .033 r
.72736 .47148 .72785 .46809 .72935 .46523 .72865 .46515 Mtetra
.887 .97 .834 r
.72865 .46515 .72935 .46523 .73095 .46411 .73022 .4634 Mtetra
.667 .799 .946 r
.73022 .4634 .73095 .46411 .7326 .46374 .73186 .46287 Mtetra
.559 .713 .944 r
.73186 .46287 .7326 .46374 .73427 .46364 .73352 .46272 Mtetra
.631 .735 .922 r
.73352 .46272 .73427 .46364 .73591 .46308 .73518 .46235 Mtetra
.664 .791 .942 r
.73518 .46235 .73591 .46308 .73755 .46237 .73682 .46182 Mtetra
.632 .835 .979 r
.73682 .46182 .73755 .46237 .73919 .46188 .73847 .46134 Mtetra
.562 .812 .992 r
.73847 .46134 .73919 .46188 .74091 .46236 .74014 .46104 Mtetra
.598 .638 .862 r
.74014 .46104 .74091 .46236 .74269 .46393 .74181 .46085 Mtetra
.595 .496 .712 r
.74181 .46085 .74269 .46393 .74458 .46693 .74348 .46067 Mtetra
.608 .445 .636 r
.74348 .46067 .74458 .46693 .74637 .46838 .74512 .45997 Mtetra
.601 .426 .617 r
.74512 .45997 .74637 .46838 .74798 .46731 .74676 .4592 Mtetra
.583 .415 .619 r
.74676 .4592 .74798 .46731 .74966 .46705 .74843 .45899 Mtetra
.461 .331 .616 r
.74843 .45899 .74966 .46705 .76423 .65413 .7503 .46161 Mtetra
.097 .019 .47 r
.7503 .46161 .76423 .65413 .76662 .66279 .76547 .65649 Mtetra
.017 .043 .543 r
.76547 .65649 .76662 .66279 .76861 .66553 .76776 .66365 Mtetra
.281 .396 .802 r
.76776 .66365 .76861 .66553 .77046 .66626 .76965 .66494 Mtetra
.611 .66 .873 r
.76965 .66494 .77046 .66626 .77224 .66598 .77143 .66466 Mtetra
.701 .698 .844 r
.77143 .66466 .77224 .66598 .77399 .66516 .77318 .66386 Mtetra
.666 .688 .861 r
.77318 .66386 .77399 .66516 .77569 .66375 .77495 .66329 Mtetra
.618 .868 .99 r
.77495 .66329 .77569 .66375 .77733 .66153 .77671 .66275 Mtetra
.121 0 0 r
.77671 .66275 .77733 .66153 .77886 .65768 .77844 .66163 Mtetra
.142 0 .312 r
.77844 .66163 .77886 .65768 .76675 .46841 .77998 .65792 Mtetra
.092 .012 .463 r
.77998 .65792 .76675 .46841 .76761 .45687 .76738 .46283 Mtetra
0 0 .236 r
.76738 .46283 .76761 .45687 .76906 .45353 .76841 .45367 Mtetra
.917 .979 .739 r
.76841 .45367 .76906 .45353 .77066 .45212 .76995 .45142 Mtetra
.696 .815 .939 r
.76995 .45142 .77066 .45212 .77233 .45165 .7716 .45076 Mtetra
.583 .722 .939 r
.7716 .45076 .77233 .45165 .77403 .45148 .7733 .45054 Mtetra
.623 .728 .922 r
.7733 .45054 .77403 .45148 .77569 .45098 .77498 .45019 Mtetra
.675 .786 .933 r
.77498 .45019 .77569 .45098 .77734 .45019 .77664 .44962 Mtetra
.648 .838 .973 r
.77664 .44962 .77734 .45019 .77901 .44962 .77831 .44909 Mtetra
.586 .829 .991 r
.77831 .44909 .77901 .44962 .78074 .44986 .77999 .44871 Mtetra
.606 .676 .89 r
.77999 .44871 .78074 .44986 .78256 .45118 .78169 .44846 Mtetra
.603 .517 .73 r
.78169 .44846 .78256 .45118 .78446 .45362 .78338 .44822 Mtetra
.611 .457 .648 r
.78338 .44822 .78446 .45362 .7863 .45515 .78505 .44756 Mtetra
.607 .435 .623 r
.78505 .44756 .7863 .45515 .78793 .45396 .7867 .4467 Mtetra
.591 .426 .627 r
.7867 .4467 .78793 .45396 .78959 .45324 .78838 .44632 Mtetra
.496 .364 .63 r
.78838 .44632 .78959 .45324 .79188 .46014 .79024 .44798 Mtetra
.979 .684 .333 r
.79024 .44798 .79188 .46014 .80909 .6494 .80722 .63487 Mtetra
.066 .033 .506 r
.80722 .63487 .80909 .6494 .81122 .65296 .81035 .6508 Mtetra
.186 .307 .756 r
.81035 .6508 .81122 .65296 .81312 .65382 .81234 .65271 Mtetra
.601 .695 .909 r
.81234 .65271 .81312 .65382 .81491 .6533 .81416 .65245 Mtetra
.721 .797 .912 r
.81416 .65245 .81491 .6533 .81667 .65237 .81592 .65162 Mtetra
.65 .802 .955 r
.81592 .65162 .81667 .65237 .81846 .65183 .81772 .65109 Mtetra
.53 .755 .979 r
.81772 .65109 .81846 .65183 .82029 .65169 .81954 .65092 Mtetra
.706 .815 .933 r
.81954 .65092 .82029 .65169 .82206 .65094 .82132 .65017 Mtetra
.925 .823 .727 r
.82132 .65017 .82206 .65094 .82361 .64758 .8229 .64712 Mtetra
.977 .684 .388 r
.8229 .64712 .82361 .64758 .8083 .44956 .80794 .45272 Mtetra
.86 .713 .188 r
.80794 .45272 .8083 .44956 .80931 .44122 .80868 .44118 Mtetra
.954 .943 .725 r
.80868 .44118 .80931 .44122 .81084 .43882 .81018 .43855 Mtetra
.632 .922 .976 r
.81018 .43855 .81084 .43882 .81252 .43827 .81186 .43788 Mtetra
.428 .802 .993 r
.81186 .43788 .81252 .43827 .81425 .4382 .81358 .43771 Mtetra
.461 .787 .999 r
.81358 .43771 .81425 .4382 .81599 .43812 .81531 .43757 Mtetra
.597 .827 .987 r
.81531 .43757 .81599 .43812 .81769 .43772 .81701 .43716 Mtetra
.595 .827 .988 r
.81701 .43716 .81769 .43772 .81939 .43729 .81872 .43677 Mtetra
.592 .834 .99 r
.81872 .43677 .81939 .43729 .82109 .43686 .82042 .43636 Mtetra
.591 .843 .992 r
.82042 .43636 .82109 .43686 .8228 .43642 .82213 .43594 Mtetra
.591 .849 .993 r
.82213 .43594 .8228 .43642 .8245 .43596 .82383 .4355 Mtetra
.592 .856 .994 r
.82383 .4355 .8245 .43596 .8262 .4355 .82554 .43506 Mtetra
.594 .862 .994 r
.82554 .43506 .8262 .4355 .8279 .43502 .82725 .43459 Mtetra
.596 .867 .993 r
.82725 .43459 .8279 .43502 .82961 .43453 .82895 .43411 Mtetra
.601 .872 .993 r
.82895 .43411 .82961 .43453 .83131 .43403 .83065 .43362 Mtetra
.607 .875 .992 r
.83065 .43362 .83131 .43403 .83301 .43352 .83236 .4331 Mtetra
.613 .877 .991 r
.83236 .4331 .83301 .43352 .83472 .433 .83406 .43257 Mtetra
.618 .878 .99 r
.83406 .43257 .83472 .433 .83642 .43246 .83576 .43203 Mtetra
.623 .878 .989 r
.83576 .43203 .83642 .43246 .83812 .43192 .83747 .43149 Mtetra
.625 .877 .989 r
.83747 .43149 .83812 .43192 .83983 .43137 .83917 .43094 Mtetra
.623 .875 .989 r
.83917 .43094 .83983 .43137 .84153 .43083 .84088 .43039 Mtetra
.62 .873 .989 r
.84088 .43039 .84153 .43083 .84324 .4303 .84259 .42986 Mtetra
.618 .872 .99 r
.84259 .42986 .84324 .4303 .84495 .42977 .8443 .42933 Mtetra
.615 .871 .99 r
.8443 .42933 .84495 .42977 .84666 .42925 .84601 .4288 Mtetra
.612 .87 .991 r
.84601 .4288 .84666 .42925 .84837 .42873 .84772 .42829 Mtetra
.612 .872 .991 r
.84772 .42829 .84837 .42873 .85008 .42821 .84943 .42777 Mtetra
.615 .874 .99 r
.84943 .42777 .85008 .42821 .85179 .42767 .85115 .42724 Mtetra
.62 .878 .99 r
.85115 .42724 .85179 .42767 .8535 .42712 .85286 .4267 Mtetra
.623 .882 .989 r
.85286 .4267 .8535 .42712 .85521 .42655 .85457 .42614 Mtetra
.635 .887 .986 r
.85457 .42614 .85521 .42655 .85692 .42592 .85628 .42554 Mtetra
.643 .901 .984 r
.85628 .42554 .85692 .42592 .85861 .42518 .85799 .4249 Mtetra
.596 .912 .979 r
.85799 .4249 .85861 .42518 .86033 .42462 .8597 .42429 Mtetra
.57 .888 .989 r
.8597 .42429 .86033 .42462 .8621 .42459 .86142 .42378 Mtetra
.604 .76 .954 r
.86142 .42378 .8621 .42459 .86399 .4257 .86316 .42345 Mtetra
.614 .553 .762 r
.86316 .42345 .86399 .4257 .86598 .42777 .86491 .42314 Mtetra
.61 .468 .663 r
.86491 .42314 .86598 .42777 .86802 .43024 .86663 .42261 Mtetra
.611 .438 .622 r
.86663 .42261 .86802 .43024 .86969 .4291 .8683 .42161 Mtetra
.598 .43 .625 r
.8683 .42161 .86969 .4291 .87135 .42799 .87002 .421 Mtetra
.55 .401 .632 r
.87002 .421 .87135 .42799 .87328 .42937 .87187 .42159 Mtetra
.27 .205 .598 r
.87187 .42159 .87328 .42937 .89583 .62216 .87431 .42769 Mtetra
.152 .068 .499 r
.87431 .42769 .89583 .62216 .89832 .62763 .89742 .62504 Mtetra
0 .124 .651 r
.89742 .62504 .89832 .62763 .90041 .6294 .8997 .62856 Mtetra
.492 .711 .968 r
.8997 .62856 .90041 .6294 .9023 .62921 .9016 .62854 Mtetra
.677 .84 .961 r
.9016 .62854 .9023 .62921 .90413 .6286 .90344 .62787 Mtetra
.699 .831 .946 r
.90344 .62787 .90413 .6286 .90597 .62795 .90526 .62712 Mtetra
.477 .707 .97 r
.90526 .62712 .90597 .62795 .90786 .62784 .90717 .62714 Mtetra
.607 .807 .977 r
.90717 .62714 .90786 .62784 .90973 .62745 .90903 .62671 Mtetra
.839 .859 .859 r
.90903 .62671 .90973 .62745 .91152 .62642 .91077 .62513 Mtetra
.957 .754 .587 r
.91077 .62513 .91152 .62642 .91313 .6237 .91195 .61867 Mtetra
.975 .672 .359 r
.91195 .61867 .91313 .6237 .91443 .6183 .89138 .4198 Mtetra
.576 .367 .561 r
.89138 .4198 .91443 .6183 .89428 .42445 .89263 .4149 Mtetra
.609 .427 .61 r
.89263 .4149 .89428 .42445 .89538 .41824 .89429 .41367 Mtetra
.614 .471 .665 r
.89429 .41367 .89538 .41824 .89686 .41543 .89602 .41308 Mtetra
.616 .547 .754 r
.89602 .41308 .89686 .41543 .89847 .41376 .89779 .41274 Mtetra
.667 .736 .901 r
.89779 .41274 .89847 .41376 .90018 .413 .89953 .41219 Mtetra
.654 .781 .941 r
.89953 .41219 .90018 .413 .90193 .41253 .90127 .41167 Mtetra
.676 .779 .928 r
.90127 .41167 .90193 .41253 .90369 .41207 .90301 .41107 Mtetra
.759 .776 .867 r
.90301 .41107 .90369 .41207 .90537 .41101 .90469 .41002 Mtetra
.689 .752 .9 r
.90469 .41002 .90537 .41101 .9071 .41036 .90643 .40937 Mtetra
.426 .623 .934 r
.90643 .40937 .9071 .41036 .90895 .41065 .90827 .40965 Mtetra
.785 .369 0 r
.90827 .40965 .90895 .41065 .91137 .41578 .91069 .41477 Mtetra
.973 .661 .312 r
.91069 .41477 .91137 .41578 .93708 .61501 .93637 .61406 Mtetra
.723 .286 0 r
.93637 .61406 .93708 .61501 .93952 .61928 .93882 .61834 Mtetra
.495 .69 .954 r
.93882 .61834 .93952 .61928 .94146 .61931 .94076 .61837 Mtetra
.69 .78 .92 r
.94076 .61837 .94146 .61931 .94331 .6186 .94261 .61767 Mtetra
.74 .798 .899 r
.94261 .61767 .94331 .6186 .94513 .61763 .94443 .6167 Mtetra
.492 .691 .956 r
.94443 .6167 .94513 .61763 .94707 .61766 .94637 .61673 Mtetra
.618 .753 .942 r
.94637 .61673 .94707 .61766 .94896 .61726 .94826 .61633 Mtetra
.798 .816 .866 r
.94826 .61633 .94896 .61726 .95073 .61591 .95004 .61499 Mtetra
.98 .778 .56 r
.95004 .61499 .95073 .61591 .95184 .60919 .95115 .6083 Mtetra
.975 .669 .322 r
.95115 .6083 .95184 .60919 .92873 .40874 .92807 .40777 Mtetra
.966 .785 .609 r
.92807 .40777 .92873 .40874 .92994 .40376 .92927 .40277 Mtetra
.758 .78 .871 r
.92927 .40277 .92994 .40376 .93163 .40272 .93097 .40173 Mtetra
.627 .728 .92 r
.93097 .40173 .93163 .40272 .93341 .40233 .93275 .40134 Mtetra
.544 .688 .933 r
.93275 .40134 .93341 .40233 .93523 .40226 .93457 .40126 Mtetra
.749 .776 .875 r
.93457 .40126 .93523 .40226 .93694 .40126 .93628 .40027 Mtetra
.682 .751 .903 r
.93628 .40027 .93694 .40126 .93869 .40064 .93803 .39964 Mtetra
.488 .657 .935 r
.93803 .39964 .93869 .40064 .94054 .40074 .93988 .39975 Mtetra
.74 .322 0 r
.93988 .39975 .94054 .40074 .943 .40554 .94234 .40455 Mtetra
.97 .655 .291 r
.94234 .40455 .943 .40554 .97087 .6056 .97018 .60466 Mtetra
.74 .309 0 r
.97018 .60466 .97087 .6056 .97345 .61036 .97276 .60942 Mtetra
.032 .463 .878 r
.36137 .77373 .36231 .77449 .36379 .77511 .36285 .77435 Mtetra
.644 .762 .935 r
.36285 .77435 .36379 .77511 .36532 .77471 .36438 .77395 Mtetra
.81 .779 .824 r
.36438 .77395 .36532 .77471 .36689 .77328 .36595 .77252 Mtetra
.908 .737 .658 r
.36595 .77252 .36689 .77328 .36863 .76802 .36769 .76726 Mtetra
.937 .686 .534 r
.36769 .76726 .36863 .76802 .37835 .57753 .37747 .57671 Mtetra
.908 .727 .645 r
.37747 .57671 .37835 .57753 .38002 .57187 .37914 .57105 Mtetra
.778 .759 .837 r
.37914 .57105 .38002 .57187 .3815 .57076 .38062 .56994 Mtetra
.643 .736 .916 r
.38062 .56994 .3815 .57076 .38294 .57039 .38207 .56957 Mtetra
.516 .694 .949 r
.38207 .56957 .38294 .57039 .38438 .57037 .3835 .56955 Mtetra
.747 .757 .861 r
.3835 .56955 .38438 .57037 .38585 .5695 .38497 .56867 Mtetra
.7 .75 .891 r
.38497 .56867 .38585 .5695 .3873 .56889 .38643 .56807 Mtetra
.498 .687 .951 r
.38643 .56807 .3873 .56889 .38874 .56891 .38786 .56809 Mtetra
.921 .532 .225 r
.38786 .56809 .38874 .56891 .39003 .57259 .38915 .57178 Mtetra
.939 .683 .522 r
.38915 .57178 .39003 .57259 .38402 .76207 .38309 .76134 Mtetra
.935 .589 .345 r
.38309 .76134 .38402 .76207 .38532 .76766 .38439 .76692 Mtetra
.207 .577 .941 r
.38439 .76692 .38532 .76766 .38683 .76808 .3859 .76733 Mtetra
.673 .774 .926 r
.3859 .76733 .38683 .76808 .38837 .76754 .38744 .76681 Mtetra
.754 .788 .881 r
.38744 .76681 .38837 .76754 .38993 .76658 .389 .76589 Mtetra
.411 .698 .98 r
.389 .76589 .38993 .76658 .39146 .76649 .39053 .76598 Mtetra
.496 .786 .997 r
.39053 .76598 .39146 .76649 .393 .7662 .39206 .76583 Mtetra
.757 .882 .935 r
.39206 .76583 .393 .7662 .39457 .76522 .39362 .76494 Mtetra
.935 .773 .656 r
.39362 .76494 .39457 .76522 .39627 .76035 .39534 .75968 Mtetra
.94 .687 .528 r
.39534 .75968 .39627 .76035 .40454 .57019 .40373 .5679 Mtetra
.848 .656 .643 r
.40373 .5679 .40454 .57019 .4062 .56427 .40537 .56243 Mtetra
.749 .634 .733 r
.40537 .56243 .4062 .56427 .40771 .5626 .40687 .56089 Mtetra
.655 .603 .784 r
.40687 .56089 .40771 .5626 .40917 .56207 .40833 .56038 Mtetra
.514 .534 .815 r
.40833 .56038 .40917 .56207 .41061 .56247 .40977 .56063 Mtetra
0 .063 .626 r
.40977 .56063 .41061 .56247 .41194 .5661 .41116 .56263 Mtetra
.878 .589 .07 r
.41116 .56263 .41194 .5661 .40715 .75575 .41237 .5699 Mtetra
0 0 .34 r
.41237 .5699 .40715 .75575 .4085 .76133 .40772 .75641 Mtetra
.481 .373 .654 r
.40772 .75641 .4085 .76133 .41002 .762 .40922 .7576 Mtetra
.612 .472 .668 r
.40922 .7576 .41002 .762 .41157 .76161 .41077 .75712 Mtetra
.629 .483 .664 r
.41077 .75712 .41157 .76161 .41314 .76082 .41234 .75632 Mtetra
.505 .398 .666 r
.41234 .75632 .41314 .76082 .4147 .76037 .41385 .75718 Mtetra
.446 .397 .71 r
.41385 .75718 .4147 .76037 .41625 .75999 .41537 .75818 Mtetra
.411 .475 .816 r
.41537 .75818 .41625 .75999 .41781 .75955 .41689 .75883 Mtetra
.506 .732 .974 r
.41689 .75883 .41781 .75955 .41938 .75889 .41844 .75876 Mtetra
.47 .868 .965 r
.41844 .75876 .41938 .75889 .42094 .75814 .42 .75838 Mtetra
.284 .78 .746 r
.42 .75838 .42094 .75814 .42251 .75739 .42156 .75787 Mtetra
.225 0 0 r
.42156 .75787 .42251 .75739 .42407 .75728 .42312 .75772 Mtetra
.122 0 0 r
.42312 .75772 .42407 .75728 .42562 .75709 .42467 .75747 Mtetra
.354 .813 .705 r
.42467 .75747 .42562 .75709 .42719 .75628 .42625 .75674 Mtetra
.945 .951 .743 r
.42625 .75674 .42719 .75628 .42886 .75198 .42787 .75412 Mtetra
.986 .87 .511 r
.42787 .75412 .42886 .75198 .43545 .56146 .4296 .74733 Mtetra
0 0 .337 r
.4296 .74733 .43545 .56146 .43709 .5549 .43612 .55831 Mtetra
0 0 .088 r
.43612 .55831 .43709 .5549 .4386 .55328 .43769 .55455 Mtetra
0 0 0 r
.43769 .55455 .4386 .55328 .44008 .5528 .4392 .55283 Mtetra
.775 .976 .915 r
.4392 .55283 .44008 .5528 .44155 .55272 .4407 .55177 Mtetra
.692 .725 .875 r
.4407 .55177 .44155 .55272 .44303 .55243 .44218 .55117 Mtetra
.632 .65 .849 r
.44218 .55117 .44303 .55243 .44451 .55202 .44366 .55085 Mtetra
.604 .653 .871 r
.44366 .55085 .44451 .55202 .44599 .55159 .44514 .55065 Mtetra
.64 .711 .898 r
.44514 .55065 .44599 .55159 .44748 .55106 .44662 .55029 Mtetra
.667 .758 .918 r
.44662 .55029 .44748 .55106 .44897 .55051 .44811 .54981 Mtetra
.678 .782 .929 r
.44811 .54981 .44897 .55051 .45045 .55 .4496 .54929 Mtetra
.747 .789 .887 r
.4496 .54929 .45045 .55 .45194 .5494 .45109 .54845 Mtetra
.724 .733 .858 r
.45109 .54845 .45194 .5494 .45343 .549 .45259 .54767 Mtetra
.636 .641 .839 r
.45259 .54767 .45343 .549 .45491 .54917 .45407 .54732 Mtetra
.172 .314 .767 r
.45407 .54732 .45491 .54917 .45633 .5522 .45553 .54865 Mtetra
0 0 .285 r
.45553 .54865 .45633 .5522 .45403 .74204 .4569 .55391 Mtetra
0 0 .363 r
.4569 .55391 .45403 .74204 .45548 .74827 .45467 .74274 Mtetra
.266 .212 .609 r
.45467 .74274 .45548 .74827 .45703 .74935 .45618 .74613 Mtetra
.452 .401 .71 r
.45618 .74613 .45703 .74935 .45861 .74904 .45773 .74712 Mtetra
.512 .522 .803 r
.45773 .74712 .45861 .74904 .4602 .74829 .4593 .74742 Mtetra
.557 .714 .945 r
.4593 .74742 .4602 .74829 .46178 .74774 .46088 .74729 Mtetra
.596 .842 .991 r
.46088 .74729 .46178 .74774 .46337 .74733 .46246 .74689 Mtetra
.652 .858 .978 r
.46246 .74689 .46337 .74733 .46495 .74687 .46405 .74636 Mtetra
.536 .803 .995 r
.46405 .74636 .46495 .74687 .46654 .74653 .46563 .74612 Mtetra
.488 .814 1 r
.46563 .74612 .46654 .74653 .46813 .74604 .46721 .7459 Mtetra
.626 .926 .972 r
.46721 .7459 .46813 .74604 .46972 .74497 .46881 .74526 Mtetra
.934 .952 .77 r
.46881 .74526 .46972 .74497 .47136 .7412 .47043 .74289 Mtetra
.992 .87 .535 r
.47043 .74289 .47136 .7412 .47572 .55071 .4721 .73645 Mtetra
0 0 .355 r
.4721 .73645 .47572 .55071 .47733 .54285 .47642 .54654 Mtetra
.006 0 .208 r
.47642 .54654 .47733 .54285 .47885 .5408 .47796 .54311 Mtetra
.417 .088 .298 r
.47796 .54311 .47885 .5408 .48036 .54021 .47947 .54244 Mtetra
.527 .191 .341 r
.47947 .54244 .48036 .54021 .48186 .54004 .48097 .54245 Mtetra
.51 .182 .348 r
.48097 .54245 .48186 .54004 .48336 .53977 .48247 .54231 Mtetra
.469 .149 .34 r
.48247 .54231 .48336 .53977 .48486 .53932 .48398 .54186 Mtetra
.47 .149 .34 r
.48398 .54186 .48486 .53932 .48637 .53886 .48549 .54142 Mtetra
.466 .146 .339 r
.48549 .54142 .48637 .53886 .48787 .5384 .48699 .54094 Mtetra
.462 .142 .337 r
.48699 .54094 .48787 .5384 .48938 .53792 .4885 .54045 Mtetra
.46 .139 .335 r
.4885 .54045 .48938 .53792 .49089 .53744 .49001 .53995 Mtetra
.459 .138 .333 r
.49001 .53995 .49089 .53744 .4924 .53696 .49153 .53945 Mtetra
.459 .137 .331 r
.49153 .53945 .4924 .53696 .49391 .53648 .49304 .53895 Mtetra
.458 .135 .33 r
.49304 .53895 .49391 .53648 .49542 .536 .49455 .53845 Mtetra
.458 .135 .329 r
.49455 .53845 .49542 .536 .49693 .53553 .49607 .53796 Mtetra
.458 .134 .328 r
.49607 .53796 .49693 .53553 .49844 .53505 .49758 .53748 Mtetra
.458 .133 .327 r
.49758 .53748 .49844 .53505 .49996 .53458 .4991 .53699 Mtetra
.458 .133 .326 r
.4991 .53699 .49996 .53458 .50147 .5341 .50061 .53651 Mtetra
.458 .133 .325 r
.50061 .53651 .50147 .5341 .50299 .53363 .50213 .53604 Mtetra
.458 .132 .325 r
.50213 .53604 .50299 .53363 .5045 .53316 .50365 .53556 Mtetra
.458 .132 .324 r
.50365 .53556 .5045 .53316 .50602 .53269 .50516 .53509 Mtetra
.50516 .53509 .50602 .53269 .50754 .53222 .50668 .53461 Mtetra
.50668 .53461 .50754 .53222 .50905 .53175 .5082 .53414 Mtetra
.458 .132 .323 r
.5082 .53414 .50905 .53175 .51057 .53129 .50973 .53367 Mtetra
.458 .131 .323 r
.50973 .53367 .51057 .53129 .51209 .53082 .51125 .5332 Mtetra
.51125 .5332 .51209 .53082 .51361 .53035 .51277 .53273 Mtetra
.51277 .53273 .51361 .53035 .51514 .52988 .51429 .53226 Mtetra
.51429 .53226 .51514 .52988 .51666 .52941 .51582 .53179 Mtetra
.51582 .53179 .51666 .52941 .51818 .52894 .51734 .53132 Mtetra
.51734 .53132 .51818 .52894 .5197 .52847 .51887 .53084 Mtetra
.458 .131 .322 r
.51887 .53084 .5197 .52847 .52123 .528 .5204 .53037 Mtetra
.458 .13 .322 r
.5204 .53037 .52123 .528 .52276 .52753 .52192 .5299 Mtetra
.52192 .5299 .52276 .52753 .52428 .52705 .52345 .52942 Mtetra
.457 .13 .322 r
.52345 .52942 .52428 .52705 .52581 .52658 .52498 .52895 Mtetra
.457 .129 .321 r
.52498 .52895 .52581 .52658 .52734 .5261 .52651 .52847 Mtetra
.52651 .52847 .52734 .5261 .52887 .52563 .52804 .52799 Mtetra
.456 .128 .321 r
.52804 .52799 .52887 .52563 .5304 .52515 .52958 .52751 Mtetra
.456 .128 .32 r
.52958 .52751 .5304 .52515 .53193 .52467 .53111 .52703 Mtetra
.455 .127 .32 r
.53111 .52703 .53193 .52467 .53346 .52419 .53264 .52654 Mtetra
.455 .127 .319 r
.53264 .52654 .53346 .52419 .53499 .52371 .53418 .52606 Mtetra
.455 .126 .319 r
.53418 .52606 .53499 .52371 .53653 .52322 .53571 .52557 Mtetra
.53571 .52557 .53653 .52322 .53806 .52272 .53725 .52508 Mtetra
.456 .128 .321 r
.53725 .52508 .53806 .52272 .53959 .5222 .53879 .5246 Mtetra
.458 .132 .324 r
.53879 .5246 .53959 .5222 .54113 .52169 .54032 .52412 Mtetra
.475 .149 .334 r
.54032 .52412 .54113 .52169 .54267 .52119 .54186 .52373 Mtetra
.495 .173 .35 r
.54186 .52373 .54267 .52119 .5442 .52071 .5434 .52345 Mtetra
.466 .154 .352 r
.5434 .52345 .5442 .52071 .54574 .52024 .54494 .52291 Mtetra
.351 .047 .302 r
.54494 .52291 .54574 .52024 .54728 .51977 .54648 .52171 Mtetra
.044 0 .085 r
.54648 .52171 .54728 .51977 .54882 .51928 .54801 .51992 Mtetra
.653 .925 .639 r
.54801 .51992 .54882 .51928 .55036 .51883 .54955 .51835 Mtetra
.807 .859 .888 r
.54955 .51835 .55036 .51883 .55191 .51849 .55109 .51719 Mtetra
.693 .673 .826 r
.55109 .51719 .55191 .51849 .55345 .51829 .55263 .5165 Mtetra
.655 .6 .781 r
.55263 .5165 .55345 .51829 .555 .51813 .55417 .51596 Mtetra
.653 .57 .749 r
.55417 .51596 .555 .51813 .55654 .51774 .55571 .51535 Mtetra
.665 .564 .731 r
.55571 .51535 .55654 .51774 .55809 .51696 .55726 .51457 Mtetra
.622 .54 .74 r
.55726 .51457 .55809 .51696 .55963 .51659 .5588 .5142 Mtetra
.396 .405 .751 r
.5588 .5142 .55963 .51659 .5612 .5179 .56037 .51522 Mtetra
.926 .603 .142 r
.56037 .51522 .5612 .5179 .56489 .7061 .56202 .52375 Mtetra
0 0 .394 r
.56202 .52375 .56489 .7061 .56667 .7174 .5658 .71578 Mtetra
.025 .265 .765 r
.5658 .71578 .56667 .7174 .56833 .71832 .56746 .71734 Mtetra
.923 .743 .64 r
.56746 .71734 .56833 .71832 .56991 .71276 .56905 .71176 Mtetra
.959 .69 .484 r
.56905 .71176 .56991 .71276 .56899 .51804 .56817 .51698 Mtetra
.91 .737 .654 r
.56817 .51698 .56899 .51804 .57049 .51328 .56967 .51229 Mtetra
.724 .735 .859 r
.56967 .51229 .57049 .51328 .57203 .51247 .57122 .51148 Mtetra
.598 .695 .911 r
.57122 .51148 .57203 .51247 .57359 .51227 .57278 .51127 Mtetra
.562 .675 .915 r
.57278 .51127 .57359 .51227 .57515 .51225 .57434 .51117 Mtetra
.675 .704 .869 r
.57434 .51117 .57515 .51225 .57671 .51185 .5759 .51063 Mtetra
.673 .68 .848 r
.5759 .51063 .57671 .51185 .57827 .51143 .57745 .51008 Mtetra
.668 .657 .83 r
.57745 .51008 .57827 .51143 .57983 .511 .57901 .50953 Mtetra
.659 .639 .818 r
.57901 .50953 .57983 .511 .58139 .51052 .58057 .50902 Mtetra
.658 .634 .815 r
.58057 .50902 .58139 .51052 .58295 .51001 .58213 .50852 Mtetra
.663 .637 .813 r
.58213 .50852 .58295 .51001 .58451 .50949 .58369 .50797 Mtetra
.678 .641 .806 r
.58369 .50797 .58451 .50949 .58607 .50894 .58525 .50733 Mtetra
.658 .621 .801 r
.58525 .50733 .58607 .50894 .58763 .50838 .58681 .5068 Mtetra
.608 .602 .819 r
.58681 .5068 .58763 .50838 .58919 .50781 .58838 .50658 Mtetra
.375 .537 .888 r
.58838 .50658 .58919 .50781 .59075 .50723 .58996 .50709 Mtetra
.514 0 0 r
.58996 .50709 .59075 .50723 .59232 .50667 .59156 .50796 Mtetra
.619 .219 .264 r
.59156 .50796 .59232 .50667 .59388 .50603 .59315 .5087 Mtetra
.401 .093 .324 r
.59315 .5087 .59388 .50603 .59543 .50511 .59471 .50775 Mtetra
.448 .133 .339 r
.59471 .50775 .59543 .50511 .597 .50458 .59627 .5071 Mtetra
.625 .296 .393 r
.59627 .5071 .597 .50458 .59859 .50503 .59787 .50803 Mtetra
.957 .679 .469 r
.59787 .50803 .59859 .50503 .60028 .51001 .6037 .6975 Mtetra
.58 .367 .556 r
.6037 .6975 .60028 .51001 .60633 .70321 .60556 .70548 Mtetra
.718 .377 .399 r
.60556 .70548 .60633 .70321 .6081 .70733 .60729 .70773 Mtetra
.233 0 0 r
.60729 .70773 .6081 .70733 .60979 .70736 .60897 .70765 Mtetra
0 0 0 r
.60897 .70765 .60979 .70736 .61145 .70672 .61064 .70708 Mtetra
.298 .77 .652 r
.61064 .70708 .61145 .70672 .61311 .7059 .6123 .70633 Mtetra
.071 0 0 r
.6123 .70633 .61311 .7059 .6148 .7058 .61398 .70599 Mtetra
.225 .74 .724 r
.61398 .70599 .6148 .7058 .61648 .7057 .61565 .70552 Mtetra
.625 .929 .97 r
.61565 .70552 .61648 .7057 .61816 .70556 .61732 .70484 Mtetra
.774 .818 .887 r
.61732 .70484 .61816 .70556 .61985 .70553 .61899 .70376 Mtetra
.765 .663 .75 r
.61899 .70376 .61985 .70553 .62153 .70507 .62063 .70208 Mtetra
.777 .609 .671 r
.62063 .70208 .62153 .70507 .62318 .70373 .62223 .69896 Mtetra
.959 .685 .474 r
.62223 .69896 .62318 .70373 .62472 .69836 .61858 .50907 Mtetra
.586 .375 .562 r
.61858 .50907 .62472 .69836 .6208 .50383 .6199 .49897 Mtetra
.719 .534 .64 r
.6199 .49897 .6208 .50383 .62223 .49798 .62141 .49592 Mtetra
.675 .592 .754 r
.62141 .49592 .62223 .49798 .62379 .4966 .62298 .49513 Mtetra
.622 .623 .831 r
.62298 .49513 .62379 .4966 .62536 .4959 .62457 .49484 Mtetra
.566 .668 .907 r
.62457 .49484 .62536 .4959 .62695 .49549 .62617 .49474 Mtetra
.753 .8 .89 r
.62617 .49474 .62695 .49549 .62852 .49453 .62774 .49383 Mtetra
.68 .797 .937 r
.62774 .49383 .62852 .49453 .6301 .49399 .62932 .49326 Mtetra
.383 .667 .971 r
.62932 .49326 .6301 .49399 .63171 .49423 .63093 .49345 Mtetra
.912 .509 .141 r
.63093 .49345 .63171 .49423 .63347 .49881 .63269 .49813 Mtetra
.965 .684 .449 r
.63269 .49813 .63347 .49881 .64154 .69372 .64071 .69298 Mtetra
.905 .495 .132 r
.64071 .69298 .64154 .69372 .64341 .6985 .64257 .69764 Mtetra
.18 .528 .921 r
.64257 .69764 .64341 .6985 .64514 .69915 .6443 .69826 Mtetra
.644 .75 .926 r
.6443 .69826 .64514 .69915 .64683 .69874 .646 .69781 Mtetra
.811 .781 .824 r
.646 .69781 .64683 .69874 .64849 .69727 .64766 .6963 Mtetra
.933 .753 .636 r
.64766 .6963 .64849 .69727 .65001 .6919 .64917 .69081 Mtetra
.966 .69 .459 r
.64917 .69081 .65001 .6919 .64465 .49612 .64386 .49502 Mtetra
.929 .737 .622 r
.64386 .49502 .64465 .49612 .64605 .49015 .64527 .48922 Mtetra
.772 .765 .846 r
.64527 .48922 .64605 .49015 .64762 .48902 .64684 .4881 Mtetra
.641 .731 .914 r
.64684 .4881 .64762 .48902 .64922 .48861 .64844 .4877 Mtetra
.53 .687 .939 r
.64844 .4877 .64922 .48861 .65084 .48857 .65006 .48766 Mtetra
.75 .765 .865 r
.65006 .48766 .65084 .48857 .65242 .48762 .65164 .48671 Mtetra
.693 .751 .897 r
.65164 .48671 .65242 .48762 .65401 .48699 .65323 .48609 Mtetra
.494 .674 .945 r
.65323 .48609 .65401 .48699 .65563 .48704 .65486 .48614 Mtetra
.886 .469 .057 r
.65486 .48614 .65563 .48704 .65743 .49132 .65665 .49044 Mtetra
.968 .684 .44 r
.65665 .49044 .65743 .49132 .66695 .68642 .66613 .68558 Mtetra
.907 .501 .121 r
.66613 .68558 .66695 .68642 .66888 .69144 .66806 .6906 Mtetra
.1 .477 .895 r
.66806 .6906 .66888 .69144 .67063 .6922 .66981 .69135 Mtetra
.625 .756 .94 r
.66981 .69135 .67063 .6922 .67235 .69182 .67153 .69096 Mtetra
.807 .799 .844 r
.67153 .69096 .67235 .69182 .67402 .69041 .6732 .68956 Mtetra
.936 .769 .649 r
.6732 .68956 .67402 .69041 .67554 .68553 .67472 .68467 Mtetra
.968 .69 .449 r
.67472 .68467 .67554 .68553 .66877 .48985 .66799 .48894 Mtetra
.947 .746 .599 r
.66799 .48894 .66877 .48985 .6701 .48314 .66933 .48222 Mtetra
.795 .775 .835 r
.66933 .48222 .6701 .48314 .67168 .48185 .67091 .48093 Mtetra
.628 .729 .92 r
.67091 .48093 .67168 .48185 .6733 .48149 .67252 .48058 Mtetra
.494 .671 .943 r
.67252 .48058 .6733 .48149 .67493 .48155 .67416 .48064 Mtetra
.638 .733 .917 r
.67416 .48064 .67493 .48155 .67655 .48115 .67578 .48024 Mtetra
.662 .742 .91 r
.67578 .48024 .67655 .48115 .67816 .48066 .67739 .47975 Mtetra
.668 .745 .908 r
.67739 .47975 .67816 .48066 .67978 .48014 .67901 .47924 Mtetra
.761 .771 .861 r
.67901 .47924 .67978 .48014 .68137 .47912 .6806 .47821 Mtetra
.718 .761 .886 r
.6806 .47821 .68137 .47912 .68297 .47836 .6822 .47746 Mtetra
.548 .698 .939 r
.6822 .47746 .68297 .47836 .68461 .47827 .68384 .47736 Mtetra
.839 .403 0 r
.68384 .47736 .68461 .47827 .68643 .48198 .68567 .48109 Mtetra
.97 .683 .428 r
.68567 .48109 .68643 .48198 .69772 .67729 .69692 .67647 Mtetra
.912 .512 .135 r
.69692 .67647 .69772 .67729 .69974 .68283 .69894 .68198 Mtetra
0 .393 .844 r
.69894 .68198 .69974 .68283 .70154 .6838 .70073 .68295 Mtetra
.607 .752 .947 r
.70073 .68295 .70154 .6838 .70327 .68347 .70247 .68262 Mtetra
.804 .802 .85 r
.70247 .68262 .70327 .68347 .70496 .68213 .70415 .68125 Mtetra
.938 .772 .651 r
.70415 .68125 .70496 .68213 .70648 .67761 .70566 .67648 Mtetra
.97 .689 .438 r
.70566 .67648 .70648 .67761 .69796 .48161 .69714 .47964 Mtetra
.904 .694 .608 r
.69714 .47964 .69796 .48161 .69923 .47422 .69845 .47292 Mtetra
.784 .713 .785 r
.69845 .47292 .69923 .47422 .70079 .47261 .70002 .47143 Mtetra
.636 .677 .872 r
.70002 .47143 .70079 .47261 .70242 .47213 .70165 .47105 Mtetra
.518 .645 .913 r
.70165 .47105 .70242 .47213 .70408 .47208 .70331 .47111 Mtetra
.685 .739 .892 r
.70331 .47111 .70408 .47208 .70569 .47134 .70494 .47051 Mtetra
.693 .774 .914 r
.70494 .47051 .70569 .47134 .70731 .47066 .70656 .46988 Mtetra
.562 .74 .959 r
.70656 .46988 .70731 .47066 .70897 .47059 .70821 .46969 Mtetra
0 .046 .572 r
.70821 .46969 .70897 .47059 .71081 .47376 .70997 .47148 Mtetra
.862 .523 .011 r
.70997 .47148 .71081 .47376 .72359 .66915 .71208 .47938 Mtetra
.08 .004 .46 r
.71208 .47938 .72359 .66915 .72572 .67554 .72468 .67052 Mtetra
.37 .304 .652 r
.72468 .67052 .72572 .67554 .72754 .67641 .7266 .67314 Mtetra
.488 .429 .717 r
.7266 .67314 .72754 .67641 .72928 .67596 .72842 .67398 Mtetra
.537 .537 .803 r
.72842 .67398 .72928 .67596 .73099 .67499 .7302 .67418 Mtetra
.461 .7 .971 r
.7302 .67418 .73099 .67499 .73274 .67445 .73198 .67423 Mtetra
.407 .832 .961 r
.73198 .67423 .73274 .67445 .73447 .67385 .73374 .67393 Mtetra
.568 .939 .867 r
.73374 .67393 .73447 .67385 .73617 .67259 .73546 .67303 Mtetra
.915 .968 .664 r
.73546 .67303 .73617 .67259 .73766 .66785 .73707 .67027 Mtetra
.837 .766 .255 r
.73707 .67027 .73766 .66785 .72736 .47148 .7384 .66297 Mtetra
.081 .001 .455 r
.7384 .66297 .72736 .47148 .72865 .46515 .72816 .4685 Mtetra
0 0 .233 r
.72816 .4685 .72865 .46515 .73022 .4634 .7296 .46464 Mtetra
0 0 0 r
.7296 .46464 .73022 .4634 .73186 .46287 .73117 .46287 Mtetra
.727 .987 .889 r
.73117 .46287 .73186 .46287 .73352 .46272 .73277 .46175 Mtetra
.695 .744 .889 r
.73277 .46175 .73352 .46272 .73518 .46235 .73441 .4611 Mtetra
.637 .669 .864 r
.73441 .4611 .73518 .46235 .73682 .46182 .73607 .46071 Mtetra
.612 .684 .893 r
.73607 .46071 .73682 .46182 .73847 .46134 .73773 .46043 Mtetra
.658 .746 .915 r
.73773 .46043 .73847 .46134 .74014 .46104 .73938 .45995 Mtetra
.686 .718 .873 r
.73938 .45995 .74014 .46104 .74181 .46085 .74102 .45932 Mtetra
.674 .645 .814 r
.74102 .45932 .74181 .46085 .74348 .46067 .74267 .45868 Mtetra
.678 .602 .764 r
.74267 .45868 .74348 .46067 .74512 .45997 .7443 .45788 Mtetra
.664 .587 .759 r
.7443 .45788 .74512 .45997 .74676 .4592 .74594 .45717 Mtetra
.614 .565 .776 r
.74594 .45717 .74676 .4592 .74843 .45899 .74761 .45689 Mtetra
.321 .386 .774 r
.74761 .45689 .74843 .45899 .7503 .46161 .74939 .45818 Mtetra
0 0 .508 r
.74939 .45818 .7503 .46161 .76547 .65649 .75143 .46331 Mtetra
.101 .022 .471 r
.75143 .46331 .76547 .65649 .76776 .66365 .76664 .6578 Mtetra
.322 .259 .63 r
.76664 .6578 .76776 .66365 .76965 .66494 .76869 .66148 Mtetra
.473 .413 .71 r
.76869 .66148 .76965 .66494 .77143 .66466 .77057 .66252 Mtetra
.526 .518 .79 r
.77057 .66252 .77143 .66466 .77318 .66386 .77239 .66281 Mtetra
.498 .659 .932 r
.77239 .66281 .77318 .66386 .77495 .66329 .7742 .66289 Mtetra
.448 .814 .995 r
.7742 .66289 .77495 .66329 .77671 .66275 .776 .66267 Mtetra
.586 .939 .93 r
.776 .66267 .77671 .66275 .77844 .66163 .77775 .66189 Mtetra
.89 .986 .722 r
.77775 .66189 .77844 .66163 .77998 .65792 .77939 .65957 Mtetra
.856 .809 .323 r
.77939 .65957 .77998 .65792 .76738 .46283 .78078 .65386 Mtetra
.095 .014 .464 r
.78078 .65386 .76738 .46283 .76841 .45367 .76808 .45809 Mtetra
.008 0 .293 r
.76808 .45809 .76841 .45367 .76995 .45142 .7694 .45294 Mtetra
0 0 .005 r
.7694 .45294 .76995 .45142 .7716 .45076 .77096 .45094 Mtetra
.679 .974 .801 r
.77096 .45094 .7716 .45076 .7733 .45054 .77257 .44968 Mtetra
.716 .779 .902 r
.77257 .44968 .7733 .45054 .77498 .45019 .77422 .44893 Mtetra
.648 .672 .86 r
.77422 .44893 .77498 .45019 .77664 .44962 .7759 .44848 Mtetra
.622 .684 .887 r
.7759 .44848 .77664 .44962 .77831 .44909 .77758 .44816 Mtetra
.655 .742 .914 r
.77758 .44816 .77831 .44909 .77999 .44871 .77926 .44768 Mtetra
.694 .735 .882 r
.77926 .44768 .77999 .44871 .78169 .44846 .78092 .44701 Mtetra
.682 .661 .823 r
.78092 .44701 .78169 .44846 .78338 .44822 .78258 .44633 Mtetra
.682 .614 .773 r
.78258 .44633 .78338 .44822 .78505 .44756 .78423 .44552 Mtetra
.673 .597 .762 r
.78423 .44552 .78505 .44756 .7867 .4467 .78589 .44474 Mtetra
.63 .58 .78 r
.78589 .44474 .7867 .4467 .78838 .44632 .78758 .44434 Mtetra
.415 .456 .795 r
.78758 .44434 .78838 .44632 .79024 .44798 .78936 .44518 Mtetra
0 .08 .614 r
.78936 .44518 .79024 .44798 .80722 .63487 .79138 .44882 Mtetra
.099 .024 .475 r
.79138 .44882 .80722 .63487 .81035 .6508 .80903 .64307 Mtetra
.265 .202 .597 r
.80903 .64307 .81035 .6508 .81234 .65271 .81134 .64889 Mtetra
.454 .391 .696 r
.81134 .64889 .81234 .65271 .81416 .65245 .81329 .65024 Mtetra
.511 .505 .786 r
.81329 .65024 .81416 .65245 .81592 .65162 .81516 .65065 Mtetra
.506 .683 .946 r
.81516 .65065 .81592 .65162 .81772 .65109 .817 .65067 Mtetra
.497 .833 .998 r
.817 .65067 .81772 .65109 .81954 .65092 .81881 .65036 Mtetra
.732 .877 .948 r
.81881 .65036 .81954 .65092 .82132 .65017 .82058 .64947 Mtetra
.899 .847 .783 r
.82058 .64947 .82132 .65017 .8229 .64712 .82222 .64716 Mtetra
.997 .826 .547 r
.82222 .64716 .8229 .64712 .80794 .45272 .82352 .64079 Mtetra
.105 .024 .472 r
.82352 .64079 .80794 .45272 .80868 .44118 .80837 .44498 Mtetra
0 0 .269 r
.80837 .44498 .80868 .44118 .81018 .43855 .8097 .44023 Mtetra
.044 0 .095 r
.8097 .44023 .81018 .43855 .81186 .43788 .81127 .43832 Mtetra
0 0 0 r
.81127 .43832 .81186 .43788 .81358 .43771 .8129 .43712 Mtetra
.708 .853 .951 r
.8129 .43712 .81358 .43771 .81531 .43757 .81457 .43638 Mtetra
.636 .683 .878 r
.81457 .43638 .81531 .43757 .81701 .43716 .81628 .43599 Mtetra
.597 .668 .89 r
.81628 .43599 .81701 .43716 .81872 .43677 .818 .43578 Mtetra
.593 .706 .922 r
.818 .43578 .81872 .43677 .82042 .43636 .81972 .43554 Mtetra
.624 .761 .944 r
.81972 .43554 .82042 .43636 .82213 .43594 .82143 .43515 Mtetra
.63 .773 .949 r
.82143 .43515 .82213 .43594 .82383 .4355 .82314 .43474 Mtetra
.634 .779 .951 r
.82314 .43474 .82383 .4355 .82554 .43506 .82485 .4343 Mtetra
.637 .784 .952 r
.82485 .4343 .82554 .43506 .82725 .43459 .82656 .43385 Mtetra
.642 .791 .954 r
.82656 .43385 .82725 .43459 .82895 .43411 .82826 .43338 Mtetra
.647 .796 .954 r
.82826 .43338 .82895 .43411 .83065 .43362 .82997 .43289 Mtetra
.653 .8 .953 r
.82997 .43289 .83065 .43362 .83236 .4331 .83167 .43238 Mtetra
.662 .804 .951 r
.83167 .43238 .83236 .4331 .83406 .43257 .83338 .43183 Mtetra
.679 .804 .942 r
.83338 .43183 .83406 .43257 .83576 .43203 .83507 .43123 Mtetra
.696 .793 .925 r
.83507 .43123 .83576 .43203 .83747 .43149 .83677 .43056 Mtetra
.695 .763 .904 r
.83677 .43056 .83747 .43149 .83917 .43094 .83846 .42989 Mtetra
.684 .733 .887 r
.83846 .42989 .83917 .43094 .84088 .43039 .84016 .42926 Mtetra
.669 .71 .878 r
.84016 .42926 .84088 .43039 .84259 .42986 .84187 .4287 Mtetra
.661 .702 .877 r
.84187 .4287 .84259 .42986 .8443 .42933 .84358 .42818 Mtetra
.65 .7 .883 r
.84358 .42818 .8443 .42933 .84601 .4288 .84529 .42772 Mtetra
.636 .706 .897 r
.84529 .42772 .84601 .4288 .84772 .42829 .84702 .42732 Mtetra
.632 .729 .918 r
.84702 .42732 .84772 .42829 .84943 .42777 .84875 .42693 Mtetra
.636 .762 .939 r
.84875 .42693 .84943 .42777 .85115 .42724 .85047 .42649 Mtetra
.653 .795 .95 r
.85047 .42649 .85115 .42724 .85286 .4267 .85219 .42598 Mtetra
.662 .807 .953 r
.85219 .42598 .85286 .4267 .85457 .42614 .8539 .42543 Mtetra
.669 .812 .952 r
.8539 .42543 .85457 .42614 .85628 .42554 .85561 .42485 Mtetra
.672 .817 .953 r
.85561 .42485 .85628 .42554 .85799 .4249 .85733 .42426 Mtetra
.68 .834 .957 r
.85733 .42426 .85799 .4249 .8597 .42429 .85903 .42362 Mtetra
.7 .833 .947 r
.85903 .42362 .8597 .42429 .86142 .42378 .86074 .42292 Mtetra
.72 .788 .906 r
.86074 .42292 .86142 .42378 .86316 .42345 .86243 .42213 Mtetra
.701 .692 .837 r
.86243 .42213 .86316 .42345 .86491 .42314 .86413 .42134 Mtetra
.69 .629 .782 r
.86413 .42134 .86491 .42314 .86663 .42261 .86582 .42047 Mtetra
.692 .603 .752 r
.86582 .42047 .86663 .42261 .8683 .42161 .86749 .41947 Mtetra
.647 .578 .764 r
.86749 .41947 .8683 .42161 .87002 .421 .86921 .41889 Mtetra
.489 .491 .786 r
.86921 .41889 .87002 .421 .87187 .42159 .87105 .41943 Mtetra
0 0 .441 r
.87105 .41943 .87187 .42159 .87431 .42769 .87335 .42427 Mtetra
.975 .668 .324 r
.87335 .42427 .87431 .42769 .89742 .62504 .89663 .62348 Mtetra
0 0 .396 r
.89663 .62348 .89742 .62504 .8997 .62856 .89899 .62772 Mtetra
.471 .703 .97 r
.89899 .62772 .8997 .62856 .9016 .62854 .9009 .62776 Mtetra
.689 .813 .941 r
.9009 .62776 .9016 .62854 .90344 .62787 .90273 .62706 Mtetra
.709 .813 .93 r
.90273 .62706 .90344 .62787 .90526 .62712 .90455 .62627 Mtetra
.464 .695 .968 r
.90455 .62627 .90526 .62712 .90717 .62714 .90647 .62634 Mtetra
.623 .783 .959 r
.90647 .62634 .90717 .62714 .90903 .62671 .90833 .6259 Mtetra
.853 .842 .833 r
.90833 .6259 .90903 .62671 .91077 .62513 .91004 .62412 Mtetra
.98 .753 .524 r
.91004 .62412 .91077 .62513 .91195 .61867 .91095 .61518 Mtetra
.976 .673 .354 r
.91095 .61518 .91195 .61867 .89138 .4198 .89045 .41657 Mtetra
.805 .614 .645 r
.89045 .41657 .89138 .4198 .89263 .4149 .8918 .41262 Mtetra
.665 .58 .75 r
.8918 .41262 .89263 .4149 .89429 .41367 .89351 .41185 Mtetra
.595 .578 .805 r
.89351 .41185 .89429 .41367 .89602 .41308 .8953 .41169 Mtetra
.541 .605 .867 r
.8953 .41169 .89602 .41308 .89779 .41274 .89711 .41175 Mtetra
.651 .737 .912 r
.89711 .41175 .89779 .41274 .89953 .41219 .89886 .41127 Mtetra
.662 .758 .921 r
.89886 .41127 .89953 .41219 .90127 .41167 .9006 .41073 Mtetra
.689 .764 .909 r
.9006 .41073 .90127 .41167 .90301 .41107 .90233 .41008 Mtetra
.759 .776 .867 r
.90233 .41008 .90301 .41107 .90469 .41002 .90402 .40902 Mtetra
.69 .75 .898 r
.90402 .40902 .90469 .41002 .90643 .40937 .90575 .40836 Mtetra
.431 .622 .932 r
.90575 .40836 .90643 .40937 .90827 .40965 .90759 .40864 Mtetra
.78 .365 0 r
.90759 .40864 .90827 .40965 .91069 .41477 .91001 .41372 Mtetra
.973 .661 .312 r
.91001 .41372 .91069 .41477 .93637 .61406 .93567 .6131 Mtetra
.721 .286 0 r
.93567 .6131 .93637 .61406 .93882 .61834 .93812 .6174 Mtetra
.493 .688 .954 r
.93812 .6174 .93882 .61834 .94076 .61837 .94006 .61744 Mtetra
.689 .779 .92 r
.94006 .61744 .94076 .61837 .94261 .61767 .94191 .61674 Mtetra
.739 .798 .9 r
.94191 .61674 .94261 .61767 .94443 .6167 .94373 .61578 Mtetra
.489 .691 .957 r
.94373 .61578 .94443 .6167 .94637 .61673 .94568 .61581 Mtetra
.616 .754 .944 r
.94568 .61581 .94637 .61673 .94826 .61633 .94757 .61542 Mtetra
.797 .819 .868 r
.94757 .61542 .94826 .61633 .95004 .61499 .94935 .61408 Mtetra
.981 .78 .561 r
.94935 .61408 .95004 .61499 .95115 .6083 .95047 .60745 Mtetra
.975 .669 .322 r
.95047 .60745 .95115 .6083 .92807 .40777 .92741 .40683 Mtetra
.967 .787 .607 r
.92741 .40683 .92807 .40777 .92927 .40277 .92861 .40179 Mtetra
.759 .781 .871 r
.92861 .40179 .92927 .40277 .93097 .40173 .93031 .40074 Mtetra
.627 .728 .92 r
.93031 .40074 .93097 .40173 .93275 .40134 .93209 .40035 Mtetra
.544 .688 .933 r
.93209 .40035 .93275 .40134 .93457 .40126 .93391 .40027 Mtetra
.75 .777 .875 r
.93391 .40027 .93457 .40126 .93628 .40027 .93562 .39928 Mtetra
.682 .751 .903 r
.93562 .39928 .93628 .40027 .93803 .39964 .93737 .39864 Mtetra
.488 .657 .935 r
.93737 .39864 .93803 .39964 .93988 .39975 .93922 .39875 Mtetra
.741 .323 0 r
.93922 .39875 .93988 .39975 .94234 .40455 .94168 .40356 Mtetra
.97 .655 .291 r
.94168 .40356 .94234 .40455 .97018 .60466 .9695 .60372 Mtetra
.74 .309 0 r
.9695 .60372 .97018 .60466 .97276 .60942 .97208 .60847 Mtetra
.033 .464 .878 r
.36043 .77297 .36137 .77373 .36285 .77435 .36191 .77359 Mtetra
.644 .762 .935 r
.36191 .77359 .36285 .77435 .36438 .77395 .36344 .77318 Mtetra
.81 .779 .824 r
.36344 .77318 .36438 .77395 .36595 .77252 .36502 .77175 Mtetra
.908 .737 .658 r
.36502 .77175 .36595 .77252 .36769 .76726 .36676 .76649 Mtetra
.937 .686 .534 r
.36676 .76649 .36769 .76726 .37747 .57671 .37659 .57589 Mtetra
.908 .727 .645 r
.37659 .57589 .37747 .57671 .37914 .57105 .37826 .57022 Mtetra
.778 .76 .837 r
.37826 .57022 .37914 .57105 .38062 .56994 .37974 .56912 Mtetra
.643 .736 .917 r
.37974 .56912 .38062 .56994 .38207 .56957 .38119 .56874 Mtetra
.516 .694 .949 r
.38119 .56874 .38207 .56957 .3835 .56955 .38262 .56873 Mtetra
.747 .758 .861 r
.38262 .56873 .3835 .56955 .38497 .56867 .38409 .56785 Mtetra
.699 .75 .891 r
.38409 .56785 .38497 .56867 .38643 .56807 .38555 .56725 Mtetra
.496 .686 .952 r
.38555 .56725 .38643 .56807 .38786 .56809 .38698 .56727 Mtetra
.922 .533 .228 r
.38698 .56727 .38786 .56809 .38915 .57178 .38827 .57099 Mtetra
.939 .683 .522 r
.38827 .57099 .38915 .57178 .38309 .76134 .38216 .76064 Mtetra
.934 .587 .345 r
.38216 .76064 .38309 .76134 .38439 .76692 .38346 .76618 Mtetra
.2 .575 .94 r
.38346 .76618 .38439 .76692 .3859 .76733 .38497 .7666 Mtetra
.669 .776 .93 r
.38497 .7666 .3859 .76733 .38744 .76681 .38651 .76609 Mtetra
.749 .791 .887 r
.38651 .76609 .38744 .76681 .389 .76589 .38807 .7652 Mtetra
.365 .678 .977 r
.38807 .7652 .389 .76589 .39053 .76598 .38959 .76536 Mtetra
.491 .754 .988 r
.38959 .76536 .39053 .76598 .39206 .76583 .39112 .76528 Mtetra
.741 .832 .921 r
.39112 .76528 .39206 .76583 .39362 .76494 .39268 .76446 Mtetra
.924 .763 .663 r
.39268 .76446 .39362 .76494 .39534 .75968 .3944 .7595 Mtetra
.941 .688 .527 r
.3944 .7595 .39534 .75968 .40373 .5679 .40284 .56752 Mtetra
.933 .755 .638 r
.40284 .56752 .40373 .5679 .40537 .56243 .40449 .56168 Mtetra
.818 .775 .812 r
.40449 .56168 .40537 .56243 .40687 .56089 .40599 .5602 Mtetra
.668 .778 .932 r
.40599 .5602 .40687 .56089 .40833 .56038 .40746 .55973 Mtetra
.387 .687 .978 r
.40746 .55973 .40833 .56038 .40977 .56063 .4089 .55985 Mtetra
0 .308 .772 r
.4089 .55985 .40977 .56063 .41116 .56263 .41032 .56072 Mtetra
0 .173 .695 r
.41032 .56072 .41116 .56263 .41237 .5699 .41172 .56247 Mtetra
.372 .26 .596 r
.41172 .56247 .41237 .5699 .40772 .75641 .41306 .56575 Mtetra
.568 .361 .56 r
.41306 .56575 .40772 .75641 .40922 .7576 .4145 .56627 Mtetra
.57 .363 .561 r
.4145 .56627 .40922 .7576 .41077 .75712 .41599 .56531 Mtetra
.569 .362 .56 r
.41599 .56531 .41077 .75712 .41234 .75632 .41745 .56534 Mtetra
0 0 .362 r
.41745 .56534 .41234 .75632 .41385 .75718 .41316 .7491 Mtetra
.088 .05 .515 r
.41316 .7491 .41385 .75718 .41537 .75818 .4145 .75561 Mtetra
0 .116 .642 r
.4145 .75561 .41537 .75818 .41689 .75883 .41597 .75799 Mtetra
.34 .623 .956 r
.41597 .75799 .41689 .75883 .41844 .75876 .41751 .75829 Mtetra
.611 .835 .985 r
.41751 .75829 .41844 .75876 .42 .75838 .41907 .75788 Mtetra
.705 .846 .95 r
.41907 .75788 .42 .75838 .42156 .75787 .42064 .7572 Mtetra
.604 .78 .965 r
.42064 .7572 .42156 .75787 .42312 .75772 .4222 .75688 Mtetra
.62 .741 .933 r
.4222 .75688 .42312 .75772 .42467 .75747 .42376 .75656 Mtetra
.689 .744 .893 r
.42376 .75656 .42467 .75747 .42625 .75674 .42533 .75596 Mtetra
.805 .783 .832 r
.42533 .75596 .42625 .75674 .42787 .75412 .42692 .75458 Mtetra
.926 .97 .761 r
.42692 .75458 .42787 .75412 .4296 .74733 .42854 .75225 Mtetra
.022 0 .247 r
.42854 .75225 .4296 .74733 .43612 .55831 .43021 .74791 Mtetra
0 0 .352 r
.43021 .74791 .43612 .55831 .43769 .55455 .43664 .56088 Mtetra
0 0 .181 r
.43664 .56088 .43769 .55455 .4392 .55283 .43829 .55387 Mtetra
.893 .955 .611 r
.43829 .55387 .4392 .55283 .4407 .55177 .43983 .55107 Mtetra
.778 .793 .865 r
.43983 .55107 .4407 .55177 .44218 .55117 .44133 .55003 Mtetra
.63 .669 .868 r
.44133 .55003 .44218 .55117 .44366 .55085 .44281 .54971 Mtetra
.557 .641 .89 r
.44281 .54971 .44366 .55085 .44514 .55065 .44429 .54968 Mtetra
.616 .699 .903 r
.44429 .54968 .44514 .55065 .44662 .55029 .44577 .54941 Mtetra
.66 .733 .904 r
.44577 .54941 .44662 .55029 .44811 .54981 .44725 .54897 Mtetra
.674 .744 .903 r
.44725 .54897 .44811 .54981 .4496 .54929 .44874 .54846 Mtetra
.726 .759 .88 r
.44874 .54846 .4496 .54929 .45109 .54845 .45024 .54771 Mtetra
.728 .781 .895 r
.45024 .54771 .45109 .54845 .45259 .54767 .45173 .54697 Mtetra
.666 .78 .934 r
.45173 .54697 .45259 .54767 .45407 .54732 .45322 .54649 Mtetra
.361 .623 .952 r
.45322 .54649 .45407 .54732 .45553 .54865 .4547 .54677 Mtetra
.222 .341 .774 r
.4547 .54677 .45553 .54865 .4569 .55391 .45615 .54801 Mtetra
.32 .24 .607 r
.45615 .54801 .4569 .55391 .45467 .74274 .45757 .55116 Mtetra
0 0 .376 r
.45757 .55116 .45467 .74274 .45618 .74613 .45543 .73737 Mtetra
.141 .087 .53 r
.45543 .73737 .45618 .74613 .45773 .74712 .45687 .7441 Mtetra
.159 .216 .673 r
.45687 .7441 .45773 .74712 .4593 .74742 .4584 .74636 Mtetra
.33 .56 .921 r
.4584 .74636 .4593 .74742 .46088 .74729 .45997 .74682 Mtetra
.584 .833 .992 r
.45997 .74682 .46088 .74729 .46246 .74689 .46155 .74646 Mtetra
.692 .868 .965 r
.46155 .74646 .46246 .74689 .46405 .74636 .46314 .7458 Mtetra
.625 .821 .976 r
.46314 .7458 .46405 .74636 .46563 .74612 .46473 .74538 Mtetra
.612 .766 .954 r
.46473 .74538 .46563 .74612 .46721 .7459 .46632 .74505 Mtetra
.684 .758 .907 r
.46632 .74505 .46721 .7459 .46881 .74526 .46791 .74447 Mtetra
.815 .786 .826 r
.46791 .74447 .46881 .74526 .47043 .74289 .46951 .74299 Mtetra
.94 .911 .762 r
.46951 .74299 .47043 .74289 .4721 .73645 .47114 .7404 Mtetra
0 0 .183 r
.47114 .7404 .4721 .73645 .47642 .54654 .47278 .73649 Mtetra
.562 .353 .554 r
.47278 .73649 .47642 .54654 .47796 .54311 .47441 .73288 Mtetra
.567 .356 .555 r
.47441 .73288 .47796 .54311 .47947 .54244 .47601 .73205 Mtetra
.569 .358 .555 r
.47601 .73205 .47947 .54244 .48097 .54245 .47758 .73258 Mtetra
.568 .358 .555 r
.47758 .73258 .48097 .54245 .48247 .54231 .47917 .73266 Mtetra
.567 .357 .555 r
.47917 .73266 .48247 .54231 .48398 .54186 .48076 .73224 Mtetra
.48076 .73224 .48398 .54186 .48549 .54142 .48235 .73181 Mtetra
.48235 .73181 .48549 .54142 .48699 .54094 .48395 .73131 Mtetra
.48395 .73131 .48699 .54094 .4885 .54045 .48555 .73077 Mtetra
.48555 .73077 .4885 .54045 .49001 .53995 .48714 .73021 Mtetra
.48714 .73021 .49001 .53995 .49153 .53945 .48874 .72965 Mtetra
.48874 .72965 .49153 .53945 .49304 .53895 .49034 .72911 Mtetra
.49034 .72911 .49304 .53895 .49455 .53845 .49194 .72858 Mtetra
.49194 .72858 .49455 .53845 .49607 .53796 .49354 .72806 Mtetra
.49354 .72806 .49607 .53796 .49758 .53748 .49514 .72755 Mtetra
.49514 .72755 .49758 .53748 .4991 .53699 .49674 .72705 Mtetra
.49674 .72705 .4991 .53699 .50061 .53651 .49835 .72656 Mtetra
.49835 .72656 .50061 .53651 .50213 .53604 .49995 .72608 Mtetra
.49995 .72608 .50213 .53604 .50365 .53556 .50155 .72561 Mtetra
.50155 .72561 .50365 .53556 .50516 .53509 .50316 .72514 Mtetra
.50316 .72514 .50516 .53509 .50668 .53461 .50477 .72468 Mtetra
.50477 .72468 .50668 .53461 .5082 .53414 .50637 .72422 Mtetra
.50637 .72422 .5082 .53414 .50973 .53367 .50798 .72377 Mtetra
.50798 .72377 .50973 .53367 .51125 .5332 .50959 .72332 Mtetra
.50959 .72332 .51125 .5332 .51277 .53273 .5112 .72287 Mtetra
.5112 .72287 .51277 .53273 .51429 .53226 .51281 .72242 Mtetra
.51281 .72242 .51429 .53226 .51582 .53179 .51442 .72197 Mtetra
.51442 .72197 .51582 .53179 .51734 .53132 .51603 .72152 Mtetra
.51603 .72152 .51734 .53132 .51887 .53084 .51765 .72107 Mtetra
.51765 .72107 .51887 .53084 .5204 .53037 .51926 .72062 Mtetra
.51926 .72062 .5204 .53037 .52192 .5299 .52088 .72017 Mtetra
.52088 .72017 .52192 .5299 .52345 .52942 .52249 .71972 Mtetra
.52249 .71972 .52345 .52942 .52498 .52895 .52411 .71926 Mtetra
.52411 .71926 .52498 .52895 .52651 .52847 .52573 .7188 Mtetra
.52573 .7188 .52651 .52847 .52804 .52799 .52735 .71834 Mtetra
.52735 .71834 .52804 .52799 .52958 .52751 .52897 .71787 Mtetra
.52897 .71787 .52958 .52751 .53111 .52703 .53059 .71741 Mtetra
.53059 .71741 .53111 .52703 .53264 .52654 .53221 .71694 Mtetra
.53221 .71694 .53264 .52654 .53418 .52606 .53384 .71647 Mtetra
.53384 .71647 .53418 .52606 .53571 .52557 .53546 .71601 Mtetra
.53546 .71601 .53571 .52557 .53725 .52508 .53708 .71557 Mtetra
.53708 .71557 .53725 .52508 .53879 .5246 .53871 .71515 Mtetra
.53871 .71515 .53879 .5246 .54032 .52412 .54034 .71472 Mtetra
.568 .358 .555 r
.54034 .71472 .54032 .52412 .54186 .52373 .54197 .71494 Mtetra
.569 .358 .555 r
.54197 .71494 .54186 .52373 .5434 .52345 .5436 .71562 Mtetra
.567 .357 .555 r
.5436 .71562 .5434 .52345 .54494 .52291 .54523 .71478 Mtetra
.547 .341 .553 r
.54523 .71478 .54494 .52291 .54648 .52171 .54679 .70207 Mtetra
0 0 .397 r
.54679 .70207 .54648 .52171 .54801 .51992 .54721 .52199 Mtetra
0 0 0 r
.54721 .52199 .54801 .51992 .54955 .51835 .54873 .51807 Mtetra
.902 .88 .804 r
.54873 .51807 .54955 .51835 .55109 .51719 .55027 .51607 Mtetra
.719 .711 .841 r
.55027 .51607 .55109 .51719 .55263 .5165 .55181 .51527 Mtetra
.663 .672 .849 r
.55181 .51527 .55263 .5165 .55417 .51596 .55335 .51477 Mtetra
.67 .682 .853 r
.55335 .51477 .55417 .51596 .55571 .51535 .5549 .51424 Mtetra
.715 .711 .845 r
.5549 .51424 .55571 .51535 .55726 .51457 .55644 .51346 Mtetra
.639 .685 .877 r
.55644 .51346 .55726 .51457 .5588 .5142 .55799 .51309 Mtetra
.077 .383 .845 r
.55799 .51309 .5588 .5142 .56037 .51522 .55955 .51407 Mtetra
.955 .609 .287 r
.55955 .51407 .56037 .51522 .56202 .52375 .56119 .52173 Mtetra
.961 .687 .471 r
.56119 .52173 .56202 .52375 .5658 .71578 .56493 .71475 Mtetra
0 .058 .586 r
.56493 .71475 .5658 .71578 .56746 .71734 .5666 .71644 Mtetra
.928 .747 .636 r
.5666 .71644 .56746 .71734 .56905 .71176 .56818 .71071 Mtetra
.958 .69 .484 r
.56818 .71071 .56905 .71176 .56817 .51698 .56736 .51588 Mtetra
.906 .734 .657 r
.56736 .51588 .56817 .51698 .56967 .51229 .56886 .51129 Mtetra
.724 .734 .859 r
.56886 .51129 .56967 .51229 .57122 .51148 .57041 .51048 Mtetra
.604 .694 .907 r
.57041 .51048 .57122 .51148 .57278 .51127 .57197 .51025 Mtetra
.576 .679 .91 r
.57197 .51025 .57278 .51127 .57434 .51117 .57353 .51011 Mtetra
.686 .711 .867 r
.57353 .51011 .57434 .51117 .5759 .51063 .57508 .50951 Mtetra
.687 .7 .857 r
.57508 .50951 .5759 .51063 .57745 .51008 .57664 .50889 Mtetra
.681 .688 .85 r
.57664 .50889 .57745 .51008 .57901 .50953 .5782 .5083 Mtetra
.669 .676 .848 r
.5782 .5083 .57901 .50953 .58057 .50902 .57976 .50778 Mtetra
.665 .672 .847 r
.57976 .50778 .58057 .50902 .58213 .50852 .58132 .50727 Mtetra
.675 .676 .843 r
.58132 .50727 .58213 .50852 .58369 .50797 .58288 .5067 Mtetra
.703 .682 .828 r
.58288 .5067 .58369 .50797 .58525 .50733 .58443 .50595 Mtetra
.659 .651 .83 r
.58443 .50595 .58525 .50733 .58681 .5068 .586 .50545 Mtetra
.512 .587 .867 r
.586 .50545 .58681 .5068 .58838 .50658 .58757 .50562 Mtetra
.642 .171 0 r
.58757 .50562 .58838 .50658 .58996 .50709 .58919 .50782 Mtetra
.904 .566 .395 r
.58919 .50782 .58996 .50709 .59156 .50796 .59091 .5149 Mtetra
.95 .673 .478 r
.59091 .5149 .59156 .50796 .59315 .5087 .59627 .70141 Mtetra
.568 .357 .555 r
.59627 .70141 .59315 .5087 .59471 .50775 .59793 .70132 Mtetra
.566 .356 .555 r
.59793 .70132 .59471 .50775 .59627 .5071 .59958 .70026 Mtetra
.568 .358 .555 r
.59958 .70026 .59627 .5071 .59787 .50803 .60127 .70058 Mtetra
.573 .362 .556 r
.60127 .70058 .59787 .50803 .6037 .6975 .60302 .704 Mtetra
.634 .363 .49 r
.60302 .704 .6037 .6975 .60556 .70548 .60474 .70595 Mtetra
.633 .133 .045 r
.60474 .70595 .60556 .70548 .60729 .70773 .60644 .70689 Mtetra
.579 .739 .951 r
.60644 .70689 .60729 .70773 .60897 .70765 .60812 .70666 Mtetra
.664 .733 .901 r
.60812 .70666 .60897 .70765 .61064 .70708 .60979 .70615 Mtetra
.678 .75 .905 r
.60979 .70615 .61064 .70708 .6123 .70633 .61146 .70556 Mtetra
.547 .746 .969 r
.61146 .70556 .6123 .70633 .61398 .70599 .61314 .7054 Mtetra
.614 .818 .979 r
.61314 .7054 .61398 .70599 .61565 .70552 .61482 .70498 Mtetra
.763 .861 .922 r
.61482 .70498 .61565 .70552 .61732 .70484 .61648 .704 Mtetra
.889 .786 .741 r
.61648 .704 .61732 .70484 .61899 .70376 .6181 .70126 Mtetra
.859 .663 .636 r
.6181 .70126 .61899 .70376 .62063 .70208 .61964 .69564 Mtetra
.956 .683 .477 r
.61964 .69564 .62063 .70208 .62223 .69896 .61609 .50445 Mtetra
.578 .369 .561 r
.61609 .50445 .62223 .69896 .61858 .50907 .61753 .49905 Mtetra
.642 .449 .606 r
.61753 .49905 .61858 .50907 .6199 .49897 .61906 .49652 Mtetra
.721 .592 .712 r
.61906 .49652 .6199 .49897 .62141 .49592 .62061 .49499 Mtetra
.687 .741 .892 r
.62061 .49499 .62141 .49592 .62298 .49513 .62219 .4944 Mtetra
.599 .761 .956 r
.62219 .4944 .62298 .49513 .62457 .49484 .62378 .4941 Mtetra
.566 .75 .964 r
.62378 .4941 .62457 .49484 .62617 .49474 .62538 .4939 Mtetra
.751 .779 .876 r
.62538 .4939 .62617 .49474 .62774 .49383 .62695 .49298 Mtetra
.686 .761 .909 r
.62695 .49298 .62774 .49383 .62932 .49326 .62853 .49239 Mtetra
.436 .655 .952 r
.62853 .49239 .62932 .49326 .63093 .49345 .63014 .49256 Mtetra
.908 .505 .12 r
.63014 .49256 .63093 .49345 .63269 .49813 .6319 .49725 Mtetra
.966 .684 .449 r
.6319 .49725 .63269 .49813 .64071 .69298 .63988 .69213 Mtetra
.902 .491 .11 r
.63988 .69213 .64071 .69298 .64257 .69764 .64174 .69679 Mtetra
.18 .529 .922 r
.64174 .69679 .64257 .69764 .6443 .69826 .64347 .6974 Mtetra
.644 .759 .933 r
.64347 .6974 .6443 .69826 .646 .69781 .64517 .69695 Mtetra
.817 .795 .831 r
.64517 .69695 .646 .69781 .64766 .6963 .64682 .69544 Mtetra
.939 .76 .634 r
.64682 .69544 .64766 .6963 .64917 .69081 .64834 .68991 Mtetra
.966 .69 .458 r
.64834 .68991 .64917 .69081 .64386 .49502 .64307 .49407 Mtetra
.936 .746 .622 r
.64307 .49407 .64386 .49502 .64527 .48922 .64448 .48829 Mtetra
.772 .767 .848 r
.64448 .48829 .64527 .48922 .64684 .4881 .64606 .48718 Mtetra
.641 .731 .914 r
.64606 .48718 .64684 .4881 .64844 .4877 .64766 .48678 Mtetra
.529 .687 .939 r
.64766 .48678 .64844 .4877 .65006 .48766 .64927 .48675 Mtetra
.75 .765 .865 r
.64927 .48675 .65006 .48766 .65164 .48671 .65086 .4858 Mtetra
.692 .75 .896 r
.65086 .4858 .65164 .48671 .65323 .48609 .65245 .48518 Mtetra
.494 .673 .944 r
.65245 .48518 .65323 .48609 .65486 .48614 .65408 .48523 Mtetra
.885 .469 .056 r
.65408 .48523 .65486 .48614 .65665 .49044 .65587 .48954 Mtetra
.968 .684 .44 r
.65587 .48954 .65665 .49044 .66613 .68558 .66531 .68473 Mtetra
.906 .5 .118 r
.66531 .68473 .66613 .68558 .66806 .6906 .66724 .68974 Mtetra
.102 .478 .896 r
.66724 .68974 .66806 .6906 .66981 .69135 .66899 .6905 Mtetra
.625 .755 .94 r
.66899 .6905 .66981 .69135 .67153 .69096 .67071 .69011 Mtetra
.807 .799 .844 r
.67071 .69011 .67153 .69096 .6732 .68956 .67238 .6887 Mtetra
.936 .769 .649 r
.67238 .6887 .6732 .68956 .67472 .68467 .6739 .68382 Mtetra
.968 .69 .449 r
.6739 .68382 .67472 .68467 .66799 .48894 .66721 .48802 Mtetra
.947 .746 .599 r
.66721 .48802 .66799 .48894 .66933 .48222 .66856 .48131 Mtetra
.795 .775 .835 r
.66856 .48131 .66933 .48222 .67091 .48093 .67013 .48002 Mtetra
.628 .729 .92 r
.67013 .48002 .67091 .48093 .67252 .48058 .67175 .47966 Mtetra
.492 .671 .943 r
.67175 .47966 .67252 .48058 .67416 .48064 .67339 .47973 Mtetra
.637 .733 .918 r
.67339 .47973 .67416 .48064 .67578 .48024 .67501 .47933 Mtetra
.661 .742 .91 r
.67501 .47933 .67578 .48024 .67739 .47975 .67662 .47885 Mtetra
.667 .745 .909 r
.67662 .47885 .67739 .47975 .67901 .47924 .67824 .47833 Mtetra
.761 .772 .862 r
.67824 .47833 .67901 .47924 .6806 .47821 .67983 .47731 Mtetra
.718 .762 .887 r
.67983 .47731 .6806 .47821 .6822 .47746 .68144 .47655 Mtetra
.546 .699 .94 r
.68144 .47655 .6822 .47746 .68384 .47736 .68307 .47646 Mtetra
.841 .407 0 r
.68307 .47646 .68384 .47736 .68567 .48109 .6849 .48021 Mtetra
.97 .683 .428 r
.6849 .48021 .68567 .48109 .69692 .67647 .69611 .67566 Mtetra
.912 .511 .133 r
.69611 .67566 .69692 .67647 .69894 .68198 .69813 .68114 Mtetra
0 .395 .845 r
.69813 .68114 .69894 .68198 .70073 .68295 .69993 .6821 Mtetra
.61 .752 .945 r
.69993 .6821 .70073 .68295 .70247 .68262 .70166 .68176 Mtetra
.805 .801 .847 r
.70166 .68176 .70247 .68262 .70415 .68125 .70334 .68037 Mtetra
.939 .771 .646 r
.70334 .68037 .70415 .68125 .70566 .67648 .70485 .67545 Mtetra
.971 .689 .438 r
.70485 .67545 .70566 .67648 .69714 .47964 .69635 .47824 Mtetra
.927 .723 .608 r
.69635 .47824 .69714 .47964 .69845 .47292 .69767 .47181 Mtetra
.795 .743 .806 r
.69767 .47181 .69845 .47292 .70002 .47143 .69925 .47037 Mtetra
.623 .697 .898 r
.69925 .47037 .70002 .47143 .70165 .47105 .70089 .47004 Mtetra
.49 .648 .928 r
.70089 .47004 .70165 .47105 .70331 .47111 .70255 .47015 Mtetra
.653 .731 .906 r
.70255 .47015 .70331 .47111 .70494 .47051 .70418 .4697 Mtetra
.677 .774 .923 r
.70418 .4697 .70494 .47051 .70656 .46988 .70581 .46913 Mtetra
.609 .768 .956 r
.70581 .46913 .70656 .46988 .70821 .46969 .70745 .4688 Mtetra
.348 .602 .942 r
.70745 .4688 .70821 .46969 .70997 .47148 .70914 .46918 Mtetra
.341 .381 .758 r
.70914 .46918 .70997 .47148 .71208 .47938 .71087 .47048 Mtetra
.429 .302 .605 r
.71087 .47048 .71208 .47938 .72468 .67052 .71274 .47399 Mtetra
.102 .019 .467 r
.71274 .47399 .72468 .67052 .7266 .67314 .7254 .66527 Mtetra
.257 .191 .589 r
.7254 .66527 .7266 .67314 .72842 .67398 .7275 .67101 Mtetra
.268 .301 .711 r
.7275 .67101 .72842 .67398 .7302 .67418 .7294 .67311 Mtetra
.372 .586 .927 r
.7294 .67311 .7302 .67418 .73198 .67423 .7312 .67354 Mtetra
.601 .793 .973 r
.7312 .67354 .73198 .67423 .73374 .67393 .73295 .67317 Mtetra
.742 .818 .911 r
.73295 .67317 .73374 .67393 .73546 .67303 .73467 .67226 Mtetra
.831 .826 .843 r
.73467 .67226 .73546 .67303 .73707 .67027 .73636 .6707 Mtetra
.884 .977 .677 r
.73636 .6707 .73707 .67027 .7384 .66297 .73798 .66821 Mtetra
.157 0 .353 r
.73798 .66821 .7384 .66297 .72816 .4685 .73948 .66355 Mtetra
.101 .015 .461 r
.73948 .66355 .72816 .4685 .7296 .46464 .7293 .47088 Mtetra
.016 0 .332 r
.7293 .47088 .7296 .46464 .73117 .46287 .73054 .46393 Mtetra
.705 .835 .395 r
.73054 .46393 .73117 .46287 .73277 .46175 .73204 .46104 Mtetra
.79 .827 .88 r
.73204 .46104 .73277 .46175 .73441 .4611 .73365 .4599 Mtetra
.635 .676 .872 r
.73365 .4599 .73441 .4611 .73607 .46071 .7353 .45952 Mtetra
.573 .651 .889 r
.7353 .45952 .73607 .46071 .73773 .46043 .73698 .45942 Mtetra
.64 .715 .901 r
.73698 .45942 .73773 .46043 .73938 .45995 .73863 .45901 Mtetra
.69 .75 .898 r
.73863 .45901 .73938 .45995 .74102 .45932 .74028 .45838 Mtetra
.694 .752 .896 r
.74028 .45838 .74102 .45932 .74267 .45868 .74192 .45773 Mtetra
.707 .754 .889 r
.74192 .45773 .74267 .45868 .7443 .45788 .74356 .45702 Mtetra
.693 .77 .911 r
.74356 .45702 .7443 .45788 .74594 .45717 .74521 .45638 Mtetra
.624 .764 .946 r
.74521 .45638 .74594 .45717 .74761 .45689 .74687 .456 Mtetra
.389 .626 .948 r
.74687 .456 .74761 .45689 .74939 .45818 .74858 .45629 Mtetra
.297 .393 .792 r
.74858 .45629 .74939 .45818 .75143 .46331 .75036 .45753 Mtetra
.363 .284 .632 r
.75036 .45753 .75143 .46331 .76664 .6578 .75227 .46068 Mtetra
.122 .037 .477 r
.75227 .46068 .76664 .6578 .76869 .66148 .76732 .65212 Mtetra
.251 .179 .577 r
.76732 .65212 .76869 .66148 .77057 .66252 .76962 .65922 Mtetra
.278 .293 .697 r
.76962 .65922 .77057 .66252 .77239 .66281 .77159 .66156 Mtetra
.349 .534 .895 r
.77159 .66156 .77239 .66281 .7742 .66289 .77344 .66218 Mtetra
.57 .779 .977 r
.77344 .66218 .7742 .66289 .776 .66267 .77523 .6619 Mtetra
.723 .815 .922 r
.77523 .6619 .776 .66267 .77775 .66189 .77698 .66108 Mtetra
.814 .822 .856 r
.77698 .66108 .77775 .66189 .77939 .65957 .77869 .65965 Mtetra
.914 .979 .766 r
.77869 .65965 .77939 .65957 .78078 .65386 .78033 .65739 Mtetra
.035 0 .255 r
.78033 .65739 .78078 .65386 .76808 .45809 .78185 .65344 Mtetra
.129 .038 .475 r
.78185 .65344 .76808 .45809 .7694 .45294 .76951 .46338 Mtetra
.082 0 .403 r
.76951 .46338 .7694 .45294 .77096 .45094 .77041 .45246 Mtetra
0 0 0 r
.77041 .45246 .77096 .45094 .77257 .44968 .77187 .44915 Mtetra
.84 .881 .872 r
.77187 .44915 .77257 .44968 .77422 .44893 .77347 .44773 Mtetra
.651 .687 .871 r
.77347 .44773 .77422 .44893 .7759 .44848 .77515 .44728 Mtetra
.587 .656 .885 r
.77515 .44728 .7759 .44848 .77758 .44816 .77685 .44711 Mtetra
.631 .707 .901 r
.77685 .44711 .77758 .44816 .77926 .44768 .77853 .44674 Mtetra
.695 .756 .899 r
.77853 .44674 .77926 .44768 .78092 .44701 .78019 .44608 Mtetra
.7 .759 .898 r
.78019 .44608 .78092 .44701 .78258 .44633 .78185 .4454 Mtetra
.71 .762 .893 r
.78185 .4454 .78258 .44633 .78423 .44552 .78351 .44466 Mtetra
.703 .777 .909 r
.78351 .44466 .78423 .44552 .78589 .44474 .78518 .44396 Mtetra
.644 .779 .945 r
.78518 .44396 .78589 .44474 .78758 .44434 .78686 .4435 Mtetra
.458 .678 .96 r
.78686 .4435 .78758 .44434 .78936 .44518 .78859 .4436 Mtetra
.322 .449 .834 r
.78859 .4436 .78936 .44518 .79138 .44882 .79039 .44456 Mtetra
.369 .316 .667 r
.79039 .44456 .79138 .44882 .80903 .64307 .7923 .44689 Mtetra
.166 .071 .494 r
.7923 .44689 .80903 .64307 .81134 .64889 .80896 .62825 Mtetra
.197 .115 .531 r
.80896 .62825 .81134 .64889 .81329 .65024 .81228 .64633 Mtetra
.27 .267 .672 r
.81228 .64633 .81329 .65024 .81516 .65065 .81436 .64923 Mtetra
.33 .493 .87 r
.81436 .64923 .81516 .65065 .817 .65067 .81627 .65004 Mtetra
.583 .811 .986 r
.81627 .65004 .817 .65067 .81881 .65036 .81807 .64967 Mtetra
.748 .846 .924 r
.81807 .64967 .81881 .65036 .82058 .64947 .81984 .64872 Mtetra
.827 .841 .858 r
.81984 .64872 .82058 .64947 .82222 .64716 .82155 .64722 Mtetra
.907 .983 .765 r
.82155 .64722 .82222 .64716 .82352 .64079 .8232 .64499 Mtetra
.161 0 .334 r
.8232 .64499 .82352 .64079 .80837 .44498 .82471 .64107 Mtetra
.148 .055 .485 r
.82471 .64107 .80837 .44498 .8097 .44023 .80997 .45067 Mtetra
.124 0 .421 r
.80997 .45067 .8097 .44023 .81127 .43832 .81079 .44013 Mtetra
0 0 0 r
.81079 .44013 .81127 .43832 .8129 .43712 .81224 .43678 Mtetra
.866 .937 .866 r
.81224 .43678 .8129 .43712 .81457 .43638 .81384 .43522 Mtetra
.648 .694 .879 r
.81384 .43522 .81457 .43638 .81628 .43599 .81554 .43477 Mtetra
.569 .646 .886 r
.81554 .43477 .81628 .43599 .818 .43578 .81728 .43468 Mtetra
.563 .667 .908 r
.81728 .43468 .818 .43578 .81972 .43554 .81901 .43458 Mtetra
.625 .727 .92 r
.81901 .43458 .81972 .43554 .82143 .43515 .82072 .43421 Mtetra
.632 .735 .922 r
.82072 .43421 .82143 .43515 .82314 .43474 .82243 .43382 Mtetra
.637 .742 .924 r
.82243 .43382 .82314 .43474 .82485 .4343 .82414 .4334 Mtetra
.64 .748 .927 r
.82414 .4334 .82485 .4343 .82656 .43385 .82585 .43297 Mtetra
.647 .754 .928 r
.82585 .43297 .82656 .43385 .82826 .43338 .82756 .43251 Mtetra
.653 .759 .928 r
.82756 .43251 .82826 .43338 .82997 .43289 .82927 .43202 Mtetra
.66 .763 .926 r
.82927 .43202 .82997 .43289 .83167 .43238 .83097 .4315 Mtetra
.671 .766 .922 r
.83097 .4315 .83167 .43238 .83338 .43183 .83268 .43094 Mtetra
.689 .769 .913 r
.83268 .43094 .83338 .43183 .83507 .43123 .83437 .4303 Mtetra
.706 .767 .9 r
.83437 .4303 .83507 .43123 .83677 .43056 .83606 .42958 Mtetra
.703 .754 .891 r
.83606 .42958 .83677 .43056 .83846 .42989 .83775 .42886 Mtetra
.691 .739 .888 r
.83775 .42886 .83846 .42989 .84016 .42926 .83945 .4282 Mtetra
.672 .725 .889 r
.83945 .4282 .84016 .42926 .84187 .4287 .84115 .42763 Mtetra
.661 .718 .891 r
.84115 .42763 .84187 .4287 .84358 .42818 .84286 .42711 Mtetra
.644 .712 .897 r
.84286 .42711 .84358 .42818 .84529 .42772 .84458 .42667 Mtetra
.624 .709 .907 r
.84458 .42667 .84529 .42772 .84702 .42732 .84631 .42632 Mtetra
.618 .717 .917 r
.84631 .42632 .84702 .42732 .84875 .42693 .84805 .42599 Mtetra
.628 .735 .924 r
.84805 .42599 .84875 .42693 .85047 .42649 .84978 .4256 Mtetra
.652 .757 .926 r
.84978 .4256 .85047 .42649 .85219 .42598 .8515 .42512 Mtetra
.664 .768 .927 r
.8515 .42512 .85219 .42598 .8539 .42543 .85321 .42458 Mtetra
.671 .775 .928 r
.85321 .42458 .8539 .42543 .85561 .42485 .85493 .42401 Mtetra
.675 .779 .928 r
.85493 .42401 .85561 .42485 .85733 .42426 .85664 .42342 Mtetra
.687 .785 .925 r
.85664 .42342 .85733 .42426 .85903 .42362 .85835 .42279 Mtetra
.706 .791 .917 r
.85835 .42279 .85903 .42362 .86074 .42292 .86005 .42206 Mtetra
.729 .793 .903 r
.86005 .42206 .86074 .42292 .86243 .42213 .86174 .42123 Mtetra
.726 .782 .897 r
.86174 .42123 .86243 .42213 .86413 .42134 .86344 .4204 Mtetra
.736 .776 .885 r
.86344 .4204 .86413 .42134 .86582 .42047 .86512 .4195 Mtetra
.755 .775 .869 r
.86512 .4195 .86582 .42047 .86749 .41947 .86679 .41848 Mtetra
.674 .744 .903 r
.86679 .41848 .86749 .41947 .86921 .41889 .86852 .4179 Mtetra
.325 .563 .924 r
.86852 .4179 .86921 .41889 .87105 .41943 .87036 .41844 Mtetra
.8 .382 0 r
.87036 .41844 .87105 .41943 .87335 .42427 .87267 .42336 Mtetra
.975 .667 .335 r
.87267 .42336 .87335 .42427 .89663 .62348 .89593 .6227 Mtetra
.779 .33 0 r
.89593 .6227 .89663 .62348 .89899 .62772 .89828 .62689 Mtetra
.474 .705 .97 r
.89828 .62689 .89899 .62772 .9009 .62776 .90019 .62692 Mtetra
.692 .799 .931 r
.90019 .62692 .9009 .62776 .90273 .62706 .90202 .62621 Mtetra
.71 .804 .923 r
.90202 .62621 .90273 .62706 .90455 .62627 .90384 .62541 Mtetra
.466 .695 .967 r
.90384 .62541 .90455 .62627 .90647 .62634 .90576 .62548 Mtetra
.627 .771 .949 r
.90576 .62548 .90647 .62634 .90833 .6259 .90762 .62504 Mtetra
.85 .833 .83 r
.90762 .62504 .90833 .6259 .91004 .62412 .90933 .62326 Mtetra
.984 .759 .517 r
.90933 .62326 .91004 .62412 .91095 .61518 .91025 .61432 Mtetra
.977 .675 .344 r
.91025 .61432 .91095 .61518 .89045 .41657 .88976 .41553 Mtetra
.939 .784 .661 r
.88976 .41553 .89045 .41657 .8918 .41262 .89111 .41159 Mtetra
.708 .749 .884 r
.89111 .41159 .8918 .41262 .89351 .41185 .89283 .41083 Mtetra
.564 .691 .925 r
.89283 .41083 .89351 .41185 .8953 .41169 .89461 .4107 Mtetra
.493 .66 .935 r
.89461 .4107 .8953 .41169 .89711 .41175 .89643 .41078 Mtetra
.652 .742 .915 r
.89643 .41078 .89711 .41175 .89886 .41127 .89818 .41029 Mtetra
.666 .746 .91 r
.89818 .41029 .89886 .41127 .9006 .41073 .89992 .40975 Mtetra
.691 .754 .899 r
.89992 .40975 .9006 .41073 .90233 .41008 .90165 .40908 Mtetra
.76 .775 .865 r
.90165 .40908 .90233 .41008 .90402 .40902 .90334 .40802 Mtetra
.69 .749 .896 r
.90334 .40802 .90402 .40902 .90575 .40836 .90507 .40735 Mtetra
.434 .623 .932 r
.90507 .40735 .90575 .40836 .90759 .40864 .90691 .40762 Mtetra
.777 .362 0 r
.90691 .40762 .90759 .40864 .91001 .41372 .90933 .41267 Mtetra
.973 .661 .312 r
.90933 .41267 .91001 .41372 .93567 .6131 .93496 .61212 Mtetra
.722 .287 0 r
.93496 .61212 .93567 .6131 .93812 .6174 .93741 .61646 Mtetra
.491 .687 .954 r
.93741 .61646 .93812 .6174 .94006 .61744 .93935 .6165 Mtetra
.687 .779 .921 r
.93935 .6165 .94006 .61744 .94191 .61674 .94121 .61581 Mtetra
.738 .798 .901 r
.94121 .61581 .94191 .61674 .94373 .61578 .94303 .61486 Mtetra
.486 .69 .958 r
.94303 .61486 .94373 .61578 .94568 .61581 .94498 .6149 Mtetra
.615 .754 .945 r
.94498 .6149 .94568 .61581 .94757 .61542 .94687 .61451 Mtetra
.797 .819 .87 r
.94687 .61451 .94757 .61542 .94935 .61408 .94866 .61318 Mtetra
.98 .78 .563 r
.94866 .61318 .94935 .61408 .95047 .60745 .94979 .60661 Mtetra
.975 .669 .322 r
.94979 .60661 .95047 .60745 .92741 .40683 .92675 .40589 Mtetra
.968 .787 .605 r
.92675 .40589 .92741 .40683 .92861 .40179 .92794 .40081 Mtetra
.76 .782 .872 r
.92794 .40081 .92861 .40179 .93031 .40074 .92964 .39975 Mtetra
.628 .73 .921 r
.92964 .39975 .93031 .40074 .93209 .40035 .93142 .39936 Mtetra
.544 .689 .934 r
.93142 .39936 .93209 .40035 .93391 .40027 .93325 .39928 Mtetra
.75 .778 .875 r
.93325 .39928 .93391 .40027 .93562 .39928 .93495 .39828 Mtetra
.683 .752 .904 r
.93495 .39828 .93562 .39928 .93737 .39864 .93671 .39765 Mtetra
.488 .658 .936 r
.93671 .39765 .93737 .39864 .93922 .39875 .93856 .39775 Mtetra
.742 .324 0 r
.93856 .39775 .93922 .39875 .94168 .40356 .94102 .40257 Mtetra
.97 .655 .291 r
.94102 .40257 .94168 .40356 .9695 .60372 .96881 .60278 Mtetra
.74 .309 0 r
.96881 .60278 .9695 .60372 .97208 .60847 .97139 .60753 Mtetra
.033 .465 .878 r
.35949 .77221 .36043 .77297 .36191 .77359 .36097 .77283 Mtetra
.644 .762 .935 r
.36097 .77283 .36191 .77359 .36344 .77318 .3625 .77242 Mtetra
.81 .779 .824 r
.3625 .77242 .36344 .77318 .36502 .77175 .36408 .77099 Mtetra
.908 .737 .658 r
.36408 .77099 .36502 .77175 .36676 .76649 .36582 .76573 Mtetra
.937 .686 .534 r
.36582 .76573 .36676 .76649 .37659 .57589 .37571 .57508 Mtetra
.909 .727 .645 r
.37571 .57508 .37659 .57589 .37826 .57022 .37738 .5694 Mtetra
.778 .76 .837 r
.37738 .5694 .37826 .57022 .37974 .56912 .37886 .56829 Mtetra
.643 .737 .917 r
.37886 .56829 .37974 .56912 .38119 .56874 .38031 .56792 Mtetra
.515 .694 .949 r
.38031 .56792 .38119 .56874 .38262 .56873 .38174 .5679 Mtetra
.747 .758 .861 r
.38174 .5679 .38262 .56873 .38409 .56785 .38321 .56703 Mtetra
.699 .751 .892 r
.38321 .56703 .38409 .56785 .38555 .56725 .38467 .56643 Mtetra
.493 .686 .953 r
.38467 .56643 .38555 .56725 .38698 .56727 .38611 .56646 Mtetra
.922 .535 .231 r
.38611 .56646 .38698 .56727 .38827 .57099 .38739 .5702 Mtetra
.939 .683 .522 r
.38739 .5702 .38827 .57099 .38216 .76064 .38122 .75995 Mtetra
.934 .586 .345 r
.38122 .75995 .38216 .76064 .38346 .76618 .38252 .76545 Mtetra
.176 .562 .933 r
.38252 .76545 .38346 .76618 .38497 .7666 .38403 .76589 Mtetra
.663 .782 .937 r
.38403 .76589 .38497 .7666 .38651 .76609 .38558 .7654 Mtetra
.751 .799 .891 r
.38558 .7654 .38651 .76609 .38807 .7652 .38714 .76451 Mtetra
.464 .722 .981 r
.38714 .76451 .38807 .7652 .38959 .76536 .38867 .76451 Mtetra
.593 .728 .938 r
.38867 .76451 .38959 .76536 .39112 .76528 .3902 .76428 Mtetra
.74 .735 .846 r
.3902 .76428 .39112 .76528 .39268 .76446 .39177 .76335 Mtetra
.891 .72 .663 r
.39177 .76335 .39268 .76446 .3944 .7595 .39348 .75845 Mtetra
.939 .687 .528 r
.39348 .75845 .3944 .7595 .40284 .56752 .40194 .56723 Mtetra
.937 .76 .636 r
.40194 .56723 .40284 .56752 .40449 .56168 .40361 .5613 Mtetra
.84 .859 .858 r
.40361 .5613 .40449 .56168 .40599 .5602 .4051 .55993 Mtetra
.591 .879 .993 r
.4051 .55993 .40599 .5602 .40746 .55973 .40657 .5595 Mtetra
.224 .716 .92 r
.40657 .5595 .40746 .55973 .4089 .55985 .40802 .55949 Mtetra
.419 .791 .994 r
.40802 .55949 .4089 .55985 .41032 .56072 .40947 .55938 Mtetra
.585 .616 .85 r
.40947 .55938 .41032 .56072 .41172 .56247 .41093 .55927 Mtetra
.588 .481 .7 r
.41093 .55927 .41172 .56247 .41306 .56575 .41239 .55917 Mtetra
.61 .442 .63 r
.41239 .55917 .41306 .56575 .4145 .56627 .41386 .55841 Mtetra
.6 .427 .619 r
.41386 .55841 .4145 .56627 .41599 .56531 .41534 .55776 Mtetra
.577 .411 .62 r
.41534 .55776 .41599 .56531 .41745 .56534 .4168 .55772 Mtetra
.35 .243 .589 r
.4168 .55772 .41745 .56534 .41316 .7491 .41814 .56135 Mtetra
0 0 .339 r
.41814 .56135 .41316 .7491 .4145 .75561 .41369 .7512 Mtetra
0 0 .397 r
.41369 .7512 .4145 .75561 .41597 .75799 .41507 .75651 Mtetra
.321 .473 .856 r
.41507 .75651 .41597 .75799 .41751 .75829 .4166 .75723 Mtetra
.64 .7 .889 r
.4166 .75723 .41751 .75829 .41907 .75788 .41816 .75685 Mtetra
.716 .727 .859 r
.41816 .75685 .41907 .75788 .42064 .7572 .41973 .75608 Mtetra
.661 .694 .87 r
.41973 .75608 .42064 .7572 .4222 .75688 .4213 .7556 Mtetra
.644 .662 .853 r
.4213 .7556 .4222 .75688 .42376 .75656 .42286 .75521 Mtetra
.655 .656 .838 r
.42286 .75521 .42376 .75656 .42533 .75596 .42443 .75474 Mtetra
.628 .666 .867 r
.42443 .75474 .42533 .75596 .42692 .75458 .42599 .75441 Mtetra
.595 .91 .98 r
.42599 .75441 .42692 .75458 .42854 .75225 .42756 .75386 Mtetra
.127 0 .034 r
.42756 .75386 .42854 .75225 .43021 .74791 .42915 .75268 Mtetra
0 0 .211 r
.42915 .75268 .43021 .74791 .43664 .56088 .43082 .74816 Mtetra
0 0 .336 r
.43082 .74816 .43664 .56088 .43829 .55387 .43732 .5573 Mtetra
.777 .767 .258 r
.43732 .5573 .43829 .55387 .43983 .55107 .43896 .55098 Mtetra
.883 .921 .845 r
.43896 .55098 .43983 .55107 .44133 .55003 .44047 .54934 Mtetra
.667 .783 .935 r
.44047 .54934 .44133 .55003 .44281 .54971 .44195 .54886 Mtetra
.547 .701 .941 r
.44195 .54886 .44281 .54971 .44429 .54968 .44343 .54878 Mtetra
.619 .715 .914 r
.44343 .54878 .44429 .54968 .44577 .54941 .44491 .54849 Mtetra
.656 .722 .897 r
.44491 .54849 .44577 .54941 .44725 .54897 .4464 .54806 Mtetra
.66 .727 .899 r
.4464 .54806 .44725 .54897 .44874 .54846 .44789 .54762 Mtetra
.681 .747 .9 r
.44789 .54762 .44874 .54846 .45024 .54771 .44938 .54709 Mtetra
.686 .802 .937 r
.44938 .54709 .45024 .54771 .45173 .54697 .45087 .54653 Mtetra
.653 .849 .975 r
.45087 .54653 .45173 .54697 .45322 .54649 .45236 .54603 Mtetra
.683 .85 .963 r
.45236 .54603 .45322 .54649 .4547 .54677 .45385 .54546 Mtetra
.643 .647 .839 r
.45385 .54546 .4547 .54677 .45615 .54801 .45534 .54507 Mtetra
.555 .471 .715 r
.45534 .54507 .45615 .54801 .45757 .55116 .45682 .54526 Mtetra
.335 .251 .611 r
.45682 .54526 .45757 .55116 .45543 .73737 .45825 .54828 Mtetra
0 0 .363 r
.45825 .54828 .45543 .73737 .45687 .7441 .45606 .73837 Mtetra
0 0 .448 r
.45606 .73837 .45687 .7441 .4584 .74636 .45751 .74462 Mtetra
.236 .383 .808 r
.45751 .74462 .4584 .74636 .45997 .74682 .45907 .74572 Mtetra
.628 .689 .888 r
.45907 .74572 .45997 .74682 .46155 .74646 .46065 .74539 Mtetra
.713 .721 .856 r
.46065 .74539 .46155 .74646 .46314 .7458 .46225 .74462 Mtetra
.676 .692 .857 r
.46225 .74462 .46314 .7458 .46473 .74538 .46384 .74405 Mtetra
.64 .656 .85 r
.46384 .74405 .46473 .74538 .46632 .74505 .46542 .74366 Mtetra
.65 .652 .838 r
.46542 .74366 .46632 .74505 .46791 .74447 .46701 .74322 Mtetra
.685 .684 .843 r
.46701 .74322 .46791 .74447 .46951 .74299 .46861 .74258 Mtetra
.726 .878 .951 r
.46861 .74258 .46951 .74299 .47114 .7404 .4702 .74179 Mtetra
.232 0 .051 r
.4702 .74179 .47114 .7404 .47278 .73649 .4718 .74099 Mtetra
.501 .225 .427 r
.4718 .74099 .47278 .73649 .47441 .73288 .4734 .74038 Mtetra
.539 .288 .484 r
.4734 .74038 .47441 .73288 .47601 .73205 .47499 .73995 Mtetra
.543 .294 .488 r
.47499 .73995 .47601 .73205 .47758 .73258 .47658 .73957 Mtetra
.538 .284 .479 r
.47658 .73957 .47758 .73258 .47917 .73266 .47818 .73917 Mtetra
.533 .277 .472 r
.47818 .73917 .47917 .73266 .48076 .73224 .47977 .73873 Mtetra
.533 .276 .472 r
.47977 .73873 .48076 .73224 .48235 .73181 .48137 .73829 Mtetra
.532 .275 .471 r
.48137 .73829 .48235 .73181 .48395 .73131 .48297 .73783 Mtetra
.532 .275 .472 r
.48297 .73783 .48395 .73131 .48555 .73077 .48457 .73737 Mtetra
.532 .276 .473 r
.48457 .73737 .48555 .73077 .48714 .73021 .48617 .7369 Mtetra
.533 .277 .474 r
.48617 .7369 .48714 .73021 .48874 .72965 .48777 .73643 Mtetra
.533 .279 .475 r
.48777 .73643 .48874 .72965 .49034 .72911 .48937 .73596 Mtetra
.534 .28 .476 r
.48937 .73596 .49034 .72911 .49194 .72858 .49098 .7355 Mtetra
.535 .281 .477 r
.49098 .7355 .49194 .72858 .49354 .72806 .49258 .73504 Mtetra
.535 .282 .478 r
.49258 .73504 .49354 .72806 .49514 .72755 .49418 .73458 Mtetra
.49418 .73458 .49514 .72755 .49674 .72705 .49579 .73413 Mtetra
.536 .283 .479 r
.49579 .73413 .49674 .72705 .49835 .72656 .4974 .73368 Mtetra
.4974 .73368 .49835 .72656 .49995 .72608 .499 .73323 Mtetra
.536 .284 .48 r
.499 .73323 .49995 .72608 .50155 .72561 .50061 .73279 Mtetra
.537 .284 .48 r
.50061 .73279 .50155 .72561 .50316 .72514 .50222 .73234 Mtetra
.537 .285 .48 r
.50222 .73234 .50316 .72514 .50477 .72468 .50383 .7319 Mtetra
.537 .285 .481 r
.50383 .7319 .50477 .72468 .50637 .72422 .50544 .73146 Mtetra
.50544 .73146 .50637 .72422 .50798 .72377 .50706 .73102 Mtetra
.50706 .73102 .50798 .72377 .50959 .72332 .50867 .73058 Mtetra
.50867 .73058 .50959 .72332 .5112 .72287 .51028 .73014 Mtetra
.51028 .73014 .5112 .72287 .51281 .72242 .5119 .7297 Mtetra
.5119 .7297 .51281 .72242 .51442 .72197 .51351 .72926 Mtetra
.537 .286 .481 r
.51351 .72926 .51442 .72197 .51603 .72152 .51513 .72882 Mtetra
.51513 .72882 .51603 .72152 .51765 .72107 .51675 .72838 Mtetra
.51675 .72838 .51765 .72107 .51926 .72062 .51837 .72794 Mtetra
.537 .286 .482 r
.51837 .72794 .51926 .72062 .52088 .72017 .51999 .72749 Mtetra
.538 .286 .482 r
.51999 .72749 .52088 .72017 .52249 .71972 .52161 .72705 Mtetra
.52161 .72705 .52249 .71972 .52411 .71926 .52323 .72661 Mtetra
.52323 .72661 .52411 .71926 .52573 .7188 .52485 .72617 Mtetra
.52485 .72617 .52573 .7188 .52735 .71834 .52648 .72572 Mtetra
.52648 .72572 .52735 .71834 .52897 .71787 .5281 .72528 Mtetra
.538 .287 .482 r
.5281 .72528 .52897 .71787 .53059 .71741 .52973 .72484 Mtetra
.538 .287 .483 r
.52973 .72484 .53059 .71741 .53221 .71694 .53135 .72439 Mtetra
.53135 .72439 .53221 .71694 .53384 .71647 .53298 .72395 Mtetra
.538 .288 .483 r
.53298 .72395 .53384 .71647 .53546 .71601 .53461 .72351 Mtetra
.539 .288 .484 r
.53461 .72351 .53546 .71601 .53708 .71557 .53624 .72308 Mtetra
.539 .289 .484 r
.53624 .72308 .53708 .71557 .53871 .71515 .53787 .72266 Mtetra
.539 .288 .484 r
.53787 .72266 .53871 .71515 .54034 .71472 .5395 .72223 Mtetra
.548 .296 .486 r
.5395 .72223 .54034 .71472 .54197 .71494 .54113 .72201 Mtetra
.555 .299 .483 r
.54113 .72201 .54197 .71494 .5436 .71562 .54277 .72197 Mtetra
.524 .267 .467 r
.54277 .72197 .5436 .71562 .54523 .71478 .5444 .72137 Mtetra
.406 .169 .439 r
.5444 .72137 .54523 .71478 .54679 .70207 .54603 .71887 Mtetra
.979 .715 .457 r
.54603 .71887 .54679 .70207 .54721 .52199 .54648 .53419 Mtetra
0 0 .224 r
.54648 .53419 .54721 .52199 .54873 .51807 .54792 .51846 Mtetra
.963 .937 .7 r
.54792 .51846 .54873 .51807 .55027 .51607 .54945 .51555 Mtetra
.744 .85 .929 r
.54945 .51555 .55027 .51607 .55181 .51527 .55099 .51473 Mtetra
.594 .814 .984 r
.55099 .51473 .55181 .51527 .55335 .51477 .55254 .51439 Mtetra
.572 .853 .996 r
.55254 .51439 .55335 .51477 .5549 .51424 .55408 .51402 Mtetra
.712 .93 .962 r
.55408 .51402 .5549 .51424 .55644 .51346 .55563 .51323 Mtetra
.508 .869 .986 r
.55563 .51323 .55644 .51346 .55799 .51309 .55718 .51286 Mtetra
.58 .004 0 r
.55718 .51286 .55799 .51309 .55955 .51407 .55874 .51393 Mtetra
.941 .617 .392 r
.55874 .51393 .55955 .51407 .56119 .52173 .5604 .52382 Mtetra
.954 .681 .479 r
.5604 .52382 .56119 .52173 .56493 .71475 .56407 .71414 Mtetra
.502 0 0 r
.56407 .71414 .56493 .71475 .5666 .71644 .56574 .7155 Mtetra
.929 .743 .63 r
.56574 .7155 .5666 .71644 .56818 .71071 .56732 .70943 Mtetra
.958 .69 .484 r
.56732 .70943 .56818 .71071 .56736 .51588 .56654 .51471 Mtetra
.9 .729 .661 r
.56654 .51471 .56736 .51588 .56886 .51129 .56804 .51029 Mtetra
.727 .735 .857 r
.56804 .51029 .56886 .51129 .57041 .51048 .5696 .50946 Mtetra
.608 .692 .902 r
.5696 .50946 .57041 .51048 .57197 .51025 .57115 .50921 Mtetra
.565 .671 .91 r
.57115 .50921 .57197 .51025 .57353 .51011 .57272 .50911 Mtetra
.657 .716 .891 r
.57272 .50911 .57353 .51011 .57508 .50951 .57427 .50866 Mtetra
.657 .749 .918 r
.57427 .50866 .57508 .50951 .57664 .50889 .57583 .5082 Mtetra
.658 .79 .945 r
.57583 .5082 .57664 .50889 .5782 .5083 .57739 .50773 Mtetra
.663 .822 .96 r
.57739 .50773 .5782 .5083 .57976 .50778 .57895 .50721 Mtetra
.663 .826 .961 r
.57895 .50721 .57976 .50778 .58132 .50727 .58051 .50668 Mtetra
.692 .828 .949 r
.58051 .50668 .58132 .50727 .58288 .5067 .58207 .50607 Mtetra
.749 .825 .911 r
.58207 .50607 .58288 .5067 .58443 .50595 .58363 .50521 Mtetra
.658 .779 .938 r
.58363 .50521 .58443 .50595 .586 .50545 .58519 .50474 Mtetra
.128 .524 .915 r
.58519 .50474 .586 .50545 .58757 .50562 .58678 .50529 Mtetra
.922 .544 .271 r
.58678 .50529 .58757 .50562 .58919 .50782 .58845 .51043 Mtetra
.957 .68 .471 r
.58845 .51043 .58919 .50782 .59091 .5149 .5938 .70355 Mtetra
.574 .362 .555 r
.5938 .70355 .59091 .5149 .59627 .70141 .59555 .70749 Mtetra
.554 .29 .47 r
.59555 .70749 .59627 .70141 .59793 .70132 .59723 .70748 Mtetra
.519 .261 .463 r
.59723 .70748 .59793 .70132 .59958 .70026 .59889 .70681 Mtetra
.515 .261 .468 r
.59889 .70681 .59958 .70026 .60127 .70058 .60055 .706 Mtetra
.546 .277 .458 r
.60055 .706 .60127 .70058 .60302 .704 .60223 .70589 Mtetra
.493 .128 .274 r
.60223 .70589 .60302 .704 .60474 .70595 .60391 .70579 Mtetra
.294 .775 .918 r
.60391 .70579 .60474 .70595 .60644 .70689 .60558 .70561 Mtetra
.637 .669 .864 r
.60558 .70561 .60644 .70689 .60812 .70666 .60726 .70522 Mtetra
.647 .65 .839 r
.60726 .70522 .60812 .70666 .60979 .70615 .60893 .70477 Mtetra
.643 .657 .849 r
.60893 .70477 .60979 .70615 .61146 .70556 .61061 .70435 Mtetra
.559 .647 .893 r
.61061 .70435 .61146 .70556 .61314 .7054 .61229 .70429 Mtetra
.647 .704 .888 r
.61229 .70429 .61314 .7054 .61482 .70498 .61397 .70385 Mtetra
.778 .74 .818 r
.61397 .70385 .61482 .70498 .61648 .704 .61562 .70253 Mtetra
.902 .717 .643 r
.61562 .70253 .61648 .704 .6181 .70126 .61717 .69718 Mtetra
.959 .686 .474 r
.61717 .69718 .6181 .70126 .61964 .69564 .61367 .50272 Mtetra
.578 .369 .561 r
.61367 .50272 .61964 .69564 .61609 .50445 .61511 .49687 Mtetra
.626 .447 .621 r
.61511 .49687 .61609 .50445 .61753 .49905 .61667 .49551 Mtetra
.632 .502 .686 r
.61667 .49551 .61753 .49905 .61906 .49652 .61824 .49483 Mtetra
.631 .601 .802 r
.61824 .49483 .61906 .49652 .62061 .49499 .61983 .49446 Mtetra
.651 .839 .973 r
.61983 .49446 .62061 .49499 .62219 .4944 .62141 .49396 Mtetra
.609 .852 .99 r
.62141 .49396 .62219 .4944 .62378 .4941 .623 .49352 Mtetra
.637 .817 .969 r
.623 .49352 .62378 .4941 .62538 .4939 .62459 .49307 Mtetra
.756 .78 .873 r
.62459 .49307 .62538 .4939 .62695 .49298 .62616 .49211 Mtetra
.688 .757 .904 r
.62616 .49211 .62695 .49298 .62853 .49239 .62774 .49152 Mtetra
.438 .653 .95 r
.62774 .49152 .62853 .49239 .63014 .49256 .62935 .49169 Mtetra
.909 .506 .123 r
.62935 .49169 .63014 .49256 .6319 .49725 .63111 .49639 Mtetra
.966 .684 .449 r
.63111 .49639 .6319 .49725 .63988 .69213 .63905 .69129 Mtetra
.901 .49 .11 r
.63905 .69129 .63988 .69213 .64174 .69679 .64091 .69593 Mtetra
.183 .53 .922 r
.64091 .69593 .64174 .69679 .64347 .6974 .64264 .69654 Mtetra
.645 .759 .932 r
.64264 .69654 .64347 .6974 .64517 .69695 .64433 .69609 Mtetra
.818 .794 .83 r
.64433 .69609 .64517 .69695 .64682 .69544 .64599 .69457 Mtetra
.939 .759 .633 r
.64599 .69457 .64682 .69544 .64834 .68991 .64751 .68902 Mtetra
.966 .69 .458 r
.64751 .68902 .64834 .68991 .64307 .49407 .64229 .49312 Mtetra
.936 .747 .622 r
.64229 .49312 .64307 .49407 .64448 .48829 .6437 .48737 Mtetra
.772 .768 .849 r
.6437 .48737 .64448 .48829 .64606 .48718 .64527 .48627 Mtetra
.64 .732 .915 r
.64527 .48627 .64606 .48718 .64766 .48678 .64688 .48587 Mtetra
.528 .687 .939 r
.64688 .48587 .64766 .48678 .64927 .48675 .64849 .48584 Mtetra
.75 .765 .865 r
.64849 .48584 .64927 .48675 .65086 .4858 .65008 .48489 Mtetra
.692 .75 .896 r
.65008 .48489 .65086 .4858 .65245 .48518 .65167 .48427 Mtetra
.495 .672 .943 r
.65167 .48427 .65245 .48518 .65408 .48523 .6533 .48432 Mtetra
.885 .469 .054 r
.6533 .48432 .65408 .48523 .65587 .48954 .65509 .48863 Mtetra
.968 .684 .44 r
.65509 .48863 .65587 .48954 .66531 .68473 .66449 .68388 Mtetra
.906 .499 .117 r
.66449 .68388 .66531 .68473 .66724 .68974 .66641 .68889 Mtetra
.103 .478 .896 r
.66641 .68889 .66724 .68974 .66899 .6905 .66817 .68964 Mtetra
.625 .755 .94 r
.66817 .68964 .66899 .6905 .67071 .69011 .66988 .68926 Mtetra
.807 .798 .843 r
.66988 .68926 .67071 .69011 .67238 .6887 .67156 .68785 Mtetra
.936 .769 .649 r
.67156 .68785 .67238 .6887 .6739 .68382 .67308 .68296 Mtetra
.968 .69 .449 r
.67308 .68296 .6739 .68382 .66721 .48802 .66644 .48711 Mtetra
.947 .746 .599 r
.66644 .48711 .66721 .48802 .66856 .48131 .66778 .4804 Mtetra
.795 .775 .835 r
.66778 .4804 .66856 .48131 .67013 .48002 .66936 .47911 Mtetra
.627 .729 .92 r
.66936 .47911 .67013 .48002 .67175 .47966 .67098 .47875 Mtetra
.491 .671 .944 r
.67098 .47875 .67175 .47966 .67339 .47973 .67262 .47882 Mtetra
.636 .734 .919 r
.67262 .47882 .67339 .47973 .67501 .47933 .67424 .47843 Mtetra
.66 .743 .911 r
.67424 .47843 .67501 .47933 .67662 .47885 .67585 .47794 Mtetra
.666 .746 .91 r
.67585 .47794 .67662 .47885 .67824 .47833 .67747 .47743 Mtetra
.761 .773 .863 r
.67747 .47743 .67824 .47833 .67983 .47731 .67906 .47641 Mtetra
.718 .763 .888 r
.67906 .47641 .67983 .47731 .68144 .47655 .68067 .47565 Mtetra
.544 .7 .941 r
.68067 .47565 .68144 .47655 .68307 .47646 .68231 .47557 Mtetra
.844 .41 0 r
.68231 .47557 .68307 .47646 .6849 .48021 .68413 .47934 Mtetra
.97 .683 .428 r
.68413 .47934 .6849 .48021 .69611 .67566 .6953 .67484 Mtetra
.91 .509 .129 r
.6953 .67484 .69611 .67566 .69813 .68114 .69732 .68028 Mtetra
.002 .407 .853 r
.69732 .68028 .69813 .68114 .69993 .6821 .69912 .68122 Mtetra
.615 .747 .94 r
.69912 .68122 .69993 .6821 .70166 .68176 .70085 .68087 Mtetra
.801 .794 .845 r
.70085 .68087 .70166 .68176 .70334 .68037 .70254 .67949 Mtetra
.936 .773 .656 r
.70254 .67949 .70334 .68037 .70485 .67545 .70405 .67486 Mtetra
.971 .689 .437 r
.70405 .67486 .70485 .67545 .69635 .47824 .69565 .47843 Mtetra
.993 .805 .548 r
.69565 .47843 .69635 .47824 .69767 .47181 .69693 .47133 Mtetra
.862 .88 .85 r
.69693 .47133 .69767 .47181 .69925 .47037 .6985 .46975 Mtetra
.638 .814 .967 r
.6985 .46975 .69925 .47037 .70089 .47004 .70014 .46929 Mtetra
.501 .72 .97 r
.70014 .46929 .70089 .47004 .70255 .47015 .70179 .46925 Mtetra
.636 .736 .921 r
.70179 .46925 .70255 .47015 .70418 .4697 .70343 .46885 Mtetra
.663 .761 .923 r
.70343 .46885 .70418 .4697 .70581 .46913 .70506 .46835 Mtetra
.648 .772 .939 r
.70506 .46835 .70581 .46913 .70745 .4688 .70669 .46789 Mtetra
.695 .757 .899 r
.70669 .46789 .70745 .4688 .70914 .46918 .70832 .46725 Mtetra
.636 .584 .779 r
.70832 .46725 .70914 .46918 .71087 .47048 .70996 .46681 Mtetra
.562 .456 .691 r
.70996 .46681 .71087 .47048 .71274 .47399 .71163 .46699 Mtetra
.374 .277 .615 r
.71163 .46699 .71274 .47399 .7254 .66527 .7135 .47057 Mtetra
.083 .006 .461 r
.7135 .47057 .7254 .66527 .7275 .67101 .72645 .66579 Mtetra
.04 .073 .568 r
.72645 .66579 .7275 .67101 .7294 .67311 .72855 .67136 Mtetra
.363 .463 .829 r
.72855 .67136 .7294 .67311 .7312 .67354 .73038 .67224 Mtetra
.631 .67 .869 r
.73038 .67224 .7312 .67354 .73295 .67317 .73213 .67187 Mtetra
.712 .702 .839 r
.73213 .67187 .73295 .67317 .73467 .67226 .73385 .671 Mtetra
.66 .689 .867 r
.73385 .671 .73467 .67226 .73636 .6707 .7356 .67047 Mtetra
.59 .914 .976 r
.7356 .67047 .73636 .6707 .73798 .66821 .73734 .66985 Mtetra
.19 0 .108 r
.73734 .66985 .73798 .66821 .73948 .66355 .73905 .66857 Mtetra
.137 0 .34 r
.73905 .66857 .73948 .66355 .7293 .47088 .74054 .66394 Mtetra
.08 0 .455 r
.74054 .66394 .7293 .47088 .73054 .46393 .73007 .46747 Mtetra
0 0 .048 r
.73007 .46747 .73054 .46393 .73204 .46104 .73134 .46094 Mtetra
.893 .966 .829 r
.73134 .46094 .73204 .46104 .73365 .4599 .73291 .45915 Mtetra
.668 .79 .939 r
.73291 .45915 .73365 .4599 .7353 .45952 .73456 .45861 Mtetra
.56 .704 .937 r
.73456 .45861 .7353 .45952 .73698 .45942 .73623 .45847 Mtetra
.618 .723 .921 r
.73623 .45847 .73698 .45942 .73863 .45901 .73789 .45815 Mtetra
.659 .757 .923 r
.73789 .45815 .73863 .45901 .74028 .45838 .73955 .45765 Mtetra
.656 .792 .947 r
.73955 .45765 .74028 .45838 .74192 .45773 .7412 .45715 Mtetra
.66 .835 .967 r
.7412 .45715 .74192 .45773 .74356 .45702 .74285 .4566 Mtetra
.636 .878 .986 r
.74285 .4566 .74356 .45702 .74521 .45638 .7445 .45604 Mtetra
.587 .885 .991 r
.7445 .45604 .74521 .45638 .74687 .456 .74616 .45554 Mtetra
.656 .874 .98 r
.74616 .45554 .74687 .456 .74858 .45629 .74781 .45495 Mtetra
.645 .659 .849 r
.74781 .45495 .74858 .45629 .75036 .45753 .74947 .45452 Mtetra
.563 .48 .719 r
.74947 .45452 .75036 .45753 .75227 .46068 .75118 .45465 Mtetra
.396 .303 .632 r
.75118 .45465 .75227 .46068 .76732 .65212 .75307 .45753 Mtetra
.102 .023 .471 r
.75307 .45753 .76732 .65212 .76962 .65922 .76846 .65289 Mtetra
.068 .078 .56 r
.76846 .65289 .76962 .65922 .77159 .66156 .77074 .6596 Mtetra
.299 .4 .798 r
.77074 .6596 .77159 .66156 .77344 .66218 .77263 .66087 Mtetra
.612 .662 .875 r
.77263 .66087 .77344 .66218 .77523 .6619 .77442 .66059 Mtetra
.702 .7 .845 r
.77442 .66059 .77523 .6619 .77698 .66108 .77617 .65979 Mtetra
.672 .691 .86 r
.77617 .65979 .77698 .66108 .77869 .65965 .77794 .65918 Mtetra
.627 .869 .988 r
.77794 .65918 .77869 .65965 .78033 .65739 .77971 .65862 Mtetra
.117 0 0 r
.77971 .65862 .78033 .65739 .78185 .65344 .78144 .65747 Mtetra
.156 0 .32 r
.78144 .65747 .78185 .65344 .76951 .46338 .78298 .65379 Mtetra
.095 .014 .464 r
.78298 .65379 .76951 .46338 .77041 .45246 .7702 .45851 Mtetra
0 0 .243 r
.7702 .45851 .77041 .45246 .77187 .44915 .77122 .44932 Mtetra
.916 .979 .732 r
.77122 .44932 .77187 .44915 .77347 .44773 .77276 .44703 Mtetra
.694 .814 .94 r
.77276 .44703 .77347 .44773 .77515 .44728 .77442 .44638 Mtetra
.579 .719 .939 r
.77442 .44638 .77515 .44728 .77685 .44711 .77611 .44617 Mtetra
.609 .722 .925 r
.77611 .44617 .77685 .44711 .77853 .44674 .7778 .44587 Mtetra
.666 .761 .921 r
.7778 .44587 .77853 .44674 .78019 .44608 .77948 .44534 Mtetra
.663 .794 .945 r
.77948 .44534 .78019 .44608 .78185 .4454 .78115 .44481 Mtetra
.665 .838 .966 r
.78115 .44481 .78185 .4454 .78351 .44466 .78283 .44423 Mtetra
.647 .881 .984 r
.78283 .44423 .78351 .44466 .78518 .44396 .7845 .44364 Mtetra
.598 .894 .989 r
.7845 .44364 .78518 .44396 .78686 .4435 .78617 .44309 Mtetra
.649 .888 .983 r
.78617 .44309 .78686 .4435 .78859 .4436 .78785 .44248 Mtetra
.666 .707 .878 r
.78785 .44248 .78859 .4436 .79039 .44456 .78953 .44195 Mtetra
.58 .51 .74 r
.78953 .44195 .79039 .44456 .7923 .44689 .79125 .44192 Mtetra
.436 .346 .656 r
.79125 .44192 .7923 .44689 .80896 .62825 .79313 .44388 Mtetra
.101 .026 .476 r
.79313 .44388 .80896 .62825 .81228 .64633 .8107 .63554 Mtetra
.089 .061 .529 r
.8107 .63554 .81228 .64633 .81436 .64923 .81349 .64698 Mtetra
.223 .323 .756 r
.81349 .64698 .81436 .64923 .81627 .65004 .81548 .64883 Mtetra
.595 .673 .895 r
.81548 .64883 .81627 .65004 .81807 .64967 .8173 .6486 Mtetra
.71 .748 .881 r
.8173 .6486 .81807 .64967 .81984 .64872 .81908 .6478 Mtetra
.696 .775 .913 r
.81908 .6478 .81984 .64872 .82155 .64722 .82086 .64709 Mtetra
.435 .864 .931 r
.82086 .64709 .82155 .64722 .8232 .64499 .82267 .64661 Mtetra
.273 0 .148 r
.82267 .64661 .8232 .64499 .82471 .64107 .82442 .64557 Mtetra
.276 .049 .377 r
.82442 .64557 .82471 .64107 .80997 .45067 .82599 .64237 Mtetra
.122 .037 .477 r
.82599 .64237 .80997 .45067 .81079 .44013 .81087 .44823 Mtetra
0 0 .332 r
.81087 .44823 .81079 .44013 .81224 .43678 .81164 .43719 Mtetra
.887 .96 .624 r
.81164 .43719 .81224 .43678 .81384 .43522 .81315 .43457 Mtetra
.695 .833 .949 r
.81315 .43457 .81384 .43522 .81554 .43477 .81483 .43389 Mtetra
.564 .72 .947 r
.81483 .43389 .81554 .43477 .81728 .43468 .81656 .43372 Mtetra
.556 .697 .934 r
.81656 .43372 .81728 .43468 .81901 .43458 .81829 .4336 Mtetra
.628 .724 .916 r
.81829 .4336 .81901 .43458 .82072 .43421 .82001 .43322 Mtetra
.627 .722 .915 r
.82001 .43322 .82072 .43421 .82243 .43382 .82172 .43286 Mtetra
.631 .729 .919 r
.82172 .43286 .82243 .43382 .82414 .4334 .82343 .43247 Mtetra
.638 .74 .922 r
.82343 .43247 .82414 .4334 .82585 .43297 .82515 .43205 Mtetra
.645 .746 .923 r
.82515 .43205 .82585 .43297 .82756 .43251 .82686 .4316 Mtetra
.655 .753 .922 r
.82686 .4316 .82756 .43251 .82927 .43202 .82856 .43111 Mtetra
.667 .756 .917 r
.82856 .43111 .82927 .43202 .83097 .4315 .83027 .43057 Mtetra
.671 .752 .912 r
.83027 .43057 .83097 .4315 .83268 .43094 .83197 .43001 Mtetra
.671 .753 .912 r
.83197 .43001 .83268 .43094 .83437 .4303 .83367 .42945 Mtetra
.667 .771 .927 r
.83367 .42945 .83437 .4303 .83606 .42958 .83538 .4289 Mtetra
.658 .815 .959 r
.83538 .4289 .83606 .42958 .83775 .42886 .83709 .42835 Mtetra
.635 .86 .984 r
.83709 .42835 .83775 .42886 .83945 .4282 .8388 .42781 Mtetra
.603 .885 .991 r
.8388 .42781 .83945 .4282 .84115 .42763 .84051 .42728 Mtetra
.59 .89 .99 r
.84051 .42728 .84115 .42763 .84286 .42711 .84222 .42675 Mtetra
.593 .886 .991 r
.84222 .42675 .84286 .42711 .84458 .42667 .84393 .42622 Mtetra
.613 .869 .991 r
.84393 .42622 .84458 .42667 .84631 .42632 .84565 .42571 Mtetra
.641 .829 .973 r
.84565 .42571 .84631 .42632 .84805 .42599 .84736 .42519 Mtetra
.653 .783 .943 r
.84736 .42519 .84805 .42599 .84978 .4256 .84908 .42469 Mtetra
.654 .753 .922 r
.84908 .42469 .84978 .4256 .8515 .42512 .8508 .4242 Mtetra
.658 .753 .92 r
.8508 .4242 .8515 .42512 .85321 .42458 .85252 .42369 Mtetra
.666 .763 .922 r
.85252 .42369 .85321 .42458 .85493 .42401 .85424 .42314 Mtetra
.678 .773 .923 r
.85424 .42314 .85493 .42401 .85664 .42342 .85595 .42255 Mtetra
.686 .774 .918 r
.85595 .42255 .85664 .42342 .85835 .42279 .85767 .42191 Mtetra
.696 .779 .915 r
.85767 .42191 .85835 .42279 .86005 .42206 .85937 .42124 Mtetra
.707 .794 .919 r
.85937 .42124 .86005 .42206 .86174 .42123 .86108 .42051 Mtetra
.707 .823 .937 r
.86108 .42051 .86174 .42123 .86344 .4204 .86278 .41978 Mtetra
.73 .858 .941 r
.86278 .41978 .86344 .4204 .86512 .4195 .86447 .41894 Mtetra
.774 .884 .925 r
.86447 .41894 .86512 .4195 .86679 .41848 .86614 .4179 Mtetra
.661 .85 .972 r
.86614 .4179 .86679 .41848 .86852 .4179 .86786 .41731 Mtetra
.107 .538 .913 r
.86786 .41731 .86852 .4179 .87036 .41844 .86971 .41788 Mtetra
.876 .454 .034 r
.86971 .41788 .87036 .41844 .87267 .42336 .87208 .42331 Mtetra
.974 .666 .338 r
.87208 .42331 .87267 .42336 .89593 .6227 .89525 .62221 Mtetra
.805 .336 0 r
.89525 .62221 .89593 .6227 .89828 .62689 .89757 .62605 Mtetra
.486 .71 .969 r
.89757 .62605 .89828 .62689 .90019 .62692 .89947 .62604 Mtetra
.691 .793 .928 r
.89947 .62604 .90019 .62692 .90202 .62621 .90131 .62534 Mtetra
.708 .799 .922 r
.90131 .62534 .90202 .62621 .90384 .62541 .90313 .62456 Mtetra
.474 .699 .967 r
.90313 .62456 .90384 .62541 .90576 .62548 .90504 .6246 Mtetra
.628 .767 .946 r
.90504 .6246 .90576 .62548 .90762 .62504 .90691 .62416 Mtetra
.842 .828 .834 r
.90691 .62416 .90762 .62504 .90933 .62326 .90863 .62245 Mtetra
.984 .768 .534 r
.90863 .62245 .90933 .62326 .91025 .61432 .90966 .6145 Mtetra
.977 .675 .34 r
.90966 .6145 .91025 .61432 .88976 .41553 .88914 .41516 Mtetra
.986 .852 .624 r
.88914 .41516 .88976 .41553 .89111 .41159 .89047 .41096 Mtetra
.737 .86 .938 r
.89047 .41096 .89111 .41159 .89283 .41083 .89217 .41009 Mtetra
.566 .764 .971 r
.89217 .41009 .89283 .41083 .89461 .4107 .89395 .40984 Mtetra
.507 .704 .959 r
.89395 .40984 .89461 .4107 .89643 .41078 .89575 .40982 Mtetra
.66 .746 .914 r
.89575 .40982 .89643 .41078 .89818 .41029 .8975 .40929 Mtetra
.668 .741 .905 r
.8975 .40929 .89818 .41029 .89992 .40975 .89924 .40874 Mtetra
.69 .748 .896 r
.89924 .40874 .89992 .40975 .90165 .40908 .90097 .40807 Mtetra
.759 .774 .865 r
.90097 .40807 .90165 .40908 .90334 .40802 .90266 .40701 Mtetra
.69 .749 .896 r
.90266 .40701 .90334 .40802 .90507 .40735 .90439 .40634 Mtetra
.433 .624 .932 r
.90439 .40634 .90507 .40735 .90691 .40762 .90624 .40661 Mtetra
.777 .361 0 r
.90624 .40661 .90691 .40762 .90933 .41267 .90865 .41163 Mtetra
.973 .661 .312 r
.90865 .41163 .90933 .41267 .93496 .61212 .93425 .61115 Mtetra
.725 .29 0 r
.93425 .61115 .93496 .61212 .93741 .61646 .93671 .61551 Mtetra
.488 .684 .954 r
.93671 .61551 .93741 .61646 .93935 .6165 .93865 .61556 Mtetra
.685 .778 .921 r
.93865 .61556 .93935 .6165 .94121 .61581 .94051 .61488 Mtetra
.736 .798 .902 r
.94051 .61488 .94121 .61581 .94303 .61486 .94233 .61394 Mtetra
.485 .69 .958 r
.94233 .61394 .94303 .61486 .94498 .6149 .94428 .61398 Mtetra
.614 .754 .945 r
.94428 .61398 .94498 .6149 .94687 .61451 .94618 .61359 Mtetra
.796 .818 .869 r
.94618 .61359 .94687 .61451 .94866 .61318 .94796 .61227 Mtetra
.98 .78 .565 r
.94796 .61227 .94866 .61318 .94979 .60661 .9491 .60575 Mtetra
.975 .669 .322 r
.9491 .60575 .94979 .60661 .92675 .40589 .92609 .40496 Mtetra
.969 .787 .603 r
.92609 .40496 .92675 .40589 .92794 .40081 .92728 .39984 Mtetra
.761 .784 .872 r
.92728 .39984 .92794 .40081 .92964 .39975 .92898 .39877 Mtetra
.628 .731 .922 r
.92898 .39877 .92964 .39975 .93142 .39936 .93076 .39838 Mtetra
.544 .69 .935 r
.93076 .39838 .93142 .39936 .93325 .39928 .93258 .3983 Mtetra
.751 .779 .875 r
.93258 .3983 .93325 .39928 .93495 .39828 .93429 .39729 Mtetra
.683 .753 .904 r
.93429 .39729 .93495 .39828 .93671 .39765 .93605 .39665 Mtetra
.488 .658 .936 r
.93605 .39665 .93671 .39765 .93856 .39775 .9379 .39675 Mtetra
.743 .325 0 r
.9379 .39675 .93856 .39775 .94102 .40257 .94036 .40158 Mtetra
.97 .655 .291 r
.94036 .40158 .94102 .40257 .96881 .60278 .96813 .60184 Mtetra
.739 .308 0 r
.96813 .60184 .96881 .60278 .97139 .60753 .9707 .60658 Mtetra
.034 .465 .879 r
.35855 .77145 .35949 .77221 .36097 .77283 .36003 .77207 Mtetra
.644 .762 .935 r
.36003 .77207 .36097 .77283 .3625 .77242 .36156 .77166 Mtetra
.81 .779 .824 r
.36156 .77166 .3625 .77242 .36408 .77099 .36314 .77023 Mtetra
.908 .737 .658 r
.36314 .77023 .36408 .77099 .36582 .76573 .36489 .76497 Mtetra
.937 .686 .534 r
.36489 .76497 .36582 .76573 .37571 .57508 .37482 .57426 Mtetra
.909 .728 .645 r
.37482 .57426 .37571 .57508 .37738 .5694 .3765 .56858 Mtetra
.778 .76 .837 r
.3765 .56858 .37738 .5694 .37886 .56829 .37798 .56747 Mtetra
.643 .737 .917 r
.37798 .56747 .37886 .56829 .38031 .56792 .37943 .5671 Mtetra
.514 .693 .95 r
.37943 .5671 .38031 .56792 .38174 .5679 .38086 .56708 Mtetra
.747 .758 .862 r
.38086 .56708 .38174 .5679 .38321 .56703 .38233 .56621 Mtetra
.699 .751 .892 r
.38233 .56621 .38321 .56703 .38467 .56643 .38379 .56561 Mtetra
.491 .685 .953 r
.38379 .56561 .38467 .56643 .38611 .56646 .38523 .56564 Mtetra
.923 .537 .235 r
.38523 .56564 .38611 .56646 .38739 .5702 .38651 .56942 Mtetra
.939 .683 .522 r
.38651 .56942 .38739 .5702 .38122 .75995 .38029 .75928 Mtetra
.933 .584 .344 r
.38029 .75928 .38122 .75995 .38252 .76545 .38159 .76472 Mtetra
.086 .507 .902 r
.38159 .76472 .38252 .76545 .38403 .76589 .38309 .76526 Mtetra
.647 .799 .956 r
.38309 .76526 .38403 .76589 .38558 .7654 .38464 .76481 Mtetra
.776 .822 .889 r
.38464 .76481 .38558 .7654 .38714 .76451 .3862 .76379 Mtetra
.753 .792 .884 r
.3862 .76379 .38714 .76451 .38867 .76451 .38777 .76288 Mtetra
.746 .656 .761 r
.38777 .76288 .38867 .76451 .3902 .76428 .38935 .76152 Mtetra
.75 .598 .688 r
.38935 .76152 .3902 .76428 .39177 .76335 .39097 .75917 Mtetra
.857 .636 .602 r
.39097 .75917 .39177 .76335 .39348 .75845 .39293 .74748 Mtetra
.925 .672 .537 r
.39293 .74748 .39348 .75845 .40194 .56723 .40115 .56417 Mtetra
.783 .604 .658 r
.40115 .56417 .40194 .56723 .40361 .5613 .40273 .56054 Mtetra
.779 .776 .85 r
.40273 .56054 .40361 .5613 .4051 .55993 .40422 .55947 Mtetra
.621 .831 .981 r
.40422 .55947 .4051 .55993 .40657 .5595 .40568 .55907 Mtetra
.466 .79 .999 r
.40568 .55907 .40657 .5595 .40802 .55949 .40714 .55894 Mtetra
.666 .815 .955 r
.40714 .55894 .40802 .55949 .40947 .55938 .40861 .55844 Mtetra
.692 .727 .877 r
.40861 .55844 .40947 .55938 .41093 .55927 .41008 .55786 Mtetra
.674 .644 .812 r
.41008 .55786 .41093 .55927 .41239 .55917 .41155 .55728 Mtetra
.684 .602 .758 r
.41155 .55728 .41239 .55917 .41386 .55841 .41303 .55648 Mtetra
.661 .588 .762 r
.41303 .55648 .41386 .55841 .41534 .55776 .41451 .55588 Mtetra
.598 .559 .781 r
.41451 .55588 .41534 .55776 .4168 .55772 .41597 .55573 Mtetra
.003 .183 .698 r
.41597 .55573 .4168 .55772 .41814 .56135 .41737 .5575 Mtetra
.778 .518 0 r
.41737 .5575 .41814 .56135 .41369 .7512 .41861 .56441 Mtetra
0 0 .343 r
.41861 .56441 .41369 .7512 .41507 .75651 .41428 .75169 Mtetra
.307 .253 .632 r
.41428 .75169 .41507 .75651 .4166 .75723 .41574 .7543 Mtetra
.459 .418 .725 r
.41574 .7543 .4166 .75723 .41816 .75685 .41727 .75514 Mtetra
.521 .547 .824 r
.41727 .75514 .41816 .75685 .41973 .75608 .41881 .75535 Mtetra
.559 .749 .966 r
.41881 .75535 .41973 .75608 .4213 .7556 .42037 .75517 Mtetra
.606 .846 .989 r
.42037 .75517 .4213 .7556 .42286 .75521 .42193 .75475 Mtetra
.658 .853 .974 r
.42193 .75475 .42286 .75521 .42443 .75474 .4235 .75421 Mtetra
.5 .786 .996 r
.4235 .75421 .42443 .75474 .42599 .75441 .42506 .75405 Mtetra
.491 .827 .999 r
.42506 .75405 .42599 .75441 .42756 .75386 .42662 .75381 Mtetra
.636 .942 .958 r
.42662 .75381 .42756 .75386 .42915 .75268 .4282 .75309 Mtetra
.945 .947 .747 r
.4282 .75309 .42915 .75268 .43082 .74816 .42982 .75048 Mtetra
.978 .869 .491 r
.42982 .75048 .43082 .74816 .43732 .5573 .43156 .74357 Mtetra
0 0 .337 r
.43156 .74357 .43732 .5573 .43896 .55098 .43799 .5543 Mtetra
0 0 .073 r
.43799 .5543 .43896 .55098 .44047 .54934 .43956 .55058 Mtetra
0 0 0 r
.43956 .55058 .44047 .54934 .44195 .54886 .44107 .54888 Mtetra
.778 .974 .916 r
.44107 .54888 .44195 .54886 .44343 .54878 .44258 .54781 Mtetra
.709 .728 .865 r
.44258 .54781 .44343 .54878 .44491 .54849 .44407 .54712 Mtetra
.655 .644 .828 r
.44407 .54712 .44491 .54849 .4464 .54806 .44555 .54667 Mtetra
.63 .63 .832 r
.44555 .54667 .4464 .54806 .44789 .54762 .44704 .54635 Mtetra
.634 .651 .849 r
.44704 .54635 .44789 .54762 .44938 .54709 .44852 .54602 Mtetra
.641 .688 .878 r
.44852 .54602 .44938 .54709 .45087 .54653 .45001 .54566 Mtetra
.646 .73 .91 r
.45001 .54566 .45087 .54653 .45236 .54603 .4515 .54527 Mtetra
.731 .775 .888 r
.4515 .54527 .45236 .54603 .45385 .54546 .453 .5445 Mtetra
.721 .733 .86 r
.453 .5445 .45385 .54546 .45534 .54507 .4545 .54374 Mtetra
.635 .641 .839 r
.4545 .54374 .45534 .54507 .45682 .54526 .45599 .54339 Mtetra
.134 .286 .755 r
.45599 .54339 .45682 .54526 .45825 .54828 .45744 .54483 Mtetra
.695 .437 0 r
.45744 .54483 .45825 .54828 .45606 .73837 .45881 .55076 Mtetra
0 0 .363 r
.45881 .55076 .45606 .73837 .45751 .74462 .45669 .73936 Mtetra
.405 .315 .64 r
.45669 .73936 .45751 .74462 .45907 .74572 .45823 .74144 Mtetra
.607 .472 .672 r
.45823 .74144 .45907 .74572 .46065 .74539 .45981 .74103 Mtetra
.632 .487 .668 r
.45981 .74103 .46065 .74539 .46225 .74462 .46141 .74021 Mtetra
.544 .427 .67 r
.46141 .74021 .46225 .74462 .46384 .74405 .46298 .74062 Mtetra
.462 .4 .701 r
.46298 .74062 .46384 .74405 .46542 .74366 .46454 .74161 Mtetra
.429 .461 .792 r
.46454 .74161 .46542 .74366 .46701 .74322 .46611 .7423 Mtetra
.459 .662 .949 r
.46611 .7423 .46701 .74322 .46861 .74258 .46769 .74242 Mtetra
.372 .818 .946 r
.46769 .74242 .46861 .74258 .4702 .74179 .46928 .74217 Mtetra
0 0 0 r
.46928 .74217 .4702 .74179 .4718 .74099 .47088 .74178 Mtetra
.203 0 0 r
.47088 .74178 .4718 .74099 .4734 .74038 .47247 .74136 Mtetra
.276 0 0 r
.47247 .74136 .4734 .74038 .47499 .73995 .47406 .74094 Mtetra
.27 0 0 r
.47406 .74094 .47499 .73995 .47658 .73957 .47566 .7405 Mtetra
.25 0 0 r
.47566 .7405 .47658 .73957 .47818 .73917 .47726 .74006 Mtetra
.236 0 0 r
.47726 .74006 .47818 .73917 .47977 .73873 .47885 .73963 Mtetra
.224 0 0 r
.47885 .73963 .47977 .73873 .48137 .73829 .48045 .73916 Mtetra
.184 0 0 r
.48045 .73916 .48137 .73829 .48297 .73783 .48205 .73864 Mtetra
.123 0 0 r
.48205 .73864 .48297 .73783 .48457 .73737 .48366 .73807 Mtetra
.059 0 0 r
.48366 .73807 .48457 .73737 .48617 .7369 .48526 .73749 Mtetra
.025 0 0 r
.48526 .73749 .48617 .7369 .48777 .73643 .48686 .73696 Mtetra
.024 0 0 r
.48686 .73696 .48777 .73643 .48937 .73596 .48847 .73649 Mtetra
.034 0 0 r
.48847 .73649 .48937 .73596 .49098 .7355 .49007 .73604 Mtetra
.042 0 0 r
.49007 .73604 .49098 .7355 .49258 .73504 .49168 .73558 Mtetra
.045 0 0 r
.49168 .73558 .49258 .73504 .49418 .73458 .49328 .73513 Mtetra
.048 0 0 r
.49328 .73513 .49418 .73458 .49579 .73413 .49489 .73468 Mtetra
.052 0 0 r
.49489 .73468 .49579 .73413 .4974 .73368 .4965 .73423 Mtetra
.054 0 0 r
.4965 .73423 .4974 .73368 .499 .73323 .4981 .73378 Mtetra
.057 0 0 r
.4981 .73378 .499 .73323 .50061 .73279 .49971 .73334 Mtetra
.059 0 0 r
.49971 .73334 .50061 .73279 .50222 .73234 .50133 .73289 Mtetra
.06 0 0 r
.50133 .73289 .50222 .73234 .50383 .7319 .50294 .73245 Mtetra
.061 0 0 r
.50294 .73245 .50383 .7319 .50544 .73146 .50455 .73201 Mtetra
.062 0 0 r
.50455 .73201 .50544 .73146 .50706 .73102 .50616 .73157 Mtetra
.063 0 0 r
.50616 .73157 .50706 .73102 .50867 .73058 .50778 .73113 Mtetra
.064 0 0 r
.50778 .73113 .50867 .73058 .51028 .73014 .50939 .73069 Mtetra
.065 0 0 r
.50939 .73069 .51028 .73014 .5119 .7297 .51101 .73025 Mtetra
.51101 .73025 .5119 .7297 .51351 .72926 .51263 .72981 Mtetra
.51263 .72981 .51351 .72926 .51513 .72882 .51424 .72937 Mtetra
.066 0 0 r
.51424 .72937 .51513 .72882 .51675 .72838 .51586 .72893 Mtetra
.51586 .72893 .51675 .72838 .51837 .72794 .51748 .72849 Mtetra
.067 0 0 r
.51748 .72849 .51837 .72794 .51999 .72749 .5191 .72805 Mtetra
.068 0 0 r
.5191 .72805 .51999 .72749 .52161 .72705 .52073 .72761 Mtetra
.52073 .72761 .52161 .72705 .52323 .72661 .52235 .72716 Mtetra
.069 0 0 r
.52235 .72716 .52323 .72661 .52485 .72617 .52397 .72672 Mtetra
.07 0 0 r
.52397 .72672 .52485 .72617 .52648 .72572 .5256 .72628 Mtetra
.072 0 0 r
.5256 .72628 .52648 .72572 .5281 .72528 .52722 .72584 Mtetra
.074 0 0 r
.52722 .72584 .5281 .72528 .52973 .72484 .52885 .7254 Mtetra
.076 0 0 r
.52885 .7254 .52973 .72484 .53135 .72439 .53048 .72496 Mtetra
.078 0 0 r
.53048 .72496 .53135 .72439 .53298 .72395 .53211 .72452 Mtetra
.082 0 0 r
.53211 .72452 .53298 .72395 .53461 .72351 .53374 .72408 Mtetra
.09 0 0 r
.53374 .72408 .53461 .72351 .53624 .72308 .53537 .72365 Mtetra
.096 0 0 r
.53537 .72365 .53624 .72308 .53787 .72266 .537 .72323 Mtetra
.092 0 0 r
.537 .72323 .53787 .72266 .5395 .72223 .53863 .7228 Mtetra
.186 0 0 r
.53863 .7228 .5395 .72223 .54113 .72201 .54027 .72252 Mtetra
.233 0 0 r
.54027 .72252 .54113 .72201 .54277 .72197 .5419 .72236 Mtetra
0 0 0 r
.5419 .72236 .54277 .72197 .5444 .72137 .54354 .72182 Mtetra
.807 .995 .762 r
.54354 .72182 .5444 .72137 .54603 .71887 .54517 .72005 Mtetra
.989 .885 .557 r
.54517 .72005 .54603 .71887 .54648 .53419 .54677 .71468 Mtetra
0 0 .371 r
.54677 .71468 .54648 .53419 .54792 .51846 .54714 .52287 Mtetra
0 0 .174 r
.54714 .52287 .54792 .51846 .54945 .51555 .54865 .5177 Mtetra
.345 .013 .251 r
.54865 .5177 .54945 .51555 .55099 .51473 .55019 .51675 Mtetra
.483 .134 .298 r
.55019 .51675 .55099 .51473 .55254 .51439 .55174 .51653 Mtetra
.483 .141 .31 r
.55174 .51653 .55254 .51439 .55408 .51402 .55329 .51628 Mtetra
.371 .044 .275 r
.55329 .51628 .55408 .51402 .55563 .51323 .55484 .51539 Mtetra
.469 .128 .306 r
.55484 .51539 .55563 .51323 .55718 .51286 .55639 .51505 Mtetra
.703 .366 .402 r
.55639 .51505 .55718 .51286 .55874 .51393 .55796 .51693 Mtetra
.953 .679 .481 r
.55796 .51693 .55874 .51393 .5604 .52382 .5615 .70834 Mtetra
.577 .364 .556 r
.5615 .70834 .5604 .52382 .56407 .71414 .56322 .71421 Mtetra
.261 0 0 r
.56322 .71421 .56407 .71414 .56574 .7155 .56487 .71447 Mtetra
.933 .732 .608 r
.56487 .71447 .56574 .7155 .56732 .70943 .56644 .707 Mtetra
.957 .688 .486 r
.56644 .707 .56732 .70943 .56654 .51471 .56571 .5129 Mtetra
.855 .682 .667 r
.56571 .5129 .56654 .51471 .56804 .51029 .56723 .50893 Mtetra
.718 .676 .808 r
.56723 .50893 .56804 .51029 .5696 .50946 .56877 .50803 Mtetra
.615 .623 .835 r
.56877 .50803 .5696 .50946 .57115 .50921 .57033 .50777 Mtetra
.506 .569 .854 r
.57033 .50777 .57115 .50921 .57272 .50911 .5719 .50799 Mtetra
.316 .526 .9 r
.5719 .50799 .57272 .50911 .57427 .50866 .57347 .50856 Mtetra
.564 0 0 r
.57347 .50856 .57427 .50866 .57583 .5082 .57506 .50949 Mtetra
.641 .245 .277 r
.57506 .50949 .57583 .5082 .57739 .50773 .57664 .51039 Mtetra
.502 .183 .359 r
.57664 .51039 .57739 .50773 .57895 .50721 .5782 .51014 Mtetra
.457 .152 .36 r
.5782 .51014 .57895 .50721 .58051 .50668 .57976 .50947 Mtetra
.411 .106 .334 r
.57976 .50947 .58051 .50668 .58207 .50607 .58132 .50855 Mtetra
.355 .042 .289 r
.58132 .50855 .58207 .50607 .58363 .50521 .58288 .50745 Mtetra
.45 .115 .305 r
.58288 .50745 .58363 .50521 .58519 .50474 .58444 .50697 Mtetra
.66 .32 .386 r
.58444 .50697 .58519 .50474 .58678 .50529 .58604 .50826 Mtetra
.956 .679 .472 r
.58604 .50826 .58678 .50529 .58845 .51043 .59119 .69801 Mtetra
.58 .366 .556 r
.59119 .69801 .58845 .51043 .5938 .70355 .59301 .70578 Mtetra
.715 .372 .396 r
.59301 .70578 .5938 .70355 .59555 .70749 .59473 .70794 Mtetra
.239 0 0 r
.59473 .70794 .59555 .70749 .59723 .70748 .5964 .70783 Mtetra
0 0 0 r
.5964 .70783 .59723 .70748 .59889 .70681 .59807 .70723 Mtetra
.59807 .70723 .59889 .70681 .60055 .706 .59973 .70645 Mtetra
.59973 .70645 .60055 .706 .60223 .70589 .6014 .70596 Mtetra
.347 .825 .838 r
.6014 .70596 .60223 .70589 .60391 .70579 .60307 .70548 Mtetra
.563 .877 .993 r
.60307 .70548 .60391 .70579 .60558 .70561 .60474 .70503 Mtetra
.575 .806 .987 r
.60474 .70503 .60558 .70561 .60726 .70522 .60642 .70471 Mtetra
.605 .836 .987 r
.60642 .70471 .60726 .70522 .60893 .70477 .60809 .70428 Mtetra
.68 .864 .969 r
.60809 .70428 .60893 .70477 .61061 .70435 .60976 .70363 Mtetra
.77 .819 .891 r
.60976 .70363 .61061 .70435 .61229 .70429 .61142 .70258 Mtetra
.766 .669 .755 r
.61142 .70258 .61229 .70429 .61397 .70385 .61307 .70094 Mtetra
.779 .612 .673 r
.61307 .70094 .61397 .70385 .61562 .70253 .61468 .69784 Mtetra
.958 .685 .475 r
.61468 .69784 .61562 .70253 .61717 .69718 .61144 .50811 Mtetra
.586 .375 .561 r
.61144 .50811 .61717 .69718 .61367 .50272 .61276 .49779 Mtetra
.717 .532 .639 r
.61276 .49779 .61367 .50272 .61511 .49687 .61428 .49476 Mtetra
.669 .585 .752 r
.61428 .49476 .61511 .49687 .61667 .49551 .61585 .49401 Mtetra
.613 .616 .829 r
.61585 .49401 .61667 .49551 .61824 .49483 .61744 .49376 Mtetra
.547 .658 .909 r
.61744 .49376 .61824 .49483 .61983 .49446 .61904 .49372 Mtetra
.653 .778 .94 r
.61904 .49372 .61983 .49446 .62141 .49396 .62063 .49326 Mtetra
.664 .794 .944 r
.62063 .49326 .62141 .49396 .623 .49352 .62221 .49275 Mtetra
.686 .782 .924 r
.62221 .49275 .623 .49352 .62459 .49307 .62379 .49217 Mtetra
.769 .77 .853 r
.62379 .49217 .62459 .49307 .62616 .49211 .62536 .49109 Mtetra
.704 .729 .87 r
.62536 .49109 .62616 .49211 .62774 .49152 .62695 .49039 Mtetra
.521 .634 .903 r
.62695 .49039 .62774 .49152 .62935 .49169 .62855 .49046 Mtetra
.863 .457 0 r
.62855 .49046 .62935 .49169 .63111 .49639 .6303 .49481 Mtetra
.967 .685 .447 r
.6303 .49481 .63111 .49639 .63905 .69129 .6382 .69006 Mtetra
.89 .49 .056 r
.6382 .69006 .63905 .69129 .64091 .69593 .64007 .69506 Mtetra
.174 .521 .918 r
.64007 .69506 .64091 .69593 .64264 .69654 .6418 .6957 Mtetra
.643 .763 .935 r
.6418 .6957 .64264 .69654 .64433 .69609 .6435 .69525 Mtetra
.82 .799 .831 r
.6435 .69525 .64433 .69609 .64599 .69457 .64516 .69372 Mtetra
.94 .761 .633 r
.64516 .69372 .64599 .69457 .64751 .68902 .64668 .68816 Mtetra
.966 .69 .458 r
.64668 .68816 .64751 .68902 .64229 .49312 .6415 .4922 Mtetra
.938 .749 .622 r
.6415 .4922 .64229 .49312 .6437 .48737 .64291 .48646 Mtetra
.772 .769 .85 r
.64291 .48646 .6437 .48737 .64527 .48627 .64449 .48535 Mtetra
.64 .732 .915 r
.64449 .48535 .64527 .48627 .64688 .48587 .64609 .48496 Mtetra
.528 .687 .94 r
.64609 .48496 .64688 .48587 .64849 .48584 .64771 .48492 Mtetra
.75 .765 .865 r
.64771 .48492 .64849 .48584 .65008 .48489 .64929 .48398 Mtetra
.692 .75 .896 r
.64929 .48398 .65008 .48489 .65167 .48427 .65089 .48335 Mtetra
.495 .672 .943 r
.65089 .48335 .65167 .48427 .6533 .48432 .65251 .48341 Mtetra
.885 .469 .053 r
.65251 .48341 .6533 .48432 .65509 .48863 .65431 .48771 Mtetra
.968 .684 .44 r
.65431 .48771 .65509 .48863 .66449 .68388 .66366 .68302 Mtetra
.906 .499 .116 r
.66366 .68302 .66449 .68388 .66641 .68889 .66559 .68803 Mtetra
.103 .478 .896 r
.66559 .68803 .66641 .68889 .66817 .68964 .66735 .68879 Mtetra
.625 .755 .94 r
.66735 .68879 .66817 .68964 .66988 .68926 .66906 .6884 Mtetra
.807 .798 .843 r
.66906 .6884 .66988 .68926 .67156 .68785 .67074 .68699 Mtetra
.936 .769 .649 r
.67074 .68699 .67156 .68785 .67308 .68296 .67226 .6821 Mtetra
.968 .69 .449 r
.67226 .6821 .67308 .68296 .66644 .48711 .66566 .4862 Mtetra
.947 .746 .599 r
.66566 .4862 .66644 .48711 .66778 .4804 .66701 .47948 Mtetra
.795 .775 .836 r
.66701 .47948 .66778 .4804 .66936 .47911 .66858 .47819 Mtetra
.627 .729 .921 r
.66858 .47819 .66936 .47911 .67098 .47875 .6702 .47784 Mtetra
.489 .671 .944 r
.6702 .47784 .67098 .47875 .67262 .47882 .67184 .47791 Mtetra
.635 .734 .919 r
.67184 .47791 .67262 .47882 .67424 .47843 .67346 .47752 Mtetra
.659 .743 .912 r
.67346 .47752 .67424 .47843 .67585 .47794 .67508 .47704 Mtetra
.665 .747 .911 r
.67508 .47704 .67585 .47794 .67747 .47743 .6767 .47654 Mtetra
.763 .775 .863 r
.6767 .47654 .67747 .47743 .67906 .47641 .67829 .47551 Mtetra
.717 .762 .888 r
.67829 .47551 .67906 .47641 .68067 .47565 .6799 .47475 Mtetra
.536 .695 .942 r
.6799 .47475 .68067 .47565 .68231 .47557 .68154 .47469 Mtetra
.868 .442 .015 r
.68154 .47469 .68231 .47557 .68413 .47934 .68338 .4788 Mtetra
.969 .682 .429 r
.68338 .4788 .68413 .47934 .6953 .67484 .69453 .67477 Mtetra
.905 .506 .232 r
.69453 .67477 .6953 .67484 .69732 .68028 .69653 .6798 Mtetra
0 .401 .781 r
.69653 .6798 .69732 .68028 .69912 .68122 .69831 .68052 Mtetra
.644 .804 .96 r
.69831 .68052 .69912 .68122 .70085 .68087 .70004 .68002 Mtetra
.805 .804 .85 r
.70004 .68002 .70085 .68087 .70254 .67949 .70173 .67865 Mtetra
.911 .793 .717 r
.70173 .67865 .70254 .67949 .70405 .67486 .70332 .67545 Mtetra
.998 .802 .512 r
.70332 .67545 .70405 .67486 .69565 .47843 .70462 .66664 Mtetra
.058 0 .443 r
.70462 .66664 .69565 .47843 .69693 .47133 .69637 .47429 Mtetra
.017 0 .21 r
.69637 .47429 .69693 .47133 .6985 .46975 .69786 .47109 Mtetra
0 0 0 r
.69786 .47109 .6985 .46975 .70014 .46929 .69943 .46952 Mtetra
.549 .922 .777 r
.69943 .46952 .70014 .46929 .70179 .46925 .70104 .46852 Mtetra
.702 .803 .928 r
.70104 .46852 .70179 .46925 .70343 .46885 .70266 .46785 Mtetra
.659 .723 .896 r
.70266 .46785 .70343 .46885 .70506 .46835 .70429 .46736 Mtetra
.641 .72 .905 r
.70429 .46736 .70506 .46835 .70669 .46789 .70593 .46696 Mtetra
.738 .763 .873 r
.70593 .46696 .70669 .46789 .70832 .46725 .70755 .46607 Mtetra
.715 .711 .845 r
.70755 .46607 .70832 .46725 .70996 .46681 .70917 .46526 Mtetra
.63 .62 .822 r
.70917 .46526 .70996 .46681 .71163 .46699 .71081 .4649 Mtetra
.242 .337 .761 r
.71081 .4649 .71163 .46699 .7135 .47057 .71256 .46645 Mtetra
0 0 .461 r
.71256 .46645 .7135 .47057 .72645 .66579 .71459 .47261 Mtetra
.084 .007 .461 r
.71459 .47261 .72645 .66579 .72855 .67136 .72749 .66592 Mtetra
.367 .295 .643 r
.72749 .66592 .72855 .67136 .73038 .67224 .72943 .66879 Mtetra
.499 .429 .709 r
.72943 .66879 .73038 .67224 .73213 .67187 .73125 .66957 Mtetra
.553 .521 .774 r
.73125 .66957 .73213 .67187 .73385 .671 .73304 .66972 Mtetra
.507 .615 .894 r
.73304 .66972 .73385 .671 .7356 .67047 .73482 .66986 Mtetra
.502 .777 .994 r
.73482 .66986 .7356 .67047 .73734 .66985 .73659 .6697 Mtetra
.62 .939 .955 r
.73659 .6697 .73734 .66985 .73905 .66857 .73833 .66893 Mtetra
.918 .972 .686 r
.73833 .66893 .73905 .66857 .74054 .66394 .73995 .66627 Mtetra
.841 .771 .263 r
.73995 .66627 .74054 .66394 .73007 .46747 .74129 .65913 Mtetra
.081 0 .455 r
.74129 .65913 .73007 .46747 .73134 .46094 .73086 .46427 Mtetra
0 0 .226 r
.73086 .46427 .73134 .46094 .73291 .45915 .7323 .46036 Mtetra
0 0 0 r
.7323 .46036 .73291 .45915 .73456 .45861 .73387 .4586 Mtetra
.726 .985 .895 r
.73387 .4586 .73456 .45861 .73623 .45847 .73548 .45749 Mtetra
.694 .743 .889 r
.73548 .45749 .73623 .45847 .73789 .45815 .73712 .45684 Mtetra
.635 .659 .856 r
.73712 .45684 .73789 .45815 .73955 .45765 .73878 .45646 Mtetra
.607 .666 .881 r
.73878 .45646 .73955 .45765 .7412 .45715 .74045 .45621 Mtetra
.63 .729 .918 r
.74045 .45621 .7412 .45715 .74285 .4566 .74212 .45584 Mtetra
.655 .783 .942 r
.74212 .45584 .74285 .4566 .7445 .45604 .74377 .45534 Mtetra
.664 .804 .95 r
.74377 .45534 .7445 .45604 .74616 .45554 .74543 .45481 Mtetra
.741 .814 .909 r
.74543 .45481 .74616 .45554 .74781 .45495 .74706 .45394 Mtetra
.727 .749 .87 r
.74706 .45394 .74781 .45495 .74947 .45452 .7487 .4531 Mtetra
.64 .645 .839 r
.7487 .4531 .74947 .45452 .75118 .45465 .75036 .45268 Mtetra
.316 .397 .787 r
.75036 .45268 .75118 .45465 .75307 .45753 .75214 .4539 Mtetra
0 0 .518 r
.75214 .4539 .75307 .45753 .76846 .65289 .75421 .45913 Mtetra
.102 .022 .471 r
.75421 .45913 .76846 .65289 .77074 .6596 .76961 .65384 Mtetra
.322 .261 .632 r
.76961 .65384 .77074 .6596 .77263 .66087 .77167 .65746 Mtetra
.476 .417 .712 r
.77167 .65746 .77263 .66087 .77442 .66059 .77355 .65844 Mtetra
.531 .521 .79 r
.77355 .65844 .77442 .66059 .77617 .65979 .77538 .65871 Mtetra
.506 .658 .928 r
.77538 .65871 .77617 .65979 .77794 .65918 .7772 .65878 Mtetra
.449 .812 .995 r
.7772 .65878 .77794 .65918 .77971 .65862 .779 .65856 Mtetra
.571 .935 .922 r
.779 .65856 .77971 .65862 .78144 .65747 .78075 .65778 Mtetra
.875 .985 .709 r
.78075 .65778 .78144 .65747 .78298 .65379 .7824 .65548 Mtetra
.845 .802 .311 r
.7824 .65548 .78298 .65379 .7702 .45851 .78379 .64975 Mtetra
.095 .014 .464 r
.78379 .64975 .7702 .45851 .77122 .44932 .77088 .45368 Mtetra
0 0 .288 r
.77088 .45368 .77122 .44932 .77276 .44703 .77221 .44853 Mtetra
0 0 0 r
.77221 .44853 .77276 .44703 .77442 .44638 .77377 .44655 Mtetra
.667 .97 .801 r
.77377 .44655 .77442 .44638 .77611 .44617 .77539 .44532 Mtetra
.715 .783 .905 r
.77539 .44532 .77611 .44617 .7778 .44587 .77705 .44457 Mtetra
.646 .667 .856 r
.77705 .44457 .7778 .44587 .77948 .44534 .77873 .44413 Mtetra
.616 .669 .878 r
.77873 .44413 .77948 .44534 .78115 .44481 .78042 .44384 Mtetra
.629 .725 .916 r
.78042 .44384 .78115 .44481 .78283 .44423 .78211 .44346 Mtetra
.659 .787 .942 r
.78211 .44346 .78283 .44423 .7845 .44364 .78379 .44294 Mtetra
.668 .811 .952 r
.78379 .44294 .7845 .44364 .78617 .44309 .78547 .44238 Mtetra
.734 .824 .92 r
.78547 .44238 .78617 .44309 .78785 .44248 .78712 .44155 Mtetra
.742 .772 .878 r
.78712 .44155 .78785 .44248 .78953 .44195 .78877 .44063 Mtetra
.66 .671 .849 r
.78877 .44063 .78953 .44195 .79125 .44192 .79045 .44011 Mtetra
.407 .47 .813 r
.79045 .44011 .79125 .44192 .79313 .44388 .79224 .44089 Mtetra
0 .076 .608 r
.79224 .44089 .79313 .44388 .8107 .63554 .79429 .44474 Mtetra
.111 .033 .479 r
.79429 .44474 .8107 .63554 .81349 .64698 .8122 .63978 Mtetra
.274 .213 .605 r
.8122 .63978 .81349 .64698 .81548 .64883 .81448 .64508 Mtetra
.462 .398 .7 r
.81448 .64508 .81548 .64883 .8173 .6486 .81643 .64632 Mtetra
.517 .504 .781 r
.81643 .64632 .8173 .6486 .81908 .6478 .8183 .64671 Mtetra
.499 .654 .928 r
.8183 .64671 .81908 .6478 .82086 .64709 .82016 .6468 Mtetra
.331 .779 .957 r
.82016 .6468 .82086 .64709 .82267 .64661 .82199 .64666 Mtetra
.438 .877 .845 r
.82199 .64666 .82267 .64661 .82442 .64557 .82378 .64595 Mtetra
.776 .968 .673 r
.82378 .64595 .82442 .64557 .82599 .64237 .82545 .64392 Mtetra
.812 .791 .294 r
.82545 .64392 .82599 .64237 .81087 .44823 .82684 .63861 Mtetra
.111 .029 .474 r
.82684 .63861 .81087 .44823 .81164 .43719 .81145 .44219 Mtetra
.018 0 .321 r
.81145 .44219 .81164 .43719 .81315 .43457 .81267 .43624 Mtetra
.004 0 .079 r
.81267 .43624 .81315 .43457 .81483 .43389 .81423 .43421 Mtetra
.536 .894 .677 r
.81423 .43421 .81483 .43389 .81656 .43372 .81587 .43297 Mtetra
.71 .813 .929 r
.81587 .43297 .81656 .43372 .81829 .4336 .81754 .43224 Mtetra
.631 .654 .854 r
.81754 .43224 .81829 .4336 .82001 .43322 .81926 .43187 Mtetra
.595 .637 .863 r
.81926 .43187 .82001 .43322 .82172 .43286 .82099 .43169 Mtetra
.596 .67 .892 r
.82099 .43169 .82172 .43286 .82343 .43247 .82272 .43147 Mtetra
.635 .724 .912 r
.82272 .43147 .82343 .43247 .82515 .43205 .82443 .43107 Mtetra
.645 .732 .912 r
.82443 .43107 .82515 .43205 .82686 .4316 .82615 .43063 Mtetra
.666 .742 .907 r
.82615 .43063 .82686 .4316 .82856 .43111 .82785 .43009 Mtetra
.684 .739 .893 r
.82785 .43009 .82856 .43111 .83027 .43057 .82955 .42947 Mtetra
.658 .712 .888 r
.82955 .42947 .83027 .43057 .83197 .43001 .83125 .42897 Mtetra
.553 .677 .921 r
.83125 .42897 .83197 .43001 .83367 .42945 .833 .42888 Mtetra
.042 .501 .886 r
.833 .42888 .83367 .42945 .83538 .4289 .83482 .42951 Mtetra
.635 .138 .051 r
.83482 .42951 .83538 .4289 .83709 .42835 .83668 .43055 Mtetra
.627 .27 .346 r
.83668 .43055 .83709 .42835 .8388 .42781 .83854 .43155 Mtetra
.544 .249 .417 r
.83854 .43155 .8388 .42781 .84051 .42728 .84031 .43156 Mtetra
.489 .216 .426 r
.84031 .43156 .84051 .42728 .84222 .42675 .842 .43074 Mtetra
.401 .141 .4 r
.842 .43074 .84222 .42675 .84393 .42622 .8436 .42901 Mtetra
.24 0 .298 r
.8436 .42901 .84393 .42622 .84565 .42571 .84515 .42681 Mtetra
0 0 0 r
.84515 .42681 .84565 .42571 .84736 .42519 .84674 .42499 Mtetra
.797 .976 .906 r
.84674 .42499 .84736 .42519 .84908 .42469 .84838 .42373 Mtetra
.682 .753 .905 r
.84838 .42373 .84908 .42469 .8508 .4242 .85009 .42312 Mtetra
.647 .713 .896 r
.85009 .42312 .8508 .4242 .85252 .42369 .85182 .42267 Mtetra
.646 .725 .906 r
.85182 .42267 .85252 .42369 .85424 .42314 .85355 .42222 Mtetra
.678 .759 .912 r
.85355 .42222 .85424 .42314 .85595 .42255 .85526 .42162 Mtetra
.685 .761 .91 r
.85526 .42162 .85595 .42255 .85767 .42191 .85697 .42099 Mtetra
.692 .765 .908 r
.85697 .42099 .85767 .42191 .85937 .42124 .85868 .42033 Mtetra
.699 .772 .909 r
.85868 .42033 .85937 .42124 .86108 .42051 .86039 .41964 Mtetra
.703 .783 .913 r
.86039 .41964 .86108 .42051 .86278 .41978 .8621 .41893 Mtetra
.736 .797 .902 r
.8621 .41893 .86278 .41978 .86447 .41894 .86379 .41805 Mtetra
.78 .801 .87 r
.86379 .41805 .86447 .41894 .86614 .4179 .86545 .4169 Mtetra
.697 .751 .893 r
.86545 .4169 .86614 .4179 .86786 .41731 .86716 .41621 Mtetra
.376 .569 .913 r
.86716 .41621 .86786 .41731 .86971 .41788 .86899 .4167 Mtetra
.78 .377 0 r
.86899 .4167 .86971 .41788 .87208 .42331 .87134 .42191 Mtetra
.975 .667 .332 r
.87134 .42191 .87208 .42331 .89525 .62221 .89452 .6212 Mtetra
.706 .267 0 r
.89452 .6212 .89525 .62221 .89757 .62605 .89685 .62517 Mtetra
.49 .704 .964 r
.89685 .62517 .89757 .62605 .89947 .62604 .89876 .62518 Mtetra
.689 .793 .929 r
.89876 .62518 .89947 .62604 .90131 .62534 .90059 .62448 Mtetra
.698 .799 .928 r
.90059 .62448 .90131 .62534 .90313 .62456 .90242 .62375 Mtetra
.417 .682 .972 r
.90242 .62375 .90313 .62456 .90504 .6246 .90435 .6239 Mtetra
.574 .793 .982 r
.90435 .6239 .90504 .6246 .90691 .62416 .90623 .62357 Mtetra
.846 .897 .874 r
.90623 .62357 .90691 .62416 .90863 .62245 .90797 .62201 Mtetra
.993 .797 .536 r
.90797 .62201 .90863 .62245 .90966 .6145 .9091 .61498 Mtetra
.977 .675 .339 r
.9091 .61498 .90966 .6145 .88914 .41516 .88851 .41469 Mtetra
.984 .832 .612 r
.88851 .41469 .88914 .41516 .89047 .41096 .8898 .41012 Mtetra
.746 .806 .9 r
.8898 .41012 .89047 .41096 .89217 .41009 .8915 .40919 Mtetra
.597 .733 .94 r
.8915 .40919 .89217 .41009 .89395 .40984 .89327 .4089 Mtetra
.531 .692 .942 r
.89327 .4089 .89395 .40984 .89575 .40982 .89507 .40884 Mtetra
.662 .745 .912 r
.89507 .40884 .89575 .40982 .8975 .40929 .89682 .40831 Mtetra
.671 .747 .907 r
.89682 .40831 .8975 .40929 .89924 .40874 .89856 .40774 Mtetra
.699 .754 .895 r
.89856 .40774 .89924 .40874 .90097 .40807 .90029 .40703 Mtetra
.773 .77 .85 r
.90029 .40703 .90097 .40807 .90266 .40701 .90196 .40585 Mtetra
.704 .725 .866 r
.90196 .40585 .90266 .40701 .90439 .40634 .90368 .40508 Mtetra
.504 .61 .891 r
.90368 .40508 .90439 .40634 .90624 .40661 .90551 .40525 Mtetra
.646 .26 0 r
.90551 .40525 .90624 .40661 .90865 .41163 .90787 .40985 Mtetra
.973 .661 .308 r
.90787 .40985 .90865 .41163 .93425 .61115 .9335 .60983 Mtetra
.663 .264 0 r
.9335 .60983 .93425 .61115 .93671 .61551 .936 .61455 Mtetra
.483 .678 .952 r
.936 .61455 .93671 .61551 .93865 .61556 .93795 .61462 Mtetra
.683 .777 .922 r
.93795 .61462 .93865 .61556 .94051 .61488 .93981 .61395 Mtetra
.729 .796 .905 r
.93981 .61395 .94051 .61488 .94233 .61394 .94164 .61305 Mtetra
.433 .669 .961 r
.94164 .61305 .94233 .61394 .94428 .61398 .9436 .61322 Mtetra
.561 .771 .977 r
.9436 .61322 .94428 .61398 .94618 .61359 .94551 .61295 Mtetra
.788 .883 .914 r
.94551 .61295 .94618 .61359 .94796 .61227 .94731 .61175 Mtetra
.993 .812 .558 r
.94731 .61175 .94796 .61227 .9491 .60575 .94851 .6057 Mtetra
.975 .669 .319 r
.94851 .6057 .9491 .60575 .92609 .40496 .92547 .40438 Mtetra
.989 .809 .57 r
.92547 .40438 .92609 .40496 .92728 .39984 .92662 .39888 Mtetra
.766 .79 .872 r
.92662 .39888 .92728 .39984 .92898 .39877 .92831 .39779 Mtetra
.629 .731 .92 r
.92831 .39779 .92898 .39877 .93076 .39838 .9301 .39739 Mtetra
.543 .688 .934 r
.9301 .39739 .93076 .39838 .93258 .3983 .93192 .39731 Mtetra
.753 .78 .875 r
.93192 .39731 .93258 .3983 .93429 .39729 .93363 .3963 Mtetra
.684 .753 .904 r
.93363 .3963 .93429 .39729 .93605 .39665 .93538 .39566 Mtetra
.489 .659 .936 r
.93538 .39566 .93605 .39665 .9379 .39675 .93724 .39576 Mtetra
.744 .326 0 r
.93724 .39576 .9379 .39675 .94036 .40158 .9397 .4006 Mtetra
.97 .655 .291 r
.9397 .4006 .94036 .40158 .96813 .60184 .96744 .60091 Mtetra
.739 .308 0 r
.96744 .60091 .96813 .60184 .9707 .60658 .97001 .60564 Mtetra
.035 .466 .879 r
.35761 .77069 .35855 .77145 .36003 .77207 .35909 .7713 Mtetra
.644 .762 .935 r
.35909 .7713 .36003 .77207 .36156 .77166 .36062 .77089 Mtetra
.81 .779 .824 r
.36062 .77089 .36156 .77166 .36314 .77023 .3622 .76946 Mtetra
.908 .738 .658 r
.3622 .76946 .36314 .77023 .36489 .76497 .36395 .7642 Mtetra
.937 .686 .534 r
.36395 .7642 .36489 .76497 .37482 .57426 .37394 .57344 Mtetra
.909 .728 .645 r
.37394 .57344 .37482 .57426 .3765 .56858 .37562 .56776 Mtetra
.778 .76 .837 r
.37562 .56776 .3765 .56858 .37798 .56747 .3771 .56665 Mtetra
.643 .737 .917 r
.3771 .56665 .37798 .56747 .37943 .5671 .37855 .56628 Mtetra
.513 .693 .95 r
.37855 .56628 .37943 .5671 .38086 .56708 .37998 .56626 Mtetra
.747 .758 .862 r
.37998 .56626 .38086 .56708 .38233 .56621 .38145 .56539 Mtetra
.698 .751 .893 r
.38145 .56539 .38233 .56621 .38379 .56561 .38291 .56479 Mtetra
.488 .685 .954 r
.38291 .56479 .38379 .56561 .38523 .56564 .38435 .56483 Mtetra
.924 .539 .24 r
.38435 .56483 .38523 .56564 .38651 .56942 .38563 .56865 Mtetra
.939 .683 .522 r
.38563 .56865 .38651 .56942 .38029 .75928 .37935 .75861 Mtetra
.932 .583 .342 r
.37935 .75861 .38029 .75928 .38159 .76472 .38065 .76399 Mtetra
0 .429 .849 r
.38065 .76399 .38159 .76472 .38309 .76526 .38215 .76466 Mtetra
.63 .803 .966 r
.38215 .76466 .38309 .76526 .38464 .76481 .3837 .76425 Mtetra
.801 .828 .872 r
.3837 .76425 .38464 .76481 .3862 .76379 .38527 .76306 Mtetra
.868 .773 .755 r
.38527 .76306 .3862 .76379 .38777 .76288 .38689 .76063 Mtetra
.84 .658 .656 r
.38689 .76063 .38777 .76288 .38935 .76152 .38861 .75576 Mtetra
.932 .68 .533 r
.38861 .75576 .38935 .76152 .39097 .75917 .39714 .56982 Mtetra
.579 .37 .561 r
.39714 .56982 .39097 .75917 .39293 .74748 .39881 .56378 Mtetra
.573 .365 .561 r
.39881 .56378 .39293 .74748 .40115 .56417 .40036 .5612 Mtetra
.705 .561 .689 r
.40036 .5612 .40115 .56417 .40273 .56054 .40186 .55961 Mtetra
.715 .733 .865 r
.40186 .55961 .40273 .56054 .40422 .55947 .40334 .5589 Mtetra
.624 .804 .969 r
.40334 .5589 .40422 .55947 .40568 .55907 .4048 .55853 Mtetra
.563 .795 .986 r
.4048 .55853 .40568 .55907 .40714 .55894 .40626 .55829 Mtetra
.682 .794 .934 r
.40626 .55829 .40714 .55894 .40861 .55844 .40773 .55776 Mtetra
.704 .787 .916 r
.40773 .55776 .40861 .55844 .41008 .55786 .4092 .55714 Mtetra
.703 .778 .91 r
.4092 .55714 .41008 .55786 .41155 .55728 .41068 .55652 Mtetra
.722 .772 .892 r
.41068 .55652 .41155 .55728 .41303 .55648 .41216 .55581 Mtetra
.695 .789 .923 r
.41216 .55581 .41303 .55648 .41451 .55588 .41363 .55523 Mtetra
.603 .775 .963 r
.41363 .55523 .41451 .55588 .41597 .55573 .4151 .55494 Mtetra
.176 .533 .923 r
.4151 .55494 .41597 .55573 .41737 .5575 .41654 .55544 Mtetra
.163 .282 .74 r
.41654 .55544 .41737 .5575 .41861 .56441 .41795 .55691 Mtetra
.318 .22 .583 r
.41795 .55691 .41861 .56441 .41428 .75169 .41929 .56084 Mtetra
0 0 .355 r
.41929 .56084 .41428 .75169 .41574 .7543 .41501 .7474 Mtetra
.143 .102 .548 r
.41501 .7474 .41574 .7543 .41727 .75514 .4164 .75255 Mtetra
.134 .227 .696 r
.4164 .75255 .41727 .75514 .41881 .75535 .41789 .7545 Mtetra
.375 .638 .958 r
.41789 .7545 .41881 .75535 .42037 .75517 .41944 .75475 Mtetra
.6 .848 .991 r
.41944 .75475 .42037 .75517 .42193 .75475 .421 .75434 Mtetra
.7 .87 .962 r
.421 .75434 .42193 .75475 .4235 .75421 .42257 .75366 Mtetra
.597 .811 .982 r
.42257 .75366 .4235 .75421 .42506 .75405 .42414 .75331 Mtetra
.618 .766 .951 r
.42414 .75331 .42506 .75405 .42662 .75381 .4257 .75297 Mtetra
.693 .762 .904 r
.4257 .75297 .42662 .75381 .4282 .75309 .42728 .75235 Mtetra
.81 .792 .835 r
.42728 .75235 .4282 .75309 .42982 .75048 .42887 .75096 Mtetra
.928 .969 .756 r
.42887 .75096 .42982 .75048 .43156 .74357 .4305 .74857 Mtetra
.009 0 .243 r
.4305 .74857 .43156 .74357 .43799 .5543 .43217 .7441 Mtetra
0 0 .352 r
.43217 .7441 .43799 .5543 .43956 .55058 .43852 .55675 Mtetra
0 0 .178 r
.43852 .55675 .43956 .55058 .44107 .54888 .44017 .54991 Mtetra
.896 .955 .613 r
.44017 .54991 .44107 .54888 .44258 .54781 .44171 .5471 Mtetra
.794 .79 .849 r
.44171 .5471 .44258 .54781 .44407 .54712 .44322 .54592 Mtetra
.664 .672 .847 r
.44322 .54592 .44407 .54712 .44555 .54667 .44471 .54544 Mtetra
.605 .644 .862 r
.44471 .54544 .44555 .54667 .44704 .54635 .44619 .54524 Mtetra
.611 .667 .879 r
.44619 .54524 .44704 .54635 .44852 .54602 .44767 .545 Mtetra
.622 .69 .892 r
.44767 .545 .44852 .54602 .45001 .54566 .44916 .54471 Mtetra
.628 .708 .904 r
.44916 .54471 .45001 .54566 .4515 .54527 .45065 .54439 Mtetra
.704 .746 .885 r
.45065 .54439 .4515 .54527 .453 .5445 .45214 .54375 Mtetra
.721 .777 .897 r
.45214 .54375 .453 .5445 .4545 .54374 .45364 .54304 Mtetra
.666 .779 .934 r
.45364 .54304 .4545 .54374 .45599 .54339 .45513 .54256 Mtetra
.215 .543 .928 r
.45513 .54256 .45599 .54339 .45744 .54483 .45661 .54305 Mtetra
.011 .218 .727 r
.45661 .54305 .45744 .54483 .45881 .55076 .45806 .54466 Mtetra
.335 .248 .607 r
.45806 .54466 .45881 .55076 .45669 .73936 .45949 .54778 Mtetra
.565 .359 .559 r
.45949 .54778 .45669 .73936 .45823 .74144 .46095 .54943 Mtetra
.57 .363 .56 r
.46095 .54943 .45823 .74144 .45981 .74103 .46246 .54832 Mtetra
.569 .361 .56 r
.46246 .54832 .45981 .74103 .46141 .74021 .46396 .54802 Mtetra
0 0 .388 r
.46396 .54802 .46141 .74021 .46298 .74062 .46225 .73013 Mtetra
.115 .058 .508 r
.46225 .73013 .46298 .74062 .46454 .74161 .46368 .73852 Mtetra
.038 .13 .632 r
.46368 .73852 .46454 .74161 .46611 .7423 .46521 .74125 Mtetra
.172 .474 .894 r
.46521 .74125 .46611 .7423 .46769 .74242 .46679 .74197 Mtetra
.487 .803 1 r
.46679 .74197 .46769 .74242 .46928 .74217 .46838 .74178 Mtetra
.617 .866 .99 r
.46838 .74178 .46928 .74217 .47088 .74178 .46997 .7413 Mtetra
.63 .845 .982 r
.46997 .7413 .47088 .74178 .47247 .74136 .47157 .74083 Mtetra
.621 .827 .979 r
.47157 .74083 .47247 .74136 .47406 .74094 .47316 .7404 Mtetra
.634 .828 .975 r
.47316 .7404 .47406 .74094 .47566 .7405 .47476 .73995 Mtetra
.632 .823 .974 r
.47476 .73995 .47566 .7405 .47726 .74006 .47636 .7395 Mtetra
.632 .82 .973 r
.47636 .7395 .47726 .74006 .47885 .73963 .47795 .73905 Mtetra
.643 .821 .968 r
.47795 .73905 .47885 .73963 .48045 .73916 .47955 .73858 Mtetra
.671 .824 .957 r
.47955 .73858 .48045 .73916 .48205 .73864 .48116 .73802 Mtetra
.692 .818 .943 r
.48116 .73802 .48205 .73864 .48366 .73807 .48276 .73739 Mtetra
.695 .804 .933 r
.48276 .73739 .48366 .73807 .48526 .73749 .48436 .73675 Mtetra
.678 .786 .931 r
.48436 .73675 .48526 .73749 .48686 .73696 .48597 .73619 Mtetra
.659 .772 .933 r
.48597 .73619 .48686 .73696 .48847 .73649 .48757 .7357 Mtetra
.651 .768 .934 r
.48757 .7357 .48847 .73649 .49007 .73604 .48918 .73525 Mtetra
.651 .767 .934 r
.48918 .73525 .49007 .73604 .49168 .73558 .49078 .73479 Mtetra
.652 .767 .933 r
.49078 .73479 .49168 .73558 .49328 .73513 .49239 .73433 Mtetra
.651 .766 .933 r
.49239 .73433 .49328 .73513 .49489 .73468 .494 .73388 Mtetra
.65 .765 .933 r
.494 .73388 .49489 .73468 .4965 .73423 .4956 .73343 Mtetra
.649 .764 .933 r
.4956 .73343 .4965 .73423 .4981 .73378 .49721 .73298 Mtetra
.49721 .73298 .4981 .73378 .49971 .73334 .49882 .73253 Mtetra
.648 .763 .933 r
.49882 .73253 .49971 .73334 .50133 .73289 .50044 .73209 Mtetra
.50044 .73209 .50133 .73289 .50294 .73245 .50205 .73164 Mtetra
.647 .763 .933 r
.50205 .73164 .50294 .73245 .50455 .73201 .50366 .7312 Mtetra
.647 .762 .933 r
.50366 .7312 .50455 .73201 .50616 .73157 .50527 .73076 Mtetra
.50527 .73076 .50616 .73157 .50778 .73113 .50689 .73032 Mtetra
.50689 .73032 .50778 .73113 .50939 .73069 .50851 .72988 Mtetra
.50851 .72988 .50939 .73069 .51101 .73025 .51012 .72944 Mtetra
.51012 .72944 .51101 .73025 .51263 .72981 .51174 .729 Mtetra
.646 .762 .933 r
.51174 .729 .51263 .72981 .51424 .72937 .51336 .72856 Mtetra
.51336 .72856 .51424 .72937 .51586 .72893 .51498 .72812 Mtetra
.51498 .72812 .51586 .72893 .51748 .72849 .5166 .72768 Mtetra
.5166 .72768 .51748 .72849 .5191 .72805 .51822 .72723 Mtetra
.51822 .72723 .5191 .72805 .52073 .72761 .51984 .72679 Mtetra
.646 .762 .934 r
.51984 .72679 .52073 .72761 .52235 .72716 .52147 .72635 Mtetra
.646 .763 .934 r
.52147 .72635 .52235 .72716 .52397 .72672 .52309 .72591 Mtetra
.52309 .72591 .52397 .72672 .5256 .72628 .52472 .72547 Mtetra
.52472 .72547 .5256 .72628 .52722 .72584 .52634 .72503 Mtetra
.645 .763 .935 r
.52634 .72503 .52722 .72584 .52885 .7254 .52797 .72459 Mtetra
.645 .764 .935 r
.52797 .72459 .52885 .7254 .53048 .72496 .5296 .72415 Mtetra
.5296 .72415 .53048 .72496 .53211 .72452 .53123 .72371 Mtetra
.644 .764 .936 r
.53123 .72371 .53211 .72452 .53374 .72408 .53286 .72328 Mtetra
.642 .764 .937 r
.53286 .72328 .53374 .72408 .53537 .72365 .53449 .72285 Mtetra
.64 .764 .938 r
.53449 .72285 .53537 .72365 .537 .72323 .53612 .72242 Mtetra
.64 .763 .937 r
.53612 .72242 .537 .72323 .53863 .7228 .53776 .722 Mtetra
.615 .756 .946 r
.53776 .722 .53863 .7228 .54027 .72252 .53939 .72166 Mtetra
.594 .736 .943 r
.53939 .72166 .54027 .72252 .5419 .72236 .54103 .7214 Mtetra
.659 .734 .905 r
.54103 .7214 .5419 .72236 .54354 .72182 .54266 .72091 Mtetra
.776 .772 .849 r
.54266 .72091 .54354 .72182 .54517 .72005 .5443 .71974 Mtetra
.918 .862 .77 r
.5443 .71974 .54517 .72005 .54677 .71468 .54592 .71724 Mtetra
0 0 0 r
.54592 .71724 .54677 .71468 .54714 .52287 .54754 .71333 Mtetra
.559 .35 .553 r
.54754 .71333 .54714 .52287 .54865 .5177 .54914 .70775 Mtetra
.564 .354 .554 r
.54914 .70775 .54865 .5177 .55019 .51675 .55076 .70567 Mtetra
.569 .358 .555 r
.55076 .70567 .55019 .51675 .55174 .51653 .55241 .7063 Mtetra
.568 .357 .555 r
.55241 .7063 .55174 .51653 .55329 .51628 .55405 .7066 Mtetra
.565 .355 .554 r
.55405 .7066 .55329 .51628 .55484 .51539 .55568 .70482 Mtetra
.567 .357 .555 r
.55568 .70482 .55484 .51539 .55639 .51505 .55732 .7048 Mtetra
.574 .362 .555 r
.55732 .7048 .55639 .51505 .55796 .51693 .559 .70871 Mtetra
.559 .70871 .55796 .51693 .5615 .70834 .56069 .71284 Mtetra
.637 .347 .462 r
.56069 .71284 .5615 .70834 .56322 .71421 .56236 .71437 Mtetra
.6 .952 .863 r
.56236 .71437 .56322 .71421 .56487 .71447 .564 .71344 Mtetra
.94 .725 .586 r
.564 .71344 .56487 .71447 .56644 .707 .56555 .70405 Mtetra
.956 .687 .487 r
.56555 .70405 .56644 .707 .56571 .5129 .56489 .51139 Mtetra
.864 .702 .679 r
.56489 .51139 .56571 .5129 .56723 .50893 .56641 .50774 Mtetra
.739 .706 .82 r
.56641 .50774 .56723 .50893 .56877 .50803 .56796 .50674 Mtetra
.612 .645 .859 r
.56796 .50674 .56877 .50803 .57033 .50777 .56952 .5065 Mtetra
.348 .513 .879 r
.56952 .5065 .57033 .50777 .5719 .50799 .57109 .50709 Mtetra
.694 .214 0 r
.57109 .50709 .5719 .50799 .57347 .50856 .57269 .50933 Mtetra
.902 .567 .402 r
.57269 .50933 .57347 .50856 .57506 .50949 .57436 .51647 Mtetra
.948 .673 .482 r
.57436 .51647 .57506 .50949 .57664 .51039 .57878 .70305 Mtetra
.569 .358 .555 r
.57878 .70305 .57664 .51039 .5782 .51014 .58046 .7037 Mtetra
.566 .356 .554 r
.58046 .7037 .5782 .51014 .57976 .50947 .58211 .70275 Mtetra
.565 .355 .554 r
.58211 .70275 .57976 .50947 .58132 .50855 .58374 .70097 Mtetra
.58374 .70097 .58132 .50855 .58288 .50745 .58538 .69939 Mtetra
.567 .356 .554 r
.58538 .69939 .58288 .50745 .58444 .50697 .58704 .69884 Mtetra
.57 .359 .555 r
.58704 .69884 .58444 .50697 .58604 .50826 .58874 .70075 Mtetra
.573 .361 .555 r
.58874 .70075 .58604 .50826 .59119 .69801 .59047 .70424 Mtetra
.637 .364 .488 r
.59047 .70424 .59119 .69801 .59301 .70578 .59218 .70621 Mtetra
.624 .115 .02 r
.59218 .70621 .59301 .70578 .59473 .70794 .59387 .70711 Mtetra
.588 .744 .951 r
.59387 .70711 .59473 .70794 .5964 .70783 .59555 .70685 Mtetra
.67 .737 .9 r
.59555 .70685 .5964 .70783 .59807 .70723 .59721 .70631 Mtetra
.69 .755 .902 r
.59721 .70631 .59807 .70723 .59973 .70645 .59888 .70567 Mtetra
.639 .775 .946 r
.59888 .70567 .59973 .70645 .6014 .70596 .60055 .70523 Mtetra
.636 .786 .954 r
.60055 .70523 .6014 .70596 .60307 .70548 .60222 .7048 Mtetra
.616 .793 .966 r
.60222 .7048 .60307 .70548 .60474 .70503 .6039 .70441 Mtetra
.517 .774 .99 r
.6039 .70441 .60474 .70503 .60642 .70471 .60558 .70424 Mtetra
.593 .845 .992 r
.60558 .70424 .60642 .70471 .60809 .70428 .60725 .70382 Mtetra
.766 .883 .93 r
.60725 .70382 .60809 .70428 .60976 .70363 .60892 .70282 Mtetra
.891 .79 .743 r
.60892 .70282 .60976 .70363 .61142 .70258 .61054 .7001 Mtetra
.858 .663 .637 r
.61054 .7001 .61142 .70258 .61307 .70094 .61209 .69456 Mtetra
.956 .683 .479 r
.61209 .69456 .61307 .70094 .61468 .69784 .60894 .50345 Mtetra
.577 .368 .561 r
.60894 .50345 .61468 .69784 .61144 .50811 .6104 .49791 Mtetra
.642 .448 .605 r
.6104 .49791 .61144 .50811 .61276 .49779 .61193 .49534 Mtetra
.72 .593 .712 r
.61193 .49534 .61276 .49779 .61428 .49476 .61348 .49382 Mtetra
.678 .737 .895 r
.61348 .49382 .61428 .49476 .61585 .49401 .61506 .49327 Mtetra
.584 .755 .959 r
.61506 .49327 .61585 .49401 .61744 .49376 .61665 .49302 Mtetra
.54 .739 .967 r
.61665 .49302 .61744 .49376 .61904 .49372 .61825 .49288 Mtetra
.658 .755 .921 r
.61825 .49288 .61904 .49372 .62063 .49326 .61983 .49241 Mtetra
.674 .758 .914 r
.61983 .49241 .62063 .49326 .62221 .49275 .62142 .49188 Mtetra
.695 .757 .9 r
.62142 .49188 .62221 .49275 .62379 .49217 .623 .49125 Mtetra
.776 .767 .845 r
.623 .49125 .62379 .49217 .62536 .49109 .62457 .49011 Mtetra
.715 .741 .872 r
.62457 .49011 .62536 .49109 .62695 .49039 .62615 .48936 Mtetra
.526 .658 .919 r
.62615 .48936 .62695 .49039 .62855 .49046 .62776 .48938 Mtetra
.871 .458 .016 r
.62776 .48938 .62855 .49046 .6303 .49481 .62949 .49356 Mtetra
.966 .685 .448 r
.62949 .49356 .6303 .49481 .6382 .69006 .63736 .68897 Mtetra
.907 .51 .106 r
.63736 .68897 .6382 .69006 .64007 .69506 .63924 .69419 Mtetra
.162 .514 .915 r
.63924 .69419 .64007 .69506 .6418 .6957 .64097 .69485 Mtetra
.642 .761 .935 r
.64097 .69485 .6418 .6957 .6435 .69525 .64267 .69441 Mtetra
.82 .798 .831 r
.64267 .69441 .6435 .69525 .64516 .69372 .64433 .69287 Mtetra
.94 .761 .633 r
.64433 .69287 .64516 .69372 .64668 .68816 .64585 .68732 Mtetra
.966 .69 .458 r
.64585 .68732 .64668 .68816 .6415 .4922 .64071 .49131 Mtetra
.939 .751 .621 r
.64071 .49131 .6415 .4922 .64291 .48646 .64213 .48555 Mtetra
.773 .77 .85 r
.64213 .48555 .64291 .48646 .64449 .48535 .6437 .48444 Mtetra
.64 .733 .916 r
.6437 .48444 .64449 .48535 .64609 .48496 .64531 .48404 Mtetra
.528 .688 .94 r
.64531 .48404 .64609 .48496 .64771 .48492 .64692 .48401 Mtetra
.75 .765 .865 r
.64692 .48401 .64771 .48492 .64929 .48398 .64851 .48306 Mtetra
.692 .749 .896 r
.64851 .48306 .64929 .48398 .65089 .48335 .65011 .48243 Mtetra
.496 .672 .942 r
.65011 .48243 .65089 .48335 .65251 .48341 .65173 .48249 Mtetra
.884 .468 .052 r
.65173 .48249 .65251 .48341 .65431 .48771 .65352 .48678 Mtetra
.968 .684 .44 r
.65352 .48678 .65431 .48771 .66366 .68302 .66284 .68215 Mtetra
.905 .5 .115 r
.66284 .68215 .66366 .68302 .66559 .68803 .66476 .68717 Mtetra
.104 .478 .896 r
.66476 .68717 .66559 .68803 .66735 .68879 .66652 .68793 Mtetra
.625 .755 .94 r
.66652 .68793 .66735 .68879 .66906 .6884 .66824 .68754 Mtetra
.807 .798 .843 r
.66824 .68754 .66906 .6884 .67074 .68699 .66991 .68613 Mtetra
.936 .769 .649 r
.66991 .68613 .67074 .68699 .67226 .6821 .67144 .68124 Mtetra
.968 .69 .449 r
.67144 .68124 .67226 .6821 .66566 .4862 .66488 .48529 Mtetra
.947 .746 .599 r
.66488 .48529 .66566 .4862 .66701 .47948 .66623 .47857 Mtetra
.794 .776 .836 r
.66623 .47857 .66701 .47948 .66858 .47819 .66781 .47728 Mtetra
.626 .729 .921 r
.66781 .47728 .66858 .47819 .6702 .47784 .66943 .47693 Mtetra
.487 .67 .945 r
.66943 .47693 .6702 .47784 .67184 .47791 .67107 .477 Mtetra
.634 .734 .92 r
.67107 .477 .67184 .47791 .67346 .47752 .67269 .47662 Mtetra
.657 .744 .914 r
.67269 .47662 .67346 .47752 .67508 .47704 .67431 .47615 Mtetra
.663 .747 .913 r
.67431 .47615 .67508 .47704 .6767 .47654 .67593 .47565 Mtetra
.763 .777 .864 r
.67593 .47565 .6767 .47654 .67829 .47551 .67752 .47462 Mtetra
.717 .765 .89 r
.67752 .47462 .67829 .47551 .6799 .47475 .67913 .47387 Mtetra
.527 .695 .946 r
.67913 .47387 .6799 .47475 .68154 .47469 .68077 .47382 Mtetra
.879 .46 .042 r
.68077 .47382 .68154 .47469 .68338 .4788 .68262 .47815 Mtetra
.97 .682 .429 r
.68262 .47815 .68338 .4788 .69453 .67477 .69374 .67432 Mtetra
.904 .492 .161 r
.69374 .67432 .69453 .67477 .69653 .6798 .69573 .67914 Mtetra
.124 .547 .92 r
.69573 .67914 .69653 .6798 .69831 .68052 .6975 .67968 Mtetra
.678 .778 .926 r
.6975 .67968 .69831 .68052 .70004 .68002 .69923 .67907 Mtetra
.787 .782 .848 r
.69923 .67907 .70004 .68002 .70173 .67865 .70092 .67779 Mtetra
.834 .804 .822 r
.70092 .67779 .70173 .67865 .70332 .67545 .70259 .67611 Mtetra
.818 .951 .606 r
.70259 .67611 .70332 .67545 .70462 .66664 .70422 .67363 Mtetra
.287 .084 .42 r
.70422 .67363 .70462 .66664 .69637 .47429 .70574 .66908 Mtetra
.087 .002 .453 r
.70574 .66908 .69637 .47429 .69786 .47109 .69749 .47773 Mtetra
.04 0 .341 r
.69749 .47773 .69786 .47109 .69943 .46952 .69878 .47076 Mtetra
.627 .779 .328 r
.69878 .47076 .69943 .46952 .70104 .46852 .70029 .46788 Mtetra
.791 .843 .891 r
.70029 .46788 .70104 .46852 .70266 .46785 .70189 .46677 Mtetra
.66 .708 .883 r
.70189 .46677 .70266 .46785 .70429 .46736 .70352 .46627 Mtetra
.61 .687 .897 r
.70352 .46627 .70429 .46736 .70593 .46696 .70517 .466 Mtetra
.714 .753 .883 r
.70517 .466 .70593 .46696 .70755 .46607 .70679 .46525 Mtetra
.726 .786 .9 r
.70679 .46525 .70755 .46607 .70917 .46526 .70841 .46446 Mtetra
.664 .774 .932 r
.70841 .46446 .70917 .46526 .71081 .4649 .71005 .46394 Mtetra
.389 .609 .937 r
.71005 .46394 .71081 .4649 .71256 .46645 .71173 .46427 Mtetra
.32 .379 .767 r
.71173 .46427 .71256 .46645 .71459 .47261 .71348 .46558 Mtetra
.391 .288 .617 r
.71348 .46558 .71459 .47261 .72749 .66592 .71534 .46893 Mtetra
.105 .022 .468 r
.71534 .46893 .72749 .66592 .72943 .66879 .72814 .65951 Mtetra
.264 .187 .578 r
.72814 .65951 .72943 .66879 .73125 .66957 .7303 .66616 Mtetra
.298 .3 .694 r
.7303 .66616 .73125 .66957 .73304 .66972 .73221 .6684 Mtetra
.362 .529 .887 r
.73221 .6684 .73304 .66972 .73482 .66986 .73403 .66902 Mtetra
.555 .734 .959 r
.73403 .66902 .73482 .66986 .73659 .6697 .7358 .66884 Mtetra
.704 .786 .915 r
.7358 .66884 .73659 .6697 .73833 .66893 .73754 .66811 Mtetra
.818 .815 .847 r
.73754 .66811 .73833 .66893 .73995 .66627 .73923 .66663 Mtetra
.898 .979 .696 r
.73923 .66663 .73995 .66627 .74129 .65913 .74086 .66415 Mtetra
.128 0 .337 r
.74086 .66415 .74129 .65913 .73086 .46427 .74236 .65945 Mtetra
.101 .014 .461 r
.74236 .65945 .73086 .46427 .7323 .46036 .732 .46665 Mtetra
.02 0 .334 r
.732 .46665 .7323 .46036 .73387 .4586 .73324 .45967 Mtetra
.695 .828 .386 r
.73324 .45967 .73387 .4586 .73548 .45749 .73474 .45677 Mtetra
.793 .826 .878 r
.73474 .45677 .73548 .45749 .73712 .45684 .73635 .4556 Mtetra
.634 .671 .868 r
.73635 .4556 .73712 .45684 .73878 .45646 .73802 .45523 Mtetra
.567 .642 .884 r
.73802 .45523 .73878 .45646 .74045 .45621 .7397 .45515 Mtetra
.606 .693 .905 r
.7397 .45515 .74045 .45621 .74212 .45584 .74137 .45489 Mtetra
.65 .736 .912 r
.74137 .45489 .74212 .45584 .74377 .45534 .74303 .45444 Mtetra
.665 .75 .914 r
.74303 .45444 .74377 .45534 .74543 .45481 .74469 .45392 Mtetra
.72 .773 .894 r
.74469 .45392 .74543 .45481 .74706 .45394 .74633 .45314 Mtetra
.729 .795 .905 r
.74633 .45314 .74706 .45394 .7487 .4531 .74796 .45233 Mtetra
.67 .787 .937 r
.74796 .45233 .7487 .4531 .75036 .45268 .74962 .45178 Mtetra
.428 .644 .948 r
.74962 .45178 .75036 .45268 .75214 .4539 .75133 .45199 Mtetra
.299 .392 .79 r
.75133 .45199 .75214 .4539 .75421 .45913 .75312 .45323 Mtetra
.359 .279 .629 r
.75312 .45323 .75421 .45913 .76961 .65384 .75505 .4565 Mtetra
.121 .036 .477 r
.75505 .4565 .76961 .65384 .77167 .65746 .77031 .64828 Mtetra
.257 .185 .58 r
.77031 .64828 .77167 .65746 .77355 .65844 .7726 .65514 Mtetra
.284 .297 .698 r
.7726 .65514 .77355 .65844 .77538 .65871 .77458 .65744 Mtetra
.35 .532 .893 r
.77458 .65744 .77538 .65871 .7772 .65878 .77644 .65807 Mtetra
.566 .78 .979 r
.77644 .65807 .7772 .65878 .779 .65856 .77823 .6578 Mtetra
.721 .818 .925 r
.77823 .6578 .779 .65856 .78075 .65778 .77999 .65698 Mtetra
.816 .825 .857 r
.77999 .65698 .78075 .65778 .7824 .65548 .7817 .65555 Mtetra
.917 .977 .766 r
.7817 .65555 .7824 .65548 .78379 .64975 .78334 .65326 Mtetra
.023 0 .249 r
.78334 .65326 .78379 .64975 .77088 .45368 .78486 .64927 Mtetra
.129 .038 .475 r
.78486 .64927 .77088 .45368 .77221 .44853 .77233 .45895 Mtetra
.086 0 .404 r
.77233 .45895 .77221 .44853 .77377 .44655 .77323 .4481 Mtetra
0 0 0 r
.77323 .4481 .77377 .44655 .77539 .44532 .77469 .4448 Mtetra
.843 .886 .871 r
.77469 .4448 .77539 .44532 .77705 .44457 .77629 .44336 Mtetra
.651 .685 .869 r
.77629 .44336 .77705 .44457 .77873 .44413 .77798 .4429 Mtetra
.581 .65 .883 r
.77798 .4429 .77873 .44413 .78042 .44384 .77968 .44276 Mtetra
.599 .689 .905 r
.77968 .44276 .78042 .44384 .78211 .44346 .78138 .44252 Mtetra
.654 .742 .914 r
.78138 .44252 .78211 .44346 .78379 .44294 .78306 .44204 Mtetra
.668 .756 .916 r
.78306 .44204 .78379 .44294 .78547 .44238 .78474 .4415 Mtetra
.716 .778 .901 r
.78474 .4415 .78547 .44238 .78712 .44155 .7864 .44074 Mtetra
.737 .801 .903 r
.7864 .44074 .78712 .44155 .78877 .44063 .78806 .43988 Mtetra
.686 .801 .936 r
.78806 .43988 .78877 .44063 .79045 .44011 .78973 .43925 Mtetra
.493 .693 .957 r
.78973 .43925 .79045 .44011 .79224 .44089 .79146 .43927 Mtetra
.318 .441 .828 r
.79146 .43927 .79224 .44089 .79429 .44474 .79327 .44027 Mtetra
.36 .306 .661 r
.79327 .44027 .79429 .44474 .8122 .63978 .79521 .44279 Mtetra
.151 .061 .49 r
.79521 .44279 .8122 .63978 .81448 .64508 .81254 .63003 Mtetra
.226 .144 .549 r
.81254 .63003 .81448 .64508 .81643 .64632 .81542 .64243 Mtetra
.283 .276 .675 r
.81542 .64243 .81643 .64632 .8183 .64671 .8175 .64523 Mtetra
.318 .476 .859 r
.8175 .64523 .8183 .64671 .82016 .6468 .81942 .64612 Mtetra
.526 .771 .987 r
.81942 .64612 .82016 .6468 .82199 .64666 .82125 .64593 Mtetra
.704 .826 .94 r
.82125 .64593 .82199 .64666 .82378 .64595 .82303 .64517 Mtetra
.808 .835 .871 r
.82303 .64517 .82378 .64595 .82545 .64392 .82477 .64381 Mtetra
.917 .965 .792 r
.82477 .64381 .82545 .64392 .82684 .63861 .82643 .64162 Mtetra
0 0 .213 r
.82643 .64162 .82684 .63861 .81145 .44219 .82795 .63787 Mtetra
.174 .073 .492 r
.82795 .63787 .81145 .44219 .81267 .43624 .81381 .45642 Mtetra
.129 .021 .452 r
.81381 .45642 .81267 .43624 .81423 .43421 .81377 .43619 Mtetra
0 0 .01 r
.81377 .43619 .81423 .43421 .81587 .43297 .81521 .43264 Mtetra
.873 .937 .859 r
.81521 .43264 .81587 .43297 .81754 .43224 .81681 .43102 Mtetra
.646 .683 .87 r
.81681 .43102 .81754 .43224 .81926 .43187 .81851 .43057 Mtetra
.566 .632 .876 r
.81851 .43057 .81926 .43187 .82099 .43169 .82026 .43051 Mtetra
.563 .652 .896 r
.82026 .43051 .82099 .43169 .82272 .43147 .822 .43043 Mtetra
.634 .713 .904 r
.822 .43043 .82272 .43147 .82443 .43107 .82371 .43004 Mtetra
.643 .719 .903 r
.82371 .43004 .82443 .43107 .82615 .43063 .82543 .4296 Mtetra
.677 .734 .894 r
.82543 .4296 .82615 .43063 .82785 .43009 .82713 .42901 Mtetra
.701 .733 .876 r
.82713 .42901 .82785 .43009 .82955 .42947 .82882 .42829 Mtetra
.641 .69 .88 r
.82882 .42829 .82955 .42947 .83125 .42897 .83053 .42787 Mtetra
.326 .54 .908 r
.83053 .42787 .83125 .42897 .833 .42888 .83235 .42848 Mtetra
.82 .351 0 r
.83235 .42848 .833 .42888 .83482 .42951 .83444 .43193 Mtetra
.973 .669 .368 r
.83444 .43193 .83482 .42951 .83668 .43055 .85452 .62347 Mtetra
.576 .363 .555 r
.85452 .62347 .83668 .43055 .83854 .43155 .857 .62978 Mtetra
.568 .357 .555 r
.857 .62978 .83854 .43155 .84031 .43156 .85892 .63031 Mtetra
.566 .356 .554 r
.85892 .63031 .84031 .43156 .842 .43074 .8607 .62931 Mtetra
.562 .353 .554 r
.8607 .62931 .842 .43074 .8436 .42901 .8622 .6254 Mtetra
.152 .06 .489 r
.8622 .6254 .8436 .42901 .84515 .42681 .84501 .43162 Mtetra
0 0 .302 r
.84501 .43162 .84515 .42681 .84674 .42499 .84615 .42523 Mtetra
.904 .972 .671 r
.84615 .42523 .84674 .42499 .84838 .42373 .84768 .42275 Mtetra
.714 .758 .887 r
.84768 .42275 .84838 .42373 .85009 .42312 .84937 .42197 Mtetra
.634 .692 .887 r
.84937 .42197 .85009 .42312 .85182 .42267 .85111 .42158 Mtetra
.62 .699 .901 r
.85111 .42158 .85182 .42267 .85355 .42222 .85285 .42124 Mtetra
.678 .749 .905 r
.85285 .42124 .85355 .42222 .85526 .42162 .85456 .42065 Mtetra
.683 .751 .903 r
.85456 .42065 .85526 .42162 .85697 .42099 .85628 .42002 Mtetra
.69 .755 .901 r
.85628 .42002 .85697 .42099 .85868 .42033 .85799 .41937 Mtetra
.698 .759 .899 r
.85799 .41937 .85868 .42033 .86039 .41964 .85969 .41867 Mtetra
.703 .761 .897 r
.85969 .41867 .86039 .41964 .8621 .41893 .8614 .41795 Mtetra
.736 .77 .88 r
.8614 .41795 .8621 .41893 .86379 .41805 .86309 .41705 Mtetra
.779 .777 .851 r
.86309 .41705 .86379 .41805 .86545 .4169 .86474 .41585 Mtetra
.704 .742 .881 r
.86474 .41585 .86545 .4169 .86716 .41621 .86645 .41511 Mtetra
.391 .578 .914 r
.86645 .41511 .86716 .41621 .86899 .4167 .86828 .41555 Mtetra
.78 .372 0 r
.86828 .41555 .86899 .4167 .87134 .42191 .87061 .42061 Mtetra
.975 .667 .333 r
.87061 .42061 .87134 .42191 .89452 .6212 .89379 .62021 Mtetra
.721 .283 0 r
.89379 .62021 .89452 .6212 .89685 .62517 .89613 .62429 Mtetra
.488 .699 .962 r
.89613 .62429 .89685 .62517 .89876 .62518 .89804 .6243 Mtetra
.685 .791 .93 r
.89804 .6243 .89876 .62518 .90059 .62448 .89988 .62362 Mtetra
.691 .796 .93 r
.89988 .62362 .90059 .62448 .90242 .62375 .90171 .62292 Mtetra
.401 .668 .968 r
.90171 .62292 .90242 .62375 .90435 .6239 .90365 .62313 Mtetra
.57 .77 .973 r
.90365 .62313 .90435 .6239 .90623 .62357 .90553 .62284 Mtetra
.83 .862 .87 r
.90553 .62284 .90623 .62357 .90797 .62201 .90728 .62135 Mtetra
.986 .79 .558 r
.90728 .62135 .90797 .62201 .9091 .61498 .90845 .6147 Mtetra
.977 .675 .342 r
.90845 .6147 .9091 .61498 .88851 .41469 .88786 .41397 Mtetra
.973 .806 .614 r
.88786 .41397 .88851 .41469 .8898 .41012 .88912 .40919 Mtetra
.747 .785 .884 r
.88912 .40919 .8898 .41012 .8915 .40919 .89082 .40823 Mtetra
.604 .724 .929 r
.89082 .40823 .8915 .40919 .89327 .4089 .89259 .40793 Mtetra
.538 .688 .936 r
.89259 .40793 .89327 .4089 .89507 .40884 .89439 .40786 Mtetra
.665 .744 .909 r
.89439 .40786 .89507 .40884 .89682 .40831 .89613 .40731 Mtetra
.675 .746 .904 r
.89613 .40731 .89682 .40831 .89856 .40774 .89787 .40672 Mtetra
.704 .753 .89 r
.89787 .40672 .89856 .40774 .90029 .40703 .8996 .40598 Mtetra
.78 .773 .846 r
.8996 .40598 .90029 .40703 .90196 .40585 .90127 .40475 Mtetra
.714 .74 .872 r
.90127 .40475 .90196 .40585 .90368 .40508 .90299 .40394 Mtetra
.505 .633 .91 r
.90299 .40394 .90368 .40508 .90551 .40525 .90481 .40405 Mtetra
.676 .271 0 r
.90481 .40405 .90551 .40525 .90787 .40985 .90715 .40845 Mtetra
.973 .661 .31 r
.90715 .40845 .90787 .40985 .9335 .60983 .93277 .60864 Mtetra
.721 .31 0 r
.93277 .60864 .9335 .60983 .936 .61455 .93529 .61359 Mtetra
.476 .674 .952 r
.93529 .61359 .936 .61455 .93795 .61462 .93724 .61368 Mtetra
.679 .775 .923 r
.93724 .61368 .93795 .61462 .93981 .61395 .93911 .61303 Mtetra
.724 .795 .908 r
.93911 .61303 .93981 .61395 .94164 .61305 .94094 .61215 Mtetra
.409 .655 .959 r
.94094 .61215 .94164 .61305 .9436 .61322 .94291 .61239 Mtetra
.553 .749 .968 r
.94291 .61239 .9436 .61322 .94551 .61295 .94483 .61218 Mtetra
.775 .847 .906 r
.94483 .61218 .94551 .61295 .94731 .61175 .94664 .61104 Mtetra
.985 .803 .578 r
.94664 .61104 .94731 .61175 .94851 .6057 .94787 .60523 Mtetra
.975 .669 .32 r
.94787 .60523 .94851 .6057 .92547 .40438 .92484 .40369 Mtetra
.986 .797 .567 r
.92484 .40369 .92547 .40438 .92662 .39888 .92595 .39793 Mtetra
.77 .792 .871 r
.92595 .39793 .92662 .39888 .92831 .39779 .92765 .39681 Mtetra
.63 .734 .922 r
.92765 .39681 .92831 .39779 .9301 .39739 .92943 .39641 Mtetra
.541 .69 .936 r
.92943 .39641 .9301 .39739 .93192 .39731 .93126 .39633 Mtetra
.754 .781 .875 r
.93126 .39633 .93192 .39731 .93363 .3963 .93296 .39531 Mtetra
.685 .755 .904 r
.93296 .39531 .93363 .3963 .93538 .39566 .93472 .39466 Mtetra
.489 .659 .937 r
.93472 .39466 .93538 .39566 .93724 .39576 .93657 .39476 Mtetra
.746 .327 0 r
.93657 .39476 .93724 .39576 .9397 .4006 .93904 .39962 Mtetra
.97 .655 .291 r
.93904 .39962 .9397 .4006 .96744 .60091 .96675 .59997 Mtetra
.739 .307 0 r
.96675 .59997 .96744 .60091 .97001 .60564 .96933 .60469 Mtetra
.037 .467 .88 r
.35667 .76992 .35761 .77069 .35909 .7713 .35815 .77054 Mtetra
.644 .762 .935 r
.35815 .77054 .35909 .7713 .36062 .77089 .35968 .77013 Mtetra
.81 .779 .824 r
.35968 .77013 .36062 .77089 .3622 .76946 .36126 .7687 Mtetra
.908 .738 .659 r
.36126 .7687 .3622 .76946 .36395 .7642 .36301 .76344 Mtetra
.937 .686 .534 r
.36301 .76344 .36395 .7642 .37394 .57344 .37305 .57262 Mtetra
.909 .728 .645 r
.37305 .57262 .37394 .57344 .37562 .56776 .37474 .56693 Mtetra
.778 .76 .837 r
.37474 .56693 .37562 .56776 .3771 .56665 .37622 .56582 Mtetra
.642 .737 .917 r
.37622 .56582 .3771 .56665 .37855 .56628 .37767 .56545 Mtetra
.512 .693 .95 r
.37767 .56545 .37855 .56628 .37998 .56626 .3791 .56544 Mtetra
.747 .758 .862 r
.3791 .56544 .37998 .56626 .38145 .56539 .38057 .56457 Mtetra
.698 .751 .893 r
.38057 .56457 .38145 .56539 .38291 .56479 .38203 .56397 Mtetra
.486 .684 .954 r
.38203 .56397 .38291 .56479 .38435 .56483 .38347 .56401 Mtetra
.925 .541 .244 r
.38347 .56401 .38435 .56483 .38563 .56865 .38475 .56788 Mtetra
.939 .683 .522 r
.38475 .56788 .38563 .56865 .37935 .75861 .37841 .75794 Mtetra
.932 .581 .339 r
.37841 .75794 .37935 .75861 .38065 .76399 .37972 .76326 Mtetra
0 .351 .789 r
.37972 .76326 .38065 .76399 .38215 .76466 .38121 .76405 Mtetra
.618 .797 .967 r
.38121 .76405 .38215 .76466 .3837 .76425 .38275 .76368 Mtetra
.817 .82 .852 r
.38275 .76368 .3837 .76425 .38527 .76306 .38434 .76232 Mtetra
.905 .749 .678 r
.38434 .76232 .38527 .76306 .38689 .76063 .38603 .75795 Mtetra
.937 .684 .53 r
.38603 .75795 .38689 .76063 .38861 .75576 .39483 .56859 Mtetra
.581 .372 .562 r
.39483 .56859 .38861 .75576 .39714 .56982 .39656 .56119 Mtetra
.628 .444 .614 r
.39656 .56119 .39714 .56982 .39881 .56378 .39806 .55959 Mtetra
.623 .48 .666 r
.39806 .55959 .39881 .56378 .40036 .5612 .39953 .55895 Mtetra
.611 .538 .748 r
.39953 .55895 .40036 .5612 .40186 .55961 .40099 .5587 Mtetra
.642 .717 .902 r
.40099 .5587 .40186 .55961 .40334 .5589 .40245 .55833 Mtetra
.616 .799 .97 r
.40245 .55833 .40334 .5589 .4048 .55853 .40392 .55798 Mtetra
.606 .803 .976 r
.40392 .55798 .4048 .55853 .40626 .55829 .40538 .55765 Mtetra
.656 .79 .946 r
.40538 .55765 .40626 .55829 .40773 .55776 .40685 .55721 Mtetra
.667 .817 .955 r
.40685 .55721 .40773 .55776 .4092 .55714 .40832 .55671 Mtetra
.664 .852 .972 r
.40832 .55671 .4092 .55714 .41068 .55652 .40979 .55619 Mtetra
.671 .881 .976 r
.40979 .55619 .41068 .55652 .41216 .55581 .41127 .55562 Mtetra
.628 .909 .983 r
.41127 .55562 .41216 .55581 .41363 .55523 .41274 .55506 Mtetra
.573 .9 .982 r
.41274 .55506 .41363 .55523 .4151 .55494 .41421 .55459 Mtetra
.675 .878 .974 r
.41421 .55459 .4151 .55494 .41654 .55544 .41569 .55401 Mtetra
.628 .624 .827 r
.41569 .55401 .41654 .55544 .41795 .55691 .41716 .5537 Mtetra
.54 .45 .702 r
.41716 .5537 .41795 .55691 .41929 .56084 .41861 .55403 Mtetra
.265 .188 .579 r
.41861 .55403 .41929 .56084 .41501 .7474 .41994 .55809 Mtetra
0 0 .342 r
.41994 .55809 .41501 .7474 .4164 .75255 .41559 .74816 Mtetra
0 0 .455 r
.41559 .74816 .4164 .75255 .41789 .7545 .41699 .75302 Mtetra
.338 .483 .857 r
.41699 .75302 .41789 .7545 .41944 .75475 .41852 .7537 Mtetra
.647 .705 .889 r
.41852 .7537 .41944 .75475 .421 .75434 .42009 .75329 Mtetra
.719 .725 .854 r
.42009 .75329 .421 .75434 .42257 .75366 .42167 .75248 Mtetra
.662 .687 .863 r
.42167 .75248 .42257 .75366 .42414 .75331 .42324 .752 Mtetra
.64 .656 .85 r
.42324 .752 .42414 .75331 .4257 .75297 .4248 .75161 Mtetra
.653 .655 .839 r
.4248 .75161 .4257 .75297 .42728 .75235 .42637 .75115 Mtetra
.634 .672 .869 r
.42637 .75115 .42728 .75235 .42887 .75096 .42794 .7508 Mtetra
.608 .916 .977 r
.42794 .7508 .42887 .75096 .4305 .74857 .42952 .75021 Mtetra
.117 0 .032 r
.42952 .75021 .4305 .74857 .43217 .7441 .43111 .74899 Mtetra
0 0 .221 r
.43111 .74899 .43217 .7441 .43852 .55675 .43279 .74441 Mtetra
0 0 .336 r
.43279 .74441 .43852 .55675 .44017 .54991 .4392 .55319 Mtetra
.796 .782 .279 r
.4392 .55319 .44017 .54991 .44171 .5471 .44083 .54698 Mtetra
.885 .913 .84 r
.44083 .54698 .44171 .5471 .44322 .54592 .44235 .54531 Mtetra
.67 .804 .947 r
.44235 .54531 .44322 .54592 .44471 .54544 .44384 .54481 Mtetra
.515 .752 .982 r
.44384 .54481 .44471 .54544 .44619 .54524 .44532 .5447 Mtetra
.578 .802 .984 r
.44532 .5447 .44619 .54524 .44767 .545 .44681 .54442 Mtetra
.637 .805 .963 r
.44681 .54442 .44767 .545 .44916 .54471 .4483 .544 Mtetra
.649 .774 .939 r
.4483 .544 .44916 .54471 .45065 .54439 .44979 .54358 Mtetra
.673 .753 .911 r
.44979 .54358 .45065 .54439 .45214 .54375 .45128 .54308 Mtetra
.677 .791 .935 r
.45128 .54308 .45214 .54375 .45364 .54304 .45278 .54256 Mtetra
.648 .839 .973 r
.45278 .54256 .45364 .54304 .45513 .54256 .45427 .54208 Mtetra
.559 .815 .993 r
.45427 .54208 .45513 .54256 .45661 .54305 .45576 .54181 Mtetra
.588 .636 .866 r
.45576 .54181 .45661 .54305 .45806 .54466 .45725 .54168 Mtetra
.59 .491 .71 r
.45725 .54168 .45806 .54466 .45949 .54778 .45874 .54156 Mtetra
.607 .443 .634 r
.45874 .54156 .45949 .54778 .46095 .54943 .46024 .54092 Mtetra
.6 .423 .614 r
.46024 .54092 .46095 .54943 .46246 .54832 .46174 .54019 Mtetra
.581 .411 .616 r
.46174 .54019 .46246 .54832 .46396 .54802 .46324 .54001 Mtetra
.442 .309 .604 r
.46324 .54001 .46396 .54802 .46225 .73013 .46468 .5426 Mtetra
0 0 .361 r
.46468 .5426 .46225 .73013 .46368 .73852 .46286 .73264 Mtetra
0 0 .405 r
.46286 .73264 .46368 .73852 .46521 .74125 .46433 .73955 Mtetra
.146 .333 .793 r
.46433 .73955 .46521 .74125 .46679 .74197 .46589 .74083 Mtetra
.608 .675 .888 r
.46589 .74083 .46679 .74197 .46838 .74178 .46748 .74058 Mtetra
.695 .696 .846 r
.46748 .74058 .46838 .74178 .46997 .7413 .46908 .73989 Mtetra
.673 .657 .826 r
.46908 .73989 .46997 .7413 .47157 .74083 .47067 .73929 Mtetra
.646 .631 .82 r
.47067 .73929 .47157 .74083 .47316 .7404 .47227 .73884 Mtetra
.649 .63 .817 r
.47227 .73884 .47316 .7404 .47476 .73995 .47387 .73838 Mtetra
.649 .629 .816 r
.47387 .73838 .47476 .73995 .47636 .7395 .47547 .73791 Mtetra
.649 .627 .814 r
.47547 .73791 .47636 .7395 .47795 .73905 .47707 .73744 Mtetra
.65 .624 .811 r
.47707 .73744 .47795 .73905 .47955 .73858 .47867 .73697 Mtetra
.652 .625 .81 r
.47867 .73697 .47955 .73858 .48116 .73802 .48027 .73648 Mtetra
.655 .635 .818 r
.48027 .73648 .48116 .73802 .48276 .73739 .48187 .73598 Mtetra
.658 .652 .833 r
.48187 .73598 .48276 .73739 .48436 .73675 .48347 .73548 Mtetra
.66 .672 .851 r
.48347 .73548 .48436 .73675 .48597 .73619 .48508 .73498 Mtetra
.659 .683 .862 r
.48508 .73498 .48597 .73619 .48757 .7357 .48668 .73449 Mtetra
.658 .683 .862 r
.48668 .73449 .48757 .7357 .48918 .73525 .48829 .73402 Mtetra
.656 .679 .86 r
.48829 .73402 .48918 .73525 .49078 .73479 .48989 .73354 Mtetra
.655 .675 .858 r
.48989 .73354 .49078 .73479 .49239 .73433 .4915 .73308 Mtetra
.654 .674 .857 r
.4915 .73308 .49239 .73433 .494 .73388 .49311 .73262 Mtetra
.653 .673 .857 r
.49311 .73262 .494 .73388 .4956 .73343 .49472 .73216 Mtetra
.652 .672 .857 r
.49472 .73216 .4956 .73343 .49721 .73298 .49633 .73171 Mtetra
.651 .671 .856 r
.49633 .73171 .49721 .73298 .49882 .73253 .49794 .73126 Mtetra
.49794 .73126 .49882 .73253 .50044 .73209 .49955 .73081 Mtetra
.65 .671 .856 r
.49955 .73081 .50044 .73209 .50205 .73164 .50116 .73037 Mtetra
.65 .67 .856 r
.50116 .73037 .50205 .73164 .50366 .7312 .50277 .72992 Mtetra
.50277 .72992 .50366 .7312 .50527 .73076 .50439 .72948 Mtetra
.50439 .72948 .50527 .73076 .50689 .73032 .506 .72904 Mtetra
.649 .67 .856 r
.506 .72904 .50689 .73032 .50851 .72988 .50762 .7286 Mtetra
.50762 .7286 .50851 .72988 .51012 .72944 .50924 .72816 Mtetra
.50924 .72816 .51012 .72944 .51174 .729 .51086 .72772 Mtetra
.51086 .72772 .51174 .729 .51336 .72856 .51248 .72727 Mtetra
.51248 .72727 .51336 .72856 .51498 .72812 .5141 .72683 Mtetra
.5141 .72683 .51498 .72812 .5166 .72768 .51572 .72639 Mtetra
.51572 .72639 .5166 .72768 .51822 .72723 .51734 .72595 Mtetra
.51734 .72595 .51822 .72723 .51984 .72679 .51896 .72551 Mtetra
.51896 .72551 .51984 .72679 .52147 .72635 .52059 .72507 Mtetra
.649 .67 .857 r
.52059 .72507 .52147 .72635 .52309 .72591 .52221 .72463 Mtetra
.52221 .72463 .52309 .72591 .52472 .72547 .52384 .72419 Mtetra
.52384 .72419 .52472 .72547 .52634 .72503 .52546 .72375 Mtetra
.648 .67 .857 r
.52546 .72375 .52634 .72503 .52797 .72459 .52709 .72331 Mtetra
.648 .67 .858 r
.52709 .72331 .52797 .72459 .5296 .72415 .52872 .72287 Mtetra
.648 .671 .858 r
.52872 .72287 .5296 .72415 .53123 .72371 .53035 .72244 Mtetra
.647 .671 .858 r
.53035 .72244 .53123 .72371 .53286 .72328 .53198 .722 Mtetra
.647 .671 .859 r
.53198 .722 .53286 .72328 .53449 .72285 .53361 .72157 Mtetra
.646 .67 .859 r
.53361 .72157 .53449 .72285 .53612 .72242 .53524 .72115 Mtetra
.645 .67 .859 r
.53524 .72115 .53612 .72242 .53776 .722 .53688 .72072 Mtetra
.64 .668 .861 r
.53688 .72072 .53776 .722 .53939 .72166 .53851 .72033 Mtetra
.634 .657 .855 r
.53851 .72033 .53939 .72166 .54103 .7214 .54015 .71996 Mtetra
.643 .645 .837 r
.54015 .71996 .54103 .7214 .54266 .72091 .54179 .71953 Mtetra
.671 .665 .836 r
.54179 .71953 .54266 .72091 .5443 .71974 .54342 .71895 Mtetra
.728 .788 .9 r
.54342 .71895 .5443 .71974 .54592 .71724 .54506 .71814 Mtetra
.012 0 0 r
.54506 .71814 .54592 .71724 .54754 .71333 .5467 .71728 Mtetra
.479 .194 .403 r
.5467 .71728 .54754 .71333 .54914 .70775 .54833 .71654 Mtetra
.541 .296 .494 r
.54833 .71654 .54914 .70775 .55076 .70567 .54997 .71606 Mtetra
.548 .308 .504 r
.54997 .71606 .55076 .70567 .55241 .7063 .55162 .71566 Mtetra
.545 .302 .498 r
.55162 .71566 .55241 .7063 .55405 .7066 .55326 .71525 Mtetra
.54 .295 .492 r
.55326 .71525 .55405 .7066 .55568 .70482 .5549 .71475 Mtetra
.545 .304 .501 r
.5549 .71475 .55568 .70482 .55732 .7048 .55655 .7143 Mtetra
.556 .312 .501 r
.55655 .7143 .55732 .7048 .559 .70871 .5582 .71419 Mtetra
.571 .299 .465 r
.5582 .71419 .559 .70871 .56069 .71284 .55985 .71454 Mtetra
.458 .079 .231 r
.55985 .71454 .56069 .71284 .56236 .71437 .5615 .71433 Mtetra
.892 .949 .837 r
.5615 .71433 .56236 .71437 .564 .71344 .56314 .71249 Mtetra
.944 .727 .579 r
.56314 .71249 .564 .71344 .56555 .70405 .56468 .70253 Mtetra
.958 .689 .485 r
.56468 .70253 .56555 .70405 .56489 .51139 .56408 .51068 Mtetra
.917 .778 .692 r
.56408 .51068 .56489 .51139 .56641 .50774 .56559 .5071 Mtetra
.788 .825 .881 r
.56559 .5071 .56641 .50774 .56796 .50674 .56714 .50602 Mtetra
.577 .753 .961 r
.56714 .50602 .56796 .50674 .56952 .5065 .5687 .50579 Mtetra
0 .271 .734 r
.5687 .50579 .56952 .5065 .57109 .50709 .57028 .50679 Mtetra
.922 .547 .283 r
.57028 .50679 .57109 .50709 .57269 .50933 .57192 .51195 Mtetra
.955 .68 .475 r
.57192 .51195 .57269 .50933 .57436 .51647 .57631 .70522 Mtetra
.573 .361 .555 r
.57631 .70522 .57436 .51647 .57878 .70305 .57803 .70906 Mtetra
.557 .291 .469 r
.57803 .70906 .57878 .70305 .58046 .7037 .5797 .70912 Mtetra
.512 .247 .449 r
.5797 .70912 .58046 .7037 .58211 .70275 .58135 .70847 Mtetra
.5 .24 .451 r
.58135 .70847 .58211 .70275 .58374 .70097 .58301 .70758 Mtetra
.529 .273 .471 r
.58301 .70758 .58374 .70097 .58538 .69939 .58467 .70705 Mtetra
.536 .286 .483 r
.58467 .70705 .58538 .69939 .58704 .69884 .58633 .70655 Mtetra
.542 .292 .485 r
.58633 .70655 .58704 .69884 .58874 .70075 .58799 .70619 Mtetra
.547 .277 .458 r
.58799 .70619 .58874 .70075 .59047 .70424 .58967 .7061 Mtetra
.493 .125 .269 r
.58967 .7061 .59047 .70424 .59218 .70621 .59134 .70602 Mtetra
.317 .784 .935 r
.59134 .70602 .59218 .70621 .59387 .70711 .59301 .70584 Mtetra
.642 .673 .864 r
.59301 .70584 .59387 .70711 .59555 .70685 .59468 .70542 Mtetra
.652 .653 .838 r
.59468 .70542 .59555 .70685 .59721 .70631 .59635 .70494 Mtetra
.656 .663 .845 r
.59635 .70494 .59721 .70631 .59888 .70567 .59802 .70444 Mtetra
.649 .682 .867 r
.59802 .70444 .59888 .70567 .60055 .70523 .59969 .70399 Mtetra
.649 .68 .866 r
.59969 .70399 .60055 .70523 .60222 .7048 .60136 .70354 Mtetra
.634 .672 .869 r
.60136 .70354 .60222 .7048 .6039 .70441 .60304 .70316 Mtetra
.554 .64 .89 r
.60304 .70316 .6039 .70441 .60558 .70424 .60472 .70313 Mtetra
.641 .702 .89 r
.60472 .70313 .60558 .70424 .60725 .70382 .6064 .70271 Mtetra
.78 .744 .821 r
.6064 .70271 .60725 .70382 .60892 .70282 .60805 .70139 Mtetra
.903 .719 .644 r
.60805 .70139 .60892 .70282 .61054 .7001 .60961 .69608 Mtetra
.959 .686 .475 r
.60961 .69608 .61054 .7001 .61209 .69456 .60652 .50161 Mtetra
.578 .369 .561 r
.60652 .50161 .61209 .69456 .60894 .50345 .60797 .49572 Mtetra
.625 .446 .62 r
.60797 .49572 .60894 .50345 .6104 .49791 .60953 .49435 Mtetra
.632 .502 .686 r
.60953 .49435 .6104 .49791 .61193 .49534 .61111 .49366 Mtetra
.631 .602 .803 r
.61111 .49366 .61193 .49534 .61348 .49382 .61269 .4933 Mtetra
.636 .835 .977 r
.61269 .4933 .61348 .49382 .61506 .49327 .61428 .49283 Mtetra
.591 .846 .993 r
.61428 .49283 .61506 .49327 .61665 .49302 .61586 .49243 Mtetra
.617 .81 .974 r
.61586 .49243 .61665 .49302 .61825 .49288 .61745 .49203 Mtetra
.673 .757 .914 r
.61745 .49203 .61825 .49288 .61983 .49241 .61904 .4915 Mtetra
.679 .745 .901 r
.61904 .4915 .61983 .49241 .62142 .49188 .62062 .49095 Mtetra
.687 .743 .894 r
.62062 .49095 .62142 .49188 .623 .49125 .62221 .49035 Mtetra
.758 .768 .86 r
.62221 .49035 .623 .49125 .62457 .49011 .62378 .48935 Mtetra
.694 .785 .921 r
.62378 .48935 .62457 .49011 .62615 .48936 .62537 .48873 Mtetra
.365 .687 .98 r
.62537 .48873 .62615 .48936 .62776 .48938 .62698 .48887 Mtetra
.912 .51 .187 r
.62698 .48887 .62776 .48938 .62949 .49356 .62873 .49343 Mtetra
.965 .683 .45 r
.62873 .49343 .62949 .49356 .63736 .68897 .63654 .68855 Mtetra
.911 .508 .201 r
.63654 .68855 .63736 .68897 .63924 .69419 .6384 .69334 Mtetra
.168 .52 .918 r
.6384 .69334 .63924 .69419 .64097 .69485 .64013 .69397 Mtetra
.641 .754 .93 r
.64013 .69397 .64097 .69485 .64267 .69441 .64183 .69353 Mtetra
.816 .793 .831 r
.64183 .69353 .64267 .69441 .64433 .69287 .64349 .69202 Mtetra
.939 .761 .633 r
.64349 .69202 .64433 .69287 .64585 .68732 .64502 .68647 Mtetra
.966 .69 .458 r
.64502 .68647 .64585 .68732 .64071 .49131 .63992 .49041 Mtetra
.939 .751 .621 r
.63992 .49041 .64071 .49131 .64213 .48555 .64134 .48465 Mtetra
.774 .772 .851 r
.64134 .48465 .64213 .48555 .6437 .48444 .64292 .48353 Mtetra
.641 .734 .916 r
.64292 .48353 .6437 .48444 .64531 .48404 .64452 .48313 Mtetra
.53 .689 .94 r
.64452 .48313 .64531 .48404 .64692 .48401 .64614 .48309 Mtetra
.75 .765 .865 r
.64614 .48309 .64692 .48401 .64851 .48306 .64772 .48214 Mtetra
.692 .749 .895 r
.64772 .48214 .64851 .48306 .65011 .48243 .64932 .48151 Mtetra
.497 .671 .942 r
.64932 .48151 .65011 .48243 .65173 .48249 .65095 .48156 Mtetra
.883 .466 .049 r
.65095 .48156 .65173 .48249 .65352 .48678 .65274 .48584 Mtetra
.968 .684 .44 r
.65274 .48584 .65352 .48678 .66284 .68215 .66201 .68126 Mtetra
.906 .5 .115 r
.66201 .68126 .66284 .68215 .66476 .68717 .66394 .68631 Mtetra
.104 .477 .895 r
.66394 .68631 .66476 .68717 .66652 .68793 .6657 .68707 Mtetra
.625 .754 .94 r
.6657 .68707 .66652 .68793 .66824 .68754 .66742 .68668 Mtetra
.807 .798 .844 r
.66742 .68668 .66824 .68754 .66991 .68613 .66909 .68527 Mtetra
.936 .769 .649 r
.66909 .68527 .66991 .68613 .67144 .68124 .67062 .68038 Mtetra
.968 .69 .449 r
.67062 .68038 .67144 .68124 .66488 .48529 .6641 .48439 Mtetra
.948 .747 .599 r
.6641 .48439 .66488 .48529 .66623 .47857 .66545 .47765 Mtetra
.794 .776 .836 r
.66545 .47765 .66623 .47857 .66781 .47728 .66703 .47637 Mtetra
.625 .729 .922 r
.66703 .47637 .66781 .47728 .66943 .47693 .66865 .47602 Mtetra
.485 .669 .945 r
.66865 .47602 .66943 .47693 .67107 .477 .67029 .47609 Mtetra
.631 .733 .921 r
.67029 .47609 .67107 .477 .67269 .47662 .67192 .47572 Mtetra
.655 .744 .915 r
.67192 .47572 .67269 .47662 .67431 .47615 .67353 .47526 Mtetra
.661 .748 .914 r
.67353 .47526 .67431 .47615 .67593 .47565 .67515 .47477 Mtetra
.76 .777 .867 r
.67515 .47477 .67593 .47565 .67752 .47462 .67675 .47376 Mtetra
.716 .772 .896 r
.67675 .47376 .67752 .47462 .67913 .47387 .67836 .47301 Mtetra
.528 .705 .951 r
.67836 .47301 .67913 .47387 .68077 .47382 .68 .47295 Mtetra
.862 .434 .003 r
.68 .47295 .68077 .47382 .68262 .47815 .68184 .47695 Mtetra
.97 .683 .427 r
.68184 .47695 .68262 .47815 .69374 .67432 .69289 .67268 Mtetra
.815 .429 0 r
.69289 .67268 .69374 .67432 .69573 .67914 .69489 .67784 Mtetra
.375 .54 .891 r
.69489 .67784 .69573 .67914 .6975 .67968 .69667 .6784 Mtetra
.658 .684 .863 r
.69667 .6784 .6975 .67968 .69923 .67907 .6984 .67788 Mtetra
.735 .726 .843 r
.6984 .67788 .69923 .67907 .70092 .67779 .70011 .67689 Mtetra
.645 .754 .928 r
.70011 .67689 .70092 .67779 .70259 .67611 .70184 .67643 Mtetra
0 0 0 r
.70184 .67643 .70259 .67611 .70422 .67363 .70357 .67581 Mtetra
.292 0 .227 r
.70357 .67581 .70422 .67363 .70574 .66908 .70526 .67453 Mtetra
.131 0 .344 r
.70526 .67453 .70574 .66908 .69749 .47773 .70676 .66958 Mtetra
.058 0 .443 r
.70676 .66958 .69749 .47773 .69878 .47076 .69821 .47349 Mtetra
0 0 0 r
.69821 .47349 .69878 .47076 .70029 .46788 .69954 .46725 Mtetra
.849 .844 .839 r
.69954 .46725 .70029 .46788 .70189 .46677 .70112 .46568 Mtetra
.664 .709 .881 r
.70112 .46568 .70189 .46677 .70352 .46627 .70275 .46517 Mtetra
.575 .668 .902 r
.70275 .46517 .70352 .46627 .70517 .466 .70441 .46504 Mtetra
.661 .733 .903 r
.70441 .46504 .70517 .466 .70679 .46525 .70604 .46455 Mtetra
.687 .806 .939 r
.70604 .46455 .70679 .46525 .70841 .46446 .70767 .46393 Mtetra
.655 .849 .974 r
.70767 .46393 .70841 .46446 .71005 .46394 .70931 .46338 Mtetra
.691 .848 .958 r
.70931 .46338 .71005 .46394 .71173 .46427 .71094 .46273 Mtetra
.64 .627 .821 r
.71094 .46273 .71173 .46427 .71348 .46558 .71258 .46231 Mtetra
.56 .467 .706 r
.71258 .46231 .71348 .46558 .71534 .46893 .71426 .46249 Mtetra
.375 .283 .622 r
.71426 .46249 .71534 .46893 .72814 .65951 .71613 .46576 Mtetra
.08 .004 .46 r
.71613 .46576 .72814 .65951 .7303 .66616 .72925 .6609 Mtetra
0 .024 .542 r
.72925 .6609 .7303 .66616 .73221 .6684 .73139 .66705 Mtetra
.228 .444 .862 r
.73139 .66705 .73221 .6684 .73403 .66902 .73323 .66804 Mtetra
.615 .727 .926 r
.73323 .66804 .73403 .66902 .7358 .66884 .73499 .6677 Mtetra
.715 .731 .863 r
.73499 .6677 .7358 .66884 .73754 .66811 .73672 .66686 Mtetra
.66 .692 .869 r
.73672 .66686 .73754 .66811 .73923 .66663 .73847 .66633 Mtetra
.61 .905 .984 r
.73847 .66633 .73923 .66663 .74086 .66415 .74022 .66571 Mtetra
.171 0 .084 r
.74022 .66571 .74086 .66415 .74236 .65945 .74193 .66444 Mtetra
.142 0 .341 r
.74193 .66444 .74236 .65945 .732 .46665 .74343 .65988 Mtetra
.08 0 .455 r
.74343 .65988 .732 .46665 .73324 .45967 .73278 .46329 Mtetra
0 0 .059 r
.73278 .46329 .73324 .45967 .73474 .45677 .73405 .45667 Mtetra
.897 .965 .825 r
.73405 .45667 .73474 .45677 .73635 .4556 .73562 .45484 Mtetra
.667 .787 .938 r
.73562 .45484 .73635 .4556 .73802 .45523 .73727 .4543 Mtetra
.555 .7 .937 r
.73727 .4543 .73802 .45523 .7397 .45515 .73895 .45418 Mtetra
.605 .712 .92 r
.73895 .45418 .7397 .45515 .74137 .45489 .74062 .45391 Mtetra
.648 .727 .906 r
.74062 .45391 .74137 .45489 .74303 .45444 .74228 .45346 Mtetra
.653 .731 .907 r
.74228 .45346 .74303 .45444 .74469 .45392 .74394 .453 Mtetra
.676 .752 .908 r
.74394 .453 .74469 .45392 .74633 .45314 .7456 .45243 Mtetra
.684 .808 .941 r
.7456 .45243 .74633 .45314 .74796 .45233 .74725 .45182 Mtetra
.651 .856 .978 r
.74725 .45182 .74796 .45233 .74962 .45178 .74891 .45126 Mtetra
.671 .86 .971 r
.74891 .45126 .74962 .45178 .75133 .45199 .75056 .45065 Mtetra
.645 .659 .849 r
.75056 .45065 .75133 .45199 .75312 .45323 .75223 .45021 Mtetra
.562 .479 .718 r
.75223 .45021 .75312 .45323 .75505 .4565 .75394 .45035 Mtetra
.401 .305 .631 r
.75394 .45035 .75505 .4565 .77031 .64828 .75584 .4532 Mtetra
.103 .023 .472 r
.75584 .4532 .77031 .64828 .7726 .65514 .77143 .64876 Mtetra
.073 .081 .561 r
.77143 .64876 .7726 .65514 .77458 .65744 .77372 .65547 Mtetra
.293 .395 .796 r
.77372 .65547 .77458 .65744 .77644 .65807 .77563 .65677 Mtetra
.61 .664 .877 r
.77563 .65677 .77644 .65807 .77823 .6578 .77742 .65649 Mtetra
.702 .702 .847 r
.77742 .65649 .77823 .6578 .77999 .65698 .77918 .65569 Mtetra
.676 .694 .86 r
.77918 .65569 .77999 .65698 .7817 .65555 .78095 .65506 Mtetra
.635 .867 .985 r
.78095 .65506 .7817 .65555 .78334 .65326 .78273 .65448 Mtetra
.108 0 0 r
.78273 .65448 .78334 .65326 .78486 .64927 .78446 .65332 Mtetra
.166 0 .323 r
.78446 .65332 .78486 .64927 .77233 .45895 .78601 .64968 Mtetra
.096 .015 .465 r
.78601 .64968 .77233 .45895 .77323 .4481 .77304 .45441 Mtetra
0 0 .255 r
.77304 .45441 .77323 .4481 .77469 .4448 .77404 .44498 Mtetra
.917 .978 .723 r
.77404 .44498 .77469 .4448 .77629 .44336 .77558 .44265 Mtetra
.693 .814 .939 r
.77558 .44265 .77629 .44336 .77798 .4429 .77725 .442 Mtetra
.575 .717 .94 r
.77725 .442 .77798 .4429 .77968 .44276 .77895 .4418 Mtetra
.596 .714 .926 r
.77895 .4418 .77968 .44276 .78138 .44252 .78065 .44155 Mtetra
.654 .734 .909 r
.78065 .44155 .78138 .44252 .78306 .44204 .78233 .44108 Mtetra
.658 .737 .908 r
.78233 .44108 .78306 .44204 .78474 .4415 .78402 .44058 Mtetra
.677 .755 .91 r
.78402 .44058 .78474 .4415 .7864 .44074 .78569 .44 Mtetra
.69 .806 .936 r
.78569 .44 .7864 .44074 .78806 .43988 .78737 .43936 Mtetra
.661 .86 .975 r
.78737 .43936 .78806 .43988 .78973 .43925 .78904 .43876 Mtetra
.668 .871 .975 r
.78904 .43876 .78973 .43925 .79146 .43927 .79072 .43813 Mtetra
.663 .704 .877 r
.79072 .43813 .79146 .43927 .79327 .44027 .79241 .43761 Mtetra
.578 .506 .738 r
.79241 .43761 .79327 .44027 .79521 .44279 .79413 .4376 Mtetra
.439 .345 .652 r
.79413 .4376 .79521 .44279 .81254 .63003 .79603 .4396 Mtetra
.117 .037 .48 r
.79603 .4396 .81254 .63003 .81542 .64243 .81389 .63233 Mtetra
.095 .069 .535 r
.81389 .63233 .81542 .64243 .8175 .64523 .81662 .64293 Mtetra
.226 .322 .753 r
.81662 .64293 .8175 .64523 .81942 .64612 .81862 .6448 Mtetra
.587 .651 .88 r
.81862 .6448 .81942 .64612 .82125 .64593 .82046 .64462 Mtetra
.693 .701 .853 r
.82046 .64462 .82125 .64593 .82303 .64517 .82224 .64387 Mtetra
.687 .699 .856 r
.82224 .64387 .82303 .64517 .82477 .64381 .82403 .64316 Mtetra
.633 .824 .974 r
.82403 .64316 .82477 .64381 .82643 .64162 .82584 .64265 Mtetra
.085 0 0 r
.82584 .64265 .82643 .64162 .82795 .63787 .8276 .6416 Mtetra
.222 0 .332 r
.8276 .6416 .82795 .63787 .81381 .45642 .82919 .63856 Mtetra
.104 .024 .471 r
.82919 .63856 .81381 .45642 .81377 .43619 .81424 .44858 Mtetra
0 0 .385 r
.81424 .44858 .81377 .43619 .81521 .43264 .81462 .4331 Mtetra
.888 .95 .597 r
.81462 .4331 .81521 .43264 .81681 .43102 .81611 .43033 Mtetra
.699 .824 .942 r
.81611 .43033 .81681 .43102 .81851 .43057 .8178 .42964 Mtetra
.567 .708 .936 r
.8178 .42964 .81851 .43057 .82026 .43051 .81953 .42947 Mtetra
.562 .682 .92 r
.81953 .42947 .82026 .43051 .822 .43043 .82128 .42936 Mtetra
.639 .709 .898 r
.82128 .42936 .822 .43043 .82371 .43004 .82299 .42894 Mtetra
.639 .705 .894 r
.82299 .42894 .82371 .43004 .82543 .4296 .82471 .42853 Mtetra
.681 .727 .885 r
.82471 .42853 .82543 .4296 .82713 .42901 .8264 .42792 Mtetra
.715 .735 .867 r
.8264 .42792 .82713 .42901 .82882 .42829 .82808 .42711 Mtetra
.625 .682 .884 r
.82808 .42711 .82882 .42829 .83053 .42787 .82981 .42676 Mtetra
.024 .34 .82 r
.82981 .42676 .83053 .42787 .83235 .42848 .83169 .42808 Mtetra
.961 .625 .293 r
.83169 .42808 .83235 .42848 .83444 .43193 .83528 .44732 Mtetra
.958 .654 .411 r
.83528 .44732 .83444 .43193 .85452 .62347 .85466 .63177 Mtetra
.634 .365 .494 r
.85466 .63177 .85452 .62347 .857 .62978 .85678 .63428 Mtetra
.556 .269 .434 r
.85678 .63428 .857 .62978 .85892 .63031 .85867 .63444 Mtetra
.485 .204 .412 r
.85867 .63444 .85892 .63031 .8607 .62931 .86047 .63363 Mtetra
.355 .106 .392 r
.86047 .63363 .8607 .62931 .8622 .6254 .86212 .63127 Mtetra
0 0 .322 r
.86212 .63127 .8622 .6254 .84501 .43162 .86325 .6236 Mtetra
.126 .042 .482 r
.86325 .6236 .84501 .43162 .84615 .42523 .8456 .42573 Mtetra
.955 .904 .527 r
.8456 .42573 .84615 .42523 .84768 .42275 .84697 .42174 Mtetra
.739 .762 .872 r
.84697 .42174 .84768 .42275 .84937 .42197 .84865 .42081 Mtetra
.622 .686 .889 r
.84865 .42081 .84937 .42197 .85111 .42158 .85039 .42047 Mtetra
.595 .684 .903 r
.85039 .42047 .85111 .42158 .85285 .42124 .85214 .42024 Mtetra
.678 .742 .899 r
.85214 .42024 .85285 .42124 .85456 .42065 .85386 .41964 Mtetra
.682 .743 .897 r
.85386 .41964 .85456 .42065 .85628 .42002 .85557 .41902 Mtetra
.689 .747 .895 r
.85557 .41902 .85628 .42002 .85799 .41937 .85728 .41837 Mtetra
.699 .751 .892 r
.85728 .41837 .85799 .41937 .85969 .41867 .85899 .41766 Mtetra
.7 .748 .889 r
.85899 .41766 .85969 .41867 .8614 .41795 .8607 .41695 Mtetra
.723 .759 .881 r
.8607 .41695 .8614 .41795 .86309 .41705 .8624 .41611 Mtetra
.763 .786 .872 r
.8624 .41611 .86309 .41705 .86474 .41585 .86407 .41505 Mtetra
.679 .794 .936 r
.86407 .41505 .86474 .41585 .86645 .41511 .86579 .41444 Mtetra
.151 .545 .925 r
.86579 .41444 .86645 .41511 .86828 .41555 .86764 .41502 Mtetra
.884 .466 .054 r
.86764 .41502 .86828 .41555 .87061 .42061 .87003 .42069 Mtetra
.974 .666 .339 r
.87003 .42069 .87061 .42061 .89379 .62021 .89311 .61965 Mtetra
.789 .319 0 r
.89311 .61965 .89379 .62021 .89613 .62429 .89541 .6234 Mtetra
.487 .698 .962 r
.89541 .6234 .89613 .62429 .89804 .6243 .89732 .62342 Mtetra
.681 .786 .929 r
.89732 .62342 .89804 .6243 .89988 .62362 .89916 .62276 Mtetra
.698 .797 .926 r
.89916 .62276 .89988 .62362 .90171 .62292 .90099 .62202 Mtetra
.483 .693 .961 r
.90099 .62202 .90171 .62292 .90365 .62313 .90291 .62206 Mtetra
.633 .726 .914 r
.90291 .62206 .90365 .62313 .90553 .62284 .90478 .62163 Mtetra
.807 .761 .81 r
.90478 .62163 .90553 .62284 .90728 .62135 .90651 .61999 Mtetra
.959 .747 .574 r
.90651 .61999 .90728 .62135 .90845 .6147 .90764 .61293 Mtetra
.977 .674 .347 r
.90764 .61293 .90845 .6147 .88786 .41397 .88715 .41282 Mtetra
.943 .769 .636 r
.88715 .41282 .88786 .41397 .88912 .40919 .88845 .40826 Mtetra
.748 .787 .885 r
.88845 .40826 .88912 .40919 .89082 .40823 .89014 .4073 Mtetra
.609 .734 .934 r
.89014 .4073 .89082 .40823 .89259 .40793 .89191 .40697 Mtetra
.548 .699 .939 r
.89191 .40697 .89259 .40793 .89439 .40786 .8937 .40686 Mtetra
.673 .745 .905 r
.8937 .40686 .89439 .40786 .89613 .40731 .89545 .40628 Mtetra
.678 .738 .897 r
.89545 .40628 .89613 .40731 .89787 .40672 .89719 .40567 Mtetra
.696 .743 .888 r
.89719 .40567 .89787 .40672 .8996 .40598 .89892 .40497 Mtetra
.762 .774 .863 r
.89892 .40497 .8996 .40598 .90127 .40475 .9006 .40389 Mtetra
.694 .786 .921 r
.9006 .40389 .90127 .40475 .90299 .40394 .90234 .40321 Mtetra
.357 .659 .97 r
.90234 .40321 .90299 .40394 .90481 .40405 .90418 .40346 Mtetra
.835 .396 0 r
.90418 .40346 .90481 .40405 .90715 .40845 .90656 .40824 Mtetra
.973 .661 .315 r
.90656 .40824 .90715 .40845 .93277 .60864 .93211 .60807 Mtetra
.818 .366 0 r
.93211 .60807 .93277 .60864 .93529 .61359 .93459 .61264 Mtetra
.47 .674 .953 r
.93459 .61264 .93529 .61359 .93724 .61368 .93654 .61274 Mtetra
.674 .773 .925 r
.93654 .61274 .93724 .61368 .93911 .61303 .9384 .61211 Mtetra
.726 .798 .908 r
.9384 .61211 .93911 .61303 .94094 .61215 .94024 .61122 Mtetra
.476 .684 .957 r
.94024 .61122 .94094 .61215 .94291 .61239 .94219 .61129 Mtetra
.616 .715 .916 r
.94219 .61129 .94291 .61239 .94483 .61218 .9441 .61093 Mtetra
.768 .749 .836 r
.9441 .61093 .94483 .61218 .94664 .61104 .94589 .60965 Mtetra
.955 .753 .592 r
.94589 .60965 .94664 .61104 .94787 .60523 .94708 .60349 Mtetra
.975 .669 .325 r
.94708 .60349 .94787 .60523 .92484 .40369 .92413 .40238 Mtetra
.95 .755 .604 r
.92413 .40238 .92484 .40369 .92595 .39793 .92529 .39697 Mtetra
.767 .79 .872 r
.92529 .39697 .92595 .39793 .92765 .39681 .92699 .39587 Mtetra
.631 .742 .928 r
.92699 .39587 .92765 .39681 .92943 .39641 .92877 .39546 Mtetra
.545 .699 .94 r
.92877 .39546 .92943 .39641 .93126 .39633 .93059 .39536 Mtetra
.756 .783 .875 r
.93059 .39536 .93126 .39633 .93296 .39531 .9323 .39433 Mtetra
.686 .756 .904 r
.9323 .39433 .93296 .39531 .93472 .39466 .93406 .39367 Mtetra
.49 .66 .937 r
.93406 .39367 .93472 .39466 .93657 .39476 .93591 .39377 Mtetra
.747 .328 0 r
.93591 .39377 .93657 .39476 .93904 .39962 .93838 .39863 Mtetra
.97 .655 .291 r
.93838 .39863 .93904 .39962 .96675 .59997 .96606 .59903 Mtetra
.738 .306 0 r
.96606 .59903 .96675 .59997 .96933 .60469 .96864 .60374 Mtetra
.038 .468 .881 r
.35572 .76916 .35667 .76992 .35815 .77054 .3572 .76977 Mtetra
.644 .762 .935 r
.3572 .76977 .35815 .77054 .35968 .77013 .35873 .76936 Mtetra
.81 .779 .824 r
.35873 .76936 .35968 .77013 .36126 .7687 .36031 .76793 Mtetra
.908 .738 .659 r
.36031 .76793 .36126 .7687 .36301 .76344 .36207 .76267 Mtetra
.937 .686 .534 r
.36207 .76267 .36301 .76344 .37305 .57262 .37217 .5718 Mtetra
.909 .728 .645 r
.37217 .5718 .37305 .57262 .37474 .56693 .37385 .56611 Mtetra
.778 .76 .837 r
.37385 .56611 .37474 .56693 .37622 .56582 .37534 .565 Mtetra
.642 .737 .918 r
.37534 .565 .37622 .56582 .37767 .56545 .37678 .56463 Mtetra
.511 .693 .95 r
.37678 .56463 .37767 .56545 .3791 .56544 .37822 .56462 Mtetra
.746 .758 .862 r
.37822 .56462 .3791 .56544 .38057 .56457 .37969 .56375 Mtetra
.697 .751 .893 r
.37969 .56375 .38057 .56457 .38203 .56397 .38115 .56315 Mtetra
.483 .683 .954 r
.38115 .56315 .38203 .56397 .38347 .56401 .38259 .5632 Mtetra
.926 .543 .247 r
.38259 .5632 .38347 .56401 .38475 .56788 .38386 .5671 Mtetra
.939 .683 .522 r
.38386 .5671 .38475 .56788 .37841 .75794 .37747 .75725 Mtetra
.932 .58 .335 r
.37747 .75725 .37841 .75794 .37972 .76326 .37878 .76252 Mtetra
0 .321 .766 r
.37878 .76252 .37972 .76326 .38121 .76405 .38027 .76335 Mtetra
.619 .776 .956 r
.38027 .76335 .38121 .76405 .38275 .76368 .38182 .763 Mtetra
.815 .8 .838 r
.38182 .763 .38275 .76368 .38434 .76232 .3834 .7616 Mtetra
.913 .742 .657 r
.3834 .7616 .38434 .76232 .38603 .75795 .38514 .7563 Mtetra
.938 .686 .529 r
.38514 .7563 .38603 .75795 .39483 .56859 .39407 .5646 Mtetra
.797 .598 .632 r
.39407 .5646 .39483 .56859 .39656 .56119 .39573 .55907 Mtetra
.706 .597 .732 r
.39573 .55907 .39656 .56119 .39806 .55959 .39722 .55793 Mtetra
.612 .587 .801 r
.39722 .55793 .39806 .55959 .39953 .55895 .39867 .5577 Mtetra
.491 .589 .88 r
.39867 .5577 .39953 .55895 .40099 .5587 .40012 .55789 Mtetra
.591 .728 .939 r
.40012 .55789 .40099 .5587 .40245 .55833 .40157 .55768 Mtetra
.618 .776 .957 r
.40157 .55768 .40245 .55833 .40392 .55798 .40304 .55735 Mtetra
.629 .784 .956 r
.40304 .55735 .40392 .55798 .40538 .55765 .4045 .55698 Mtetra
.647 .779 .944 r
.4045 .55698 .40538 .55765 .40685 .55721 .40597 .55657 Mtetra
.658 .791 .946 r
.40597 .55657 .40685 .55721 .40832 .55671 .40744 .55612 Mtetra
.666 .805 .95 r
.40744 .55612 .40832 .55671 .40979 .55619 .40891 .55563 Mtetra
.671 .816 .953 r
.40891 .55563 .40979 .55619 .41127 .55562 .41038 .55512 Mtetra
.675 .836 .96 r
.41038 .55512 .41127 .55562 .41274 .55506 .41186 .55459 Mtetra
.682 .841 .96 r
.41186 .55459 .41274 .55506 .41421 .55459 .41333 .55403 Mtetra
.769 .824 .896 r
.41333 .55403 .41421 .55459 .41569 .55401 .41482 .5531 Mtetra
.724 .74 .864 r
.41482 .5531 .41569 .55401 .41716 .5537 .41631 .55234 Mtetra
.622 .63 .837 r
.41631 .55234 .41716 .5537 .41861 .55403 .41778 .55206 Mtetra
0 .133 .669 r
.41778 .55206 .41861 .55403 .41994 .55809 .41918 .55396 Mtetra
.889 .614 .1 r
.41918 .55396 .41994 .55809 .41559 .74816 .42037 .56282 Mtetra
0 0 .344 r
.42037 .56282 .41559 .74816 .41699 .75302 .41619 .74839 Mtetra
.474 .374 .661 r
.41619 .74839 .41699 .75302 .41852 .7537 .4177 .74958 Mtetra
.616 .481 .674 r
.4177 .74958 .41852 .7537 .42009 .75329 .41927 .74906 Mtetra
.635 .491 .67 r
.41927 .74906 .42009 .75329 .42167 .75248 .42085 .74822 Mtetra
.523 .415 .673 r
.42085 .74822 .42167 .75248 .42324 .752 .42238 .74884 Mtetra
.459 .407 .713 r
.42238 .74884 .42324 .752 .4248 .75161 .42391 .74974 Mtetra
.432 .482 .811 r
.42391 .74974 .4248 .75161 .42637 .75115 .42545 .75034 Mtetra
.387 .655 .964 r
.42545 .75034 .42637 .75115 .42794 .7508 .42701 .75054 Mtetra
.436 .829 .983 r
.42701 .75054 .42794 .7508 .42952 .75021 .42857 .7503 Mtetra
.628 .956 .919 r
.42857 .7503 .42952 .75021 .43111 .74899 .43016 .74948 Mtetra
.952 .945 .728 r
.43016 .74948 .43111 .74899 .43279 .74441 .43179 .74668 Mtetra
.994 .854 .509 r
.43179 .74668 .43279 .74441 .4392 .55319 .43356 .73881 Mtetra
0 0 .337 r
.43356 .73881 .4392 .55319 .44083 .54698 .43987 .55003 Mtetra
.093 0 .203 r
.43987 .55003 .44083 .54698 .44235 .54531 .44141 .54759 Mtetra
.457 .123 .311 r
.44141 .54759 .44235 .54531 .44384 .54481 .4429 .54717 Mtetra
.519 .188 .346 r
.4429 .54717 .44384 .54481 .44532 .5447 .44438 .5471 Mtetra
.27 0 .235 r
.44438 .5471 .44532 .5447 .44681 .54442 .4459 .54578 Mtetra
0 0 0 r
.4459 .54578 .44681 .54442 .4483 .544 .44742 .54407 Mtetra
.849 .972 .873 r
.44742 .54407 .4483 .544 .44979 .54358 .44893 .54267 Mtetra
.72 .741 .868 r
.44893 .54267 .44979 .54358 .45128 .54308 .45043 .54192 Mtetra
.643 .672 .863 r
.45043 .54192 .45128 .54308 .45278 .54256 .45192 .54155 Mtetra
.619 .692 .896 r
.45192 .54155 .45278 .54256 .45427 .54208 .45341 .54127 Mtetra
.665 .75 .913 r
.45341 .54127 .45427 .54208 .45576 .54181 .45491 .5408 Mtetra
.691 .714 .867 r
.45491 .5408 .45576 .54181 .45725 .54168 .45641 .54019 Mtetra
.675 .639 .806 r
.45641 .54019 .45725 .54168 .45874 .54156 .45791 .53959 Mtetra
.676 .594 .756 r
.45791 .53959 .45874 .54156 .46024 .54092 .45941 .53883 Mtetra
.661 .578 .751 r
.45941 .53883 .46024 .54092 .46174 .54019 .46091 .53818 Mtetra
.61 .556 .769 r
.46091 .53818 .46174 .54019 .46324 .54001 .46241 .53794 Mtetra
.2 .307 .75 r
.46241 .53794 .46324 .54001 .46468 .5426 .46387 .53937 Mtetra
.729 .454 0 r
.46387 .53937 .46468 .5426 .46286 .73264 .46526 .54521 Mtetra
0 0 .363 r
.46526 .54521 .46286 .73264 .46433 .73955 .4635 .73439 Mtetra
.363 .287 .637 r
.4635 .73439 .46433 .73955 .46589 .74083 .46504 .73681 Mtetra
.594 .469 .68 r
.46504 .73681 .46589 .74083 .46748 .74058 .46663 .73659 Mtetra
.642 .501 .676 r
.46663 .73659 .46748 .74058 .46908 .73989 .46823 .73568 Mtetra
.629 .489 .672 r
.46823 .73568 .46908 .73989 .47067 .73929 .46983 .73492 Mtetra
.61 .473 .67 r
.46983 .73492 .47067 .73929 .47227 .73884 .47142 .73444 Mtetra
.611 .473 .669 r
.47142 .73444 .47227 .73884 .47387 .73838 .47302 .73395 Mtetra
.621 .479 .667 r
.47302 .73395 .47387 .73838 .47547 .73791 .47462 .7333 Mtetra
.619 .475 .663 r
.47462 .7333 .47547 .73791 .47707 .73744 .47622 .73263 Mtetra
.599 .457 .661 r
.47622 .73263 .47707 .73744 .47867 .73697 .47782 .73229 Mtetra
.532 .415 .664 r
.47782 .73229 .47867 .73697 .48027 .73648 .4794 .73287 Mtetra
.474 .402 .695 r
.4794 .73287 .48027 .73648 .48187 .73598 .48099 .73382 Mtetra
.446 .463 .784 r
.48099 .73382 .48187 .73598 .48347 .73548 .48258 .73448 Mtetra
.502 .665 .935 r
.48258 .73448 .48347 .73548 .48508 .73498 .48417 .73454 Mtetra
.6 .846 .991 r
.48417 .73454 .48508 .73498 .48668 .73449 .48578 .73412 Mtetra
.647 .877 .983 r
.48578 .73412 .48668 .73449 .48829 .73402 .48739 .73355 Mtetra
.651 .855 .978 r
.48739 .73355 .48829 .73402 .48989 .73354 .48899 .73302 Mtetra
.633 .833 .977 r
.48899 .73302 .48989 .73354 .4915 .73308 .4906 .73255 Mtetra
.633 .832 .977 r
.4906 .73255 .4915 .73308 .49311 .73262 .49221 .73208 Mtetra
.631 .831 .977 r
.49221 .73208 .49311 .73262 .49472 .73216 .49382 .73163 Mtetra
.629 .83 .978 r
.49382 .73163 .49472 .73216 .49633 .73171 .49543 .73117 Mtetra
.628 .829 .978 r
.49543 .73117 .49633 .73171 .49794 .73126 .49704 .73072 Mtetra
.627 .829 .978 r
.49704 .73072 .49794 .73126 .49955 .73081 .49865 .73028 Mtetra
.626 .829 .978 r
.49865 .73028 .49955 .73081 .50116 .73037 .50027 .72983 Mtetra
.625 .829 .978 r
.50027 .72983 .50116 .73037 .50277 .72992 .50188 .72939 Mtetra
.625 .828 .979 r
.50188 .72939 .50277 .72992 .50439 .72948 .5035 .72894 Mtetra
.5035 .72894 .50439 .72948 .506 .72904 .50511 .7285 Mtetra
.624 .828 .979 r
.50511 .7285 .506 .72904 .50762 .7286 .50673 .72806 Mtetra
.50673 .72806 .50762 .7286 .50924 .72816 .50835 .72762 Mtetra
.50835 .72762 .50924 .72816 .51086 .72772 .50997 .72717 Mtetra
.50997 .72717 .51086 .72772 .51248 .72727 .51159 .72673 Mtetra
.51159 .72673 .51248 .72727 .5141 .72683 .51321 .72629 Mtetra
.623 .828 .979 r
.51321 .72629 .5141 .72683 .51572 .72639 .51483 .72585 Mtetra
.51483 .72585 .51572 .72639 .51734 .72595 .51645 .72541 Mtetra
.51645 .72541 .51734 .72595 .51896 .72551 .51808 .72497 Mtetra
.51808 .72497 .51896 .72551 .52059 .72507 .5197 .72453 Mtetra
.622 .828 .98 r
.5197 .72453 .52059 .72507 .52221 .72463 .52133 .72409 Mtetra
.622 .829 .98 r
.52133 .72409 .52221 .72463 .52384 .72419 .52295 .72365 Mtetra
.52295 .72365 .52384 .72419 .52546 .72375 .52458 .72321 Mtetra
.621 .829 .98 r
.52458 .72321 .52546 .72375 .52709 .72331 .52621 .72277 Mtetra
.62 .829 .98 r
.52621 .72277 .52709 .72331 .52872 .72287 .52784 .72234 Mtetra
.62 .829 .981 r
.52784 .72234 .52872 .72287 .53035 .72244 .52947 .7219 Mtetra
.619 .829 .981 r
.52947 .7219 .53035 .72244 .53198 .722 .5311 .72147 Mtetra
.618 .829 .981 r
.5311 .72147 .53198 .722 .53361 .72157 .53273 .72103 Mtetra
.617 .828 .981 r
.53273 .72103 .53361 .72157 .53524 .72115 .53437 .7206 Mtetra
.616 .827 .981 r
.53437 .7206 .53524 .72115 .53688 .72072 .536 .72018 Mtetra
.536 .72018 .53688 .72072 .53851 .72033 .53764 .71975 Mtetra
.62 .82 .977 r
.53764 .71975 .53851 .72033 .54015 .71996 .53927 .71933 Mtetra
.62 .804 .971 r
.53927 .71933 .54015 .71996 .54179 .71953 .54091 .71892 Mtetra
.598 .803 .978 r
.54091 .71892 .54179 .71953 .54342 .71895 .54255 .71857 Mtetra
.508 .836 .999 r
.54255 .71857 .54342 .71895 .54506 .71814 .54419 .71828 Mtetra
.14 .682 .713 r
.54419 .71828 .54506 .71814 .5467 .71728 .54583 .71798 Mtetra
.216 0 0 r
.54583 .71798 .5467 .71728 .54833 .71654 .54747 .71764 Mtetra
.314 0 .025 r
.54747 .71764 .54833 .71654 .54997 .71606 .54912 .71722 Mtetra
.318 0 .044 r
.54912 .71722 .54997 .71606 .55162 .71566 .55076 .71677 Mtetra
.305 0 .023 r
.55076 .71677 .55162 .71566 .55326 .71525 .5524 .71632 Mtetra
.301 0 .01 r
.5524 .71632 .55326 .71525 .5549 .71475 .55405 .71589 Mtetra
.3 0 .027 r
.55405 .71589 .5549 .71475 .55655 .7143 .5557 .71541 Mtetra
.299 0 .018 r
.5557 .71541 .55655 .7143 .5582 .71419 .55734 .71494 Mtetra
.195 0 0 r
.55734 .71494 .5582 .71419 .55985 .71454 .55899 .71452 Mtetra
.621 .949 .937 r
.55899 .71452 .55985 .71454 .5615 .71433 .56064 .71374 Mtetra
.864 .834 .815 r
.56064 .71374 .5615 .71433 .56314 .71249 .56227 .71187 Mtetra
.942 .766 .636 r
.56227 .71187 .56314 .71249 .56468 .70253 .56387 .70623 Mtetra
.965 .697 .476 r
.56387 .70623 .56468 .70253 .56408 .51068 .56331 .51421 Mtetra
0 0 .023 r
.56331 .51421 .56408 .51068 .56559 .5071 .56481 .50904 Mtetra
.211 0 .164 r
.56481 .50904 .56559 .5071 .56714 .50602 .56636 .50772 Mtetra
.483 .111 .258 r
.56636 .50772 .56714 .50602 .5687 .50579 .56792 .5076 Mtetra
.72 .367 .379 r
.56792 .5076 .5687 .50579 .57028 .50679 .56952 .50955 Mtetra
.955 .68 .476 r
.56952 .50955 .57028 .50679 .57192 .51195 .57373 .70013 Mtetra
.579 .366 .555 r
.57373 .70013 .57192 .51195 .57631 .70522 .5755 .70779 Mtetra
.7 .369 .412 r
.5755 .70779 .57631 .70522 .57803 .70906 .57719 .70987 Mtetra
.372 0 0 r
.57719 .70987 .57803 .70906 .5797 .70912 .57886 .70978 Mtetra
.056 0 0 r
.57886 .70978 .5797 .70912 .58135 .70847 .58052 .7092 Mtetra
.002 0 0 r
.58052 .7092 .58135 .70847 .58301 .70758 .58218 .70847 Mtetra
.239 0 0 r
.58218 .70847 .58301 .70758 .58467 .70705 .58384 .70802 Mtetra
.254 0 0 r
.58384 .70802 .58467 .70705 .58633 .70655 .5855 .70753 Mtetra
.24 0 0 r
.5855 .70753 .58633 .70655 .58799 .70619 .58717 .70701 Mtetra
.139 0 0 r
.58717 .70701 .58799 .70619 .58967 .7061 .58883 .70642 Mtetra
0 0 0 r
.58883 .70642 .58967 .7061 .59134 .70602 .5905 .70581 Mtetra
.571 .904 .979 r
.5905 .70581 .59134 .70602 .59301 .70584 .59216 .70526 Mtetra
.594 .815 .984 r
.59216 .70526 .59301 .70584 .59468 .70542 .59383 .70489 Mtetra
.619 .837 .983 r
.59383 .70489 .59468 .70542 .59635 .70494 .5955 .70443 Mtetra
.705 .864 .957 r
.5955 .70443 .59635 .70494 .59802 .70444 .59717 .7037 Mtetra
.82 .815 .845 r
.59717 .7037 .59802 .70444 .59969 .70399 .59882 .70224 Mtetra
.773 .668 .747 r
.59882 .70224 .59969 .70399 .60136 .70354 .60046 .70046 Mtetra
.707 .567 .694 r
.60046 .70046 .60136 .70354 .60304 .70316 .60211 .69879 Mtetra
.579 .454 .674 r
.60211 .69879 .60304 .70316 .60472 .70313 .60379 .69876 Mtetra
.598 .466 .673 r
.60379 .69876 .60472 .70313 .6064 .70271 .60547 .69846 Mtetra
.677 .52 .665 r
.60547 .69846 .6064 .70271 .60805 .70139 .60712 .6968 Mtetra
.958 .685 .477 r
.60712 .6968 .60805 .70139 .60961 .69608 .60436 .51035 Mtetra
.591 .379 .561 r
.60436 .51035 .60961 .69608 .60652 .50161 .60563 .49679 Mtetra
.725 .539 .639 r
.60563 .49679 .60652 .50161 .60797 .49572 .60714 .49357 Mtetra
.668 .582 .75 r
.60714 .49357 .60797 .49572 .60953 .49435 .60872 .49283 Mtetra
.611 .612 .828 r
.60872 .49283 .60953 .49435 .61111 .49366 .6103 .49259 Mtetra
.543 .657 .91 r
.6103 .49259 .61111 .49366 .61269 .4933 .6119 .49256 Mtetra
.644 .777 .945 r
.6119 .49256 .61269 .4933 .61428 .49283 .61348 .49213 Mtetra
.655 .791 .947 r
.61348 .49213 .61428 .49283 .61586 .49243 .61507 .49165 Mtetra
.676 .776 .925 r
.61507 .49165 .61586 .49243 .61745 .49203 .61665 .4911 Mtetra
.72 .752 .877 r
.61665 .4911 .61745 .49203 .61904 .4915 .61823 .49033 Mtetra
.694 .699 .85 r
.61823 .49033 .61904 .4915 .62062 .49095 .61982 .48966 Mtetra
.654 .664 .848 r
.61982 .48966 .62062 .49095 .62221 .49035 .62141 .48919 Mtetra
.554 .644 .894 r
.62141 .48919 .62221 .49035 .62378 .48935 .62301 .48916 Mtetra
.247 0 0 r
.62301 .48916 .62378 .48935 .62537 .48873 .62463 .48966 Mtetra
.731 .315 .258 r
.62463 .48966 .62537 .48873 .62698 .48887 .62629 .49131 Mtetra
.961 .679 .456 r
.62629 .49131 .62698 .48887 .62873 .49343 .63363 .67587 Mtetra
.589 .373 .556 r
.63363 .67587 .62873 .49343 .63654 .68855 .63577 .68979 Mtetra
.785 .402 .331 r
.63577 .68979 .63654 .68855 .6384 .69334 .63757 .69254 Mtetra
.158 .531 .922 r
.63757 .69254 .6384 .69334 .64013 .69397 .6393 .69313 Mtetra
.604 .751 .948 r
.6393 .69313 .64013 .69397 .64183 .69353 .641 .69282 Mtetra
.804 .826 .868 r
.641 .69282 .64183 .69353 .64349 .69202 .64267 .69152 Mtetra
.956 .79 .635 r
.64267 .69152 .64349 .69202 .64502 .68647 .64421 .68626 Mtetra
.967 .691 .457 r
.64421 .68626 .64502 .68647 .63992 .49041 .63915 .48994 Mtetra
.962 .775 .604 r
.63915 .48994 .63992 .49041 .64134 .48465 .64055 .48376 Mtetra
.779 .776 .85 r
.64055 .48376 .64134 .48465 .64292 .48353 .64213 .48261 Mtetra
.643 .733 .914 r
.64213 .48261 .64292 .48353 .64452 .48313 .64373 .4822 Mtetra
.53 .686 .938 r
.64373 .4822 .64452 .48313 .64614 .48309 .64535 .48217 Mtetra
.751 .764 .864 r
.64535 .48217 .64614 .48309 .64772 .48214 .64694 .48121 Mtetra
.693 .748 .893 r
.64694 .48121 .64772 .48214 .64932 .48151 .64854 .48058 Mtetra
.501 .671 .94 r
.64854 .48058 .64932 .48151 .65095 .48156 .65016 .48062 Mtetra
.88 .463 .042 r
.65016 .48062 .65095 .48156 .65274 .48584 .65195 .48487 Mtetra
.968 .684 .439 r
.65195 .48487 .65274 .48584 .66201 .68126 .66119 .68036 Mtetra
.906 .501 .113 r
.66119 .68036 .66201 .68126 .66394 .68631 .66311 .68544 Mtetra
.103 .475 .895 r
.66311 .68544 .66394 .68631 .6657 .68707 .66487 .6862 Mtetra
.624 .754 .939 r
.66487 .6862 .6657 .68707 .66742 .68668 .66659 .68582 Mtetra
.807 .798 .844 r
.66659 .68582 .66742 .68668 .66909 .68527 .66827 .68441 Mtetra
.936 .769 .649 r
.66827 .68441 .66909 .68527 .67062 .68038 .6698 .67952 Mtetra
.968 .69 .449 r
.6698 .67952 .67062 .68038 .6641 .48439 .66332 .48348 Mtetra
.948 .747 .598 r
.66332 .48348 .6641 .48439 .66545 .47765 .66467 .47674 Mtetra
.794 .776 .836 r
.66467 .47674 .66545 .47765 .66703 .47637 .66625 .47545 Mtetra
.624 .729 .922 r
.66625 .47545 .66703 .47637 .66865 .47602 .66788 .47511 Mtetra
.482 .668 .945 r
.66788 .47511 .66865 .47602 .67029 .47609 .66952 .47519 Mtetra
.628 .733 .923 r
.66952 .47519 .67029 .47609 .67192 .47572 .67114 .47483 Mtetra
.652 .745 .918 r
.67114 .47483 .67192 .47572 .67353 .47526 .67276 .47438 Mtetra
.659 .75 .917 r
.67276 .47438 .67353 .47526 .67515 .47477 .67438 .47389 Mtetra
.746 .776 .878 r
.67438 .47389 .67515 .47477 .67675 .47376 .67598 .47298 Mtetra
.714 .792 .912 r
.67598 .47298 .67675 .47376 .67836 .47301 .67759 .47226 Mtetra
.565 .747 .963 r
.67759 .47226 .67836 .47301 .68 .47295 .67923 .47205 Mtetra
.601 .125 0 r
.67923 .47205 .68 .47295 .68184 .47695 .68098 .47428 Mtetra
.972 .685 .422 r
.68098 .47428 .68184 .47695 .69289 .67268 .69091 .64742 Mtetra
.048 0 .469 r
.69091 .64742 .69289 .67268 .69489 .67784 .6939 .67335 Mtetra
.414 .344 .669 r
.6939 .67335 .69489 .67784 .69667 .6784 .69575 .67524 Mtetra
.517 .451 .722 r
.69575 .67524 .69667 .6784 .6984 .67788 .69753 .67579 Mtetra
.565 .544 .789 r
.69753 .67579 .6984 .67788 .70011 .67689 .69929 .67584 Mtetra
.441 .628 .933 r
.69929 .67584 .70011 .67689 .70184 .67643 .70106 .67608 Mtetra
.397 .797 .985 r
.70106 .67608 .70184 .67643 .70357 .67581 .70281 .67591 Mtetra
.57 .94 .859 r
.70281 .67591 .70357 .67581 .70526 .67453 .70452 .67499 Mtetra
.985 .902 .604 r
.70452 .67499 .70526 .67453 .70676 .66958 .70606 .67072 Mtetra
.973 .691 .431 r
.70606 .67072 .70676 .66958 .69821 .47349 .69752 .47394 Mtetra
.998 .805 .521 r
.69752 .47394 .69821 .47349 .69954 .46725 .69876 .46604 Mtetra
.803 .732 .785 r
.69876 .46604 .69954 .46725 .70112 .46568 .70034 .46441 Mtetra
.642 .667 .859 r
.70034 .46441 .70112 .46568 .70275 .46517 .70198 .464 Mtetra
.534 .635 .897 r
.70198 .464 .70275 .46517 .70441 .46504 .70364 .46403 Mtetra
.625 .71 .907 r
.70364 .46403 .70441 .46504 .70604 .46455 .70529 .46369 Mtetra
.667 .761 .921 r
.70529 .46369 .70604 .46455 .70767 .46393 .70692 .46317 Mtetra
.676 .787 .933 r
.70692 .46317 .70767 .46393 .70931 .46338 .70856 .4626 Mtetra
.769 .805 .882 r
.70856 .4626 .70931 .46338 .71094 .46273 .71017 .46157 Mtetra
.725 .718 .843 r
.71017 .46157 .71094 .46273 .71258 .46231 .71179 .46069 Mtetra
.616 .606 .818 r
.71179 .46069 .71258 .46231 .71426 .46249 .71344 .46041 Mtetra
0 .112 .654 r
.71344 .46041 .71426 .46249 .71613 .46576 .71526 .46302 Mtetra
.974 .683 .408 r
.71526 .46302 .71613 .46576 .72925 .6609 .72834 .65816 Mtetra
.809 .485 0 r
.72834 .65816 .72925 .6609 .73139 .66705 .7306 .66642 Mtetra
0 .321 .758 r
.7306 .66642 .73139 .66705 .73323 .66804 .73245 .66742 Mtetra
.638 .829 .974 r
.73245 .66742 .73323 .66804 .73499 .6677 .7342 .6669 Mtetra
.756 .813 .898 r
.7342 .6669 .73499 .6677 .73672 .66686 .73592 .6659 Mtetra
.607 .728 .931 r
.73592 .6659 .73672 .66686 .73847 .66633 .73769 .66559 Mtetra
.532 .752 .977 r
.73769 .66559 .73847 .66633 .74022 .66571 .73946 .66543 Mtetra
.616 .911 .982 r
.73946 .66543 .74022 .66571 .74193 .66444 .74121 .66478 Mtetra
.913 .976 .694 r
.74121 .66478 .74193 .66444 .74343 .65988 .74284 .6622 Mtetra
.84 .771 .263 r
.74284 .6622 .74343 .65988 .73278 .46329 .74418 .65508 Mtetra
.08 0 .455 r
.74418 .65508 .73278 .46329 .73405 .45667 .73356 .45996 Mtetra
0 0 .218 r
.73356 .45996 .73405 .45667 .73562 .45484 .735 .45602 Mtetra
0 0 0 r
.735 .45602 .73562 .45484 .73727 .4543 .73658 .45428 Mtetra
.721 .984 .898 r
.73658 .45428 .73727 .4543 .73895 .45418 .7382 .4532 Mtetra
.691 .742 .89 r
.7382 .4532 .73895 .45418 .74062 .45391 .73984 .45255 Mtetra
.633 .652 .85 r
.73984 .45255 .74062 .45391 .74228 .45346 .74151 .45218 Mtetra
.607 .651 .868 r
.74151 .45218 .74228 .45346 .74394 .453 .74319 .45194 Mtetra
.633 .704 .898 r
.74319 .45194 .74394 .453 .7456 .45243 .74486 .45156 Mtetra
.661 .76 .923 r
.74486 .45156 .7456 .45243 .74725 .45182 .74652 .45106 Mtetra
.671 .79 .938 r
.74652 .45106 .74725 .45182 .74891 .45126 .74817 .4505 Mtetra
.742 .81 .906 r
.74817 .4505 .74891 .45126 .75056 .45065 .74981 .44963 Mtetra
.73 .749 .867 r
.74981 .44963 .75056 .45065 .75223 .45021 .75145 .44876 Mtetra
.642 .643 .835 r
.75145 .44876 .75223 .45021 .75394 .45035 .75312 .44833 Mtetra
.33 .401 .784 r
.75312 .44833 .75394 .45035 .75584 .4532 .75491 .44953 Mtetra
0 0 .52 r
.75491 .44953 .75584 .4532 .77143 .64876 .75698 .45479 Mtetra
.102 .022 .471 r
.75698 .45479 .77143 .64876 .77372 .65547 .7726 .64977 Mtetra
.318 .259 .633 r
.7726 .64977 .77372 .65547 .77563 .65677 .77467 .65338 Mtetra
.478 .42 .713 r
.77467 .65338 .77563 .65677 .77742 .65649 .77655 .65434 Mtetra
.534 .523 .79 r
.77655 .65434 .77742 .65649 .77918 .65569 .77839 .65459 Mtetra
.513 .657 .924 r
.77839 .65459 .77918 .65569 .78095 .65506 .78021 .65464 Mtetra
.449 .81 .996 r
.78021 .65464 .78095 .65506 .78273 .65448 .78201 .65443 Mtetra
.557 .93 .916 r
.78201 .65443 .78273 .65448 .78446 .65332 .78378 .65366 Mtetra
.859 .984 .699 r
.78378 .65366 .78446 .65332 .78601 .64968 .78543 .65139 Mtetra
.836 .798 .304 r
.78543 .65139 .78601 .64968 .77304 .45441 .78682 .64569 Mtetra
.094 .013 .464 r
.78682 .64569 .77304 .45441 .77404 .44498 .77371 .44934 Mtetra
0 0 .284 r
.77371 .44934 .77404 .44498 .77558 .44265 .77503 .44413 Mtetra
0 0 0 r
.77503 .44413 .77558 .44265 .77725 .442 .7766 .44216 Mtetra
.661 .968 .803 r
.7766 .44216 .77725 .442 .77895 .4418 .77823 .44095 Mtetra
.712 .783 .907 r
.77823 .44095 .77895 .4418 .78065 .44155 .77989 .44021 Mtetra
.643 .661 .852 r
.77989 .44021 .78065 .44155 .78233 .44108 .78158 .43978 Mtetra
.615 .655 .866 r
.78158 .43978 .78233 .44108 .78402 .44058 .78328 .4395 Mtetra
.631 .701 .896 r
.78328 .4395 .78402 .44058 .78569 .44 .78497 .43912 Mtetra
.665 .761 .922 r
.78497 .43912 .78569 .44 .78737 .43936 .78665 .4386 Mtetra
.674 .794 .939 r
.78665 .4386 .78737 .43936 .78904 .43876 .78833 .43802 Mtetra
.734 .816 .915 r
.78833 .43802 .78904 .43876 .79072 .43813 .78999 .43718 Mtetra
.743 .769 .874 r
.78999 .43718 .79072 .43813 .79241 .43761 .79165 .43624 Mtetra
.661 .665 .844 r
.79165 .43624 .79241 .43761 .79413 .4376 .79333 .43571 Mtetra
.417 .469 .806 r
.79333 .43571 .79413 .4376 .79603 .4396 .79513 .43649 Mtetra
0 .075 .605 r
.79513 .43649 .79603 .4396 .81389 .63233 .79719 .44045 Mtetra
.113 .034 .479 r
.79719 .44045 .81389 .63233 .81662 .64293 .81534 .6359 Mtetra
.283 .221 .609 r
.81534 .6359 .81662 .64293 .81862 .6448 .81761 .64094 Mtetra
.483 .408 .697 r
.81761 .64094 .81862 .6448 .82046 .64462 .81955 .64201 Mtetra
.541 .496 .755 r
.81955 .64201 .82046 .64462 .82224 .64387 .82142 .64229 Mtetra
.539 .588 .852 r
.82142 .64229 .82224 .64387 .82403 .64316 .82328 .64239 Mtetra
.477 .722 .978 r
.82328 .64239 .82403 .64316 .82584 .64265 .82514 .64237 Mtetra
.557 .897 .981 r
.82514 .64237 .82584 .64265 .8276 .6416 .82694 .64181 Mtetra
.811 .993 .754 r
.82694 .64181 .8276 .6416 .82919 .63856 .82863 .63993 Mtetra
.834 .815 .332 r
.82863 .63993 .82919 .63856 .81424 .44858 .83005 .63492 Mtetra
.098 .019 .47 r
.83005 .63492 .81424 .44858 .81462 .4331 .81448 .43871 Mtetra
.03 0 .339 r
.81448 .43871 .81462 .4331 .81611 .43033 .81565 .43214 Mtetra
.073 0 .129 r
.81565 .43214 .81611 .43033 .8178 .42964 .81722 .43017 Mtetra
0 0 0 r
.81722 .43017 .8178 .42964 .81953 .42947 .81886 .429 Mtetra
.701 .89 .966 r
.81886 .429 .81953 .42947 .82128 .42936 .82055 .42825 Mtetra
.659 .711 .886 r
.82055 .42825 .82128 .42936 .82299 .42894 .82225 .42774 Mtetra
.625 .678 .88 r
.82225 .42774 .82299 .42894 .82471 .42853 .82398 .4274 Mtetra
.667 .709 .879 r
.82398 .4274 .82471 .42853 .8264 .42792 .82568 .42685 Mtetra
.722 .742 .868 r
.82568 .42685 .8264 .42792 .82808 .42711 .82736 .426 Mtetra
.615 .692 .898 r
.82736 .426 .82808 .42711 .82981 .42676 .82909 .42569 Mtetra
0 .209 .732 r
.82909 .42569 .82981 .42676 .83169 .42808 .83101 .42739 Mtetra
.975 .671 .357 r
.83101 .42739 .83169 .42808 .83528 .44732 .85135 .6235 Mtetra
.581 .366 .554 r
.85135 .6235 .83528 .44732 .85466 .63177 .8541 .63274 Mtetra
.747 .306 .204 r
.8541 .63274 .85466 .63177 .85678 .63428 .85618 .63486 Mtetra
.339 0 0 r
.85618 .63486 .85678 .63428 .85867 .63444 .85806 .63487 Mtetra
0 0 0 r
.85806 .63487 .85867 .63444 .86047 .63363 .85986 .63399 Mtetra
.817 .969 .656 r
.85986 .63399 .86047 .63363 .86212 .63127 .86152 .63171 Mtetra
.995 .842 .49 r
.86152 .63171 .86212 .63127 .86325 .6236 .86277 .6253 Mtetra
.979 .681 .359 r
.86277 .6253 .86325 .6236 .8456 .42573 .84495 .42537 Mtetra
.986 .835 .609 r
.84495 .42537 .8456 .42573 .84697 .42174 .84626 .42071 Mtetra
.746 .761 .864 r
.84626 .42071 .84697 .42174 .84865 .42081 .84794 .41972 Mtetra
.616 .699 .904 r
.84794 .41972 .84865 .42081 .85039 .42047 .84968 .41941 Mtetra
.582 .688 .914 r
.84968 .41941 .85039 .42047 .85214 .42024 .85144 .41922 Mtetra
.677 .738 .897 r
.85144 .41922 .85214 .42024 .85386 .41964 .85315 .41862 Mtetra
.683 .742 .895 r
.85315 .41862 .85386 .41964 .85557 .41902 .85487 .418 Mtetra
.705 .748 .885 r
.85487 .418 .85557 .41902 .85728 .41837 .85657 .41725 Mtetra
.731 .741 .859 r
.85657 .41725 .85728 .41837 .85899 .41766 .85826 .41634 Mtetra
.7 .693 .84 r
.85826 .41634 .85899 .41766 .8607 .41695 .85996 .41556 Mtetra
.654 .662 .846 r
.85996 .41556 .8607 .41695 .8624 .41611 .86169 .41505 Mtetra
.543 .671 .921 r
.86169 .41505 .8624 .41611 .86407 .41505 .86347 .415 Mtetra
.297 0 0 r
.86347 .415 .86407 .41505 .86579 .41444 .86531 .41555 Mtetra
.751 .323 .236 r
.86531 .41555 .86579 .41444 .86764 .41502 .86733 .41771 Mtetra
.973 .665 .35 r
.86733 .41771 .86764 .41502 .87003 .42069 .88966 .61107 Mtetra
.58 .366 .554 r
.88966 .61107 .87003 .42069 .89311 .61965 .89255 .62031 Mtetra
.761 .29 .127 r
.89255 .62031 .89311 .61965 .89541 .6234 .8947 .62256 Mtetra
.435 .686 .97 r
.8947 .62256 .89541 .6234 .89732 .62342 .89662 .62269 Mtetra
.634 .809 .967 r
.89662 .62269 .89732 .62342 .89916 .62276 .89848 .62218 Mtetra
.73 .883 .951 r
.89848 .62218 .89916 .62276 .90099 .62202 .90029 .62127 Mtetra
.767 .846 .911 r
.90029 .62127 .90099 .62202 .90291 .62206 .90209 .62018 Mtetra
.767 .67 .756 r
.90209 .62018 .90291 .62206 .90478 .62163 .90381 .61847 Mtetra
.787 .613 .665 r
.90381 .61847 .90478 .62163 .90651 .61999 .90536 .61512 Mtetra
.975 .672 .36 r
.90536 .61512 .90651 .61999 .90764 .61293 .8857 .42117 Mtetra
.585 .373 .56 r
.8857 .42117 .90764 .61293 .88715 .41282 .8863 .41036 Mtetra
.809 .644 .678 r
.8863 .41036 .88715 .41282 .88845 .40826 .88776 .40731 Mtetra
.729 .776 .891 r
.88776 .40731 .88845 .40826 .89014 .4073 .88947 .40645 Mtetra
.616 .758 .946 r
.88947 .40645 .89014 .4073 .89191 .40697 .89124 .40608 Mtetra
.58 .73 .945 r
.89124 .40608 .89191 .40697 .8937 .40686 .89302 .40584 Mtetra
.697 .749 .892 r
.89302 .40584 .8937 .40686 .89545 .40628 .89475 .40514 Mtetra
.677 .717 .879 r
.89475 .40514 .89545 .40628 .89719 .40567 .89649 .40452 Mtetra
.641 .7 .888 r
.89649 .40452 .89719 .40567 .89892 .40497 .89825 .40409 Mtetra
.551 .719 .951 r
.89825 .40409 .89892 .40497 .9006 .40389 .90004 .40394 Mtetra
.261 0 0 r
.90004 .40394 .9006 .40389 .90234 .40321 .9019 .40431 Mtetra
.703 .264 .205 r
.9019 .40431 .90234 .40321 .90418 .40346 .90391 .40594 Mtetra
.973 .66 .329 r
.90391 .40594 .90418 .40346 .90656 .40824 .92814 .59592 Mtetra
.585 .369 .554 r
.92814 .59592 .90656 .40824 .93211 .60807 .93163 .60912 Mtetra
.772 .333 .207 r
.93163 .60912 .93211 .60807 .93459 .61264 .93388 .61172 Mtetra
.474 .687 .96 r
.93388 .61172 .93459 .61264 .93654 .61274 .93583 .61179 Mtetra
.665 .768 .927 r
.93583 .61179 .93654 .61274 .9384 .61211 .9377 .6112 Mtetra
.751 .808 .898 r
.9377 .6112 .9384 .61211 .94024 .61122 .93952 .61017 Mtetra
.736 .773 .883 r
.93952 .61017 .94024 .61122 .94219 .61129 .94135 .6092 Mtetra
.739 .642 .752 r
.94135 .6092 .94219 .61129 .9441 .61093 .94311 .60767 Mtetra
.76 .596 .674 r
.94311 .60767 .9441 .61093 .94589 .60965 .94472 .60488 Mtetra
.975 .668 .34 r
.94472 .60488 .94589 .60965 .94708 .60349 .92371 .41836 Mtetra
.597 .382 .559 r
.92371 .41836 .94708 .60349 .92413 .40238 .92322 .39944 Mtetra
.803 .623 .658 r
.92322 .39944 .92413 .40238 .92529 .39697 .92462 .39598 Mtetra
.742 .774 .879 r
.92462 .39598 .92529 .39697 .92699 .39587 .92634 .39502 Mtetra
.631 .766 .944 r
.92634 .39502 .92699 .39587 .92877 .39546 .92812 .39459 Mtetra
.566 .731 .953 r
.92812 .39459 .92877 .39546 .93059 .39536 .92993 .39438 Mtetra
.757 .784 .875 r
.92993 .39438 .93059 .39536 .9323 .39433 .93164 .39334 Mtetra
.688 .758 .905 r
.93164 .39334 .9323 .39433 .93406 .39367 .93339 .39268 Mtetra
.491 .662 .938 r
.93339 .39268 .93406 .39367 .93591 .39377 .93525 .39277 Mtetra
.748 .33 0 r
.93525 .39277 .93591 .39377 .93838 .39863 .93771 .39765 Mtetra
.97 .655 .291 r
.93771 .39765 .93838 .39863 .96606 .59903 .96537 .59809 Mtetra
.737 .305 0 r
.96537 .59809 .96606 .59903 .96864 .60374 .96795 .60279 Mtetra
.04 .469 .881 r
.35478 .7684 .35572 .76916 .3572 .76977 .35626 .76901 Mtetra
.645 .762 .934 r
.35626 .76901 .3572 .76977 .35873 .76936 .35779 .76859 Mtetra
.81 .779 .824 r
.35779 .76859 .35873 .76936 .36031 .76793 .35937 .76716 Mtetra
.908 .738 .659 r
.35937 .76716 .36031 .76793 .36207 .76267 .36112 .7619 Mtetra
.937 .686 .534 r
.36112 .7619 .36207 .76267 .37217 .5718 .37128 .57098 Mtetra
.909 .728 .645 r
.37128 .57098 .37217 .5718 .37385 .56611 .37297 .56528 Mtetra
.778 .76 .837 r
.37297 .56528 .37385 .56611 .37534 .565 .37445 .56417 Mtetra
.642 .737 .918 r
.37445 .56417 .37534 .565 .37678 .56463 .3759 .5638 Mtetra
.51 .692 .95 r
.3759 .5638 .37678 .56463 .37822 .56462 .37734 .5638 Mtetra
.746 .758 .862 r
.37734 .5638 .37822 .56462 .37969 .56375 .37881 .56292 Mtetra
.697 .751 .893 r
.37881 .56292 .37969 .56375 .38115 .56315 .38027 .56233 Mtetra
.482 .682 .954 r
.38027 .56233 .38115 .56315 .38259 .5632 .3817 .56238 Mtetra
.926 .545 .249 r
.3817 .56238 .38259 .5632 .38386 .5671 .38298 .56631 Mtetra
.939 .683 .522 r
.38298 .56631 .38386 .5671 .37747 .75725 .37653 .75654 Mtetra
.933 .58 .332 r
.37653 .75654 .37747 .75725 .37878 .76252 .37784 .76177 Mtetra
0 .319 .765 r
.37784 .76177 .37878 .76252 .38027 .76335 .37934 .76261 Mtetra
.62 .764 .949 r
.37934 .76261 .38027 .76335 .38182 .763 .38088 .76227 Mtetra
.809 .789 .833 r
.38088 .76227 .38182 .763 .3834 .7616 .38246 .76088 Mtetra
.913 .743 .657 r
.38246 .76088 .3834 .7616 .38514 .7563 .3842 .75559 Mtetra
.939 .687 .529 r
.3842 .75559 .38514 .7563 .39407 .5646 .39319 .56376 Mtetra
.909 .729 .646 r
.39319 .56376 .39407 .5646 .39573 .55907 .39485 .55821 Mtetra
.776 .755 .834 r
.39485 .55821 .39573 .55907 .39722 .55793 .39634 .55709 Mtetra
.583 .718 .936 r
.39634 .55709 .39722 .55793 .39867 .5577 .3978 .5569 Mtetra
.361 .634 .958 r
.3978 .5569 .39867 .5577 .40012 .55789 .39924 .55715 Mtetra
.575 .739 .954 r
.39924 .55715 .40012 .55789 .40157 .55768 .40069 .55696 Mtetra
.619 .759 .946 r
.40069 .55696 .40157 .55768 .40304 .55735 .40216 .55664 Mtetra
.633 .766 .943 r
.40216 .55664 .40304 .55735 .4045 .55698 .40362 .55628 Mtetra
.647 .771 .939 r
.40362 .55628 .4045 .55698 .40597 .55657 .40509 .55587 Mtetra
.659 .775 .935 r
.40509 .55587 .40597 .55657 .40744 .55612 .40656 .55542 Mtetra
.669 .779 .932 r
.40656 .55542 .40744 .55612 .40891 .55563 .40803 .55494 Mtetra
.673 .781 .931 r
.40803 .55494 .40891 .55563 .41038 .55512 .4095 .55444 Mtetra
.681 .786 .929 r
.4095 .55444 .41038 .55512 .41186 .55459 .41098 .55391 Mtetra
.692 .789 .925 r
.41098 .55391 .41186 .55459 .41333 .55403 .41246 .55334 Mtetra
.751 .793 .887 r
.41246 .55334 .41333 .55403 .41482 .5531 .41394 .55248 Mtetra
.738 .81 .908 r
.41394 .55248 .41482 .5531 .41631 .55234 .41543 .55171 Mtetra
.662 .796 .946 r
.41543 .55171 .41631 .55234 .41778 .55206 .41691 .55124 Mtetra
.021 .427 .864 r
.41691 .55124 .41778 .55206 .41918 .55396 .41834 .55194 Mtetra
0 .166 .687 r
.41834 .55194 .41918 .55396 .42037 .56282 .41975 .55378 Mtetra
.384 .259 .584 r
.41975 .55378 .42037 .56282 .41619 .74839 .4211 .55757 Mtetra
.566 .359 .559 r
.4211 .55757 .41619 .74839 .4177 .74958 .42254 .55857 Mtetra
.57 .362 .56 r
.42254 .55857 .4177 .74958 .41927 .74906 .42405 .55724 Mtetra
.568 .361 .559 r
.42405 .55724 .41927 .74906 .42085 .74822 .42552 .55708 Mtetra
0 0 .364 r
.42552 .55708 .42085 .74822 .42238 .74884 .42167 .74077 Mtetra
.114 .07 .525 r
.42167 .74077 .42238 .74884 .42391 .74974 .42305 .74706 Mtetra
.015 .139 .651 r
.42305 .74706 .42391 .74974 .42545 .75034 .42454 .74943 Mtetra
.231 .546 .928 r
.42454 .74943 .42545 .75034 .42701 .75054 .42608 .74994 Mtetra
.59 .795 .978 r
.42608 .74994 .42701 .75054 .42857 .7503 .42765 .74963 Mtetra
.74 .808 .906 r
.42765 .74963 .42857 .7503 .43016 .74948 .42924 .74879 Mtetra
.842 .798 .808 r
.42924 .74879 .43016 .74948 .43179 .74668 .43084 .74704 Mtetra
.953 .928 .739 r
.43084 .74704 .43179 .74668 .43356 .73881 .43248 .74424 Mtetra
.081 0 .286 r
.43248 .74424 .43356 .73881 .43987 .55003 .43416 .73981 Mtetra
.563 .353 .554 r
.43416 .73981 .43987 .55003 .44141 .54759 .43578 .73753 Mtetra
.567 .357 .554 r
.43578 .73753 .44141 .54759 .4429 .54717 .43733 .73776 Mtetra
.566 .355 .554 r
.43733 .73776 .4429 .54717 .44438 .5471 .43891 .73713 Mtetra
0 0 .364 r
.43891 .73713 .44438 .5471 .4459 .54578 .44484 .55334 Mtetra
0 0 .215 r
.44484 .55334 .4459 .54578 .44742 .54407 .44651 .54514 Mtetra
.928 .947 .608 r
.44651 .54514 .44742 .54407 .44893 .54267 .44807 .54197 Mtetra
.796 .795 .851 r
.44807 .54197 .44893 .54267 .45043 .54192 .44958 .54078 Mtetra
.639 .674 .867 r
.44958 .54078 .45043 .54192 .45192 .54155 .45107 .54042 Mtetra
.575 .653 .889 r
.45107 .54042 .45192 .54155 .45341 .54127 .45256 .54032 Mtetra
.647 .715 .897 r
.45256 .54032 .45341 .54127 .45491 .5408 .45405 .53992 Mtetra
.696 .745 .889 r
.45405 .53992 .45491 .5408 .45641 .54019 .45555 .53931 Mtetra
.698 .744 .887 r
.45555 .53931 .45641 .54019 .45791 .53959 .45705 .5387 Mtetra
.707 .743 .88 r
.45705 .5387 .45791 .53959 .45941 .53883 .45855 .53803 Mtetra
.691 .76 .904 r
.45855 .53803 .45941 .53883 .46091 .53818 .46006 .53744 Mtetra
.619 .759 .946 r
.46006 .53744 .46091 .53818 .46241 .53794 .46155 .53712 Mtetra
.158 .513 .914 r
.46155 .53712 .46241 .53794 .46387 .53937 .46304 .53768 Mtetra
0 .176 .707 r
.46304 .53768 .46387 .53937 .46526 .54521 .4645 .53936 Mtetra
.297 .225 .604 r
.4645 .53936 .46526 .54521 .4635 .73439 .46594 .54268 Mtetra
.561 .355 .558 r
.46594 .54268 .4635 .73439 .46504 .73681 .46737 .54642 Mtetra
.567 .36 .559 r
.46737 .54642 .46504 .73681 .46663 .73659 .46887 .54656 Mtetra
.571 .363 .56 r
.46887 .54656 .46663 .73659 .46823 .73568 .4704 .54453 Mtetra
.57 .362 .56 r
.4704 .54453 .46823 .73568 .46983 .73492 .47193 .54326 Mtetra
.569 .361 .559 r
.47193 .54326 .46983 .73492 .47142 .73444 .47344 .5426 Mtetra
.47344 .5426 .47142 .73444 .47302 .73395 .47496 .54196 Mtetra
.57 .363 .56 r
.47496 .54196 .47302 .73395 .47462 .7333 .47648 .54044 Mtetra
.57 .362 .56 r
.47648 .54044 .47462 .7333 .47622 .73263 .47801 .53913 Mtetra
.567 .36 .559 r
.47801 .53913 .47622 .73263 .47782 .73229 .47951 .53931 Mtetra
0 0 .397 r
.47951 .53931 .47782 .73229 .4794 .73287 .47866 .7204 Mtetra
.113 .049 .498 r
.47866 .7204 .4794 .73287 .48099 .73382 .48012 .73048 Mtetra
.068 .139 .629 r
.48012 .73048 .48099 .73382 .48258 .73448 .48168 .73335 Mtetra
.202 .474 .89 r
.48168 .73335 .48258 .73448 .48417 .73454 .48327 .73409 Mtetra
.561 .835 .997 r
.48327 .73409 .48417 .73454 .48578 .73412 .48488 .73376 Mtetra
.679 .888 .974 r
.48488 .73376 .48578 .73412 .48739 .73355 .48649 .7331 Mtetra
.675 .862 .971 r
.48649 .7331 .48739 .73355 .48899 .73302 .48809 .73249 Mtetra
.633 .833 .977 r
.48809 .73249 .48899 .73302 .4906 .73255 .4897 .73202 Mtetra
.4897 .73202 .4906 .73255 .49221 .73208 .49131 .73155 Mtetra
.631 .832 .977 r
.49131 .73155 .49221 .73208 .49382 .73163 .49292 .73109 Mtetra
.629 .83 .978 r
.49292 .73109 .49382 .73163 .49543 .73117 .49453 .73064 Mtetra
.627 .83 .978 r
.49453 .73064 .49543 .73117 .49704 .73072 .49615 .73019 Mtetra
.626 .83 .979 r
.49615 .73019 .49704 .73072 .49865 .73028 .49776 .72974 Mtetra
.49776 .72974 .49865 .73028 .50027 .72983 .49937 .7293 Mtetra
.625 .83 .979 r
.49937 .7293 .50027 .72983 .50188 .72939 .50099 .72885 Mtetra
.624 .829 .979 r
.50099 .72885 .50188 .72939 .5035 .72894 .50261 .72841 Mtetra
.50261 .72841 .5035 .72894 .50511 .7285 .50422 .72796 Mtetra
.50422 .72796 .50511 .7285 .50673 .72806 .50584 .72752 Mtetra
.623 .829 .979 r
.50584 .72752 .50673 .72806 .50835 .72762 .50746 .72708 Mtetra
.623 .829 .98 r
.50746 .72708 .50835 .72762 .50997 .72717 .50908 .72664 Mtetra
.50908 .72664 .50997 .72717 .51159 .72673 .5107 .7262 Mtetra
.5107 .7262 .51159 .72673 .51321 .72629 .51232 .72576 Mtetra
.51232 .72576 .51321 .72629 .51483 .72585 .51394 .72531 Mtetra
.622 .829 .98 r
.51394 .72531 .51483 .72585 .51645 .72541 .51557 .72487 Mtetra
.51557 .72487 .51645 .72541 .51808 .72497 .51719 .72443 Mtetra
.51719 .72443 .51808 .72497 .5197 .72453 .51882 .72399 Mtetra
.621 .829 .98 r
.51882 .72399 .5197 .72453 .52133 .72409 .52044 .72355 Mtetra
.52044 .72355 .52133 .72409 .52295 .72365 .52207 .72311 Mtetra
.621 .83 .981 r
.52207 .72311 .52295 .72365 .52458 .72321 .5237 .72268 Mtetra
.62 .83 .981 r
.5237 .72268 .52458 .72321 .52621 .72277 .52533 .72224 Mtetra
.52533 .72224 .52621 .72277 .52784 .72234 .52696 .7218 Mtetra
.619 .83 .981 r
.52696 .7218 .52784 .72234 .52947 .7219 .52859 .72136 Mtetra
.618 .83 .981 r
.52859 .72136 .52947 .7219 .5311 .72147 .53022 .72093 Mtetra
.618 .83 .982 r
.53022 .72093 .5311 .72147 .53273 .72103 .53186 .7205 Mtetra
.617 .829 .982 r
.53186 .7205 .53273 .72103 .53437 .7206 .53349 .72006 Mtetra
.616 .828 .982 r
.53349 .72006 .53437 .7206 .536 .72018 .53512 .71964 Mtetra
.618 .828 .981 r
.53512 .71964 .536 .72018 .53764 .71975 .53676 .7192 Mtetra
.62 .827 .98 r
.53676 .7192 .53764 .71975 .53927 .71933 .5384 .71877 Mtetra
.612 .822 .981 r
.5384 .71877 .53927 .71933 .54091 .71892 .54004 .71836 Mtetra
.588 .813 .985 r
.54004 .71836 .54091 .71892 .54255 .71857 .54168 .71801 Mtetra
.554 .802 .991 r
.54168 .71801 .54255 .71857 .54419 .71828 .54332 .71774 Mtetra
.55 .807 .993 r
.54332 .71774 .54419 .71828 .54583 .71798 .54496 .71746 Mtetra
.571 .82 .992 r
.54496 .71746 .54583 .71798 .54747 .71764 .5466 .71713 Mtetra
.608 .835 .986 r
.5466 .71713 .54747 .71764 .54912 .71722 .54825 .71671 Mtetra
.622 .838 .983 r
.54825 .71671 .54912 .71722 .55076 .71677 .54989 .71625 Mtetra
.625 .836 .981 r
.54989 .71625 .55076 .71677 .5524 .71632 .55153 .71579 Mtetra
.619 .831 .982 r
.55153 .71579 .5524 .71632 .55405 .71589 .55318 .71534 Mtetra
.638 .835 .976 r
.55318 .71534 .55405 .71589 .5557 .71541 .55483 .71485 Mtetra
.661 .837 .968 r
.55483 .71485 .5557 .71541 .55734 .71494 .55647 .7143 Mtetra
.691 .819 .944 r
.55647 .7143 .55734 .71494 .55899 .71452 .55812 .71365 Mtetra
.734 .775 .886 r
.55812 .71365 .55899 .71452 .56064 .71374 .55977 .71279 Mtetra
.797 .769 .827 r
.55977 .71279 .56064 .71374 .56227 .71187 .56141 .7114 Mtetra
.91 .835 .759 r
.56141 .7114 .56227 .71187 .56387 .70623 .56304 .70878 Mtetra
0 0 0 r
.56304 .70878 .56387 .70623 .56331 .51421 .56465 .70477 Mtetra
.556 .347 .553 r
.56465 .70477 .56331 .51421 .56481 .50904 .56622 .69786 Mtetra
.553 .345 .552 r
.56622 .69786 .56481 .50904 .56636 .50772 .56777 .68908 Mtetra
.576 .363 .555 r
.56777 .68908 .56636 .50772 .56792 .5076 .56949 .69471 Mtetra
.578 .365 .555 r
.56949 .69471 .56792 .5076 .56952 .50955 .57124 .70158 Mtetra
.574 .362 .555 r
.57124 .70158 .56952 .50955 .57373 .70013 .57296 .70603 Mtetra
.649 .372 .486 r
.57296 .70603 .57373 .70013 .5755 .70779 .57465 .70825 Mtetra
.639 .141 .05 r
.57465 .70825 .5755 .70779 .57719 .70987 .57633 .70921 Mtetra
.549 .775 .982 r
.57633 .70921 .57719 .70987 .57886 .70978 .578 .709 Mtetra
.662 .779 .936 r
.578 .709 .57886 .70978 .58052 .7092 .57966 .70848 Mtetra
.684 .799 .936 r
.57966 .70848 .58052 .7092 .58218 .70847 .58132 .70786 Mtetra
.625 .816 .973 r
.58132 .70786 .58218 .70847 .58384 .70802 .58298 .70742 Mtetra
.633 .822 .973 r
.58298 .70742 .58384 .70802 .5855 .70753 .58465 .70696 Mtetra
.648 .83 .97 r
.58465 .70696 .5855 .70753 .58717 .70701 .58631 .70644 Mtetra
.673 .839 .963 r
.58631 .70644 .58717 .70701 .58883 .70642 .58798 .70584 Mtetra
.678 .838 .96 r
.58798 .70584 .58883 .70642 .5905 .70581 .58964 .70522 Mtetra
.654 .828 .967 r
.58964 .70522 .5905 .70581 .59216 .70526 .59131 .70468 Mtetra
.536 .794 .993 r
.59131 .70468 .59216 .70526 .59383 .70489 .59298 .70445 Mtetra
.602 .856 .992 r
.59298 .70445 .59383 .70489 .5955 .70443 .59466 .70399 Mtetra
.785 .888 .919 r
.59466 .70399 .5955 .70443 .59717 .7037 .59631 .7029 Mtetra
.903 .785 .721 r
.59631 .7029 .59717 .7037 .59882 .70224 .59793 .69976 Mtetra
.873 .669 .624 r
.59793 .69976 .59882 .70224 .60046 .70046 .59947 .69323 Mtetra
.954 .682 .483 r
.59947 .69323 .60046 .70046 .60211 .69879 .59706 .50452 Mtetra
.569 .362 .56 r
.59706 .50452 .60211 .69879 .60379 .69876 .59863 .50348 Mtetra
.567 .36 .559 r
.59863 .50348 .60379 .69876 .60547 .69846 .60023 .5038 Mtetra
.57 .362 .56 r
.60023 .5038 .60547 .69846 .60712 .6968 .60179 .50248 Mtetra
.576 .367 .56 r
.60179 .50248 .60712 .6968 .60436 .51035 .60327 .4974 Mtetra
.635 .436 .596 r
.60327 .4974 .60436 .51035 .60563 .49679 .60479 .49446 Mtetra
.745 .612 .71 r
.60479 .49446 .60563 .49679 .60714 .49357 .60634 .49263 Mtetra
.676 .737 .896 r
.60634 .49263 .60714 .49357 .60872 .49283 .60792 .49209 Mtetra
.581 .755 .961 r
.60792 .49209 .60872 .49283 .6103 .49259 .60951 .49185 Mtetra
.539 .738 .967 r
.60951 .49185 .6103 .49259 .6119 .49256 .6111 .49171 Mtetra
.653 .751 .922 r
.6111 .49171 .6119 .49256 .61348 .49213 .61269 .49126 Mtetra
.669 .752 .913 r
.61269 .49126 .61348 .49213 .61507 .49165 .61427 .49075 Mtetra
.69 .75 .898 r
.61427 .49075 .61507 .49165 .61665 .4911 .61586 .49014 Mtetra
.75 .753 .855 r
.61586 .49014 .61665 .4911 .61823 .49033 .61743 .48917 Mtetra
.703 .704 .848 r
.61743 .48917 .61823 .49033 .61982 .48966 .61901 .48844 Mtetra
.607 .657 .873 r
.61901 .48844 .61982 .48966 .62141 .48919 .62061 .48821 Mtetra
0 .149 .674 r
.62061 .48821 .62141 .48919 .62301 .48916 .62226 .48969 Mtetra
.871 .489 .315 r
.62226 .48969 .62301 .48916 .62463 .48966 .62398 .49379 Mtetra
.958 .677 .46 r
.62398 .49379 .62463 .48966 .62629 .49131 .63138 .68429 Mtetra
.574 .362 .555 r
.63138 .68429 .62629 .49131 .63363 .67587 .63323 .6891 Mtetra
.601 .358 .521 r
.63323 .6891 .63363 .67587 .63577 .68979 .635 .69093 Mtetra
.62 .196 .216 r
.635 .69093 .63577 .68979 .63757 .69254 .63673 .69176 Mtetra
.24 .586 .946 r
.63673 .69176 .63757 .69254 .6393 .69313 .63846 .69221 Mtetra
.586 .723 .937 r
.63846 .69221 .6393 .69313 .641 .69282 .64016 .69197 Mtetra
.77 .794 .872 r
.64016 .69197 .641 .69282 .64267 .69152 .64184 .69087 Mtetra
.947 .78 .642 r
.64184 .69087 .64267 .69152 .64421 .68626 .64339 .68576 Mtetra
.967 .691 .457 r
.64339 .68576 .64421 .68626 .63915 .48994 .63837 .48933 Mtetra
.957 .763 .601 r
.63837 .48933 .63915 .48994 .64055 .48376 .63977 .48287 Mtetra
.782 .777 .848 r
.63977 .48287 .64055 .48376 .64213 .48261 .64134 .4817 Mtetra
.645 .736 .915 r
.64134 .4817 .64213 .48261 .64373 .4822 .64295 .48128 Mtetra
.531 .688 .939 r
.64295 .48128 .64373 .4822 .64535 .48217 .64457 .48124 Mtetra
.752 .764 .863 r
.64457 .48124 .64535 .48217 .64694 .48121 .64615 .48028 Mtetra
.694 .747 .892 r
.64615 .48028 .64694 .48121 .64854 .48058 .64775 .47964 Mtetra
.503 .671 .939 r
.64775 .47964 .64854 .48058 .65016 .48062 .64938 .47968 Mtetra
.878 .46 .037 r
.64938 .47968 .65016 .48062 .65195 .48487 .65116 .4839 Mtetra
.968 .684 .439 r
.65116 .4839 .65195 .48487 .66119 .68036 .66036 .67945 Mtetra
.906 .503 .114 r
.66036 .67945 .66119 .68036 .66311 .68544 .66229 .68457 Mtetra
.101 .473 .894 r
.66229 .68457 .66311 .68544 .66487 .6862 .66405 .68534 Mtetra
.624 .753 .939 r
.66405 .68534 .66487 .6862 .66659 .68582 .66576 .68496 Mtetra
.806 .798 .844 r
.66576 .68496 .66659 .68582 .66827 .68441 .66744 .68355 Mtetra
.936 .769 .649 r
.66744 .68355 .66827 .68441 .6698 .67952 .66897 .67866 Mtetra
.968 .69 .449 r
.66897 .67866 .6698 .67952 .66332 .48348 .66254 .48257 Mtetra
.948 .747 .598 r
.66254 .48257 .66332 .48348 .66467 .47674 .6639 .47582 Mtetra
.794 .776 .836 r
.6639 .47582 .66467 .47674 .66625 .47545 .66548 .47454 Mtetra
.623 .729 .923 r
.66548 .47454 .66625 .47545 .66788 .47511 .6671 .4742 Mtetra
.479 .667 .946 r
.6671 .4742 .66788 .47511 .66952 .47519 .66874 .47429 Mtetra
.623 .731 .924 r
.66874 .47429 .66952 .47519 .67114 .47483 .67037 .47394 Mtetra
.648 .744 .92 r
.67037 .47394 .67114 .47483 .67276 .47438 .67199 .4735 Mtetra
.658 .751 .919 r
.67199 .4735 .67276 .47438 .67438 .47389 .67361 .47302 Mtetra
.722 .772 .892 r
.67361 .47302 .67438 .47389 .67598 .47298 .67522 .47225 Mtetra
.708 .801 .923 r
.67522 .47225 .67598 .47298 .67759 .47226 .67683 .47155 Mtetra
.628 .786 .957 r
.67683 .47155 .67759 .47226 .67923 .47205 .67846 .47115 Mtetra
.287 .565 .933 r
.67846 .47115 .67923 .47205 .68098 .47428 .68013 .47164 Mtetra
.323 .347 .73 r
.68013 .47164 .68098 .47428 .69091 .64742 .68185 .4732 Mtetra
.559 .354 .559 r
.68185 .4732 .69091 .64742 .6939 .67335 .68372 .47776 Mtetra
.084 .003 .457 r
.68372 .47776 .6939 .67335 .69575 .67524 .69463 .66817 Mtetra
.289 .219 .602 r
.69463 .66817 .69575 .67524 .69753 .67579 .69661 .67283 Mtetra
.303 .324 .717 r
.69661 .67283 .69753 .67579 .69929 .67584 .69846 .6747 Mtetra
.279 .519 .905 r
.69846 .6747 .69929 .67584 .70106 .67608 .70025 .67538 Mtetra
.515 .757 .984 r
.70025 .67538 .70106 .67608 .70281 .67591 .70201 .67524 Mtetra
.765 .841 .91 r
.70201 .67524 .70281 .67591 .70452 .67499 .70372 .67421 Mtetra
.94 .786 .663 r
.70372 .67421 .70452 .67499 .70606 .67072 .70525 .66981 Mtetra
.971 .689 .436 r
.70525 .66981 .70606 .67072 .69752 .47394 .69672 .47242 Mtetra
.931 .716 .59 r
.69672 .47242 .69752 .47394 .69876 .46604 .69798 .46487 Mtetra
.802 .738 .792 r
.69798 .46487 .69876 .46604 .70034 .46441 .69956 .4633 Mtetra
.631 .691 .887 r
.69956 .4633 .70034 .46441 .70198 .464 .70121 .46294 Mtetra
.502 .643 .919 r
.70121 .46294 .70198 .464 .70364 .46403 .70287 .46303 Mtetra
.612 .707 .913 r
.70287 .46303 .70364 .46403 .70529 .46369 .70452 .46274 Mtetra
.661 .737 .906 r
.70452 .46274 .70529 .46369 .70692 .46317 .70616 .46225 Mtetra
.674 .748 .907 r
.70616 .46225 .70692 .46317 .70856 .4626 .7078 .46169 Mtetra
.765 .777 .863 r
.7078 .46169 .70856 .4626 .71017 .46157 .70941 .46064 Mtetra
.741 .767 .874 r
.70941 .46064 .71017 .46157 .71179 .46069 .71103 .45973 Mtetra
.61 .717 .921 r
.71103 .45973 .71179 .46069 .71344 .46041 .71268 .45944 Mtetra
.661 .203 0 r
.71268 .45944 .71344 .46041 .71526 .46302 .71451 .46214 Mtetra
.972 .681 .413 r
.71451 .46214 .71526 .46302 .72834 .65816 .72759 .65799 Mtetra
.934 .565 .275 r
.72759 .65799 .72834 .65816 .7306 .66642 .72982 .66579 Mtetra
0 .359 .787 r
.72982 .66579 .7306 .66642 .73245 .66742 .73166 .66671 Mtetra
.668 .814 .953 r
.73166 .66671 .73245 .66742 .7342 .6669 .73341 .66612 Mtetra
.77 .819 .891 r
.73341 .66612 .7342 .6669 .73592 .6659 .73513 .66504 Mtetra
.638 .764 .939 r
.73513 .66504 .73592 .6659 .73769 .66559 .73688 .66459 Mtetra
.58 .709 .931 r
.73688 .66459 .73769 .66559 .73946 .66543 .73866 .66438 Mtetra
.651 .728 .905 r
.73866 .66438 .73946 .66543 .74121 .66478 .74042 .6639 Mtetra
.802 .801 .85 r
.74042 .6639 .74121 .66478 .74284 .6622 .74212 .66252 Mtetra
.906 .979 .705 r
.74212 .66252 .74284 .6622 .74418 .65508 .74376 .66003 Mtetra
.117 0 .331 r
.74376 .66003 .74418 .65508 .73356 .45996 .74525 .65531 Mtetra
.101 .015 .461 r
.74525 .65531 .73356 .45996 .735 .45602 .73472 .46239 Mtetra
.026 0 .337 r
.73472 .46239 .735 .45602 .73658 .45428 .73596 .45538 Mtetra
.68 .816 .371 r
.73596 .45538 .73658 .45428 .7382 .4532 .73746 .45248 Mtetra
.795 .828 .877 r
.73746 .45248 .7382 .4532 .73984 .45255 .73907 .4513 Mtetra
.633 .668 .866 r
.73907 .4513 .73984 .45255 .74151 .45218 .74074 .45093 Mtetra
.566 .637 .881 r
.74074 .45093 .74151 .45218 .74319 .45194 .74243 .45085 Mtetra
.605 .688 .901 r
.74243 .45085 .74319 .45194 .74486 .45156 .74411 .4506 Mtetra
.653 .733 .908 r
.74411 .4506 .74486 .45156 .74652 .45106 .74577 .45013 Mtetra
.668 .748 .911 r
.74577 .45013 .74652 .45106 .74817 .4505 .74743 .4496 Mtetra
.722 .771 .892 r
.74743 .4496 .74817 .4505 .74981 .44963 .74908 .44881 Mtetra
.731 .793 .901 r
.74908 .44881 .74981 .44963 .75145 .44876 .75072 .44798 Mtetra
.673 .785 .934 r
.75072 .44798 .75145 .44876 .75312 .44833 .75238 .44741 Mtetra
.434 .645 .946 r
.75238 .44741 .75312 .44833 .75491 .44953 .7541 .44762 Mtetra
.292 .389 .79 r
.7541 .44762 .75491 .44953 .75698 .45479 .75589 .44888 Mtetra
.353 .275 .628 r
.75589 .44888 .75698 .45479 .7726 .64977 .75783 .45222 Mtetra
.121 .036 .477 r
.75783 .45222 .7726 .64977 .77467 .65338 .7733 .64427 Mtetra
.261 .188 .582 r
.7733 .64427 .77467 .65338 .77655 .65434 .7756 .65101 Mtetra
.289 .3 .698 r
.7756 .65101 .77655 .65434 .77839 .65459 .77758 .65329 Mtetra
.35 .528 .891 r
.77758 .65329 .77839 .65459 .78021 .65464 .77945 .65394 Mtetra
.56 .78 .981 r
.77945 .65394 .78021 .65464 .78201 .65443 .78125 .65367 Mtetra
.719 .82 .928 r
.78125 .65367 .78201 .65443 .78378 .65366 .78301 .65286 Mtetra
.816 .828 .859 r
.78301 .65286 .78378 .65366 .78543 .65139 .78472 .65143 Mtetra
.919 .974 .767 r
.78472 .65143 .78543 .65139 .78682 .64569 .78638 .64913 Mtetra
.004 0 .238 r
.78638 .64913 .78682 .64569 .77371 .44934 .7879 .64511 Mtetra
.129 .038 .475 r
.7879 .64511 .77371 .44934 .77503 .44413 .77518 .45472 Mtetra
.089 0 .406 r
.77518 .45472 .77503 .44413 .7766 .44216 .77606 .44375 Mtetra
0 0 0 r
.77606 .44375 .7766 .44216 .77823 .44095 .77753 .44044 Mtetra
.845 .888 .87 r
.77753 .44044 .77823 .44095 .77989 .44021 .77913 .43898 Mtetra
.65 .682 .867 r
.77913 .43898 .77989 .44021 .78158 .43978 .78082 .43852 Mtetra
.58 .645 .879 r
.78082 .43852 .78158 .43978 .78328 .4395 .78253 .43839 Mtetra
.598 .683 .901 r
.78253 .43839 .78328 .4395 .78497 .43912 .78424 .43816 Mtetra
.656 .737 .909 r
.78424 .43816 .78497 .43912 .78665 .4386 .78593 .43767 Mtetra
.671 .752 .912 r
.78593 .43767 .78665 .4386 .78833 .43802 .78761 .43712 Mtetra
.717 .774 .897 r
.78761 .43712 .78833 .43802 .78999 .43718 .78927 .43634 Mtetra
.739 .796 .898 r
.78927 .43634 .78999 .43718 .79165 .43624 .79093 .43547 Mtetra
.689 .795 .931 r
.79093 .43547 .79165 .43624 .79333 .43571 .79261 .43483 Mtetra
.499 .688 .952 r
.79261 .43483 .79333 .43571 .79513 .43649 .79435 .43484 Mtetra
.313 .435 .825 r
.79435 .43484 .79513 .43649 .79719 .44045 .79616 .43587 Mtetra
.362 .305 .658 r
.79616 .43587 .79719 .44045 .81534 .6359 .79811 .43842 Mtetra
.158 .066 .492 r
.79811 .43842 .81534 .6359 .81761 .64094 .81547 .62362 Mtetra
.233 .145 .546 r
.81547 .62362 .81761 .64094 .81955 .64201 .8185 .63763 Mtetra
.316 .285 .665 r
.8185 .63763 .81955 .64201 .82142 .64229 .82059 .64049 Mtetra
.345 .448 .823 r
.82059 .64049 .82142 .64229 .82328 .64239 .82253 .6415 Mtetra
.494 .701 .962 r
.82253 .6415 .82328 .64239 .82514 .64237 .82438 .6415 Mtetra
.661 .778 .936 r
.82438 .6415 .82514 .64237 .82694 .64181 .82619 .64094 Mtetra
.784 .813 .875 r
.82619 .64094 .82694 .64181 .82863 .63993 .82794 .63972 Mtetra
.914 .952 .807 r
.82794 .63972 .82863 .63993 .83005 .63492 .82961 .63759 Mtetra
0 0 .165 r
.82961 .63759 .83005 .63492 .81448 .43871 .83115 .634 Mtetra
.55 .343 .553 r
.83115 .634 .81448 .43871 .81565 .43214 .83194 .62199 Mtetra
.133 .044 .48 r
.83194 .62199 .81565 .43214 .81722 .43017 .81682 .43273 Mtetra
0 0 .139 r
.81682 .43273 .81722 .43017 .81886 .429 .81823 .42891 Mtetra
.882 .983 .825 r
.81823 .42891 .81886 .429 .82055 .42825 .81982 .42713 Mtetra
.683 .719 .877 r
.81982 .42713 .82055 .42825 .82225 .42774 .82151 .4265 Mtetra
.609 .664 .878 r
.82151 .4265 .82225 .42774 .82398 .4274 .82324 .42624 Mtetra
.646 .695 .882 r
.82324 .42624 .82398 .4274 .82568 .42685 .82496 .42579 Mtetra
.723 .746 .871 r
.82496 .42579 .82568 .42685 .82736 .426 .82664 .42495 Mtetra
.61 .702 .909 r
.82664 .42495 .82736 .426 .82909 .42569 .82837 .42465 Mtetra
0 .182 .709 r
.82837 .42465 .82909 .42569 .83101 .42739 .8303 .4264 Mtetra
.975 .672 .356 r
.8303 .4264 .83101 .42739 .85135 .6235 .85067 .62328 Mtetra
.932 .553 .214 r
.85067 .62328 .85135 .6235 .8541 .63274 .85338 .63207 Mtetra
.528 .017 0 r
.85338 .63207 .8541 .63274 .85618 .63486 .85545 .63413 Mtetra
.47 .735 .985 r
.85545 .63413 .85618 .63486 .85806 .63487 .85733 .6341 Mtetra
.738 .829 .921 r
.85733 .6341 .85806 .63487 .85986 .63399 .85912 .63317 Mtetra
.892 .834 .782 r
.85912 .63317 .85986 .63399 .86152 .63171 .86078 .63085 Mtetra
.972 .777 .581 r
.86078 .63085 .86152 .63171 .86277 .6253 .86204 .62441 Mtetra
.977 .679 .367 r
.86204 .62441 .86277 .6253 .84495 .42537 .84424 .42433 Mtetra
.946 .772 .634 r
.84424 .42433 .84495 .42537 .84626 .42071 .84555 .41967 Mtetra
.746 .76 .864 r
.84555 .41967 .84626 .42071 .84794 .41972 .84723 .41869 Mtetra
.614 .708 .912 r
.84723 .41869 .84794 .41972 .84968 .41941 .84897 .41837 Mtetra
.58 .693 .919 r
.84897 .41837 .84968 .41941 .85144 .41922 .85073 .41818 Mtetra
.678 .735 .893 r
.85073 .41818 .85144 .41922 .85315 .41862 .85244 .41758 Mtetra
.685 .736 .89 r
.85244 .41758 .85315 .41862 .85487 .418 .85416 .41694 Mtetra
.717 .746 .875 r
.85416 .41694 .85487 .418 .85657 .41725 .85586 .41613 Mtetra
.754 .746 .845 r
.85586 .41613 .85657 .41725 .85826 .41634 .85753 .41504 Mtetra
.701 .698 .844 r
.85753 .41504 .85826 .41634 .85996 .41556 .85923 .41426 Mtetra
.56 .632 .88 r
.85923 .41426 .85996 .41556 .86169 .41505 .86101 .41422 Mtetra
0 .152 .669 r
.86101 .41422 .86169 .41505 .86347 .415 .86297 .41593 Mtetra
.875 .476 .27 r
.86297 .41593 .86347 .415 .86531 .41555 .86529 .421 Mtetra
.972 .663 .362 r
.86529 .421 .86531 .41555 .86733 .41771 .88758 .61528 Mtetra
.573 .36 .554 r
.88758 .61528 .86733 .41771 .88966 .61107 .88992 .61938 Mtetra
.609 .344 .492 r
.88992 .61938 .88966 .61107 .89255 .62031 .892 .62101 Mtetra
.559 .053 .009 r
.892 .62101 .89255 .62031 .8947 .62256 .89398 .62172 Mtetra
.424 .678 .968 r
.89398 .62172 .8947 .62256 .89662 .62269 .89591 .62188 Mtetra
.612 .779 .961 r
.89591 .62188 .89662 .62269 .89848 .62218 .89778 .62147 Mtetra
.788 .86 .904 r
.89778 .62147 .89848 .62218 .90029 .62127 .89956 .62027 Mtetra
.911 .806 .731 r
.89956 .62027 .90029 .62127 .90209 .62018 .90115 .61732 Mtetra
.879 .666 .611 r
.90115 .61732 .90209 .62018 .90381 .61847 .90238 .6111 Mtetra
.974 .671 .369 r
.90238 .6111 .90381 .61847 .90536 .61512 .88267 .41537 Mtetra
.575 .366 .559 r
.88267 .41537 .90536 .61512 .8857 .42117 .88392 .41034 Mtetra
.633 .438 .601 r
.88392 .41034 .8857 .42117 .8863 .41036 .88544 .40785 Mtetra
.718 .595 .718 r
.88544 .40785 .8863 .41036 .88776 .40731 .88708 .40635 Mtetra
.698 .762 .901 r
.88708 .40635 .88776 .40731 .88947 .40645 .88881 .40564 Mtetra
.631 .775 .95 r
.88881 .40564 .88947 .40645 .89124 .40608 .89056 .40521 Mtetra
.627 .757 .94 r
.89056 .40521 .89124 .40608 .89302 .40584 .89233 .4048 Mtetra
.723 .756 .878 r
.89233 .4048 .89302 .40584 .89475 .40514 .89404 .40395 Mtetra
.677 .709 .872 r
.89404 .40395 .89475 .40514 .89649 .40452 .89578 .40334 Mtetra
.557 .652 .898 r
.89578 .40334 .89649 .40452 .89825 .40409 .89759 .40327 Mtetra
0 .2 .709 r
.89759 .40327 .89825 .40409 .90004 .40394 .89959 .40488 Mtetra
.863 .452 .249 r
.89959 .40488 .90004 .40394 .9019 .40431 .90194 .40951 Mtetra
.972 .659 .341 r
.90194 .40951 .9019 .40431 .90391 .40594 .92655 .60385 Mtetra
.573 .36 .554 r
.92655 .60385 .90391 .40594 .92814 .59592 .92901 .60837 Mtetra
.598 .35 .512 r
.92901 .60837 .92814 .59592 .93163 .60912 .93116 .61012 Mtetra
.576 .11 .111 r
.93116 .61012 .93163 .60912 .93388 .61172 .93318 .61083 Mtetra
.49 .701 .963 r
.93318 .61083 .93388 .61172 .93583 .61179 .93512 .61084 Mtetra
.654 .764 .93 r
.93512 .61084 .93583 .61179 .9377 .6112 .937 .6103 Mtetra
.782 .818 .881 r
.937 .6103 .9377 .6112 .93952 .61017 .9388 .60907 Mtetra
.903 .797 .733 r
.9388 .60907 .93952 .61017 .94135 .6092 .9404 .60618 Mtetra
.871 .659 .613 r
.9404 .60618 .94135 .6092 .94311 .60767 .94161 .60019 Mtetra
.974 .667 .35 r
.94161 .60019 .94311 .60767 .94472 .60488 .91962 .40446 Mtetra
.576 .366 .559 r
.91962 .40446 .94472 .60488 .92371 .41836 .9208 .39918 Mtetra
.607 .406 .583 r
.9208 .39918 .92371 .41836 .92322 .39944 .92232 .39659 Mtetra
.712 .578 .702 r
.92232 .39659 .92322 .39944 .92462 .39598 .92395 .39497 Mtetra
.704 .757 .893 r
.92395 .39497 .92462 .39598 .92634 .39502 .92569 .39422 Mtetra
.635 .781 .951 r
.92569 .39422 .92634 .39502 .92812 .39459 .92747 .39376 Mtetra
.605 .761 .954 r
.92747 .39376 .92812 .39459 .92993 .39438 .92927 .39341 Mtetra
.758 .785 .875 r
.92927 .39341 .92993 .39438 .93164 .39334 .93097 .39236 Mtetra
.69 .759 .905 r
.93097 .39236 .93164 .39334 .93339 .39268 .93273 .39169 Mtetra
.493 .664 .938 r
.93273 .39169 .93339 .39268 .93525 .39277 .93458 .39177 Mtetra
.749 .331 0 r
.93458 .39177 .93525 .39277 .93771 .39765 .93705 .39667 Mtetra
.97 .655 .291 r
.93705 .39667 .93771 .39765 .96537 .59809 .96468 .59715 Mtetra
.736 .304 0 r
.96468 .59715 .96537 .59809 .96795 .60279 .96725 .60184 Mtetra
.042 .47 .882 r
.35383 .76763 .35478 .7684 .35626 .76901 .35531 .76824 Mtetra
.645 .762 .934 r
.35531 .76824 .35626 .76901 .35779 .76859 .35685 .76783 Mtetra
.81 .779 .824 r
.35685 .76783 .35779 .76859 .35937 .76716 .35843 .76639 Mtetra
.908 .738 .659 r
.35843 .76639 .35937 .76716 .36112 .7619 .36018 .76114 Mtetra
.937 .686 .534 r
.36018 .76114 .36112 .7619 .37128 .57098 .37039 .57016 Mtetra
.909 .727 .645 r
.37039 .57016 .37128 .57098 .37297 .56528 .37208 .56446 Mtetra
.778 .76 .837 r
.37208 .56446 .37297 .56528 .37445 .56417 .37357 .56335 Mtetra
.641 .736 .918 r
.37357 .56335 .37445 .56417 .3759 .5638 .37502 .56298 Mtetra
.51 .692 .95 r
.37502 .56298 .3759 .5638 .37734 .5638 .37645 .56297 Mtetra
.746 .758 .862 r
.37645 .56297 .37734 .5638 .37881 .56292 .37792 .5621 Mtetra
.696 .75 .893 r
.37792 .5621 .37881 .56292 .38027 .56233 .37939 .56151 Mtetra
.48 .681 .954 r
.37939 .56151 .38027 .56233 .3817 .56238 .38082 .56156 Mtetra
.926 .546 .251 r
.38082 .56156 .3817 .56238 .38298 .56631 .38209 .56552 Mtetra
.939 .683 .522 r
.38209 .56552 .38298 .56631 .37653 .75654 .3756 .75582 Mtetra
.933 .579 .33 r
.3756 .75582 .37653 .75654 .37784 .76177 .3769 .76102 Mtetra
0 .328 .774 r
.3769 .76102 .37784 .76177 .37934 .76261 .3784 .76185 Mtetra
.62 .759 .945 r
.3784 .76185 .37934 .76261 .38088 .76227 .37994 .76152 Mtetra
.804 .784 .834 r
.37994 .76152 .38088 .76227 .38246 .76088 .38152 .76016 Mtetra
.91 .746 .665 r
.38152 .76016 .38246 .76088 .3842 .75559 .38325 .75523 Mtetra
.94 .688 .528 r
.38325 .75523 .3842 .75559 .39319 .56376 .39227 .56385 Mtetra
.954 .781 .63 r
.39227 .56385 .39319 .56376 .39485 .55821 .39396 .55778 Mtetra
.82 .851 .871 r
.39396 .55778 .39485 .55821 .39634 .55709 .39545 .55655 Mtetra
.581 .8 .983 r
.39545 .55655 .39634 .55709 .3978 .5569 .39691 .55627 Mtetra
.356 .681 .979 r
.39691 .55627 .3978 .5569 .39924 .55715 .39836 .55642 Mtetra
.586 .747 .954 r
.39836 .55642 .39924 .55715 .40069 .55696 .39981 .5562 Mtetra
.621 .749 .938 r
.39981 .5562 .40069 .55696 .40216 .55664 .40128 .55588 Mtetra
.629 .753 .936 r
.40128 .55588 .40216 .55664 .40362 .55628 .40274 .55554 Mtetra
.646 .763 .934 r
.40274 .55554 .40362 .55628 .40509 .55587 .40421 .55514 Mtetra
.658 .768 .931 r
.40421 .55514 .40509 .55587 .40656 .55542 .40568 .5547 Mtetra
.667 .772 .928 r
.40568 .5547 .40656 .55542 .40803 .55494 .40715 .55423 Mtetra
.675 .775 .926 r
.40715 .55423 .40803 .55494 .4095 .55444 .40863 .55372 Mtetra
.682 .775 .922 r
.40863 .55372 .4095 .55444 .41098 .55391 .4101 .55319 Mtetra
.688 .777 .919 r
.4101 .55319 .41098 .55391 .41246 .55334 .41158 .55264 Mtetra
.708 .784 .911 r
.41158 .55264 .41246 .55334 .41394 .55248 .41306 .552 Mtetra
.702 .843 .95 r
.41306 .552 .41394 .55248 .41543 .55171 .41454 .55137 Mtetra
.659 .879 .98 r
.41454 .55137 .41543 .55171 .41691 .55124 .41602 .55083 Mtetra
.543 .826 .998 r
.41602 .55083 .41691 .55124 .41834 .55194 .41749 .55055 Mtetra
.593 .614 .842 r
.41749 .55055 .41834 .55194 .41975 .55378 .41896 .55041 Mtetra
.589 .477 .693 r
.41896 .55041 .41975 .55378 .4211 .55757 .42043 .55029 Mtetra
.607 .435 .623 r
.42043 .55029 .4211 .55757 .42254 .55857 .42192 .54951 Mtetra
.598 .419 .611 r
.42192 .54951 .42254 .55857 .42405 .55724 .42341 .54879 Mtetra
.578 .407 .614 r
.42341 .54879 .42405 .55724 .42552 .55708 .42488 .54868 Mtetra
.393 .269 .591 r
.42488 .54868 .42552 .55708 .42167 .74077 .42625 .55208 Mtetra
0 0 .343 r
.42625 .55208 .42167 .74077 .42305 .74706 .42224 .74235 Mtetra
0 0 .41 r
.42224 .74235 .42305 .74706 .42454 .74943 .42364 .74788 Mtetra
.268 .431 .839 r
.42364 .74788 .42454 .74943 .42608 .74994 .42517 .74876 Mtetra
.629 .675 .875 r
.42517 .74876 .42608 .74994 .42765 .74963 .42674 .74843 Mtetra
.712 .699 .837 r
.42674 .74843 .42765 .74963 .42924 .74879 .42833 .74763 Mtetra
.717 .706 .839 r
.42833 .74763 .42924 .74879 .43084 .74704 .42991 .7468 Mtetra
.73 .921 .957 r
.42991 .7468 .43084 .74704 .43248 .74424 .4315 .74596 Mtetra
.279 0 .137 r
.4315 .74596 .43248 .74424 .43416 .73981 .43308 .74509 Mtetra
.538 .268 .454 r
.43308 .74509 .43416 .73981 .43578 .73753 .43466 .74488 Mtetra
.549 .295 .484 r
.43466 .74488 .43578 .73753 .43733 .73776 .43623 .74471 Mtetra
.517 .264 .471 r
.43623 .74471 .43733 .73776 .43891 .73713 .43781 .74394 Mtetra
.259 .044 .385 r
.43781 .74394 .43891 .73713 .44484 .55334 .43948 .73987 Mtetra
0 0 .336 r
.43948 .73987 .44484 .55334 .44651 .54514 .44555 .54872 Mtetra
.801 .774 .266 r
.44555 .54872 .44651 .54514 .44807 .54197 .44719 .54187 Mtetra
.895 .911 .828 r
.44719 .54187 .44807 .54197 .44958 .54078 .44872 .54008 Mtetra
.676 .782 .93 r
.44872 .54008 .44958 .54078 .45107 .54042 .45021 .53956 Mtetra
.56 .706 .938 r
.45021 .53956 .45107 .54042 .45256 .54032 .4517 .53944 Mtetra
.624 .724 .919 r
.4517 .53944 .45256 .54032 .45405 .53992 .45319 .53913 Mtetra
.667 .756 .917 r
.45319 .53913 .45405 .53992 .45555 .53931 .45469 .53865 Mtetra
.664 .789 .941 r
.45469 .53865 .45555 .53931 .45705 .5387 .45619 .53817 Mtetra
.664 .828 .962 r
.45619 .53817 .45705 .5387 .45855 .53803 .45769 .53766 Mtetra
.638 .87 .985 r
.45769 .53766 .45855 .53803 .46006 .53744 .45919 .53716 Mtetra
.586 .879 .993 r
.45919 .53716 .46006 .53744 .46155 .53712 .46069 .53673 Mtetra
.509 .821 1 r
.46069 .53673 .46155 .53712 .46304 .53768 .46219 .53649 Mtetra
.572 .64 .879 r
.46219 .53649 .46304 .53768 .4645 .53936 .46368 .53641 Mtetra
.584 .489 .712 r
.46368 .53641 .4645 .53936 .46594 .54268 .46518 .53634 Mtetra
.589 .429 .632 r
.46518 .53634 .46594 .54268 .46737 .54642 .46668 .53606 Mtetra
.587 .406 .604 r
.46668 .53606 .46737 .54642 .46887 .54656 .46819 .53558 Mtetra
.588 .405 .602 r
.46819 .53558 .46887 .54656 .4704 .54453 .46969 .53503 Mtetra
.59 .412 .608 r
.46969 .53503 .4704 .54453 .47193 .54326 .4712 .5345 Mtetra
.591 .416 .613 r
.4712 .5345 .47193 .54326 .47344 .5426 .47271 .53399 Mtetra
.47271 .53399 .47344 .5426 .47496 .54196 .47422 .53349 Mtetra
.602 .425 .615 r
.47422 .53349 .47496 .54196 .47648 .54044 .47573 .53271 Mtetra
.604 .43 .62 r
.47573 .53271 .47648 .54044 .47801 .53913 .47725 .53195 Mtetra
.583 .418 .624 r
.47725 .53195 .47801 .53913 .47951 .53931 .47875 .53175 Mtetra
.456 .323 .611 r
.47875 .53175 .47951 .53931 .47866 .7204 .48023 .53398 Mtetra
0 0 .367 r
.48023 .53398 .47866 .7204 .48012 .73048 .4793 .72336 Mtetra
0 0 .407 r
.4793 .72336 .48012 .73048 .48168 .73335 .48079 .73154 Mtetra
.097 .286 .766 r
.48079 .73154 .48168 .73335 .48327 .73409 .48238 .73303 Mtetra
.61 .693 .902 r
.48238 .73303 .48327 .73409 .48488 .73376 .48398 .73276 Mtetra
.712 .738 .872 r
.48398 .73276 .48488 .73376 .48649 .7331 .48559 .73201 Mtetra
.697 .718 .865 r
.48559 .73201 .48649 .7331 .48809 .73249 .4872 .73133 Mtetra
.656 .692 .871 r
.4872 .73133 .48809 .73249 .4897 .73202 .48881 .73086 Mtetra
.657 .692 .871 r
.48881 .73086 .4897 .73202 .49131 .73155 .49042 .73039 Mtetra
.655 .69 .871 r
.49042 .73039 .49131 .73155 .49292 .73109 .49203 .72992 Mtetra
.653 .689 .871 r
.49203 .72992 .49292 .73109 .49453 .73064 .49364 .72947 Mtetra
.652 .688 .871 r
.49364 .72947 .49453 .73064 .49615 .73019 .49526 .72901 Mtetra
.49526 .72901 .49615 .73019 .49776 .72974 .49687 .72857 Mtetra
.651 .688 .871 r
.49687 .72857 .49776 .72974 .49937 .7293 .49848 .72812 Mtetra
.49848 .72812 .49937 .7293 .50099 .72885 .5001 .72767 Mtetra
.651 .687 .871 r
.5001 .72767 .50099 .72885 .50261 .72841 .50172 .72723 Mtetra
.50172 .72723 .50261 .72841 .50422 .72796 .50333 .72678 Mtetra
.65 .687 .871 r
.50333 .72678 .50422 .72796 .50584 .72752 .50495 .72634 Mtetra
.50495 .72634 .50584 .72752 .50746 .72708 .50657 .7259 Mtetra
.50657 .7259 .50746 .72708 .50908 .72664 .50819 .72546 Mtetra
.50819 .72546 .50908 .72664 .5107 .7262 .50981 .72501 Mtetra
.50981 .72501 .5107 .7262 .51232 .72576 .51143 .72457 Mtetra
.65 .687 .872 r
.51143 .72457 .51232 .72576 .51394 .72531 .51306 .72413 Mtetra
.51306 .72413 .51394 .72531 .51557 .72487 .51468 .72369 Mtetra
.649 .687 .872 r
.51468 .72369 .51557 .72487 .51719 .72443 .51631 .72325 Mtetra
.51631 .72325 .51719 .72443 .51882 .72399 .51793 .72281 Mtetra
.51793 .72281 .51882 .72399 .52044 .72355 .51956 .72237 Mtetra
.51956 .72237 .52044 .72355 .52207 .72311 .52119 .72193 Mtetra
.649 .687 .873 r
.52119 .72193 .52207 .72311 .5237 .72268 .52282 .7215 Mtetra
.649 .688 .873 r
.52282 .7215 .5237 .72268 .52533 .72224 .52445 .72106 Mtetra
.648 .688 .873 r
.52445 .72106 .52533 .72224 .52696 .7218 .52608 .72062 Mtetra
.648 .688 .874 r
.52608 .72062 .52696 .7218 .52859 .72136 .52771 .72019 Mtetra
.52771 .72019 .52859 .72136 .53022 .72093 .52934 .71975 Mtetra
.52934 .71975 .53022 .72093 .53186 .7205 .53097 .71932 Mtetra
.647 .688 .874 r
.53097 .71932 .53186 .7205 .53349 .72006 .53261 .71889 Mtetra
.53261 .71889 .53349 .72006 .53512 .71964 .53424 .71846 Mtetra
.53424 .71846 .53512 .71964 .53676 .7192 .53588 .71803 Mtetra
.647 .688 .875 r
.53588 .71803 .53676 .7192 .5384 .71877 .53752 .7176 Mtetra
.646 .689 .876 r
.53752 .7176 .5384 .71877 .54004 .71836 .53916 .71717 Mtetra
.642 .685 .875 r
.53916 .71717 .54004 .71836 .54168 .71801 .5408 .71676 Mtetra
.637 .674 .868 r
.5408 .71676 .54168 .71801 .54332 .71774 .54244 .71638 Mtetra
.637 .656 .852 r
.54244 .71638 .54332 .71774 .54496 .71746 .54408 .71599 Mtetra
.64 .641 .835 r
.54408 .71599 .54496 .71746 .5466 .71713 .54572 .71558 Mtetra
.645 .633 .824 r
.54572 .71558 .5466 .71713 .54825 .71671 .54737 .71514 Mtetra
.647 .632 .82 r
.54737 .71514 .54825 .71671 .54989 .71625 .54901 .71467 Mtetra
.649 .632 .819 r
.54901 .71467 .54989 .71625 .55153 .71579 .55066 .71419 Mtetra
.65 .63 .817 r
.55066 .71419 .55153 .71579 .55318 .71534 .5523 .7137 Mtetra
.652 .626 .811 r
.5523 .7137 .55318 .71534 .55483 .71485 .55395 .7132 Mtetra
.653 .625 .81 r
.55395 .7132 .55483 .71485 .55647 .7143 .5556 .71269 Mtetra
.655 .631 .814 r
.5556 .71269 .55647 .7143 .55812 .71365 .55725 .71216 Mtetra
.665 .65 .825 r
.55725 .71216 .55812 .71365 .55977 .71279 .55889 .7116 Mtetra
.691 .702 .855 r
.55889 .7116 .55977 .71279 .56141 .7114 .56054 .71091 Mtetra
.74 .872 .941 r
.56054 .71091 .56141 .7114 .56304 .70878 .56219 .71005 Mtetra
.176 0 0 r
.56219 .71005 .56304 .70878 .56465 .70477 .56384 .70917 Mtetra
.486 .209 .418 r
.56384 .70917 .56465 .70477 .56622 .69786 .56549 .7084 Mtetra
.544 .305 .503 r
.56549 .7084 .56622 .69786 .56777 .68908 .56714 .70789 Mtetra
.558 .331 .528 r
.56714 .70789 .56777 .68908 .56949 .69471 .5688 .70756 Mtetra
.558 .323 .515 r
.5688 .70756 .56949 .69471 .57124 .70158 .57046 .70744 Mtetra
.558 .291 .467 r
.57046 .70744 .57124 .70158 .57296 .70603 .57213 .70754 Mtetra
.503 .108 .223 r
.57213 .70754 .57296 .70603 .57465 .70825 .57379 .70761 Mtetra
.483 .753 .989 r
.57379 .70761 .57465 .70825 .57633 .70921 .57546 .70753 Mtetra
.629 .611 .814 r
.57546 .70753 .57633 .70921 .578 .709 .57712 .70716 Mtetra
.639 .601 .795 r
.57712 .70716 .578 .709 .57966 .70848 .57878 .70672 Mtetra
.645 .611 .801 r
.57878 .70672 .57966 .70848 .58132 .70786 .58045 .70624 Mtetra
.642 .624 .817 r
.58045 .70624 .58132 .70786 .58298 .70742 .58211 .7058 Mtetra
.643 .625 .817 r
.58211 .7058 .58298 .70742 .58465 .70696 .58378 .70535 Mtetra
.646 .628 .818 r
.58378 .70535 .58465 .70696 .58631 .70644 .58544 .70488 Mtetra
.65 .636 .823 r
.58544 .70488 .58631 .70644 .58798 .70584 .58711 .70439 Mtetra
.654 .653 .836 r
.58711 .70439 .58798 .70584 .58964 .70522 .58878 .7039 Mtetra
.64 .665 .858 r
.58878 .7039 .58964 .70522 .59131 .70468 .59045 .70349 Mtetra
.564 .654 .896 r
.59045 .70349 .59131 .70468 .59298 .70445 .59212 .7034 Mtetra
.653 .718 .897 r
.59212 .7034 .59298 .70445 .59466 .70399 .5938 .70294 Mtetra
.796 .754 .815 r
.5938 .70294 .59466 .70399 .59631 .7029 .59545 .70148 Mtetra
.907 .719 .636 r
.59545 .70148 .59631 .7029 .59793 .69976 .59701 .69574 Mtetra
.958 .686 .478 r
.59701 .69574 .59793 .69976 .59947 .69323 .59461 .50109 Mtetra
.576 .367 .56 r
.59461 .50109 .59947 .69323 .59706 .50452 .59609 .49587 Mtetra
.606 .427 .614 r
.59609 .49587 .59706 .50452 .59863 .50348 .59766 .49493 Mtetra
.584 .412 .615 r
.59766 .49493 .59863 .50348 .60023 .5038 .59924 .49465 Mtetra
.577 .404 .611 r
.59924 .49465 .60023 .5038 .60179 .50248 .60083 .49454 Mtetra
.605 .43 .619 r
.60083 .49454 .60179 .50248 .60327 .4974 .6024 .49369 Mtetra
.64 .503 .68 r
.6024 .49369 .60327 .4974 .60479 .49446 .60397 .49285 Mtetra
.686 .636 .794 r
.60397 .49285 .60479 .49446 .60634 .49263 .60555 .49211 Mtetra
.634 .835 .978 r
.60555 .49211 .60634 .49263 .60792 .49209 .60713 .49165 Mtetra
.591 .846 .993 r
.60713 .49165 .60792 .49209 .60951 .49185 .60872 .49125 Mtetra
.619 .808 .973 r
.60872 .49125 .60951 .49185 .6111 .49171 .6103 .49085 Mtetra
.67 .754 .913 r
.6103 .49085 .6111 .49171 .61269 .49126 .61189 .49033 Mtetra
.675 .74 .899 r
.61189 .49033 .61269 .49126 .61427 .49075 .61347 .48979 Mtetra
.685 .736 .89 r
.61347 .48979 .61427 .49075 .61586 .49014 .61506 .4892 Mtetra
.748 .757 .86 r
.61506 .4892 .61586 .49014 .61743 .48917 .61663 .48825 Mtetra
.687 .745 .896 r
.61663 .48825 .61743 .48917 .61901 .48844 .61822 .48765 Mtetra
.424 .672 .965 r
.61822 .48765 .61901 .48844 .62061 .48821 .61982 .4878 Mtetra
.896 .477 .16 r
.61982 .4878 .62061 .48821 .62226 .48969 .62154 .49168 Mtetra
.961 .68 .457 r
.62154 .49168 .62226 .48969 .62398 .49379 .6289 .68554 Mtetra
.575 .362 .555 r
.6289 .68554 .62398 .49379 .63138 .68429 .63077 .69114 Mtetra
.579 .316 .482 r
.63077 .69114 .63138 .68429 .63323 .6891 .6325 .69169 Mtetra
.503 .173 .341 r
.6325 .69169 .63323 .6891 .635 .69093 .6342 .69149 Mtetra
.026 0 0 r
.6342 .69149 .635 .69093 .63673 .69176 .63589 .69095 Mtetra
.434 .685 .97 r
.63589 .69095 .63673 .69176 .63846 .69221 .63761 .69106 Mtetra
.624 .691 .891 r
.63761 .69106 .63846 .69221 .64016 .69197 .63931 .69072 Mtetra
.747 .716 .823 r
.63931 .69072 .64016 .69197 .64184 .69087 .64099 .6896 Mtetra
.917 .734 .64 r
.64099 .6896 .64184 .69087 .64339 .68576 .64253 .68419 Mtetra
.965 .689 .459 r
.64253 .68419 .64339 .68576 .63837 .48933 .63756 .48794 Mtetra
.916 .719 .622 r
.63756 .48794 .63837 .48933 .63977 .48287 .63898 .48197 Mtetra
.779 .773 .848 r
.63898 .48197 .63977 .48287 .64134 .4817 .64056 .48081 Mtetra
.648 .742 .918 r
.64056 .48081 .64134 .4817 .64295 .48128 .64216 .48038 Mtetra
.538 .696 .941 r
.64216 .48038 .64295 .48128 .64457 .48124 .64378 .48031 Mtetra
.752 .763 .862 r
.64378 .48031 .64457 .48124 .64615 .48028 .64537 .47934 Mtetra
.694 .747 .892 r
.64537 .47934 .64615 .48028 .64775 .47964 .64697 .4787 Mtetra
.503 .672 .939 r
.64697 .4787 .64775 .47964 .64938 .47968 .64859 .47874 Mtetra
.877 .458 .035 r
.64859 .47874 .64938 .47968 .65116 .4839 .65038 .48293 Mtetra
.968 .684 .439 r
.65038 .48293 .65116 .4839 .66036 .67945 .65953 .67854 Mtetra
.907 .504 .117 r
.65953 .67854 .66036 .67945 .66229 .68457 .66146 .6837 Mtetra
.098 .471 .892 r
.66146 .6837 .66229 .68457 .66405 .68534 .66322 .68447 Mtetra
.622 .752 .939 r
.66322 .68447 .66405 .68534 .66576 .68496 .66494 .68409 Mtetra
.806 .798 .844 r
.66494 .68409 .66576 .68496 .66744 .68355 .66661 .68269 Mtetra
.936 .769 .65 r
.66661 .68269 .66744 .68355 .66897 .67866 .66815 .67781 Mtetra
.968 .69 .449 r
.66815 .67781 .66897 .67866 .66254 .48257 .66176 .48167 Mtetra
.948 .747 .598 r
.66176 .48167 .66254 .48257 .6639 .47582 .66312 .47491 Mtetra
.794 .776 .837 r
.66312 .47491 .6639 .47582 .66548 .47454 .6647 .47362 Mtetra
.622 .729 .923 r
.6647 .47362 .66548 .47454 .6671 .4742 .66632 .47329 Mtetra
.476 .666 .946 r
.66632 .47329 .6671 .4742 .66874 .47429 .66796 .47338 Mtetra
.619 .73 .925 r
.66796 .47338 .66874 .47429 .67037 .47394 .66959 .47305 Mtetra
.644 .742 .92 r
.66959 .47305 .67037 .47394 .67199 .4735 .67121 .47263 Mtetra
.656 .75 .919 r
.67121 .47263 .67199 .4735 .67361 .47302 .67283 .47215 Mtetra
.695 .764 .905 r
.67283 .47215 .67361 .47302 .67522 .47225 .67445 .47151 Mtetra
.7 .799 .926 r
.67445 .47151 .67522 .47225 .67683 .47155 .67606 .47085 Mtetra
.685 .804 .939 r
.67606 .47085 .67683 .47155 .67846 .47115 .67768 .47025 Mtetra
.714 .763 .891 r
.67768 .47025 .67846 .47115 .68013 .47164 .6793 .46951 Mtetra
.631 .565 .763 r
.6793 .46951 .68013 .47164 .68185 .4732 .68092 .46908 Mtetra
.556 .44 .677 r
.68092 .46908 .68185 .4732 .68372 .47776 .68259 .46934 Mtetra
.356 .252 .597 r
.68259 .46934 .68372 .47776 .69463 .66817 .68446 .47383 Mtetra
.064 0 .45 r
.68446 .47383 .69463 .66817 .69661 .67283 .69565 .66888 Mtetra
0 .031 .564 r
.69565 .66888 .69661 .67283 .69846 .6747 .69764 .67356 Mtetra
.145 .435 .872 r
.69764 .67356 .69846 .6747 .70025 .67538 .69944 .67452 Mtetra
.585 .743 .952 r
.69944 .67452 .70025 .67538 .70201 .67524 .70119 .67426 Mtetra
.781 .776 .848 r
.70119 .67426 .70201 .67524 .70372 .67421 .70289 .67301 Mtetra
.913 .748 .663 r
.70289 .67301 .70372 .67421 .70525 .66981 .70442 .66857 Mtetra
.971 .688 .437 r
.70442 .66857 .70525 .66981 .69672 .47242 .69597 .47187 Mtetra
.97 .763 .569 r
.69597 .47187 .69672 .47242 .69798 .46487 .69724 .46429 Mtetra
.862 .856 .835 r
.69724 .46429 .69798 .46487 .69956 .4633 .69881 .46263 Mtetra
.647 .806 .959 r
.69881 .46263 .69956 .4633 .70121 .46294 .70045 .46215 Mtetra
.51 .717 .965 r
.70045 .46215 .70121 .46294 .70287 .46303 .70211 .4621 Mtetra
.624 .727 .921 r
.70211 .4621 .70287 .46303 .70452 .46274 .70376 .46175 Mtetra
.658 .727 .9 r
.70376 .46175 .70452 .46274 .70616 .46225 .7054 .46127 Mtetra
.661 .732 .902 r
.7054 .46127 .70616 .46225 .7078 .46169 .70704 .46077 Mtetra
.745 .77 .873 r
.70704 .46077 .7078 .46169 .70941 .46064 .70865 .45985 Mtetra
.725 .794 .907 r
.70865 .45985 .70941 .46064 .71103 .45973 .71028 .45906 Mtetra
.546 .766 .979 r
.71028 .45906 .71103 .45973 .71268 .45944 .71194 .45886 Mtetra
.784 .299 0 r
.71194 .45886 .71268 .45944 .71451 .46214 .71377 .4616 Mtetra
.972 .681 .414 r
.71377 .4616 .71451 .46214 .72759 .65799 .72677 .65682 Mtetra
.929 .556 .16 r
.72677 .65682 .72759 .65799 .72982 .66579 .729 .66451 Mtetra
.195 .438 .866 r
.729 .66451 .72982 .66579 .73166 .66671 .73084 .66551 Mtetra
.649 .697 .881 r
.73084 .66551 .73166 .66671 .73341 .66612 .7326 .66504 Mtetra
.735 .749 .864 r
.7326 .66504 .73341 .66612 .73513 .66504 .73432 .66409 Mtetra
.677 .757 .912 r
.73432 .66409 .73513 .66504 .73688 .66459 .73607 .66348 Mtetra
.637 .709 .899 r
.73607 .66348 .73688 .66459 .73866 .66438 .73784 .66307 Mtetra
.65 .678 .863 r
.73784 .66307 .73866 .66438 .74042 .6639 .7396 .66258 Mtetra
.633 .671 .868 r
.7396 .66258 .74042 .6639 .74212 .66252 .74136 .66219 Mtetra
.616 .901 .986 r
.74136 .66219 .74212 .66252 .74376 .66003 .74312 .66157 Mtetra
.172 0 .081 r
.74312 .66157 .74376 .66003 .74525 .65531 .74483 .66032 Mtetra
.155 0 .345 r
.74483 .66032 .74525 .65531 .73472 .46239 .74634 .65584 Mtetra
.081 0 .455 r
.74634 .65584 .73472 .46239 .73596 .45538 .73551 .45914 Mtetra
0 0 .075 r
.73551 .45914 .73596 .45538 .73746 .45248 .73677 .45238 Mtetra
.901 .965 .819 r
.73677 .45238 .73746 .45248 .73907 .4513 .73833 .45051 Mtetra
.668 .783 .935 r
.73833 .45051 .73907 .4513 .74074 .45093 .73999 .44997 Mtetra
.556 .695 .933 r
.73999 .44997 .74074 .45093 .74243 .45085 .74168 .44986 Mtetra
.604 .706 .916 r
.74168 .44986 .74243 .45085 .74411 .4506 .74335 .44959 Mtetra
.649 .722 .902 r
.74335 .44959 .74411 .4506 .74577 .45013 .74502 .44914 Mtetra
.654 .728 .903 r
.74502 .44914 .74577 .45013 .74743 .4496 .74669 .44867 Mtetra
.678 .75 .905 r
.74669 .44867 .74743 .4496 .74908 .44881 .74835 .44808 Mtetra
.688 .806 .938 r
.74835 .44808 .74908 .44881 .75072 .44798 .75 .44746 Mtetra
.655 .855 .976 r
.75 .44746 .75072 .44798 .75238 .44741 .75166 .44689 Mtetra
.669 .858 .972 r
.75166 .44689 .75238 .44741 .7541 .44762 .75332 .44628 Mtetra
.643 .66 .851 r
.75332 .44628 .7541 .44762 .75589 .44888 .755 .44585 Mtetra
.561 .478 .718 r
.755 .44585 .75589 .44888 .75783 .45222 .75671 .446 Mtetra
.405 .307 .631 r
.75671 .446 .75783 .45222 .7733 .64427 .75862 .44882 Mtetra
.104 .024 .472 r
.75862 .44882 .7733 .64427 .7756 .65101 .77442 .64456 Mtetra
.077 .083 .561 r
.77442 .64456 .7756 .65101 .77758 .65329 .77672 .6513 Mtetra
.286 .39 .794 r
.77672 .6513 .77758 .65329 .77945 .65394 .77864 .65264 Mtetra
.608 .665 .88 r
.77864 .65264 .77945 .65394 .78125 .65367 .78044 .65237 Mtetra
.701 .703 .849 r
.78044 .65237 .78125 .65367 .78301 .65286 .7822 .65157 Mtetra
.679 .696 .859 r
.7822 .65157 .78301 .65286 .78472 .65143 .78398 .65091 Mtetra
.643 .864 .983 r
.78398 .65091 .78472 .65143 .78638 .64913 .78576 .65032 Mtetra
.094 0 0 r
.78576 .65032 .78638 .64913 .7879 .64511 .7875 .64915 Mtetra
.171 0 .324 r
.7875 .64915 .7879 .64511 .77518 .45472 .78905 .64557 Mtetra
.097 .015 .465 r
.78905 .64557 .77518 .45472 .77606 .44375 .7759 .45034 Mtetra
0 0 .266 r
.7759 .45034 .77606 .44375 .77753 .44044 .77688 .44063 Mtetra
.919 .977 .716 r
.77688 .44063 .77753 .44044 .77913 .43898 .77842 .43825 Mtetra
.694 .809 .936 r
.77842 .43825 .77913 .43898 .78082 .43852 .78009 .43759 Mtetra
.576 .712 .935 r
.78009 .43759 .78082 .43852 .78253 .43839 .7818 .4374 Mtetra
.595 .706 .921 r
.7818 .4374 .78253 .43839 .78424 .43816 .7835 .43715 Mtetra
.655 .728 .903 r
.7835 .43715 .78424 .43816 .78593 .43767 .78519 .43667 Mtetra
.659 .732 .903 r
.78519 .43667 .78593 .43767 .78761 .43712 .78688 .43617 Mtetra
.679 .751 .905 r
.78688 .43617 .78761 .43712 .78927 .43634 .78856 .43558 Mtetra
.694 .801 .931 r
.78856 .43558 .78927 .43634 .79093 .43547 .79024 .43492 Mtetra
.668 .855 .971 r
.79024 .43492 .79093 .43547 .79261 .43483 .79192 .43431 Mtetra
.672 .864 .972 r
.79192 .43431 .79261 .43483 .79435 .43484 .7936 .43367 Mtetra
.663 .7 .874 r
.7936 .43367 .79435 .43484 .79616 .43587 .79529 .43315 Mtetra
.578 .503 .734 r
.79529 .43315 .79616 .43587 .79811 .43842 .79703 .43313 Mtetra
.449 .35 .651 r
.79703 .43313 .79811 .43842 .81547 .62362 .79892 .43504 Mtetra
.114 .035 .48 r
.79892 .43504 .81547 .62362 .8185 .63763 .81691 .62693 Mtetra
.073 .051 .525 r
.81691 .62693 .8185 .63763 .82059 .64049 .81974 .63856 Mtetra
.107 .28 .758 r
.81974 .63856 .82059 .64049 .82253 .6415 .82176 .64053 Mtetra
.553 .706 .942 r
.82176 .64053 .82253 .6415 .82438 .6415 .82361 .64039 Mtetra
.691 .736 .885 r
.82361 .64039 .82438 .6415 .82619 .64094 .8254 .63969 Mtetra
.684 .707 .865 r
.8254 .63969 .82619 .64094 .82794 .63972 .8272 .639 Mtetra
.632 .805 .966 r
.8272 .639 .82794 .63972 .82961 .63759 .82901 .63851 Mtetra
.049 0 0 r
.82901 .63851 .82961 .63759 .83115 .634 .83079 .6375 Mtetra
.217 0 .318 r
.83079 .6375 .83115 .634 .83194 .62199 .83239 .63463 Mtetra
0 0 .345 r
.83239 .63463 .83194 .62199 .81682 .43273 .83265 .61675 Mtetra
.119 .034 .476 r
.83265 .61675 .81682 .43273 .81823 .42891 .8176 .42898 Mtetra
.964 .94 .681 r
.8176 .42898 .81823 .42891 .81982 .42713 .81909 .42603 Mtetra
.704 .73 .871 r
.81909 .42603 .81982 .42713 .82151 .4265 .82078 .42529 Mtetra
.593 .662 .886 r
.82078 .42529 .82151 .4265 .82324 .42624 .82251 .42509 Mtetra
.622 .688 .89 r
.82251 .42509 .82324 .42624 .82496 .42579 .82424 .42475 Mtetra
.718 .748 .876 r
.82424 .42475 .82496 .42579 .82664 .42495 .82592 .42394 Mtetra
.609 .712 .918 r
.82592 .42394 .82664 .42495 .82837 .42465 .82765 .42364 Mtetra
0 .242 .754 r
.82765 .42364 .82837 .42465 .8303 .4264 .82956 .42519 Mtetra
.976 .672 .355 r
.82956 .42519 .8303 .4264 .85067 .62328 .84959 .61877 Mtetra
0 0 .232 r
.84959 .61877 .85067 .62328 .85338 .63207 .85255 .63029 Mtetra
0 .208 .726 r
.85255 .63029 .85338 .63207 .85545 .63413 .85465 .63257 Mtetra
.54 .593 .856 r
.85465 .63257 .85545 .63413 .85733 .6341 .85654 .63266 Mtetra
.699 .687 .836 r
.85654 .63266 .85733 .6341 .85912 .63317 .85834 .63183 Mtetra
.844 .749 .758 r
.85834 .63183 .85912 .63317 .86078 .63085 .86 .62955 Mtetra
.954 .748 .586 r
.86 .62955 .86078 .63085 .86204 .62441 .86123 .6228 Mtetra
.977 .679 .37 r
.86123 .6228 .86204 .62441 .84424 .42433 .8435 .42308 Mtetra
.929 .755 .646 r
.8435 .42308 .84424 .42433 .84555 .41967 .84484 .41865 Mtetra
.744 .761 .866 r
.84484 .41865 .84555 .41967 .84723 .41869 .84652 .41767 Mtetra
.616 .715 .916 r
.84652 .41767 .84723 .41869 .84897 .41837 .84826 .41734 Mtetra
.588 .699 .919 r
.84826 .41734 .84897 .41837 .85073 .41818 .85002 .41712 Mtetra
.684 .734 .888 r
.85002 .41712 .85073 .41818 .85244 .41758 .85173 .41649 Mtetra
.684 .727 .883 r
.85173 .41649 .85244 .41758 .85416 .41694 .85345 .41585 Mtetra
.71 .737 .872 r
.85345 .41585 .85416 .41694 .85586 .41613 .85515 .41506 Mtetra
.75 .757 .858 r
.85515 .41506 .85586 .41613 .85753 .41504 .85682 .41404 Mtetra
.677 .743 .9 r
.85682 .41404 .85753 .41504 .85923 .41426 .85855 .41344 Mtetra
.245 .561 .935 r
.85855 .41344 .85923 .41426 .86101 .41422 .86039 .414 Mtetra
.887 .459 .094 r
.86039 .414 .86101 .41422 .86297 .41593 .8627 .41908 Mtetra
.973 .665 .354 r
.8627 .41908 .86297 .41593 .86529 .421 .88526 .61725 Mtetra
.572 .36 .554 r
.88526 .61725 .86529 .421 .88758 .61528 .88759 .62133 Mtetra
.567 .296 .465 r
.88759 .62133 .88758 .61528 .88992 .61938 .88953 .62166 Mtetra
.473 .129 .302 r
.88953 .62166 .88992 .61938 .892 .62101 .8914 .6213 Mtetra
0 0 0 r
.8914 .6213 .892 .62101 .89398 .62172 .89326 .62081 Mtetra
.508 .705 .959 r
.89326 .62081 .89398 .62172 .89591 .62188 .89516 .62078 Mtetra
.652 .728 .905 r
.89516 .62078 .89591 .62188 .89778 .62147 .89702 .62026 Mtetra
.81 .763 .809 r
.89702 .62026 .89778 .62147 .89956 .62027 .89875 .61859 Mtetra
.935 .731 .603 r
.89875 .61859 .89956 .62027 .90115 .61732 .9 .61243 Mtetra
.976 .673 .361 r
.9 .61243 .90115 .61732 .90238 .6111 .88001 .41285 Mtetra
.575 .366 .559 r
.88001 .41285 .90238 .6111 .88267 .41537 .88124 .4077 Mtetra
.62 .443 .621 r
.88124 .4077 .88267 .41537 .88392 .41034 .8829 .4064 Mtetra
.622 .49 .68 r
.8829 .4064 .88392 .41034 .88544 .40785 .88463 .40576 Mtetra
.623 .571 .775 r
.88463 .40576 .88544 .40785 .88708 .40635 .8864 .40538 Mtetra
.666 .749 .912 r
.8864 .40538 .88708 .40635 .88881 .40564 .88814 .40483 Mtetra
.649 .779 .943 r
.88814 .40483 .88881 .40564 .89056 .40521 .88989 .40433 Mtetra
.669 .771 .926 r
.88989 .40433 .89056 .40521 .89233 .4048 .89164 .40376 Mtetra
.744 .761 .867 r
.89164 .40376 .89233 .4048 .89404 .40395 .89333 .40278 Mtetra
.676 .71 .874 r
.89333 .40278 .89404 .40395 .89578 .40334 .89508 .40216 Mtetra
.457 .601 .906 r
.89508 .40216 .89578 .40334 .89759 .40327 .89692 .40245 Mtetra
.78 .343 0 r
.89692 .40245 .89759 .40327 .89959 .40488 .89925 .40686 Mtetra
.973 .661 .328 r
.89925 .40686 .89959 .40488 .90194 .40951 .92422 .60564 Mtetra
.573 .361 .554 r
.92422 .60564 .90194 .40951 .92655 .60385 .92673 .61054 Mtetra
.57 .303 .473 r
.92673 .61054 .92655 .60385 .92901 .60837 .92871 .61093 Mtetra
.485 .153 .329 r
.92871 .61093 .92901 .60837 .93116 .61012 .93061 .61058 Mtetra
0 0 0 r
.93061 .61058 .93116 .61012 .93318 .61083 .93248 .60994 Mtetra
.507 .711 .963 r
.93248 .60994 .93318 .61083 .93512 .61084 .93442 .6099 Mtetra
.643 .761 .935 r
.93442 .6099 .93512 .61084 .937 .6103 .9363 .6094 Mtetra
.808 .825 .864 r
.9363 .6094 .937 .6103 .9388 .60907 .93808 .60798 Mtetra
.966 .776 .596 r
.93808 .60798 .9388 .60907 .9404 .60618 .93932 .6022 Mtetra
.975 .669 .337 r
.93932 .6022 .9404 .60618 .94161 .60019 .91694 .40207 Mtetra
.576 .366 .559 r
.91694 .40207 .94161 .60019 .91962 .40446 .91807 .3963 Mtetra
.619 .439 .617 r
.91807 .3963 .91962 .40446 .9208 .39918 .91973 .39496 Mtetra
.62 .482 .673 r
.91973 .39496 .9208 .39918 .92232 .39659 .92148 .39429 Mtetra
.615 .552 .761 r
.92148 .39429 .92232 .39659 .92395 .39497 .92328 .39396 Mtetra
.662 .741 .909 r
.92328 .39396 .92395 .39497 .92569 .39422 .92505 .39342 Mtetra
.642 .784 .95 r
.92505 .39342 .92569 .39422 .92747 .39376 .92682 .39293 Mtetra
.646 .779 .944 r
.92682 .39293 .92747 .39376 .92927 .39341 .9286 .39244 Mtetra
.759 .785 .874 r
.9286 .39244 .92927 .39341 .93097 .39236 .93031 .39138 Mtetra
.692 .76 .904 r
.93031 .39138 .93097 .39236 .93273 .39169 .93206 .3907 Mtetra
.496 .665 .938 r
.93206 .3907 .93273 .39169 .93458 .39177 .93391 .39077 Mtetra
.749 .332 0 r
.93391 .39077 .93458 .39177 .93705 .39667 .93639 .39568 Mtetra
.97 .655 .291 r
.93639 .39568 .93705 .39667 .96468 .59715 .96399 .59621 Mtetra
.735 .303 0 r
.96399 .59621 .96468 .59715 .96725 .60184 .96656 .60089 Mtetra
.043 .471 .883 r
.35288 .76686 .35383 .76763 .35531 .76824 .35437 .76747 Mtetra
.645 .762 .934 r
.35437 .76747 .35531 .76824 .35685 .76783 .3559 .76706 Mtetra
.81 .779 .824 r
.3559 .76706 .35685 .76783 .35843 .76639 .35748 .76562 Mtetra
.908 .738 .659 r
.35748 .76562 .35843 .76639 .36018 .76114 .35924 .76037 Mtetra
.937 .686 .534 r
.35924 .76037 .36018 .76114 .37039 .57016 .3695 .56934 Mtetra
.909 .727 .645 r
.3695 .56934 .37039 .57016 .37208 .56446 .3712 .56363 Mtetra
.777 .76 .837 r
.3712 .56363 .37208 .56446 .37357 .56335 .37268 .56252 Mtetra
.641 .736 .918 r
.37268 .56252 .37357 .56335 .37502 .56298 .37413 .56215 Mtetra
.509 .692 .95 r
.37413 .56215 .37502 .56298 .37645 .56297 .37557 .56214 Mtetra
.746 .758 .862 r
.37557 .56214 .37645 .56297 .37792 .5621 .37704 .56127 Mtetra
.696 .75 .893 r
.37704 .56127 .37792 .5621 .37939 .56151 .3785 .56068 Mtetra
.479 .68 .954 r
.3785 .56068 .37939 .56151 .38082 .56156 .37994 .56074 Mtetra
.927 .547 .252 r
.37994 .56074 .38082 .56156 .38209 .56552 .38121 .56471 Mtetra
.939 .683 .522 r
.38121 .56471 .38209 .56552 .3756 .75582 .37466 .75509 Mtetra
.933 .579 .327 r
.37466 .75509 .3756 .75582 .3769 .76102 .37596 .76027 Mtetra
0 .333 .779 r
.37596 .76027 .3769 .76102 .3784 .76185 .37746 .76109 Mtetra
.619 .759 .946 r
.37746 .76109 .3784 .76185 .37994 .76152 .379 .76076 Mtetra
.803 .785 .836 r
.379 .76076 .37994 .76152 .38152 .76016 .38059 .75942 Mtetra
.908 .746 .668 r
.38059 .75942 .38152 .76016 .38325 .75523 .38231 .75464 Mtetra
.94 .687 .529 r
.38231 .75464 .38325 .75523 .39227 .56385 .39138 .56347 Mtetra
.933 .75 .631 r
.39138 .56347 .39227 .56385 .39396 .55778 .39307 .55712 Mtetra
.807 .796 .842 r
.39307 .55712 .39396 .55778 .39545 .55655 .39457 .55585 Mtetra
.615 .762 .949 r
.39457 .55585 .39545 .55655 .39691 .55627 .39603 .55554 Mtetra
.42 .68 .97 r
.39603 .55554 .39691 .55627 .39836 .55642 .39748 .55565 Mtetra
.594 .739 .945 r
.39748 .55565 .39836 .55642 .39981 .5562 .39893 .55542 Mtetra
.622 .745 .935 r
.39893 .55542 .39981 .5562 .40128 .55588 .4004 .5551 Mtetra
.629 .747 .932 r
.4004 .5551 .40128 .55588 .40274 .55554 .40186 .55477 Mtetra
.649 .753 .925 r
.40186 .55477 .40274 .55554 .40421 .55514 .40333 .55436 Mtetra
.661 .754 .919 r
.40333 .55436 .40421 .55514 .40568 .5547 .4048 .55391 Mtetra
.67 .755 .914 r
.4048 .55391 .40568 .5547 .40715 .55423 .40628 .55343 Mtetra
.676 .755 .911 r
.40628 .55343 .40715 .55423 .40863 .55372 .40775 .55292 Mtetra
.681 .756 .908 r
.40775 .55292 .40863 .55372 .4101 .55319 .40923 .5524 Mtetra
.684 .758 .907 r
.40923 .5524 .4101 .55319 .41158 .55264 .4107 .55185 Mtetra
.684 .761 .909 r
.4107 .55185 .41158 .55264 .41306 .552 .41218 .55131 Mtetra
.688 .786 .925 r
.41218 .55131 .41306 .552 .41454 .55137 .41366 .55076 Mtetra
.693 .805 .935 r
.41366 .55076 .41454 .55137 .41602 .55083 .41514 .55018 Mtetra
.71 .799 .92 r
.41514 .55018 .41602 .55083 .41749 .55055 .41663 .54953 Mtetra
.702 .714 .858 r
.41663 .54953 .41749 .55055 .41896 .55041 .41811 .54886 Mtetra
.677 .631 .796 r
.41811 .54886 .41896 .55041 .42043 .55029 .4196 .54823 Mtetra
.681 .589 .746 r
.4196 .54823 .42043 .55029 .42192 .54951 .42109 .54739 Mtetra
.661 .575 .748 r
.42109 .54739 .42192 .54951 .42341 .54879 .42257 .54674 Mtetra
.603 .549 .766 r
.42257 .54674 .42341 .54879 .42488 .54868 .42405 .54655 Mtetra
.112 .241 .719 r
.42405 .54655 .42488 .54868 .42625 .55208 .42547 .5482 Mtetra
.716 .47 0 r
.42547 .5482 .42625 .55208 .42224 .74235 .42675 .55475 Mtetra
0 0 .345 r
.42675 .55475 .42224 .74235 .42364 .74788 .42283 .74302 Mtetra
.291 .241 .628 r
.42283 .74302 .42364 .74788 .42517 .74876 .42431 .74576 Mtetra
.464 .418 .722 r
.42431 .74576 .42517 .74876 .42674 .74843 .42585 .74658 Mtetra
.53 .539 .809 r
.42585 .74658 .42674 .74843 .42833 .74763 .42741 .74677 Mtetra
.568 .722 .946 r
.42741 .74677 .42833 .74763 .42991 .7468 .42898 .7466 Mtetra
.51 .874 .982 r
.42898 .7466 .42991 .7468 .4315 .74596 .43055 .74621 Mtetra
.282 .778 .738 r
.43055 .74621 .4315 .74596 .43308 .74509 .43213 .74569 Mtetra
.247 0 0 r
.43213 .74569 .43308 .74509 .43466 .74488 .4337 .7455 Mtetra
.221 0 0 r
.4337 .7455 .43466 .74488 .43623 .74471 .43528 .74525 Mtetra
0 0 0 r
.43528 .74525 .43623 .74471 .43781 .74394 .43686 .74454 Mtetra
.928 .973 .727 r
.43686 .74454 .43781 .74394 .43948 .73987 .43849 .74201 Mtetra
.984 .87 .505 r
.43849 .74201 .43948 .73987 .44555 .54872 .44023 .73519 Mtetra
0 0 .338 r
.44023 .73519 .44555 .54872 .44719 .54187 .44624 .54509 Mtetra
0 0 .036 r
.44624 .54509 .44719 .54187 .44872 .54008 .44781 .54126 Mtetra
0 0 0 r
.44781 .54126 .44872 .54008 .45021 .53956 .44933 .53959 Mtetra
.768 .976 .917 r
.44933 .53959 .45021 .53956 .4517 .53944 .45084 .53853 Mtetra
.712 .743 .875 r
.45084 .53853 .4517 .53944 .45319 .53913 .45234 .53784 Mtetra
.659 .658 .838 r
.45234 .53784 .45319 .53913 .45469 .53865 .45384 .53736 Mtetra
.633 .649 .848 r
.45384 .53736 .45469 .53865 .45619 .53817 .45534 .53703 Mtetra
.631 .673 .872 r
.45534 .53703 .45619 .53817 .45769 .53766 .45683 .53671 Mtetra
.634 .711 .902 r
.45683 .53671 .45769 .53766 .45919 .53716 .45833 .53636 Mtetra
.636 .748 .929 r
.45833 .53636 .45919 .53716 .46069 .53673 .45983 .53599 Mtetra
.67 .774 .928 r
.45983 .53599 .46069 .53673 .46219 .53649 .46133 .5355 Mtetra
.688 .719 .873 r
.46133 .5355 .46219 .53649 .46368 .53641 .46284 .53491 Mtetra
.673 .637 .806 r
.46284 .53491 .46368 .53641 .46518 .53634 .46435 .53431 Mtetra
.65 .577 .76 r
.46435 .53431 .46518 .53634 .46668 .53606 .46585 .53377 Mtetra
.638 .554 .743 r
.46585 .53377 .46668 .53606 .46819 .53558 .46736 .53327 Mtetra
.636 .552 .742 r
.46736 .53327 .46819 .53558 .46969 .53503 .46886 .53279 Mtetra
.639 .557 .746 r
.46886 .53279 .46969 .53503 .4712 .5345 .47037 .5323 Mtetra
.64 .561 .749 r
.47037 .5323 .4712 .5345 .47271 .53399 .47188 .53181 Mtetra
.64 .561 .75 r
.47188 .53181 .47271 .53399 .47422 .53349 .47339 .53132 Mtetra
.661 .574 .746 r
.47339 .53132 .47422 .53349 .47573 .53271 .4749 .53064 Mtetra
.663 .581 .753 r
.4749 .53064 .47573 .53271 .47725 .53195 .47641 .52997 Mtetra
.616 .563 .772 r
.47641 .52997 .47725 .53195 .47875 .53175 .47792 .52969 Mtetra
.274 .356 .766 r
.47792 .52969 .47875 .53175 .48023 .53398 .47941 .53092 Mtetra
0 0 .226 r
.47941 .53092 .48023 .53398 .4793 .72336 .48085 .53604 Mtetra
0 0 .368 r
.48085 .53604 .4793 .72336 .48079 .73154 .47995 .7261 Mtetra
.321 .253 .624 r
.47995 .7261 .48079 .73154 .48238 .73303 .48151 .72902 Mtetra
.591 .468 .681 r
.48151 .72902 .48238 .73303 .48398 .73276 .48312 .72884 Mtetra
.644 .504 .678 r
.48312 .72884 .48398 .73276 .48559 .73201 .48473 .72791 Mtetra
.636 .495 .674 r
.48473 .72791 .48559 .73201 .4872 .73133 .48634 .72707 Mtetra
.612 .476 .672 r
.48634 .72707 .4872 .73133 .48881 .73086 .48795 .72658 Mtetra
.48795 .72658 .48881 .73086 .49042 .73039 .48956 .72608 Mtetra
.611 .475 .671 r
.48956 .72608 .49042 .73039 .49203 .72992 .49117 .72559 Mtetra
.61 .473 .671 r
.49117 .72559 .49203 .72992 .49364 .72947 .49278 .72512 Mtetra
.609 .473 .671 r
.49278 .72512 .49364 .72947 .49526 .72901 .49439 .72466 Mtetra
.609 .472 .67 r
.49439 .72466 .49526 .72901 .49687 .72857 .496 .7242 Mtetra
.608 .472 .67 r
.496 .7242 .49687 .72857 .49848 .72812 .49762 .72375 Mtetra
.49762 .72375 .49848 .72812 .5001 .72767 .49923 .72329 Mtetra
.608 .471 .67 r
.49923 .72329 .5001 .72767 .50172 .72723 .50085 .72285 Mtetra
.50085 .72285 .50172 .72723 .50333 .72678 .50246 .7224 Mtetra
.50246 .7224 .50333 .72678 .50495 .72634 .50408 .72195 Mtetra
.607 .471 .67 r
.50408 .72195 .50495 .72634 .50657 .7259 .5057 .72151 Mtetra
.5057 .72151 .50657 .7259 .50819 .72546 .50732 .72106 Mtetra
.50732 .72106 .50819 .72546 .50981 .72501 .50894 .72062 Mtetra
.50894 .72062 .50981 .72501 .51143 .72457 .51056 .72018 Mtetra
.51056 .72018 .51143 .72457 .51306 .72413 .51218 .71973 Mtetra
.51218 .71973 .51306 .72413 .51468 .72369 .5138 .71929 Mtetra
.5138 .71929 .51468 .72369 .51631 .72325 .51543 .71886 Mtetra
.51543 .71886 .51631 .72325 .51793 .72281 .51705 .71842 Mtetra
.51705 .71842 .51793 .72281 .51956 .72237 .51868 .71798 Mtetra
.51868 .71798 .51956 .72237 .52119 .72193 .52031 .71755 Mtetra
.52031 .71755 .52119 .72193 .52282 .7215 .52193 .71712 Mtetra
.606 .471 .67 r
.52193 .71712 .52282 .7215 .52445 .72106 .52356 .71669 Mtetra
.606 .471 .671 r
.52356 .71669 .52445 .72106 .52608 .72062 .52519 .71626 Mtetra
.52519 .71626 .52608 .72062 .52771 .72019 .52682 .71583 Mtetra
.52682 .71583 .52771 .72019 .52934 .71975 .52846 .71541 Mtetra
.52846 .71541 .52934 .71975 .53097 .71932 .53009 .71498 Mtetra
.606 .472 .672 r
.53009 .71498 .53097 .71932 .53261 .71889 .53172 .71456 Mtetra
.53172 .71456 .53261 .71889 .53424 .71846 .53336 .71414 Mtetra
.53336 .71414 .53424 .71846 .53588 .71803 .53499 .71372 Mtetra
.53499 .71372 .53588 .71803 .53752 .7176 .53663 .7133 Mtetra
.606 .472 .673 r
.53663 .7133 .53752 .7176 .53916 .71717 .53827 .71288 Mtetra
.606 .473 .673 r
.53827 .71288 .53916 .71717 .5408 .71676 .5399 .71246 Mtetra
.606 .472 .672 r
.5399 .71246 .5408 .71676 .54244 .71638 .54154 .71204 Mtetra
.607 .472 .672 r
.54154 .71204 .54244 .71638 .54408 .71599 .54319 .71161 Mtetra
.608 .472 .671 r
.54319 .71161 .54408 .71599 .54572 .71558 .54483 .71116 Mtetra
.609 .472 .669 r
.54483 .71116 .54572 .71558 .54737 .71514 .54647 .71068 Mtetra
.61 .472 .669 r
.54647 .71068 .54737 .71514 .54901 .71467 .54811 .71018 Mtetra
.616 .475 .667 r
.54811 .71018 .54901 .71467 .55066 .71419 .54976 .70958 Mtetra
.624 .478 .664 r
.54976 .70958 .55066 .71419 .5523 .7137 .5514 .70884 Mtetra
.608 .464 .66 r
.5514 .70884 .5523 .7137 .55395 .7132 .55304 .70832 Mtetra
.568 .437 .662 r
.55304 .70832 .55395 .7132 .5556 .71269 .5547 .70845 Mtetra
.504 .406 .677 r
.5547 .70845 .5556 .71269 .55725 .71216 .55636 .70929 Mtetra
.487 .442 .733 r
.55636 .70929 .55725 .71216 .55889 .7116 .55802 .70997 Mtetra
.497 .552 .842 r
.55802 .70997 .55889 .7116 .56054 .71091 .55968 .71026 Mtetra
.554 .776 .981 r
.55968 .71026 .56054 .71091 .56219 .71005 .56133 .71003 Mtetra
.349 .822 .887 r
.56133 .71003 .56219 .71005 .56384 .70917 .56299 .70965 Mtetra
.061 0 0 r
.56299 .70965 .56384 .70917 .56549 .7084 .56464 .70926 Mtetra
.303 0 0 r
.56464 .70926 .56549 .7084 .56714 .70789 .5663 .70897 Mtetra
.305 0 .013 r
.5663 .70897 .56714 .70789 .5688 .70756 .56796 .70854 Mtetra
.108 0 0 r
.56796 .70854 .5688 .70756 .57046 .70744 .56961 .70776 Mtetra
.754 .993 .805 r
.56961 .70776 .57046 .70744 .57213 .70754 .57126 .70629 Mtetra
.806 .726 .776 r
.57126 .70629 .57213 .70754 .57379 .70761 .5729 .70451 Mtetra
.707 .566 .693 r
.5729 .70451 .57379 .70761 .57546 .70753 .57454 .70282 Mtetra
.616 .472 .663 r
.57454 .70282 .57546 .70753 .57712 .70716 .5762 .70219 Mtetra
.593 .452 .659 r
.5762 .70219 .57712 .70716 .57878 .70672 .57786 .70192 Mtetra
.589 .452 .663 r
.57786 .70192 .57878 .70672 .58045 .70624 .57953 .70172 Mtetra
.604 .467 .668 r
.57953 .70172 .58045 .70624 .58211 .7058 .58119 .70131 Mtetra
.605 .468 .669 r
.58119 .70131 .58211 .7058 .58378 .70535 .58286 .70089 Mtetra
.605 .469 .67 r
.58286 .70089 .58378 .70535 .58544 .70488 .58452 .70047 Mtetra
.605 .47 .671 r
.58452 .70047 .58544 .70488 .58711 .70439 .58619 .70004 Mtetra
.607 .472 .672 r
.58619 .70004 .58711 .70439 .58878 .7039 .58786 .69961 Mtetra
.599 .468 .674 r
.58786 .69961 .58878 .7039 .59045 .70349 .58953 .6993 Mtetra
.565 .448 .679 r
.58953 .6993 .59045 .70349 .59212 .7034 .59121 .69944 Mtetra
.611 .484 .682 r
.59121 .69944 .59212 .7034 .5938 .70294 .59288 .69899 Mtetra
.702 .542 .668 r
.59288 .69899 .5938 .70294 .59545 .70148 .59452 .69695 Mtetra
.957 .685 .48 r
.59452 .69695 .59545 .70148 .59701 .69574 .59238 .50864 Mtetra
.588 .376 .561 r
.59238 .50864 .59701 .69574 .59461 .50109 .59373 .49679 Mtetra
.735 .552 .646 r
.59373 .49679 .59461 .50109 .59609 .49587 .59525 .49366 Mtetra
.674 .581 .742 r
.59525 .49366 .59609 .49587 .59766 .49493 .59682 .49282 Mtetra
.622 .559 .763 r
.59682 .49282 .59766 .49493 .59924 .49465 .5984 .49247 Mtetra
.59 .538 .764 r
.5984 .49247 .59924 .49465 .60083 .49454 .59999 .49236 Mtetra
.62 .554 .759 r
.59999 .49236 .60083 .49454 .6024 .49369 .60158 .49202 Mtetra
.624 .601 .807 r
.60158 .49202 .6024 .49369 .60397 .49285 .60316 .4917 Mtetra
.63 .678 .877 r
.60316 .4917 .60397 .49285 .60555 .49211 .60475 .49136 Mtetra
.643 .773 .943 r
.60475 .49136 .60555 .49211 .60713 .49165 .60633 .49093 Mtetra
.656 .787 .944 r
.60633 .49093 .60713 .49165 .60872 .49125 .60792 .49045 Mtetra
.678 .772 .922 r
.60792 .49045 .60872 .49125 .6103 .49085 .6095 .4899 Mtetra
.717 .747 .875 r
.6095 .4899 .6103 .49085 .61189 .49033 .61108 .48914 Mtetra
.691 .694 .848 r
.61108 .48914 .61189 .49033 .61347 .48979 .61266 .48847 Mtetra
.65 .659 .846 r
.61266 .48847 .61347 .48979 .61506 .4892 .61425 .48803 Mtetra
.554 .642 .892 r
.61425 .48803 .61506 .4892 .61663 .48825 .61585 .48799 Mtetra
0 .373 .677 r
.61585 .48799 .61663 .48825 .61822 .48765 .61747 .48852 Mtetra
.748 .331 .258 r
.61747 .48852 .61822 .48765 .61982 .4878 .61913 .49033 Mtetra
.96 .679 .458 r
.61913 .49033 .61982 .4878 .62154 .49168 .62621 .67948 Mtetra
.582 .367 .555 r
.62621 .67948 .62154 .49168 .6289 .68554 .62819 .68931 Mtetra
.69 .382 .449 r
.62819 .68931 .6289 .68554 .63077 .69114 .62998 .69181 Mtetra
.412 0 0 r
.62998 .69181 .63077 .69114 .6325 .69169 .63169 .69191 Mtetra
.241 .748 .707 r
.63169 .69191 .6325 .69169 .6342 .69149 .63338 .69138 Mtetra
.72 .964 .94 r
.63338 .69138 .6342 .69149 .63589 .69095 .63506 .69039 Mtetra
.76 .863 .925 r
.63506 .69039 .63589 .69095 .63761 .69106 .63675 .68942 Mtetra
.759 .675 .768 r
.63675 .68942 .63761 .69106 .63931 .69072 .63841 .68792 Mtetra
.762 .608 .687 r
.63841 .68792 .63931 .69072 .64099 .6896 .64004 .68539 Mtetra
.882 .646 .576 r
.64004 .68539 .64099 .6896 .64253 .68419 .64134 .67289 Mtetra
.952 .676 .477 r
.64134 .67289 .64253 .68419 .63756 .48794 .63669 .48469 Mtetra
.787 .603 .652 r
.63669 .48469 .63756 .48794 .63898 .48197 .63819 .481 Mtetra
.753 .757 .855 r
.63819 .481 .63898 .48197 .64056 .48081 .63977 .48001 Mtetra
.651 .765 .933 r
.63977 .48001 .64056 .48081 .64216 .48038 .64137 .47956 Mtetra
.574 .731 .949 r
.64137 .47956 .64216 .48038 .64378 .48031 .64299 .47936 Mtetra
.765 .761 .85 r
.64299 .47936 .64378 .48031 .64537 .47934 .64457 .47828 Mtetra
.708 .726 .865 r
.64457 .47828 .64537 .47934 .64697 .4787 .64617 .47755 Mtetra
.561 .649 .894 r
.64617 .47755 .64697 .4787 .64859 .47874 .64779 .47748 Mtetra
.804 .39 0 r
.64779 .47748 .64859 .47874 .65038 .48293 .64956 .48135 Mtetra
.969 .685 .438 r
.64956 .48135 .65038 .48293 .65953 .67854 .65868 .67718 Mtetra
.894 .505 .062 r
.65868 .67718 .65953 .67854 .66146 .6837 .66063 .6828 Mtetra
.087 .457 .886 r
.66063 .6828 .66146 .6837 .66322 .68447 .66239 .68361 Mtetra
.619 .754 .942 r
.66239 .68361 .66322 .68447 .66494 .68409 .66411 .68324 Mtetra
.807 .801 .845 r
.66411 .68324 .66494 .68409 .66661 .68269 .66579 .68184 Mtetra
.937 .77 .65 r
.66579 .68184 .66661 .68269 .66815 .67781 .66733 .67697 Mtetra
.968 .69 .449 r
.66733 .67697 .66815 .67781 .66176 .48167 .66098 .48079 Mtetra
.949 .748 .597 r
.66098 .48079 .66176 .48167 .66312 .47491 .66234 .474 Mtetra
.795 .777 .837 r
.66234 .474 .66312 .47491 .6647 .47362 .66392 .47271 Mtetra
.622 .728 .923 r
.66392 .47271 .6647 .47362 .66632 .47329 .66554 .47237 Mtetra
.475 .665 .946 r
.66554 .47237 .66632 .47329 .66796 .47338 .66719 .47247 Mtetra
.616 .728 .926 r
.66719 .47247 .66796 .47338 .66959 .47305 .66881 .47215 Mtetra
.641 .74 .92 r
.66881 .47215 .66959 .47305 .67121 .47263 .67044 .47174 Mtetra
.654 .747 .918 r
.67044 .47174 .67121 .47263 .67283 .47215 .67206 .47128 Mtetra
.68 .759 .91 r
.67206 .47128 .67283 .47215 .67445 .47151 .67368 .4707 Mtetra
.695 .779 .916 r
.67368 .4707 .67445 .47151 .67606 .47085 .67529 .47006 Mtetra
.704 .787 .916 r
.67529 .47006 .67606 .47085 .67768 .47025 .67691 .46938 Mtetra
.786 .787 .853 r
.67691 .46938 .67768 .47025 .6793 .46951 .6785 .46819 Mtetra
.719 .691 .822 r
.6785 .46819 .6793 .46951 .68092 .46908 .68011 .4673 Mtetra
.604 .582 .802 r
.68011 .4673 .68092 .46908 .68259 .46934 .68175 .46709 Mtetra
0 0 .528 r
.68175 .46709 .68259 .46934 .68446 .47383 .68357 .47054 Mtetra
.973 .686 .42 r
.68357 .47054 .68446 .47383 .69565 .66888 .69479 .667 Mtetra
.828 .461 0 r
.69479 .667 .69565 .66888 .69764 .67356 .69684 .67297 Mtetra
0 .361 .778 r
.69684 .67297 .69764 .67356 .69944 .67452 .69864 .67384 Mtetra
.625 .805 .969 r
.69864 .67384 .69944 .67452 .70119 .67426 .70038 .6734 Mtetra
.801 .802 .853 r
.70038 .6734 .70119 .67426 .70289 .67301 .70207 .67205 Mtetra
.903 .78 .716 r
.70207 .67205 .70289 .67301 .70442 .66857 .70367 .66886 Mtetra
.994 .79 .525 r
.70367 .66886 .70442 .66857 .69597 .47187 .70497 .65988 Mtetra
.053 0 .44 r
.70497 .65988 .69597 .47187 .69724 .46429 .69666 .46701 Mtetra
0 0 .152 r
.69666 .46701 .69724 .46429 .69881 .46263 .69815 .46372 Mtetra
0 0 0 r
.69815 .46372 .69881 .46263 .70045 .46215 .69973 .46209 Mtetra
.73 .978 .918 r
.69973 .46209 .70045 .46215 .70211 .4621 .70134 .46105 Mtetra
.687 .725 .878 r
.70134 .46105 .70211 .4621 .70376 .46175 .70297 .46042 Mtetra
.637 .655 .851 r
.70297 .46042 .70376 .46175 .7054 .46127 .70462 .46003 Mtetra
.614 .661 .872 r
.70462 .46003 .7054 .46127 .70704 .46077 .70627 .45975 Mtetra
.706 .738 .877 r
.70627 .45975 .70704 .46077 .70865 .45985 .7079 .45903 Mtetra
.705 .783 .913 r
.7079 .45903 .70865 .45985 .71028 .45906 .70953 .45834 Mtetra
.574 .764 .968 r
.70953 .45834 .71028 .45906 .71194 .45886 .71119 .45809 Mtetra
0 .057 .561 r
.71119 .45809 .71194 .45886 .71377 .4616 .71295 .45974 Mtetra
.875 .516 .023 r
.71295 .45974 .71377 .4616 .72677 .65682 .71504 .46681 Mtetra
.073 0 .457 r
.71504 .46681 .72677 .65682 .729 .66451 .72796 .65955 Mtetra
.35 .292 .651 r
.72796 .65955 .729 .66451 .73084 .66551 .7299 .66231 Mtetra
.489 .433 .721 r
.7299 .66231 .73084 .66551 .7326 .66504 .73173 .6631 Mtetra
.545 .548 .808 r
.73173 .6631 .7326 .66504 .73432 .66409 .73353 .66324 Mtetra
.601 .753 .951 r
.73353 .66324 .73432 .66409 .73607 .66348 .7353 .66291 Mtetra
.655 .849 .974 r
.7353 .66291 .73607 .66348 .73784 .66307 .73705 .66232 Mtetra
.696 .813 .938 r
.73705 .66232 .73784 .66307 .7396 .66258 .7388 .66162 Mtetra
.568 .714 .94 r
.7388 .66162 .7396 .66258 .74136 .66219 .74058 .66144 Mtetra
.521 .748 .978 r
.74058 .66144 .74136 .66219 .74312 .66157 .74236 .66131 Mtetra
.595 .909 .981 r
.74236 .66131 .74312 .66157 .74483 .66032 .74412 .66069 Mtetra
.899 .977 .688 r
.74412 .66069 .74483 .66032 .74634 .65584 .74575 .65815 Mtetra
.831 .767 .257 r
.74575 .65815 .74634 .65584 .73551 .45914 .7471 .65114 Mtetra
.08 0 .455 r
.7471 .65114 .73551 .45914 .73677 .45238 .73629 .45568 Mtetra
0 0 .214 r
.73629 .45568 .73677 .45238 .73833 .45051 .73772 .45168 Mtetra
0 0 0 r
.73772 .45168 .73833 .45051 .73999 .44997 .7393 .44995 Mtetra
.717 .983 .899 r
.7393 .44995 .73999 .44997 .74168 .44986 .74093 .44887 Mtetra
.692 .743 .891 r
.74093 .44887 .74168 .44986 .74335 .44959 .74258 .44822 Mtetra
.634 .651 .85 r
.74258 .44822 .74335 .44959 .74502 .44914 .74425 .44784 Mtetra
.608 .651 .866 r
.74425 .44784 .74502 .44914 .74669 .44867 .74593 .44759 Mtetra
.633 .703 .896 r
.74593 .44759 .74669 .44867 .74835 .44808 .7476 .44721 Mtetra
.663 .76 .922 r
.7476 .44721 .74835 .44808 .75 .44746 .74927 .4467 Mtetra
.672 .792 .938 r
.74927 .4467 .75 .44746 .75166 .44689 .75093 .44613 Mtetra
.742 .812 .907 r
.75093 .44613 .75166 .44689 .75332 .44628 .75257 .44526 Mtetra
.731 .749 .867 r
.75257 .44526 .75332 .44628 .755 .44585 .75422 .44438 Mtetra
.643 .641 .833 r
.75422 .44438 .755 .44585 .75671 .446 .75589 .44394 Mtetra
.343 .405 .782 r
.75589 .44394 .75671 .446 .75862 .44882 .75768 .44511 Mtetra
0 0 .524 r
.75768 .44511 .75862 .44882 .77442 .64456 .75977 .45038 Mtetra
.101 .022 .471 r
.75977 .45038 .77442 .64456 .77672 .6513 .7756 .64566 Mtetra
.314 .257 .633 r
.7756 .64566 .77672 .6513 .77864 .65264 .77768 .64928 Mtetra
.48 .422 .715 r
.77768 .64928 .77864 .65264 .78044 .65237 .77957 .65021 Mtetra
.537 .525 .789 r
.77957 .65021 .78044 .65237 .7822 .65157 .78141 .65044 Mtetra
.519 .654 .92 r
.78141 .65044 .7822 .65157 .78398 .65091 .78323 .65048 Mtetra
.452 .807 .997 r
.78323 .65048 .78398 .65091 .78576 .65032 .78505 .65027 Mtetra
.547 .926 .913 r
.78505 .65027 .78576 .65032 .7875 .64915 .78682 .64952 Mtetra
.844 .981 .69 r
.78682 .64952 .7875 .64915 .78905 .64557 .78847 .64727 Mtetra
.831 .795 .299 r
.78847 .64727 .78905 .64557 .7759 .45034 .78987 .6416 Mtetra
.093 .013 .464 r
.78987 .6416 .7759 .45034 .77688 .44063 .77655 .44497 Mtetra
0 0 .279 r
.77655 .44497 .77688 .44063 .77842 .43825 .77787 .43969 Mtetra
0 0 0 r
.77787 .43969 .77842 .43825 .78009 .43759 .77944 .43774 Mtetra
.665 .971 .813 r
.77944 .43774 .78009 .43759 .7818 .4374 .78107 .43654 Mtetra
.711 .781 .907 r
.78107 .43654 .7818 .4374 .7835 .43715 .78274 .4358 Mtetra
.644 .659 .85 r
.78274 .4358 .7835 .43715 .78519 .43667 .78443 .43536 Mtetra
.617 .654 .863 r
.78443 .43536 .78519 .43667 .78688 .43617 .78614 .43506 Mtetra
.633 .698 .892 r
.78614 .43506 .78688 .43617 .78856 .43558 .78784 .43468 Mtetra
.668 .758 .918 r
.78784 .43468 .78856 .43558 .79024 .43492 .78952 .43413 Mtetra
.678 .79 .934 r
.78952 .43413 .79024 .43492 .79192 .43431 .79121 .43354 Mtetra
.746 .815 .906 r
.79121 .43354 .79192 .43431 .7936 .43367 .79287 .43263 Mtetra
.751 .756 .857 r
.79287 .43263 .7936 .43367 .79529 .43315 .79452 .43162 Mtetra
.651 .639 .825 r
.79452 .43162 .79529 .43315 .79703 .43313 .79621 .43112 Mtetra
.29 .378 .781 r
.79621 .43112 .79703 .43313 .79892 .43504 .79806 .43249 Mtetra
.9 .569 .083 r
.79806 .43249 .79892 .43504 .81691 .62693 .80085 .44487 Mtetra
.09 .018 .473 r
.80085 .44487 .81691 .62693 .81974 .63856 .81899 .63771 Mtetra
0 0 .496 r
.81899 .63771 .81974 .63856 .82176 .64053 .82103 .63993 Mtetra
.549 .806 .993 r
.82103 .63993 .82176 .64053 .82361 .64039 .82286 .63962 Mtetra
.732 .824 .922 r
.82286 .63962 .82361 .64039 .8254 .63969 .82464 .63874 Mtetra
.662 .759 .922 r
.82464 .63874 .8254 .63969 .8272 .639 .82645 .63818 Mtetra
.47 .707 .972 r
.82645 .63818 .8272 .639 .82901 .63851 .82831 .6382 Mtetra
.54 .883 .986 r
.82831 .6382 .82901 .63851 .83079 .6375 .83013 .6377 Mtetra
.891 .985 .721 r
.83013 .6377 .83079 .6375 .83239 .63463 .83178 .63536 Mtetra
.997 .788 .436 r
.83178 .63536 .83239 .63463 .83265 .61675 .83273 .62506 Mtetra
.981 .688 .349 r
.83273 .62506 .83265 .61675 .8176 .42898 .81688 .42794 Mtetra
.913 .779 .699 r
.81688 .42794 .8176 .42898 .81909 .42603 .81834 .42467 Mtetra
.683 .678 .839 r
.81834 .42467 .81909 .42603 .82078 .42529 .82003 .424 Mtetra
.566 .634 .878 r
.82003 .424 .82078 .42529 .82251 .42509 .82178 .42393 Mtetra
.583 .667 .896 r
.82178 .42393 .82251 .42509 .82424 .42475 .82352 .42376 Mtetra
.702 .751 .89 r
.82352 .42376 .82424 .42475 .82592 .42394 .82522 .42304 Mtetra
.614 .74 .935 r
.82522 .42304 .82592 .42394 .82765 .42364 .82694 .4227 Mtetra
.116 .446 .881 r
.82694 .4227 .82765 .42364 .82956 .42519 .82879 .42362 Mtetra
.762 .385 0 r
.82879 .42362 .82956 .42519 .84959 .61877 .83109 .42928 Mtetra
.119 .041 .485 r
.83109 .42928 .84959 .61877 .85255 .63029 .85141 .62515 Mtetra
.254 .228 .636 r
.85141 .62515 .85255 .63029 .85465 .63257 .85367 .6292 Mtetra
.446 .402 .716 r
.85367 .6292 .85465 .63257 .85654 .63266 .85567 .63045 Mtetra
.563 .537 .784 r
.85567 .63045 .85654 .63266 .85834 .63183 .85756 .63051 Mtetra
.796 .74 .8 r
.85756 .63051 .85834 .63183 .86 .62955 .85929 .6289 Mtetra
.98 .793 .581 r
.85929 .6289 .86 .62955 .86123 .6228 .86057 .62274 Mtetra
.978 .68 .365 r
.86057 .62274 .86123 .6228 .8435 .42308 .84283 .42246 Mtetra
.974 .809 .617 r
.84283 .42246 .8435 .42308 .84484 .41865 .84413 .41766 Mtetra
.751 .772 .87 r
.84413 .41766 .84484 .41865 .84652 .41767 .84581 .41666 Mtetra
.621 .717 .915 r
.84581 .41666 .84652 .41767 .84826 .41734 .84755 .41631 Mtetra
.602 .705 .916 r
.84755 .41631 .84826 .41734 .85002 .41712 .8493 .41604 Mtetra
.704 .736 .876 r
.8493 .41604 .85002 .41712 .85173 .41649 .85101 .41529 Mtetra
.678 .705 .868 r
.85101 .41529 .85173 .41649 .85345 .41585 .85272 .41468 Mtetra
.637 .692 .884 r
.85272 .41468 .85345 .41585 .85515 .41506 .85446 .41427 Mtetra
.521 .726 .967 r
.85446 .41427 .85515 .41506 .85682 .41404 .85624 .41417 Mtetra
.385 0 0 r
.85624 .41417 .85682 .41404 .85855 .41344 .85807 .41469 Mtetra
.766 .353 .266 r
.85807 .41469 .85855 .41344 .86039 .414 .86012 .41717 Mtetra
.973 .665 .355 r
.86012 .41717 .86039 .414 .8627 .41908 .88231 .61326 Mtetra
.576 .362 .554 r
.88231 .61326 .8627 .41908 .88526 .61725 .88491 .61998 Mtetra
.675 .326 .376 r
.88491 .61998 .88526 .61725 .88759 .62133 .88701 .62185 Mtetra
.228 0 0 r
.88701 .62185 .88759 .62133 .88953 .62166 .8889 .62165 Mtetra
.518 .917 .875 r
.8889 .62165 .88953 .62166 .8914 .6213 .89072 .62083 Mtetra
.778 .92 .932 r
.89072 .62083 .8914 .6213 .89326 .62081 .89251 .61968 Mtetra
.747 .757 .86 r
.89251 .61968 .89326 .62081 .89516 .62078 .8943 .6186 Mtetra
.746 .638 .74 r
.8943 .6186 .89516 .62078 .89702 .62026 .89604 .61693 Mtetra
.785 .607 .659 r
.89604 .61693 .89702 .62026 .89875 .61859 .89757 .61342 Mtetra
.975 .673 .363 r
.89757 .61342 .89875 .61859 .9 .61243 .87802 .41656 Mtetra
.58 .369 .559 r
.87802 .41656 .9 .61243 .88001 .41285 .87892 .40824 Mtetra
.718 .536 .643 r
.87892 .40824 .88001 .41285 .88124 .4077 .88041 .40542 Mtetra
.657 .576 .752 r
.88041 .40542 .88124 .4077 .8829 .4064 .88213 .4047 Mtetra
.603 .598 .819 r
.88213 .4047 .8829 .4064 .88463 .40576 .88391 .40448 Mtetra
.563 .638 .884 r
.88391 .40448 .88463 .40576 .8864 .40538 .88571 .40442 Mtetra
.653 .745 .917 r
.88571 .40442 .8864 .40538 .88814 .40483 .88746 .40392 Mtetra
.665 .764 .924 r
.88746 .40392 .88814 .40483 .88989 .40433 .88921 .40337 Mtetra
.697 .764 .903 r
.88921 .40337 .88989 .40433 .89164 .40376 .89094 .40267 Mtetra
.765 .761 .849 r
.89094 .40267 .89164 .40376 .89333 .40278 .89262 .40153 Mtetra
.692 .705 .857 r
.89262 .40153 .89333 .40278 .89508 .40216 .89435 .40082 Mtetra
.472 .577 .879 r
.89435 .40082 .89508 .40216 .89692 .40245 .8962 .40113 Mtetra
.761 .37 0 r
.8962 .40113 .89692 .40245 .89925 .40686 .89867 .4068 Mtetra
.973 .662 .319 r
.89867 .4068 .89925 .40686 .92422 .60564 .92379 .60712 Mtetra
.818 .416 .288 r
.92379 .60712 .92422 .60564 .92673 .61054 .92619 .61107 Mtetra
.277 0 0 r
.92619 .61107 .92673 .61054 .92871 .61093 .92812 .61097 Mtetra
.478 .897 .833 r
.92812 .61097 .92871 .61093 .93061 .61058 .92996 .61013 Mtetra
.761 .928 .942 r
.92996 .61013 .93061 .61058 .93248 .60994 .93177 .60903 Mtetra
.513 .708 .959 r
.93177 .60903 .93248 .60994 .93442 .6099 .93371 .60898 Mtetra
.634 .763 .941 r
.93371 .60898 .93442 .6099 .9363 .6094 .9356 .60851 Mtetra
.817 .829 .859 r
.9356 .60851 .9363 .6094 .93808 .60798 .93737 .60703 Mtetra
.982 .769 .542 r
.93737 .60703 .93808 .60798 .93932 .6022 .93841 .59951 Mtetra
.975 .669 .332 r
.93841 .59951 .93932 .6022 .91694 .40207 .91596 .39855 Mtetra
.814 .613 .63 r
.91596 .39855 .91694 .40207 .91807 .3963 .91723 .39397 Mtetra
.672 .582 .746 r
.91723 .39397 .91807 .3963 .91973 .39496 .91895 .39309 Mtetra
.602 .581 .802 r
.91895 .39309 .91973 .39496 .92148 .39429 .92076 .39287 Mtetra
.529 .597 .867 r
.92076 .39287 .92148 .39429 .92328 .39396 .92261 .39299 Mtetra
.643 .742 .921 r
.92261 .39299 .92328 .39396 .92505 .39342 .92439 .39253 Mtetra
.651 .765 .932 r
.92439 .39253 .92505 .39342 .92682 .39293 .92616 .39202 Mtetra
.666 .766 .925 r
.92616 .39202 .92682 .39293 .9286 .39244 .92793 .39146 Mtetra
.76 .785 .873 r
.92793 .39146 .9286 .39244 .93031 .39138 .92964 .39039 Mtetra
.693 .759 .902 r
.92964 .39039 .93031 .39138 .93206 .3907 .9314 .3897 Mtetra
.499 .665 .937 r
.9314 .3897 .93206 .3907 .93391 .39077 .93325 .38977 Mtetra
.749 .332 0 r
.93325 .38977 .93391 .39077 .93639 .39568 .93572 .39468 Mtetra
.97 .655 .291 r
.93572 .39468 .93639 .39568 .96399 .59621 .9633 .59526 Mtetra
.733 .301 0 r
.9633 .59526 .96399 .59621 .96656 .60089 .96587 .59994 Mtetra
.045 .471 .883 r
.35193 .76609 .35288 .76686 .35437 .76747 .35342 .7667 Mtetra
.645 .762 .934 r
.35342 .7667 .35437 .76747 .3559 .76706 .35495 .76629 Mtetra
.809 .778 .824 r
.35495 .76629 .3559 .76706 .35748 .76562 .35653 .76485 Mtetra
.908 .737 .659 r
.35653 .76485 .35748 .76562 .35924 .76037 .35829 .75959 Mtetra
.937 .686 .534 r
.35829 .75959 .35924 .76037 .3695 .56934 .36861 .56851 Mtetra
.909 .727 .645 r
.36861 .56851 .3695 .56934 .3712 .56363 .37031 .5628 Mtetra
.777 .76 .837 r
.37031 .5628 .3712 .56363 .37268 .56252 .37179 .56169 Mtetra
.641 .736 .918 r
.37179 .56169 .37268 .56252 .37413 .56215 .37324 .56132 Mtetra
.509 .691 .95 r
.37324 .56132 .37413 .56215 .37557 .56214 .37468 .56132 Mtetra
.746 .758 .862 r
.37468 .56132 .37557 .56214 .37704 .56127 .37615 .56045 Mtetra
.696 .75 .893 r
.37615 .56045 .37704 .56127 .3785 .56068 .37762 .55986 Mtetra
.478 .679 .954 r
.37762 .55986 .3785 .56068 .37994 .56074 .37905 .55991 Mtetra
.927 .548 .253 r
.37905 .55991 .37994 .56074 .38121 .56471 .38032 .56391 Mtetra
.939 .683 .522 r
.38032 .56391 .38121 .56471 .37466 .75509 .37372 .75435 Mtetra
.933 .578 .325 r
.37372 .75435 .37466 .75509 .37596 .76027 .37502 .75951 Mtetra
0 .335 .781 r
.37502 .75951 .37596 .76027 .37746 .76109 .37652 .76033 Mtetra
.618 .759 .946 r
.37652 .76033 .37746 .76109 .379 .76076 .37806 .76 Mtetra
.802 .784 .836 r
.37806 .76 .379 .76076 .38059 .75942 .37965 .75866 Mtetra
.907 .745 .669 r
.37965 .75866 .38059 .75942 .38231 .75464 .38137 .75393 Mtetra
.939 .687 .529 r
.38137 .75393 .38231 .75464 .39138 .56347 .39049 .56276 Mtetra
.92 .732 .632 r
.39049 .56276 .39138 .56347 .39307 .55712 .39219 .55632 Mtetra
.797 .769 .827 r
.39219 .55632 .39307 .55712 .39457 .55585 .39369 .55505 Mtetra
.622 .739 .931 r
.39369 .55505 .39457 .55585 .39603 .55554 .39515 .55474 Mtetra
.438 .67 .961 r
.39515 .55474 .39603 .55554 .39748 .55565 .3966 .55486 Mtetra
.598 .733 .939 r
.3966 .55486 .39748 .55565 .39893 .55542 .39806 .55462 Mtetra
.626 .74 .929 r
.39806 .55462 .39893 .55542 .4004 .5551 .39952 .55429 Mtetra
.633 .741 .926 r
.39952 .55429 .4004 .5551 .40186 .55477 .40099 .55395 Mtetra
.654 .744 .916 r
.40099 .55395 .40186 .55477 .40333 .55436 .40246 .55353 Mtetra
.665 .744 .909 r
.40246 .55353 .40333 .55436 .4048 .55391 .40393 .55307 Mtetra
.672 .743 .903 r
.40393 .55307 .4048 .55391 .40628 .55343 .4054 .55257 Mtetra
.675 .741 .9 r
.4054 .55257 .40628 .55343 .40775 .55292 .40688 .55207 Mtetra
.679 .742 .898 r
.40688 .55207 .40775 .55292 .40923 .5524 .40835 .55155 Mtetra
.682 .744 .898 r
.40835 .55155 .40923 .5524 .4107 .55185 .40983 .55101 Mtetra
.679 .746 .901 r
.40983 .55101 .4107 .55185 .41218 .55131 .41131 .55049 Mtetra
.683 .751 .903 r
.41131 .55049 .41218 .55131 .41366 .55076 .41279 .54995 Mtetra
.69 .757 .903 r
.41279 .54995 .41366 .55076 .41514 .55018 .41427 .54938 Mtetra
.711 .764 .894 r
.41427 .54938 .41514 .55018 .41663 .54953 .41575 .54872 Mtetra
.715 .761 .889 r
.41575 .54872 .41663 .54953 .41811 .54886 .41724 .54803 Mtetra
.71 .755 .887 r
.41724 .54803 .41811 .54886 .4196 .54823 .41873 .54736 Mtetra
.722 .751 .875 r
.41873 .54736 .4196 .54823 .42109 .54739 .42022 .54662 Mtetra
.699 .768 .905 r
.42022 .54662 .42109 .54739 .42257 .54674 .4217 .54601 Mtetra
.617 .76 .947 r
.4217 .54601 .42257 .54674 .42405 .54655 .42318 .5457 Mtetra
.236 .552 .931 r
.42318 .5457 .42405 .54655 .42547 .5482 .42463 .54616 Mtetra
.164 .286 .744 r
.42463 .54616 .42547 .5482 .42675 .55475 .42606 .54762 Mtetra
.307 .216 .586 r
.42606 .54762 .42675 .55475 .42283 .74302 .42742 .55146 Mtetra
0 0 .357 r
.42742 .55146 .42283 .74302 .42431 .74576 .42358 .73843 Mtetra
.154 .106 .547 r
.42358 .73843 .42431 .74576 .42585 .74658 .42499 .74381 Mtetra
.163 .234 .691 r
.42499 .74381 .42585 .74658 .42741 .74677 .42649 .74581 Mtetra
.376 .611 .942 r
.42649 .74581 .42741 .74677 .42898 .7466 .42805 .74612 Mtetra
.607 .833 .986 r
.42805 .74612 .42898 .7466 .43055 .74621 .42962 .74571 Mtetra
.702 .851 .954 r
.42962 .74571 .43055 .74621 .43213 .74569 .43121 .74504 Mtetra
.614 .791 .967 r
.43121 .74504 .43213 .74569 .4337 .7455 .43278 .74468 Mtetra
.615 .747 .94 r
.43278 .74468 .4337 .7455 .43528 .74525 .43436 .74436 Mtetra
.687 .749 .899 r
.43436 .74436 .43528 .74525 .43686 .74454 .43595 .74376 Mtetra
.807 .786 .834 r
.43595 .74376 .43686 .74454 .43849 .74201 .43755 .74237 Mtetra
.936 .955 .763 r
.43755 .74237 .43849 .74201 .44023 .73519 .43918 .73993 Mtetra
0 0 .201 r
.43918 .73993 .44023 .73519 .44624 .54509 .44086 .73532 Mtetra
0 0 .354 r
.44086 .73532 .44624 .54509 .44781 .54126 .44679 .54744 Mtetra
0 0 .188 r
.44679 .54744 .44781 .54126 .44933 .53959 .44843 .54069 Mtetra
.872 .946 .586 r
.44843 .54069 .44933 .53959 .45084 .53853 .44998 .53787 Mtetra
.805 .804 .851 r
.44998 .53787 .45084 .53853 .45234 .53784 .45149 .53663 Mtetra
.669 .676 .848 r
.45149 .53663 .45234 .53784 .45384 .53736 .45299 .53612 Mtetra
.609 .646 .862 r
.45299 .53612 .45384 .53736 .45534 .53703 .45449 .5359 Mtetra
.607 .665 .88 r
.45449 .5359 .45534 .53703 .45683 .53671 .45598 .53567 Mtetra
.617 .688 .894 r
.45598 .53567 .45683 .53671 .45833 .53636 .45748 .5354 Mtetra
.622 .705 .905 r
.45748 .5354 .45833 .53636 .45983 .53599 .45898 .5351 Mtetra
.666 .735 .901 r
.45898 .5351 .45983 .53599 .46133 .5355 .46048 .53463 Mtetra
.696 .747 .891 r
.46048 .53463 .46133 .5355 .46284 .53491 .46198 .53402 Mtetra
.699 .743 .885 r
.46198 .53402 .46284 .53491 .46435 .53431 .46349 .53339 Mtetra
.682 .733 .889 r
.46349 .53339 .46435 .53431 .46585 .53377 .465 .53284 Mtetra
.668 .727 .894 r
.465 .53284 .46585 .53377 .46736 .53327 .4665 .53235 Mtetra
.664 .728 .897 r
.4665 .53235 .46736 .53327 .46886 .53279 .46801 .53188 Mtetra
.666 .731 .898 r
.46801 .53188 .46886 .53279 .47037 .5323 .46952 .53141 Mtetra
.668 .734 .9 r
.46952 .53141 .47037 .5323 .47188 .53181 .47103 .53092 Mtetra
.667 .736 .902 r
.47103 .53092 .47188 .53181 .47339 .53132 .47254 .53044 Mtetra
.693 .745 .891 r
.47254 .53044 .47339 .53132 .4749 .53064 .47405 .52984 Mtetra
.693 .764 .906 r
.47405 .52984 .4749 .53064 .47641 .52997 .47556 .52925 Mtetra
.629 .766 .945 r
.47556 .52925 .47641 .52997 .47792 .52969 .47707 .52889 Mtetra
.226 .559 .935 r
.47707 .52889 .47792 .52969 .47941 .53092 .47857 .52935 Mtetra
0 .188 .718 r
.47857 .52935 .47941 .53092 .48085 .53604 .48005 .53095 Mtetra
.266 .216 .613 r
.48005 .53095 .48085 .53604 .47995 .7261 .48152 .53408 Mtetra
.56 .354 .558 r
.48152 .53408 .47995 .7261 .48151 .72902 .48299 .53786 Mtetra
.567 .36 .559 r
.48299 .53786 .48151 .72902 .48312 .72884 .4845 .53803 Mtetra
.571 .363 .559 r
.4845 .53803 .48312 .72884 .48473 .72791 .48604 .53607 Mtetra
.57 .362 .559 r
.48604 .53607 .48473 .72791 .48634 .72707 .48757 .53473 Mtetra
.568 .361 .559 r
.48757 .53473 .48634 .72707 .48795 .72658 .48909 .53412 Mtetra
.48909 .53412 .48795 .72658 .48956 .72608 .49062 .53351 Mtetra
.49062 .53351 .48956 .72608 .49117 .72559 .49214 .53294 Mtetra
.49214 .53294 .49117 .72559 .49278 .72512 .49367 .5324 Mtetra
.568 .36 .559 r
.49367 .5324 .49278 .72512 .49439 .72466 .4952 .53188 Mtetra
.4952 .53188 .49439 .72466 .496 .7242 .49672 .53137 Mtetra
.49672 .53137 .496 .7242 .49762 .72375 .49825 .53087 Mtetra
.49825 .53087 .49762 .72375 .49923 .72329 .49978 .53037 Mtetra
.49978 .53037 .49923 .72329 .50085 .72285 .50131 .52988 Mtetra
.50131 .52988 .50085 .72285 .50246 .7224 .50284 .52939 Mtetra
.50284 .52939 .50246 .7224 .50408 .72195 .50437 .52891 Mtetra
.50437 .52891 .50408 .72195 .5057 .72151 .5059 .52843 Mtetra
.5059 .52843 .5057 .72151 .50732 .72106 .50743 .52795 Mtetra
.50743 .52795 .50732 .72106 .50894 .72062 .50896 .52748 Mtetra
.50896 .52748 .50894 .72062 .51056 .72018 .5105 .52701 Mtetra
.5105 .52701 .51056 .72018 .51218 .71973 .51203 .52654 Mtetra
.51203 .52654 .51218 .71973 .5138 .71929 .51357 .52607 Mtetra
.51357 .52607 .5138 .71929 .51543 .71886 .5151 .52561 Mtetra
.5151 .52561 .51543 .71886 .51705 .71842 .51664 .52516 Mtetra
.51664 .52516 .51705 .71842 .51868 .71798 .51818 .52471 Mtetra
.51818 .52471 .51868 .71798 .52031 .71755 .51972 .52427 Mtetra
.51972 .52427 .52031 .71755 .52193 .71712 .52126 .52383 Mtetra
.52126 .52383 .52193 .71712 .52356 .71669 .5228 .5234 Mtetra
.5228 .5234 .52356 .71669 .52519 .71626 .52434 .52298 Mtetra
.52434 .52298 .52519 .71626 .52682 .71583 .52588 .52256 Mtetra
.52588 .52256 .52682 .71583 .52846 .71541 .52743 .52214 Mtetra
.52743 .52214 .52846 .71541 .53009 .71498 .52897 .52173 Mtetra
.52897 .52173 .53009 .71498 .53172 .71456 .53052 .52132 Mtetra
.53052 .52132 .53172 .71456 .53336 .71414 .53206 .52091 Mtetra
.53206 .52091 .53336 .71414 .53499 .71372 .53361 .5205 Mtetra
.53361 .5205 .53499 .71372 .53663 .7133 .53516 .52008 Mtetra
.53516 .52008 .53663 .7133 .53827 .71288 .53671 .51966 Mtetra
.53671 .51966 .53827 .71288 .5399 .71246 .53826 .51924 Mtetra
.53826 .51924 .5399 .71246 .54154 .71204 .53981 .51882 Mtetra
.53981 .51882 .54154 .71204 .54319 .71161 .54136 .51835 Mtetra
.54136 .51835 .54319 .71161 .54483 .71116 .54291 .51782 Mtetra
.568 .361 .559 r
.54291 .51782 .54483 .71116 .54647 .71068 .54446 .51718 Mtetra
.54446 .51718 .54647 .71068 .54811 .71018 .54602 .51651 Mtetra
.569 .361 .559 r
.54602 .51651 .54811 .71018 .54976 .70958 .54757 .51535 Mtetra
.57 .362 .559 r
.54757 .51535 .54976 .70958 .5514 .70884 .54912 .51373 Mtetra
.568 .36 .559 r
.54912 .51373 .5514 .70884 .55304 .70832 .55067 .51326 Mtetra
.561 .354 .558 r
.55067 .51326 .55304 .70832 .5547 .70845 .55226 .5171 Mtetra
.005 0 .412 r
.55226 .5171 .5547 .70845 .55636 .70929 .55545 .7039 Mtetra
.181 .159 .596 r
.55545 .7039 .55636 .70929 .55802 .70997 .55714 .70801 Mtetra
.177 .32 .771 r
.55714 .70801 .55802 .70997 .55968 .71026 .55881 .70949 Mtetra
.496 .724 .974 r
.55881 .70949 .55968 .71026 .56133 .71003 .56046 .70945 Mtetra
.615 .819 .979 r
.56046 .70945 .56133 .71003 .56299 .70965 .56212 .70903 Mtetra
.632 .812 .969 r
.56212 .70903 .56299 .70965 .56464 .70926 .56377 .70857 Mtetra
.531 .761 .981 r
.56377 .70857 .56464 .70926 .5663 .70897 .56543 .70841 Mtetra
.633 .83 .976 r
.56543 .70841 .5663 .70897 .56796 .70854 .56709 .70793 Mtetra
.808 .842 .876 r
.56709 .70793 .56796 .70854 .56961 .70776 .56874 .70666 Mtetra
.886 .747 .703 r
.56874 .70666 .56961 .70776 .57126 .70629 .57036 .70324 Mtetra
.871 .655 .608 r
.57036 .70324 .57126 .70629 .5729 .70451 .57192 .69505 Mtetra
.948 .678 .493 r
.57192 .69505 .5729 .70451 .57454 .70282 .57099 .50783 Mtetra
.57 .362 .559 r
.57099 .50783 .57454 .70282 .5762 .70219 .57254 .50638 Mtetra
.567 .36 .559 r
.57254 .50638 .5762 .70219 .57786 .70192 .57412 .50652 Mtetra
.566 .359 .559 r
.57412 .50652 .57786 .70192 .57953 .70172 .57571 .50734 Mtetra
.568 .36 .559 r
.57571 .50734 .57953 .70172 .58119 .70131 .57729 .50703 Mtetra
.57729 .50703 .58119 .70131 .58286 .70089 .57886 .50674 Mtetra
.57886 .50674 .58286 .70089 .58452 .70047 .58044 .50644 Mtetra
.58044 .50644 .58452 .70047 .58619 .70004 .58201 .5061 Mtetra
.58201 .5061 .58619 .70004 .58786 .69961 .58359 .50573 Mtetra
.567 .36 .559 r
.58359 .50573 .58786 .69961 .58953 .6993 .58518 .50566 Mtetra
.565 .358 .559 r
.58518 .50566 .58953 .6993 .59121 .69944 .58679 .50715 Mtetra
.568 .36 .559 r
.58679 .50715 .59121 .69944 .59288 .69899 .58837 .50691 Mtetra
.574 .365 .56 r
.58837 .50691 .59288 .69899 .59452 .69695 .58988 .50281 Mtetra
.576 .367 .56 r
.58988 .50281 .59452 .69695 .59238 .50864 .59137 .49758 Mtetra
.645 .448 .601 r
.59137 .49758 .59238 .50864 .59373 .49679 .5929 .4946 Mtetra
.753 .623 .714 r
.5929 .4946 .59373 .49679 .59525 .49366 .59445 .49274 Mtetra
.706 .751 .887 r
.59445 .49274 .59525 .49366 .59682 .49282 .59602 .49205 Mtetra
.631 .765 .943 r
.59602 .49205 .59682 .49282 .5984 .49247 .5976 .49167 Mtetra
.585 .738 .948 r
.5976 .49167 .5984 .49247 .59999 .49236 .59919 .49143 Mtetra
.619 .722 .919 r
.59919 .49143 .59999 .49236 .60158 .49202 .60077 .49112 Mtetra
.614 .725 .924 r
.60077 .49112 .60158 .49202 .60316 .4917 .60236 .49082 Mtetra
.622 .732 .925 r
.60236 .49082 .60316 .4917 .60475 .49136 .60394 .49048 Mtetra
.653 .744 .916 r
.60394 .49048 .60475 .49136 .60633 .49093 .60553 .49003 Mtetra
.669 .744 .907 r
.60553 .49003 .60633 .49093 .60792 .49045 .60711 .48952 Mtetra
.69 .744 .892 r
.60711 .48952 .60792 .49045 .6095 .4899 .6087 .48891 Mtetra
.747 .747 .852 r
.6087 .48891 .6095 .4899 .61108 .48914 .61027 .48795 Mtetra
.7 .699 .845 r
.61027 .48795 .61108 .48914 .61266 .48847 .61185 .48723 Mtetra
.6 .65 .871 r
.61185 .48723 .61266 .48847 .61425 .48803 .61345 .48703 Mtetra
0 .143 .669 r
.61345 .48703 .61425 .48803 .61585 .48799 .61509 .48853 Mtetra
.874 .494 .32 r
.61509 .48853 .61585 .48799 .61747 .48852 .61681 .49276 Mtetra
.958 .677 .462 r
.61681 .49276 .61747 .48852 .61913 .49033 .6238 .68355 Mtetra
.574 .361 .554 r
.6238 .68355 .61913 .49033 .62621 .67948 .62565 .68842 Mtetra
.616 .358 .504 r
.62565 .68842 .62621 .67948 .62819 .68931 .62741 .6903 Mtetra
.618 .177 .18 r
.62741 .6903 .62819 .68931 .62998 .69181 .62914 .69112 Mtetra
.42 .71 .983 r
.62914 .69112 .62998 .69181 .63169 .69191 .63085 .69118 Mtetra
.64 .792 .955 r
.63085 .69118 .63169 .69191 .63338 .69138 .63255 .69072 Mtetra
.774 .838 .901 r
.63255 .69072 .63338 .69138 .63506 .69039 .63423 .68966 Mtetra
.893 .809 .758 r
.63423 .68966 .63506 .69039 .63675 .68942 .63586 .6871 Mtetra
.856 .669 .649 r
.63586 .6871 .63675 .68942 .63841 .68792 .63742 .68224 Mtetra
.96 .684 .468 r
.63742 .68224 .63841 .68792 .64004 .68539 .63291 .49126 Mtetra
.578 .368 .56 r
.63291 .49126 .64004 .68539 .64134 .67289 .6343 .48449 Mtetra
.572 .364 .559 r
.6343 .48449 .64134 .67289 .63669 .48469 .63583 .48171 Mtetra
.711 .567 .69 r
.63583 .48171 .63669 .48469 .63819 .481 .63739 .48001 Mtetra
.717 .741 .871 r
.63739 .48001 .63819 .481 .63977 .48001 .63899 .47924 Mtetra
.657 .775 .936 r
.63899 .47924 .63977 .48001 .64137 .47956 .64059 .47876 Mtetra
.624 .757 .942 r
.64059 .47876 .64137 .47956 .64299 .47936 .6422 .4784 Mtetra
.772 .762 .844 r
.6422 .4784 .64299 .47936 .64457 .47828 .64378 .47727 Mtetra
.719 .738 .867 r
.64378 .47727 .64457 .47828 .64617 .47755 .64538 .47648 Mtetra
.57 .672 .908 r
.64538 .47648 .64617 .47755 .64779 .47748 .647 .47636 Mtetra
.815 .389 0 r
.647 .47636 .64779 .47748 .64956 .48135 .64876 .48005 Mtetra
.968 .684 .439 r
.64876 .48005 .64956 .48135 .65868 .67718 .65784 .67596 Mtetra
.913 .527 .114 r
.65784 .67596 .65868 .67718 .66063 .6828 .65979 .6819 Mtetra
.067 .445 .878 r
.65979 .6819 .66063 .6828 .66239 .68361 .66156 .68275 Mtetra
.617 .751 .942 r
.66156 .68275 .66239 .68361 .66411 .68324 .66328 .68239 Mtetra
.807 .8 .845 r
.66328 .68239 .66411 .68324 .66579 .68184 .66496 .68098 Mtetra
.936 .77 .65 r
.66496 .68098 .66579 .68184 .66733 .67697 .6665 .67612 Mtetra
.968 .69 .449 r
.6665 .67612 .66733 .67697 .66098 .48079 .6602 .47992 Mtetra
.95 .748 .596 r
.6602 .47992 .66098 .48079 .66234 .474 .66155 .47309 Mtetra
.795 .777 .837 r
.66155 .47309 .66234 .474 .66392 .47271 .66314 .47179 Mtetra
.622 .729 .923 r
.66314 .47179 .66392 .47271 .66554 .47237 .66476 .47146 Mtetra
.474 .664 .946 r
.66476 .47146 .66554 .47237 .66719 .47247 .66641 .47156 Mtetra
.615 .726 .926 r
.66641 .47156 .66719 .47247 .66881 .47215 .66803 .47124 Mtetra
.639 .737 .92 r
.66803 .47124 .66881 .47215 .67044 .47174 .66966 .47084 Mtetra
.651 .744 .917 r
.66966 .47084 .67044 .47174 .67206 .47128 .67128 .47039 Mtetra
.676 .755 .91 r
.67128 .47039 .67206 .47128 .67368 .4707 .6729 .46983 Mtetra
.691 .764 .907 r
.6729 .46983 .67368 .4707 .67529 .47006 .67452 .46921 Mtetra
.702 .771 .905 r
.67452 .46921 .67529 .47006 .67691 .46938 .67614 .46853 Mtetra
.793 .791 .85 r
.67614 .46853 .67691 .46938 .6785 .46819 .67773 .46729 Mtetra
.748 .773 .873 r
.67773 .46729 .6785 .46819 .68011 .4673 .67933 .46636 Mtetra
.593 .712 .926 r
.67933 .46636 .68011 .4673 .68175 .46709 .68097 .46612 Mtetra
.813 .374 0 r
.68097 .46612 .68175 .46709 .68357 .47054 .6828 .46968 Mtetra
.97 .683 .426 r
.6828 .46968 .68357 .47054 .69479 .667 .694 .66658 Mtetra
.92 .527 .209 r
.694 .66658 .69479 .667 .69684 .67297 .69603 .67234 Mtetra
0 .469 .866 r
.69603 .67234 .69684 .67297 .69864 .67384 .69783 .67303 Mtetra
.667 .784 .936 r
.69783 .67303 .69864 .67384 .70038 .6734 .69956 .67247 Mtetra
.787 .787 .852 r
.69956 .67247 .70038 .6734 .70207 .67205 .70126 .67119 Mtetra
.837 .805 .821 r
.70126 .67119 .70207 .67205 .70367 .66886 .70294 .66948 Mtetra
.851 .96 .624 r
.70294 .66948 .70367 .66886 .70497 .65988 .70457 .6669 Mtetra
.253 .056 .409 r
.70457 .6669 .70497 .65988 .69666 .46701 .70608 .66193 Mtetra
.08 0 .45 r
.70608 .66193 .69666 .46701 .69815 .46372 .69772 .46911 Mtetra
0 0 .291 r
.69772 .46911 .69815 .46372 .69973 .46209 .69906 .46295 Mtetra
.792 .905 .504 r
.69906 .46295 .69973 .46209 .70134 .46105 .70058 .4602 Mtetra
.766 .791 .874 r
.70058 .4602 .70134 .46105 .70297 .46042 .70219 .45917 Mtetra
.632 .667 .866 r
.70219 .45917 .70297 .46042 .70462 .46003 .70384 .45881 Mtetra
.57 .645 .885 r
.70384 .45881 .70462 .46003 .70627 .45975 .7055 .45872 Mtetra
.668 .722 .89 r
.7055 .45872 .70627 .45975 .7079 .45903 .70714 .45819 Mtetra
.687 .772 .916 r
.70714 .45819 .7079 .45903 .70953 .45834 .70878 .45758 Mtetra
.621 .77 .951 r
.70878 .45758 .70953 .45834 .71119 .45809 .71043 .4572 Mtetra
.35 .607 .945 r
.71043 .4572 .71119 .45809 .71295 .45974 .71212 .45757 Mtetra
.316 .377 .767 r
.71212 .45757 .71295 .45974 .71504 .46681 .71387 .45889 Mtetra
.405 .291 .61 r
.71387 .45889 .71504 .46681 .72796 .65955 .71575 .46239 Mtetra
.1 .017 .465 r
.71575 .46239 .72796 .65955 .7299 .66231 .72867 .65412 Mtetra
.258 .189 .586 r
.72867 .65412 .7299 .66231 .73173 .6631 .73081 .66005 Mtetra
.277 .304 .709 r
.73081 .66005 .73173 .6631 .73353 .66324 .73272 .66215 Mtetra
.462 .632 .928 r
.73272 .66215 .73353 .66324 .7353 .66291 .73452 .66234 Mtetra
.665 .851 .971 r
.73452 .66234 .7353 .66291 .73705 .66232 .73627 .66172 Mtetra
.739 .86 .937 r
.73627 .66172 .73705 .66232 .7388 .66162 .738 .66082 Mtetra
.61 .769 .956 r
.738 .66082 .7388 .66162 .74058 .66144 .73977 .66045 Mtetra
.571 .708 .935 r
.73977 .66045 .74058 .66144 .74236 .66131 .74156 .66027 Mtetra
.645 .728 .909 r
.74156 .66027 .74236 .66131 .74412 .66069 .74332 .65981 Mtetra
.8 .803 .854 r
.74332 .65981 .74412 .66069 .74575 .65815 .74503 .65845 Mtetra
.909 .979 .71 r
.74503 .65845 .74575 .65815 .7471 .65114 .74667 .65596 Mtetra
.103 0 .322 r
.74667 .65596 .7471 .65114 .73629 .45568 .74817 .65125 Mtetra
.101 .015 .461 r
.74817 .65125 .73629 .45568 .73772 .45168 .73746 .45824 Mtetra
.033 0 .342 r
.73746 .45824 .73772 .45168 .7393 .44995 .73869 .45109 Mtetra
.658 .799 .349 r
.73869 .45109 .7393 .44995 .74093 .44887 .74019 .44816 Mtetra
.8 .833 .877 r
.74019 .44816 .74093 .44887 .74258 .44822 .74181 .44695 Mtetra
.634 .667 .864 r
.74181 .44695 .74258 .44822 .74425 .44784 .74348 .44657 Mtetra
.568 .637 .879 r
.74348 .44657 .74425 .44784 .74593 .44759 .74517 .44649 Mtetra
.604 .686 .9 r
.74517 .44649 .74593 .44759 .7476 .44721 .74686 .44624 Mtetra
.653 .733 .908 r
.74686 .44624 .7476 .44721 .74927 .4467 .74852 .44577 Mtetra
.669 .748 .91 r
.74852 .44577 .74927 .4467 .75093 .44613 .75019 .44523 Mtetra
.722 .772 .892 r
.75019 .44523 .75093 .44613 .75257 .44526 .75184 .44443 Mtetra
.733 .793 .9 r
.75184 .44443 .75257 .44526 .75422 .44438 .75348 .44359 Mtetra
.675 .785 .932 r
.75348 .44359 .75422 .44438 .75589 .44394 .75515 .44301 Mtetra
.438 .645 .945 r
.75515 .44301 .75589 .44394 .75768 .44511 .75687 .44321 Mtetra
.284 .385 .79 r
.75687 .44321 .75768 .44511 .75977 .45038 .75867 .44449 Mtetra
.345 .271 .628 r
.75867 .44449 .75977 .45038 .7756 .64566 .76063 .4479 Mtetra
.121 .036 .477 r
.76063 .4479 .7756 .64566 .77768 .64928 .77631 .64021 Mtetra
.264 .191 .583 r
.77631 .64021 .77768 .64928 .77957 .65021 .77861 .64685 Mtetra
.294 .302 .698 r
.77861 .64685 .77957 .65021 .78141 .65044 .7806 .64912 Mtetra
.35 .525 .888 r
.7806 .64912 .78141 .65044 .78323 .65048 .78247 .64978 Mtetra
.555 .779 .982 r
.78247 .64978 .78323 .65048 .78505 .65027 .78428 .64952 Mtetra
.716 .822 .93 r
.78428 .64952 .78505 .65027 .78682 .64952 .78605 .64872 Mtetra
.816 .829 .86 r
.78605 .64872 .78682 .64952 .78847 .64727 .78777 .64729 Mtetra
.922 .971 .769 r
.78777 .64729 .78847 .64727 .78987 .6416 .78942 .64497 Mtetra
0 0 .225 r
.78942 .64497 .78987 .6416 .77655 .44497 .79094 .6409 Mtetra
.129 .038 .475 r
.79094 .6409 .77655 .44497 .77787 .43969 .77803 .45025 Mtetra
.091 0 .406 r
.77803 .45025 .77787 .43969 .77944 .43774 .77891 .43933 Mtetra
0 0 0 r
.77891 .43933 .77944 .43774 .78107 .43654 .78037 .43602 Mtetra
.848 .889 .868 r
.78037 .43602 .78107 .43654 .78274 .4358 .78198 .43455 Mtetra
.651 .68 .864 r
.78198 .43455 .78274 .4358 .78443 .43536 .78367 .43408 Mtetra
.583 .643 .876 r
.78367 .43408 .78443 .43536 .78614 .43506 .78539 .43393 Mtetra
.601 .68 .897 r
.78539 .43393 .78614 .43506 .78784 .43468 .7871 .43369 Mtetra
.66 .735 .905 r
.7871 .43369 .78784 .43468 .78952 .43413 .78879 .43318 Mtetra
.674 .748 .907 r
.78879 .43318 .78952 .43413 .79121 .43354 .79048 .43261 Mtetra
.741 .776 .881 r
.79048 .43261 .79121 .43354 .79287 .43263 .79214 .43169 Mtetra
.762 .779 .868 r
.79214 .43169 .79287 .43263 .79452 .43162 .79379 .43065 Mtetra
.662 .74 .908 r
.79379 .43065 .79452 .43162 .79621 .43112 .79548 .43013 Mtetra
0 .275 .776 r
.79548 .43013 .79621 .43112 .79806 .43249 .79734 .43153 Mtetra
.958 .617 .26 r
.79734 .43153 .79806 .43249 .80085 .44487 .80034 .44656 Mtetra
.973 .672 .381 r
.80034 .44656 .80085 .44487 .81899 .63771 .81825 .63711 Mtetra
.594 .073 0 r
.81825 .63711 .81899 .63771 .82103 .63993 .82029 .63923 Mtetra
.595 .798 .977 r
.82029 .63923 .82103 .63993 .82286 .63962 .82211 .63885 Mtetra
.747 .827 .913 r
.82211 .63885 .82286 .63962 .82464 .63874 .82388 .63788 Mtetra
.67 .784 .935 r
.82388 .63788 .82464 .63874 .82645 .63818 .82569 .63728 Mtetra
.482 .691 .96 r
.82569 .63728 .82645 .63818 .82831 .6382 .82756 .63732 Mtetra
.642 .767 .939 r
.82756 .63732 .82831 .6382 .83013 .6377 .82937 .63683 Mtetra
.889 .82 .773 r
.82937 .63683 .83013 .6377 .83178 .63536 .83103 .63445 Mtetra
.978 .741 .509 r
.83103 .63445 .83178 .63536 .83273 .62506 .83189 .62325 Mtetra
.977 .681 .384 r
.83189 .62325 .83273 .62506 .81688 .42794 .81613 .42663 Mtetra
.888 .748 .7 r
.81613 .42663 .81688 .42794 .81834 .42467 .8176 .42347 Mtetra
.678 .701 .864 r
.8176 .42347 .81834 .42467 .82003 .424 .8193 .42285 Mtetra
.541 .649 .905 r
.8193 .42285 .82003 .424 .82178 .42393 .82105 .42284 Mtetra
.549 .666 .914 r
.82105 .42284 .82178 .42393 .82352 .42376 .82281 .42278 Mtetra
.677 .746 .903 r
.82281 .42278 .82352 .42376 .82522 .42304 .82451 .42219 Mtetra
.626 .756 .94 r
.82451 .42219 .82522 .42304 .82694 .4227 .82624 .42179 Mtetra
.436 .651 .95 r
.82624 .42179 .82694 .4227 .82879 .42362 .82802 .42198 Mtetra
.199 .364 .804 r
.82802 .42198 .82879 .42362 .83109 .42928 .82991 .4234 Mtetra
.308 .248 .626 r
.82991 .4234 .83109 .42928 .85141 .62515 .83206 .42739 Mtetra
.147 .061 .492 r
.83206 .42739 .85141 .62515 .85367 .6292 .85226 .62132 Mtetra
.276 .21 .6 r
.85226 .62132 .85367 .6292 .85567 .63045 .8547 .62718 Mtetra
.37 .358 .715 r
.8547 .62718 .85567 .63045 .85756 .63051 .85675 .62897 Mtetra
.679 .665 .829 r
.85675 .62897 .85756 .63051 .85929 .6289 .85857 .62825 Mtetra
.977 .803 .601 r
.85857 .62825 .85929 .6289 .86057 .62274 .85992 .62272 Mtetra
.978 .68 .364 r
.85992 .62272 .86057 .62274 .84283 .42246 .84217 .422 Mtetra
.985 .813 .589 r
.84217 .422 .84283 .42246 .84413 .41766 .84343 .4167 Mtetra
.758 .779 .87 r
.84343 .4167 .84413 .41766 .84581 .41666 .8451 .41566 Mtetra
.627 .723 .916 r
.8451 .41566 .84581 .41666 .84755 .41631 .84684 .41529 Mtetra
.62 .714 .913 r
.84684 .41529 .84755 .41631 .8493 .41604 .84859 .41494 Mtetra
.726 .742 .864 r
.84859 .41494 .8493 .41604 .85101 .41529 .85028 .41406 Mtetra
.67 .696 .865 r
.85028 .41406 .85101 .41529 .85272 .41468 .852 .41348 Mtetra
.502 .621 .901 r
.852 .41348 .85272 .41468 .85446 .41427 .8538 .41362 Mtetra
0 .019 .514 r
.8538 .41362 .85446 .41427 .85624 .41417 .85577 .41551 Mtetra
.884 .507 .32 r
.85577 .41551 .85624 .41417 .85807 .41469 .85822 .42191 Mtetra
.97 .662 .371 r
.85822 .42191 .85807 .41469 .86012 .41717 .87996 .61512 Mtetra
.572 .359 .554 r
.87996 .61512 .86012 .41717 .88231 .61326 .88226 .61889 Mtetra
.621 .335 .461 r
.88226 .61889 .88231 .61326 .88491 .61998 .88433 .62047 Mtetra
.493 0 0 r
.88433 .62047 .88491 .61998 .88701 .62185 .88629 .62102 Mtetra
.567 .755 .966 r
.88629 .62102 .88701 .62185 .8889 .62165 .88817 .62077 Mtetra
.712 .8 .92 r
.88817 .62077 .8889 .62165 .89072 .62083 .89 .61996 Mtetra
.826 .83 .851 r
.89 .61996 .89072 .62083 .89251 .61968 .89174 .61841 Mtetra
.893 .768 .717 r
.89174 .61841 .89251 .61968 .8943 .6186 .89332 .61532 Mtetra
.872 .652 .602 r
.89332 .61532 .8943 .6186 .89604 .61693 .8945 .60851 Mtetra
.973 .67 .375 r
.8945 .60851 .89604 .61693 .89757 .61342 .87528 .4133 Mtetra
.575 .365 .559 r
.87528 .4133 .89757 .61342 .87802 .41656 .87654 .40838 Mtetra
.653 .462 .613 r
.87654 .40838 .87802 .41656 .87892 .40824 .87807 .40586 Mtetra
.722 .605 .725 r
.87807 .40586 .87892 .40824 .88041 .40542 .87971 .40438 Mtetra
.662 .731 .901 r
.87971 .40438 .88041 .40542 .88213 .4047 .88146 .40385 Mtetra
.575 .737 .953 r
.88146 .40385 .88213 .4047 .88391 .40448 .88324 .40362 Mtetra
.556 .726 .953 r
.88324 .40362 .88391 .40448 .88571 .40442 .88502 .40345 Mtetra
.656 .745 .915 r
.88502 .40345 .88571 .40442 .88746 .40392 .88677 .40294 Mtetra
.673 .749 .907 r
.88677 .40294 .88746 .40392 .88921 .40337 .88852 .40235 Mtetra
.706 .754 .889 r
.88852 .40235 .88921 .40337 .89094 .40267 .89024 .4016 Mtetra
.775 .766 .845 r
.89024 .4016 .89094 .40267 .89262 .40153 .89192 .40039 Mtetra
.705 .729 .869 r
.89192 .40039 .89262 .40153 .89435 .40082 .89364 .39962 Mtetra
.468 .603 .903 r
.89364 .39962 .89435 .40082 .8962 .40113 .89549 .39988 Mtetra
.757 .361 0 r
.89549 .39988 .8962 .40113 .89867 .4068 .89793 .40529 Mtetra
.973 .662 .313 r
.89793 .40529 .89867 .4068 .92379 .60712 .92307 .6061 Mtetra
.691 .257 0 r
.92307 .6061 .92379 .60712 .92619 .61107 .92549 .61019 Mtetra
.527 .724 .964 r
.92549 .61019 .92619 .61107 .92812 .61097 .92741 .61008 Mtetra
.721 .805 .916 r
.92741 .61008 .92812 .61097 .92996 .61013 .92925 .60922 Mtetra
.766 .813 .89 r
.92925 .60922 .92996 .61013 .93177 .60903 .93106 .6081 Mtetra
.51 .702 .957 r
.93106 .6081 .93177 .60903 .93371 .60898 .933 .60807 Mtetra
.628 .763 .944 r
.933 .60807 .93371 .60898 .9356 .60851 .9349 .60762 Mtetra
.814 .828 .861 r
.9349 .60762 .9356 .60851 .93737 .60703 .93667 .60615 Mtetra
.984 .773 .538 r
.93667 .60615 .93737 .60703 .93841 .59951 .93771 .59865 Mtetra
.976 .67 .325 r
.93771 .59865 .93841 .59951 .91596 .39855 .91527 .39751 Mtetra
.955 .783 .629 r
.91527 .39751 .91596 .39855 .91723 .39397 .91655 .39292 Mtetra
.723 .756 .878 r
.91655 .39292 .91723 .39397 .91895 .39309 .91828 .39206 Mtetra
.574 .697 .925 r
.91828 .39206 .91895 .39309 .92076 .39287 .92009 .39188 Mtetra
.467 .65 .938 r
.92009 .39188 .92076 .39287 .92261 .39299 .92194 .39204 Mtetra
.643 .747 .924 r
.92194 .39204 .92261 .39299 .92439 .39253 .92372 .39157 Mtetra
.656 .752 .92 r
.92372 .39157 .92439 .39253 .92616 .39202 .9255 .39105 Mtetra
.67 .755 .914 r
.9255 .39105 .92616 .39202 .92793 .39146 .92727 .39047 Mtetra
.762 .784 .871 r
.92727 .39047 .92793 .39146 .92964 .39039 .92897 .3894 Mtetra
.694 .758 .901 r
.92897 .3894 .92964 .39039 .9314 .3897 .93073 .3887 Mtetra
.501 .665 .936 r
.93073 .3887 .9314 .3897 .93325 .38977 .93258 .38876 Mtetra
.749 .331 0 r
.93258 .38876 .93325 .38977 .93572 .39468 .93505 .39368 Mtetra
.97 .655 .291 r
.93505 .39368 .93572 .39468 .9633 .59526 .9626 .5943 Mtetra
.732 .3 0 r
.9626 .5943 .9633 .59526 .96587 .59994 .96517 .59898 Mtetra
.046 .472 .884 r
.35099 .76532 .35193 .76609 .35342 .7667 .35247 .76593 Mtetra
.645 .762 .934 r
.35247 .76593 .35342 .7667 .35495 .76629 .354 .76551 Mtetra
.809 .778 .824 r
.354 .76551 .35495 .76629 .35653 .76485 .35559 .76408 Mtetra
.908 .737 .659 r
.35559 .76408 .35653 .76485 .35829 .75959 .35735 .75882 Mtetra
.937 .686 .534 r
.35735 .75882 .35829 .75959 .36861 .56851 .36772 .56769 Mtetra
.909 .727 .645 r
.36772 .56769 .36861 .56851 .37031 .5628 .36942 .56197 Mtetra
.777 .76 .837 r
.36942 .56197 .37031 .5628 .37179 .56169 .37091 .56086 Mtetra
.641 .736 .918 r
.37091 .56086 .37179 .56169 .37324 .56132 .37236 .56049 Mtetra
.508 .691 .95 r
.37236 .56049 .37324 .56132 .37468 .56132 .37379 .56049 Mtetra
.745 .758 .862 r
.37379 .56049 .37468 .56132 .37615 .56045 .37527 .55962 Mtetra
.695 .75 .893 r
.37527 .55962 .37615 .56045 .37762 .55986 .37673 .55903 Mtetra
.477 .679 .954 r
.37673 .55903 .37762 .55986 .37905 .55991 .37817 .55909 Mtetra
.927 .548 .254 r
.37817 .55909 .37905 .55991 .38032 .56391 .37944 .56309 Mtetra
.939 .683 .522 r
.37944 .56309 .38032 .56391 .37372 .75435 .37277 .7536 Mtetra
.933 .578 .324 r
.37277 .7536 .37372 .75435 .37502 .75951 .37408 .75874 Mtetra
0 .337 .784 r
.37408 .75874 .37502 .75951 .37652 .76033 .37558 .75957 Mtetra
.618 .757 .945 r
.37558 .75957 .37652 .76033 .37806 .76 .37712 .75923 Mtetra
.801 .783 .836 r
.37712 .75923 .37806 .76 .37965 .75866 .37871 .7579 Mtetra
.907 .745 .67 r
.37871 .7579 .37965 .75866 .38137 .75393 .38043 .7532 Mtetra
.939 .687 .529 r
.38043 .7532 .38137 .75393 .39049 .56276 .3896 .56205 Mtetra
.92 .731 .631 r
.3896 .56205 .39049 .56276 .39219 .55632 .39131 .55553 Mtetra
.798 .769 .826 r
.39131 .55553 .39219 .55632 .39369 .55505 .39281 .55424 Mtetra
.624 .739 .929 r
.39281 .55424 .39369 .55505 .39515 .55474 .39427 .55393 Mtetra
.445 .67 .959 r
.39427 .55393 .39515 .55474 .3966 .55486 .39572 .55404 Mtetra
.603 .729 .934 r
.39572 .55404 .3966 .55486 .39806 .55462 .39718 .55379 Mtetra
.631 .735 .923 r
.39718 .55379 .39806 .55462 .39952 .55429 .39864 .55345 Mtetra
.638 .734 .918 r
.39864 .55345 .39952 .55429 .40099 .55395 .40011 .55309 Mtetra
.657 .736 .908 r
.40011 .55309 .40099 .55395 .40246 .55353 .40158 .55266 Mtetra
.668 .736 .901 r
.40158 .55266 .40246 .55353 .40393 .55307 .40305 .55218 Mtetra
.673 .735 .897 r
.40305 .55218 .40393 .55307 .4054 .55257 .40453 .55168 Mtetra
.676 .734 .894 r
.40453 .55168 .4054 .55257 .40688 .55207 .406 .55118 Mtetra
.678 .734 .893 r
.406 .55118 .40688 .55207 .40835 .55155 .40748 .55066 Mtetra
.679 .735 .893 r
.40748 .55066 .40835 .55155 .40983 .55101 .40896 .55013 Mtetra
.677 .737 .896 r
.40896 .55013 .40983 .55101 .41131 .55049 .41044 .54962 Mtetra
.678 .739 .897 r
.41044 .54962 .41131 .55049 .41279 .54995 .41191 .5491 Mtetra
.68 .744 .899 r
.41191 .5491 .41279 .54995 .41427 .54938 .41339 .54857 Mtetra
.686 .755 .904 r
.41339 .54857 .41427 .54938 .41575 .54872 .41488 .54802 Mtetra
.689 .783 .923 r
.41488 .54802 .41575 .54872 .41724 .54803 .41636 .54746 Mtetra
.686 .817 .946 r
.41636 .54746 .41724 .54803 .41873 .54736 .41784 .5469 Mtetra
.689 .848 .959 r
.41784 .5469 .41873 .54736 .42022 .54662 .41933 .54631 Mtetra
.658 .885 .981 r
.41933 .54631 .42022 .54662 .4217 .54601 .42081 .54575 Mtetra
.604 .887 .99 r
.42081 .54575 .4217 .54601 .42318 .5457 .4223 .54528 Mtetra
.669 .859 .972 r
.4223 .54528 .42318 .5457 .42463 .54616 .42378 .54473 Mtetra
.625 .624 .829 r
.42378 .54473 .42463 .54616 .42606 .54762 .42526 .54443 Mtetra
.541 .452 .704 r
.42526 .54443 .42606 .54762 .42742 .55146 .42672 .54474 Mtetra
.304 .217 .59 r
.42672 .54474 .42742 .55146 .42358 .73843 .42809 .54839 Mtetra
0 0 .346 r
.42809 .54839 .42358 .73843 .42499 .74381 .42418 .73889 Mtetra
0 0 .456 r
.42418 .73889 .42499 .74381 .42649 .74581 .42559 .74421 Mtetra
.297 .441 .837 r
.42559 .74421 .42649 .74581 .42805 .74612 .42713 .74505 Mtetra
.635 .699 .892 r
.42713 .74505 .42805 .74612 .42962 .74571 .42871 .74469 Mtetra
.715 .73 .862 r
.42871 .74469 .42962 .74571 .43121 .74504 .4303 .74391 Mtetra
.668 .699 .87 r
.4303 .74391 .43121 .74504 .43278 .74468 .43188 .7434 Mtetra
.643 .664 .856 r
.43188 .7434 .43278 .74468 .43436 .74436 .43346 .74299 Mtetra
.656 .657 .839 r
.43346 .74299 .43436 .74436 .43595 .74376 .43504 .74251 Mtetra
.642 .669 .861 r
.43504 .74251 .43595 .74376 .43755 .74237 .43662 .74212 Mtetra
.644 .906 .982 r
.43662 .74212 .43755 .74237 .43918 .73993 .43821 .74151 Mtetra
.088 0 .001 r
.43821 .74151 .43918 .73993 .44086 .73532 .43981 .74027 Mtetra
.013 0 .243 r
.43981 .74027 .44086 .73532 .44679 .54744 .44149 .73585 Mtetra
0 0 .339 r
.44149 .73585 .44679 .54744 .44843 .54069 .44747 .5442 Mtetra
.757 .752 .237 r
.44747 .5442 .44843 .54069 .44998 .53787 .4491 .5378 Mtetra
.896 .918 .828 r
.4491 .5378 .44998 .53787 .45149 .53663 .45063 .53601 Mtetra
.679 .804 .942 r
.45063 .53601 .45149 .53663 .45299 .53612 .45213 .53547 Mtetra
.529 .753 .978 r
.45213 .53547 .45299 .53612 .45449 .5359 .45362 .53534 Mtetra
.569 .794 .984 r
.45362 .53534 .45449 .5359 .45598 .53567 .45512 .53508 Mtetra
.632 .803 .965 r
.45512 .53508 .45598 .53567 .45748 .5354 .45662 .53468 Mtetra
.644 .77 .94 r
.45662 .53468 .45748 .5354 .45898 .5351 .45812 .53427 Mtetra
.66 .747 .915 r
.45812 .53427 .45898 .5351 .46048 .53463 .45962 .53382 Mtetra
.669 .755 .915 r
.45962 .53382 .46048 .53463 .46198 .53402 .46112 .53333 Mtetra
.67 .785 .936 r
.46112 .53333 .46198 .53402 .46349 .53339 .46263 .53283 Mtetra
.657 .819 .961 r
.46263 .53283 .46349 .53339 .465 .53284 .46414 .53234 Mtetra
.645 .836 .974 r
.46414 .53234 .465 .53284 .4665 .53235 .46564 .53187 Mtetra
.642 .84 .976 r
.46564 .53187 .4665 .53235 .46801 .53188 .46715 .53141 Mtetra
.643 .841 .976 r
.46715 .53141 .46801 .53188 .46952 .53141 .46866 .53094 Mtetra
.643 .843 .977 r
.46866 .53094 .46952 .53141 .47103 .53092 .47017 .53046 Mtetra
.642 .846 .978 r
.47017 .53046 .47103 .53092 .47254 .53044 .47168 .52999 Mtetra
.655 .851 .975 r
.47168 .52999 .47254 .53044 .47405 .52984 .47319 .52948 Mtetra
.642 .873 .984 r
.47319 .52948 .47405 .52984 .47556 .52925 .4747 .52896 Mtetra
.593 .882 .992 r
.4747 .52896 .47556 .52925 .47707 .52889 .47621 .52851 Mtetra
.514 .829 1 r
.47621 .52851 .47707 .52889 .47857 .52935 .47772 .52825 Mtetra
.566 .656 .897 r
.47772 .52825 .47857 .52935 .48005 .53095 .47923 .52816 Mtetra
.584 .496 .722 r
.47923 .52816 .48005 .53095 .48152 .53408 .48074 .5281 Mtetra
.589 .432 .637 r
.48074 .5281 .48152 .53408 .48299 .53786 .48225 .52784 Mtetra
.587 .408 .606 r
.48225 .52784 .48299 .53786 .4845 .53803 .48377 .52735 Mtetra
.588 .406 .603 r
.48377 .52735 .4845 .53803 .48604 .53607 .48529 .5268 Mtetra
.591 .413 .609 r
.48529 .5268 .48604 .53607 .48757 .53473 .48681 .52626 Mtetra
.591 .417 .614 r
.48681 .52626 .48757 .53473 .48909 .53412 .48833 .52576 Mtetra
.591 .418 .615 r
.48833 .52576 .48909 .53412 .49062 .53351 .48985 .52527 Mtetra
.592 .418 .616 r
.48985 .52527 .49062 .53351 .49214 .53294 .49137 .52478 Mtetra
.592 .419 .616 r
.49137 .52478 .49214 .53294 .49367 .5324 .49289 .5243 Mtetra
.592 .419 .617 r
.49289 .5243 .49367 .5324 .4952 .53188 .49441 .52382 Mtetra
.49441 .52382 .4952 .53188 .49672 .53137 .49594 .52334 Mtetra
.592 .42 .617 r
.49594 .52334 .49672 .53137 .49825 .53087 .49746 .52286 Mtetra
.49746 .52286 .49825 .53087 .49978 .53037 .49899 .52238 Mtetra
.592 .42 .618 r
.49899 .52238 .49978 .53037 .50131 .52988 .50051 .5219 Mtetra
.50051 .5219 .50131 .52988 .50284 .52939 .50204 .52143 Mtetra
.50204 .52143 .50284 .52939 .50437 .52891 .50357 .52095 Mtetra
.50357 .52095 .50437 .52891 .5059 .52843 .5051 .52048 Mtetra
.5051 .52048 .5059 .52843 .50743 .52795 .50663 .52 Mtetra
.50663 .52 .50743 .52795 .50896 .52748 .50816 .51953 Mtetra
.50816 .51953 .50896 .52748 .5105 .52701 .50969 .51905 Mtetra
.50969 .51905 .5105 .52701 .51203 .52654 .51122 .51858 Mtetra
.51122 .51858 .51203 .52654 .51357 .52607 .51275 .51811 Mtetra
.51275 .51811 .51357 .52607 .5151 .52561 .51429 .51764 Mtetra
.51429 .51764 .5151 .52561 .51664 .52516 .51582 .51717 Mtetra
.591 .42 .618 r
.51582 .51717 .51664 .52516 .51818 .52471 .51736 .5167 Mtetra
.51736 .5167 .51818 .52471 .51972 .52427 .51889 .51623 Mtetra
.591 .419 .617 r
.51889 .51623 .51972 .52427 .52126 .52383 .52043 .51577 Mtetra
.52043 .51577 .52126 .52383 .5228 .5234 .52197 .5153 Mtetra
.52197 .5153 .5228 .5234 .52434 .52298 .52351 .51484 Mtetra
.591 .418 .617 r
.52351 .51484 .52434 .52298 .52588 .52256 .52505 .51438 Mtetra
.591 .418 .616 r
.52505 .51438 .52588 .52256 .52743 .52214 .52659 .51392 Mtetra
.52659 .51392 .52743 .52214 .52897 .52173 .52813 .51346 Mtetra
.59 .418 .616 r
.52813 .51346 .52897 .52173 .53052 .52132 .52967 .51299 Mtetra
.59 .417 .615 r
.52967 .51299 .53052 .52132 .53206 .52091 .53122 .51253 Mtetra
.53122 .51253 .53206 .52091 .53361 .5205 .53276 .51207 Mtetra
.53276 .51207 .53361 .5205 .53516 .52008 .5343 .5116 Mtetra
.59 .416 .614 r
.5343 .5116 .53516 .52008 .53671 .51966 .53585 .51113 Mtetra
.53585 .51113 .53671 .51966 .53826 .51924 .5374 .51066 Mtetra
.5374 .51066 .53826 .51924 .53981 .51882 .53895 .51018 Mtetra
.59 .416 .613 r
.53895 .51018 .53981 .51882 .54136 .51835 .54049 .50969 Mtetra
.591 .416 .613 r
.54049 .50969 .54136 .51835 .54291 .51782 .54204 .50919 Mtetra
.592 .417 .614 r
.54204 .50919 .54291 .51782 .54446 .51718 .54359 .50867 Mtetra
.592 .418 .614 r
.54359 .50867 .54446 .51718 .54602 .51651 .54514 .50814 Mtetra
.598 .423 .615 r
.54514 .50814 .54602 .51651 .54757 .51535 .54669 .50744 Mtetra
.607 .432 .619 r
.54669 .50744 .54757 .51535 .54912 .51373 .54824 .50654 Mtetra
.593 .426 .624 r
.54824 .50654 .54912 .51373 .55067 .51326 .5498 .50609 Mtetra
.527 .379 .623 r
.5498 .50609 .55067 .51326 .55226 .5171 .55136 .50706 Mtetra
.093 .047 .508 r
.55136 .50706 .55226 .5171 .55545 .7039 .553 .51581 Mtetra
0 0 .401 r
.553 .51581 .55545 .7039 .55714 .70801 .55625 .70589 Mtetra
0 0 .566 r
.55625 .70589 .55714 .70801 .55881 .70949 .55793 .70869 Mtetra
.497 .713 .968 r
.55793 .70869 .55881 .70949 .56046 .70945 .55959 .70866 Mtetra
.687 .785 .925 r
.55959 .70866 .56046 .70945 .56212 .70903 .56125 .70804 Mtetra
.689 .741 .89 r
.56125 .70804 .56212 .70903 .56377 .70857 .5629 .7074 Mtetra
.556 .654 .901 r
.5629 .7074 .56377 .70857 .56543 .70841 .56456 .70734 Mtetra
.662 .716 .888 r
.56456 .70734 .56543 .70841 .56709 .70793 .56622 .70683 Mtetra
.817 .747 .787 r
.56622 .70683 .56709 .70793 .56874 .70666 .56786 .70505 Mtetra
.91 .707 .615 r
.56786 .70505 .56874 .70666 .57036 .70324 .56944 .69784 Mtetra
.954 .684 .487 r
.56944 .69784 .57036 .70324 .57192 .69505 .56856 .50416 Mtetra
.574 .365 .559 r
.56856 .50416 .57192 .69505 .57099 .50783 .57008 .50005 Mtetra
.607 .432 .62 r
.57008 .50005 .57099 .50783 .57254 .50638 .57164 .49918 Mtetra
.585 .42 .625 r
.57164 .49918 .57254 .50638 .57412 .50652 .57321 .49893 Mtetra
.576 .411 .621 r
.57321 .49893 .57412 .50652 .57571 .50734 .57478 .49888 Mtetra
.589 .416 .615 r
.57478 .49888 .57571 .50734 .57729 .50703 .57635 .49844 Mtetra
.588 .415 .614 r
.57635 .49844 .57729 .50703 .57886 .50674 .57792 .498 Mtetra
.588 .414 .613 r
.57792 .498 .57886 .50674 .58044 .50644 .57949 .49757 Mtetra
.588 .413 .612 r
.57949 .49757 .58044 .50644 .58201 .5061 .58106 .49712 Mtetra
.58106 .49712 .58201 .5061 .58359 .50573 .58264 .49666 Mtetra
.588 .412 .611 r
.58264 .49666 .58359 .50573 .58518 .50566 .58421 .49622 Mtetra
.585 .409 .609 r
.58421 .49622 .58518 .50566 .58679 .50715 .58579 .49584 Mtetra
.584 .401 .601 r
.58579 .49584 .58679 .50715 .58837 .50691 .58736 .49541 Mtetra
.587 .404 .6 r
.58736 .49541 .58837 .50691 .58988 .50281 .58894 .49482 Mtetra
.606 .431 .618 r
.58894 .49482 .58988 .50281 .59137 .49758 .5905 .49393 Mtetra
.645 .507 .681 r
.5905 .49393 .59137 .49758 .5929 .4946 .59207 .49304 Mtetra
.693 .646 .798 r
.59207 .49304 .5929 .4946 .59445 .49274 .59365 .49226 Mtetra
.644 .851 .979 r
.59365 .49226 .59445 .49274 .59602 .49205 .59523 .49175 Mtetra
.563 .877 .993 r
.59523 .49175 .59602 .49205 .5976 .49167 .59681 .49132 Mtetra
.562 .864 .996 r
.59681 .49132 .5976 .49167 .59919 .49143 .59839 .49093 Mtetra
.618 .835 .983 r
.59839 .49093 .59919 .49143 .60077 .49112 .59997 .4905 Mtetra
.637 .807 .965 r
.59997 .4905 .60077 .49112 .60236 .49082 .60156 .49006 Mtetra
.653 .774 .938 r
.60156 .49006 .60236 .49082 .60394 .49048 .60314 .48959 Mtetra
.671 .748 .908 r
.60314 .48959 .60394 .49048 .60553 .49003 .60472 .48907 Mtetra
.674 .733 .894 r
.60472 .48907 .60553 .49003 .60711 .48952 .60631 .48853 Mtetra
.685 .73 .885 r
.60631 .48853 .60711 .48952 .6087 .48891 .60789 .48794 Mtetra
.745 .751 .857 r
.60789 .48794 .6087 .48891 .61027 .48795 .60947 .487 Mtetra
.683 .739 .893 r
.60947 .487 .61027 .48795 .61185 .48723 .61105 .48642 Mtetra
.407 .657 .961 r
.61105 .48642 .61185 .48723 .61345 .48703 .61266 .48661 Mtetra
.899 .484 .169 r
.61266 .48661 .61345 .48703 .61509 .48853 .61437 .49059 Mtetra
.961 .68 .458 r
.61437 .49059 .61509 .48853 .61681 .49276 .62131 .68458 Mtetra
.575 .362 .554 r
.62131 .68458 .61681 .49276 .6238 .68355 .62316 .69001 Mtetra
.581 .314 .477 r
.62316 .69001 .6238 .68355 .62565 .68842 .62489 .6906 Mtetra
.494 .144 .301 r
.62489 .6906 .62565 .68842 .62741 .6903 .62659 .69045 Mtetra
.292 .788 .775 r
.62659 .69045 .62741 .6903 .62914 .69112 .62829 .68994 Mtetra
.541 .649 .905 r
.62829 .68994 .62914 .69112 .63085 .69118 .63 .68993 Mtetra
.645 .68 .869 r
.63 .68993 .63085 .69118 .63255 .69072 .63169 .68949 Mtetra
.756 .722 .821 r
.63169 .68949 .63255 .69072 .63423 .68966 .63337 .68831 Mtetra
.904 .729 .655 r
.63337 .68831 .63423 .68966 .63586 .6871 .63493 .68349 Mtetra
.962 .687 .465 r
.63493 .68349 .63586 .6871 .63742 .68224 .63044 .4888 Mtetra
.579 .369 .56 r
.63044 .4888 .63742 .68224 .63291 .49126 .63183 .48164 Mtetra
.617 .431 .608 r
.63183 .48164 .63291 .49126 .6343 .48449 .6334 .48015 Mtetra
.626 .481 .665 r
.6334 .48015 .6343 .48449 .63583 .48171 .63499 .4794 Mtetra
.624 .549 .75 r
.63499 .4794 .63583 .48171 .63739 .48001 .6366 .47901 Mtetra
.68 .729 .887 r
.6366 .47901 .63739 .48001 .63899 .47924 .6382 .47844 Mtetra
.665 .77 .928 r
.6382 .47844 .63899 .47924 .64059 .47876 .6398 .47793 Mtetra
.658 .761 .926 r
.6398 .47793 .64059 .47876 .6422 .4784 .64141 .47745 Mtetra
.755 .761 .858 r
.64141 .47745 .6422 .4784 .64378 .47727 .643 .47645 Mtetra
.701 .778 .911 r
.643 .47645 .64378 .47727 .64538 .47648 .6446 .47579 Mtetra
.464 .722 .981 r
.6446 .47579 .64538 .47648 .647 .47636 .64622 .47579 Mtetra
.891 .466 .11 r
.64622 .47579 .647 .47636 .64876 .48005 .648 .47976 Mtetra
.967 .683 .441 r
.648 .47976 .64876 .48005 .65784 .67596 .65703 .67557 Mtetra
.919 .527 .224 r
.65703 .67557 .65784 .67596 .65979 .6819 .65896 .68104 Mtetra
.064 .45 .88 r
.65896 .68104 .65979 .6819 .66156 .68275 .66073 .68186 Mtetra
.617 .745 .937 r
.66073 .68186 .66156 .68275 .66328 .68239 .66245 .6815 Mtetra
.802 .793 .844 r
.66245 .6815 .66328 .68239 .66496 .68098 .66413 .68012 Mtetra
.936 .77 .651 r
.66413 .68012 .66496 .68098 .6665 .67612 .66567 .67527 Mtetra
.968 .69 .449 r
.66567 .67527 .6665 .67612 .6602 .47992 .65941 .47904 Mtetra
.95 .748 .596 r
.65941 .47904 .6602 .47992 .66155 .47309 .66077 .47218 Mtetra
.796 .778 .837 r
.66077 .47218 .66155 .47309 .66314 .47179 .66236 .47088 Mtetra
.623 .729 .923 r
.66236 .47088 .66314 .47179 .66476 .47146 .66398 .47054 Mtetra
.475 .664 .945 r
.66398 .47054 .66476 .47146 .66641 .47156 .66563 .47064 Mtetra
.615 .725 .924 r
.66563 .47064 .66641 .47156 .66803 .47124 .66725 .47032 Mtetra
.638 .734 .918 r
.66725 .47032 .66803 .47124 .66966 .47084 .66888 .46992 Mtetra
.649 .739 .915 r
.66888 .46992 .66966 .47084 .67128 .47039 .67051 .46948 Mtetra
.675 .75 .908 r
.67051 .46948 .67128 .47039 .6729 .46983 .67213 .46893 Mtetra
.688 .755 .903 r
.67213 .46893 .6729 .46983 .67452 .46921 .67375 .46832 Mtetra
.694 .76 .903 r
.67375 .46832 .67452 .46921 .67614 .46853 .67536 .46768 Mtetra
.777 .789 .862 r
.67536 .46768 .67614 .46853 .67773 .46729 .67696 .46656 Mtetra
.736 .81 .91 r
.67696 .46656 .67773 .46729 .67933 .46636 .67857 .46573 Mtetra
.511 .766 .988 r
.67857 .46573 .67933 .46636 .68097 .46612 .68022 .46559 Mtetra
.87 .427 .056 r
.68022 .46559 .68097 .46612 .6828 .46968 .68204 .46922 Mtetra
.97 .682 .427 r
.68204 .46922 .6828 .46968 .694 .66658 .69317 .66546 Mtetra
.901 .504 .083 r
.69317 .66546 .694 .66658 .69603 .67234 .6952 .67111 Mtetra
.319 .524 .897 r
.6952 .67111 .69603 .67234 .69783 .67303 .69699 .67176 Mtetra
.654 .686 .868 r
.69699 .67176 .69783 .67303 .69956 .67247 .69873 .67126 Mtetra
.735 .726 .842 r
.69873 .67126 .69956 .67247 .70126 .67119 .70044 .67027 Mtetra
.66 .755 .921 r
.70044 .67027 .70126 .67119 .70294 .66948 .70218 .66974 Mtetra
.292 .776 .695 r
.70218 .66974 .70294 .66948 .70457 .6669 .70391 .66906 Mtetra
.269 0 .214 r
.70391 .66906 .70457 .6669 .70608 .66193 .70561 .6677 Mtetra
.138 0 .351 r
.70561 .6677 .70608 .66193 .69772 .46911 .70711 .66254 Mtetra
.06 0 .443 r
.70711 .66254 .69772 .46911 .69906 .46295 .69849 .46588 Mtetra
0 0 0 r
.69849 .46588 .69906 .46295 .70058 .4602 .69985 .45996 Mtetra
.87 .94 .862 r
.69985 .45996 .70058 .4602 .70219 .45917 .70143 .45838 Mtetra
.661 .776 .934 r
.70143 .45838 .70219 .45917 .70384 .45881 .70307 .45787 Mtetra
.559 .698 .934 r
.70307 .45787 .70384 .45881 .7055 .45872 .70473 .45774 Mtetra
.644 .726 .908 r
.70473 .45774 .7055 .45872 .70714 .45819 .70638 .45732 Mtetra
.67 .759 .918 r
.70638 .45732 .70714 .45819 .70878 .45758 .70802 .45678 Mtetra
.653 .772 .936 r
.70802 .45678 .70878 .45758 .71043 .4572 .70967 .4563 Mtetra
.686 .758 .906 r
.70967 .4563 .71043 .4572 .71212 .45757 .71131 .45569 Mtetra
.632 .588 .787 r
.71131 .45569 .71212 .45757 .71387 .45889 .71296 .45529 Mtetra
.559 .456 .694 r
.71296 .45529 .71387 .45889 .71575 .46239 .71465 .45548 Mtetra
.383 .284 .617 r
.71465 .45548 .71575 .46239 .72867 .65412 .71652 .45884 Mtetra
.081 .004 .459 r
.71652 .45884 .72867 .65412 .73081 .66005 .72973 .65447 Mtetra
.043 .069 .562 r
.72973 .65447 .73081 .66005 .73272 .66215 .73186 .66038 Mtetra
.359 .46 .828 r
.73186 .66038 .73272 .66215 .73452 .66234 .73371 .66127 Mtetra
.644 .72 .904 r
.73371 .66127 .73452 .66234 .73627 .66172 .73547 .66082 Mtetra
.732 .786 .896 r
.73547 .66082 .73627 .66172 .738 .66082 .73721 .65993 Mtetra
.669 .77 .926 r
.73721 .65993 .738 .66082 .73977 .66045 .73896 .65936 Mtetra
.631 .711 .904 r
.73896 .65936 .73977 .66045 .74156 .66027 .74073 .65896 Mtetra
.646 .679 .867 r
.74073 .65896 .74156 .66027 .74332 .65981 .7425 .6585 Mtetra
.633 .673 .87 r
.7425 .6585 .74332 .65981 .74503 .65845 .74427 .6581 Mtetra
.621 .899 .986 r
.74427 .6581 .74503 .65845 .74667 .65596 .74603 .65748 Mtetra
.165 0 .072 r
.74603 .65748 .74667 .65596 .74817 .65125 .74775 .65623 Mtetra
.163 0 .346 r
.74775 .65623 .74817 .65125 .73746 .45824 .74927 .65186 Mtetra
.081 0 .455 r
.74927 .65186 .73746 .45824 .73869 .45109 .73826 .45508 Mtetra
0 0 .098 r
.73826 .45508 .73869 .45109 .74019 .44816 .7395 .44809 Mtetra
.905 .967 .811 r
.7395 .44809 .74019 .44816 .74181 .44695 .74107 .44616 Mtetra
.67 .783 .934 r
.74107 .44616 .74181 .44695 .74348 .44657 .74273 .44561 Mtetra
.558 .695 .932 r
.74273 .44561 .74348 .44657 .74517 .44649 .74442 .44549 Mtetra
.602 .705 .916 r
.74442 .44549 .74517 .44649 .74686 .44624 .7461 .44522 Mtetra
.65 .723 .902 r
.7461 .44522 .74686 .44624 .74852 .44577 .74777 .44477 Mtetra
.655 .729 .903 r
.74777 .44477 .74852 .44577 .75019 .44523 .74944 .44429 Mtetra
.68 .751 .905 r
.74944 .44429 .75019 .44523 .75184 .44443 .75111 .4437 Mtetra
.69 .806 .937 r
.75111 .4437 .75184 .44443 .75348 .44359 .75277 .44306 Mtetra
.658 .855 .975 r
.75277 .44306 .75348 .44359 .75515 .44301 .75443 .44248 Mtetra
.666 .857 .972 r
.75443 .44248 .75515 .44301 .75687 .44321 .7561 .44188 Mtetra
.641 .662 .854 r
.7561 .44188 .75687 .44321 .75867 .44449 .75778 .44146 Mtetra
.56 .477 .719 r
.75778 .44146 .75867 .44449 .76063 .4479 .7595 .44162 Mtetra
.409 .31 .63 r
.7595 .44162 .76063 .4479 .77631 .64021 .76142 .4444 Mtetra
.104 .024 .472 r
.76142 .4444 .77631 .64021 .77861 .64685 .77742 .64031 Mtetra
.081 .085 .561 r
.77742 .64031 .77861 .64685 .7806 .64912 .77974 .64711 Mtetra
.28 .384 .791 r
.77974 .64711 .7806 .64912 .78247 .64978 .78166 .64849 Mtetra
.606 .666 .882 r
.78166 .64849 .78247 .64978 .78428 .64952 .78347 .64822 Mtetra
.701 .705 .85 r
.78347 .64822 .78428 .64952 .78605 .64872 .78524 .64743 Mtetra
.683 .699 .858 r
.78524 .64743 .78605 .64872 .78777 .64729 .78702 .64675 Mtetra
.652 .861 .979 r
.78702 .64675 .78777 .64729 .78942 .64497 .7888 .64614 Mtetra
.078 0 0 r
.7888 .64614 .78942 .64497 .79094 .6409 .79055 .64495 Mtetra
.176 0 .325 r
.79055 .64495 .79094 .6409 .77803 .45025 .79211 .6414 Mtetra
.098 .016 .465 r
.79211 .6414 .77803 .45025 .77891 .43933 .77877 .44607 Mtetra
0 0 .271 r
.77877 .44607 .77891 .43933 .78037 .43602 .77973 .43621 Mtetra
.922 .975 .712 r
.77973 .43621 .78037 .43602 .78198 .43455 .78127 .43379 Mtetra
.696 .805 .933 r
.78127 .43379 .78198 .43455 .78367 .43408 .78294 .43312 Mtetra
.58 .71 .931 r
.78294 .43312 .78367 .43408 .78539 .43393 .78466 .43292 Mtetra
.598 .704 .918 r
.78466 .43292 .78539 .43393 .7871 .43369 .78637 .43266 Mtetra
.66 .727 .9 r
.78637 .43266 .7871 .43369 .78879 .43318 .78806 .43216 Mtetra
.662 .729 .899 r
.78806 .43216 .78879 .43318 .79048 .43261 .78975 .43164 Mtetra
.72 .761 .885 r
.78975 .43164 .79048 .43261 .79214 .43169 .79142 .43084 Mtetra
.745 .794 .892 r
.79142 .43084 .79214 .43169 .79379 .43065 .79308 .42992 Mtetra
.625 .788 .96 r
.79308 .42992 .79379 .43065 .79548 .43013 .79478 .4295 Mtetra
0 .127 .604 r
.79478 .4295 .79548 .43013 .79734 .43153 .79664 .43097 Mtetra
.96 .622 .291 r
.79664 .43097 .79734 .43153 .80034 .44656 .79977 .44738 Mtetra
.974 .673 .377 r
.79977 .44738 .80034 .44656 .81825 .63711 .81746 .63584 Mtetra
0 .124 .67 r
.81746 .63584 .81825 .63711 .82029 .63923 .8195 .63799 Mtetra
.603 .675 .891 r
.8195 .63799 .82029 .63923 .82211 .63885 .82133 .63772 Mtetra
.714 .742 .873 r
.82133 .63772 .82211 .63885 .82388 .63788 .82312 .63688 Mtetra
.669 .751 .911 r
.82312 .63688 .82388 .63788 .82569 .63728 .82493 .63629 Mtetra
.541 .699 .942 r
.82493 .63629 .82569 .63728 .82756 .63732 .82678 .63619 Mtetra
.674 .727 .89 r
.82678 .63619 .82756 .63732 .82937 .63683 .82859 .63558 Mtetra
.86 .76 .751 r
.82859 .63558 .82937 .63683 .83103 .63445 .83023 .63311 Mtetra
.968 .728 .521 r
.83023 .63311 .83103 .63445 .83189 .62325 .8311 .62186 Mtetra
.977 .681 .382 r
.8311 .62186 .83189 .62325 .81613 .42663 .81544 .42599 Mtetra
.944 .834 .704 r
.81544 .42599 .81613 .42663 .8176 .42347 .81691 .42279 Mtetra
.706 .833 .943 r
.81691 .42279 .8176 .42347 .8193 .42285 .8186 .42206 Mtetra
.541 .738 .967 r
.8186 .42206 .8193 .42285 .82105 .42284 .82034 .42191 Mtetra
.55 .705 .942 r
.82034 .42191 .82105 .42284 .82281 .42278 .82209 .42179 Mtetra
.655 .736 .909 r
.82209 .42179 .82281 .42278 .82451 .42219 .8238 .4213 Mtetra
.637 .752 .932 r
.8238 .4213 .82451 .42219 .82624 .42179 .82552 .42087 Mtetra
.633 .742 .927 r
.82552 .42087 .82624 .42179 .82802 .42198 .82725 .42046 Mtetra
.626 .629 .834 r
.82725 .42046 .82802 .42198 .82991 .4234 .82898 .42011 Mtetra
.558 .468 .709 r
.82898 .42011 .82991 .4234 .83206 .42739 .83077 .4203 Mtetra
.439 .324 .626 r
.83077 .4203 .83206 .42739 .85226 .62132 .83279 .42305 Mtetra
.136 .053 .489 r
.83279 .42305 .85226 .62132 .8547 .62718 .8535 .62156 Mtetra
.176 .167 .609 r
.8535 .62156 .8547 .62718 .85675 .62897 .85589 .6268 Mtetra
.539 .528 .791 r
.85589 .6268 .85675 .62897 .85857 .62825 .85779 .62702 Mtetra
.944 .76 .623 r
.85779 .62702 .85857 .62825 .85992 .62272 .85916 .62166 Mtetra
.977 .679 .368 r
.85916 .62166 .85992 .62272 .84217 .422 .84147 .4211 Mtetra
.963 .778 .606 r
.84147 .4211 .84217 .422 .84343 .4167 .84272 .41574 Mtetra
.76 .781 .87 r
.84272 .41574 .84343 .4167 .8451 .41566 .8444 .41469 Mtetra
.635 .733 .919 r
.8444 .41469 .8451 .41566 .84684 .41529 .84613 .41428 Mtetra
.639 .726 .911 r
.84613 .41428 .84684 .41529 .84859 .41494 .84787 .41385 Mtetra
.744 .749 .856 r
.84787 .41385 .84859 .41494 .85028 .41406 .84955 .41285 Mtetra
.664 .697 .871 r
.84955 .41285 .85028 .41406 .852 .41348 .85128 .41231 Mtetra
.315 .519 .895 r
.85128 .41231 .852 .41348 .8538 .41362 .85313 .413 Mtetra
.885 .472 .053 r
.85313 .413 .8538 .41362 .85577 .41551 .85551 .41883 Mtetra
.973 .665 .357 r
.85551 .41883 .85577 .41551 .85822 .42191 .87758 .61662 Mtetra
.572 .359 .553 r
.87758 .61662 .85822 .42191 .87996 .61512 .87986 .62029 Mtetra
.565 .284 .448 r
.87986 .62029 .87996 .61512 .88226 .61889 .8818 .6206 Mtetra
.436 .056 .217 r
.8818 .6206 .88226 .61889 .88433 .62047 .88367 .62025 Mtetra
.48 .878 .959 r
.88367 .62025 .88433 .62047 .88629 .62102 .88552 .61975 Mtetra
.578 .66 .894 r
.88552 .61975 .88629 .62102 .88817 .62077 .88742 .6196 Mtetra
.676 .723 .885 r
.88742 .6196 .88817 .62077 .89 .61996 .88926 .61896 Mtetra
.841 .803 .814 r
.88926 .61896 .89 .61996 .89174 .61841 .89098 .61713 Mtetra
.958 .754 .586 r
.89098 .61713 .89174 .61841 .89332 .61532 .89219 .61058 Mtetra
.976 .673 .363 r
.89219 .61058 .89332 .61532 .8945 .60851 .87264 .41104 Mtetra
.575 .365 .559 r
.87264 .41104 .8945 .60851 .87528 .4133 .87392 .40617 Mtetra
.625 .449 .625 r
.87392 .40617 .87528 .4133 .87654 .40838 .87557 .40485 Mtetra
.63 .505 .692 r
.87557 .40485 .87654 .40838 .87807 .40586 .8773 .40416 Mtetra
.631 .613 .813 r
.8773 .40416 .87807 .40586 .87971 .40438 .87906 .40376 Mtetra
.623 .826 .978 r
.87906 .40376 .87971 .40438 .88146 .40385 .88081 .40328 Mtetra
.588 .829 .99 r
.88081 .40328 .88146 .40385 .88324 .40362 .88257 .40288 Mtetra
.62 .791 .964 r
.88257 .40288 .88324 .40362 .88502 .40345 .88433 .40246 Mtetra
.67 .746 .908 r
.88433 .40246 .88502 .40345 .88677 .40294 .88608 .40189 Mtetra
.677 .736 .895 r
.88608 .40189 .88677 .40294 .88852 .40235 .88782 .40128 Mtetra
.697 .741 .885 r
.88782 .40128 .88852 .40235 .89024 .4016 .88955 .40057 Mtetra
.758 .771 .864 r
.88955 .40057 .89024 .4016 .89192 .40039 .89125 .39951 Mtetra
.686 .78 .922 r
.89125 .39951 .89192 .40039 .89364 .39962 .89299 .39886 Mtetra
.32 .629 .961 r
.89299 .39886 .89364 .39962 .89549 .39988 .89484 .39921 Mtetra
.851 .426 0 r
.89484 .39921 .89549 .39988 .89793 .40529 .89728 .40458 Mtetra
.973 .662 .316 r
.89728 .40458 .89793 .40529 .92307 .6061 .92231 .60473 Mtetra
0 0 .385 r
.92231 .60473 .92307 .6061 .92549 .61019 .92473 .60885 Mtetra
.545 .632 .889 r
.92473 .60885 .92549 .61019 .92741 .61008 .92667 .60885 Mtetra
.688 .721 .874 r
.92667 .60885 .92741 .61008 .92925 .60922 .92852 .60813 Mtetra
.733 .764 .878 r
.92852 .60813 .92925 .60922 .93106 .6081 .93035 .60716 Mtetra
.503 .697 .956 r
.93035 .60716 .93106 .6081 .933 .60807 .9323 .60715 Mtetra
.625 .761 .944 r
.9323 .60715 .933 .60807 .9349 .60762 .93419 .60672 Mtetra
.808 .825 .864 r
.93419 .60672 .9349 .60762 .93667 .60615 .93597 .6053 Mtetra
.983 .781 .556 r
.93597 .6053 .93667 .60615 .93771 .59865 .9371 .59851 Mtetra
.976 .67 .322 r
.9371 .59851 .93771 .59865 .91527 .39751 .91469 .39723 Mtetra
.996 .844 .572 r
.91469 .39723 .91527 .39751 .91655 .39292 .91592 .3923 Mtetra
.755 .874 .934 r
.91592 .3923 .91655 .39292 .91828 .39206 .91764 .39133 Mtetra
.573 .776 .975 r
.91764 .39133 .91828 .39206 .92009 .39188 .91944 .39105 Mtetra
.475 .696 .965 r
.91944 .39105 .92009 .39188 .92194 .39204 .92128 .39109 Mtetra
.651 .751 .923 r
.92128 .39109 .92194 .39204 .92372 .39157 .92305 .39059 Mtetra
.659 .746 .914 r
.92305 .39059 .92372 .39157 .9255 .39105 .92483 .39006 Mtetra
.67 .748 .909 r
.92483 .39006 .9255 .39105 .92727 .39047 .9266 .38948 Mtetra
.763 .783 .87 r
.9266 .38948 .92727 .39047 .92897 .3894 .9283 .38839 Mtetra
.695 .757 .899 r
.9283 .38839 .92897 .3894 .93073 .3887 .93006 .38769 Mtetra
.503 .665 .935 r
.93006 .38769 .93073 .3887 .93258 .38876 .93191 .38775 Mtetra
.747 .33 0 r
.93191 .38775 .93258 .38876 .93505 .39368 .93438 .39266 Mtetra
.97 .655 .291 r
.93438 .39266 .93505 .39368 .9626 .5943 .96191 .59334 Mtetra
.73 .299 0 r
.96191 .59334 .9626 .5943 .96517 .59898 .96448 .59802 Mtetra
.047 .471 .884 r
.35004 .76454 .35099 .76532 .35247 .76593 .35152 .76515 Mtetra
.645 .761 .934 r
.35152 .76515 .35247 .76593 .354 .76551 .35305 .76474 Mtetra
.809 .778 .824 r
.35305 .76474 .354 .76551 .35559 .76408 .35464 .7633 Mtetra
.908 .737 .659 r
.35464 .7633 .35559 .76408 .35735 .75882 .3564 .75804 Mtetra
.937 .686 .534 r
.3564 .75804 .35735 .75882 .36772 .56769 .36683 .56686 Mtetra
.908 .727 .645 r
.36683 .56686 .36772 .56769 .36942 .56197 .36853 .56114 Mtetra
.777 .76 .837 r
.36853 .56114 .36942 .56197 .37091 .56086 .37002 .56003 Mtetra
.641 .736 .918 r
.37002 .56003 .37091 .56086 .37236 .56049 .37147 .55966 Mtetra
.508 .691 .95 r
.37147 .55966 .37236 .56049 .37379 .56049 .37291 .55966 Mtetra
.745 .757 .862 r
.37291 .55966 .37379 .56049 .37527 .55962 .37438 .55879 Mtetra
.695 .749 .893 r
.37438 .55879 .37527 .55962 .37673 .55903 .37585 .5582 Mtetra
.477 .678 .954 r
.37585 .5582 .37673 .55903 .37817 .55909 .37728 .55826 Mtetra
.928 .549 .255 r
.37728 .55826 .37817 .55909 .37944 .56309 .37855 .56227 Mtetra
.939 .683 .522 r
.37855 .56227 .37944 .56309 .37277 .7536 .37183 .75284 Mtetra
.933 .578 .322 r
.37183 .75284 .37277 .7536 .37408 .75874 .37314 .75797 Mtetra
0 .339 .785 r
.37314 .75797 .37408 .75874 .37558 .75957 .37464 .75879 Mtetra
.617 .757 .945 r
.37464 .75879 .37558 .75957 .37712 .75923 .37618 .75846 Mtetra
.801 .782 .836 r
.37618 .75846 .37712 .75923 .37871 .7579 .37777 .75714 Mtetra
.906 .745 .67 r
.37777 .75714 .37871 .7579 .38043 .7532 .37949 .75246 Mtetra
.939 .687 .529 r
.37949 .75246 .38043 .7532 .3896 .56205 .38871 .56129 Mtetra
.918 .729 .63 r
.38871 .56129 .3896 .56205 .39131 .55553 .39043 .55471 Mtetra
.797 .765 .824 r
.39043 .55471 .39131 .55553 .39281 .55424 .39193 .55342 Mtetra
.626 .735 .925 r
.39193 .55342 .39281 .55424 .39427 .55393 .39339 .5531 Mtetra
.456 .67 .955 r
.39339 .5531 .39427 .55393 .39572 .55404 .39483 .5532 Mtetra
.607 .725 .928 r
.39483 .5532 .39572 .55404 .39718 .55379 .3963 .55294 Mtetra
.637 .732 .917 r
.3963 .55294 .39718 .55379 .39864 .55345 .39776 .55258 Mtetra
.65 .732 .909 r
.39776 .55258 .39864 .55345 .40011 .55309 .39923 .55218 Mtetra
.683 .731 .887 r
.39923 .55218 .40011 .55309 .40158 .55266 .40071 .55163 Mtetra
.691 .711 .863 r
.40071 .55163 .40158 .55266 .40305 .55218 .40219 .55103 Mtetra
.688 .687 .843 r
.40219 .55103 .40305 .55218 .40453 .55168 .40367 .55041 Mtetra
.673 .665 .833 r
.40367 .55041 .40453 .55168 .406 .55118 .40514 .54987 Mtetra
.667 .657 .83 r
.40514 .54987 .406 .55118 .40748 .55066 .40662 .54935 Mtetra
.665 .656 .831 r
.40662 .54935 .40748 .55066 .40896 .55013 .4081 .54884 Mtetra
.667 .659 .833 r
.4081 .54884 .40896 .55013 .41044 .54962 .40958 .54833 Mtetra
.665 .659 .834 r
.40958 .54833 .41044 .54962 .41191 .5491 .41105 .54783 Mtetra
.662 .661 .838 r
.41105 .54783 .41191 .5491 .41339 .54857 .41253 .54735 Mtetra
.65 .664 .85 r
.41253 .54735 .41339 .54857 .41488 .54802 .41401 .54694 Mtetra
.647 .687 .873 r
.41401 .54694 .41488 .54802 .41636 .54746 .41549 .54655 Mtetra
.649 .722 .902 r
.41549 .54655 .41636 .54746 .41784 .5469 .41697 .54614 Mtetra
.664 .765 .925 r
.41697 .54614 .41784 .5469 .41933 .54631 .41845 .54568 Mtetra
.674 .799 .942 r
.41845 .54568 .41933 .54631 .42081 .54575 .41993 .54516 Mtetra
.681 .813 .946 r
.41993 .54516 .42081 .54575 .4223 .54528 .42142 .54462 Mtetra
.756 .803 .891 r
.42142 .54462 .4223 .54528 .42378 .54473 .42291 .54374 Mtetra
.719 .725 .855 r
.42291 .54374 .42378 .54473 .42526 .54443 .42441 .54298 Mtetra
.624 .62 .826 r
.42441 .54298 .42526 .54443 .42672 .54474 .42589 .54268 Mtetra
.112 .25 .728 r
.42589 .54268 .42672 .54474 .42809 .54839 .42732 .54428 Mtetra
0 0 .168 r
.42732 .54428 .42809 .54839 .42418 .73889 .4286 .55081 Mtetra
0 0 .346 r
.4286 .55081 .42418 .73889 .42559 .74421 .42478 .73936 Mtetra
.287 .239 .628 r
.42478 .73936 .42559 .74421 .42713 .74505 .42627 .74211 Mtetra
.466 .422 .725 r
.42627 .74211 .42713 .74505 .42871 .74469 .42781 .7429 Mtetra
.532 .547 .816 r
.42781 .7429 .42871 .74469 .4303 .74391 .42938 .74307 Mtetra
.574 .727 .947 r
.42938 .74307 .4303 .74391 .43188 .7434 .43095 .74288 Mtetra
.616 .828 .982 r
.43095 .74288 .43188 .7434 .43346 .74299 .43253 .74246 Mtetra
.663 .835 .966 r
.43253 .74246 .43346 .74299 .43504 .74251 .43411 .74192 Mtetra
.533 .783 .989 r
.43411 .74192 .43504 .74251 .43662 .74212 .43569 .74173 Mtetra
.49 .822 .999 r
.43569 .74173 .43662 .74212 .43821 .74151 .43727 .74149 Mtetra
.604 .939 .946 r
.43727 .74149 .43821 .74151 .43981 .74027 .43886 .74079 Mtetra
.943 .959 .732 r
.43886 .74079 .43981 .74027 .44149 .73585 .4405 .73813 Mtetra
.991 .857 .501 r
.4405 .73813 .44149 .73585 .44747 .5442 .44225 .73044 Mtetra
0 0 .339 r
.44225 .73044 .44747 .5442 .4491 .5378 .44815 .5408 Mtetra
.018 0 .163 r
.44815 .5408 .4491 .5378 .45063 .53601 .4497 .53814 Mtetra
.435 .092 .284 r
.4497 .53814 .45063 .53601 .45213 .53547 .4512 .53766 Mtetra
.508 .168 .325 r
.4512 .53766 .45213 .53547 .45362 .53534 .45269 .53757 Mtetra
.284 0 .223 r
.45269 .53757 .45362 .53534 .45512 .53508 .45421 .5364 Mtetra
0 0 0 r
.45421 .5364 .45512 .53508 .45662 .53468 .45574 .53476 Mtetra
.843 .977 .874 r
.45574 .53476 .45662 .53468 .45812 .53427 .45726 .53337 Mtetra
.736 .749 .863 r
.45726 .53337 .45812 .53427 .45962 .53382 .45877 .53253 Mtetra
.662 .66 .838 r
.45877 .53253 .45962 .53382 .46112 .53333 .46028 .53204 Mtetra
.64 .652 .846 r
.46028 .53204 .46112 .53333 .46263 .53283 .46178 .53167 Mtetra
.649 .676 .862 r
.46178 .53167 .46263 .53283 .46414 .53234 .46328 .53125 Mtetra
.66 .693 .87 r
.46328 .53125 .46414 .53234 .46564 .53187 .46479 .5308 Mtetra
.66 .695 .872 r
.46479 .5308 .46564 .53187 .46715 .53141 .4663 .53034 Mtetra
.662 .698 .873 r
.4663 .53034 .46715 .53141 .46866 .53094 .46781 .52987 Mtetra
.46781 .52987 .46866 .53094 .47017 .53046 .46932 .5294 Mtetra
.659 .698 .875 r
.46932 .5294 .47017 .53046 .47168 .52999 .47083 .52895 Mtetra
.647 .698 .883 r
.47083 .52895 .47168 .52999 .47319 .52948 .47234 .52855 Mtetra
.638 .719 .906 r
.47234 .52855 .47319 .52948 .4747 .52896 .47385 .52818 Mtetra
.64 .755 .932 r
.47385 .52818 .4747 .52896 .47621 .52851 .47536 .52779 Mtetra
.67 .781 .932 r
.47536 .52779 .47621 .52851 .47772 .52825 .47687 .52729 Mtetra
.69 .729 .88 r
.47687 .52729 .47772 .52825 .47923 .52816 .47839 .52669 Mtetra
.675 .642 .809 r
.47839 .52669 .47923 .52816 .48074 .5281 .4799 .52608 Mtetra
.652 .579 .761 r
.4799 .52608 .48074 .5281 .48225 .52784 .48142 .52552 Mtetra
.639 .553 .742 r
.48142 .52552 .48225 .52784 .48377 .52735 .48294 .52502 Mtetra
.636 .55 .741 r
.48294 .52502 .48377 .52735 .48529 .5268 .48446 .52453 Mtetra
.637 .555 .745 r
.48446 .52453 .48529 .5268 .48681 .52626 .48598 .52404 Mtetra
.638 .559 .749 r
.48598 .52404 .48681 .52626 .48833 .52576 .48749 .52356 Mtetra
.48749 .52356 .48833 .52576 .48985 .52527 .48901 .52307 Mtetra
.638 .56 .75 r
.48901 .52307 .48985 .52527 .49137 .52478 .49054 .52259 Mtetra
.638 .56 .751 r
.49054 .52259 .49137 .52478 .49289 .5243 .49206 .52211 Mtetra
.638 .561 .751 r
.49206 .52211 .49289 .5243 .49441 .52382 .49358 .52163 Mtetra
.49358 .52163 .49441 .52382 .49594 .52334 .4951 .52115 Mtetra
.638 .561 .752 r
.4951 .52115 .49594 .52334 .49746 .52286 .49663 .52068 Mtetra
.49663 .52068 .49746 .52286 .49899 .52238 .49815 .5202 Mtetra
.49815 .5202 .49899 .52238 .50051 .5219 .49968 .51972 Mtetra
.49968 .51972 .50051 .5219 .50204 .52143 .50121 .51925 Mtetra
.50121 .51925 .50204 .52143 .50357 .52095 .50273 .51877 Mtetra
.50273 .51877 .50357 .52095 .5051 .52048 .50426 .51829 Mtetra
.50426 .51829 .5051 .52048 .50663 .52 .50579 .51782 Mtetra
.50579 .51782 .50663 .52 .50816 .51953 .50732 .51734 Mtetra
.637 .561 .752 r
.50732 .51734 .50816 .51953 .50969 .51905 .50885 .51687 Mtetra
.50885 .51687 .50969 .51905 .51122 .51858 .51039 .51639 Mtetra
.51039 .51639 .51122 .51858 .51275 .51811 .51192 .51592 Mtetra
.51192 .51592 .51275 .51811 .51429 .51764 .51345 .51545 Mtetra
.51345 .51545 .51429 .51764 .51582 .51717 .51499 .51498 Mtetra
.51499 .51498 .51582 .51717 .51736 .5167 .51652 .51451 Mtetra
.636 .56 .752 r
.51652 .51451 .51736 .5167 .51889 .51623 .51806 .51404 Mtetra
.51806 .51404 .51889 .51623 .52043 .51577 .5196 .51357 Mtetra
.5196 .51357 .52043 .51577 .52197 .5153 .52113 .51311 Mtetra
.52113 .51311 .52197 .5153 .52351 .51484 .52267 .51265 Mtetra
.635 .56 .753 r
.52267 .51265 .52351 .51484 .52505 .51438 .52421 .51219 Mtetra
.52421 .51219 .52505 .51438 .52659 .51392 .52575 .51173 Mtetra
.52575 .51173 .52659 .51392 .52813 .51346 .5273 .51127 Mtetra
.636 .561 .753 r
.5273 .51127 .52813 .51346 .52967 .51299 .52884 .51081 Mtetra
.52884 .51081 .52967 .51299 .53122 .51253 .53038 .51034 Mtetra
.53038 .51034 .53122 .51253 .53276 .51207 .53193 .50988 Mtetra
.53193 .50988 .53276 .51207 .5343 .5116 .53347 .50941 Mtetra
.637 .561 .753 r
.53347 .50941 .5343 .5116 .53585 .51113 .53502 .50894 Mtetra
.637 .561 .752 r
.53502 .50894 .53585 .51113 .5374 .51066 .53656 .50846 Mtetra
.638 .561 .752 r
.53656 .50846 .5374 .51066 .53895 .51018 .53811 .50798 Mtetra
.638 .561 .751 r
.53811 .50798 .53895 .51018 .54049 .50969 .53966 .50749 Mtetra
.64 .562 .751 r
.53966 .50749 .54049 .50969 .54204 .50919 .54121 .50698 Mtetra
.642 .563 .75 r
.54121 .50698 .54204 .50919 .54359 .50867 .54276 .50646 Mtetra
.642 .563 .751 r
.54276 .50646 .54359 .50867 .54514 .50814 .54431 .50594 Mtetra
.659 .573 .747 r
.54431 .50594 .54514 .50814 .54669 .50744 .54586 .50526 Mtetra
.679 .585 .743 r
.54586 .50526 .54669 .50744 .54824 .50654 .54741 .5044 Mtetra
.634 .563 .758 r
.54741 .5044 .54824 .50654 .5498 .50609 .54896 .50395 Mtetra
.404 .431 .775 r
.54896 .50395 .5498 .50609 .55136 .50706 .55053 .50481 Mtetra
.896 .555 .071 r
.55053 .50481 .55136 .50706 .553 .51581 .55214 .51134 Mtetra
.964 .69 .467 r
.55214 .51134 .553 .51581 .55625 .70589 .55538 .70508 Mtetra
.849 .398 0 r
.55538 .70508 .55625 .70589 .55793 .70869 .55707 .70824 Mtetra
.441 .79 .998 r
.55707 .70824 .55793 .70869 .55959 .70866 .55872 .7081 Mtetra
.73 .851 .938 r
.55872 .7081 .55959 .70866 .56125 .70804 .56038 .70728 Mtetra
.729 .801 .909 r
.56038 .70728 .56125 .70804 .5629 .7074 .56203 .70647 Mtetra
.523 .692 .945 r
.56203 .70647 .5629 .7074 .56456 .70734 .56369 .70643 Mtetra
.665 .751 .914 r
.56369 .70643 .56456 .70734 .56622 .70683 .56535 .70591 Mtetra
.846 .776 .783 r
.56535 .70591 .56622 .70683 .56786 .70505 .56699 .7039 Mtetra
.942 .718 .572 r
.56699 .7039 .56786 .70505 .56944 .69784 .56852 .69285 Mtetra
.954 .685 .487 r
.56852 .69285 .56944 .69784 .56856 .50416 .56771 .50127 Mtetra
.791 .615 .662 r
.56771 .50127 .56856 .50416 .57008 .50005 .56924 .49782 Mtetra
.673 .579 .741 r
.56924 .49782 .57008 .50005 .57164 .49918 .5708 .49699 Mtetra
.612 .549 .759 r
.5708 .49699 .57164 .49918 .57321 .49893 .57237 .49672 Mtetra
.589 .534 .761 r
.57237 .49672 .57321 .49893 .57478 .49888 .57394 .49661 Mtetra
.631 .554 .749 r
.57394 .49661 .57478 .49888 .57635 .49844 .57551 .49616 Mtetra
.57551 .49616 .57635 .49844 .57792 .498 .57708 .49572 Mtetra
.631 .553 .749 r
.57708 .49572 .57792 .498 .57949 .49757 .57865 .49528 Mtetra
.633 .554 .748 r
.57865 .49528 .57949 .49757 .58106 .49712 .58023 .49482 Mtetra
.58023 .49482 .58106 .49712 .58264 .49666 .5818 .49436 Mtetra
.633 .553 .747 r
.5818 .49436 .58264 .49666 .58421 .49622 .58337 .4939 Mtetra
.633 .552 .746 r
.58337 .4939 .58421 .49622 .58579 .49584 .58495 .49344 Mtetra
.63 .545 .741 r
.58495 .49344 .58579 .49584 .58736 .49541 .58652 .49299 Mtetra
.626 .543 .741 r
.58652 .49299 .58736 .49541 .58894 .49482 .5881 .49258 Mtetra
.62 .55 .754 r
.5881 .49258 .58894 .49482 .5905 .49393 .58968 .49223 Mtetra
.626 .599 .803 r
.58968 .49223 .5905 .49393 .59207 .49304 .59126 .4919 Mtetra
.633 .681 .877 r
.59126 .4919 .59207 .49304 .59365 .49226 .59284 .49155 Mtetra
.64 .781 .949 r
.59284 .49155 .59365 .49226 .59523 .49175 .59442 .49112 Mtetra
.648 .807 .959 r
.59442 .49112 .59523 .49175 .59681 .49132 .596 .49065 Mtetra
.666 .801 .947 r
.596 .49065 .59681 .49132 .59839 .49093 .59758 .49013 Mtetra
.688 .775 .917 r
.59758 .49013 .59839 .49093 .59997 .4905 .59916 .48953 Mtetra
.689 .737 .888 r
.59916 .48953 .59997 .4905 .60156 .49006 .60074 .48892 Mtetra
.686 .703 .86 r
.60074 .48892 .60156 .49006 .60314 .48959 .60233 .4883 Mtetra
.688 .678 .835 r
.60233 .4883 .60314 .48959 .60472 .48907 .60391 .48764 Mtetra
.664 .649 .824 r
.60391 .48764 .60472 .48907 .60631 .48853 .60549 .48709 Mtetra
.629 .632 .835 r
.60549 .48709 .60631 .48853 .60789 .48794 .60708 .48675 Mtetra
.55 .637 .89 r
.60708 .48675 .60789 .48794 .60947 .487 .60868 .48673 Mtetra
0 .379 .686 r
.60868 .48673 .60947 .487 .61105 .48642 .6103 .48726 Mtetra
.751 .332 .255 r
.6103 .48726 .61105 .48642 .61266 .48661 .61195 .48908 Mtetra
.96 .68 .46 r
.61195 .48908 .61266 .48661 .61437 .49059 .61863 .67862 Mtetra
.581 .366 .554 r
.61863 .67862 .61437 .49059 .62131 .68458 .62059 .68822 Mtetra
.691 .381 .445 r
.62059 .68822 .62131 .68458 .62316 .69001 .62236 .69068 Mtetra
.405 0 0 r
.62236 .69068 .62316 .69001 .62489 .6906 .62407 .69077 Mtetra
.306 .796 .77 r
.62407 .69077 .62489 .6906 .62659 .69045 .62576 .69022 Mtetra
.747 .945 .946 r
.62576 .69022 .62659 .69045 .62829 .68994 .62744 .68922 Mtetra
.757 .822 .903 r
.62744 .68922 .62829 .68994 .63 .68993 .62913 .68824 Mtetra
.759 .67 .764 r
.62913 .68824 .63 .68993 .63169 .68949 .63079 .68671 Mtetra
.77 .613 .685 r
.63079 .68671 .63169 .68949 .63337 .68831 .63242 .68402 Mtetra
.961 .686 .468 r
.63242 .68402 .63337 .68831 .63493 .68349 .62854 .5045 Mtetra
.604 .388 .561 r
.62854 .5045 .63493 .68349 .63044 .4888 .62948 .48266 Mtetra
.706 .513 .625 r
.62948 .48266 .63044 .4888 .63183 .48164 .63099 .47923 Mtetra
.668 .567 .733 r
.63099 .47923 .63183 .48164 .6334 .48015 .63258 .4784 Mtetra
.62 .592 .8 r
.63258 .4784 .6334 .48015 .63499 .4794 .63418 .47809 Mtetra
.565 .623 .869 r
.63418 .47809 .63499 .4794 .6366 .47901 .6358 .47804 Mtetra
.705 .742 .88 r
.6358 .47804 .6366 .47901 .6382 .47844 .6374 .47734 Mtetra
.691 .713 .865 r
.6374 .47734 .6382 .47844 .6398 .47793 .639 .47669 Mtetra
.655 .676 .858 r
.639 .47669 .6398 .47793 .64141 .47745 .64061 .47622 Mtetra
.574 .642 .88 r
.64061 .47622 .64141 .47745 .643 .47645 .64223 .47612 Mtetra
0 .513 .822 r
.64223 .47612 .643 .47645 .6446 .47579 .64387 .47651 Mtetra
.704 .255 .182 r
.64387 .47651 .6446 .47579 .64622 .47579 .64554 .47787 Mtetra
.903 .587 .437 r
.64554 .47787 .64622 .47579 .648 .47976 .64762 .48984 Mtetra
.952 .668 .463 r
.64762 .48984 .648 .47976 .65703 .67557 .65629 .67717 Mtetra
.784 .416 .361 r
.65629 .67717 .65703 .67557 .65896 .68104 .65814 .68027 Mtetra
.058 .475 .888 r
.65814 .68027 .65896 .68104 .66073 .68186 .6599 .68099 Mtetra
.581 .739 .951 r
.6599 .68099 .66073 .68186 .66245 .6815 .66162 .68075 Mtetra
.786 .821 .88 r
.66162 .68075 .66245 .6815 .66413 .68012 .66331 .67957 Mtetra
.952 .8 .655 r
.66331 .67957 .66413 .68012 .66567 .67527 .66487 .67496 Mtetra
.969 .69 .448 r
.66487 .67496 .66567 .67527 .65941 .47904 .65866 .47879 Mtetra
.976 .776 .569 r
.65866 .47879 .65941 .47904 .66077 .47218 .65999 .4713 Mtetra
.803 .785 .836 r
.65999 .4713 .66077 .47218 .66236 .47088 .66157 .46996 Mtetra
.625 .728 .921 r
.66157 .46996 .66236 .47088 .66398 .47054 .6632 .46961 Mtetra
.477 .662 .943 r
.6632 .46961 .66398 .47054 .66563 .47064 .66484 .4697 Mtetra
.617 .724 .922 r
.66484 .4697 .66563 .47064 .66725 .47032 .66647 .46938 Mtetra
.64 .73 .914 r
.66647 .46938 .66725 .47032 .66888 .46992 .6681 .46898 Mtetra
.649 .732 .91 r
.6681 .46898 .66888 .46992 .67051 .46948 .66973 .46853 Mtetra
.671 .74 .902 r
.66973 .46853 .67051 .46948 .67213 .46893 .67135 .468 Mtetra
.682 .747 .901 r
.67135 .468 .67213 .46893 .67375 .46832 .67297 .46741 Mtetra
.687 .755 .903 r
.67297 .46741 .67375 .46832 .67536 .46768 .67459 .4668 Mtetra
.755 .78 .873 r
.67459 .4668 .67536 .46768 .67696 .46656 .6762 .46583 Mtetra
.722 .806 .917 r
.6762 .46583 .67696 .46656 .67857 .46573 .67781 .46507 Mtetra
.556 .771 .978 r
.67781 .46507 .67857 .46573 .68022 .46559 .67945 .46484 Mtetra
.649 .151 0 r
.67945 .46484 .68022 .46559 .68204 .46922 .68121 .467 Mtetra
.971 .655 .304 r
.68121 .467 .68204 .46922 .69317 .66546 .68376 .48563 Mtetra
.059 0 .448 r
.68376 .48563 .69317 .66546 .6952 .67111 .69422 .6668 Mtetra
.389 .331 .672 r
.69422 .6668 .6952 .67111 .69699 .67176 .69608 .66882 Mtetra
.502 .452 .734 r
.69608 .66882 .69699 .67176 .69873 .67126 .69787 .66944 Mtetra
.554 .564 .819 r
.69787 .66944 .69873 .67126 .70044 .67027 .69964 .66951 Mtetra
.452 .712 .979 r
.69964 .66951 .70044 .67027 .70218 .66974 .7014 .66954 Mtetra
.401 .834 .953 r
.7014 .66954 .70218 .66974 .70391 .66906 .70315 .66922 Mtetra
.528 .919 .822 r
.70315 .66922 .70391 .66906 .70561 .6677 .70487 .6683 Mtetra
.906 .957 .624 r
.70487 .6683 .70561 .6677 .70711 .66254 .70649 .66534 Mtetra
.839 .758 .244 r
.70649 .66534 .70711 .66254 .69849 .46588 .70783 .65726 Mtetra
.06 0 .443 r
.70783 .65726 .69849 .46588 .69985 .45996 .69928 .46285 Mtetra
0 0 .17 r
.69928 .46285 .69985 .45996 .70143 .45838 .70077 .45938 Mtetra
0 0 0 r
.70077 .45938 .70143 .45838 .70307 .45787 .70235 .45773 Mtetra
.75 .97 .929 r
.70235 .45773 .70307 .45787 .70473 .45774 .70396 .45668 Mtetra
.69 .726 .877 r
.70396 .45668 .70473 .45774 .70638 .45732 .7056 .45604 Mtetra
.643 .668 .859 r
.7056 .45604 .70638 .45732 .70802 .45678 .70724 .45562 Mtetra
.623 .681 .884 r
.70724 .45562 .70802 .45678 .70967 .4563 .7089 .4553 Mtetra
.723 .748 .872 r
.7089 .4553 .70967 .4563 .71131 .45569 .71053 .45448 Mtetra
.712 .706 .843 r
.71053 .45448 .71131 .45569 .71296 .45529 .71216 .45367 Mtetra
.63 .615 .816 r
.71216 .45367 .71296 .45529 .71465 .45548 .71381 .4533 Mtetra
.28 .354 .761 r
.71381 .4533 .71465 .45548 .71652 .45884 .71558 .45476 Mtetra
0 0 .482 r
.71558 .45476 .71652 .45884 .72973 .65447 .7176 .46065 Mtetra
.08 .003 .459 r
.7176 .46065 .72973 .65447 .73186 .66038 .7308 .65504 Mtetra
.339 .277 .641 r
.7308 .65504 .73186 .66038 .73371 .66127 .73277 .65812 Mtetra
.482 .431 .724 r
.73277 .65812 .73371 .66127 .73547 .66082 .73461 .65896 Mtetra
.541 .554 .816 r
.73461 .65896 .73547 .66082 .73721 .65993 .73641 .6591 Mtetra
.594 .756 .955 r
.73641 .6591 .73721 .65993 .73896 .65936 .73818 .65879 Mtetra
.647 .848 .977 r
.73818 .65879 .73896 .65936 .74073 .65896 .73994 .65822 Mtetra
.691 .813 .94 r
.73994 .65822 .74073 .65896 .7425 .6585 .7417 .65754 Mtetra
.567 .714 .941 r
.7417 .65754 .7425 .6585 .74427 .6581 .74348 .65736 Mtetra
.513 .746 .98 r
.74348 .65736 .74427 .6581 .74603 .65748 .74528 .65724 Mtetra
.576 .907 .978 r
.74528 .65724 .74603 .65748 .74775 .65623 .74704 .65664 Mtetra
.881 .977 .678 r
.74704 .65664 .74775 .65623 .74927 .65186 .74868 .65416 Mtetra
.817 .762 .248 r
.74868 .65416 .74927 .65186 .73826 .45508 .75004 .64734 Mtetra
.079 0 .454 r
.75004 .64734 .73826 .45508 .7395 .44809 .73903 .45145 Mtetra
0 0 .214 r
.73903 .45145 .7395 .44809 .74107 .44616 .74046 .44733 Mtetra
0 0 0 r
.74046 .44733 .74107 .44616 .74273 .44561 .74204 .4456 Mtetra
.712 .983 .897 r
.74204 .4456 .74273 .44561 .74442 .44549 .74367 .44452 Mtetra
.693 .748 .894 r
.74367 .44452 .74442 .44549 .7461 .44522 .74533 .44386 Mtetra
.636 .653 .85 r
.74533 .44386 .7461 .44522 .74777 .44477 .747 .44347 Mtetra
.61 .652 .867 r
.747 .44347 .74777 .44477 .74944 .44429 .74869 .44321 Mtetra
.634 .703 .896 r
.74869 .44321 .74944 .44429 .75111 .4437 .75037 .44283 Mtetra
.664 .761 .922 r
.75037 .44283 .75111 .4437 .75277 .44306 .75204 .4423 Mtetra
.673 .794 .939 r
.75204 .4423 .75277 .44306 .75443 .44248 .7537 .44173 Mtetra
.742 .815 .909 r
.7537 .44173 .75443 .44248 .7561 .44188 .75535 .44086 Mtetra
.732 .751 .867 r
.75535 .44086 .7561 .44188 .75778 .44146 .757 .43997 Mtetra
.644 .639 .831 r
.757 .43997 .75778 .44146 .7595 .44162 .75868 .43952 Mtetra
.355 .41 .78 r
.75868 .43952 .7595 .44162 .76142 .4444 .76047 .44066 Mtetra
0 0 .528 r
.76047 .44066 .76142 .4444 .77742 .64031 .76257 .44592 Mtetra
.101 .022 .471 r
.76257 .44592 .77742 .64031 .77974 .64711 .77861 .6415 Mtetra
.309 .255 .633 r
.77861 .6415 .77974 .64711 .78166 .64849 .7807 .64515 Mtetra
.481 .424 .716 r
.7807 .64515 .78166 .64849 .78347 .64822 .7826 .64606 Mtetra
.54 .526 .789 r
.7826 .64606 .78347 .64822 .78524 .64743 .78444 .64627 Mtetra
.525 .652 .915 r
.78444 .64627 .78524 .64743 .78702 .64675 .78628 .64629 Mtetra
.456 .804 .998 r
.78628 .64629 .78702 .64675 .7888 .64614 .78809 .64609 Mtetra
.538 .923 .91 r
.78809 .64609 .7888 .64614 .79055 .64495 .78987 .64534 Mtetra
.828 .977 .68 r
.78987 .64534 .79055 .64495 .79211 .6414 .79153 .64312 Mtetra
.826 .792 .294 r
.79153 .64312 .79211 .6414 .77877 .44607 .79293 .63742 Mtetra
.093 .012 .463 r
.79293 .63742 .77877 .44607 .77973 .43621 .7794 .44046 Mtetra
0 0 .27 r
.7794 .44046 .77973 .43621 .78127 .43379 .78072 .43518 Mtetra
0 0 0 r
.78072 .43518 .78127 .43379 .78294 .43312 .7823 .43325 Mtetra
.672 .974 .825 r
.7823 .43325 .78294 .43312 .78466 .43292 .78393 .43206 Mtetra
.713 .782 .907 r
.78393 .43206 .78466 .43292 .78637 .43266 .7856 .43131 Mtetra
.648 .662 .849 r
.7856 .43131 .78637 .43266 .78806 .43216 .7873 .43084 Mtetra
.621 .656 .863 r
.7873 .43084 .78806 .43216 .78975 .43164 .78901 .43052 Mtetra
.673 .714 .879 r
.78901 .43052 .78975 .43164 .79142 .43084 .7907 .42995 Mtetra
.719 .779 .9 r
.7907 .42995 .79142 .43084 .79308 .42992 .79237 .42916 Mtetra
.626 .781 .955 r
.79237 .42916 .79308 .42992 .79478 .4295 .79407 .42875 Mtetra
0 .417 .857 r
.79407 .42875 .79478 .4295 .79664 .43097 .79589 .42965 Mtetra
.752 .351 0 r
.79589 .42965 .79664 .43097 .79977 .44738 .79801 .43423 Mtetra
.978 .682 .322 r
.79801 .43423 .79977 .44738 .81746 .63584 .81629 .63007 Mtetra
.262 .222 .623 r
.81629 .63007 .81746 .63584 .8195 .63799 .81851 .63442 Mtetra
.476 .414 .708 r
.81851 .63442 .8195 .63799 .82133 .63772 .82045 .63545 Mtetra
.535 .517 .782 r
.82045 .63545 .82133 .63772 .82312 .63688 .82233 .63571 Mtetra
.546 .662 .913 r
.82233 .63571 .82312 .63688 .82493 .63629 .82419 .63566 Mtetra
.539 .795 .992 r
.82419 .63566 .82493 .63629 .82678 .63619 .82603 .63539 Mtetra
.713 .814 .927 r
.82603 .63539 .82678 .63619 .82859 .63558 .82782 .63459 Mtetra
.86 .801 .791 r
.82782 .63459 .82859 .63558 .83023 .63311 .8295 .63251 Mtetra
.976 .804 .606 r
.8295 .63251 .83023 .63311 .8311 .62186 .83088 .62705 Mtetra
.98 .686 .361 r
.83088 .62705 .8311 .62186 .81544 .42599 .81518 .43023 Mtetra
0 0 .261 r
.81518 .43023 .81544 .42599 .81691 .42279 .81643 .42449 Mtetra
.061 0 .101 r
.81643 .42449 .81691 .42279 .8186 .42206 .81802 .42262 Mtetra
0 0 0 r
.81802 .42262 .8186 .42206 .82034 .42191 .81967 .42149 Mtetra
.69 .902 .972 r
.81967 .42149 .82034 .42191 .82209 .42179 .82136 .42074 Mtetra
.662 .726 .897 r
.82136 .42074 .82209 .42179 .8238 .4213 .82308 .42022 Mtetra
.63 .706 .901 r
.82308 .42022 .8238 .4213 .82552 .42087 .8248 .41984 Mtetra
.665 .731 .899 r
.8248 .41984 .82552 .42087 .82725 .42046 .82652 .4193 Mtetra
.712 .725 .86 r
.82652 .4193 .82725 .42046 .82898 .42011 .82821 .41849 Mtetra
.637 .623 .82 r
.82821 .41849 .82898 .42011 .83077 .4203 .82993 .41806 Mtetra
.397 .425 .773 r
.82993 .41806 .83077 .4203 .83279 .42305 .8318 .41912 Mtetra
0 0 .335 r
.8318 .41912 .83279 .42305 .8535 .62156 .83439 .42774 Mtetra
.136 .053 .489 r
.83439 .42774 .8535 .62156 .85589 .6268 .85477 .62196 Mtetra
.499 .397 .67 r
.85477 .62196 .85589 .6268 .85779 .62702 .85676 .62309 Mtetra
.866 .637 .59 r
.85676 .62309 .85779 .62702 .85916 .62166 .85787 .61503 Mtetra
.974 .675 .385 r
.85787 .61503 .85916 .62166 .84147 .4211 .84062 .41865 Mtetra
.839 .658 .657 r
.84062 .41865 .84147 .4211 .84272 .41574 .84202 .41477 Mtetra
.745 .774 .877 r
.84202 .41477 .84272 .41574 .8444 .41469 .8437 .41381 Mtetra
.649 .762 .932 r
.8437 .41381 .8444 .41469 .84613 .41428 .84543 .41333 Mtetra
.676 .756 .912 r
.84543 .41333 .84613 .41428 .84787 .41385 .84715 .41274 Mtetra
.764 .753 .843 r
.84715 .41274 .84787 .41385 .84955 .41285 .84882 .41159 Mtetra
.679 .695 .858 r
.84882 .41159 .84955 .41285 .85128 .41231 .85053 .41095 Mtetra
.329 .492 .869 r
.85053 .41095 .85128 .41231 .85313 .413 .8524 .41174 Mtetra
.891 .515 .052 r
.8524 .41174 .85313 .413 .85551 .41883 .85502 .42 Mtetra
.974 .667 .349 r
.85502 .42 .85551 .41883 .87758 .61662 .87706 .61776 Mtetra
.79 .369 .248 r
.87706 .61776 .87758 .61662 .87986 .62029 .87927 .62072 Mtetra
.168 0 0 r
.87927 .62072 .87986 .62029 .8818 .6206 .88115 .62049 Mtetra
.61 .949 .924 r
.88115 .62049 .8818 .6206 .88367 .62025 .88296 .6196 Mtetra
.724 .862 .947 r
.88296 .6196 .88367 .62025 .88552 .61975 .88478 .61873 Mtetra
.511 .68 .942 r
.88478 .61873 .88552 .61975 .88742 .6196 .88669 .61874 Mtetra
.628 .775 .951 r
.88669 .61874 .88742 .6196 .88926 .61896 .88856 .61829 Mtetra
.867 .875 .841 r
.88856 .61829 .88926 .61896 .89098 .61713 .89028 .61648 Mtetra
.988 .772 .522 r
.89028 .61648 .89098 .61713 .89219 .61058 .8913 .60815 Mtetra
.977 .675 .355 r
.8913 .60815 .89219 .61058 .87264 .41104 .87172 .40796 Mtetra
.815 .625 .645 r
.87172 .40796 .87264 .41104 .87392 .40617 .87309 .40391 Mtetra
.669 .584 .751 r
.87309 .40391 .87392 .40617 .87557 .40485 .8748 .40309 Mtetra
.597 .589 .814 r
.8748 .40309 .87557 .40485 .8773 .40416 .87658 .4029 Mtetra
.537 .629 .89 r
.87658 .4029 .8773 .40416 .87906 .40376 .87839 .40293 Mtetra
.636 .774 .946 r
.87839 .40293 .87906 .40376 .88081 .40328 .88014 .40248 Mtetra
.648 .784 .946 r
.88014 .40248 .88081 .40328 .88257 .40288 .88189 .40198 Mtetra
.675 .77 .922 r
.88189 .40198 .88257 .40288 .88433 .40246 .88364 .40138 Mtetra
.713 .745 .877 r
.88364 .40138 .88433 .40246 .88608 .40189 .88535 .40058 Mtetra
.689 .693 .849 r
.88535 .40058 .88608 .40189 .88782 .40128 .88709 .39987 Mtetra
.65 .659 .846 r
.88709 .39987 .88782 .40128 .88955 .40057 .88884 .39938 Mtetra
.563 .654 .897 r
.88884 .39938 .88955 .40057 .89125 .39951 .89065 .39929 Mtetra
0 .467 .756 r
.89065 .39929 .89125 .39951 .89299 .39886 .89251 .39975 Mtetra
.725 .267 .164 r
.89251 .39975 .89299 .39886 .89484 .39921 .89454 .40155 Mtetra
.973 .661 .331 r
.89454 .40155 .89484 .39921 .89728 .40458 .91846 .59339 Mtetra
.583 .367 .553 r
.91846 .59339 .89728 .40458 .92231 .60473 .92176 .60526 Mtetra
.778 .298 .092 r
.92176 .60526 .92231 .60473 .92473 .60885 .924 .60779 Mtetra
.509 .672 .937 r
.924 .60779 .92473 .60885 .92667 .60885 .92594 .60782 Mtetra
.649 .745 .919 r
.92594 .60782 .92667 .60885 .92852 .60813 .92783 .6073 Mtetra
.684 .808 .941 r
.92783 .6073 .92852 .60813 .93035 .60716 .92969 .60661 Mtetra
.383 .742 .991 r
.92969 .60661 .93035 .60716 .9323 .60715 .93164 .60661 Mtetra
.57 .843 .996 r
.93164 .60661 .9323 .60715 .93419 .60672 .93353 .60618 Mtetra
.818 .916 .904 r
.93353 .60618 .93419 .60672 .93597 .6053 .93532 .60481 Mtetra
.993 .812 .556 r
.93532 .60481 .93597 .6053 .9371 .59851 .93653 .59867 Mtetra
.976 .67 .321 r
.93653 .59867 .9371 .59851 .91469 .39723 .91409 .39693 Mtetra
.997 .829 .555 r
.91409 .39693 .91469 .39723 .91592 .3923 .91527 .3915 Mtetra
.766 .828 .9 r
.91527 .3915 .91592 .3923 .91764 .39133 .91698 .39046 Mtetra
.605 .749 .946 r
.91698 .39046 .91764 .39133 .91944 .39105 .91877 .39012 Mtetra
.506 .688 .949 r
.91877 .39012 .91944 .39105 .92128 .39109 .92061 .39013 Mtetra
.657 .75 .919 r
.92061 .39013 .92128 .39109 .92305 .39059 .92238 .3896 Mtetra
.662 .747 .913 r
.92238 .3896 .92305 .39059 .92483 .39006 .92416 .38906 Mtetra
.671 .748 .908 r
.92416 .38906 .92483 .39006 .9266 .38948 .92593 .38847 Mtetra
.763 .781 .868 r
.92593 .38847 .9266 .38948 .9283 .38839 .92763 .38738 Mtetra
.696 .755 .897 r
.92763 .38738 .9283 .38839 .93006 .38769 .92939 .38667 Mtetra
.505 .664 .933 r
.92939 .38667 .93006 .38769 .93191 .38775 .93124 .38672 Mtetra
.745 .328 0 r
.93124 .38672 .93191 .38775 .93438 .39266 .93371 .39163 Mtetra
.97 .655 .291 r
.93371 .39163 .93438 .39266 .96191 .59334 .96121 .59236 Mtetra
.729 .299 0 r
.96121 .59236 .96191 .59334 .96448 .59802 .96378 .59705 Mtetra
.047 .471 .883 r
.34909 .76376 .35004 .76454 .35152 .76515 .35057 .76438 Mtetra
.644 .761 .933 r
.35057 .76438 .35152 .76515 .35305 .76474 .3521 .76396 Mtetra
.809 .778 .824 r
.3521 .76396 .35305 .76474 .35464 .7633 .35369 .76253 Mtetra
.908 .737 .659 r
.35369 .76253 .35464 .7633 .3564 .75804 .35545 .75726 Mtetra
.937 .686 .534 r
.35545 .75726 .3564 .75804 .36683 .56686 .36594 .56602 Mtetra
.908 .727 .645 r
.36594 .56602 .36683 .56686 .36853 .56114 .36764 .56031 Mtetra
.777 .759 .837 r
.36764 .56031 .36853 .56114 .37002 .56003 .36913 .55919 Mtetra
.641 .736 .918 r
.36913 .55919 .37002 .56003 .37147 .55966 .37058 .55883 Mtetra
.508 .69 .95 r
.37058 .55883 .37147 .55966 .37291 .55966 .37202 .55882 Mtetra
.745 .757 .862 r
.37202 .55882 .37291 .55966 .37438 .55879 .37349 .55795 Mtetra
.695 .749 .893 r
.37349 .55795 .37438 .55879 .37585 .5582 .37496 .55737 Mtetra
.477 .678 .953 r
.37496 .55737 .37585 .5582 .37728 .55826 .37639 .55743 Mtetra
.928 .549 .255 r
.37639 .55743 .37728 .55826 .37855 .56227 .37766 .56145 Mtetra
.939 .683 .522 r
.37766 .56145 .37855 .56227 .37183 .75284 .37089 .75207 Mtetra
.934 .578 .321 r
.37089 .75207 .37183 .75284 .37314 .75797 .3722 .7572 Mtetra
0 .34 .787 r
.3722 .7572 .37314 .75797 .37464 .75879 .37369 .75802 Mtetra
.617 .756 .944 r
.37369 .75802 .37464 .75879 .37618 .75846 .37524 .75769 Mtetra
.8 .782 .836 r
.37524 .75769 .37618 .75846 .37777 .75714 .37682 .75636 Mtetra
.906 .745 .671 r
.37682 .75636 .37777 .75714 .37949 .75246 .37855 .75169 Mtetra
.939 .687 .529 r
.37855 .75169 .37949 .75246 .38871 .56129 .38783 .56048 Mtetra
.917 .726 .63 r
.38783 .56048 .38871 .56129 .39043 .55471 .38954 .55388 Mtetra
.796 .762 .822 r
.38954 .55388 .39043 .55471 .39193 .55342 .39104 .55258 Mtetra
.629 .732 .922 r
.39104 .55258 .39193 .55342 .39339 .5531 .39251 .55225 Mtetra
.467 .67 .952 r
.39251 .55225 .39339 .5531 .39483 .5532 .39395 .55233 Mtetra
.614 .722 .923 r
.39395 .55233 .39483 .5532 .3963 .55294 .39542 .55206 Mtetra
.645 .728 .909 r
.39542 .55206 .3963 .55294 .39776 .55258 .39689 .55167 Mtetra
.66 .726 .898 r
.39689 .55167 .39776 .55258 .39923 .55218 .39836 .55123 Mtetra
.697 .728 .874 r
.39836 .55123 .39923 .55218 .40071 .55163 .39984 .55062 Mtetra
.705 .716 .858 r
.39984 .55062 .40071 .55163 .40219 .55103 .40132 .54994 Mtetra
.701 .702 .848 r
.40132 .54994 .40219 .55103 .40367 .55041 .4028 .54927 Mtetra
.681 .686 .848 r
.4028 .54927 .40367 .55041 .40514 .54987 .40428 .54869 Mtetra
.672 .679 .848 r
.40428 .54869 .40514 .54987 .40662 .54935 .40575 .54817 Mtetra
.667 .677 .85 r
.40575 .54817 .40662 .54935 .4081 .54884 .40723 .54767 Mtetra
.669 .679 .85 r
.40723 .54767 .4081 .54884 .40958 .54833 .40871 .54717 Mtetra
.666 .679 .852 r
.40871 .54717 .40958 .54833 .41105 .54783 .41019 .54668 Mtetra
.659 .679 .857 r
.41019 .54668 .41105 .54783 .41253 .54735 .41167 .54622 Mtetra
.639 .676 .869 r
.41167 .54622 .41253 .54735 .41401 .54694 .41314 .54587 Mtetra
.629 .684 .883 r
.41314 .54587 .41401 .54694 .41549 .54655 .41462 .54555 Mtetra
.63 .7 .896 r
.41462 .54555 .41549 .54655 .41697 .54614 .4161 .54523 Mtetra
.652 .724 .901 r
.4161 .54523 .41697 .54614 .41845 .54568 .41758 .54482 Mtetra
.669 .741 .904 r
.41758 .54482 .41845 .54568 .41993 .54516 .41906 .54434 Mtetra
.681 .751 .904 r
.41906 .54434 .41993 .54516 .42142 .54462 .42055 .5438 Mtetra
.734 .763 .876 r
.42055 .5438 .42142 .54462 .42291 .54374 .42204 .543 Mtetra
.728 .782 .895 r
.42204 .543 .42291 .54374 .42441 .54298 .42353 .54226 Mtetra
.66 .773 .933 r
.42353 .54226 .42441 .54298 .42589 .54268 .42502 .5418 Mtetra
.289 .574 .937 r
.42502 .5418 .42589 .54268 .42732 .54428 .42648 .54221 Mtetra
.168 .287 .743 r
.42648 .54221 .42732 .54428 .4286 .55081 .42791 .54367 Mtetra
.298 .209 .584 r
.42791 .54367 .4286 .55081 .42478 .73936 .42928 .5476 Mtetra
0 0 .357 r
.42928 .5476 .42478 .73936 .42627 .74211 .42553 .73479 Mtetra
.158 .109 .548 r
.42553 .73479 .42627 .74211 .42781 .7429 .42694 .74012 Mtetra
.165 .236 .691 r
.42694 .74012 .42781 .7429 .42938 .74307 .42846 .74212 Mtetra
.358 .607 .943 r
.42846 .74212 .42938 .74307 .43095 .74288 .43002 .74245 Mtetra
.588 .845 .993 r
.43002 .74245 .43095 .74288 .43253 .74246 .4316 .74206 Mtetra
.692 .874 .967 r
.4316 .74206 .43253 .74246 .43411 .74192 .43319 .74139 Mtetra
.605 .821 .983 r
.43319 .74139 .43411 .74192 .43569 .74173 .43477 .74101 Mtetra
.611 .773 .958 r
.43477 .74101 .43569 .74173 .43727 .74149 .43635 .74067 Mtetra
.69 .768 .911 r
.43635 .74067 .43727 .74149 .43886 .74079 .43794 .74006 Mtetra
.831 .795 .817 r
.43794 .74006 .43886 .74079 .4405 .73813 .43955 .73843 Mtetra
.953 .921 .74 r
.43955 .73843 .4405 .73813 .44225 .73044 .44119 .7356 Mtetra
.022 0 .253 r
.44119 .7356 .44225 .73044 .44815 .5408 .44288 .73105 Mtetra
.561 .351 .552 r
.44288 .73105 .44815 .5408 .4497 .53814 .44452 .72818 Mtetra
.566 .355 .553 r
.44452 .72818 .4497 .53814 .4512 .53766 .44609 .7284 Mtetra
.565 .354 .553 r
.44609 .7284 .4512 .53766 .45269 .53757 .44768 .72782 Mtetra
0 0 .366 r
.44768 .72782 .45269 .53757 .45421 .5364 .45317 .54408 Mtetra
0 0 .229 r
.45317 .54408 .45421 .5364 .45574 .53476 .45484 .53591 Mtetra
.915 .942 .585 r
.45484 .53591 .45574 .53476 .45726 .53337 .4564 .53268 Mtetra
.817 .798 .834 r
.4564 .53268 .45726 .53337 .45877 .53253 .45792 .5313 Mtetra
.673 .674 .843 r
.45792 .5313 .45877 .53253 .46028 .53204 .45943 .53076 Mtetra
.62 .646 .854 r
.45943 .53076 .46028 .53204 .46178 .53167 .46093 .53048 Mtetra
.637 .668 .864 r
.46093 .53048 .46178 .53167 .46328 .53125 .46243 .53013 Mtetra
.658 .686 .865 r
.46243 .53013 .46328 .53125 .46479 .5308 .46394 .52968 Mtetra
.657 .687 .866 r
.46394 .52968 .46479 .5308 .4663 .53034 .46545 .52923 Mtetra
.66 .69 .867 r
.46545 .52923 .4663 .53034 .46781 .52987 .46695 .52877 Mtetra
.66 .691 .868 r
.46695 .52877 .46781 .52987 .46932 .5294 .46846 .5283 Mtetra
.656 .691 .871 r
.46846 .5283 .46932 .5294 .47083 .52895 .46997 .52786 Mtetra
.636 .687 .881 r
.46997 .52786 .47083 .52895 .47234 .52855 .47148 .52751 Mtetra
.621 .691 .894 r
.47148 .52751 .47234 .52855 .47385 .52818 .47299 .52722 Mtetra
.626 .709 .905 r
.47299 .52722 .47385 .52818 .47536 .52779 .4745 .5269 Mtetra
.666 .737 .903 r
.4745 .5269 .47536 .52779 .47687 .52729 .47602 .52642 Mtetra
.697 .75 .892 r
.47602 .52642 .47687 .52729 .47839 .52669 .47754 .5258 Mtetra
.701 .745 .886 r
.47754 .5258 .47839 .52669 .4799 .52608 .47905 .52516 Mtetra
.686 .735 .888 r
.47905 .52516 .4799 .52608 .48142 .52552 .48057 .52459 Mtetra
.669 .728 .894 r
.48057 .52459 .48142 .52552 .48294 .52502 .48209 .52409 Mtetra
.665 .729 .897 r
.48209 .52409 .48294 .52502 .48446 .52453 .48361 .52361 Mtetra
.665 .731 .899 r
.48361 .52361 .48446 .52453 .48598 .52404 .48513 .52314 Mtetra
.666 .734 .9 r
.48513 .52314 .48598 .52404 .48749 .52356 .48665 .52265 Mtetra
.666 .735 .901 r
.48665 .52265 .48749 .52356 .48901 .52307 .48817 .52217 Mtetra
.665 .736 .902 r
.48817 .52217 .48901 .52307 .49054 .52259 .48969 .52169 Mtetra
.665 .736 .903 r
.48969 .52169 .49054 .52259 .49206 .52211 .49121 .52121 Mtetra
.49121 .52121 .49206 .52211 .49358 .52163 .49273 .52074 Mtetra
.49273 .52074 .49358 .52163 .4951 .52115 .49426 .52026 Mtetra
.49426 .52026 .4951 .52115 .49663 .52068 .49578 .51978 Mtetra
.49578 .51978 .49663 .52068 .49815 .5202 .49731 .5193 Mtetra
.664 .736 .903 r
.49731 .5193 .49815 .5202 .49968 .51972 .49884 .51882 Mtetra
.49884 .51882 .49968 .51972 .50121 .51925 .50036 .51835 Mtetra
.50036 .51835 .50121 .51925 .50273 .51877 .50189 .51787 Mtetra
.50189 .51787 .50273 .51877 .50426 .51829 .50342 .51739 Mtetra
.50342 .51739 .50426 .51829 .50579 .51782 .50495 .51691 Mtetra
.50495 .51691 .50579 .51782 .50732 .51734 .50648 .51644 Mtetra
.663 .735 .903 r
.50648 .51644 .50732 .51734 .50885 .51687 .50801 .51596 Mtetra
.50801 .51596 .50885 .51687 .51039 .51639 .50955 .51549 Mtetra
.663 .735 .904 r
.50955 .51549 .51039 .51639 .51192 .51592 .51108 .51502 Mtetra
.662 .735 .904 r
.51108 .51502 .51192 .51592 .51345 .51545 .51261 .51455 Mtetra
.51261 .51455 .51345 .51545 .51499 .51498 .51415 .51408 Mtetra
.661 .735 .905 r
.51415 .51408 .51499 .51498 .51652 .51451 .51568 .51361 Mtetra
.661 .736 .905 r
.51568 .51361 .51652 .51451 .51806 .51404 .51722 .51314 Mtetra
.66 .736 .906 r
.51722 .51314 .51806 .51404 .5196 .51357 .51876 .51268 Mtetra
.66 .737 .907 r
.51876 .51268 .5196 .51357 .52113 .51311 .5203 .51222 Mtetra
.658 .737 .908 r
.5203 .51222 .52113 .51311 .52267 .51265 .52184 .51176 Mtetra
.657 .738 .909 r
.52184 .51176 .52267 .51265 .52421 .51219 .52338 .51131 Mtetra
.657 .74 .911 r
.52338 .51131 .52421 .51219 .52575 .51173 .52492 .51086 Mtetra
.657 .742 .912 r
.52492 .51086 .52575 .51173 .5273 .51127 .52646 .5104 Mtetra
.658 .743 .913 r
.52646 .5104 .5273 .51127 .52884 .51081 .528 .50994 Mtetra
.659 .745 .913 r
.528 .50994 .52884 .51081 .53038 .51034 .52955 .50948 Mtetra
.659 .746 .914 r
.52955 .50948 .53038 .51034 .53193 .50988 .53109 .50902 Mtetra
.66 .747 .914 r
.53109 .50902 .53193 .50988 .53347 .50941 .53264 .50855 Mtetra
.661 .748 .914 r
.53264 .50855 .53347 .50941 .53502 .50894 .53418 .50808 Mtetra
.662 .748 .914 r
.53418 .50808 .53502 .50894 .53656 .50846 .53573 .5076 Mtetra
.664 .749 .914 r
.53573 .5076 .53656 .50846 .53811 .50798 .53728 .50712 Mtetra
.666 .749 .913 r
.53728 .50712 .53811 .50798 .53966 .50749 .53883 .50663 Mtetra
.67 .75 .911 r
.53883 .50663 .53966 .50749 .54121 .50698 .54038 .50612 Mtetra
.674 .751 .909 r
.54038 .50612 .54121 .50698 .54276 .50646 .54193 .5056 Mtetra
.675 .75 .908 r
.54193 .5056 .54276 .50646 .54431 .50594 .54348 .50507 Mtetra
.708 .758 .892 r
.54348 .50507 .54431 .50594 .54586 .50526 .54503 .50439 Mtetra
.742 .764 .87 r
.54503 .50439 .54586 .50526 .54741 .5044 .54658 .5035 Mtetra
.655 .738 .911 r
.54658 .5035 .54741 .5044 .54896 .50395 .54814 .50306 Mtetra
0 .38 .84 r
.54814 .50306 .54896 .50395 .55053 .50481 .5497 .50395 Mtetra
.949 .599 .3 r
.5497 .50395 .55053 .50481 .55214 .51134 .55132 .51109 Mtetra
.958 .684 .475 r
.55132 .51109 .55214 .51134 .55538 .70508 .55451 .70468 Mtetra
.861 .411 .1 r
.55451 .70468 .55538 .70508 .55707 .70824 .55619 .70768 Mtetra
.523 .793 .994 r
.55619 .70768 .55707 .70824 .55872 .7081 .55785 .70746 Mtetra
.746 .832 .917 r
.55785 .70746 .55872 .7081 .56038 .70728 .5595 .70657 Mtetra
.743 .813 .907 r
.5595 .70657 .56038 .70728 .56203 .70647 .56116 .70568 Mtetra
.503 .722 .971 r
.56116 .70568 .56203 .70647 .56369 .70643 .56282 .70563 Mtetra
.664 .776 .933 r
.56282 .70563 .56369 .70643 .56535 .70591 .56448 .7051 Mtetra
.856 .795 .79 r
.56448 .7051 .56535 .70591 .56699 .7039 .56612 .70309 Mtetra
.951 .728 .565 r
.56612 .70309 .56699 .7039 .56852 .69285 .56765 .69178 Mtetra
.959 .69 .481 r
.56765 .69178 .56852 .69285 .56771 .50127 .56689 .50028 Mtetra
.895 .751 .695 r
.56689 .50028 .56771 .50127 .56924 .49782 .56842 .49684 Mtetra
.727 .743 .865 r
.56842 .49684 .56924 .49782 .5708 .49699 .56998 .49603 Mtetra
.61 .707 .913 r
.56998 .49603 .5708 .49699 .57237 .49672 .57155 .49575 Mtetra
.558 .687 .926 r
.57155 .49575 .57237 .49672 .57394 .49661 .57313 .49565 Mtetra
.653 .724 .901 r
.57313 .49565 .57394 .49661 .57551 .49616 .5747 .49521 Mtetra
.652 .725 .902 r
.5747 .49521 .57551 .49616 .57708 .49572 .57627 .49477 Mtetra
.653 .726 .903 r
.57627 .49477 .57708 .49572 .57865 .49528 .57784 .49433 Mtetra
.656 .728 .902 r
.57784 .49433 .57865 .49528 .58023 .49482 .57941 .49387 Mtetra
.657 .728 .902 r
.57941 .49387 .58023 .49482 .5818 .49436 .58098 .49341 Mtetra
.658 .728 .901 r
.58098 .49341 .5818 .49436 .58337 .4939 .58256 .49295 Mtetra
.66 .728 .9 r
.58256 .49295 .58337 .4939 .58495 .49344 .58413 .49247 Mtetra
.656 .725 .9 r
.58413 .49247 .58495 .49344 .58652 .49299 .58571 .49202 Mtetra
.645 .72 .902 r
.58571 .49202 .58652 .49299 .5881 .49258 .58729 .49161 Mtetra
.62 .711 .911 r
.58729 .49161 .5881 .49258 .58968 .49223 .58887 .49129 Mtetra
.615 .717 .918 r
.58887 .49129 .58968 .49223 .59126 .4919 .59045 .49099 Mtetra
.622 .727 .922 r
.59045 .49099 .59126 .4919 .59284 .49155 .59203 .49066 Mtetra
.649 .742 .917 r
.59203 .49066 .59284 .49155 .59442 .49112 .59361 .49023 Mtetra
.664 .746 .911 r
.59361 .49023 .59442 .49112 .596 .49065 .59519 .48974 Mtetra
.681 .745 .9 r
.59519 .48974 .596 .49065 .59758 .49013 .59678 .48917 Mtetra
.702 .741 .882 r
.59678 .48917 .59758 .49013 .59916 .48953 .59835 .48849 Mtetra
.701 .725 .868 r
.59835 .48849 .59916 .48953 .60074 .48892 .59993 .48781 Mtetra
.699 .71 .857 r
.59993 .48781 .60074 .48892 .60233 .4883 .60151 .48712 Mtetra
.713 .703 .839 r
.60151 .48712 .60233 .4883 .60391 .48764 .60309 .48632 Mtetra
.667 .665 .839 r
.60309 .48632 .60391 .48764 .60549 .48709 .60468 .48577 Mtetra
.562 .62 .867 r
.60468 .48577 .60549 .48709 .60708 .48675 .60627 .48573 Mtetra
0 .133 .662 r
.60627 .48573 .60708 .48675 .60868 .48673 .60791 .48726 Mtetra
.874 .494 .32 r
.60791 .48726 .60868 .48673 .6103 .48726 .60962 .49147 Mtetra
.957 .677 .464 r
.60962 .49147 .6103 .48726 .61195 .48908 .6162 .68224 Mtetra
.574 .361 .554 r
.6162 .68224 .61195 .48908 .61863 .67862 .61803 .68724 Mtetra
.618 .358 .502 r
.61803 .68724 .61863 .67862 .62059 .68822 .61979 .68915 Mtetra
.618 .171 .166 r
.61979 .68915 .62059 .68822 .62236 .69068 .62152 .68997 Mtetra
.425 .71 .983 r
.62152 .68997 .62236 .69068 .62407 .69077 .62323 .69003 Mtetra
.644 .792 .954 r
.62323 .69003 .62407 .69077 .62576 .69022 .62492 .68956 Mtetra
.778 .838 .897 r
.62492 .68956 .62576 .69022 .62744 .68922 .6266 .68847 Mtetra
.891 .805 .757 r
.6266 .68847 .62744 .68922 .62913 .68824 .62824 .68591 Mtetra
.856 .668 .648 r
.62824 .68591 .62913 .68824 .63079 .68671 .6298 .68097 Mtetra
.959 .684 .47 r
.6298 .68097 .63079 .68671 .63242 .68402 .62569 .48948 Mtetra
.578 .368 .559 r
.62569 .48948 .63242 .68402 .62854 .5045 .6271 .48269 Mtetra
.607 .404 .581 r
.6271 .48269 .62854 .5045 .62948 .48266 .62862 .47986 Mtetra
.719 .578 .697 r
.62862 .47986 .62948 .48266 .63099 .47923 .63019 .47817 Mtetra
.686 .718 .873 r
.63019 .47817 .63099 .47923 .63258 .4784 .63178 .47755 Mtetra
.607 .739 .938 r
.63178 .47755 .63258 .4784 .63418 .47809 .63339 .47726 Mtetra
.564 .725 .949 r
.63339 .47726 .63418 .47809 .6358 .47804 .63501 .47709 Mtetra
.74 .756 .866 r
.63501 .47709 .6358 .47804 .6374 .47734 .6366 .47619 Mtetra
.703 .708 .852 r
.6366 .47619 .6374 .47734 .639 .47669 .6382 .47546 Mtetra
.627 .665 .867 r
.6382 .47546 .639 .47669 .64061 .47622 .63981 .47512 Mtetra
0 .279 .781 r
.63981 .47512 .64061 .47622 .64223 .47612 .64148 .47641 Mtetra
.864 .452 .247 r
.64148 .47641 .64223 .47612 .64387 .47651 .64323 .47987 Mtetra
.962 .678 .45 r
.64323 .47987 .64387 .47651 .64554 .47787 .65177 .67014 Mtetra
.576 .362 .554 r
.65177 .67014 .64554 .47787 .64762 .48984 .65373 .67648 Mtetra
.569 .357 .553 r
.65373 .67648 .64762 .48984 .65629 .67717 .65554 .6786 Mtetra
.634 .233 .267 r
.65554 .6786 .65629 .67717 .65814 .68027 .65731 .67955 Mtetra
.173 .563 .933 r
.65731 .67955 .65814 .68027 .6599 .68099 .65906 .68006 Mtetra
.564 .714 .942 r
.65906 .68006 .6599 .68099 .66162 .68075 .66079 .67989 Mtetra
.752 .791 .885 r
.66079 .67989 .66162 .68075 .66331 .67957 .66249 .6789 Mtetra
.943 .791 .662 r
.66249 .6789 .66331 .67957 .66487 .67496 .66405 .67443 Mtetra
.969 .69 .449 r
.66405 .67443 .66487 .67496 .65866 .47879 .65789 .4784 Mtetra
.972 .764 .566 r
.65789 .4784 .65866 .47879 .65999 .4713 .65921 .47041 Mtetra
.806 .784 .833 r
.65921 .47041 .65999 .4713 .66157 .46996 .66079 .46904 Mtetra
.629 .731 .921 r
.66079 .46904 .66157 .46996 .6632 .46961 .66242 .46867 Mtetra
.481 .663 .942 r
.66242 .46867 .6632 .46961 .66484 .4697 .66406 .46876 Mtetra
.622 .723 .919 r
.66406 .46876 .66484 .4697 .66647 .46938 .66569 .46842 Mtetra
.643 .728 .91 r
.66569 .46842 .66647 .46938 .6681 .46898 .66732 .46801 Mtetra
.65 .728 .906 r
.66732 .46801 .6681 .46898 .66973 .46853 .66894 .46756 Mtetra
.666 .733 .9 r
.66894 .46756 .66973 .46853 .67135 .468 .67057 .46705 Mtetra
.675 .741 .9 r
.67057 .46705 .67135 .468 .67297 .46741 .67219 .46649 Mtetra
.682 .75 .902 r
.67219 .46649 .67297 .46741 .67459 .4668 .67381 .4659 Mtetra
.73 .769 .884 r
.67381 .4659 .67459 .4668 .6762 .46583 .67543 .46507 Mtetra
.712 .799 .919 r
.67543 .46507 .6762 .46583 .67781 .46507 .67704 .46436 Mtetra
.626 .786 .958 r
.67704 .46436 .67781 .46507 .67945 .46484 .67868 .46396 Mtetra
.266 .559 .932 r
.67868 .46396 .67945 .46484 .68121 .467 .68036 .46447 Mtetra
.286 .329 .733 r
.68036 .46447 .68121 .467 .68376 .48563 .68209 .46612 Mtetra
.476 .309 .575 r
.68209 .46612 .68376 .48563 .69422 .6668 .684 .4713 Mtetra
.079 0 .455 r
.684 .4713 .69422 .6668 .69608 .66882 .69499 .66245 Mtetra
.274 .216 .609 r
.69499 .66245 .69608 .66882 .69787 .66944 .69696 .66679 Mtetra
.276 .326 .734 r
.69696 .66679 .69787 .66944 .69964 .66951 .69882 .66857 Mtetra
.38 .625 .949 r
.69882 .66857 .69964 .66951 .7014 .66954 .7006 .66888 Mtetra
.604 .803 .976 r
.7006 .66888 .7014 .66954 .70315 .66922 .70235 .66848 Mtetra
.745 .824 .913 r
.70235 .66848 .70315 .66922 .70487 .6683 .70407 .66756 Mtetra
.841 .831 .837 r
.70407 .66756 .70487 .6683 .70649 .66534 .70575 .66591 Mtetra
.88 .966 .64 r
.70575 .66591 .70649 .66534 .70783 .65726 .70738 .66323 Mtetra
.152 0 .36 r
.70738 .66323 .70783 .65726 .69928 .46285 .70888 .65803 Mtetra
.079 0 .449 r
.70888 .65803 .69928 .46285 .70077 .45938 .70033 .4647 Mtetra
0 0 .287 r
.70033 .4647 .70077 .45938 .70235 .45773 .70168 .45858 Mtetra
.793 .907 .508 r
.70168 .45858 .70235 .45773 .70396 .45668 .7032 .45584 Mtetra
.768 .793 .873 r
.7032 .45584 .70396 .45668 .7056 .45604 .70481 .45479 Mtetra
.635 .67 .866 r
.70481 .45479 .7056 .45604 .70724 .45562 .70646 .45442 Mtetra
.581 .653 .886 r
.70646 .45442 .70724 .45562 .7089 .4553 .70813 .45427 Mtetra
.694 .735 .882 r
.70813 .45427 .7089 .4553 .71053 .45448 .70977 .45361 Mtetra
.721 .777 .897 r
.70977 .45361 .71053 .45448 .71216 .45367 .7114 .45283 Mtetra
.663 .768 .927 r
.7114 .45283 .71216 .45367 .71381 .4533 .71305 .45231 Mtetra
.393 .607 .935 r
.71305 .45231 .71381 .4533 .71558 .45476 .71475 .45265 Mtetra
.294 .369 .77 r
.71475 .45265 .71558 .45476 .7176 .46065 .71651 .45401 Mtetra
.358 .269 .617 r
.71651 .45401 .7176 .46065 .7308 .65504 .7184 .45757 Mtetra
.099 .017 .465 r
.7184 .45757 .7308 .65504 .73277 .65812 .73152 .64975 Mtetra
.252 .184 .583 r
.73152 .64975 .73277 .65812 .73461 .65896 .73368 .65589 Mtetra
.275 .302 .708 r
.73368 .65589 .73461 .65896 .73641 .6591 .7356 .658 Mtetra
.45 .626 .928 r
.7356 .658 .73641 .6591 .73818 .65879 .73741 .65823 Mtetra
.656 .854 .975 r
.73741 .65823 .73818 .65879 .73994 .65822 .73916 .65763 Mtetra
.734 .864 .942 r
.73916 .65763 .73994 .65822 .7417 .65754 .74091 .65675 Mtetra
.606 .773 .96 r
.74091 .65675 .7417 .65754 .74348 .65736 .74268 .65639 Mtetra
.564 .709 .939 r
.74268 .65639 .74348 .65736 .74528 .65724 .74447 .65622 Mtetra
.641 .731 .914 r
.74447 .65622 .74528 .65724 .74704 .65664 .74624 .65577 Mtetra
.8 .808 .858 r
.74624 .65577 .74704 .65664 .74868 .65416 .74796 .65443 Mtetra
.911 .98 .715 r
.74796 .65443 .74868 .65416 .75004 .64734 .7496 .65195 Mtetra
.081 0 .308 r
.7496 .65195 .75004 .64734 .73903 .45145 .7511 .64729 Mtetra
.102 .015 .462 r
.7511 .64729 .73903 .45145 .74046 .44733 .74022 .45419 Mtetra
.041 0 .349 r
.74022 .45419 .74046 .44733 .74204 .4456 .74143 .44679 Mtetra
.632 .777 .321 r
.74143 .44679 .74204 .4456 .74367 .44452 .74294 .44383 Mtetra
.806 .84 .876 r
.74294 .44383 .74367 .44452 .74533 .44386 .74455 .44259 Mtetra
.637 .668 .863 r
.74455 .44259 .74533 .44386 .747 .44347 .74623 .44219 Mtetra
.571 .637 .878 r
.74623 .44219 .747 .44347 .74869 .44321 .74793 .4421 Mtetra
.604 .685 .899 r
.74793 .4421 .74869 .44321 .75037 .44283 .74962 .44185 Mtetra
.654 .733 .907 r
.74962 .44185 .75037 .44283 .75204 .4423 .75129 .44137 Mtetra
.669 .749 .91 r
.75129 .44137 .75204 .4423 .7537 .44173 .75296 .44082 Mtetra
.722 .772 .892 r
.75296 .44082 .7537 .44173 .75535 .44086 .75461 .44002 Mtetra
.735 .793 .899 r
.75461 .44002 .75535 .44086 .757 .43997 .75626 .43917 Mtetra
.677 .784 .93 r
.75626 .43917 .757 .43997 .75868 .43952 .75793 .43858 Mtetra
.443 .646 .944 r
.75793 .43858 .75868 .43952 .76047 .44066 .75966 .43877 Mtetra
.277 .383 .791 r
.75966 .43877 .76047 .44066 .76257 .44592 .76147 .44007 Mtetra
.339 .266 .627 r
.76147 .44007 .76257 .44592 .77861 .6415 .76344 .44353 Mtetra
.121 .036 .477 r
.76344 .44353 .77861 .6415 .7807 .64515 .77932 .63608 Mtetra
.268 .193 .584 r
.77932 .63608 .7807 .64515 .7826 .64606 .78163 .64266 Mtetra
.299 .304 .697 r
.78163 .64266 .7826 .64606 .78444 .64627 .78363 .64492 Mtetra
.351 .522 .885 r
.78363 .64492 .78444 .64627 .78628 .64629 .78551 .64559 Mtetra
.551 .779 .983 r
.78551 .64559 .78628 .64629 .78809 .64609 .78733 .64534 Mtetra
.714 .823 .932 r
.78733 .64534 .78809 .64609 .78987 .64534 .7891 .64455 Mtetra
.817 .831 .86 r
.7891 .64455 .78987 .64534 .79153 .64312 .79083 .6431 Mtetra
.926 .967 .768 r
.79083 .6431 .79153 .64312 .79293 .63742 .79248 .64075 Mtetra
0 0 .213 r
.79248 .64075 .79293 .63742 .7794 .44046 .794 .6366 Mtetra
.127 .037 .474 r
.794 .6366 .7794 .44046 .78072 .43518 .78085 .44524 Mtetra
.09 0 .402 r
.78085 .44524 .78072 .43518 .7823 .43325 .78176 .43483 Mtetra
0 0 0 r
.78176 .43483 .7823 .43325 .78393 .43206 .78323 .43154 Mtetra
.85 .891 .867 r
.78323 .43154 .78393 .43206 .7856 .43131 .78485 .43004 Mtetra
.654 .68 .862 r
.78485 .43004 .7856 .43131 .7873 .43084 .78654 .42956 Mtetra
.587 .645 .875 r
.78654 .42956 .7873 .43084 .78901 .43052 .78826 .42939 Mtetra
.628 .692 .891 r
.78826 .42939 .78901 .43052 .7907 .42995 .78997 .42903 Mtetra
.694 .765 .906 r
.78997 .42903 .7907 .42995 .79237 .42916 .79165 .42837 Mtetra
.645 .777 .944 r
.79165 .42837 .79237 .42916 .79407 .42875 .79335 .4279 Mtetra
.455 .677 .96 r
.79335 .4279 .79407 .42875 .79589 .42965 .7951 .428 Mtetra
.296 .425 .823 r
.7951 .428 .79589 .42965 .79801 .43423 .79693 .42908 Mtetra
.37 .3 .646 r
.79693 .42908 .79801 .43423 .81629 .63007 .79891 .43185 Mtetra
.143 .054 .487 r
.79891 .43185 .81629 .63007 .81851 .63442 .81681 .62241 Mtetra
.257 .174 .567 r
.81681 .62241 .81851 .63442 .82045 .63545 .81944 .63157 Mtetra
.306 .293 .68 r
.81944 .63157 .82045 .63545 .82233 .63571 .82152 .63416 Mtetra
.361 .494 .858 r
.82152 .63416 .82233 .63571 .82419 .63566 .82345 .63495 Mtetra
.583 .79 .978 r
.82345 .63495 .82419 .63566 .82603 .63539 .82528 .63461 Mtetra
.734 .822 .92 r
.82528 .63461 .82603 .63539 .82782 .63459 .82707 .63371 Mtetra
.812 .816 .853 r
.82707 .63371 .82782 .63459 .8295 .63251 .8288 .63225 Mtetra
.918 .942 .803 r
.8288 .63225 .8295 .63251 .83088 .62705 .83048 .63006 Mtetra
.003 0 .217 r
.83048 .63006 .83088 .62705 .81518 .43023 .83202 .62642 Mtetra
.545 .339 .552 r
.83202 .62642 .81518 .43023 .81643 .42449 .8326 .61206 Mtetra
.131 .043 .479 r
.8326 .61206 .81643 .42449 .81802 .42262 .81762 .42517 Mtetra
0 0 .144 r
.81762 .42517 .81802 .42262 .81967 .42149 .81904 .42145 Mtetra
.874 .99 .818 r
.81904 .42145 .81967 .42149 .82136 .42074 .82064 .41967 Mtetra
.683 .728 .885 r
.82064 .41967 .82136 .42074 .82308 .42022 .82234 .41904 Mtetra
.612 .678 .889 r
.82234 .41904 .82308 .42022 .8248 .41984 .82408 .41875 Mtetra
.634 .706 .898 r
.82408 .41875 .8248 .41984 .82652 .4193 .8258 .41835 Mtetra
.713 .767 .895 r
.8258 .41835 .82652 .4193 .82821 .41849 .8275 .41758 Mtetra
.664 .759 .921 r
.8275 .41758 .82821 .41849 .82993 .41806 .82921 .41704 Mtetra
.419 .613 .93 r
.82921 .41704 .82993 .41806 .8318 .41912 .83101 .41735 Mtetra
0 .195 .715 r
.83101 .41735 .8318 .41912 .83439 .42774 .833 .41962 Mtetra
.313 .23 .6 r
.833 .41962 .83439 .42774 .85477 .62196 .83529 .42504 Mtetra
.556 .351 .558 r
.83529 .42504 .85477 .62196 .85676 .62309 .83774 .43206 Mtetra
.585 .373 .559 r
.83774 .43206 .85676 .62309 .85787 .61503 .83838 .42026 Mtetra
.573 .364 .559 r
.83838 .42026 .85787 .61503 .84062 .41865 .83975 .41602 Mtetra
.758 .61 .694 r
.83975 .41602 .84062 .41865 .84202 .41477 .84131 .41379 Mtetra
.72 .764 .887 r
.84131 .41379 .84202 .41477 .8437 .41381 .843 .41297 Mtetra
.668 .778 .932 r
.843 .41297 .8437 .41381 .84543 .41333 .84473 .41241 Mtetra
.708 .773 .903 r
.84473 .41241 .84543 .41333 .84715 .41274 .84643 .41167 Mtetra
.775 .763 .842 r
.84643 .41167 .84715 .41274 .84882 .41159 .84809 .41045 Mtetra
.694 .722 .872 r
.84809 .41045 .84882 .41159 .85053 .41095 .84981 .40975 Mtetra
.313 .512 .89 r
.84981 .40975 .85053 .41095 .8524 .41174 .85166 .41047 Mtetra
.876 .496 .021 r
.85166 .41047 .8524 .41174 .85502 .42 .85422 .4181 Mtetra
.975 .669 .337 r
.85422 .4181 .85502 .42 .87706 .61776 .87632 .61679 Mtetra
.595 .143 0 r
.87632 .61679 .87706 .61776 .87927 .62072 .87854 .61985 Mtetra
.571 .745 .959 r
.87854 .61985 .87927 .62072 .88115 .62049 .88042 .6196 Mtetra
.73 .803 .909 r
.88042 .6196 .88115 .62049 .88296 .6196 .88223 .61869 Mtetra
.722 .796 .91 r
.88223 .61869 .88296 .6196 .88478 .61873 .88405 .61783 Mtetra
.46 .683 .962 r
.88405 .61783 .88478 .61873 .88669 .61874 .88597 .61793 Mtetra
.602 .775 .963 r
.88597 .61793 .88669 .61874 .88856 .61829 .88785 .61755 Mtetra
.855 .861 .845 r
.88785 .61755 .88856 .61829 .89028 .61648 .88958 .61582 Mtetra
.988 .776 .53 r
.88958 .61582 .89028 .61648 .8913 .60815 .89065 .60788 Mtetra
.977 .676 .348 r
.89065 .60788 .8913 .60815 .87172 .40796 .87103 .40704 Mtetra
.951 .794 .651 r
.87103 .40704 .87172 .40796 .87309 .40391 .87239 .40288 Mtetra
.715 .754 .883 r
.87239 .40288 .87309 .40391 .8748 .40309 .8741 .40208 Mtetra
.567 .695 .927 r
.8741 .40208 .8748 .40309 .87658 .4029 .87589 .40192 Mtetra
.499 .667 .938 r
.87589 .40192 .87658 .4029 .87839 .40293 .8777 .40198 Mtetra
.648 .745 .92 r
.8777 .40198 .87839 .40293 .88014 .40248 .87945 .4015 Mtetra
.663 .746 .912 r
.87945 .4015 .88014 .40248 .88189 .40198 .8812 .40096 Mtetra
.692 .749 .895 r
.8812 .40096 .88189 .40198 .88364 .40138 .88293 .40028 Mtetra
.744 .752 .859 r
.88293 .40028 .88364 .40138 .88535 .40058 .88463 .39928 Mtetra
.696 .699 .848 r
.88463 .39928 .88535 .40058 .88709 .39987 .88636 .39853 Mtetra
.586 .64 .871 r
.88636 .39853 .88709 .39987 .88884 .39938 .88815 .39836 Mtetra
0 .271 .775 r
.88815 .39836 .88884 .39938 .89065 .39929 .89014 .39991 Mtetra
.865 .439 .2 r
.89014 .39991 .89065 .39929 .89251 .39975 .89245 .40425 Mtetra
.972 .66 .341 r
.89245 .40425 .89251 .39975 .89454 .40155 .91662 .5995 Mtetra
.573 .359 .553 r
.91662 .5995 .89454 .40155 .91846 .59339 .91911 .60431 Mtetra
.603 .349 .505 r
.91911 .60431 .91846 .59339 .92176 .60526 .92126 .60614 Mtetra
.575 .092 .072 r
.92126 .60614 .92176 .60526 .924 .60779 .92329 .60689 Mtetra
.523 .717 .961 r
.92329 .60689 .924 .60779 .92594 .60782 .92522 .6068 Mtetra
.62 .734 .928 r
.92522 .6068 .92594 .60782 .92783 .6073 .92712 .60641 Mtetra
.635 .771 .945 r
.92712 .60641 .92783 .6073 .92969 .60661 .92901 .60593 Mtetra
.433 .731 .989 r
.92901 .60593 .92969 .60661 .93164 .60661 .93096 .60593 Mtetra
.598 .813 .982 r
.93096 .60593 .93164 .60661 .93353 .60618 .93285 .60551 Mtetra
.811 .879 .895 r
.93285 .60551 .93353 .60618 .93532 .60481 .93464 .60415 Mtetra
.987 .807 .575 r
.93464 .60415 .93532 .60481 .93653 .59867 .93589 .59831 Mtetra
.976 .67 .323 r
.93589 .59831 .93653 .59867 .91409 .39693 .91346 .39633 Mtetra
.989 .804 .564 r
.91346 .39633 .91409 .39693 .91527 .3915 .9146 .39057 Mtetra
.765 .798 .879 r
.9146 .39057 .91527 .3915 .91698 .39046 .91631 .3895 Mtetra
.614 .732 .93 r
.91631 .3895 .91698 .39046 .91877 .39012 .9181 .38915 Mtetra
.515 .681 .941 r
.9181 .38915 .91877 .39012 .92061 .39013 .91994 .38915 Mtetra
.661 .749 .915 r
.91994 .38915 .92061 .39013 .92238 .3896 .92171 .38861 Mtetra
.665 .747 .911 r
.92171 .38861 .92238 .3896 .92416 .38906 .92348 .38805 Mtetra
.673 .747 .906 r
.92348 .38805 .92416 .38906 .92593 .38847 .92525 .38746 Mtetra
.763 .778 .865 r
.92525 .38746 .92593 .38847 .92763 .38738 .92696 .38636 Mtetra
.696 .753 .896 r
.92696 .38636 .92763 .38738 .92939 .38667 .92871 .38564 Mtetra
.507 .663 .932 r
.92871 .38564 .92939 .38667 .93124 .38672 .93057 .38569 Mtetra
.742 .325 0 r
.93057 .38569 .93124 .38672 .93371 .39163 .93304 .39058 Mtetra
.97 .655 .291 r
.93304 .39058 .93371 .39163 .96121 .59236 .96051 .59138 Mtetra
.728 .299 0 r
.96051 .59138 .96121 .59236 .96378 .59705 .96309 .59609 Mtetra
.046 .469 .883 r
.34813 .76298 .34909 .76376 .35057 .76438 .34962 .7636 Mtetra
.644 .76 .933 r
.34962 .7636 .35057 .76438 .3521 .76396 .35115 .76318 Mtetra
.809 .778 .824 r
.35115 .76318 .3521 .76396 .35369 .76253 .35274 .76175 Mtetra
.908 .737 .659 r
.35274 .76175 .35369 .76253 .35545 .75726 .35451 .75648 Mtetra
.937 .686 .534 r
.35451 .75648 .35545 .75726 .36594 .56602 .36505 .56519 Mtetra
.908 .727 .645 r
.36505 .56519 .36594 .56602 .36764 .56031 .36675 .55947 Mtetra
.777 .759 .837 r
.36675 .55947 .36764 .56031 .36913 .55919 .36824 .55836 Mtetra
.64 .736 .918 r
.36824 .55836 .36913 .55919 .37058 .55883 .36969 .55799 Mtetra
.508 .69 .95 r
.36969 .55799 .37058 .55883 .37202 .55882 .37113 .55799 Mtetra
.745 .757 .862 r
.37113 .55799 .37202 .55882 .37349 .55795 .3726 .55712 Mtetra
.695 .749 .893 r
.3726 .55712 .37349 .55795 .37496 .55737 .37407 .55653 Mtetra
.477 .677 .953 r
.37407 .55653 .37496 .55737 .37639 .55743 .37551 .55659 Mtetra
.928 .549 .255 r
.37551 .55659 .37639 .55743 .37766 .56145 .37677 .56062 Mtetra
.939 .683 .522 r
.37677 .56062 .37766 .56145 .37089 .75207 .36995 .7513 Mtetra
.934 .578 .321 r
.36995 .7513 .37089 .75207 .3722 .7572 .37125 .75642 Mtetra
0 .341 .788 r
.37125 .75642 .3722 .7572 .37369 .75802 .37275 .75724 Mtetra
.618 .756 .944 r
.37275 .75724 .37369 .75802 .37524 .75769 .37429 .75691 Mtetra
.8 .781 .836 r
.37429 .75691 .37524 .75769 .37682 .75636 .37588 .75558 Mtetra
.906 .744 .671 r
.37588 .75558 .37682 .75636 .37855 .75169 .37761 .75091 Mtetra
.939 .687 .529 r
.37761 .75091 .37855 .75169 .38783 .56048 .38694 .55965 Mtetra
.916 .725 .63 r
.38694 .55965 .38783 .56048 .38954 .55388 .38866 .55303 Mtetra
.796 .761 .82 r
.38866 .55303 .38954 .55388 .39104 .55258 .39016 .55173 Mtetra
.633 .731 .919 r
.39016 .55173 .39104 .55258 .39251 .55225 .39163 .55139 Mtetra
.478 .672 .949 r
.39163 .55139 .39251 .55225 .39395 .55233 .39307 .55146 Mtetra
.627 .723 .916 r
.39307 .55146 .39395 .55233 .39542 .55206 .39454 .55114 Mtetra
.654 .721 .898 r
.39454 .55114 .39542 .55206 .39689 .55167 .39601 .55072 Mtetra
.66 .716 .89 r
.39601 .55072 .39689 .55167 .39836 .55123 .39748 .55028 Mtetra
.673 .719 .884 r
.39748 .55028 .39836 .55123 .39984 .55062 .39896 .54977 Mtetra
.681 .746 .9 r
.39896 .54977 .39984 .55062 .40132 .54994 .40043 .54924 Mtetra
.685 .782 .924 r
.40043 .54924 .40132 .54994 .4028 .54927 .40191 .54869 Mtetra
.68 .815 .948 r
.40191 .54869 .4028 .54927 .40428 .54869 .40339 .54815 Mtetra
.676 .823 .954 r
.40339 .54815 .40428 .54869 .40575 .54817 .40487 .54762 Mtetra
.673 .82 .954 r
.40487 .54762 .40575 .54817 .40723 .54767 .40635 .5471 Mtetra
.666 .812 .954 r
.40635 .5471 .40723 .54767 .40871 .54717 .40782 .5466 Mtetra
.658 .814 .958 r
.40782 .5466 .40871 .54717 .41019 .54668 .4093 .54613 Mtetra
.652 .818 .963 r
.4093 .54613 .41019 .54668 .41167 .54622 .41078 .54567 Mtetra
.646 .815 .964 r
.41078 .54567 .41167 .54622 .41314 .54587 .41226 .54523 Mtetra
.651 .791 .949 r
.41226 .54523 .41314 .54587 .41462 .54555 .41374 .54479 Mtetra
.656 .76 .926 r
.41374 .54479 .41462 .54555 .4161 .54523 .41522 .54435 Mtetra
.66 .734 .904 r
.41522 .54435 .4161 .54523 .41758 .54482 .4167 .54391 Mtetra
.663 .728 .897 r
.4167 .54391 .41758 .54482 .41906 .54434 .41819 .54345 Mtetra
.668 .734 .899 r
.41819 .54345 .41906 .54434 .42055 .5438 .41967 .54297 Mtetra
.691 .751 .898 r
.41967 .54297 .42055 .5438 .42204 .543 .42116 .54239 Mtetra
.691 .807 .937 r
.42116 .54239 .42204 .543 .42353 .54226 .42265 .54181 Mtetra
.654 .848 .974 r
.42265 .54181 .42353 .54226 .42502 .5418 .42414 .54131 Mtetra
.671 .839 .964 r
.42414 .54131 .42502 .5418 .42648 .54221 .42563 .54078 Mtetra
.621 .622 .83 r
.42563 .54078 .42648 .54221 .42791 .54367 .42711 .5405 Mtetra
.538 .451 .704 r
.42711 .5405 .42791 .54367 .42928 .5476 .42858 .54083 Mtetra
.307 .219 .59 r
.42858 .54083 .42928 .5476 .42553 .73479 .42995 .54447 Mtetra
0 0 .346 r
.42995 .54447 .42553 .73479 .42694 .74012 .42613 .73523 Mtetra
0 0 .455 r
.42613 .73523 .42694 .74012 .42846 .74212 .42755 .74054 Mtetra
.282 .436 .838 r
.42755 .74054 .42846 .74212 .43002 .74245 .4291 .74141 Mtetra
.636 .705 .896 r
.4291 .74141 .43002 .74245 .4316 .74206 .43068 .74103 Mtetra
.717 .731 .862 r
.43068 .74103 .4316 .74206 .43319 .74139 .43227 .74025 Mtetra
.67 .697 .867 r
.43227 .74025 .43319 .74139 .43477 .74101 .43386 .73971 Mtetra
.641 .663 .855 r
.43386 .73971 .43477 .74101 .43635 .74067 .43544 .73932 Mtetra
.654 .659 .842 r
.43544 .73932 .43635 .74067 .43794 .74006 .43703 .73885 Mtetra
.697 .695 .844 r
.43703 .73885 .43794 .74006 .43955 .73843 .43862 .73814 Mtetra
.741 .91 .951 r
.43862 .73814 .43955 .73843 .44119 .7356 .44022 .73726 Mtetra
.254 0 .111 r
.44022 .73726 .44119 .7356 .44288 .73105 .44182 .73636 Mtetra
.533 .263 .451 r
.44182 .73636 .44288 .73105 .44452 .72818 .4434 .73609 Mtetra
.549 .298 .487 r
.4434 .73609 .44452 .72818 .44609 .7284 .44499 .73593 Mtetra
.52 .271 .477 r
.44499 .73593 .44609 .7284 .44768 .72782 .44658 .73517 Mtetra
.305 .087 .408 r
.44658 .73517 .44768 .72782 .45317 .54408 .44825 .73128 Mtetra
0 0 .339 r
.44825 .73128 .45317 .54408 .45484 .53591 .45388 .53966 Mtetra
.784 .758 .243 r
.45388 .53966 .45484 .53591 .4564 .53268 .45552 .53257 Mtetra
.905 .904 .812 r
.45552 .53257 .4564 .53268 .45792 .5313 .45706 .53063 Mtetra
.692 .796 .929 r
.45706 .53063 .45792 .5313 .45943 .53076 .45856 .53005 Mtetra
.562 .748 .964 r
.45856 .53005 .45943 .53076 .46093 .53048 .46006 .52986 Mtetra
.595 .785 .971 r
.46006 .52986 .46093 .53048 .46243 .53013 .46157 .52957 Mtetra
.645 .816 .965 r
.46157 .52957 .46243 .53013 .46394 .52968 .46308 .52912 Mtetra
.642 .816 .967 r
.46308 .52912 .46394 .52968 .46545 .52923 .46458 .52868 Mtetra
.641 .819 .968 r
.46458 .52868 .46545 .52923 .46695 .52877 .46609 .52823 Mtetra
.639 .824 .971 r
.46609 .52823 .46695 .52877 .46846 .5283 .4676 .52779 Mtetra
.635 .829 .975 r
.4676 .52779 .46846 .5283 .46997 .52786 .46911 .52735 Mtetra
.63 .827 .976 r
.46911 .52735 .46997 .52786 .47148 .52751 .47062 .52693 Mtetra
.636 .807 .965 r
.47062 .52693 .47148 .52751 .47299 .52722 .47214 .52651 Mtetra
.649 .776 .941 r
.47214 .52651 .47299 .52722 .4745 .5269 .47365 .52608 Mtetra
.663 .751 .916 r
.47365 .52608 .4745 .5269 .47602 .52642 .47516 .52561 Mtetra
.672 .756 .914 r
.47516 .52561 .47602 .52642 .47754 .5258 .47668 .5251 Mtetra
.672 .785 .934 r
.47668 .5251 .47754 .5258 .47905 .52516 .4782 .52459 Mtetra
.661 .818 .959 r
.4782 .52459 .47905 .52516 .48057 .52459 .47972 .52409 Mtetra
.648 .836 .973 r
.47972 .52409 .48057 .52459 .48209 .52409 .48123 .52361 Mtetra
.644 .841 .976 r
.48123 .52361 .48209 .52409 .48361 .52361 .48275 .52313 Mtetra
.48275 .52313 .48361 .52361 .48513 .52314 .48427 .52266 Mtetra
.645 .841 .976 r
.48427 .52266 .48513 .52314 .48665 .52265 .48579 .52218 Mtetra
.644 .843 .977 r
.48579 .52218 .48665 .52265 .48817 .52217 .48731 .5217 Mtetra
.643 .843 .977 r
.48731 .5217 .48817 .52217 .48969 .52169 .48884 .52122 Mtetra
.48884 .52122 .48969 .52169 .49121 .52121 .49036 .52074 Mtetra
.643 .844 .977 r
.49036 .52074 .49121 .52121 .49273 .52074 .49188 .52026 Mtetra
.49188 .52026 .49273 .52074 .49426 .52026 .49341 .51978 Mtetra
.643 .843 .977 r
.49341 .51978 .49426 .52026 .49578 .51978 .49493 .5193 Mtetra
.49493 .5193 .49578 .51978 .49731 .5193 .49646 .51882 Mtetra
.49646 .51882 .49731 .5193 .49884 .51882 .49799 .51834 Mtetra
.49799 .51834 .49884 .51882 .50036 .51835 .49952 .51786 Mtetra
.643 .842 .977 r
.49952 .51786 .50036 .51835 .50189 .51787 .50105 .51738 Mtetra
.50105 .51738 .50189 .51787 .50342 .51739 .50258 .51691 Mtetra
.642 .841 .977 r
.50258 .51691 .50342 .51739 .50495 .51691 .50411 .51643 Mtetra
.50411 .51643 .50495 .51691 .50648 .51644 .50564 .51595 Mtetra
.50564 .51595 .50648 .51644 .50801 .51596 .50717 .51548 Mtetra
.641 .841 .977 r
.50717 .51548 .50801 .51596 .50955 .51549 .5087 .515 Mtetra
.64 .841 .977 r
.5087 .515 .50955 .51549 .51108 .51502 .51024 .51453 Mtetra
.639 .841 .978 r
.51024 .51453 .51108 .51502 .51261 .51455 .51177 .51406 Mtetra
.638 .841 .978 r
.51177 .51406 .51261 .51455 .51415 .51408 .51331 .51359 Mtetra
.637 .841 .979 r
.51331 .51359 .51415 .51408 .51568 .51361 .51484 .51313 Mtetra
.635 .841 .979 r
.51484 .51313 .51568 .51361 .51722 .51314 .51638 .51266 Mtetra
.633 .842 .98 r
.51638 .51266 .51722 .51314 .51876 .51268 .51792 .5122 Mtetra
.63 .843 .982 r
.51792 .5122 .51876 .51268 .5203 .51222 .51946 .51175 Mtetra
.627 .844 .983 r
.51946 .51175 .5203 .51222 .52184 .51176 .521 .5113 Mtetra
.624 .845 .984 r
.521 .5113 .52184 .51176 .52338 .51131 .52254 .51085 Mtetra
.622 .847 .985 r
.52254 .51085 .52338 .51131 .52492 .51086 .52408 .51041 Mtetra
.622 .849 .986 r
.52408 .51041 .52492 .51086 .52646 .5104 .52563 .50996 Mtetra
.622 .851 .986 r
.52563 .50996 .52646 .5104 .528 .50994 .52717 .50951 Mtetra
.622 .853 .987 r
.52717 .50951 .528 .50994 .52955 .50948 .52871 .50906 Mtetra
.622 .855 .987 r
.52871 .50906 .52955 .50948 .53109 .50902 .53026 .5086 Mtetra
.622 .857 .987 r
.53026 .5086 .53109 .50902 .53264 .50855 .53181 .50814 Mtetra
.624 .859 .987 r
.53181 .50814 .53264 .50855 .53418 .50808 .53335 .50767 Mtetra
.625 .861 .987 r
.53335 .50767 .53418 .50808 .53573 .5076 .5349 .50719 Mtetra
.628 .862 .987 r
.5349 .50719 .53573 .5076 .53728 .50712 .53645 .50671 Mtetra
.632 .864 .986 r
.53645 .50671 .53728 .50712 .53883 .50663 .538 .50622 Mtetra
.638 .865 .984 r
.538 .50622 .53883 .50663 .54038 .50612 .53955 .50571 Mtetra
.647 .867 .982 r
.53955 .50571 .54038 .50612 .54193 .5056 .5411 .50518 Mtetra
.649 .867 .981 r
.5411 .50518 .54193 .5056 .54348 .50507 .54266 .50465 Mtetra
.705 .876 .961 r
.54266 .50465 .54348 .50507 .54503 .50439 .54421 .50395 Mtetra
.759 .879 .932 r
.54421 .50395 .54503 .50439 .54658 .5035 .54576 .50306 Mtetra
.622 .851 .986 r
.54576 .50306 .54658 .5035 .54814 .50306 .54731 .5026 Mtetra
.363 0 0 r
.54731 .5026 .54814 .50306 .5497 .50395 .54888 .5035 Mtetra
.941 .596 .339 r
.54888 .5035 .5497 .50395 .55132 .51109 .5505 .51085 Mtetra
.958 .684 .475 r
.5505 .51085 .55132 .51109 .55451 .70468 .55363 .70356 Mtetra
.773 .323 0 r
.55363 .70356 .55451 .70468 .55619 .70768 .55532 .70654 Mtetra
.568 .667 .905 r
.55532 .70654 .55619 .70768 .55785 .70746 .55698 .70643 Mtetra
.71 .737 .873 r
.55698 .70643 .55785 .70746 .5595 .70657 .55863 .70567 Mtetra
.715 .766 .892 r
.55863 .70567 .5595 .70657 .56116 .70568 .56029 .7049 Mtetra
.506 .724 .971 r
.56029 .7049 .56116 .70568 .56282 .70563 .56195 .70484 Mtetra
.666 .779 .933 r
.56195 .70484 .56282 .70563 .56448 .7051 .56361 .7043 Mtetra
.854 .796 .794 r
.56361 .7043 .56448 .7051 .56612 .70309 .56525 .70233 Mtetra
.95 .735 .576 r
.56525 .70233 .56612 .70309 .56765 .69178 .5668 .69252 Mtetra
.962 .693 .478 r
.5668 .69252 .56765 .69178 .56689 .50028 .56608 .49986 Mtetra
.939 .812 .693 r
.56608 .49986 .56689 .50028 .56842 .49684 .56761 .49629 Mtetra
.742 .846 .928 r
.56761 .49629 .56842 .49684 .56998 .49603 .56917 .49546 Mtetra
.56 .798 .988 r
.56917 .49546 .56998 .49603 .57155 .49575 .57074 .4952 Mtetra
.465 .763 .995 r
.57074 .4952 .57155 .49575 .57313 .49565 .57231 .49512 Mtetra
.626 .829 .978 r
.57231 .49512 .57313 .49565 .5747 .49521 .57388 .49468 Mtetra
.624 .83 .98 r
.57388 .49468 .5747 .49521 .57627 .49477 .57546 .49425 Mtetra
.625 .832 .98 r
.57546 .49425 .57627 .49477 .57784 .49433 .57703 .49381 Mtetra
.631 .835 .979 r
.57703 .49381 .57784 .49433 .57941 .49387 .5786 .49336 Mtetra
.632 .836 .979 r
.5786 .49336 .57941 .49387 .58098 .49341 .58018 .4929 Mtetra
.634 .836 .978 r
.58018 .4929 .58098 .49341 .58256 .49295 .58175 .49243 Mtetra
.635 .837 .978 r
.58175 .49243 .58256 .49295 .58413 .49247 .58333 .49196 Mtetra
.632 .838 .979 r
.58333 .49196 .58413 .49247 .58571 .49202 .5849 .4915 Mtetra
.629 .835 .979 r
.5849 .4915 .58571 .49202 .58729 .49161 .58648 .49105 Mtetra
.623 .821 .977 r
.58648 .49105 .58729 .49161 .58887 .49129 .58806 .49063 Mtetra
.636 .794 .958 r
.58806 .49063 .58887 .49129 .59045 .49099 .58964 .4902 Mtetra
.648 .765 .934 r
.58964 .4902 .59045 .49099 .59203 .49066 .59122 .48976 Mtetra
.662 .742 .909 r
.59122 .48976 .59203 .49066 .59361 .49023 .5928 .48928 Mtetra
.668 .732 .898 r
.5928 .48928 .59361 .49023 .59519 .48974 .59438 .48876 Mtetra
.673 .73 .893 r
.59438 .48876 .59519 .48974 .59678 .48917 .59597 .48823 Mtetra
.679 .74 .897 r
.59597 .48823 .59678 .48917 .59835 .48849 .59755 .48767 Mtetra
.68 .767 .916 r
.59755 .48767 .59835 .48849 .59993 .48781 .59913 .48711 Mtetra
.689 .801 .934 r
.59913 .48711 .59993 .48781 .60151 .48712 .60071 .4865 Mtetra
.756 .836 .912 r
.60071 .4865 .60151 .48712 .60309 .48632 .60229 .4856 Mtetra
.675 .793 .937 r
.60229 .4856 .60309 .48632 .60468 .48577 .60387 .48505 Mtetra
.343 .651 .968 r
.60387 .48505 .60468 .48577 .60627 .48573 .60548 .48529 Mtetra
.899 .482 .165 r
.60548 .48529 .60627 .48573 .60791 .48726 .60718 .48923 Mtetra
.96 .681 .46 r
.60718 .48923 .60791 .48726 .60962 .49147 .6137 .6833 Mtetra
.574 .361 .554 r
.6137 .6833 .60962 .49147 .6162 .68224 .61554 .68878 Mtetra
.581 .315 .478 r
.61554 .68878 .6162 .68224 .61803 .68724 .61726 .6894 Mtetra
.495 .143 .299 r
.61726 .6894 .61803 .68724 .61979 .68915 .61896 .68927 Mtetra
.296 .792 .794 r
.61896 .68927 .61979 .68915 .62152 .68997 .62066 .68879 Mtetra
.541 .649 .904 r
.62066 .68879 .62152 .68997 .62323 .69003 .62237 .68877 Mtetra
.647 .681 .868 r
.62237 .68877 .62323 .69003 .62492 .68956 .62406 .68832 Mtetra
.76 .723 .818 r
.62406 .68832 .62492 .68956 .6266 .68847 .62574 .6871 Mtetra
.903 .727 .654 r
.62574 .6871 .6266 .68847 .62824 .68591 .62731 .68222 Mtetra
.962 .687 .467 r
.62731 .68222 .62824 .68591 .6298 .68097 .62323 .48729 Mtetra
.578 .368 .559 r
.62323 .48729 .6298 .68097 .62569 .48948 .62464 .48033 Mtetra
.621 .435 .61 r
.62464 .48033 .62569 .48948 .6271 .48269 .62621 .47878 Mtetra
.635 .495 .675 r
.62621 .47878 .6271 .48269 .62862 .47986 .6278 .47797 Mtetra
.637 .587 .781 r
.6278 .47797 .62862 .47986 .63019 .47817 .6294 .47753 Mtetra
.663 .813 .955 r
.6294 .47753 .63019 .47817 .63178 .47755 .631 .477 Mtetra
.625 .826 .978 r
.631 .477 .63178 .47755 .63339 .47726 .63261 .47656 Mtetra
.629 .786 .957 r
.63261 .47656 .63339 .47726 .63501 .47709 .63421 .47615 Mtetra
.745 .762 .867 r
.63421 .47615 .63501 .47709 .6366 .47619 .6358 .47523 Mtetra
.691 .743 .891 r
.6358 .47523 .6366 .47619 .6382 .47546 .63741 .4746 Mtetra
.513 .699 .954 r
.63741 .4746 .6382 .47546 .63981 .47512 .63903 .47457 Mtetra
.861 .411 .042 r
.63903 .47457 .63981 .47512 .64148 .47641 .64077 .47786 Mtetra
.964 .681 .447 r
.64077 .47786 .64148 .47641 .64323 .47987 .64929 .67149 Mtetra
.577 .363 .554 r
.64929 .67149 .64323 .47987 .65177 .67014 .65128 .6786 Mtetra
.584 .329 .495 r
.65128 .6786 .65177 .67014 .65373 .67648 .65304 .6794 Mtetra
.521 .201 .366 r
.65304 .6794 .65373 .67648 .65554 .6786 .65476 .6793 Mtetra
.142 0 0 r
.65476 .6793 .65554 .6786 .65731 .67955 .65648 .6788 Mtetra
.413 .694 .978 r
.65648 .6788 .65731 .67955 .65906 .68006 .65822 .67891 Mtetra
.607 .687 .9 r
.65822 .67891 .65906 .68006 .66079 .67989 .65995 .67864 Mtetra
.732 .715 .835 r
.65995 .67864 .66079 .67989 .66249 .6789 .66164 .67765 Mtetra
.911 .74 .658 r
.66164 .67765 .66249 .6789 .66405 .67443 .6632 .67297 Mtetra
.968 .689 .45 r
.6632 .67297 .66405 .67443 .65789 .4784 .65708 .47675 Mtetra
.92 .708 .6 r
.65708 .47675 .65789 .4784 .65921 .47041 .65842 .46948 Mtetra
.8 .776 .83 r
.65842 .46948 .65921 .47041 .66079 .46904 .66001 .46813 Mtetra
.633 .736 .923 r
.66001 .46813 .66079 .46904 .66242 .46867 .66163 .46775 Mtetra
.492 .672 .944 r
.66163 .46775 .66242 .46867 .66406 .46876 .66328 .4678 Mtetra
.626 .722 .915 r
.66328 .4678 .66406 .46876 .66569 .46842 .66491 .46745 Mtetra
.645 .725 .907 r
.66491 .46745 .66569 .46842 .66732 .46801 .66653 .46703 Mtetra
.65 .726 .904 r
.66653 .46703 .66732 .46801 .66894 .46756 .66816 .46658 Mtetra
.662 .73 .9 r
.66816 .46658 .66894 .46756 .67057 .46705 .66979 .46608 Mtetra
.671 .737 .899 r
.66979 .46608 .67057 .46705 .67219 .46649 .67141 .46554 Mtetra
.678 .743 .9 r
.67141 .46554 .67219 .46649 .67381 .4659 .67303 .46497 Mtetra
.7 .754 .894 r
.67303 .46497 .67381 .4659 .67543 .46507 .67465 .4643 Mtetra
.699 .79 .922 r
.67465 .4643 .67543 .46507 .67704 .46436 .67628 .46364 Mtetra
.677 .8 .94 r
.67628 .46364 .67704 .46436 .67868 .46396 .6779 .46307 Mtetra
.7 .764 .901 r
.6779 .46307 .67868 .46396 .68036 .46447 .67953 .4624 Mtetra
.623 .566 .77 r
.67953 .4624 .68036 .46447 .68209 .46612 .68116 .46204 Mtetra
.548 .436 .678 r
.68116 .46204 .68209 .46612 .684 .4713 .68284 .46238 Mtetra
.356 .249 .593 r
.68284 .46238 .684 .4713 .69499 .66245 .68473 .46711 Mtetra
.064 0 .45 r
.68473 .46711 .69499 .66245 .69696 .66679 .69598 .6625 Mtetra
.028 .086 .588 r
.69598 .6625 .69696 .66679 .69882 .66857 .69797 .66701 Mtetra
.397 .512 .858 r
.69797 .66701 .69882 .66857 .7006 .66888 .69976 .66764 Mtetra
.639 .686 .877 r
.69976 .66764 .7006 .66888 .70235 .66848 .70151 .66721 Mtetra
.717 .71 .843 r
.70151 .66721 .70235 .66848 .70407 .66756 .70324 .66633 Mtetra
.664 .697 .87 r
.70324 .66633 .70407 .66756 .70575 .66591 .70498 .66577 Mtetra
.607 .936 .954 r
.70498 .66577 .70575 .66591 .70738 .66323 .70671 .66503 Mtetra
.175 0 .122 r
.70671 .66503 .70738 .66323 .70888 .65803 .70841 .6636 Mtetra
.117 0 .34 r
.70841 .6636 .70888 .65803 .70033 .4647 .70991 .65843 Mtetra
.06 0 .443 r
.70991 .65843 .70033 .4647 .70168 .45858 .70112 .46151 Mtetra
0 0 0 r
.70112 .46151 .70168 .45858 .7032 .45584 .70247 .4556 Mtetra
.874 .94 .858 r
.70247 .4556 .7032 .45584 .70481 .45479 .70405 .45398 Mtetra
.665 .774 .931 r
.70405 .45398 .70481 .45479 .70646 .45442 .7057 .45346 Mtetra
.566 .7 .931 r
.7057 .45346 .70646 .45442 .70813 .45427 .70736 .45331 Mtetra
.654 .734 .908 r
.70736 .45331 .70813 .45427 .70977 .45361 .70901 .45284 Mtetra
.682 .791 .932 r
.70901 .45284 .70977 .45361 .7114 .45283 .71066 .45225 Mtetra
.651 .832 .97 r
.71066 .45225 .7114 .45283 .71305 .45231 .71231 .45172 Mtetra
.668 .835 .964 r
.71231 .45172 .71305 .45231 .71475 .45265 .71395 .45115 Mtetra
.627 .629 .833 r
.71395 .45115 .71475 .45265 .71651 .45401 .71561 .4508 Mtetra
.551 .464 .71 r
.71561 .4508 .71651 .45401 .7184 .45757 .71731 .45105 Mtetra
.373 .281 .62 r
.71731 .45105 .7184 .45757 .73152 .64975 .71919 .45436 Mtetra
.081 .004 .459 r
.71919 .45436 .73152 .64975 .73368 .65589 .73259 .65019 Mtetra
.043 .067 .56 r
.73259 .65019 .73368 .65589 .7356 .658 .73474 .65623 Mtetra
.343 .451 .826 r
.73474 .65623 .7356 .658 .73741 .65823 .7366 .65718 Mtetra
.638 .723 .909 r
.7366 .65718 .73741 .65823 .73916 .65763 .73837 .65675 Mtetra
.729 .79 .901 r
.73837 .65675 .73916 .65763 .74091 .65675 .74011 .65588 Mtetra
.667 .774 .93 r
.74011 .65588 .74091 .65675 .74268 .65639 .74187 .65531 Mtetra
.626 .713 .909 r
.74187 .65531 .74268 .65639 .74447 .65622 .74365 .65493 Mtetra
.644 .682 .871 r
.74365 .65493 .74447 .65622 .74624 .65577 .74542 .65448 Mtetra
.636 .677 .872 r
.74542 .65448 .74624 .65577 .74796 .65443 .7472 .65406 Mtetra
.632 .898 .986 r
.7472 .65406 .74796 .65443 .7496 .65195 .74896 .65343 Mtetra
.148 0 .054 r
.74896 .65343 .7496 .65195 .7511 .64729 .75069 .65216 Mtetra
.166 0 .344 r
.75069 .65216 .7511 .64729 .74022 .45419 .75222 .64792 Mtetra
.081 0 .455 r
.75222 .64792 .74022 .45419 .74143 .44679 .74103 .45108 Mtetra
0 0 .125 r
.74103 .45108 .74143 .44679 .74294 .44383 .74225 .44378 Mtetra
.909 .97 .8 r
.74225 .44378 .74294 .44383 .74455 .44259 .74381 .44179 Mtetra
.674 .785 .933 r
.74381 .44179 .74455 .44259 .74623 .44219 .74548 .44123 Mtetra
.561 .696 .931 r
.74548 .44123 .74623 .44219 .74793 .4421 .74718 .44109 Mtetra
.601 .704 .916 r
.74718 .44109 .74793 .4421 .74962 .44185 .74886 .44083 Mtetra
.651 .723 .902 r
.74886 .44083 .74962 .44185 .75129 .44137 .75054 .44037 Mtetra
.656 .729 .903 r
.75054 .44037 .75129 .44137 .75296 .44082 .75221 .43988 Mtetra
.681 .752 .905 r
.75221 .43988 .75296 .44082 .75461 .44002 .75388 .43928 Mtetra
.692 .806 .935 r
.75388 .43928 .75461 .44002 .75626 .43917 .75555 .43863 Mtetra
.66 .854 .974 r
.75555 .43863 .75626 .43917 .75793 .43858 .75722 .43805 Mtetra
.663 .855 .973 r
.75722 .43805 .75793 .43858 .75966 .43877 .75889 .43745 Mtetra
.639 .663 .857 r
.75889 .43745 .75966 .43877 .76147 .44007 .76058 .43704 Mtetra
.558 .477 .719 r
.76058 .43704 .76147 .44007 .76344 .44353 .7623 .43721 Mtetra
.413 .312 .63 r
.7623 .43721 .76344 .44353 .77932 .63608 .76422 .43994 Mtetra
.105 .025 .472 r
.76422 .43994 .77932 .63608 .78163 .64266 .78043 .63599 Mtetra
.085 .086 .561 r
.78043 .63599 .78163 .64266 .78363 .64492 .78277 .64289 Mtetra
.274 .378 .788 r
.78277 .64289 .78363 .64492 .78551 .64559 .78471 .64431 Mtetra
.604 .666 .883 r
.78471 .64431 .78551 .64559 .78733 .64534 .78652 .64404 Mtetra
.701 .705 .851 r
.78652 .64404 .78733 .64534 .7891 .64455 .78829 .64325 Mtetra
.687 .7 .857 r
.78829 .64325 .7891 .64455 .79083 .6431 .79008 .64253 Mtetra
.661 .857 .975 r
.79008 .64253 .79083 .6431 .79248 .64075 .79187 .6419 Mtetra
.062 0 0 r
.79187 .6419 .79248 .64075 .794 .6366 .79361 .64069 Mtetra
.181 0 .328 r
.79361 .64069 .794 .6366 .78085 .44524 .79517 .63714 Mtetra
.099 .017 .465 r
.79517 .63714 .78085 .44524 .78176 .43483 .78162 .44146 Mtetra
0 0 .269 r
.78162 .44146 .78176 .43483 .78323 .43154 .78259 .43173 Mtetra
.924 .974 .71 r
.78259 .43173 .78323 .43154 .78485 .43004 .78413 .42928 Mtetra
.698 .804 .93 r
.78413 .42928 .78485 .43004 .78654 .42956 .78581 .4286 Mtetra
.583 .711 .931 r
.78581 .4286 .78654 .42956 .78826 .42939 .78753 .42838 Mtetra
.606 .709 .917 r
.78753 .42838 .78826 .42939 .78997 .42903 .78924 .42809 Mtetra
.671 .752 .911 r
.78924 .42809 .78997 .42903 .79165 .42837 .79093 .42753 Mtetra
.657 .773 .935 r
.79093 .42753 .79165 .42837 .79335 .4279 .79263 .42702 Mtetra
.67 .768 .924 r
.79263 .42702 .79335 .4279 .7951 .428 .79432 .42647 Mtetra
.651 .639 .825 r
.79432 .42647 .7951 .428 .79693 .42908 .79602 .42596 Mtetra
.575 .485 .714 r
.79602 .42596 .79693 .42908 .79891 .43185 .79777 .42597 Mtetra
.455 .346 .641 r
.79777 .42597 .79891 .43185 .81681 .62241 .79968 .42797 Mtetra
.122 .04 .481 r
.79968 .42797 .81681 .62241 .81944 .63157 .81794 .62203 Mtetra
.106 .08 .542 r
.81794 .62203 .81944 .63157 .82152 .63416 .82063 .63183 Mtetra
.231 .324 .753 r
.82063 .63183 .82152 .63416 .82345 .63495 .82266 .63369 Mtetra
.593 .669 .892 r
.82266 .63369 .82345 .63495 .82528 .63461 .8245 .63347 Mtetra
.705 .739 .877 r
.8245 .63347 .82528 .63461 .82707 .63371 .8263 .63268 Mtetra
.704 .759 .895 r
.8263 .63268 .82707 .63371 .8288 .63225 .82809 .63191 Mtetra
.55 .881 .989 r
.82809 .63191 .8288 .63225 .83048 .63006 .82992 .63141 Mtetra
.212 0 .059 r
.82992 .63141 .83048 .63006 .83202 .62642 .8317 .6304 Mtetra
.269 .029 .353 r
.8317 .6304 .83202 .62642 .8326 .61206 .83331 .62756 Mtetra
.029 0 .408 r
.83331 .62756 .8326 .61206 .81762 .42517 .83356 .60948 Mtetra
.117 .033 .475 r
.83356 .60948 .81762 .42517 .81904 .42145 .81842 .42157 Mtetra
.961 .945 .668 r
.81842 .42157 .81904 .42145 .82064 .41967 .81991 .41859 Mtetra
.703 .737 .878 r
.81991 .41859 .82064 .41967 .82234 .41904 .8216 .41786 Mtetra
.593 .669 .892 r
.8216 .41786 .82234 .41904 .82408 .41875 .82335 .41765 Mtetra
.583 .681 .908 r
.82335 .41765 .82408 .41875 .8258 .41835 .8251 .41746 Mtetra
.668 .766 .924 r
.8251 .41746 .8258 .41835 .8275 .41758 .82681 .41691 Mtetra
.639 .813 .967 r
.82681 .41691 .8275 .41758 .82921 .41704 .82853 .41642 Mtetra
.549 .791 .988 r
.82853 .41642 .82921 .41704 .83101 .41735 .83028 .41616 Mtetra
.51 .626 .902 r
.83028 .41616 .83101 .41735 .833 .41962 .83206 .41626 Mtetra
.564 .47 .706 r
.83206 .41626 .833 .41962 .83529 .42504 .83384 .41639 Mtetra
.583 .412 .615 r
.83384 .41639 .83529 .42504 .83774 .43206 .83559 .41608 Mtetra
.59 .397 .588 r
.83559 .41608 .83774 .43206 .83838 .42026 .83726 .41499 Mtetra
.636 .475 .647 r
.83726 .41499 .83838 .42026 .83975 .41602 .83892 .4138 Mtetra
.689 .597 .748 r
.83892 .4138 .83975 .41602 .84131 .41379 .8406 .41279 Mtetra
.698 .752 .894 r
.8406 .41279 .84131 .41379 .843 .41297 .84231 .41209 Mtetra
.684 .774 .919 r
.84231 .41209 .843 .41297 .84473 .41241 .84402 .41146 Mtetra
.715 .769 .895 r
.84402 .41146 .84473 .41241 .84643 .41167 .84573 .41067 Mtetra
.76 .775 .865 r
.84573 .41067 .84643 .41167 .84809 .41045 .8474 .40961 Mtetra
.673 .78 .93 r
.8474 .40961 .84809 .41045 .84981 .40975 .84913 .40902 Mtetra
.071 .473 .889 r
.84913 .40902 .84981 .40975 .85166 .41047 .85099 .40981 Mtetra
.913 .522 .118 r
.85099 .40981 .85166 .41047 .85422 .4181 .85354 .41735 Mtetra
.975 .668 .341 r
.85354 .41735 .85422 .4181 .87632 .61679 .87554 .61544 Mtetra
0 0 .519 r
.87554 .61544 .87632 .61679 .87854 .61985 .87776 .61854 Mtetra
.571 .651 .89 r
.87776 .61854 .87854 .61985 .88042 .6196 .87965 .61841 Mtetra
.698 .73 .875 r
.87965 .61841 .88042 .6196 .88223 .61869 .88148 .61764 Mtetra
.705 .759 .894 r
.88148 .61764 .88223 .61869 .88405 .61783 .88331 .61685 Mtetra
.515 .692 .949 r
.88331 .61685 .88405 .61783 .88597 .61793 .88522 .61683 Mtetra
.646 .727 .908 r
.88522 .61683 .88597 .61793 .88785 .61755 .88708 .61634 Mtetra
.822 .766 .8 r
.88708 .61634 .88785 .61755 .88958 .61582 .88881 .61454 Mtetra
.965 .747 .558 r
.88881 .61454 .88958 .61582 .89065 .60788 .8899 .60677 Mtetra
.977 .676 .351 r
.8899 .60677 .89065 .60788 .87103 .40704 .87038 .40649 Mtetra
.976 .832 .636 r
.87038 .40649 .87103 .40704 .87239 .40288 .87173 .40226 Mtetra
.742 .866 .938 r
.87173 .40226 .87239 .40288 .8741 .40208 .87344 .40136 Mtetra
.569 .775 .976 r
.87344 .40136 .8741 .40208 .87589 .40192 .87521 .40109 Mtetra
.519 .717 .963 r
.87521 .40109 .87589 .40192 .8777 .40198 .87701 .40101 Mtetra
.664 .749 .914 r
.87701 .40101 .8777 .40198 .87945 .4015 .87875 .40046 Mtetra
.668 .735 .9 r
.87875 .40046 .87945 .4015 .8812 .40096 .8805 .3999 Mtetra
.688 .738 .889 r
.8805 .3999 .8812 .40096 .88293 .40028 .88223 .39923 Mtetra
.744 .762 .867 r
.88223 .39923 .88293 .40028 .88463 .39928 .88394 .39825 Mtetra
.678 .741 .898 r
.88394 .39825 .88463 .39928 .88636 .39853 .88568 .39764 Mtetra
.384 .629 .95 r
.88568 .39764 .88636 .39853 .88815 .39836 .88753 .39794 Mtetra
.838 .387 0 r
.88753 .39794 .88815 .39836 .89014 .39991 .88983 .40224 Mtetra
.973 .661 .333 r
.88983 .40224 .89014 .39991 .89245 .40425 .91429 .60132 Mtetra
.573 .359 .553 r
.91429 .60132 .89245 .40425 .91662 .5995 .9168 .60635 Mtetra
.572 .305 .473 r
.9168 .60635 .91662 .5995 .91911 .60431 .91879 .60681 Mtetra
.49 .153 .322 r
.91879 .60681 .91911 .60431 .92126 .60614 .9207 .60654 Mtetra
0 0 0 r
.9207 .60654 .92126 .60614 .92329 .60689 .92257 .60594 Mtetra
.619 .751 .94 r
.92257 .60594 .92329 .60689 .92522 .6068 .92447 .60553 Mtetra
.644 .696 .884 r
.92447 .60553 .92522 .6068 .92712 .60641 .92636 .60505 Mtetra
.638 .679 .872 r
.92636 .60505 .92712 .60641 .92901 .60593 .92825 .6046 Mtetra
.542 .636 .893 r
.92825 .6046 .92901 .60593 .93096 .60593 .9302 .60461 Mtetra
.631 .68 .878 r
.9302 .60461 .93096 .60593 .93285 .60551 .9321 .60419 Mtetra
.77 .74 .825 r
.9321 .60419 .93285 .60551 .93464 .60415 .93389 .60285 Mtetra
.957 .76 .595 r
.93389 .60285 .93464 .60415 .93589 .59831 .93512 .59684 Mtetra
.976 .67 .328 r
.93512 .59684 .93589 .59831 .91346 .39633 .91277 .3952 Mtetra
.962 .767 .595 r
.91277 .3952 .91346 .39633 .9146 .39057 .91393 .38964 Mtetra
.765 .796 .878 r
.91393 .38964 .9146 .39057 .91631 .3895 .91564 .38856 Mtetra
.618 .741 .934 r
.91564 .38856 .91631 .3895 .9181 .38915 .91743 .38819 Mtetra
.524 .689 .943 r
.91743 .38819 .9181 .38915 .91994 .38915 .91926 .38815 Mtetra
.664 .747 .911 r
.91926 .38815 .91994 .38915 .92171 .38861 .92104 .3876 Mtetra
.668 .744 .908 r
.92104 .3876 .92171 .38861 .92348 .38805 .92281 .38703 Mtetra
.675 .745 .903 r
.92281 .38703 .92348 .38805 .92525 .38746 .92458 .38642 Mtetra
.763 .775 .863 r
.92458 .38642 .92525 .38746 .92696 .38636 .92628 .38532 Mtetra
.696 .751 .894 r
.92628 .38532 .92696 .38636 .92871 .38564 .92804 .38461 Mtetra
.508 .662 .93 r
.92804 .38461 .92871 .38564 .93057 .38569 .92989 .38465 Mtetra
.737 .321 0 r
.92989 .38465 .93057 .38569 .93304 .39058 .93236 .3895 Mtetra
.97 .655 .291 r
.93236 .3895 .93304 .39058 .96051 .59138 .95981 .59038 Mtetra
.727 .299 0 r
.95981 .59038 .96051 .59138 .96309 .59609 .96239 .59511 Mtetra
.043 .466 .881 r
.34718 .76219 .34813 .76298 .34962 .7636 .34867 .76281 Mtetra
.643 .76 .933 r
.34867 .76281 .34962 .7636 .35115 .76318 .3502 .7624 Mtetra
.809 .777 .824 r
.3502 .7624 .35115 .76318 .35274 .76175 .35179 .76097 Mtetra
.908 .737 .659 r
.35179 .76097 .35274 .76175 .35451 .75648 .35356 .7557 Mtetra
.937 .686 .534 r
.35356 .7557 .35451 .75648 .36505 .56519 .36415 .56435 Mtetra
.908 .727 .645 r
.36415 .56435 .36505 .56519 .36675 .55947 .36586 .55864 Mtetra
.777 .759 .837 r
.36586 .55864 .36675 .55947 .36824 .55836 .36735 .55752 Mtetra
.64 .735 .918 r
.36735 .55752 .36824 .55836 .36969 .55799 .3688 .55716 Mtetra
.508 .69 .95 r
.3688 .55716 .36969 .55799 .37113 .55799 .37024 .55715 Mtetra
.745 .757 .862 r
.37024 .55715 .37113 .55799 .3726 .55712 .37171 .55628 Mtetra
.695 .749 .893 r
.37171 .55628 .3726 .55712 .37407 .55653 .37318 .55569 Mtetra
.477 .677 .953 r
.37318 .55569 .37407 .55653 .37551 .55659 .37462 .55575 Mtetra
.928 .549 .255 r
.37462 .55575 .37551 .55659 .37677 .56062 .37588 .55978 Mtetra
.939 .683 .522 r
.37588 .55978 .37677 .56062 .36995 .7513 .369 .75052 Mtetra
.934 .578 .32 r
.369 .75052 .36995 .7513 .37125 .75642 .37031 .75564 Mtetra
0 .342 .789 r
.37031 .75564 .37125 .75642 .37275 .75724 .3718 .75646 Mtetra
.618 .755 .944 r
.3718 .75646 .37275 .75724 .37429 .75691 .37335 .75613 Mtetra
.8 .781 .835 r
.37335 .75613 .37429 .75691 .37588 .75558 .37494 .7548 Mtetra
.906 .744 .671 r
.37494 .7548 .37588 .75558 .37761 .75091 .37667 .75013 Mtetra
.939 .687 .529 r
.37667 .75013 .37761 .75091 .38694 .55965 .38605 .5588 Mtetra
.915 .724 .63 r
.38605 .5588 .38694 .55965 .38866 .55303 .38778 .55218 Mtetra
.797 .759 .819 r
.38778 .55218 .38866 .55303 .39016 .55173 .38928 .55087 Mtetra
.637 .73 .916 r
.38928 .55087 .39016 .55173 .39163 .55139 .39074 .55052 Mtetra
.488 .673 .946 r
.39074 .55052 .39163 .55139 .39307 .55146 .39219 .55057 Mtetra
.658 .73 .902 r
.39219 .55057 .39307 .55146 .39454 .55114 .39366 .55013 Mtetra
.665 .707 .879 r
.39366 .55013 .39454 .55114 .39601 .55072 .39514 .54966 Mtetra
.632 .686 .883 r
.39514 .54966 .39601 .55072 .39748 .55028 .3966 .54934 Mtetra
.404 .618 .938 r
.3966 .54934 .39748 .55028 .39896 .54977 .39805 .54959 Mtetra
.398 0 0 r
.39805 .54959 .39896 .54977 .40043 .54924 .39949 .55017 Mtetra
.629 .206 .221 r
.39949 .55017 .40043 .54924 .40191 .54869 .40092 .5509 Mtetra
.507 .168 .326 r
.40092 .5509 .40191 .54869 .40339 .54815 .40238 .55081 Mtetra
.444 .127 .331 r
.40238 .55081 .40339 .54815 .40487 .54762 .40386 .55022 Mtetra
.409 .09 .311 r
.40386 .55022 .40487 .54762 .40635 .5471 .40535 .54945 Mtetra
.467 .135 .319 r
.40535 .54945 .40635 .5471 .40782 .5466 .40683 .54908 Mtetra
.468 .141 .329 r
.40683 .54908 .40782 .5466 .4093 .54613 .40831 .54868 Mtetra
.416 .095 .311 r
.40831 .54868 .4093 .54613 .41078 .54567 .4098 .54797 Mtetra
.142 0 .153 r
.4098 .54797 .41078 .54567 .41226 .54523 .41132 .54633 Mtetra
0 0 0 r
.41132 .54633 .41226 .54523 .41374 .54479 .41284 .54467 Mtetra
.851 .927 .879 r
.41284 .54467 .41374 .54479 .41522 .54435 .41435 .5433 Mtetra
.715 .713 .847 r
.41435 .5433 .41522 .54435 .4167 .54391 .41585 .54255 Mtetra
.657 .646 .828 r
.41585 .54255 .4167 .54391 .41819 .54345 .41733 .54208 Mtetra
.635 .637 .835 r
.41733 .54208 .41819 .54345 .41967 .54297 .41881 .54173 Mtetra
.64 .659 .853 r
.41881 .54173 .41967 .54297 .42116 .54239 .42029 .54137 Mtetra
.645 .699 .885 r
.42029 .54137 .42116 .54239 .42265 .54181 .42178 .54098 Mtetra
.649 .743 .919 r
.42178 .54098 .42265 .54181 .42414 .54131 .42326 .54057 Mtetra
.739 .784 .889 r
.42326 .54057 .42414 .54131 .42563 .54078 .42476 .53977 Mtetra
.715 .722 .856 r
.42476 .53977 .42563 .54078 .42711 .5405 .42626 .53903 Mtetra
.624 .619 .825 r
.42626 .53903 .42711 .5405 .42858 .54083 .42774 .53874 Mtetra
.075 .222 .713 r
.42774 .53874 .42858 .54083 .42995 .54447 .42917 .54044 Mtetra
.794 .534 0 r
.42917 .54044 .42995 .54447 .42613 .73523 .43044 .54793 Mtetra
0 0 .345 r
.43044 .54793 .42613 .73523 .42755 .74054 .42674 .73587 Mtetra
.43 .343 .657 r
.42674 .73587 .42755 .74054 .4291 .74141 .42826 .73746 Mtetra
.611 .482 .68 r
.42826 .73746 .4291 .74141 .43068 .74103 .42984 .73701 Mtetra
.636 .497 .675 r
.42984 .73701 .43068 .74103 .43227 .74025 .43144 .73618 Mtetra
.542 .433 .68 r
.43144 .73618 .43227 .74025 .43386 .73971 .433 .73656 Mtetra
.471 .417 .715 r
.433 .73656 .43386 .73971 .43544 .73932 .43455 .73737 Mtetra
.444 .483 .805 r
.43455 .73737 .43544 .73932 .43703 .73885 .43611 .73794 Mtetra
.484 .679 .952 r
.43611 .73794 .43703 .73885 .43862 .73814 .43768 .738 Mtetra
.371 .82 .941 r
.43768 .738 .43862 .73814 .44022 .73726 .43927 .73773 Mtetra
.007 0 0 r
.43927 .73773 .44022 .73726 .44182 .73636 .44086 .73732 Mtetra
.339 0 0 r
.44086 .73732 .44182 .73636 .4434 .73609 .44244 .73707 Mtetra
.304 0 0 r
.44244 .73707 .4434 .73609 .44499 .73593 .44403 .73673 Mtetra
0 0 0 r
.44403 .73673 .44499 .73593 .44658 .73517 .44563 .73593 Mtetra
.913 .975 .691 r
.44563 .73593 .44658 .73517 .44825 .73128 .44727 .7333 Mtetra
.994 .858 .518 r
.44727 .7333 .44825 .73128 .45388 .53966 .44901 .72587 Mtetra
0 0 .339 r
.44901 .72587 .45388 .53966 .45552 .53257 .45458 .53553 Mtetra
0 0 .105 r
.45458 .53553 .45552 .53257 .45706 .53063 .45614 .53253 Mtetra
.373 .017 .226 r
.45614 .53253 .45706 .53063 .45856 .53005 .45765 .53188 Mtetra
.506 .144 .286 r
.45765 .53188 .45856 .53005 .46006 .52986 .45915 .53186 Mtetra
.482 .13 .292 r
.45915 .53186 .46006 .52986 .46157 .52957 .46065 .53167 Mtetra
.442 .097 .284 r
.46065 .53167 .46157 .52957 .46308 .52912 .46216 .53124 Mtetra
.445 .101 .287 r
.46216 .53124 .46308 .52912 .46458 .52868 .46367 .53081 Mtetra
.471 .128 .301 r
.46367 .53081 .46458 .52868 .46609 .52823 .46518 .53052 Mtetra
.479 .143 .318 r
.46518 .53052 .46609 .52823 .4676 .52779 .46669 .53023 Mtetra
.439 .112 .313 r
.46669 .53023 .4676 .52779 .46911 .52735 .4682 .52967 Mtetra
.248 0 .214 r
.4682 .52967 .46911 .52735 .47062 .52693 .46973 .52831 Mtetra
0 0 0 r
.46973 .52831 .47062 .52693 .47214 .52651 .47127 .52664 Mtetra
.839 .987 .864 r
.47127 .52664 .47214 .52651 .47365 .52608 .4728 .52522 Mtetra
.747 .763 .866 r
.4728 .52522 .47365 .52608 .47516 .52561 .47432 .52433 Mtetra
.665 .664 .839 r
.47432 .52433 .47516 .52561 .47668 .5251 .47583 .52382 Mtetra
.642 .655 .847 r
.47583 .52382 .47668 .5251 .4782 .52459 .47735 .52343 Mtetra
.649 .678 .864 r
.47735 .52343 .4782 .52459 .47972 .52409 .47887 .52301 Mtetra
.661 .698 .873 r
.47887 .52301 .47972 .52409 .48123 .52361 .48038 .52254 Mtetra
.662 .7 .875 r
.48038 .52254 .48123 .52361 .48275 .52313 .4819 .52208 Mtetra
.662 .702 .876 r
.4819 .52208 .48275 .52313 .48427 .52266 .48342 .5216 Mtetra
.663 .703 .877 r
.48342 .5216 .48427 .52266 .48579 .52218 .48494 .52113 Mtetra
.663 .704 .877 r
.48494 .52113 .48579 .52218 .48731 .5217 .48647 .52065 Mtetra
.663 .705 .878 r
.48647 .52065 .48731 .5217 .48884 .52122 .48799 .52017 Mtetra
.664 .705 .878 r
.48799 .52017 .48884 .52122 .49036 .52074 .48951 .51969 Mtetra
.48951 .51969 .49036 .52074 .49188 .52026 .49104 .51922 Mtetra
.49104 .51922 .49188 .52026 .49341 .51978 .49256 .51874 Mtetra
.49256 .51874 .49341 .51978 .49493 .5193 .49409 .51826 Mtetra
.49409 .51826 .49493 .5193 .49646 .51882 .49562 .51778 Mtetra
.49562 .51778 .49646 .51882 .49799 .51834 .49714 .51729 Mtetra
.49714 .51729 .49799 .51834 .49952 .51786 .49867 .51681 Mtetra
.49867 .51681 .49952 .51786 .50105 .51738 .5002 .51633 Mtetra
.663 .704 .878 r
.5002 .51633 .50105 .51738 .50258 .51691 .50173 .51585 Mtetra
.663 .704 .877 r
.50173 .51585 .50258 .51691 .50411 .51643 .50326 .51537 Mtetra
.50326 .51537 .50411 .51643 .50564 .51595 .5048 .5149 Mtetra
.662 .704 .878 r
.5048 .5149 .50564 .51595 .50717 .51548 .50633 .51442 Mtetra
.662 .703 .878 r
.50633 .51442 .50717 .51548 .5087 .515 .50786 .51394 Mtetra
.50786 .51394 .5087 .515 .51024 .51453 .5094 .51347 Mtetra
.661 .703 .878 r
.5094 .51347 .51024 .51453 .51177 .51406 .51093 .513 Mtetra
.66 .703 .878 r
.51093 .513 .51177 .51406 .51331 .51359 .51247 .51253 Mtetra
.659 .703 .879 r
.51247 .51253 .51331 .51359 .51484 .51313 .51401 .51207 Mtetra
.51401 .51207 .51484 .51313 .51638 .51266 .51554 .51161 Mtetra
.51554 .51161 .51638 .51266 .51792 .5122 .51708 .51114 Mtetra
.655 .701 .88 r
.51708 .51114 .51792 .5122 .51946 .51175 .51862 .5107 Mtetra
.645 .7 .886 r
.51862 .5107 .51946 .51175 .521 .5113 .52016 .5103 Mtetra
.631 .706 .9 r
.52016 .5103 .521 .5113 .52254 .51085 .5217 .50996 Mtetra
.626 .728 .92 r
.5217 .50996 .52254 .51085 .52408 .51041 .52325 .50963 Mtetra
.631 .757 .938 r
.52325 .50963 .52408 .51041 .52563 .50996 .52479 .50926 Mtetra
.645 .781 .947 r
.52479 .50926 .52563 .50996 .52717 .50951 .52633 .50883 Mtetra
.65 .789 .948 r
.52633 .50883 .52717 .50951 .52871 .50906 .52788 .50837 Mtetra
.652 .79 .948 r
.52788 .50837 .52871 .50906 .53026 .5086 .52943 .50791 Mtetra
.651 .789 .948 r
.52943 .50791 .53026 .5086 .53181 .50814 .53097 .50746 Mtetra
.653 .792 .948 r
.53097 .50746 .53181 .50814 .53335 .50767 .53252 .50699 Mtetra
.655 .793 .949 r
.53252 .50699 .53335 .50767 .5349 .50719 .53407 .50652 Mtetra
.656 .795 .949 r
.53407 .50652 .5349 .50719 .53645 .50671 .53562 .50605 Mtetra
.659 .797 .949 r
.53562 .50605 .53645 .50671 .538 .50622 .53717 .50556 Mtetra
.663 .8 .948 r
.53717 .50556 .538 .50622 .53955 .50571 .53872 .50506 Mtetra
.668 .803 .947 r
.53872 .50506 .53955 .50571 .5411 .50518 .54027 .50454 Mtetra
.67 .806 .948 r
.54027 .50454 .5411 .50518 .54266 .50465 .54183 .50401 Mtetra
.706 .816 .933 r
.54183 .50401 .54266 .50465 .54421 .50395 .54338 .50335 Mtetra
.746 .83 .916 r
.54338 .50335 .54421 .50395 .54576 .50306 .54493 .50251 Mtetra
.649 .828 .969 r
.54493 .50251 .54576 .50306 .54731 .5026 .54649 .50202 Mtetra
.037 .505 .884 r
.54649 .50202 .54731 .5026 .54888 .5035 .54805 .50254 Mtetra
.878 .454 .044 r
.54805 .50254 .54888 .5035 .5505 .51085 .54964 .50616 Mtetra
.964 .691 .466 r
.54964 .50616 .5505 .51085 .55363 .70356 .55271 .69704 Mtetra
.077 .068 .543 r
.55271 .69704 .55363 .70356 .55532 .70654 .55442 .70284 Mtetra
.463 .394 .694 r
.55442 .70284 .55532 .70654 .55698 .70643 .55609 .70391 Mtetra
.538 .494 .755 r
.55609 .70391 .55698 .70643 .55863 .70567 .55775 .70417 Mtetra
.561 .603 .853 r
.55775 .70417 .55863 .70567 .56029 .7049 .55941 .70415 Mtetra
.451 .71 .978 r
.55941 .70415 .56029 .7049 .56195 .70484 .56108 .70419 Mtetra
.674 .818 .952 r
.56108 .70419 .56195 .70484 .56361 .7043 .56274 .7036 Mtetra
.869 .812 .792 r
.56274 .7036 .56361 .7043 .56525 .70233 .56438 .70152 Mtetra
.949 .732 .574 r
.56438 .70152 .56525 .70233 .5668 .69252 .56593 .69131 Mtetra
.959 .69 .481 r
.56593 .69131 .5668 .69252 .56608 .49986 .56525 .49877 Mtetra
.89 .741 .69 r
.56525 .49877 .56608 .49986 .56761 .49629 .56678 .49523 Mtetra
.724 .728 .853 r
.56678 .49523 .56761 .49629 .56917 .49546 .56835 .49441 Mtetra
.612 .689 .898 r
.56835 .49441 .56917 .49546 .57074 .4952 .56992 .49414 Mtetra
.563 .668 .908 r
.56992 .49414 .57074 .4952 .57231 .49512 .57149 .49404 Mtetra
.652 .701 .882 r
.57149 .49404 .57231 .49512 .57388 .49468 .57306 .49361 Mtetra
.651 .7 .882 r
.57306 .49361 .57388 .49468 .57546 .49425 .57464 .49317 Mtetra
.653 .7 .881 r
.57464 .49317 .57546 .49425 .57703 .49381 .57621 .49273 Mtetra
.656 .701 .88 r
.57621 .49273 .57703 .49381 .5786 .49336 .57778 .49227 Mtetra
.657 .701 .879 r
.57778 .49227 .5786 .49336 .58018 .4929 .57936 .49181 Mtetra
.658 .7 .878 r
.57936 .49181 .58018 .4929 .58175 .49243 .58093 .49134 Mtetra
.658 .7 .877 r
.58093 .49134 .58175 .49243 .58333 .49196 .58251 .49087 Mtetra
.659 .7 .877 r
.58251 .49087 .58333 .49196 .5849 .4915 .58409 .4904 Mtetra
.659 .698 .875 r
.58409 .4904 .5849 .4915 .58648 .49105 .58566 .48992 Mtetra
.659 .694 .871 r
.58566 .48992 .58648 .49105 .58806 .49063 .58724 .48944 Mtetra
.659 .684 .862 r
.58724 .48944 .58806 .49063 .58964 .4902 .58882 .48896 Mtetra
.662 .676 .852 r
.58882 .48896 .58964 .4902 .59122 .48976 .5904 .48846 Mtetra
.678 .672 .837 r
.5904 .48846 .59122 .48976 .5928 .48928 .59198 .48785 Mtetra
.659 .647 .828 r
.59198 .48785 .5928 .48928 .59438 .48876 .59356 .48734 Mtetra
.617 .629 .84 r
.59356 .48734 .59438 .48876 .59597 .48823 .59515 .48706 Mtetra
.417 .575 .903 r
.59515 .48706 .59597 .48823 .59755 .48767 .59675 .48743 Mtetra
.316 0 0 r
.59675 .48743 .59755 .48767 .59913 .48711 .59836 .48807 Mtetra
.588 .147 .168 r
.59836 .48807 .59913 .48711 .60071 .4865 .59997 .48867 Mtetra
.359 .025 .257 r
.59997 .48867 .60071 .4865 .60229 .4856 .60155 .48776 Mtetra
.414 .075 .28 r
.60155 .48776 .60229 .4856 .60387 .48505 .60314 .48713 Mtetra
.589 .237 .341 r
.60314 .48713 .60387 .48505 .60548 .48529 .60475 .48768 Mtetra
.959 .68 .461 r
.60475 .48768 .60548 .48529 .60718 .48923 .61096 .67482 Mtetra
.584 .369 .554 r
.61096 .67482 .60718 .48923 .6137 .6833 .61296 .68683 Mtetra
.702 .389 .443 r
.61296 .68683 .6137 .6833 .61554 .68878 .61473 .68949 Mtetra
.412 0 0 r
.61473 .68949 .61554 .68878 .61726 .6894 .61644 .68957 Mtetra
.3 .791 .762 r
.61644 .68957 .61726 .6894 .61896 .68927 .61813 .68902 Mtetra
.746 .942 .947 r
.61813 .68902 .61896 .68927 .62066 .68879 .61981 .68803 Mtetra
.753 .813 .9 r
.61981 .68803 .62066 .68879 .62237 .68877 .6215 .68707 Mtetra
.757 .668 .764 r
.6215 .68707 .62237 .68877 .62406 .68832 .62316 .68556 Mtetra
.771 .614 .685 r
.62316 .68556 .62406 .68832 .62574 .6871 .6248 .68285 Mtetra
.961 .686 .469 r
.6248 .68285 .62574 .6871 .62731 .68222 .6212 .49968 Mtetra
.598 .383 .561 r
.6212 .49968 .62731 .68222 .62323 .48729 .62228 .4813 Mtetra
.707 .515 .626 r
.62228 .4813 .62323 .48729 .62464 .48033 .62379 .47792 Mtetra
.668 .568 .733 r
.62379 .47792 .62464 .48033 .62621 .47878 .62538 .47708 Mtetra
.622 .599 .806 r
.62538 .47708 .62621 .47878 .6278 .47797 .62699 .47677 Mtetra
.562 .642 .887 r
.62699 .47677 .6278 .47797 .6294 .47753 .62861 .4767 Mtetra
.707 .776 .906 r
.62861 .4767 .6294 .47753 .631 .477 .6302 .47601 Mtetra
.69 .735 .885 r
.6302 .47601 .631 .477 .63261 .47656 .6318 .47538 Mtetra
.651 .686 .869 r
.6318 .47538 .63261 .47656 .63421 .47615 .63341 .47494 Mtetra
.574 .645 .883 r
.63341 .47494 .63421 .47615 .6358 .47523 .63503 .47483 Mtetra
.02 .538 .862 r
.63503 .47483 .6358 .47523 .63741 .4746 .63666 .47522 Mtetra
.712 .253 .161 r
.63666 .47522 .63741 .4746 .63903 .47457 .63834 .47662 Mtetra
.937 .635 .445 r
.63834 .47662 .63903 .47457 .64077 .47786 .64083 .5013 Mtetra
.927 .645 .488 r
.64083 .5013 .64077 .47786 .64929 .67149 .64867 .67653 Mtetra
.683 .39 .471 r
.64867 .67653 .64929 .67149 .65128 .6786 .6505 .67947 Mtetra
.484 .009 .052 r
.6505 .67947 .65128 .6786 .65304 .6794 .65224 .6797 Mtetra
0 0 0 r
.65224 .6797 .65304 .6794 .65476 .6793 .65396 .67922 Mtetra
.689 .965 .936 r
.65396 .67922 .65476 .6793 .65648 .6788 .65566 .67827 Mtetra
.744 .872 .939 r
.65566 .67827 .65648 .6788 .65822 .67891 .65736 .67736 Mtetra
.753 .684 .784 r
.65736 .67736 .65822 .67891 .65995 .67864 .65904 .67601 Mtetra
.756 .612 .699 r
.65904 .67601 .65995 .67864 .66164 .67765 .66069 .67376 Mtetra
.857 .635 .601 r
.66069 .67376 .66164 .67765 .6632 .67297 .6621 .66535 Mtetra
.96 .681 .462 r
.6621 .66535 .6632 .67297 .65708 .47675 .65616 .4726 Mtetra
.772 .578 .636 r
.65616 .4726 .65708 .47675 .65842 .46948 .65763 .46842 Mtetra
.763 .744 .835 r
.65763 .46842 .65842 .46948 .66001 .46813 .65923 .4673 Mtetra
.634 .755 .935 r
.65923 .4673 .66001 .46813 .66163 .46775 .66085 .4669 Mtetra
.532 .71 .953 r
.66085 .4669 .66163 .46775 .66328 .4678 .66249 .46682 Mtetra
.659 .728 .9 r
.66249 .46682 .66328 .4678 .66491 .46745 .66412 .46633 Mtetra
.671 .706 .873 r
.66412 .46633 .66491 .46745 .66653 .46703 .66574 .46578 Mtetra
.666 .681 .855 r
.66574 .46578 .66653 .46703 .66816 .46658 .66736 .46525 Mtetra
.646 .658 .848 r
.66736 .46525 .66816 .46658 .66979 .46608 .66899 .46481 Mtetra
.643 .667 .858 r
.66899 .46481 .66979 .46608 .67141 .46554 .67062 .46439 Mtetra
.648 .691 .876 r
.67062 .46439 .67141 .46554 .67303 .46497 .67225 .46396 Mtetra
.671 .726 .891 r
.67225 .46396 .67303 .46497 .67465 .4643 .67388 .46342 Mtetra
.685 .76 .909 r
.67388 .46342 .67465 .4643 .67628 .46364 .6755 .46282 Mtetra
.694 .777 .915 r
.6755 .46282 .67628 .46364 .6779 .46307 .67713 .46218 Mtetra
.763 .779 .866 r
.67713 .46218 .6779 .46307 .67953 .4624 .67873 .46114 Mtetra
.714 .699 .835 r
.67873 .46114 .67953 .4624 .68116 .46204 .68035 .46031 Mtetra
.62 .597 .805 r
.68035 .46031 .68116 .46204 .68284 .46238 .68199 .46 Mtetra
.187 .276 .724 r
.68199 .46 .68284 .46238 .68473 .46711 .68374 .46193 Mtetra
0 0 .273 r
.68374 .46193 .68473 .46711 .69598 .6625 .68588 .47159 Mtetra
.064 0 .45 r
.68588 .47159 .69598 .6625 .69797 .66701 .69697 .66246 Mtetra
.377 .318 .664 r
.69697 .66246 .69797 .66701 .69976 .66764 .69884 .6647 Mtetra
.497 .449 .734 r
.69884 .6647 .69976 .66764 .70151 .66721 .70065 .66535 Mtetra
.555 .56 .814 r
.70065 .66535 .70151 .66721 .70324 .66633 .70242 .66541 Mtetra
.488 .689 .956 r
.70242 .66541 .70324 .66633 .70498 .66577 .70419 .66545 Mtetra
.472 .843 .99 r
.70419 .66545 .70498 .66577 .70671 .66503 .70595 .66513 Mtetra
.572 .941 .862 r
.70595 .66513 .70671 .66503 .70841 .6636 .70767 .6642 Mtetra
.905 .957 .622 r
.70767 .6642 .70841 .6636 .70991 .65843 .70929 .66124 Mtetra
.846 .759 .247 r
.70929 .66124 .70991 .65843 .70112 .46151 .71063 .653 Mtetra
.06 0 .443 r
.71063 .653 .70112 .46151 .70247 .4556 .7019 .45838 Mtetra
0 0 .152 r
.7019 .45838 .70247 .4556 .70405 .45398 .70339 .45494 Mtetra
0 0 0 r
.70339 .45494 .70405 .45398 .7057 .45346 .70497 .45331 Mtetra
.747 .968 .932 r
.70497 .45331 .7057 .45346 .70736 .45331 .70659 .45228 Mtetra
.692 .732 .882 r
.70659 .45228 .70736 .45331 .70901 .45284 .70823 .45163 Mtetra
.646 .68 .868 r
.70823 .45163 .70901 .45284 .71066 .45225 .70989 .45119 Mtetra
.624 .703 .902 r
.70989 .45119 .71066 .45225 .71231 .45172 .71155 .45086 Mtetra
.726 .779 .895 r
.71155 .45086 .71231 .45172 .71395 .45115 .71318 .45005 Mtetra
.716 .729 .861 r
.71318 .45005 .71395 .45115 .71561 .4508 .71482 .44925 Mtetra
.63 .623 .825 r
.71482 .44925 .71561 .4508 .71731 .45105 .71648 .44888 Mtetra
.282 .357 .763 r
.71648 .44888 .71731 .45105 .71919 .45436 .71825 .45032 Mtetra
0 0 .479 r
.71825 .45032 .71919 .45436 .73259 .65019 .72028 .45621 Mtetra
.08 .003 .459 r
.72028 .45621 .73259 .65019 .73474 .65623 .73368 .65098 Mtetra
.332 .274 .642 r
.73368 .65098 .73474 .65623 .7366 .65718 .73566 .65408 Mtetra
.481 .433 .727 r
.73566 .65408 .7366 .65718 .73837 .65675 .73751 .6549 Mtetra
.539 .554 .819 r
.73751 .6549 .73837 .65675 .74011 .65588 .73931 .65505 Mtetra
.562 .744 .962 r
.73931 .65505 .74011 .65588 .74187 .65531 .7411 .65483 Mtetra
.58 .851 .995 r
.7411 .65483 .74187 .65531 .74365 .65493 .74287 .65439 Mtetra
.641 .855 .981 r
.74287 .65439 .74365 .65493 .74542 .65448 .74464 .65383 Mtetra
.537 .784 .989 r
.74464 .65383 .74542 .65448 .7472 .65406 .74643 .65359 Mtetra
.486 .813 1 r
.74643 .65359 .7472 .65406 .74896 .65343 .74822 .65335 Mtetra
.545 .922 .928 r
.74822 .65335 .74896 .65343 .75069 .65216 .74998 .65265 Mtetra
.858 .97 .652 r
.74998 .65265 .75069 .65216 .75222 .64792 .75163 .65015 Mtetra
.813 .763 .25 r
.75163 .65015 .75222 .64792 .74103 .45108 .753 .64349 Mtetra
.078 0 .454 r
.753 .64349 .74103 .45108 .74225 .44378 .74178 .4472 Mtetra
0 0 .213 r
.74178 .4472 .74225 .44378 .74381 .44179 .74321 .44296 Mtetra
0 0 0 r
.74321 .44296 .74381 .44179 .74548 .44123 .74479 .44121 Mtetra
.708 .982 .895 r
.74479 .44121 .74548 .44123 .74718 .44109 .74643 .44013 Mtetra
.694 .752 .896 r
.74643 .44013 .74718 .44109 .74886 .44083 .74809 .43947 Mtetra
.637 .656 .851 r
.74809 .43947 .74886 .44083 .75054 .44037 .74977 .43907 Mtetra
.612 .654 .867 r
.74977 .43907 .75054 .44037 .75221 .43988 .75146 .4388 Mtetra
.635 .703 .895 r
.75146 .4388 .75221 .43988 .75388 .43928 .75314 .43841 Mtetra
.665 .761 .922 r
.75314 .43841 .75388 .43928 .75555 .43863 .75482 .43788 Mtetra
.673 .796 .94 r
.75482 .43788 .75555 .43863 .75722 .43805 .75649 .4373 Mtetra
.741 .817 .911 r
.75649 .4373 .75722 .43805 .75889 .43745 .75814 .43643 Mtetra
.733 .752 .867 r
.75814 .43643 .75889 .43745 .76058 .43704 .75979 .43553 Mtetra
.645 .638 .828 r
.75979 .43553 .76058 .43704 .7623 .43721 .76147 .43507 Mtetra
.367 .414 .778 r
.76147 .43507 .7623 .43721 .76422 .43994 .76327 .43617 Mtetra
0 0 .535 r
.76327 .43617 .76422 .43994 .78043 .63599 .76538 .44138 Mtetra
.101 .022 .471 r
.76538 .44138 .78043 .63599 .78277 .64289 .78164 .63727 Mtetra
.304 .251 .632 r
.78164 .63727 .78277 .64289 .78471 .64431 .78374 .64097 Mtetra
.482 .425 .717 r
.78374 .64097 .78471 .64431 .78652 .64404 .78564 .64186 Mtetra
.543 .527 .788 r
.78564 .64186 .78652 .64404 .78829 .64325 .78749 .64205 Mtetra
.533 .649 .909 r
.78749 .64205 .78829 .64325 .79008 .64253 .78933 .64206 Mtetra
.464 .802 .999 r
.78933 .64206 .79008 .64253 .79187 .6419 .79116 .64186 Mtetra
.536 .922 .909 r
.79116 .64186 .79187 .6419 .79361 .64069 .79294 .64111 Mtetra
.816 .973 .669 r
.79294 .64111 .79361 .64069 .79517 .63714 .79461 .63889 Mtetra
.824 .788 .288 r
.79461 .63889 .79517 .63714 .78162 .44146 .796 .63311 Mtetra
.093 .012 .463 r
.796 .63311 .78162 .44146 .78259 .43173 .78225 .43581 Mtetra
0 0 .256 r
.78225 .43581 .78259 .43173 .78413 .42928 .78358 .43061 Mtetra
0 0 0 r
.78358 .43061 .78413 .42928 .78581 .4286 .78516 .42871 Mtetra
.67 .974 .831 r
.78516 .42871 .78581 .4286 .78753 .42838 .7868 .42753 Mtetra
.711 .787 .911 r
.7868 .42753 .78753 .42838 .78924 .42809 .78848 .42679 Mtetra
.65 .672 .858 r
.78848 .42679 .78924 .42809 .79093 .42753 .79018 .42632 Mtetra
.625 .676 .878 r
.79018 .42632 .79093 .42753 .79263 .42702 .79189 .42597 Mtetra
.688 .734 .886 r
.79189 .42597 .79263 .42702 .79432 .42647 .79358 .42532 Mtetra
.729 .732 .853 r
.79358 .42532 .79432 .42647 .79602 .42596 .79525 .42441 Mtetra
.656 .64 .822 r
.79525 .42441 .79602 .42596 .79777 .42597 .79695 .42388 Mtetra
.44 .464 .788 r
.79695 .42388 .79777 .42597 .79968 .42797 .79875 .42463 Mtetra
0 .081 .603 r
.79875 .42463 .79968 .42797 .81794 .62203 .80085 .42877 Mtetra
.112 .033 .479 r
.80085 .42877 .81794 .62203 .82063 .63183 .81938 .6252 Mtetra
.275 .22 .612 r
.81938 .6252 .82063 .63183 .82266 .63369 .82166 .63003 Mtetra
.487 .417 .704 r
.82166 .63003 .82266 .63369 .8245 .63347 .8236 .63098 Mtetra
.547 .509 .764 r
.8236 .63098 .8245 .63347 .8263 .63268 .82548 .63118 Mtetra
.532 .599 .866 r
.82548 .63118 .8263 .63268 .82809 .63191 .82736 .63128 Mtetra
.379 .715 .987 r
.82736 .63128 .82809 .63191 .82992 .63141 .82924 .63137 Mtetra
.416 .863 .886 r
.82924 .63137 .82992 .63141 .8317 .6304 .83106 .6308 Mtetra
.828 .968 .65 r
.83106 .6308 .8317 .6304 .83331 .62756 .83272 .62844 Mtetra
.994 .795 .423 r
.83272 .62844 .83331 .62756 .83356 .60948 .83371 .61864 Mtetra
.981 .688 .343 r
.83371 .61864 .83356 .60948 .81842 .42157 .8177 .42063 Mtetra
.925 .792 .694 r
.8177 .42063 .81842 .42157 .81991 .41859 .81916 .41726 Mtetra
.684 .683 .843 r
.81916 .41726 .81991 .41859 .8216 .41786 .82086 .41657 Mtetra
.564 .636 .881 r
.82086 .41657 .8216 .41786 .82335 .41765 .82261 .4165 Mtetra
.537 .649 .907 r
.82261 .4165 .82335 .41765 .8251 .41746 .82438 .4165 Mtetra
.639 .737 .919 r
.82438 .4165 .8251 .41746 .82681 .41691 .82611 .41607 Mtetra
.643 .769 .94 r
.82611 .41607 .82681 .41691 .82853 .41642 .82783 .4156 Mtetra
.655 .781 .941 r
.82783 .4156 .82853 .41642 .83028 .41616 .82955 .41509 Mtetra
.671 .727 .892 r
.82955 .41509 .83028 .41616 .83206 .41626 .83127 .41452 Mtetra
.657 .62 .801 r
.83127 .41452 .83206 .41626 .83384 .41639 .83299 .41394 Mtetra
.637 .554 .744 r
.83299 .41394 .83384 .41639 .83559 .41608 .83471 .41338 Mtetra
.628 .535 .73 r
.83471 .41338 .83559 .41608 .83726 .41499 .83643 .41287 Mtetra
.64 .577 .769 r
.83643 .41287 .83726 .41499 .83892 .4138 .83816 .41235 Mtetra
.668 .661 .834 r
.83816 .41235 .83892 .4138 .8406 .41279 .83988 .41175 Mtetra
.704 .746 .884 r
.83988 .41175 .8406 .41279 .84231 .41209 .84159 .41101 Mtetra
.684 .73 .885 r
.84159 .41101 .84231 .41209 .84402 .41146 .8433 .41037 Mtetra
.644 .712 .897 r
.8433 .41037 .84402 .41146 .84573 .41067 .84504 .40992 Mtetra
.525 .742 .974 r
.84504 .40992 .84573 .41067 .8474 .40961 .84681 .40979 Mtetra
.377 0 0 r
.84681 .40979 .8474 .40961 .84913 .40902 .84864 .41024 Mtetra
.755 .337 .256 r
.84864 .41024 .84913 .40902 .85099 .40981 .85066 .41252 Mtetra
.973 .666 .356 r
.85066 .41252 .85099 .40981 .85354 .41735 .87222 .60781 Mtetra
.577 .362 .553 r
.87222 .60781 .85354 .41735 .87554 .61544 .8749 .61544 Mtetra
.715 .18 0 r
.8749 .61544 .87554 .61544 .87776 .61854 .87701 .61749 Mtetra
.507 .672 .938 r
.87701 .61749 .87776 .61854 .87965 .61841 .87892 .61752 Mtetra
.66 .778 .936 r
.87892 .61752 .87965 .61841 .88148 .61764 .88077 .61695 Mtetra
.738 .853 .934 r
.88077 .61695 .88148 .61764 .88331 .61685 .88259 .61601 Mtetra
.758 .822 .902 r
.88259 .61601 .88331 .61685 .88522 .61683 .88439 .61495 Mtetra
.763 .669 .759 r
.88439 .61495 .88522 .61683 .88708 .61634 .88613 .61328 Mtetra
.791 .619 .667 r
.88613 .61328 .88708 .61634 .88881 .61454 .88769 .60993 Mtetra
.976 .674 .364 r
.88769 .60993 .88881 .61454 .8899 .60677 .86893 .41535 Mtetra
.584 .371 .558 r
.86893 .41535 .8899 .60677 .87038 .40649 .86957 .40447 Mtetra
.834 .679 .69 r
.86957 .40447 .87038 .40649 .87173 .40226 .87105 .40146 Mtetra
.73 .812 .915 r
.87105 .40146 .87173 .40226 .87344 .40136 .87277 .40061 Mtetra
.605 .781 .965 r
.87277 .40061 .87344 .40136 .87521 .40109 .87453 .40024 Mtetra
.587 .748 .954 r
.87453 .40024 .87521 .40109 .87701 .40101 .87631 .39996 Mtetra
.71 .75 .883 r
.87631 .39996 .87701 .40101 .87875 .40046 .87803 .39918 Mtetra
.684 .696 .855 r
.87803 .39918 .87875 .40046 .8805 .3999 .87976 .3985 Mtetra
.644 .66 .851 r
.87976 .3985 .8805 .3999 .88223 .39923 .88152 .39805 Mtetra
.559 .655 .899 r
.88152 .39805 .88223 .39923 .88394 .39825 .88332 .39797 Mtetra
0 .473 .785 r
.88332 .39797 .88394 .39825 .88568 .39764 .88519 .39847 Mtetra
.746 .288 .163 r
.88519 .39847 .88568 .39764 .88753 .39794 .88724 .4005 Mtetra
.973 .661 .335 r
.88724 .4005 .88753 .39794 .88983 .40224 .91114 .59598 Mtetra
.578 .363 .553 r
.91114 .59598 .88983 .40224 .91429 .60132 .91407 .60476 Mtetra
.681 .347 .404 r
.91407 .60476 .91429 .60132 .9168 .60635 .91627 .60705 Mtetra
.356 0 0 r
.91627 .60705 .9168 .60635 .91879 .60681 .9182 .60702 Mtetra
.24 .74 .669 r
.9182 .60702 .91879 .60681 .9207 .60654 .92007 .60635 Mtetra
.718 .976 .922 r
.92007 .60635 .9207 .60654 .92257 .60594 .92188 .60522 Mtetra
.828 .869 .876 r
.92188 .60522 .92257 .60594 .92447 .60553 .92365 .60374 Mtetra
.777 .684 .762 r
.92365 .60374 .92447 .60553 .92636 .60505 .92539 .60196 Mtetra
.709 .574 .701 r
.92539 .60196 .92636 .60505 .92825 .6046 .92714 .60025 Mtetra
.579 .46 .681 r
.92714 .60025 .92825 .6046 .9302 .60461 .92908 .6002 Mtetra
.595 .468 .678 r
.92908 .6002 .9302 .60461 .9321 .60419 .93099 .59992 Mtetra
.661 .512 .671 r
.93099 .59992 .9321 .60419 .93389 .60285 .93278 .59852 Mtetra
.899 .648 .549 r
.93278 .59852 .93389 .60285 .93512 .59684 .93336 .58707 Mtetra
.973 .665 .358 r
.93336 .58707 .93512 .59684 .91277 .3952 .91189 .39251 Mtetra
.831 .646 .653 r
.91189 .39251 .91277 .3952 .91393 .38964 .91326 .38866 Mtetra
.742 .778 .882 r
.91326 .38866 .91393 .38964 .91564 .38856 .91498 .3877 Mtetra
.624 .762 .945 r
.91498 .3877 .91564 .38856 .91743 .38819 .91677 .38729 Mtetra
.555 .719 .95 r
.91677 .38729 .91743 .38819 .91926 .38815 .91859 .38713 Mtetra
.667 .742 .906 r
.91859 .38713 .91926 .38815 .92104 .3876 .92036 .38656 Mtetra
.671 .74 .902 r
.92036 .38656 .92104 .3876 .92281 .38703 .92213 .38597 Mtetra
.677 .74 .898 r
.92213 .38597 .92281 .38703 .92458 .38642 .92389 .38536 Mtetra
.76 .769 .86 r
.92389 .38536 .92458 .38642 .92628 .38532 .9256 .38426 Mtetra
.695 .745 .89 r
.9256 .38426 .92628 .38532 .92804 .38461 .92736 .38354 Mtetra
.511 .659 .926 r
.92736 .38354 .92804 .38461 .92989 .38465 .92921 .38359 Mtetra
.727 .313 0 r
.92921 .38359 .92989 .38465 .93236 .3895 .93167 .38839 Mtetra
.97 .655 .291 r
.93167 .38839 .93236 .3895 .95981 .59038 .9591 .58935 Mtetra
.724 .299 0 r
.9591 .58935 .95981 .59038 .96239 .59511 .96169 .59413 Mtetra
.039 .462 .879 r
.34623 .7614 .34718 .76219 .34867 .76281 .34771 .76203 Mtetra
.642 .759 .933 r
.34771 .76203 .34867 .76281 .3502 .7624 .34925 .76162 Mtetra
.808 .777 .824 r
.34925 .76162 .3502 .7624 .35179 .76097 .35084 .76019 Mtetra
.908 .737 .659 r
.35084 .76019 .35179 .76097 .35356 .7557 .35261 .75491 Mtetra
.937 .686 .534 r
.35261 .75491 .35356 .7557 .36415 .56435 .36326 .56352 Mtetra
.908 .727 .645 r
.36326 .56352 .36415 .56435 .36586 .55864 .36497 .5578 Mtetra
.777 .759 .837 r
.36497 .5578 .36586 .55864 .36735 .55752 .36646 .55669 Mtetra
.64 .735 .918 r
.36646 .55669 .36735 .55752 .3688 .55716 .36791 .55632 Mtetra
.508 .69 .95 r
.36791 .55632 .3688 .55716 .37024 .55715 .36935 .55632 Mtetra
.745 .757 .862 r
.36935 .55632 .37024 .55715 .37171 .55628 .37082 .55545 Mtetra
.695 .749 .893 r
.37082 .55545 .37171 .55628 .37318 .55569 .37229 .55486 Mtetra
.477 .677 .953 r
.37229 .55486 .37318 .55569 .37462 .55575 .37373 .55491 Mtetra
.928 .549 .255 r
.37373 .55491 .37462 .55575 .37588 .55978 .37499 .55894 Mtetra
.939 .683 .522 r
.37499 .55894 .37588 .55978 .369 .75052 .36806 .74974 Mtetra
.934 .578 .319 r
.36806 .74974 .369 .75052 .37031 .75564 .36936 .75486 Mtetra
0 .342 .79 r
.36936 .75486 .37031 .75564 .3718 .75646 .37086 .75568 Mtetra
.618 .755 .943 r
.37086 .75568 .3718 .75646 .37335 .75613 .37241 .75535 Mtetra
.8 .781 .835 r
.37241 .75535 .37335 .75613 .37494 .7548 .37399 .75402 Mtetra
.905 .744 .67 r
.37399 .75402 .37494 .7548 .37667 .75013 .37572 .74934 Mtetra
.939 .687 .529 r
.37572 .74934 .37667 .75013 .38605 .5588 .38517 .55793 Mtetra
.914 .723 .63 r
.38517 .55793 .38605 .5588 .38778 .55218 .38689 .55133 Mtetra
.797 .758 .817 r
.38689 .55133 .38778 .55218 .38928 .55087 .38839 .55 Mtetra
.641 .73 .913 r
.38839 .55 .38928 .55087 .39074 .55052 .38986 .54963 Mtetra
.496 .675 .944 r
.38986 .54963 .39074 .55052 .39219 .55057 .39131 .54967 Mtetra
.691 .737 .886 r
.39131 .54967 .39219 .55057 .39366 .55013 .39279 .54909 Mtetra
.676 .703 .867 r
.39279 .54909 .39366 .55013 .39514 .54966 .39426 .54856 Mtetra
.588 .662 .889 r
.39426 .54856 .39514 .54966 .3966 .54934 .39572 .5484 Mtetra
.55 .057 0 r
.39572 .5484 .3966 .54934 .39805 .54959 .39712 .54995 Mtetra
.882 .537 .392 r
.39712 .54995 .39805 .54959 .39949 .55017 .39841 .55444 Mtetra
.934 .675 .522 r
.39841 .55444 .39949 .55017 .40092 .5509 .39303 .73935 Mtetra
.569 .357 .553 r
.39303 .73935 .40092 .5509 .40238 .55081 .39449 .74146 Mtetra
.565 .353 .552 r
.39449 .74146 .40238 .55081 .40386 .55022 .39606 .74086 Mtetra
.563 .352 .552 r
.39606 .74086 .40386 .55022 .40535 .54945 .39767 .7392 Mtetra
.566 .355 .553 r
.39767 .7392 .40535 .54945 .40683 .54908 .3992 .73944 Mtetra
.566 .354 .553 r
.3992 .73944 .40683 .54908 .40831 .54868 .40075 .73936 Mtetra
.563 .352 .552 r
.40075 .73936 .40831 .54868 .4098 .54797 .40237 .73752 Mtetra
0 0 .338 r
.40237 .73752 .4098 .54797 .41132 .54633 .41022 .55208 Mtetra
0 0 .111 r
.41022 .55208 .41132 .54633 .41284 .54467 .41191 .54537 Mtetra
.959 .945 .69 r
.41191 .54537 .41284 .54467 .41435 .5433 .41348 .5424 Mtetra
.775 .753 .832 r
.41348 .5424 .41435 .5433 .41585 .54255 .41498 .54127 Mtetra
.661 .66 .839 r
.41498 .54127 .41585 .54255 .41733 .54208 .41647 .54079 Mtetra
.607 .637 .855 r
.41647 .54079 .41733 .54208 .41881 .54173 .41795 .54058 Mtetra
.617 .664 .873 r
.41795 .54058 .41881 .54173 .42029 .54137 .41943 .54031 Mtetra
.623 .686 .888 r
.41943 .54031 .42029 .54137 .42178 .54098 .42091 .54002 Mtetra
.629 .707 .902 r
.42091 .54002 .42178 .54098 .42326 .54057 .42239 .53969 Mtetra
.711 .747 .88 r
.42239 .53969 .42326 .54057 .42476 .53977 .42388 .53901 Mtetra
.72 .775 .896 r
.42388 .53901 .42476 .53977 .42626 .53903 .42538 .5383 Mtetra
.659 .77 .931 r
.42538 .5383 .42626 .53903 .42774 .53874 .42687 .53784 Mtetra
.121 .473 .895 r
.42687 .53784 .42774 .53874 .42917 .54044 .42833 .53849 Mtetra
0 .156 .685 r
.42833 .53849 .42917 .54044 .43044 .54793 .42976 .54033 Mtetra
.327 .227 .585 r
.42976 .54033 .43044 .54793 .42674 .73587 .43113 .54418 Mtetra
.563 .355 .557 r
.43113 .54418 .42674 .73587 .42826 .73746 .43256 .54615 Mtetra
.569 .36 .558 r
.43256 .54615 .42826 .73746 .42984 .73701 .43408 .54485 Mtetra
.567 .359 .558 r
.43408 .54485 .42984 .73701 .43144 .73618 .43557 .54463 Mtetra
0 0 .367 r
.43557 .54463 .43144 .73618 .433 .73656 .43227 .72812 Mtetra
.131 .08 .527 r
.43227 .72812 .433 .73656 .43455 .73737 .43368 .73453 Mtetra
.033 .142 .647 r
.43368 .73453 .43455 .73737 .43611 .73794 .43519 .73699 Mtetra
.196 .517 .916 r
.43519 .73699 .43611 .73794 .43768 .738 .43675 .73758 Mtetra
.48 .812 1 r
.43675 .73758 .43768 .738 .43927 .73773 .43834 .73738 Mtetra
.62 .875 .989 r
.43834 .73738 .43927 .73773 .44086 .73732 .43993 .73687 Mtetra
.606 .847 .989 r
.43993 .73687 .44086 .73732 .44244 .73707 .44152 .73644 Mtetra
.65 .807 .959 r
.44152 .73644 .44244 .73707 .44403 .73673 .44311 .73596 Mtetra
.722 .786 .903 r
.44311 .73596 .44403 .73673 .44563 .73593 .44471 .7352 Mtetra
.835 .795 .813 r
.44471 .7352 .44563 .73593 .44727 .7333 .44633 .7335 Mtetra
.951 .906 .74 r
.44633 .7335 .44727 .7333 .44901 .72587 .44798 .73062 Mtetra
0 0 .199 r
.44798 .73062 .44901 .72587 .45458 .53553 .44966 .72597 Mtetra
.557 .348 .551 r
.44966 .72597 .45458 .53553 .45614 .53253 .45135 .72106 Mtetra
.564 .353 .552 r
.45135 .72106 .45614 .53253 .45765 .53188 .45295 .71996 Mtetra
.568 .356 .553 r
.45295 .71996 .45765 .53188 .45915 .53186 .45451 .72114 Mtetra
.566 .355 .553 r
.45451 .72114 .45915 .53186 .46065 .53167 .45609 .72147 Mtetra
.565 .354 .552 r
.45609 .72147 .46065 .53167 .46216 .53124 .45768 .72113 Mtetra
.45768 .72113 .46216 .53124 .46367 .53081 .45928 .72079 Mtetra
.567 .355 .553 r
.45928 .72079 .46367 .53081 .46518 .53052 .46085 .72147 Mtetra
.566 .355 .553 r
.46085 .72147 .46518 .53052 .46669 .53023 .46244 .72191 Mtetra
.564 .353 .552 r
.46244 .72191 .46669 .53023 .4682 .52967 .46405 .72066 Mtetra
0 0 .375 r
.46405 .72066 .4682 .52967 .46973 .52831 .46871 .53723 Mtetra
0 0 .262 r
.46871 .53723 .46973 .52831 .47127 .52664 .47037 .52796 Mtetra
.885 .923 .533 r
.47037 .52796 .47127 .52664 .4728 .52522 .47194 .52459 Mtetra
.834 .812 .83 r
.47194 .52459 .4728 .52522 .47432 .52433 .47347 .52309 Mtetra
.677 .677 .842 r
.47347 .52309 .47432 .52433 .47583 .52382 .47499 .52252 Mtetra
.624 .646 .852 r
.47499 .52252 .47583 .52382 .47735 .52343 .4765 .52222 Mtetra
.634 .665 .863 r
.4765 .52222 .47735 .52343 .47887 .52301 .47802 .52188 Mtetra
.659 .687 .865 r
.47802 .52188 .47887 .52301 .48038 .52254 .47953 .52142 Mtetra
.659 .687 .866 r
.47953 .52142 .48038 .52254 .4819 .52208 .48105 .52095 Mtetra
.66 .689 .866 r
.48105 .52095 .4819 .52208 .48342 .5216 .48257 .52049 Mtetra
.661 .691 .867 r
.48257 .52049 .48342 .5216 .48494 .52113 .4841 .52001 Mtetra
.662 .692 .867 r
.4841 .52001 .48494 .52113 .48647 .52065 .48562 .51954 Mtetra
.662 .692 .868 r
.48562 .51954 .48647 .52065 .48799 .52017 .48714 .51906 Mtetra
.48714 .51906 .48799 .52017 .48951 .51969 .48867 .51858 Mtetra
.663 .693 .868 r
.48867 .51858 .48951 .51969 .49104 .51922 .49019 .5181 Mtetra
.49019 .5181 .49104 .51922 .49256 .51874 .49172 .51762 Mtetra
.49172 .51762 .49256 .51874 .49409 .51826 .49324 .51714 Mtetra
.663 .693 .867 r
.49324 .51714 .49409 .51826 .49562 .51778 .49477 .51666 Mtetra
.663 .692 .867 r
.49477 .51666 .49562 .51778 .49714 .51729 .4963 .51618 Mtetra
.4963 .51618 .49714 .51729 .49867 .51681 .49783 .51569 Mtetra
.49783 .51569 .49867 .51681 .5002 .51633 .49936 .51521 Mtetra
.49936 .51521 .5002 .51633 .50173 .51585 .50089 .51473 Mtetra
.662 .691 .867 r
.50089 .51473 .50173 .51585 .50326 .51537 .50242 .51425 Mtetra
.50242 .51425 .50326 .51537 .5048 .5149 .50395 .51377 Mtetra
.50395 .51377 .5048 .5149 .50633 .51442 .50549 .51329 Mtetra
.661 .69 .867 r
.50549 .51329 .50633 .51442 .50786 .51394 .50702 .51282 Mtetra
.50702 .51282 .50786 .51394 .5094 .51347 .50856 .51234 Mtetra
.66 .69 .867 r
.50856 .51234 .5094 .51347 .51093 .513 .51009 .51187 Mtetra
.659 .69 .867 r
.51009 .51187 .51093 .513 .51247 .51253 .51163 .51141 Mtetra
.658 .69 .868 r
.51163 .51141 .51247 .51253 .51401 .51207 .51317 .51094 Mtetra
.51317 .51094 .51401 .51207 .51554 .51161 .5147 .51048 Mtetra
.658 .69 .869 r
.5147 .51048 .51554 .51161 .51708 .51114 .51624 .51002 Mtetra
.652 .688 .871 r
.51624 .51002 .51708 .51114 .51862 .5107 .51778 .50959 Mtetra
.637 .684 .878 r
.51778 .50959 .51862 .5107 .52016 .5103 .51932 .50922 Mtetra
.617 .683 .89 r
.51932 .50922 .52016 .5103 .5217 .50996 .52087 .50894 Mtetra
.612 .694 .902 r
.52087 .50894 .5217 .50996 .52325 .50963 .52241 .50867 Mtetra
.624 .713 .91 r
.52241 .50867 .52325 .50963 .52479 .50926 .52395 .50835 Mtetra
.647 .732 .911 r
.52395 .50835 .52479 .50926 .52633 .50883 .5255 .50794 Mtetra
.656 .738 .911 r
.5255 .50794 .52633 .50883 .52788 .50837 .52704 .50749 Mtetra
.658 .74 .91 r
.52704 .50749 .52788 .50837 .52943 .50791 .52859 .50703 Mtetra
.656 .74 .912 r
.52859 .50703 .52943 .50791 .53097 .50746 .53014 .50658 Mtetra
.657 .742 .912 r
.53014 .50658 .53097 .50746 .53252 .50699 .53169 .50612 Mtetra
.659 .744 .913 r
.53169 .50612 .53252 .50699 .53407 .50652 .53324 .50566 Mtetra
.66 .746 .913 r
.53324 .50566 .53407 .50652 .53562 .50605 .53479 .50519 Mtetra
.662 .748 .914 r
.53479 .50519 .53562 .50605 .53717 .50556 .53634 .50471 Mtetra
.665 .751 .915 r
.53634 .50471 .53717 .50556 .53872 .50506 .53789 .50422 Mtetra
.668 .755 .916 r
.53789 .50422 .53872 .50506 .54027 .50454 .53944 .50372 Mtetra
.671 .76 .917 r
.53944 .50372 .54027 .50454 .54183 .50401 .541 .5032 Mtetra
.693 .769 .91 r
.541 .5032 .54183 .50401 .54338 .50335 .54255 .50259 Mtetra
.72 .788 .906 r
.54255 .50259 .54338 .50335 .54493 .50251 .5441 .50186 Mtetra
.669 .806 .948 r
.5441 .50186 .54493 .50251 .54649 .50202 .54566 .50133 Mtetra
.483 .729 .979 r
.54566 .50133 .54649 .50202 .54805 .50254 .54722 .5013 Mtetra
.162 .41 .852 r
.54722 .5013 .54805 .50254 .54964 .50616 .54879 .50223 Mtetra
.301 .271 .658 r
.54879 .50223 .54964 .50616 .55271 .69704 .55037 .50452 Mtetra
.54 .338 .555 r
.55037 .50452 .55271 .69704 .55442 .70284 .55205 .51867 Mtetra
0 0 .409 r
.55205 .51867 .55442 .70284 .55609 .70391 .55518 .69915 Mtetra
.265 .231 .633 r
.55518 .69915 .55609 .70391 .55775 .70417 .55686 .7022 Mtetra
.268 .378 .79 r
.55686 .7022 .55775 .70417 .55941 .70415 .55854 .70342 Mtetra
.373 .677 .976 r
.55854 .70342 .55941 .70415 .56108 .70419 .56021 .70359 Mtetra
.69 .835 .953 r
.56021 .70359 .56108 .70419 .56274 .7036 .56187 .70294 Mtetra
.88 .816 .782 r
.56187 .70294 .56274 .7036 .56438 .70152 .56351 .70071 Mtetra
.95 .73 .569 r
.56351 .70071 .56438 .70152 .56593 .69131 .56505 .68993 Mtetra
.959 .69 .481 r
.56505 .68993 .56593 .69131 .56525 .49877 .56443 .49763 Mtetra
.886 .737 .691 r
.56443 .49763 .56525 .49877 .56678 .49523 .56596 .49415 Mtetra
.723 .721 .848 r
.56596 .49415 .56678 .49523 .56835 .49441 .56752 .49331 Mtetra
.616 .683 .89 r
.56752 .49331 .56835 .49441 .56992 .49414 .5691 .49303 Mtetra
.57 .662 .899 r
.5691 .49303 .56992 .49414 .57149 .49404 .57067 .49292 Mtetra
.653 .692 .874 r
.57067 .49292 .57149 .49404 .57306 .49361 .57224 .49248 Mtetra
.652 .691 .873 r
.57224 .49248 .57306 .49361 .57464 .49317 .57381 .49203 Mtetra
.653 .69 .872 r
.57381 .49203 .57464 .49317 .57621 .49273 .57539 .49159 Mtetra
.656 .69 .87 r
.57539 .49159 .57621 .49273 .57778 .49227 .57696 .49112 Mtetra
.657 .69 .869 r
.57696 .49112 .57778 .49227 .57936 .49181 .57854 .49066 Mtetra
.658 .689 .868 r
.57854 .49066 .57936 .49181 .58093 .49134 .58011 .49018 Mtetra
.658 .689 .867 r
.58011 .49018 .58093 .49134 .58251 .49087 .58169 .48971 Mtetra
.659 .688 .866 r
.58169 .48971 .58251 .49087 .58409 .4904 .58327 .48923 Mtetra
.66 .687 .865 r
.58327 .48923 .58409 .4904 .58566 .48992 .58484 .48875 Mtetra
.661 .686 .863 r
.58484 .48875 .58566 .48992 .58724 .48944 .58642 .48826 Mtetra
.661 .684 .862 r
.58642 .48826 .58724 .48944 .58882 .48896 .588 .48777 Mtetra
.668 .686 .857 r
.588 .48777 .58882 .48896 .5904 .48846 .58958 .48723 Mtetra
.7 .693 .84 r
.58958 .48723 .5904 .48846 .59198 .48785 .59116 .48651 Mtetra
.66 .659 .839 r
.59116 .48651 .59198 .48785 .59356 .48734 .59274 .486 Mtetra
.543 .608 .868 r
.59274 .486 .59356 .48734 .59515 .48706 .59434 .48604 Mtetra
0 0 .508 r
.59434 .48604 .59515 .48706 .59675 .48743 .59597 .48793 Mtetra
.89 .524 .342 r
.59597 .48793 .59675 .48743 .59836 .48807 .59768 .49297 Mtetra
.955 .676 .468 r
.59768 .49297 .59836 .48807 .59997 .48867 .60351 .68143 Mtetra
.566 .354 .553 r
.60351 .68143 .59997 .48867 .60155 .48776 .60521 .68161 Mtetra
.564 .353 .552 r
.60521 .68161 .60155 .48776 .60314 .48713 .60688 .6805 Mtetra
.566 .355 .553 r
.60688 .6805 .60314 .48713 .60475 .48768 .60858 .68088 Mtetra
.572 .359 .553 r
.60858 .68088 .60475 .48768 .61096 .67482 .61039 .68534 Mtetra
.619 .366 .512 r
.61039 .68534 .61096 .67482 .61296 .68683 .61215 .68763 Mtetra
.671 .219 .171 r
.61215 .68763 .61296 .68683 .61473 .68949 .61388 .68879 Mtetra
.424 .712 .984 r
.61388 .68879 .61473 .68949 .61644 .68957 .61559 .68885 Mtetra
.644 .794 .954 r
.61559 .68885 .61644 .68957 .61813 .68902 .61728 .68837 Mtetra
.78 .838 .897 r
.61728 .68837 .61813 .68902 .61981 .68803 .61896 .68727 Mtetra
.89 .803 .757 r
.61896 .68727 .61981 .68803 .6215 .68707 .6206 .68471 Mtetra
.854 .667 .648 r
.6206 .68471 .6215 .68707 .62316 .68556 .62218 .6798 Mtetra
.959 .684 .471 r
.62218 .6798 .62316 .68556 .6248 .68285 .61848 .48833 Mtetra
.578 .367 .559 r
.61848 .48833 .6248 .68285 .6212 .49968 .61989 .48142 Mtetra
.615 .412 .585 r
.61989 .48142 .6212 .49968 .62228 .4813 .62143 .47857 Mtetra
.721 .582 .699 r
.62143 .47857 .62228 .4813 .62379 .47792 .62299 .47686 Mtetra
.687 .72 .875 r
.62299 .47686 .62379 .47792 .62538 .47708 .62459 .47624 Mtetra
.608 .742 .94 r
.62459 .47624 .62538 .47708 .62699 .47677 .62619 .47594 Mtetra
.566 .729 .951 r
.62619 .47594 .62699 .47677 .62861 .4767 .62781 .47576 Mtetra
.739 .758 .868 r
.62781 .47576 .62861 .4767 .6302 .47601 .6294 .47486 Mtetra
.701 .709 .854 r
.6294 .47486 .6302 .47601 .6318 .47538 .631 .47415 Mtetra
.624 .664 .868 r
.631 .47415 .6318 .47538 .63341 .47494 .63261 .47383 Mtetra
0 .283 .784 r
.63261 .47383 .63341 .47494 .63503 .47483 .63427 .47511 Mtetra
.862 .449 .243 r
.63427 .47511 .63503 .47483 .63666 .47522 .63601 .4785 Mtetra
.961 .678 .452 r
.63601 .4785 .63666 .47522 .63834 .47662 .64414 .66883 Mtetra
.576 .362 .553 r
.64414 .66883 .63834 .47662 .64083 .5013 .6461 .6756 Mtetra
.569 .357 .553 r
.6461 .6756 .64083 .5013 .64867 .67653 .64791 .67784 Mtetra
.638 .228 .249 r
.64791 .67784 .64867 .67653 .6505 .67947 .64967 .67882 Mtetra
.357 .693 .982 r
.64967 .67882 .6505 .67947 .65224 .6797 .65141 .67896 Mtetra
.621 .785 .96 r
.65141 .67896 .65224 .6797 .65396 .67922 .65313 .67855 Mtetra
.758 .837 .912 r
.65313 .67855 .65396 .67922 .65566 .67827 .65483 .67757 Mtetra
.889 .822 .776 r
.65483 .67757 .65566 .67827 .65736 .67736 .65648 .67522 Mtetra
.854 .677 .661 r
.65648 .67522 .65736 .67736 .65904 .67601 .65805 .67092 Mtetra
.963 .684 .459 r
.65805 .67092 .65904 .67601 .66069 .67376 .65252 .48265 Mtetra
.584 .372 .559 r
.65252 .48265 .66069 .67376 .6621 .66535 .65375 .47221 Mtetra
.572 .362 .558 r
.65375 .47221 .6621 .66535 .65616 .4726 .65527 .4691 Mtetra
.702 .548 .675 r
.65527 .4691 .65616 .4726 .65763 .46842 .65684 .46728 Mtetra
.713 .717 .852 r
.65684 .46728 .65763 .46842 .65923 .4673 .65845 .4665 Mtetra
.638 .763 .939 r
.65845 .4665 .65923 .4673 .66085 .4669 .66007 .46608 Mtetra
.591 .741 .948 r
.66007 .46608 .66085 .4669 .66249 .46682 .6617 .46582 Mtetra
.678 .732 .891 r
.6617 .46582 .66249 .46682 .66412 .46633 .66332 .46524 Mtetra
.686 .716 .872 r
.66332 .46524 .66412 .46633 .66574 .46578 .66494 .46462 Mtetra
.678 .7 .863 r
.66494 .46462 .66574 .46578 .66736 .46525 .66657 .46403 Mtetra
.642 .677 .868 r
.66657 .46403 .66736 .46525 .66899 .46481 .6682 .46362 Mtetra
.629 .677 .876 r
.6682 .46362 .66899 .46481 .67062 .46439 .66983 .46327 Mtetra
.63 .689 .887 r
.66983 .46327 .67062 .46439 .67225 .46396 .67146 .46292 Mtetra
.656 .716 .892 r
.67146 .46292 .67225 .46396 .67388 .46342 .6731 .46244 Mtetra
.674 .736 .897 r
.6731 .46244 .67388 .46342 .6755 .46282 .67472 .46189 Mtetra
.688 .751 .9 r
.67472 .46189 .6755 .46282 .67713 .46218 .67635 .46127 Mtetra
.748 .773 .873 r
.67635 .46127 .67713 .46218 .67873 .46114 .67796 .46033 Mtetra
.735 .791 .897 r
.67796 .46033 .67873 .46114 .68035 .46031 .67958 .45949 Mtetra
.662 .769 .929 r
.67958 .45949 .68035 .46031 .68199 .46 .68121 .45898 Mtetra
.325 .56 .922 r
.68121 .45898 .68199 .46 .68374 .46193 .68289 .45948 Mtetra
.269 .325 .736 r
.68289 .45948 .68374 .46193 .68588 .47159 .68464 .46114 Mtetra
.382 .26 .587 r
.68464 .46114 .68588 .47159 .69697 .66246 .68654 .46613 Mtetra
.079 0 .454 r
.68654 .46613 .69697 .66246 .69884 .6647 .69775 .65813 Mtetra
.269 .211 .605 r
.69775 .65813 .69884 .6647 .70065 .66535 .69974 .66264 Mtetra
.28 .325 .731 r
.69974 .66264 .70065 .66535 .70242 .66541 .7016 .66444 Mtetra
.38 .617 .944 r
.7016 .66444 .70242 .66541 .70419 .66545 .70339 .66477 Mtetra
.603 .801 .975 r
.70339 .66477 .70419 .66545 .70595 .66513 .70514 .66438 Mtetra
.745 .823 .912 r
.70514 .66438 .70595 .66513 .70767 .6642 .70687 .66345 Mtetra
.842 .829 .835 r
.70687 .66345 .70767 .6642 .70929 .66124 .70856 .66178 Mtetra
.893 .967 .648 r
.70856 .66178 .70929 .66124 .71063 .653 .71019 .65905 Mtetra
.141 0 .357 r
.71019 .65905 .71063 .653 .7019 .45838 .71168 .65366 Mtetra
.078 0 .449 r
.71168 .65366 .7019 .45838 .70339 .45494 .70295 .46011 Mtetra
0 0 .284 r
.70295 .46011 .70339 .45494 .70497 .45331 .70431 .45416 Mtetra
.783 .903 .503 r
.70431 .45416 .70497 .45331 .70659 .45228 .70583 .45145 Mtetra
.772 .799 .875 r
.70583 .45145 .70659 .45228 .70823 .45163 .70745 .45039 Mtetra
.637 .673 .867 r
.70745 .45039 .70823 .45163 .70989 .45119 .70911 .45 Mtetra
.583 .656 .887 r
.70911 .45 .70989 .45119 .71155 .45086 .71078 .44984 Mtetra
.691 .737 .886 r
.71078 .44984 .71155 .45086 .71318 .45005 .71242 .44919 Mtetra
.72 .78 .9 r
.71242 .44919 .71318 .45005 .71482 .44925 .71406 .44842 Mtetra
.661 .77 .93 r
.71406 .44842 .71482 .44925 .71648 .44888 .71571 .44791 Mtetra
.385 .606 .936 r
.71571 .44791 .71648 .44888 .71825 .45032 .71742 .44825 Mtetra
.274 .361 .771 r
.71742 .44825 .71825 .45032 .72028 .45621 .71919 .44966 Mtetra
.341 .258 .615 r
.71919 .44966 .72028 .45621 .73368 .65098 .7211 .45338 Mtetra
.098 .016 .465 r
.7211 .45338 .73368 .65098 .73566 .65408 .73442 .64591 Mtetra
.255 .188 .586 r
.73442 .64591 .73566 .65408 .73751 .6549 .73658 .65185 Mtetra
.272 .301 .709 r
.73658 .65185 .73751 .6549 .73931 .65505 .7385 .65396 Mtetra
.391 .598 .929 r
.7385 .65396 .73931 .65505 .7411 .65483 .74033 .65434 Mtetra
.57 .844 .996 r
.74033 .65434 .7411 .65483 .74287 .65439 .7421 .65393 Mtetra
.673 .886 .976 r
.7421 .65393 .74287 .65439 .74464 .65383 .74386 .65323 Mtetra
.6 .826 .986 r
.74386 .65323 .74464 .65383 .74643 .65359 .74564 .65281 Mtetra
.601 .773 .963 r
.74564 .65281 .74643 .65359 .74822 .65335 .74742 .65246 Mtetra
.681 .774 .921 r
.74742 .65246 .74822 .65335 .74998 .65265 .74919 .65182 Mtetra
.813 .82 .856 r
.74919 .65182 .74998 .65265 .75163 .65015 .75091 .6504 Mtetra
.917 .978 .72 r
.75091 .6504 .75163 .65015 .753 .64349 .75255 .64789 Mtetra
.058 0 .292 r
.75255 .64789 .753 .64349 .74178 .4472 .75406 .64328 Mtetra
.103 .016 .462 r
.75406 .64328 .74178 .4472 .74321 .44296 .743 .45014 Mtetra
.047 0 .356 r
.743 .45014 .74321 .44296 .74479 .44121 .74419 .44246 Mtetra
0 0 0 r
.74419 .44246 .74479 .44121 .74643 .44013 .74569 .43946 Mtetra
.811 .846 .876 r
.74569 .43946 .74643 .44013 .74809 .43947 .74731 .43819 Mtetra
.639 .669 .863 r
.74731 .43819 .74809 .43947 .74977 .43907 .749 .43778 Mtetra
.573 .638 .877 r
.749 .43778 .74977 .43907 .75146 .4388 .7507 .43768 Mtetra
.604 .684 .899 r
.7507 .43768 .75146 .4388 .75314 .43841 .75239 .43742 Mtetra
.655 .734 .907 r
.75239 .43742 .75314 .43841 .75482 .43788 .75407 .43694 Mtetra
.67 .749 .91 r
.75407 .43694 .75482 .43788 .75649 .4373 .75574 .43639 Mtetra
.723 .772 .892 r
.75574 .43639 .75649 .4373 .75814 .43643 .7574 .43558 Mtetra
.736 .792 .897 r
.7574 .43558 .75814 .43643 .75979 .43553 .75906 .43472 Mtetra
.68 .783 .928 r
.75906 .43472 .75979 .43553 .76147 .43507 .76073 .43412 Mtetra
.449 .648 .943 r
.76073 .43412 .76147 .43507 .76327 .43617 .76246 .43429 Mtetra
.274 .382 .792 r
.76246 .43429 .76327 .43617 .76538 .44138 .76428 .4356 Mtetra
.334 .264 .628 r
.76428 .4356 .76538 .44138 .78164 .63727 .76626 .43906 Mtetra
.121 .036 .477 r
.76626 .43906 .78164 .63727 .78374 .64097 .78235 .63177 Mtetra
.27 .194 .583 r
.78235 .63177 .78374 .64097 .78564 .64186 .78467 .6384 Mtetra
.304 .305 .696 r
.78467 .6384 .78564 .64186 .78749 .64205 .78668 .64067 Mtetra
.354 .518 .881 r
.78668 .64067 .78749 .64205 .78933 .64206 .78857 .64135 Mtetra
.55 .777 .983 r
.78857 .64135 .78933 .64206 .79116 .64186 .79039 .6411 Mtetra
.714 .823 .932 r
.79039 .6411 .79116 .64186 .79294 .64111 .79217 .6403 Mtetra
.818 .83 .859 r
.79217 .6403 .79294 .64111 .79461 .63889 .7939 .63884 Mtetra
.93 .962 .767 r
.7939 .63884 .79461 .63889 .796 .63311 .79555 .63645 Mtetra
0 0 .208 r
.79555 .63645 .796 .63311 .78225 .43581 .79706 .63218 Mtetra
.125 .036 .473 r
.79706 .63218 .78225 .43581 .78358 .43061 .78366 .44002 Mtetra
.091 0 .398 r
.78366 .44002 .78358 .43061 .78516 .42871 .78463 .43029 Mtetra
0 0 0 r
.78463 .43029 .78516 .42871 .7868 .42753 .78611 .42704 Mtetra
.851 .897 .869 r
.78611 .42704 .7868 .42753 .78848 .42679 .78772 .42554 Mtetra
.653 .683 .865 r
.78772 .42554 .78848 .42679 .79018 .42632 .78942 .42506 Mtetra
.591 .652 .879 r
.78942 .42506 .79018 .42632 .79189 .42597 .79115 .42487 Mtetra
.649 .708 .891 r
.79115 .42487 .79189 .42597 .79358 .42532 .79285 .42441 Mtetra
.73 .778 .891 r
.79285 .42441 .79358 .42532 .79525 .42441 .79453 .42356 Mtetra
.687 .779 .921 r
.79453 .42356 .79525 .42441 .79695 .42388 .79622 .42293 Mtetra
.505 .677 .942 r
.79622 .42293 .79695 .42388 .79875 .42463 .79797 .42295 Mtetra
.291 .418 .818 r
.79797 .42295 .79875 .42463 .80085 .42877 .79981 .42407 Mtetra
.341 .289 .653 r
.79981 .42407 .80085 .42877 .81938 .6252 .8018 .42687 Mtetra
.147 .057 .488 r
.8018 .42687 .81938 .6252 .82166 .63003 .81976 .61593 Mtetra
.258 .168 .559 r
.81976 .61593 .82166 .63003 .8236 .63098 .82254 .62663 Mtetra
.33 .295 .668 r
.82254 .62663 .8236 .63098 .82548 .63118 .82464 .62933 Mtetra
.321 .43 .816 r
.82464 .62933 .82548 .63118 .82736 .63128 .82661 .63046 Mtetra
.39 .666 .969 r
.82661 .63046 .82736 .63128 .82924 .63137 .82849 .63067 Mtetra
.666 .827 .961 r
.82849 .63067 .82924 .63137 .83106 .6308 .83031 .63005 Mtetra
.905 .842 .771 r
.83031 .63005 .83106 .6308 .83272 .62844 .83196 .62758 Mtetra
.979 .747 .515 r
.83196 .62758 .83272 .62844 .83371 .61864 .8329 .61715 Mtetra
.977 .681 .38 r
.8329 .61715 .83371 .61864 .8177 .42063 .81695 .41932 Mtetra
.894 .749 .695 r
.81695 .41932 .8177 .42063 .81916 .41726 .81842 .41604 Mtetra
.678 .701 .864 r
.81842 .41604 .81916 .41726 .82086 .41657 .82012 .41541 Mtetra
.538 .647 .905 r
.82012 .41541 .82086 .41657 .82261 .4165 .82189 .41541 Mtetra
.51 .647 .918 r
.82189 .41541 .82261 .4165 .82438 .4165 .82366 .41548 Mtetra
.63 .72 .911 r
.82366 .41548 .82438 .4165 .82611 .41607 .82539 .41509 Mtetra
.643 .734 .915 r
.82539 .41509 .82611 .41607 .82783 .4156 .82712 .41464 Mtetra
.664 .747 .912 r
.82712 .41464 .82783 .4156 .82955 .41509 .82884 .4141 Mtetra
.686 .75 .9 r
.82884 .4141 .82955 .41509 .83127 .41452 .83055 .41346 Mtetra
.687 .735 .887 r
.83055 .41346 .83127 .41452 .83299 .41394 .83226 .41281 Mtetra
.673 .715 .881 r
.83226 .41281 .83299 .41394 .83471 .41338 .83398 .41222 Mtetra
.648 .7 .884 r
.83398 .41222 .83471 .41338 .83643 .41287 .83571 .41175 Mtetra
.646 .708 .892 r
.83571 .41175 .83643 .41287 .83816 .41235 .83744 .4113 Mtetra
.68 .734 .891 r
.83744 .4113 .83816 .41235 .83988 .41175 .83916 .41068 Mtetra
.726 .749 .87 r
.83916 .41068 .83988 .41175 .84159 .41101 .84085 .40981 Mtetra
.676 .705 .87 r
.84085 .40981 .84159 .41101 .8433 .41037 .84258 .4092 Mtetra
.504 .629 .907 r
.84258 .4092 .8433 .41037 .84504 .40992 .84437 .40932 Mtetra
.506 0 0 r
.84437 .40932 .84504 .40992 .84681 .40979 .84634 .41118 Mtetra
.877 .499 .323 r
.84634 .41118 .84681 .40979 .84864 .41024 .84873 .41723 Mtetra
.97 .662 .372 r
.84873 .41723 .84864 .41024 .85066 .41252 .86995 .61051 Mtetra
.571 .358 .553 r
.86995 .61051 .85066 .41252 .87222 .60781 .87223 .61429 Mtetra
.616 .337 .472 r
.87223 .61429 .87222 .60781 .8749 .61544 .8743 .6159 Mtetra
.522 0 0 r
.8743 .6159 .8749 .61544 .87701 .61749 .87628 .61659 Mtetra
.462 .685 .962 r
.87628 .61659 .87701 .61749 .87892 .61752 .87819 .61667 Mtetra
.629 .778 .953 r
.87819 .61667 .87892 .61752 .88077 .61695 .88006 .61621 Mtetra
.795 .856 .896 r
.88006 .61621 .88077 .61695 .88259 .61601 .88184 .61496 Mtetra
.903 .799 .734 r
.88184 .61496 .88259 .61601 .88439 .61495 .88345 .61207 Mtetra
.872 .663 .617 r
.88345 .61207 .88439 .61495 .88613 .61328 .88475 .60617 Mtetra
.974 .672 .373 r
.88475 .60617 .88613 .61328 .88769 .60993 .86598 .41023 Mtetra
.575 .365 .558 r
.86598 .41023 .88769 .60993 .86893 .41535 .8672 .40468 Mtetra
.637 .44 .6 r
.8672 .40468 .86893 .41535 .86957 .40447 .86872 .40206 Mtetra
.726 .605 .722 r
.86872 .40206 .86957 .40447 .87105 .40146 .87036 .40051 Mtetra
.697 .766 .905 r
.87036 .40051 .87105 .40146 .87277 .40061 .87209 .39981 Mtetra
.63 .777 .951 r
.87209 .39981 .87277 .40061 .87453 .40024 .87385 .39937 Mtetra
.645 .765 .936 r
.87385 .39937 .87453 .40024 .87631 .39996 .8756 .39889 Mtetra
.743 .758 .864 r
.8756 .39889 .87631 .39996 .87803 .39918 .8773 .39791 Mtetra
.693 .702 .853 r
.8773 .39791 .87803 .39918 .87976 .3985 .87903 .39718 Mtetra
.577 .638 .875 r
.87903 .39718 .87976 .3985 .88152 .39805 .88083 .39705 Mtetra
0 .256 .764 r
.88083 .39705 .88152 .39805 .88332 .39797 .88281 .39862 Mtetra
.869 .448 .211 r
.88281 .39862 .88332 .39797 .88519 .39847 .88513 .40314 Mtetra
.972 .66 .344 r
.88513 .40314 .88519 .39847 .88724 .4005 .90892 .59882 Mtetra
.572 .359 .552 r
.90892 .59882 .88724 .4005 .91114 .59598 .91139 .60365 Mtetra
.617 .345 .483 r
.91139 .60365 .91114 .59598 .91407 .60476 .91354 .60551 Mtetra
.567 .066 .024 r
.91354 .60551 .91407 .60476 .91627 .60705 .91557 .60627 Mtetra
.478 .728 .98 r
.91557 .60627 .91627 .60705 .9182 .60702 .9175 .60623 Mtetra
.657 .808 .955 r
.9175 .60623 .9182 .60702 .92007 .60635 .91938 .60564 Mtetra
.803 .868 .896 r
.91938 .60564 .92007 .60635 .92188 .60522 .92117 .60433 Mtetra
.931 .826 .72 r
.92117 .60433 .92188 .60522 .92365 .60374 .92275 .60118 Mtetra
.895 .683 .608 r
.92275 .60118 .92365 .60374 .92539 .60196 .92397 .59498 Mtetra
.974 .668 .354 r
.92397 .59498 .92539 .60196 .92714 .60025 .90309 .40048 Mtetra
.568 .36 .558 r
.90309 .40048 .92714 .60025 .92908 .6002 .90478 .39925 Mtetra
.565 .358 .558 r
.90478 .39925 .92908 .6002 .93099 .59992 .9067 .39991 Mtetra
.568 .359 .558 r
.9067 .39991 .93099 .59992 .93278 .59852 .90844 .39909 Mtetra
.576 .365 .558 r
.90844 .39909 .93278 .59852 .93336 .58707 .90955 .39301 Mtetra
.571 .362 .558 r
.90955 .39301 .93336 .58707 .91189 .39251 .91099 .38972 Mtetra
.744 .598 .694 r
.91099 .38972 .91189 .39251 .91326 .38866 .91257 .38763 Mtetra
.706 .756 .891 r
.91257 .38763 .91326 .38866 .91498 .3877 .91432 .38687 Mtetra
.635 .775 .948 r
.91432 .38687 .91498 .3877 .91677 .38729 .9161 .38641 Mtetra
.602 .748 .947 r
.9161 .38641 .91677 .38729 .91859 .38713 .9179 .38608 Mtetra
.67 .738 .901 r
.9179 .38608 .91859 .38713 .92036 .38656 .91967 .3855 Mtetra
.673 .737 .898 r
.91967 .3855 .92036 .38656 .92213 .38597 .92144 .3849 Mtetra
.679 .737 .894 r
.92144 .3849 .92213 .38597 .92389 .38536 .92321 .38427 Mtetra
.759 .765 .858 r
.92321 .38427 .92389 .38536 .9256 .38426 .92492 .38318 Mtetra
.694 .742 .888 r
.92492 .38318 .9256 .38426 .92736 .38354 .92668 .38247 Mtetra
.513 .657 .924 r
.92668 .38247 .92736 .38354 .92921 .38359 .92853 .38252 Mtetra
.719 .305 0 r
.92853 .38252 .92921 .38359 .93167 .38839 .93098 .38725 Mtetra
.97 .655 .291 r
.93098 .38725 .93167 .38839 .9591 .58935 .95839 .5883 Mtetra
.725 .301 0 r
.95839 .5883 .9591 .58935 .96169 .59413 .96098 .59315 Mtetra
.032 .457 .876 r
.34527 .7606 .34623 .7614 .34771 .76203 .34676 .76124 Mtetra
.641 .758 .933 r
.34676 .76124 .34771 .76203 .34925 .76162 .34829 .76084 Mtetra
.808 .777 .824 r
.34829 .76084 .34925 .76162 .35084 .76019 .34988 .75941 Mtetra
.908 .737 .659 r
.34988 .75941 .35084 .76019 .35261 .75491 .35166 .75413 Mtetra
.937 .686 .534 r
.35166 .75413 .35261 .75491 .36326 .56352 .36236 .56268 Mtetra
.909 .727 .645 r
.36236 .56268 .36326 .56352 .36497 .5578 .36407 .55697 Mtetra
.777 .76 .837 r
.36407 .55697 .36497 .5578 .36646 .55669 .36556 .55585 Mtetra
.641 .736 .918 r
.36556 .55585 .36646 .55669 .36791 .55632 .36702 .55548 Mtetra
.508 .69 .95 r
.36702 .55548 .36791 .55632 .36935 .55632 .36845 .55548 Mtetra
.745 .757 .862 r
.36845 .55548 .36935 .55632 .37082 .55545 .36993 .55461 Mtetra
.695 .748 .893 r
.36993 .55461 .37082 .55545 .37229 .55486 .3714 .55401 Mtetra
.478 .677 .953 r
.3714 .55401 .37229 .55486 .37373 .55491 .37284 .55407 Mtetra
.928 .549 .254 r
.37284 .55407 .37373 .55491 .37499 .55894 .3741 .5581 Mtetra
.939 .683 .522 r
.3741 .5581 .37499 .55894 .36806 .74974 .36711 .74895 Mtetra
.934 .578 .319 r
.36711 .74895 .36806 .74974 .36936 .75486 .36842 .75407 Mtetra
0 .342 .791 r
.36842 .75407 .36936 .75486 .37086 .75568 .36991 .7549 Mtetra
.618 .754 .943 r
.36991 .7549 .37086 .75568 .37241 .75535 .37146 .75456 Mtetra
.8 .78 .835 r
.37146 .75456 .37241 .75535 .37399 .75402 .37305 .75323 Mtetra
.905 .744 .67 r
.37305 .75323 .37399 .75402 .37572 .74934 .37478 .74854 Mtetra
.939 .687 .529 r
.37478 .74854 .37572 .74934 .38517 .55793 .38428 .55705 Mtetra
.914 .723 .631 r
.38428 .55705 .38517 .55793 .38689 .55133 .386 .55047 Mtetra
.798 .758 .816 r
.386 .55047 .38689 .55133 .38839 .55 .38751 .54913 Mtetra
.644 .73 .911 r
.38751 .54913 .38839 .55 .38986 .54963 .38898 .54875 Mtetra
.503 .677 .943 r
.38898 .54875 .38986 .54963 .39131 .54967 .39043 .54877 Mtetra
.717 .742 .871 r
.39043 .54877 .39131 .54967 .39279 .54909 .39191 .54805 Mtetra
.686 .708 .865 r
.39191 .54805 .39279 .54909 .39426 .54856 .39339 .54748 Mtetra
.539 .646 .903 r
.39339 .54748 .39426 .54856 .39572 .5484 .39484 .54747 Mtetra
.897 .478 .113 r
.39484 .54747 .39572 .5484 .39712 .54995 .39618 .55064 Mtetra
.94 .681 .518 r
.39618 .55064 .39712 .54995 .39841 .55444 .3905 .73992 Mtetra
.576 .363 .554 r
.3905 .73992 .39841 .55444 .39303 .73935 .3918 .74643 Mtetra
.585 .325 .489 r
.3918 .74643 .39303 .73935 .39449 .74146 .39332 .74713 Mtetra
.522 .256 .453 r
.39332 .74713 .39449 .74146 .39606 .74086 .39488 .74666 Mtetra
.492 .231 .446 r
.39488 .74666 .39606 .74086 .39767 .7392 .39647 .74574 Mtetra
.545 .285 .473 r
.39647 .74574 .39767 .7392 .3992 .73944 .39802 .74558 Mtetra
.537 .274 .465 r
.39802 .74558 .3992 .73944 .40075 .73936 .39958 .7453 Mtetra
.489 .23 .448 r
.39958 .7453 .40075 .73936 .40237 .73752 .40117 .74431 Mtetra
.133 0 .329 r
.40117 .74431 .40237 .73752 .41022 .55208 .4029 .73931 Mtetra
0 0 .314 r
.4029 .73931 .41022 .55208 .41191 .54537 .41093 .54768 Mtetra
.938 .877 .461 r
.41093 .54768 .41191 .54537 .41348 .5424 .41259 .54206 Mtetra
.854 .866 .849 r
.41259 .54206 .41348 .5424 .41498 .54127 .4141 .54056 Mtetra
.666 .777 .932 r
.4141 .54056 .41498 .54127 .41647 .54079 .41559 .54008 Mtetra
.53 .735 .969 r
.41559 .54008 .41647 .54079 .41795 .54058 .41706 .53997 Mtetra
.598 .789 .972 r
.41706 .53997 .41795 .54058 .41943 .54031 .41854 .53967 Mtetra
.637 .787 .954 r
.41854 .53967 .41943 .54031 .42091 .54002 .42003 .53927 Mtetra
.646 .762 .933 r
.42003 .53927 .42091 .54002 .42239 .53969 .42152 .53886 Mtetra
.677 .75 .906 r
.42152 .53886 .42239 .53969 .42388 .53901 .42301 .53834 Mtetra
.68 .793 .934 r
.42301 .53834 .42388 .53901 .42538 .5383 .4245 .53781 Mtetra
.649 .836 .972 r
.4245 .53781 .42538 .5383 .42687 .53784 .42599 .53733 Mtetra
.531 .796 .994 r
.42599 .53733 .42687 .53784 .42833 .53849 .42747 .53713 Mtetra
.568 .609 .854 r
.42747 .53713 .42833 .53849 .42976 .54033 .42895 .53708 Mtetra
.578 .474 .7 r
.42895 .53708 .42976 .54033 .43113 .54418 .43043 .53706 Mtetra
.602 .432 .624 r
.43043 .53706 .43113 .54418 .43256 .54615 .43193 .5364 Mtetra
.594 .414 .606 r
.43193 .5364 .43256 .54615 .43408 .54485 .43343 .53568 Mtetra
.577 .402 .609 r
.43343 .53568 .43408 .54485 .43557 .54463 .43492 .53554 Mtetra
.427 .29 .592 r
.43492 .53554 .43557 .54463 .43227 .72812 .43632 .53864 Mtetra
0 0 .346 r
.43632 .53864 .43227 .72812 .43368 .73453 .43287 .72954 Mtetra
0 0 .405 r
.43287 .72954 .43368 .73453 .43519 .73699 .43429 .73542 Mtetra
.197 .387 .825 r
.43429 .73542 .43519 .73699 .43675 .73758 .43584 .73646 Mtetra
.616 .684 .891 r
.43584 .73646 .43675 .73758 .43834 .73738 .43742 .73618 Mtetra
.698 .698 .846 r
.43742 .73618 .43834 .73738 .43993 .73687 .43902 .73546 Mtetra
.667 .657 .831 r
.43902 .73546 .43993 .73687 .44152 .73644 .44061 .73491 Mtetra
.647 .633 .822 r
.44061 .73491 .44152 .73644 .44311 .73596 .44221 .73445 Mtetra
.661 .642 .82 r
.44221 .73445 .44311 .73596 .44471 .7352 .4438 .73392 Mtetra
.702 .688 .833 r
.4438 .73392 .44471 .7352 .44633 .7335 .4454 .73315 Mtetra
.757 .897 .94 r
.4454 .73315 .44633 .7335 .44798 .73062 .44701 .73223 Mtetra
.223 0 .082 r
.44701 .73223 .44798 .73062 .44966 .72597 .44861 .73128 Mtetra
.504 .236 .442 r
.44861 .73128 .44966 .72597 .45135 .72106 .45022 .7306 Mtetra
.542 .298 .496 r
.45022 .7306 .45135 .72106 .45295 .71996 .45181 .73015 Mtetra
.546 .305 .501 r
.45181 .73015 .45295 .71996 .45451 .72114 .45341 .72978 Mtetra
.542 .294 .49 r
.45341 .72978 .45451 .72114 .45609 .72147 .45501 .72939 Mtetra
.538 .287 .484 r
.45501 .72939 .45609 .72147 .45768 .72113 .45661 .72897 Mtetra
.537 .286 .483 r
.45661 .72897 .45768 .72113 .45928 .72079 .45821 .72854 Mtetra
.551 .298 .486 r
.45821 .72854 .45928 .72079 .46085 .72147 .4598 .72844 Mtetra
.548 .29 .477 r
.4598 .72844 .46085 .72147 .46244 .72191 .4614 .72831 Mtetra
.51 .253 .461 r
.4614 .72831 .46244 .72191 .46405 .72066 .46301 .72754 Mtetra
.313 .089 .405 r
.46301 .72754 .46405 .72066 .46871 .53723 .46466 .72397 Mtetra
0 0 .345 r
.46466 .72397 .46871 .53723 .47037 .52796 .46943 .53245 Mtetra
.709 .694 .157 r
.46943 .53245 .47037 .52796 .47194 .52459 .47107 .52455 Mtetra
.92 .909 .793 r
.47107 .52455 .47194 .52459 .47347 .52309 .47261 .52242 Mtetra
.701 .797 .925 r
.47261 .52242 .47347 .52309 .47499 .52252 .47413 .52179 Mtetra
.573 .748 .96 r
.47413 .52179 .47499 .52252 .4765 .52222 .47564 .52158 Mtetra
.589 .778 .97 r
.47564 .52158 .4765 .52222 .47802 .52188 .47716 .5213 Mtetra
.648 .814 .963 r
.47716 .5213 .47802 .52188 .47953 .52142 .47868 .52084 Mtetra
.646 .815 .964 r
.47868 .52084 .47953 .52142 .48105 .52095 .4802 .52039 Mtetra
.648 .817 .965 r
.4802 .52039 .48105 .52095 .48257 .52049 .48172 .51992 Mtetra
.65 .819 .965 r
.48172 .51992 .48257 .52049 .4841 .52001 .48324 .51945 Mtetra
.651 .82 .965 r
.48324 .51945 .4841 .52001 .48562 .51954 .48476 .51898 Mtetra
.652 .821 .965 r
.48476 .51898 .48562 .51954 .48714 .51906 .48629 .5185 Mtetra
.48629 .5185 .48714 .51906 .48867 .51858 .48781 .51802 Mtetra
.653 .821 .964 r
.48781 .51802 .48867 .51858 .49019 .5181 .48934 .51754 Mtetra
.48934 .51754 .49019 .5181 .49172 .51762 .49086 .51706 Mtetra
.654 .821 .964 r
.49086 .51706 .49172 .51762 .49324 .51714 .49239 .51658 Mtetra
.654 .821 .963 r
.49239 .51658 .49324 .51714 .49477 .51666 .49392 .51609 Mtetra
.655 .82 .963 r
.49392 .51609 .49477 .51666 .4963 .51618 .49545 .51561 Mtetra
.655 .819 .962 r
.49545 .51561 .4963 .51618 .49783 .51569 .49698 .51512 Mtetra
.655 .818 .962 r
.49698 .51512 .49783 .51569 .49936 .51521 .49851 .51463 Mtetra
.49851 .51463 .49936 .51521 .50089 .51473 .50004 .51415 Mtetra
.655 .817 .961 r
.50004 .51415 .50089 .51473 .50242 .51425 .50157 .51366 Mtetra
.654 .816 .961 r
.50157 .51366 .50242 .51425 .50395 .51377 .50311 .51318 Mtetra
.653 .815 .961 r
.50311 .51318 .50395 .51377 .50549 .51329 .50464 .5127 Mtetra
.652 .815 .961 r
.50464 .5127 .50549 .51329 .50702 .51282 .50618 .51223 Mtetra
.651 .814 .962 r
.50618 .51223 .50702 .51282 .50856 .51234 .50771 .51175 Mtetra
.65 .814 .962 r
.50771 .51175 .50856 .51234 .51009 .51187 .50925 .51128 Mtetra
.648 .814 .963 r
.50925 .51128 .51009 .51187 .51163 .51141 .51079 .51082 Mtetra
.646 .814 .964 r
.51079 .51082 .51163 .51141 .51317 .51094 .51232 .51036 Mtetra
.643 .814 .966 r
.51232 .51036 .51317 .51094 .5147 .51048 .51386 .50991 Mtetra
.638 .817 .969 r
.51386 .50991 .5147 .51048 .51624 .51002 .5154 .50947 Mtetra
.632 .821 .973 r
.5154 .50947 .51624 .51002 .51778 .50959 .51694 .50904 Mtetra
.626 .82 .975 r
.51694 .50904 .51778 .50959 .51932 .50922 .51849 .50862 Mtetra
.626 .805 .968 r
.51849 .50862 .51932 .50922 .52087 .50894 .52003 .50822 Mtetra
.635 .774 .947 r
.52003 .50822 .52087 .50894 .52241 .50867 .52157 .50782 Mtetra
.644 .744 .922 r
.52157 .50782 .52241 .50867 .52395 .50835 .52312 .50741 Mtetra
.65 .726 .904 r
.52312 .50741 .52395 .50835 .5255 .50794 .52466 .50699 Mtetra
.652 .725 .902 r
.52466 .50699 .5255 .50794 .52704 .50749 .52621 .50656 Mtetra
.653 .729 .904 r
.52621 .50656 .52704 .50749 .52859 .50703 .52776 .50612 Mtetra
.655 .733 .907 r
.52776 .50612 .52859 .50703 .53014 .50658 .5293 .50567 Mtetra
.656 .735 .908 r
.5293 .50567 .53014 .50658 .53169 .50612 .53085 .50522 Mtetra
.657 .737 .909 r
.53085 .50522 .53169 .50612 .53324 .50566 .5324 .50477 Mtetra
.658 .739 .91 r
.5324 .50477 .53324 .50566 .53479 .50519 .53395 .50431 Mtetra
.66 .742 .911 r
.53395 .50431 .53479 .50519 .53634 .50471 .53551 .50384 Mtetra
.662 .745 .912 r
.53551 .50384 .53634 .50471 .53789 .50422 .53706 .50336 Mtetra
.664 .749 .913 r
.53706 .50336 .53789 .50422 .53944 .50372 .53861 .50287 Mtetra
.668 .754 .914 r
.53861 .50287 .53944 .50372 .541 .5032 .54017 .50237 Mtetra
.68 .76 .912 r
.54017 .50237 .541 .5032 .54255 .50259 .54172 .50181 Mtetra
.694 .777 .916 r
.54172 .50181 .54255 .50259 .5441 .50186 .54328 .5012 Mtetra
.68 .805 .942 r
.54328 .5012 .5441 .50186 .54566 .50133 .54483 .50064 Mtetra
.679 .795 .936 r
.54483 .50064 .54566 .50133 .54722 .5013 .54639 .50008 Mtetra
.672 .682 .851 r
.54639 .50008 .54722 .5013 .54879 .50223 .54795 .49953 Mtetra
.587 .504 .728 r
.54795 .49953 .54879 .50223 .55037 .50452 .54951 .49943 Mtetra
.477 .366 .649 r
.54951 .49943 .55037 .50452 .55205 .51867 .55108 .50074 Mtetra
.159 .072 .5 r
.55108 .50074 .55205 .51867 .55518 .69915 .55277 .51478 Mtetra
0 0 .401 r
.55277 .51478 .55518 .69915 .55686 .7022 .55598 .7 Mtetra
0 .04 .605 r
.55598 .7 .55686 .7022 .55854 .70342 .55766 .70267 Mtetra
.32 .644 .967 r
.55766 .70267 .55854 .70342 .56021 .70359 .55933 .70295 Mtetra
.706 .826 .939 r
.55933 .70295 .56021 .70359 .56187 .70294 .56099 .70223 Mtetra
.878 .809 .777 r
.56099 .70223 .56187 .70294 .56351 .70071 .56264 .69996 Mtetra
.95 .737 .581 r
.56264 .69996 .56351 .70071 .56505 .68993 .5642 .69057 Mtetra
.962 .692 .478 r
.5642 .69057 .56505 .68993 .56443 .49763 .56361 .49723 Mtetra
.941 .813 .69 r
.56361 .49723 .56443 .49763 .56596 .49415 .56514 .49359 Mtetra
.748 .847 .925 r
.56514 .49359 .56596 .49415 .56752 .49331 .56671 .49274 Mtetra
.572 .799 .985 r
.56671 .49274 .56752 .49331 .5691 .49303 .56828 .49245 Mtetra
.486 .765 .993 r
.56828 .49245 .5691 .49303 .57067 .49292 .56985 .49235 Mtetra
.636 .82 .971 r
.56985 .49235 .57067 .49292 .57224 .49248 .57143 .4919 Mtetra
.635 .818 .971 r
.57143 .4919 .57224 .49248 .57381 .49203 .573 .49145 Mtetra
.636 .818 .97 r
.573 .49145 .57381 .49203 .57539 .49159 .57457 .491 Mtetra
.642 .819 .968 r
.57457 .491 .57539 .49159 .57696 .49112 .57615 .49054 Mtetra
.644 .819 .967 r
.57615 .49054 .57696 .49112 .57854 .49066 .57772 .49007 Mtetra
.646 .819 .966 r
.57772 .49007 .57854 .49066 .58011 .49018 .5793 .48959 Mtetra
.647 .819 .966 r
.5793 .48959 .58011 .49018 .58169 .48971 .58088 .48911 Mtetra
.649 .818 .965 r
.58088 .48911 .58169 .48971 .58327 .48923 .58246 .48863 Mtetra
.651 .818 .963 r
.58246 .48863 .58327 .48923 .58484 .48875 .58404 .48814 Mtetra
.656 .817 .961 r
.58404 .48814 .58484 .48875 .58642 .48826 .58561 .48764 Mtetra
.656 .814 .959 r
.58561 .48764 .58642 .48826 .588 .48777 .5872 .48714 Mtetra
.674 .816 .951 r
.5872 .48714 .588 .48777 .58958 .48723 .58878 .48658 Mtetra
.743 .823 .913 r
.58878 .48658 .58958 .48723 .59116 .48651 .59035 .48574 Mtetra
.662 .775 .933 r
.59035 .48574 .59116 .48651 .59274 .486 .59193 .48524 Mtetra
.292 .611 .955 r
.59193 .48524 .59274 .486 .59434 .48604 .59354 .48559 Mtetra
.909 .503 .195 r
.59354 .48559 .59434 .48604 .59597 .48793 .59522 .48987 Mtetra
.96 .681 .463 r
.59522 .48987 .59597 .48793 .59768 .49297 .60104 .68411 Mtetra
.573 .36 .553 r
.60104 .68411 .59768 .49297 .60351 .68143 .60284 .68897 Mtetra
.558 .302 .483 r
.60284 .68897 .60351 .68143 .60521 .68161 .60454 .68905 Mtetra
.527 .275 .476 r
.60454 .68905 .60521 .68161 .60688 .6805 .60623 .68842 Mtetra
.521 .273 .48 r
.60623 .68842 .60688 .6805 .60858 .68088 .60791 .6876 Mtetra
.555 .294 .474 r
.60791 .6876 .60858 .68088 .61039 .68534 .60961 .68764 Mtetra
.522 .176 .321 r
.60961 .68764 .61039 .68534 .61215 .68763 .61132 .68767 Mtetra
0 0 0 r
.61132 .68767 .61215 .68763 .61388 .68879 .61302 .68761 Mtetra
.541 .65 .906 r
.61302 .68761 .61388 .68879 .61559 .68885 .61473 .68759 Mtetra
.647 .682 .869 r
.61473 .68759 .61559 .68885 .61728 .68837 .61642 .68714 Mtetra
.764 .726 .817 r
.61642 .68714 .61728 .68837 .61896 .68727 .6181 .68589 Mtetra
.903 .727 .653 r
.6181 .68589 .61896 .68727 .6206 .68471 .61968 .68099 Mtetra
.961 .687 .468 r
.61968 .68099 .6206 .68471 .62218 .6798 .61602 .48599 Mtetra
.578 .367 .559 r
.61602 .48599 .62218 .6798 .61848 .48833 .61744 .47909 Mtetra
.62 .435 .61 r
.61744 .47909 .61848 .48833 .61989 .48142 .61901 .47753 Mtetra
.636 .497 .675 r
.61901 .47753 .61989 .48142 .62143 .47857 .6206 .4767 Mtetra
.641 .592 .783 r
.6206 .4767 .62143 .47857 .62299 .47686 .6222 .47623 Mtetra
.665 .816 .956 r
.6222 .47623 .62299 .47686 .62459 .47624 .6238 .47569 Mtetra
.625 .829 .979 r
.6238 .47569 .62459 .47624 .62619 .47594 .6254 .47525 Mtetra
.63 .79 .959 r
.6254 .47525 .62619 .47594 .62781 .47576 .62701 .47484 Mtetra
.746 .766 .869 r
.62701 .47484 .62781 .47576 .6294 .47486 .6286 .47392 Mtetra
.69 .744 .893 r
.6286 .47392 .6294 .47486 .631 .47415 .6302 .47329 Mtetra
.512 .698 .954 r
.6302 .47329 .631 .47415 .63261 .47383 .63182 .47327 Mtetra
.861 .412 .04 r
.63182 .47327 .63261 .47383 .63427 .47511 .63355 .47655 Mtetra
.964 .681 .448 r
.63355 .47655 .63427 .47511 .63601 .4785 .64165 .67011 Mtetra
.576 .362 .553 r
.64165 .67011 .63601 .4785 .64414 .66883 .64362 .67735 Mtetra
.585 .329 .495 r
.64362 .67735 .64414 .66883 .6461 .6756 .64538 .67819 Mtetra
.52 .186 .342 r
.64538 .67819 .6461 .6756 .64791 .67784 .64711 .67815 Mtetra
0 0 0 r
.64711 .67815 .64791 .67784 .64967 .67882 .64882 .67768 Mtetra
.529 .654 .915 r
.64882 .67768 .64967 .67882 .65141 .67896 .65056 .67769 Mtetra
.631 .675 .873 r
.65056 .67769 .65141 .67896 .65313 .67855 .65228 .67731 Mtetra
.74 .719 .832 r
.65228 .67731 .65313 .67855 .65483 .67757 .65397 .67625 Mtetra
.9 .736 .67 r
.65397 .67625 .65483 .67757 .65648 .67522 .65555 .67197 Mtetra
.965 .687 .456 r
.65555 .67197 .65648 .67522 .65805 .67092 .64995 .47824 Mtetra
.581 .37 .559 r
.64995 .47824 .65805 .67092 .65252 .48265 .65124 .46912 Mtetra
.608 .414 .593 r
.65124 .46912 .65252 .48265 .65375 .47221 .65281 .46736 Mtetra
.623 .471 .655 r
.65281 .46736 .65375 .47221 .65527 .4691 .65442 .46655 Mtetra
.621 .535 .736 r
.65442 .46655 .65527 .4691 .65684 .46728 .65604 .46616 Mtetra
.661 .7 .875 r
.65604 .46616 .65684 .46728 .65845 .4665 .65766 .46566 Mtetra
.645 .757 .931 r
.65766 .46566 .65845 .4665 .66007 .46608 .65929 .46522 Mtetra
.633 .748 .931 r
.65929 .46522 .66007 .46608 .6617 .46582 .66092 .46483 Mtetra
.653 .724 .902 r
.66092 .46483 .6617 .46582 .66332 .46524 .66254 .46437 Mtetra
.655 .752 .921 r
.66254 .46437 .66332 .46524 .66494 .46462 .66417 .4639 Mtetra
.652 .79 .948 r
.66417 .4639 .66494 .46462 .66657 .46403 .6658 .46341 Mtetra
.647 .819 .966 r
.6658 .46341 .66657 .46403 .6682 .46362 .66742 .46292 Mtetra
.656 .798 .951 r
.66742 .46292 .6682 .46362 .66983 .46327 .66905 .46242 Mtetra
.663 .761 .923 r
.66905 .46242 .66983 .46327 .67146 .46292 .67068 .46191 Mtetra
.663 .726 .896 r
.67068 .46191 .67146 .46292 .6731 .46244 .67231 .4614 Mtetra
.666 .72 .889 r
.67231 .4614 .6731 .46244 .67472 .46189 .67394 .46088 Mtetra
.672 .729 .893 r
.67394 .46088 .67472 .46189 .67635 .46127 .67557 .46033 Mtetra
.701 .754 .893 r
.67557 .46033 .67635 .46127 .67796 .46033 .67719 .45965 Mtetra
.701 .817 .937 r
.67719 .45965 .67796 .46033 .67958 .45949 .67882 .45897 Mtetra
.664 .854 .973 r
.67882 .45897 .67958 .45949 .68121 .45898 .68045 .45839 Mtetra
.678 .838 .96 r
.68045 .45839 .68121 .45898 .68289 .45948 .68208 .45779 Mtetra
.616 .6 .811 r
.68208 .45779 .68289 .45948 .68464 .46114 .68373 .4575 Mtetra
.539 .442 .693 r
.68373 .4575 .68464 .46114 .68654 .46613 .68541 .4579 Mtetra
.348 .247 .597 r
.68541 .4579 .68654 .46613 .69775 .65813 .68729 .46238 Mtetra
.064 0 .45 r
.68729 .46238 .69775 .65813 .69974 .66264 .69874 .65814 Mtetra
.035 .085 .584 r
.69874 .65814 .69974 .66264 .7016 .66444 .70074 .66283 Mtetra
.389 .5 .851 r
.70074 .66283 .7016 .66444 .70339 .66477 .70255 .66351 Mtetra
.637 .683 .876 r
.70255 .66351 .70339 .66477 .70514 .66438 .7043 .6631 Mtetra
.716 .709 .842 r
.7043 .6631 .70514 .66438 .70687 .66345 .70603 .6622 Mtetra
.668 .697 .868 r
.70603 .6622 .70687 .66345 .70856 .66178 .70778 .66162 Mtetra
.619 .938 .957 r
.70778 .66162 .70856 .66178 .71019 .65905 .70952 .66086 Mtetra
.173 0 .123 r
.70952 .66086 .71019 .65905 .71168 .65366 .71122 .65942 Mtetra
.133 0 .349 r
.71122 .65942 .71168 .65366 .70295 .46011 .71272 .65423 Mtetra
.061 0 .443 r
.71272 .65423 .70295 .46011 .70431 .45416 .70375 .45709 Mtetra
0 0 0 r
.70375 .45709 .70431 .45416 .70583 .45145 .7051 .45122 Mtetra
.877 .942 .855 r
.7051 .45122 .70583 .45145 .70745 .45039 .70669 .44958 Mtetra
.665 .775 .931 r
.70669 .44958 .70745 .45039 .70911 .45 .70834 .44905 Mtetra
.565 .702 .933 r
.70834 .44905 .70911 .45 .71078 .44984 .71001 .4489 Mtetra
.65 .737 .913 r
.71001 .4489 .71078 .44984 .71242 .44919 .71167 .44844 Mtetra
.681 .795 .935 r
.71167 .44844 .71242 .44919 .71406 .44842 .71332 .44784 Mtetra
.646 .835 .973 r
.71332 .44784 .71406 .44842 .71571 .44791 .71497 .44732 Mtetra
.657 .836 .969 r
.71497 .44732 .71571 .44791 .71742 .44825 .71662 .44677 Mtetra
.621 .63 .838 r
.71662 .44677 .71742 .44825 .71919 .44966 .71829 .44646 Mtetra
.546 .462 .711 r
.71829 .44646 .71919 .44966 .7211 .45338 .72 .44675 Mtetra
.371 .278 .619 r
.72 .44675 .7211 .45338 .73442 .64591 .72189 .45013 Mtetra
.081 .004 .459 r
.72189 .45013 .73442 .64591 .73658 .65185 .7355 .64637 Mtetra
.036 .067 .562 r
.7355 .64637 .73658 .65185 .7385 .65396 .73765 .65223 Mtetra
.323 .444 .829 r
.73765 .65223 .7385 .65396 .74033 .65434 .73951 .65323 Mtetra
.629 .707 .902 r
.73951 .65323 .74033 .65434 .7421 .65393 .74129 .65284 Mtetra
.713 .743 .875 r
.74129 .65284 .7421 .65393 .74386 .65323 .74304 .65201 Mtetra
.669 .704 .873 r
.74304 .65201 .74386 .65323 .74564 .65281 .74481 .65143 Mtetra
.637 .665 .86 r
.74481 .65143 .74564 .65281 .74742 .65246 .74659 .651 Mtetra
.651 .66 .846 r
.74659 .651 .74742 .65246 .74919 .65182 .74837 .65049 Mtetra
.645 .677 .865 r
.74837 .65049 .74919 .65182 .75091 .6504 .75015 .65003 Mtetra
.644 .903 .983 r
.75015 .65003 .75091 .6504 .75255 .64789 .75191 .64936 Mtetra
.137 0 .044 r
.75191 .64936 .75255 .64789 .75406 .64328 .75364 .64807 Mtetra
.169 0 .342 r
.75364 .64807 .75406 .64328 .743 .45014 .75518 .64392 Mtetra
.081 .001 .455 r
.75518 .64392 .743 .45014 .74419 .44246 .74381 .44704 Mtetra
0 0 .147 r
.74381 .44704 .74419 .44246 .74569 .43946 .74501 .43945 Mtetra
.913 .971 .79 r
.74501 .43945 .74569 .43946 .74731 .43819 .74657 .43739 Mtetra
.677 .786 .931 r
.74657 .43739 .74731 .43819 .749 .43778 .74824 .43681 Mtetra
.564 .697 .93 r
.74824 .43681 .749 .43778 .7507 .43768 .74994 .43666 Mtetra
.6 .704 .916 r
.74994 .43666 .7507 .43768 .75239 .43742 .75164 .4364 Mtetra
.652 .724 .902 r
.75164 .4364 .75239 .43742 .75407 .43694 .75332 .43593 Mtetra
.657 .73 .903 r
.75332 .43593 .75407 .43694 .75574 .43639 .755 .43544 Mtetra
.682 .752 .904 r
.755 .43544 .75574 .43639 .7574 .43558 .75667 .43483 Mtetra
.695 .805 .933 r
.75667 .43483 .7574 .43558 .75906 .43472 .75834 .43417 Mtetra
.664 .853 .972 r
.75834 .43417 .75906 .43472 .76073 .43412 .76002 .43358 Mtetra
.662 .853 .973 r
.76002 .43358 .76073 .43412 .76246 .43429 .76169 .43298 Mtetra
.638 .665 .859 r
.76169 .43298 .76246 .43429 .76428 .4356 .76338 .43258 Mtetra
.558 .478 .72 r
.76338 .43258 .76428 .4356 .76626 .43906 .76512 .43274 Mtetra
.419 .316 .631 r
.76512 .43274 .76626 .43906 .78235 .63177 .76704 .43538 Mtetra
.106 .025 .472 r
.76704 .43538 .78235 .63177 .78467 .6384 .78344 .63144 Mtetra
.09 .087 .559 r
.78344 .63144 .78467 .6384 .78668 .64067 .78581 .63858 Mtetra
.27 .37 .782 r
.78581 .63858 .78668 .64067 .78857 .64135 .78776 .64005 Mtetra
.603 .664 .882 r
.78776 .64005 .78857 .64135 .79039 .6411 .78958 .63979 Mtetra
.701 .705 .851 r
.78958 .63979 .79039 .6411 .79217 .6403 .79136 .63899 Mtetra
.691 .701 .855 r
.79136 .63899 .79217 .6403 .7939 .63884 .79315 .63825 Mtetra
.667 .853 .971 r
.79315 .63825 .7939 .63884 .79555 .63645 .79494 .63761 Mtetra
.058 0 0 r
.79494 .63761 .79555 .63645 .79706 .63218 .79669 .63638 Mtetra
.194 0 .335 r
.79669 .63638 .79706 .63218 .78366 .44002 .79826 .63284 Mtetra
.101 .018 .466 r
.79826 .63284 .78366 .44002 .78463 .43029 .78449 .43687 Mtetra
0 0 .27 r
.78449 .43687 .78463 .43029 .78611 .42704 .78547 .42724 Mtetra
.922 .974 .702 r
.78547 .42724 .78611 .42704 .78772 .42554 .78701 .42478 Mtetra
.698 .804 .931 r
.78701 .42478 .78772 .42554 .78942 .42506 .78869 .42409 Mtetra
.585 .712 .931 r
.78869 .42409 .78942 .42506 .79115 .42487 .79041 .42387 Mtetra
.613 .716 .918 r
.79041 .42387 .79115 .42487 .79285 .42441 .79213 .42355 Mtetra
.687 .778 .92 r
.79213 .42355 .79285 .42441 .79453 .42356 .79382 .42292 Mtetra
.665 .828 .962 r
.79382 .42292 .79453 .42356 .79622 .42293 .79552 .42234 Mtetra
.657 .842 .971 r
.79552 .42234 .79622 .42293 .79797 .42295 .79722 .42177 Mtetra
.649 .694 .878 r
.79722 .42177 .79797 .42295 .79981 .42407 .79893 .4213 Mtetra
.57 .497 .734 r
.79893 .4213 .79981 .42407 .8018 .42687 .80068 .42134 Mtetra
.452 .349 .647 r
.80068 .42134 .8018 .42687 .81976 .61593 .8026 .42327 Mtetra
.12 .039 .481 r
.8026 .42327 .81976 .61593 .82254 .62663 .82097 .61631 Mtetra
.081 .059 .53 r
.82097 .61631 .82254 .62663 .82464 .62933 .82379 .62735 Mtetra
.055 .241 .737 r
.82379 .62735 .82464 .62933 .82661 .63046 .82585 .62955 Mtetra
.435 .666 .959 r
.82585 .62955 .82661 .63046 .82849 .63067 .82773 .62971 Mtetra
.713 .778 .903 r
.82773 .62971 .82849 .63067 .83031 .63005 .82953 .6289 Mtetra
.879 .777 .746 r
.82953 .6289 .83031 .63005 .83196 .62758 .83117 .62627 Mtetra
.968 .732 .529 r
.83117 .62627 .83196 .62758 .8329 .61715 .83211 .61584 Mtetra
.977 .681 .379 r
.83211 .61584 .8329 .61715 .81695 .41932 .81626 .41866 Mtetra
.947 .831 .697 r
.81626 .41866 .81695 .41932 .81842 .41604 .81772 .41534 Mtetra
.707 .829 .94 r
.81772 .41534 .81842 .41604 .82012 .41541 .81942 .41461 Mtetra
.537 .732 .965 r
.81942 .41461 .82012 .41541 .82189 .41541 .82117 .41447 Mtetra
.524 .691 .944 r
.82117 .41447 .82189 .41541 .82366 .41548 .82293 .41443 Mtetra
.63 .714 .907 r
.82293 .41443 .82366 .41548 .82539 .41509 .82467 .41404 Mtetra
.634 .716 .907 r
.82467 .41404 .82539 .41509 .82712 .41464 .8264 .41364 Mtetra
.645 .731 .912 r
.8264 .41364 .82712 .41464 .82884 .4141 .82813 .41319 Mtetra
.661 .758 .922 r
.82813 .41319 .82884 .4141 .83055 .41346 .82985 .41266 Mtetra
.667 .789 .939 r
.82985 .41266 .83055 .41346 .83226 .41281 .83157 .4121 Mtetra
.665 .813 .954 r
.83157 .4121 .83226 .41281 .83398 .41222 .83329 .41152 Mtetra
.663 .816 .957 r
.83329 .41152 .83398 .41222 .83571 .41175 .83501 .41095 Mtetra
.671 .79 .938 r
.83501 .41095 .83571 .41175 .83744 .4113 .83673 .41037 Mtetra
.711 .773 .9 r
.83673 .41037 .83744 .4113 .83916 .41068 .83844 .40961 Mtetra
.746 .754 .859 r
.83844 .40961 .83916 .41068 .84085 .40981 .84012 .4086 Mtetra
.668 .7 .871 r
.84012 .4086 .84085 .40981 .84258 .4092 .84185 .40803 Mtetra
.304 .515 .895 r
.84185 .40803 .84258 .4092 .84437 .40932 .8437 .40874 Mtetra
.891 .479 .071 r
.8437 .40874 .84437 .40932 .84634 .41118 .84607 .41464 Mtetra
.973 .666 .36 r
.84607 .41464 .84634 .41118 .84873 .41723 .8676 .61251 Mtetra
.571 .357 .552 r
.8676 .61251 .84873 .41723 .86995 .61051 .86986 .61612 Mtetra
.564 .287 .455 r
.86986 .61612 .86995 .61051 .87223 .61429 .8718 .61641 Mtetra
.463 .108 .278 r
.8718 .61641 .87223 .61429 .8743 .6159 .87367 .61607 Mtetra
0 0 0 r
.87367 .61607 .8743 .6159 .87628 .61659 .87553 .61562 Mtetra
.525 .701 .95 r
.87553 .61562 .87628 .61659 .87819 .61667 .87744 .61556 Mtetra
.658 .728 .901 r
.87744 .61556 .87819 .61667 .88006 .61621 .87929 .61501 Mtetra
.817 .766 .805 r
.87929 .61501 .88006 .61621 .88184 .61496 .88102 .61327 Mtetra
.932 .73 .607 r
.88102 .61327 .88184 .61496 .88345 .61207 .88231 .6072 Mtetra
.976 .674 .366 r
.88231 .6072 .88345 .61207 .88475 .60617 .86328 .40733 Mtetra
.574 .364 .558 r
.86328 .40733 .88475 .60617 .86598 .41023 .86453 .4021 Mtetra
.619 .439 .617 r
.86453 .4021 .86598 .41023 .8672 .40468 .86619 .40073 Mtetra
.626 .492 .679 r
.86619 .40073 .8672 .40468 .86872 .40206 .86791 .40001 Mtetra
.633 .581 .778 r
.86791 .40001 .86872 .40206 .87036 .40051 .86967 .39955 Mtetra
.671 .755 .914 r
.86967 .39955 .87036 .40051 .87209 .39981 .87141 .39897 Mtetra
.652 .778 .94 r
.87141 .39897 .87209 .39981 .87385 .39937 .87316 .39846 Mtetra
.675 .768 .921 r
.87316 .39846 .87385 .39937 .8756 .39889 .8749 .39786 Mtetra
.743 .765 .871 r
.8749 .39786 .8756 .39889 .8773 .39791 .8766 .39689 Mtetra
.675 .743 .902 r
.8766 .39689 .8773 .39791 .87903 .39718 .87835 .39629 Mtetra
.358 .617 .949 r
.87835 .39629 .87903 .39718 .88083 .39705 .8802 .39665 Mtetra
.849 .401 0 r
.8802 .39665 .88083 .39705 .88281 .39862 .88251 .4011 Mtetra
.973 .662 .336 r
.88251 .4011 .88281 .39862 .88513 .40314 .90653 .60029 Mtetra
.572 .359 .552 r
.90653 .60029 .88513 .40314 .90892 .59882 .90901 .60514 Mtetra
.574 .302 .466 r
.90901 .60514 .90892 .59882 .91139 .60365 .91101 .60567 Mtetra
.478 .114 .269 r
.91101 .60567 .91139 .60365 .91354 .60551 .91292 .60547 Mtetra
.345 .823 .862 r
.91292 .60547 .91354 .60551 .91557 .60627 .91481 .60498 Mtetra
.561 .652 .897 r
.91481 .60498 .91557 .60627 .9175 .60623 .91674 .60489 Mtetra
.657 .69 .869 r
.91674 .60489 .9175 .60623 .91938 .60564 .91862 .60433 Mtetra
.789 .747 .814 r
.91862 .60433 .91938 .60564 .92117 .60433 .92039 .60281 Mtetra
.941 .745 .61 r
.92039 .60281 .92117 .60433 .92275 .60118 .92167 .59709 Mtetra
.976 .67 .343 r
.92167 .59709 .92275 .60118 .92397 .59498 .90022 .39648 Mtetra
.575 .365 .558 r
.90022 .39648 .92397 .59498 .90309 .40048 .90137 .39068 Mtetra
.601 .419 .608 r
.90137 .39068 .90309 .40048 .90478 .39925 .90308 .38965 Mtetra
.582 .407 .61 r
.90308 .38965 .90478 .39925 .9067 .39991 .90488 .38932 Mtetra
.574 .398 .605 r
.90488 .38932 .9067 .39991 .90844 .39909 .9067 .38922 Mtetra
.597 .416 .607 r
.9067 .38922 .90844 .39909 .90955 .39301 .90843 .38832 Mtetra
.628 .479 .66 r
.90843 .38832 .90955 .39301 .91099 .38972 .91015 .38741 Mtetra
.668 .582 .75 r
.91015 .38741 .91099 .38972 .91257 .38763 .91189 .38658 Mtetra
.666 .736 .902 r
.91189 .38658 .91257 .38763 .91432 .38687 .91366 .38602 Mtetra
.648 .775 .941 r
.91366 .38602 .91432 .38687 .9161 .38641 .91544 .38552 Mtetra
.646 .763 .934 r
.91544 .38552 .9161 .38641 .9179 .38608 .91722 .38503 Mtetra
.672 .737 .899 r
.91722 .38503 .9179 .38608 .91967 .3855 .91899 .38443 Mtetra
.675 .736 .896 r
.91899 .38443 .91967 .3855 .92144 .3849 .92076 .38382 Mtetra
.681 .736 .892 r
.92076 .38382 .92144 .3849 .92321 .38427 .92253 .38319 Mtetra
.757 .763 .858 r
.92253 .38319 .92321 .38427 .92492 .38318 .92424 .3821 Mtetra
.693 .741 .888 r
.92424 .3821 .92492 .38318 .92668 .38247 .926 .3814 Mtetra
.512 .656 .925 r
.926 .3814 .92668 .38247 .92853 .38252 .92785 .38145 Mtetra
.714 .299 0 r
.92785 .38145 .92853 .38252 .93098 .38725 .9303 .38611 Mtetra
.97 .655 .291 r
.9303 .38611 .93098 .38725 .95839 .5883 .95768 .58725 Mtetra
.728 .306 0 r
.95768 .58725 .95839 .5883 .96098 .59315 .96028 .59216 Mtetra
.011 .438 .866 r
.34432 .75978 .34527 .7606 .34676 .76124 .3458 .76046 Mtetra
.637 .76 .936 r
.3458 .76046 .34676 .76124 .34829 .76084 .34734 .76007 Mtetra
.809 .78 .825 r
.34734 .76007 .34829 .76084 .34988 .75941 .34893 .75863 Mtetra
.908 .738 .659 r
.34893 .75863 .34988 .75941 .35166 .75413 .3507 .75337 Mtetra
.937 .686 .534 r
.3507 .75337 .35166 .75413 .36236 .56268 .36147 .56187 Mtetra
.909 .728 .645 r
.36147 .56187 .36236 .56268 .36407 .55697 .36318 .55613 Mtetra
.777 .76 .837 r
.36318 .55613 .36407 .55697 .36556 .55585 .36467 .55502 Mtetra
.641 .736 .918 r
.36467 .55502 .36556 .55585 .36702 .55548 .36612 .55465 Mtetra
.509 .691 .95 r
.36612 .55465 .36702 .55548 .36845 .55548 .36756 .55464 Mtetra
.745 .757 .862 r
.36756 .55464 .36845 .55548 .36993 .55461 .36904 .55376 Mtetra
.695 .748 .892 r
.36904 .55376 .36993 .55461 .3714 .55401 .37051 .55317 Mtetra
.478 .677 .952 r
.37051 .55317 .3714 .55401 .37284 .55407 .37195 .55323 Mtetra
.928 .549 .253 r
.37195 .55323 .37284 .55407 .3741 .5581 .37321 .55725 Mtetra
.939 .683 .522 r
.37321 .55725 .3741 .5581 .36711 .74895 .36617 .74815 Mtetra
.935 .578 .319 r
.36617 .74815 .36711 .74895 .36842 .75407 .36747 .75328 Mtetra
0 .342 .791 r
.36747 .75328 .36842 .75407 .36991 .7549 .36896 .75411 Mtetra
.618 .754 .943 r
.36896 .75411 .36991 .7549 .37146 .75456 .37051 .75378 Mtetra
.8 .78 .835 r
.37051 .75378 .37146 .75456 .37305 .75323 .3721 .75244 Mtetra
.905 .744 .67 r
.3721 .75244 .37305 .75323 .37478 .74854 .37384 .74774 Mtetra
.939 .687 .529 r
.37384 .74774 .37478 .74854 .38428 .55705 .38339 .55617 Mtetra
.914 .723 .631 r
.38339 .55617 .38428 .55705 .386 .55047 .38512 .54961 Mtetra
.798 .758 .816 r
.38512 .54961 .386 .55047 .38751 .54913 .38662 .54826 Mtetra
.647 .732 .911 r
.38662 .54826 .38751 .54913 .38898 .54875 .38809 .54787 Mtetra
.508 .681 .944 r
.38809 .54787 .38898 .54875 .39043 .54877 .38955 .54788 Mtetra
.728 .745 .865 r
.38955 .54788 .39043 .54877 .39191 .54805 .39103 .54709 Mtetra
.694 .725 .873 r
.39103 .54709 .39191 .54805 .39339 .54748 .39251 .54649 Mtetra
.509 .654 .924 r
.39251 .54649 .39339 .54748 .39484 .54747 .39396 .54653 Mtetra
.926 .54 .216 r
.39396 .54653 .39484 .54747 .39618 .55064 .39527 .5505 Mtetra
.941 .682 .517 r
.39527 .5505 .39618 .55064 .3905 .73992 .38945 .74211 Mtetra
.815 .504 .464 r
.38945 .74211 .3905 .73992 .3918 .74643 .3908 .74716 Mtetra
.585 .12 .117 r
.3908 .74716 .3918 .74643 .39332 .74713 .39233 .74774 Mtetra
.061 0 0 r
.39233 .74774 .39332 .74713 .39488 .74666 .39389 .74728 Mtetra
0 0 0 r
.39389 .74728 .39488 .74666 .39647 .74574 .39548 .74641 Mtetra
.231 0 0 r
.39548 .74641 .39647 .74574 .39802 .74558 .39704 .74615 Mtetra
.132 0 0 r
.39704 .74615 .39802 .74558 .39958 .7453 .3986 .74582 Mtetra
0 0 0 r
.3986 .74582 .39958 .7453 .40117 .74431 .40018 .74499 Mtetra
.962 .94 .699 r
.40018 .74499 .40117 .74431 .4029 .73931 .40185 .74185 Mtetra
1 .823 .519 r
.40185 .74185 .4029 .73931 .41093 .54768 .40376 .73135 Mtetra
0 0 .317 r
.40376 .73135 .41093 .54768 .41259 .54206 .4116 .54439 Mtetra
.034 0 .101 r
.4116 .54439 .41259 .54206 .4141 .54056 .41314 .54242 Mtetra
.428 .067 .248 r
.41314 .54242 .4141 .54056 .41559 .54008 .41462 .54202 Mtetra
.502 .147 .297 r
.41462 .54202 .41559 .54008 .41706 .53997 .41609 .54196 Mtetra
.195 0 .142 r
.41609 .54196 .41706 .53997 .41854 .53967 .41761 .5407 Mtetra
0 0 0 r
.41761 .5407 .41854 .53967 .42003 .53927 .41913 .53917 Mtetra
.837 .939 .893 r
.41913 .53917 .42003 .53927 .42152 .53886 .42064 .53789 Mtetra
.704 .727 .868 r
.42064 .53789 .42152 .53886 .42301 .53834 .42214 .53722 Mtetra
.642 .679 .87 r
.42214 .53722 .42301 .53834 .4245 .53781 .42363 .53685 Mtetra
.62 .705 .906 r
.42363 .53685 .4245 .53781 .42599 .53733 .42511 .53655 Mtetra
.67 .762 .919 r
.42511 .53655 .42599 .53733 .42747 .53713 .42661 .53606 Mtetra
.688 .705 .861 r
.42661 .53606 .42747 .53713 .42895 .53708 .4281 .53547 Mtetra
.669 .622 .794 r
.4281 .53547 .42895 .53708 .43043 .53706 .4296 .53487 Mtetra
.671 .577 .741 r
.4296 .53487 .43043 .53706 .43193 .5364 .4311 .53409 Mtetra
.654 .561 .738 r
.4311 .53409 .43193 .5364 .43343 .53568 .4326 .53345 Mtetra
.602 .537 .754 r
.4326 .53345 .43343 .53568 .43492 .53554 .43409 .53325 Mtetra
.155 .257 .718 r
.43409 .53325 .43492 .53554 .43632 .53864 .43553 .53492 Mtetra
.805 .533 0 r
.43553 .53492 .43632 .53864 .43287 .72954 .43683 .54203 Mtetra
0 0 .346 r
.43683 .54203 .43287 .72954 .43429 .73542 .43346 .73079 Mtetra
.405 .327 .655 r
.43346 .73079 .43429 .73542 .43584 .73646 .43499 .73257 Mtetra
.607 .481 .682 r
.43499 .73257 .43584 .73646 .43742 .73618 .43658 .73218 Mtetra
.634 .496 .677 r
.43658 .73218 .43742 .73618 .43902 .73546 .43818 .73138 Mtetra
.551 .439 .679 r
.43818 .73138 .43902 .73546 .44061 .73491 .43975 .73166 Mtetra
.484 .421 .711 r
.43975 .73166 .44061 .73491 .44221 .73445 .44132 .73241 Mtetra
.462 .484 .795 r
.44132 .73241 .44221 .73445 .4438 .73392 .44289 .73294 Mtetra
.504 .671 .939 r
.44289 .73294 .4438 .73392 .4454 .73315 .44447 .73297 Mtetra
.414 .836 .962 r
.44447 .73297 .4454 .73315 .44701 .73223 .44606 .73268 Mtetra
.003 0 0 r
.44606 .73268 .44701 .73223 .44861 .73128 .44766 .73227 Mtetra
.269 0 0 r
.44766 .73227 .44861 .73128 .45022 .7306 .44925 .73185 Mtetra
.335 0 .072 r
.44925 .73185 .45022 .7306 .45181 .73015 .45085 .73143 Mtetra
.328 0 .074 r
.45085 .73143 .45181 .73015 .45341 .72978 .45245 .73097 Mtetra
.289 0 .025 r
.45245 .73097 .45341 .72978 .45501 .72939 .45405 .73047 Mtetra
.242 0 0 r
.45405 .73047 .45501 .72939 .45661 .72897 .45566 .72993 Mtetra
.198 0 0 r
.45566 .72993 .45661 .72897 .45821 .72854 .45726 .72939 Mtetra
.301 0 0 r
.45726 .72939 .45821 .72854 .4598 .72844 .45886 .72913 Mtetra
.256 0 0 r
.45886 .72913 .4598 .72844 .4614 .72831 .46046 .72889 Mtetra
0 0 0 r
.46046 .72889 .4614 .72831 .46301 .72754 .46207 .72823 Mtetra
.892 .983 .706 r
.46207 .72823 .46301 .72754 .46466 .72397 .46371 .72583 Mtetra
.992 .865 .521 r
.46371 .72583 .46466 .72397 .46943 .53245 .46542 .71893 Mtetra
0 0 .345 r
.46542 .71893 .46943 .53245 .47107 .52455 .47014 .52762 Mtetra
0 0 .082 r
.47014 .52762 .47107 .52455 .47261 .52242 .47171 .52425 Mtetra
.351 0 .205 r
.47171 .52425 .47261 .52242 .47413 .52179 .47323 .52354 Mtetra
.495 .127 .269 r
.47323 .52354 .47413 .52179 .47564 .52158 .47474 .52349 Mtetra
.484 .125 .282 r
.47474 .52349 .47564 .52158 .47716 .5213 .47626 .52334 Mtetra
.434 .084 .272 r
.47626 .52334 .47716 .5213 .47868 .52084 .47778 .52289 Mtetra
.436 .088 .274 r
.47778 .52289 .47868 .52084 .4802 .52039 .4793 .52245 Mtetra
.435 .087 .275 r
.4793 .52245 .4802 .52039 .48172 .51992 .48083 .522 Mtetra
.433 .086 .275 r
.48083 .522 .48172 .51992 .48324 .51945 .48235 .52153 Mtetra
.432 .085 .275 r
.48235 .52153 .48324 .51945 .48476 .51898 .48387 .52106 Mtetra
.431 .084 .275 r
.48387 .52106 .48476 .51898 .48629 .5185 .4854 .52058 Mtetra
.43 .083 .274 r
.4854 .52058 .48629 .5185 .48781 .51802 .48693 .5201 Mtetra
.429 .082 .273 r
.48693 .5201 .48781 .51802 .48934 .51754 .48845 .51961 Mtetra
.428 .08 .272 r
.48845 .51961 .48934 .51754 .49086 .51706 .48998 .51912 Mtetra
.426 .079 .271 r
.48998 .51912 .49086 .51706 .49239 .51658 .49151 .51862 Mtetra
.425 .077 .269 r
.49151 .51862 .49239 .51658 .49392 .51609 .49304 .51813 Mtetra
.423 .074 .267 r
.49304 .51813 .49392 .51609 .49545 .51561 .49457 .51763 Mtetra
.421 .071 .264 r
.49457 .51763 .49545 .51561 .49698 .51512 .49611 .51712 Mtetra
.42 .069 .261 r
.49611 .51712 .49698 .51512 .49851 .51463 .49764 .51662 Mtetra
.419 .067 .259 r
.49764 .51662 .49851 .51463 .50004 .51415 .49917 .51611 Mtetra
.419 .066 .257 r
.49917 .51611 .50004 .51415 .50157 .51366 .50071 .51562 Mtetra
.419 .065 .256 r
.50071 .51562 .50157 .51366 .50311 .51318 .50224 .51513 Mtetra
.42 .065 .255 r
.50224 .51513 .50311 .51318 .50464 .5127 .50378 .51465 Mtetra
.421 .066 .255 r
.50378 .51465 .50464 .5127 .50618 .51223 .50531 .51417 Mtetra
.423 .068 .256 r
.50531 .51417 .50618 .51223 .50771 .51175 .50685 .5137 Mtetra
.425 .07 .257 r
.50685 .5137 .50771 .51175 .50925 .51128 .50839 .51324 Mtetra
.429 .074 .26 r
.50839 .51324 .50925 .51128 .51079 .51082 .50993 .51279 Mtetra
.431 .078 .263 r
.50993 .51279 .51079 .51082 .51232 .51036 .51147 .51235 Mtetra
.453 .1 .276 r
.51147 .51235 .51232 .51036 .51386 .50991 .51301 .51201 Mtetra
.475 .128 .297 r
.51301 .51201 .51386 .50991 .5154 .50947 .51455 .51175 Mtetra
.445 .11 .302 r
.51455 .51175 .5154 .50947 .51694 .50904 .51609 .51127 Mtetra
.306 0 .235 r
.51609 .51127 .51694 .50904 .51849 .50862 .51764 .51015 Mtetra
0 0 0 r
.51764 .51015 .51849 .50862 .52003 .50822 .51919 .50852 Mtetra
.788 .999 .818 r
.51919 .50852 .52003 .50822 .52157 .50782 .52073 .50708 Mtetra
.768 .797 .876 r
.52073 .50708 .52157 .50782 .52312 .50741 .52228 .50608 Mtetra
.664 .659 .836 r
.52228 .50608 .52312 .50741 .52466 .50699 .52382 .50556 Mtetra
.637 .635 .832 r
.52382 .50556 .52466 .50699 .52621 .50656 .52537 .50518 Mtetra
.636 .642 .84 r
.52537 .50518 .52621 .50656 .52776 .50612 .52692 .50482 Mtetra
.651 .66 .845 r
.52692 .50482 .52776 .50612 .5293 .50567 .52847 .50437 Mtetra
.652 .66 .845 r
.52847 .50437 .5293 .50567 .53085 .50522 .53002 .50392 Mtetra
.653 .661 .845 r
.53002 .50392 .53085 .50522 .5324 .50477 .53157 .50347 Mtetra
.654 .662 .845 r
.53157 .50347 .5324 .50477 .53395 .50431 .53312 .50301 Mtetra
.653 .661 .846 r
.53312 .50301 .53395 .50431 .53551 .50384 .53467 .50256 Mtetra
.647 .661 .85 r
.53467 .50256 .53551 .50384 .53706 .50336 .53622 .50214 Mtetra
.638 .667 .862 r
.53622 .50214 .53706 .50336 .53861 .50287 .53778 .50177 Mtetra
.64 .689 .88 r
.53778 .50177 .53861 .50287 .54017 .50237 .53933 .50138 Mtetra
.652 .718 .897 r
.53933 .50138 .54017 .50237 .54172 .50181 .54089 .50095 Mtetra
.673 .75 .909 r
.54089 .50095 .54172 .50181 .54328 .5012 .54245 .50042 Mtetra
.683 .775 .92 r
.54245 .50042 .54328 .5012 .54483 .50064 .544 .49985 Mtetra
.729 .784 .897 r
.544 .49985 .54483 .50064 .54639 .50008 .54556 .49907 Mtetra
.758 .743 .839 r
.54556 .49907 .54639 .50008 .54795 .49953 .54711 .49802 Mtetra
.668 .64 .812 r
.54711 .49802 .54795 .49953 .54951 .49943 .54867 .49744 Mtetra
.405 .447 .791 r
.54867 .49744 .54951 .49943 .55108 .50074 .55024 .49822 Mtetra
.893 .562 .07 r
.55024 .49822 .55108 .50074 .55277 .51478 .55187 .50532 Mtetra
.971 .697 .455 r
.55187 .50532 .55277 .51478 .55598 .7 .5551 .69901 Mtetra
.828 .379 0 r
.5551 .69901 .55598 .7 .55766 .70267 .55679 .70222 Mtetra
.184 .646 .938 r
.55679 .70222 .55766 .70267 .55933 .70295 .55846 .70244 Mtetra
.703 .863 .958 r
.55846 .70244 .55933 .70295 .56099 .70223 .56012 .70172 Mtetra
.875 .851 .816 r
.56012 .70172 .56099 .70223 .56264 .69996 .56177 .69979 Mtetra
.964 .81 .642 r
.56177 .69979 .56264 .69996 .5642 .69057 .56338 .6947 Mtetra
.966 .697 .472 r
.56338 .6947 .5642 .69057 .56361 .49723 .56285 .50152 Mtetra
0 0 .08 r
.56285 .50152 .56361 .49723 .56514 .49359 .56435 .49552 Mtetra
.299 0 .199 r
.56435 .49552 .56514 .49359 .56671 .49274 .56592 .49453 Mtetra
.465 .098 .256 r
.56592 .49453 .56671 .49274 .56828 .49245 .56749 .49431 Mtetra
.516 .152 .288 r
.56749 .49431 .56828 .49245 .56985 .49235 .56907 .49436 Mtetra
.438 .087 .271 r
.56907 .49436 .56985 .49235 .57143 .4919 .57065 .49392 Mtetra
.441 .09 .274 r
.57065 .49392 .57143 .4919 .573 .49145 .57222 .4935 Mtetra
.441 .092 .276 r
.57222 .4935 .573 .49145 .57457 .491 .5738 .49307 Mtetra
.438 .091 .277 r
.5738 .49307 .57457 .491 .57615 .49054 .57538 .49261 Mtetra
.437 .09 .278 r
.57538 .49261 .57615 .49054 .57772 .49007 .57695 .49215 Mtetra
.436 .09 .278 r
.57695 .49215 .57772 .49007 .5793 .48959 .57853 .49168 Mtetra
.436 .09 .279 r
.57853 .49168 .5793 .48959 .58088 .48911 .58011 .49121 Mtetra
.435 .089 .279 r
.58011 .49121 .58088 .48911 .58246 .48863 .58169 .49072 Mtetra
.432 .087 .278 r
.58169 .49072 .58246 .48863 .58404 .48814 .58327 .49023 Mtetra
.428 .083 .275 r
.58327 .49023 .58404 .48814 .58561 .48764 .58485 .48971 Mtetra
.428 .081 .274 r
.58485 .48971 .58561 .48764 .5872 .48714 .58644 .4892 Mtetra
.409 .063 .264 r
.58644 .4892 .5872 .48714 .58878 .48658 .58802 .48859 Mtetra
.301 0 .212 r
.58802 .48859 .58878 .48658 .59035 .48574 .58959 .48754 Mtetra
.407 .043 .231 r
.58959 .48754 .59035 .48574 .59193 .48524 .59118 .48704 Mtetra
.627 .261 .329 r
.59118 .48704 .59193 .48524 .59354 .48559 .59279 .48792 Mtetra
.959 .68 .464 r
.59279 .48792 .59354 .48559 .59522 .48987 .59833 .67578 Mtetra
.583 .367 .554 r
.59833 .67578 .59522 .48987 .60104 .68411 .60027 .68717 Mtetra
.711 .388 .43 r
.60027 .68717 .60104 .68411 .60284 .68897 .60202 .68977 Mtetra
.422 0 0 r
.60202 .68977 .60284 .68897 .60454 .68905 .60372 .68983 Mtetra
.185 0 0 r
.60372 .68983 .60454 .68905 .60623 .68842 .60541 .68936 Mtetra
.128 0 0 r
.60541 .68936 .60623 .68842 .60791 .6876 .6071 .68864 Mtetra
.289 0 0 r
.6071 .68864 .60791 .6876 .60961 .68764 .60879 .6882 Mtetra
0 0 0 r
.60879 .6882 .60961 .68764 .61132 .68767 .61048 .68762 Mtetra
.602 .942 .937 r
.61048 .68762 .61132 .68767 .61302 .68761 .61217 .68685 Mtetra
.754 .811 .898 r
.61217 .68685 .61302 .68761 .61473 .68759 .61385 .68588 Mtetra
.754 .666 .764 r
.61385 .68588 .61473 .68759 .61642 .68714 .61552 .68439 Mtetra
.77 .614 .685 r
.61552 .68439 .61642 .68714 .6181 .68589 .61716 .68171 Mtetra
.96 .686 .47 r
.61716 .68171 .6181 .68589 .61968 .68099 .61396 .49868 Mtetra
.598 .383 .56 r
.61396 .49868 .61968 .68099 .61602 .48599 .61507 .48002 Mtetra
.707 .515 .627 r
.61507 .48002 .61602 .48599 .61744 .47909 .61659 .47665 Mtetra
.667 .565 .731 r
.61659 .47665 .61744 .47909 .61901 .47753 .61818 .47581 Mtetra
.622 .597 .804 r
.61818 .47581 .61901 .47753 .6206 .4767 .61979 .4755 Mtetra
.566 .645 .887 r
.61979 .4755 .6206 .4767 .6222 .47623 .6214 .47542 Mtetra
.707 .779 .908 r
.6214 .47542 .6222 .47623 .6238 .47569 .623 .47472 Mtetra
.69 .739 .888 r
.623 .47472 .6238 .47569 .6254 .47525 .6246 .4741 Mtetra
.652 .69 .873 r
.6246 .4741 .6254 .47525 .62701 .47484 .6262 .47365 Mtetra
.578 .651 .886 r
.6262 .47365 .62701 .47484 .6286 .47392 .62782 .47352 Mtetra
.041 .555 .872 r
.62782 .47352 .6286 .47392 .6302 .47329 .62945 .47388 Mtetra
.705 .24 .145 r
.62945 .47388 .6302 .47329 .63182 .47327 .63112 .47522 Mtetra
.924 .617 .442 r
.63112 .47522 .63182 .47327 .63355 .47655 .63331 .49253 Mtetra
.941 .658 .477 r
.63331 .49253 .63355 .47655 .64165 .67011 .64101 .67529 Mtetra
.681 .389 .473 r
.64101 .67529 .64165 .67011 .64362 .67735 .64284 .67823 Mtetra
.448 0 .031 r
.64284 .67823 .64362 .67735 .64538 .67819 .64457 .67834 Mtetra
.352 .826 .794 r
.64457 .67834 .64538 .67819 .64711 .67815 .64628 .67773 Mtetra
.778 .905 .929 r
.64628 .67773 .64711 .67815 .64882 .67768 .64798 .67665 Mtetra
.725 .752 .874 r
.64798 .67665 .64882 .67768 .65056 .67769 .64968 .67579 Mtetra
.73 .642 .761 r
.64968 .67579 .65056 .67769 .65228 .67731 .65137 .67447 Mtetra
.749 .6 .692 r
.65137 .67447 .65228 .67731 .65397 .67625 .65302 .67219 Mtetra
.884 .648 .577 r
.65302 .67219 .65397 .67625 .65555 .67197 .65432 .66035 Mtetra
.954 .676 .471 r
.65432 .66035 .65555 .67197 .64995 .47824 .64889 .4702 Mtetra
.688 .488 .611 r
.64889 .4702 .64995 .47824 .65124 .46912 .65038 .46643 Mtetra
.671 .557 .716 r
.65038 .46643 .65124 .46912 .65281 .46736 .65198 .46545 Mtetra
.618 .577 .786 r
.65198 .46545 .65281 .46736 .65442 .46655 .65361 .46514 Mtetra
.558 .606 .857 r
.65361 .46514 .65442 .46655 .65604 .46616 .65525 .46513 Mtetra
.679 .727 .886 r
.65525 .46513 .65604 .46616 .65766 .46566 .65687 .46455 Mtetra
.68 .711 .872 r
.65687 .46455 .65766 .46566 .65929 .46522 .65849 .46396 Mtetra
.645 .67 .86 r
.65849 .46396 .65929 .46522 .66092 .46483 .66011 .46353 Mtetra
.411 .549 .884 r
.66011 .46353 .66092 .46483 .66254 .46437 .66178 .46398 Mtetra
0 .256 .632 r
.66178 .46398 .66254 .46437 .66417 .4639 .66346 .46483 Mtetra
.622 .177 .172 r
.66346 .46483 .66417 .4639 .6658 .46341 .66515 .46566 Mtetra
.258 0 .229 r
.66515 .46566 .6658 .46341 .66742 .46292 .66674 .46422 Mtetra
0 0 0 r
.66674 .46422 .66742 .46292 .66905 .46242 .6683 .46233 Mtetra
.871 .969 .854 r
.6683 .46233 .66905 .46242 .67068 .46191 .66989 .46072 Mtetra
.697 .703 .852 r
.66989 .46072 .67068 .46191 .67231 .4614 .67151 .46001 Mtetra
.639 .648 .843 r
.67151 .46001 .67231 .4614 .67394 .46088 .67314 .45961 Mtetra
.621 .658 .865 r
.67314 .45961 .67394 .46088 .67557 .46033 .67478 .4593 Mtetra
.66 .719 .893 r
.67478 .4593 .67557 .46033 .67719 .45965 .67642 .45881 Mtetra
.677 .768 .92 r
.67642 .45881 .67719 .45965 .67882 .45897 .67805 .45824 Mtetra
.684 .798 .935 r
.67805 .45824 .67882 .45897 .68045 .45839 .67968 .45763 Mtetra
.763 .81 .89 r
.67968 .45763 .68045 .45839 .68208 .45779 .68129 .45665 Mtetra
.715 .719 .852 r
.68129 .45665 .68208 .45779 .68373 .4575 .68292 .45583 Mtetra
.619 .604 .813 r
.68292 .45583 .68373 .4575 .68541 .4579 .68456 .45553 Mtetra
.201 .287 .729 r
.68456 .45553 .68541 .4579 .68729 .46238 .68632 .45739 Mtetra
0 0 .321 r
.68632 .45739 .68729 .46238 .69874 .65814 .68842 .46614 Mtetra
.064 0 .45 r
.68842 .46614 .69874 .65814 .70074 .66283 .69974 .65818 Mtetra
.384 .32 .662 r
.69974 .65818 .70074 .66283 .70255 .66351 .70162 .6604 Mtetra
.514 .452 .725 r
.70162 .6604 .70255 .66351 .7043 .6631 .70342 .66095 Mtetra
.572 .544 .786 r
.70342 .66095 .7043 .6631 .70603 .6622 .7052 .66094 Mtetra
.512 .625 .9 r
.7052 .66094 .70603 .6622 .70778 .66162 .70698 .66105 Mtetra
.503 .79 .997 r
.70698 .66105 .70778 .66162 .70952 .66086 .70875 .66085 Mtetra
.575 .938 .911 r
.70875 .66085 .70952 .66086 .71122 .65942 .71049 .66004 Mtetra
.891 .956 .615 r
.71049 .66004 .71122 .65942 .71272 .65423 .71211 .65714 Mtetra
.83 .749 .23 r
.71211 .65714 .71272 .65423 .70375 .45709 .71344 .64883 Mtetra
.06 0 .443 r
.71344 .64883 .70375 .45709 .7051 .45122 .70454 .45394 Mtetra
0 0 .139 r
.70454 .45394 .7051 .45122 .70669 .44958 .70603 .4505 Mtetra
0 0 0 r
.70603 .4505 .70669 .44958 .70834 .44905 .70762 .4489 Mtetra
.738 .968 .934 r
.70762 .4489 .70834 .44905 .71001 .4489 .70924 .44789 Mtetra
.691 .738 .887 r
.70924 .44789 .71001 .4489 .71167 .44844 .71089 .44724 Mtetra
.645 .685 .873 r
.71089 .44724 .71167 .44844 .71332 .44784 .71255 .44681 Mtetra
.622 .707 .907 r
.71255 .44681 .71332 .44784 .71497 .44732 .71421 .44647 Mtetra
.722 .783 .901 r
.71421 .44647 .71497 .44732 .71662 .44677 .71585 .44569 Mtetra
.715 .731 .864 r
.71585 .44569 .71662 .44677 .71829 .44646 .71749 .44489 Mtetra
.627 .621 .825 r
.71749 .44489 .71829 .44646 .72 .44675 .71916 .44454 Mtetra
.253 .335 .755 r
.71916 .44454 .72 .44675 .72189 .45013 .72094 .44612 Mtetra
0 0 .379 r
.72094 .44612 .72189 .45013 .7355 .64637 .72306 .45313 Mtetra
.079 .002 .459 r
.72306 .45313 .7355 .64637 .73765 .65223 .7366 .64732 Mtetra
.434 .35 .662 r
.7366 .64732 .73765 .65223 .73951 .65323 .73852 .64917 Mtetra
.608 .482 .683 r
.73852 .64917 .73951 .65323 .74129 .65284 .74029 .64871 Mtetra
.635 .497 .677 r
.74029 .64871 .74129 .65284 .74304 .65201 .74204 .64783 Mtetra
.554 .444 .684 r
.74204 .64783 .74304 .65201 .74481 .65143 .74386 .64812 Mtetra
.492 .432 .717 r
.74386 .64812 .74481 .65143 .74659 .651 .74572 .6489 Mtetra
.479 .497 .798 r
.74572 .6489 .74659 .651 .74837 .65049 .74756 .64943 Mtetra
.454 .637 .935 r
.74756 .64943 .74837 .65049 .75015 .65003 .74938 .64963 Mtetra
.442 .813 .994 r
.74938 .64963 .75015 .65003 .75191 .64936 .75118 .64941 Mtetra
.507 .912 .866 r
.75118 .64941 .75191 .64936 .75364 .64807 .75294 .64862 Mtetra
.834 .96 .626 r
.75294 .64862 .75364 .64807 .75518 .64392 .75459 .64612 Mtetra
.806 .762 .248 r
.75459 .64612 .75518 .64392 .74381 .44704 .75597 .63961 Mtetra
.078 0 .454 r
.75597 .63961 .74381 .44704 .74501 .43945 .74455 .4429 Mtetra
0 0 .211 r
.74455 .4429 .74501 .43945 .74657 .43739 .74597 .43855 Mtetra
0 0 0 r
.74597 .43855 .74657 .43739 .74824 .43681 .74756 .43679 Mtetra
.706 .982 .895 r
.74756 .43679 .74824 .43681 .74994 .43666 .74919 .43572 Mtetra
.695 .756 .898 r
.74919 .43572 .74994 .43666 .75164 .4364 .75086 .43505 Mtetra
.639 .658 .852 r
.75086 .43505 .75164 .4364 .75332 .43593 .75255 .43463 Mtetra
.614 .655 .867 r
.75255 .43463 .75332 .43593 .755 .43544 .75424 .43435 Mtetra
.635 .703 .895 r
.75424 .43435 .755 .43544 .75667 .43483 .75593 .43395 Mtetra
.666 .762 .922 r
.75593 .43395 .75667 .43483 .75834 .43417 .75761 .43341 Mtetra
.675 .797 .94 r
.75761 .43341 .75834 .43417 .76002 .43358 .75929 .43283 Mtetra
.741 .819 .912 r
.75929 .43283 .76002 .43358 .76169 .43298 .76094 .43196 Mtetra
.735 .753 .866 r
.76094 .43196 .76169 .43298 .76338 .43258 .7626 .43104 Mtetra
.648 .637 .826 r
.7626 .43104 .76338 .43258 .76512 .43274 .76428 .43057 Mtetra
.382 .421 .777 r
.76428 .43057 .76512 .43274 .76704 .43538 .76609 .43162 Mtetra
0 0 .547 r
.76609 .43162 .76704 .43538 .78344 .63144 .76819 .43668 Mtetra
.1 .022 .471 r
.76819 .43668 .78344 .63144 .78581 .63858 .78467 .63286 Mtetra
.307 .252 .631 r
.78467 .63286 .78581 .63858 .78776 .64005 .78679 .63658 Mtetra
.499 .431 .711 r
.78679 .63658 .78776 .64005 .78958 .63979 .78869 .63736 Mtetra
.56 .519 .766 r
.78869 .63736 .78958 .63979 .79136 .63899 .79053 .63746 Mtetra
.549 .602 .858 r
.79053 .63746 .79136 .63899 .79315 .63825 .79238 .63748 Mtetra
.497 .735 .979 r
.79238 .63748 .79315 .63825 .79494 .63761 .79422 .63741 Mtetra
.558 .912 .964 r
.79422 .63741 .79494 .63761 .79669 .63638 .79602 .63677 Mtetra
.804 .974 .679 r
.79602 .63677 .79669 .63638 .79826 .63284 .7977 .63464 Mtetra
.808 .777 .272 r
.7977 .63464 .79826 .63284 .78449 .43687 .79908 .62884 Mtetra
.093 .013 .464 r
.79908 .62884 .78449 .43687 .78547 .42724 .78513 .43129 Mtetra
0 0 .257 r
.78513 .43129 .78547 .42724 .78701 .42478 .78646 .42617 Mtetra
0 0 0 r
.78646 .42617 .78701 .42478 .78869 .42409 .78806 .4244 Mtetra
.477 .87 .685 r
.78806 .4244 .78869 .42409 .79041 .42387 .78971 .42332 Mtetra
.709 .867 .957 r
.78971 .42332 .79041 .42387 .79213 .42355 .7914 .42256 Mtetra
.676 .743 .901 r
.7914 .42256 .79213 .42355 .79382 .42292 .79309 .42197 Mtetra
.652 .745 .918 r
.79309 .42197 .79382 .42292 .79552 .42234 .7948 .42149 Mtetra
.718 .791 .909 r
.7948 .42149 .79552 .42234 .79722 .42177 .79648 .42071 Mtetra
.748 .754 .858 r
.79648 .42071 .79722 .42177 .79893 .4213 .79814 .41971 Mtetra
.649 .631 .819 r
.79814 .41971 .79893 .4213 .80068 .42134 .79985 .4192 Mtetra
.332 .393 .776 r
.79985 .4192 .80068 .42134 .8026 .42327 .80171 .42049 Mtetra
.858 .534 .012 r
.80171 .42049 .8026 .42327 .82097 .61631 .80444 .43184 Mtetra
.091 .018 .472 r
.80444 .43184 .82097 .61631 .82379 .62735 .82302 .62638 Mtetra
0 0 .478 r
.82302 .62638 .82379 .62735 .82585 .62955 .8251 .62888 Mtetra
.446 .741 .991 r
.8251 .62888 .82585 .62955 .82773 .62971 .82697 .62885 Mtetra
.744 .809 .904 r
.82697 .62885 .82773 .62971 .82953 .6289 .82876 .62788 Mtetra
.871 .797 .775 r
.82876 .62788 .82953 .6289 .83117 .62627 .83043 .62559 Mtetra
.973 .8 .609 r
.83043 .62559 .83117 .62627 .83211 .61584 .83182 .62015 Mtetra
.98 .685 .361 r
.83182 .62015 .83211 .61584 .81626 .41866 .81599 .42276 Mtetra
0 0 .24 r
.81599 .42276 .81626 .41866 .81772 .41534 .81723 .41695 Mtetra
.039 0 .073 r
.81723 .41695 .81772 .41534 .81942 .41461 .81883 .41512 Mtetra
0 0 0 r
.81883 .41512 .81942 .41461 .82117 .41447 .8205 .41403 Mtetra
.673 .895 .977 r
.8205 .41403 .82117 .41447 .82293 .41443 .8222 .41334 Mtetra
.65 .714 .895 r
.8222 .41334 .82293 .41443 .82467 .41404 .82393 .41287 Mtetra
.62 .683 .888 r
.82393 .41287 .82467 .41404 .8264 .41364 .82567 .41253 Mtetra
.62 .698 .9 r
.82567 .41253 .8264 .41364 .82813 .41319 .82741 .4122 Mtetra
.65 .735 .911 r
.82741 .4122 .82813 .41319 .82985 .41266 .82914 .41172 Mtetra
.659 .751 .918 r
.82914 .41172 .82985 .41266 .83157 .4121 .83086 .4112 Mtetra
.669 .765 .922 r
.83086 .4112 .83157 .4121 .83329 .41152 .83258 .41063 Mtetra
.68 .772 .92 r
.83258 .41063 .83329 .41152 .83501 .41095 .8343 .41002 Mtetra
.688 .765 .91 r
.8343 .41002 .83501 .41095 .83673 .41037 .83602 .40937 Mtetra
.73 .765 .88 r
.83602 .40937 .83673 .41037 .83844 .40961 .83771 .40849 Mtetra
.765 .753 .842 r
.83771 .40849 .83844 .40961 .84012 .4086 .83938 .40733 Mtetra
.68 .694 .857 r
.83938 .40733 .84012 .4086 .84185 .40803 .8411 .40668 Mtetra
.306 .479 .867 r
.8411 .40668 .84185 .40803 .8437 .40874 .84297 .40753 Mtetra
.907 .535 .09 r
.84297 .40753 .8437 .40874 .84607 .41464 .84564 .41648 Mtetra
.974 .667 .354 r
.84564 .41648 .84607 .41464 .8676 .61251 .86708 .61383 Mtetra
.778 .366 .269 r
.86708 .61383 .8676 .61251 .86986 .61612 .86927 .6167 Mtetra
.274 0 0 r
.86927 .6167 .86986 .61612 .8718 .61641 .87116 .61655 Mtetra
.45 .877 .781 r
.87116 .61655 .8718 .61641 .87367 .61607 .87298 .61566 Mtetra
.788 .937 .927 r
.87298 .61566 .87367 .61607 .87553 .61562 .87477 .61444 Mtetra
.737 .746 .859 r
.87477 .61444 .87553 .61562 .87744 .61556 .87657 .61342 Mtetra
.743 .64 .746 r
.87657 .61342 .87744 .61556 .87929 .61501 .87832 .61182 Mtetra
.789 .613 .663 r
.87832 .61182 .87929 .61501 .88102 .61327 .87988 .60838 Mtetra
.975 .674 .368 r
.87988 .60838 .88102 .61327 .88231 .6072 .8613 .41142 Mtetra
.58 .368 .558 r
.8613 .41142 .88231 .6072 .86328 .40733 .86217 .40251 Mtetra
.713 .53 .64 r
.86217 .40251 .86328 .40733 .86453 .4021 .86368 .39968 Mtetra
.655 .567 .743 r
.86368 .39968 .86453 .4021 .86619 .40073 .8654 .39894 Mtetra
.606 .591 .81 r
.8654 .39894 .86619 .40073 .86791 .40001 .86718 .3987 Mtetra
.579 .642 .877 r
.86718 .3987 .86791 .40001 .86967 .39955 .86897 .39856 Mtetra
.68 .752 .905 r
.86897 .39856 .86967 .39955 .87141 .39897 .87071 .39794 Mtetra
.665 .736 .903 r
.87071 .39794 .87141 .39897 .87316 .39846 .87245 .39739 Mtetra
.63 .713 .906 r
.87245 .39739 .87316 .39846 .8749 .39786 .87422 .397 Mtetra
.545 .723 .957 r
.87422 .397 .8749 .39786 .8766 .39689 .87601 .39686 Mtetra
.224 0 0 r
.87601 .39686 .8766 .39689 .87835 .39629 .87787 .39726 Mtetra
.738 .291 .192 r
.87787 .39726 .87835 .39629 .8802 .39665 .8799 .39924 Mtetra
.973 .662 .338 r
.8799 .39924 .8802 .39665 .88251 .4011 .90341 .59511 Mtetra
.577 .362 .552 r
.90341 .59511 .88251 .4011 .90653 .60029 .90628 .60356 Mtetra
.682 .344 .397 r
.90628 .60356 .90653 .60029 .90901 .60514 .90847 .60581 Mtetra
.348 0 0 r
.90847 .60581 .90901 .60514 .91101 .60567 .9104 .60578 Mtetra
.321 .804 .761 r
.9104 .60578 .91101 .60567 .91292 .60547 .91227 .60512 Mtetra
.738 .95 .947 r
.91227 .60512 .91292 .60547 .91481 .60498 .91409 .60406 Mtetra
.754 .807 .895 r
.91409 .60406 .91481 .60498 .91674 .60489 .91591 .603 Mtetra
.761 .669 .761 r
.91591 .603 .91674 .60489 .91862 .60433 .91766 .60136 Mtetra
.787 .62 .674 r
.91766 .60136 .91862 .60433 .92039 .60281 .91925 .59824 Mtetra
.975 .67 .347 r
.91925 .59824 .92039 .60281 .92167 .59709 .89857 .40295 Mtetra
.584 .371 .558 r
.89857 .40295 .92167 .59709 .90022 .39648 .89906 .39136 Mtetra
.721 .531 .632 r
.89906 .39136 .90022 .39648 .90137 .39068 .90051 .38812 Mtetra
.669 .568 .732 r
.90051 .38812 .90137 .39068 .90308 .38965 .90223 .3872 Mtetra
.62 .546 .749 r
.90223 .3872 .90308 .38965 .90488 .38932 .90401 .38679 Mtetra
.59 .524 .749 r
.90401 .38679 .90488 .38932 .9067 .38922 .90583 .38665 Mtetra
.615 .536 .743 r
.90583 .38665 .9067 .38922 .90843 .38832 .90762 .38628 Mtetra
.62 .576 .783 r
.90762 .38628 .90843 .38832 .91015 .38741 .90941 .38592 Mtetra
.633 .642 .842 r
.90941 .38592 .91015 .38741 .91189 .38658 .9112 .38551 Mtetra
.672 .733 .896 r
.9112 .38551 .91189 .38658 .91366 .38602 .91297 .38492 Mtetra
.682 .732 .888 r
.91297 .38492 .91366 .38602 .91544 .38552 .91473 .38427 Mtetra
.682 .705 .865 r
.91473 .38427 .91544 .38552 .91722 .38503 .91649 .38361 Mtetra
.67 .671 .843 r
.91649 .38361 .91722 .38503 .91899 .38443 .91826 .38299 Mtetra
.668 .666 .839 r
.91826 .38299 .91899 .38443 .92076 .38382 .92003 .38237 Mtetra
.669 .667 .839 r
.92003 .38237 .92076 .38382 .92253 .38319 .9218 .38175 Mtetra
.731 .696 .818 r
.9218 .38175 .92253 .38319 .92424 .3821 .92351 .38069 Mtetra
.68 .678 .842 r
.92351 .38069 .92424 .3821 .926 .3814 .92528 .38001 Mtetra
.543 .612 .872 r
.92528 .38001 .926 .3814 .92785 .38145 .92713 .38004 Mtetra
0 0 .381 r
.92713 .38004 .92785 .38145 .9303 .38611 .92953 .38436 Mtetra
.97 .655 .288 r
.92953 .38436 .9303 .38611 .95768 .58725 .95692 .58584 Mtetra
.673 .284 0 r
.95692 .58584 .95768 .58725 .96028 .59216 .95957 .59115 Mtetra
0 .418 .852 r
.34337 .75896 .34432 .75978 .3458 .76046 .34485 .75967 Mtetra
.634 .757 .937 r
.34485 .75967 .3458 .76046 .34734 .76007 .34638 .75929 Mtetra
.809 .779 .825 r
.34638 .75929 .34734 .76007 .34893 .75863 .34797 .75786 Mtetra
.908 .738 .659 r
.34797 .75786 .34893 .75863 .3507 .75337 .34975 .75261 Mtetra
.937 .686 .534 r
.34975 .75261 .3507 .75337 .36147 .56187 .36057 .56105 Mtetra
.91 .728 .644 r
.36057 .56105 .36147 .56187 .36318 .55613 .36228 .5553 Mtetra
.778 .761 .837 r
.36228 .5553 .36318 .55613 .36467 .55502 .36377 .55418 Mtetra
.642 .736 .918 r
.36377 .55418 .36467 .55502 .36612 .55465 .36523 .55381 Mtetra
.51 .691 .95 r
.36523 .55381 .36612 .55465 .36756 .55464 .36667 .5538 Mtetra
.746 .757 .861 r
.36667 .5538 .36756 .55464 .36904 .55376 .36815 .55292 Mtetra
.695 .748 .892 r
.36815 .55292 .36904 .55376 .37051 .55317 .36962 .55233 Mtetra
.48 .677 .952 r
.36962 .55233 .37051 .55317 .37195 .55323 .37105 .55238 Mtetra
.928 .548 .252 r
.37105 .55238 .37195 .55323 .37321 .55725 .37232 .55639 Mtetra
.939 .683 .522 r
.37232 .55639 .37321 .55725 .36617 .74815 .36522 .74735 Mtetra
.935 .579 .319 r
.36522 .74735 .36617 .74815 .36747 .75328 .36652 .75249 Mtetra
0 .342 .791 r
.36652 .75249 .36747 .75328 .36896 .75411 .36802 .75332 Mtetra
.618 .754 .943 r
.36802 .75332 .36896 .75411 .37051 .75378 .36956 .75299 Mtetra
.8 .78 .834 r
.36956 .75299 .37051 .75378 .3721 .75244 .37116 .75165 Mtetra
.906 .743 .67 r
.37116 .75165 .3721 .75244 .37384 .74774 .37289 .74693 Mtetra
.939 .687 .529 r
.37289 .74693 .37384 .74774 .38339 .55617 .3825 .55529 Mtetra
.914 .723 .631 r
.3825 .55529 .38339 .55617 .38512 .54961 .38423 .54874 Mtetra
.799 .758 .816 r
.38423 .54874 .38512 .54961 .38662 .54826 .38574 .5474 Mtetra
.649 .733 .911 r
.38574 .5474 .38662 .54826 .38809 .54787 .38721 .547 Mtetra
.514 .684 .944 r
.38721 .547 .38809 .54787 .38955 .54788 .38866 .54699 Mtetra
.731 .747 .864 r
.38866 .54699 .38955 .54788 .39103 .54709 .39015 .54619 Mtetra
.699 .737 .88 r
.39015 .54619 .39103 .54709 .39251 .54649 .39163 .54556 Mtetra
.507 .669 .936 r
.39163 .54556 .39251 .54649 .39396 .54653 .39308 .54559 Mtetra
.925 .536 .209 r
.39308 .54559 .39396 .54653 .39527 .5505 .39439 .54949 Mtetra
.942 .684 .516 r
.39439 .54949 .39527 .5505 .38945 .74211 .38851 .74125 Mtetra
.936 .575 .3 r
.38851 .74125 .38945 .74211 .3908 .74716 .38986 .74638 Mtetra
.08 .495 .898 r
.38986 .74638 .3908 .74716 .39233 .74774 .39139 .74696 Mtetra
.657 .769 .932 r
.39139 .74696 .39233 .74774 .39389 .74728 .39295 .74649 Mtetra
.744 .781 .883 r
.39295 .74649 .39389 .74728 .39548 .74641 .39454 .74561 Mtetra
.633 .756 .937 r
.39454 .74561 .39548 .74641 .39704 .74615 .3961 .74522 Mtetra
.635 .729 .916 r
.3961 .74522 .39704 .74615 .3986 .74582 .39767 .74485 Mtetra
.701 .736 .879 r
.39767 .74485 .3986 .74582 .40018 .74499 .39925 .74417 Mtetra
.839 .773 .788 r
.39925 .74417 .40018 .74499 .40185 .74185 .40087 .74228 Mtetra
.963 .911 .716 r
.40087 .74228 .40185 .74185 .40376 .73135 .40253 .73908 Mtetra
.134 0 .343 r
.40253 .73908 .40376 .73135 .4116 .54439 .40428 .73339 Mtetra
.561 .35 .551 r
.40428 .73339 .4116 .54439 .41314 .54242 .40593 .73066 Mtetra
.566 .354 .552 r
.40593 .73066 .41314 .54242 .41462 .54202 .40746 .73133 Mtetra
.564 .353 .552 r
.40746 .73133 .41462 .54202 .41609 .54196 .40904 .73067 Mtetra
0 0 .34 r
.40904 .73067 .41609 .54196 .41761 .5407 .41653 .54602 Mtetra
0 0 .118 r
.41653 .54602 .41761 .5407 .41913 .53917 .4182 .53994 Mtetra
.948 .957 .682 r
.4182 .53994 .41913 .53917 .42064 .53789 .41977 .53707 Mtetra
.768 .769 .853 r
.41977 .53707 .42064 .53789 .42214 .53722 .42127 .53604 Mtetra
.632 .666 .865 r
.42127 .53604 .42214 .53722 .42363 .53685 .42276 .53571 Mtetra
.573 .651 .888 r
.42276 .53571 .42363 .53685 .42511 .53655 .42424 .53561 Mtetra
.656 .719 .895 r
.42424 .53561 .42511 .53655 .42661 .53606 .42573 .53517 Mtetra
.697 .743 .887 r
.42573 .53517 .42661 .53606 .4281 .53547 .42723 .53455 Mtetra
.698 .738 .882 r
.42723 .53455 .4281 .53547 .4296 .53487 .42873 .53393 Mtetra
.708 .735 .872 r
.42873 .53393 .4296 .53487 .4311 .53409 .43023 .53325 Mtetra
.689 .751 .899 r
.43023 .53325 .4311 .53409 .4326 .53345 .43173 .53267 Mtetra
.613 .747 .941 r
.43173 .53267 .4326 .53345 .43409 .53325 .43322 .53237 Mtetra
.082 .452 .883 r
.43322 .53237 .43409 .53325 .43553 .53492 .43469 .53306 Mtetra
0 .126 .67 r
.43469 .53306 .43553 .53492 .43683 .54203 .43612 .53493 Mtetra
.292 .205 .583 r
.43612 .53493 .43683 .54203 .43346 .73079 .43751 .53889 Mtetra
.561 .354 .557 r
.43751 .53889 .43346 .73079 .43499 .73257 .43893 .54154 Mtetra
.568 .36 .558 r
.43893 .54154 .43499 .73257 .43658 .73218 .44046 .54027 Mtetra
.566 .358 .557 r
.44046 .54027 .43658 .73218 .43818 .73138 .44195 .54007 Mtetra
0 0 .369 r
.44195 .54007 .43818 .73138 .43975 .73166 .43901 .72334 Mtetra
.147 .093 .534 r
.43901 .72334 .43975 .73166 .44132 .73241 .44044 .72952 Mtetra
.058 .157 .653 r
.44044 .72952 .44132 .73241 .44289 .73294 .44197 .73195 Mtetra
.203 .512 .913 r
.44197 .73195 .44289 .73294 .44447 .73297 .44354 .73256 Mtetra
.481 .814 1 r
.44354 .73256 .44447 .73297 .44606 .73268 .44513 .73235 Mtetra
.605 .877 .992 r
.44513 .73235 .44606 .73268 .44766 .73227 .44673 .73186 Mtetra
.612 .859 .99 r
.44673 .73186 .44766 .73227 .44925 .73185 .44833 .7314 Mtetra
.608 .846 .989 r
.44833 .7314 .44925 .73185 .45085 .73143 .44993 .73096 Mtetra
.631 .849 .983 r
.44993 .73096 .45085 .73143 .45245 .73097 .45153 .73048 Mtetra
.662 .849 .972 r
.45153 .73048 .45245 .73097 .45405 .73047 .45313 .72992 Mtetra
.682 .838 .958 r
.45313 .72992 .45405 .73047 .45566 .72993 .45473 .72931 Mtetra
.686 .819 .946 r
.45473 .72931 .45566 .72993 .45726 .72939 .45634 .7287 Mtetra
.624 .786 .959 r
.45634 .7287 .45726 .72939 .45886 .72913 .45794 .7283 Mtetra
.613 .749 .942 r
.45794 .7283 .45886 .72913 .46046 .72889 .45955 .72798 Mtetra
.678 .748 .904 r
.45955 .72798 .46046 .72889 .46207 .72823 .46115 .72742 Mtetra
.817 .785 .823 r
.46115 .72742 .46207 .72823 .46371 .72583 .46278 .72589 Mtetra
.945 .894 .746 r
.46278 .72589 .46371 .72583 .46542 .71893 .46443 .72306 Mtetra
0 0 .115 r
.46443 .72306 .46542 .71893 .47014 .52762 .4661 .71841 Mtetra
.556 .346 .551 r
.4661 .71841 .47014 .52762 .47171 .52425 .46779 .71284 Mtetra
.563 .352 .552 r
.46779 .71284 .47171 .52425 .47323 .52354 .46941 .7115 Mtetra
.567 .355 .552 r
.46941 .7115 .47323 .52354 .47474 .52349 .47099 .71289 Mtetra
.566 .354 .552 r
.47099 .71289 .47474 .52349 .47626 .52334 .47258 .71343 Mtetra
.565 .353 .552 r
.47258 .71343 .47626 .52334 .47778 .52289 .47418 .7131 Mtetra
.47418 .7131 .47778 .52289 .4793 .52245 .47579 .71277 Mtetra
.47579 .71277 .4793 .52245 .48083 .522 .4774 .7124 Mtetra
.564 .353 .552 r
.4774 .7124 .48083 .522 .48235 .52153 .47901 .71197 Mtetra
.47901 .71197 .48235 .52153 .48387 .52106 .48062 .71153 Mtetra
.48062 .71153 .48387 .52106 .4854 .52058 .48224 .71106 Mtetra
.48224 .71106 .4854 .52058 .48693 .5201 .48385 .71058 Mtetra
.48385 .71058 .48693 .5201 .48845 .51961 .48547 .71008 Mtetra
.48547 .71008 .48845 .51961 .48998 .51912 .48708 .70955 Mtetra
.48708 .70955 .48998 .51912 .49151 .51862 .4887 .70901 Mtetra
.4887 .70901 .49151 .51862 .49304 .51813 .49032 .70845 Mtetra
.49032 .70845 .49304 .51813 .49457 .51763 .49194 .70785 Mtetra
.49194 .70785 .49457 .51763 .49611 .51712 .49356 .70722 Mtetra
.49356 .70722 .49611 .51712 .49764 .51662 .49518 .70659 Mtetra
.49518 .70659 .49764 .51662 .49917 .51611 .49681 .70597 Mtetra
.49681 .70597 .49917 .51611 .50071 .51562 .49843 .7054 Mtetra
.49843 .7054 .50071 .51562 .50224 .51513 .50005 .70486 Mtetra
.50005 .70486 .50224 .51513 .50378 .51465 .50168 .70436 Mtetra
.50168 .70436 .50378 .51465 .50531 .51417 .5033 .7039 Mtetra
.565 .353 .552 r
.5033 .7039 .50531 .51417 .50685 .5137 .50493 .70348 Mtetra
.50493 .70348 .50685 .5137 .50839 .51324 .50655 .70315 Mtetra
.50655 .70315 .50839 .51324 .50993 .51279 .50818 .70288 Mtetra
.50818 .70288 .50993 .51279 .51147 .51235 .50981 .70262 Mtetra
.566 .354 .552 r
.50981 .70262 .51147 .51235 .51301 .51201 .51143 .70324 Mtetra
.567 .355 .552 r
.51143 .70324 .51301 .51201 .51455 .51175 .51306 .70413 Mtetra
.564 .352 .552 r
.51306 .70413 .51455 .51175 .51609 .51127 .51469 .7033 Mtetra
.029 0 .408 r
.51469 .7033 .51609 .51127 .51764 .51015 .51676 .52617 Mtetra
0 0 .343 r
.51676 .52617 .51764 .51015 .51919 .50852 .51834 .51037 Mtetra
.73 .81 .34 r
.51834 .51037 .51919 .50852 .52073 .50708 .51989 .50664 Mtetra
.877 .853 .816 r
.51989 .50664 .52073 .50708 .52228 .50608 .52144 .50482 Mtetra
.685 .679 .838 r
.52144 .50482 .52228 .50608 .52382 .50556 .52299 .50419 Mtetra
.626 .639 .843 r
.52299 .50419 .52382 .50556 .52537 .50518 .52453 .50387 Mtetra
.619 .645 .854 r
.52453 .50387 .52537 .50518 .52692 .50482 .52608 .50359 Mtetra
.653 .672 .856 r
.52608 .50359 .52692 .50482 .52847 .50437 .52763 .50314 Mtetra
.652 .672 .856 r
.52763 .50314 .52847 .50437 .53002 .50392 .52918 .5027 Mtetra
.653 .673 .856 r
.52918 .5027 .53002 .50392 .53157 .50347 .53073 .50225 Mtetra
.655 .674 .856 r
.53073 .50225 .53157 .50347 .53312 .50301 .53228 .50179 Mtetra
.651 .673 .858 r
.53228 .50179 .53312 .50301 .53467 .50256 .53383 .50135 Mtetra
.64 .671 .864 r
.53383 .50135 .53467 .50256 .53622 .50214 .53539 .50097 Mtetra
.622 .671 .876 r
.53539 .50097 .53622 .50214 .53778 .50177 .53694 .50067 Mtetra
.62 .684 .888 r
.53694 .50067 .53778 .50177 .53933 .50138 .5385 .50037 Mtetra
.634 .706 .898 r
.5385 .50037 .53933 .50138 .54089 .50095 .54006 .50001 Mtetra
.662 .732 .902 r
.54006 .50001 .54089 .50095 .54245 .50042 .54161 .49953 Mtetra
.677 .747 .904 r
.54161 .49953 .54245 .50042 .544 .49985 .54317 .49899 Mtetra
.727 .765 .883 r
.54317 .49899 .544 .49985 .54556 .49907 .54473 .4982 Mtetra
.772 .772 .852 r
.54473 .4982 .54556 .49907 .54711 .49802 .54628 .49711 Mtetra
.691 .746 .894 r
.54628 .49711 .54711 .49802 .54867 .49744 .54784 .49651 Mtetra
.091 .44 .877 r
.54784 .49651 .54867 .49744 .55024 .49822 .54941 .49729 Mtetra
.952 .606 .305 r
.54941 .49729 .55024 .49822 .55187 .50532 .55104 .50492 Mtetra
.959 .684 .473 r
.55104 .50492 .55187 .50532 .5551 .69901 .55422 .69856 Mtetra
.863 .414 .093 r
.55422 .69856 .5551 .69901 .55679 .70222 .55592 .70164 Mtetra
.351 .708 .985 r
.55592 .70164 .55679 .70222 .55846 .70244 .55758 .70173 Mtetra
.705 .811 .93 r
.55758 .70173 .55846 .70244 .56012 .70172 .55925 .70103 Mtetra
.823 .824 .849 r
.55925 .70103 .56012 .70172 .56177 .69979 .5609 .69957 Mtetra
.926 .883 .772 r
.5609 .69957 .56177 .69979 .56338 .6947 .56254 .69705 Mtetra
0 0 0 r
.56254 .69705 .56338 .6947 .56285 .50152 .56417 .69306 Mtetra
.554 .345 .551 r
.56417 .69306 .56285 .50152 .56435 .49552 .56576 .68641 Mtetra
.561 .35 .551 r
.56576 .68641 .56435 .49552 .56592 .49453 .5674 .68359 Mtetra
.567 .355 .552 r
.5674 .68359 .56592 .49453 .56749 .49431 .56908 .68462 Mtetra
.56908 .68462 .56749 .49431 .56907 .49436 .57077 .68605 Mtetra
.565 .353 .552 r
.57077 .68605 .56907 .49436 .57065 .49392 .57244 .68576 Mtetra
.57244 .68576 .57065 .49392 .57222 .4935 .57411 .68548 Mtetra
.57411 .68548 .57222 .4935 .5738 .49307 .57578 .68519 Mtetra
.57578 .68519 .5738 .49307 .57538 .49261 .57745 .68483 Mtetra
.57745 .68483 .57538 .49261 .57695 .49215 .57912 .68444 Mtetra
.57912 .68444 .57695 .49215 .57853 .49168 .58079 .68404 Mtetra
.58079 .68404 .57853 .49168 .58011 .49121 .58247 .68361 Mtetra
.564 .353 .552 r
.58247 .68361 .58011 .49121 .58169 .49072 .58414 .68316 Mtetra
.58414 .68316 .58169 .49072 .58327 .49023 .58582 .68268 Mtetra
.58582 .68268 .58327 .49023 .58485 .48971 .58749 .68215 Mtetra
.58749 .68215 .58485 .48971 .58644 .4892 .58917 .68161 Mtetra
.564 .352 .552 r
.58917 .68161 .58644 .4892 .58802 .48859 .59084 .68084 Mtetra
.562 .351 .552 r
.59084 .68084 .58802 .48859 .58959 .48754 .59248 .67855 Mtetra
.564 .353 .552 r
.59248 .67855 .58959 .48754 .59118 .48704 .59416 .67797 Mtetra
.57 .357 .552 r
.59416 .67797 .59118 .48704 .59279 .48792 .59591 .6809 Mtetra
.572 .359 .553 r
.59591 .6809 .59279 .48792 .59833 .67578 .59769 .68551 Mtetra
.624 .367 .509 r
.59769 .68551 .59833 .67578 .60027 .68717 .59944 .68786 Mtetra
.674 .211 .144 r
.59944 .68786 .60027 .68717 .60202 .68977 .60116 .68904 Mtetra
.477 .729 .981 r
.60116 .68904 .60202 .68977 .60372 .68983 .60286 .689 Mtetra
.615 .758 .947 r
.60286 .689 .60372 .68983 .60541 .68936 .60456 .68864 Mtetra
.656 .8 .951 r
.60456 .68864 .60541 .68936 .6071 .68864 .60625 .68812 Mtetra
.561 .823 .995 r
.60625 .68812 .6071 .68864 .60879 .6882 .60794 .68779 Mtetra
.646 .88 .984 r
.60794 .68779 .60879 .6882 .61048 .68762 .60964 .68719 Mtetra
.782 .896 .924 r
.60964 .68719 .61048 .68762 .61217 .68685 .61132 .6861 Mtetra
.892 .805 .756 r
.61132 .6861 .61217 .68685 .61385 .68588 .61296 .68352 Mtetra
.853 .666 .649 r
.61296 .68352 .61385 .68588 .61552 .68439 .61454 .67865 Mtetra
.958 .684 .473 r
.61454 .67865 .61552 .68439 .61716 .68171 .61126 .48742 Mtetra
.578 .367 .558 r
.61126 .48742 .61716 .68171 .61396 .49868 .61268 .48021 Mtetra
.614 .412 .584 r
.61268 .48021 .61396 .49868 .61507 .48002 .61422 .47731 Mtetra
.723 .584 .7 r
.61422 .47731 .61507 .48002 .61659 .47665 .61578 .47559 Mtetra
.687 .721 .875 r
.61578 .47559 .61659 .47665 .61818 .47581 .61738 .47498 Mtetra
.608 .742 .94 r
.61738 .47498 .61818 .47581 .61979 .4755 .61899 .47467 Mtetra
.571 .731 .95 r
.61899 .47467 .61979 .4755 .6214 .47542 .6206 .47447 Mtetra
.74 .759 .868 r
.6206 .47447 .6214 .47542 .623 .47472 .62219 .47358 Mtetra
.701 .709 .854 r
.62219 .47358 .623 .47472 .6246 .4741 .62379 .47286 Mtetra
.623 .664 .869 r
.62379 .47286 .6246 .4741 .6262 .47365 .6254 .47255 Mtetra
0 .287 .786 r
.6254 .47255 .6262 .47365 .62782 .47352 .62706 .47381 Mtetra
.858 .443 .241 r
.62706 .47381 .62782 .47352 .62945 .47388 .62878 .47709 Mtetra
.961 .678 .453 r
.62878 .47709 .62945 .47388 .63112 .47522 .63648 .66699 Mtetra
.576 .362 .553 r
.63648 .66699 .63112 .47522 .63331 .49253 .63844 .67428 Mtetra
.569 .356 .552 r
.63844 .67428 .63331 .49253 .64101 .67529 .64024 .67658 Mtetra
.636 .224 .244 r
.64024 .67658 .64101 .67529 .64284 .67823 .642 .67754 Mtetra
.46 .735 .987 r
.642 .67754 .64284 .67823 .64457 .67834 .64373 .67751 Mtetra
.677 .782 .929 r
.64373 .67751 .64457 .67834 .64628 .67773 .64544 .67691 Mtetra
.784 .805 .87 r
.64544 .67691 .64628 .67773 .64798 .67665 .64713 .67572 Mtetra
.874 .785 .758 r
.64713 .67572 .64798 .67665 .64968 .67579 .64878 .67326 Mtetra
.843 .658 .651 r
.64878 .67326 .64968 .67579 .65137 .67447 .65035 .66863 Mtetra
.961 .683 .462 r
.65035 .66863 .65137 .67447 .65302 .67219 .64514 .4781 Mtetra
.579 .368 .558 r
.64514 .4781 .65302 .67219 .65432 .66035 .64649 .47009 Mtetra
.571 .362 .558 r
.64649 .47009 .65432 .66035 .64889 .4702 .64801 .46705 Mtetra
.713 .564 .684 r
.64801 .46705 .64889 .4702 .65038 .46643 .64958 .46524 Mtetra
.69 .699 .853 r
.64958 .46524 .65038 .46643 .65198 .46545 .65119 .46457 Mtetra
.601 .73 .935 r
.65119 .46457 .65198 .46545 .65361 .46514 .65282 .46429 Mtetra
.544 .715 .952 r
.65282 .46429 .65361 .46514 .65525 .46513 .65446 .46418 Mtetra
.721 .754 .878 r
.65446 .46418 .65525 .46513 .65687 .46455 .65607 .46338 Mtetra
.698 .707 .854 r
.65607 .46338 .65687 .46455 .65849 .46396 .65769 .46267 Mtetra
.625 .658 .862 r
.65769 .46267 .65849 .46396 .66011 .46353 .65932 .46235 Mtetra
0 .061 .613 r
.65932 .46235 .66011 .46353 .66178 .46398 .66104 .46428 Mtetra
.908 .535 .308 r
.66104 .46428 .66178 .46398 .66346 .46483 .66293 .47 Mtetra
.961 .675 .445 r
.66293 .47 .66346 .46483 .66515 .46566 .67263 .65951 Mtetra
.082 0 .446 r
.67263 .65951 .66515 .46566 .66674 .46422 .66639 .4736 Mtetra
0 0 .34 r
.66639 .4736 .66674 .46422 .6683 .46233 .6676 .46332 Mtetra
.899 .911 .509 r
.6676 .46332 .6683 .46233 .66989 .46072 .6691 .4597 Mtetra
.753 .751 .85 r
.6691 .4597 .66989 .46072 .67151 .46001 .67071 .45867 Mtetra
.629 .652 .854 r
.67071 .45867 .67151 .46001 .67314 .45961 .67235 .45832 Mtetra
.573 .636 .875 r
.67235 .45832 .67314 .45961 .67478 .4593 .674 .45823 Mtetra
.639 .704 .893 r
.674 .45823 .67478 .4593 .67642 .45881 .67564 .45783 Mtetra
.666 .733 .9 r
.67564 .45783 .67642 .45881 .67805 .45824 .67727 .4573 Mtetra
.68 .748 .903 r
.67727 .4573 .67805 .45824 .67968 .45763 .6789 .45672 Mtetra
.741 .771 .878 r
.6789 .45672 .67968 .45763 .68129 .45665 .68052 .45582 Mtetra
.73 .789 .899 r
.68052 .45582 .68129 .45665 .68292 .45583 .68214 .45501 Mtetra
.66 .768 .929 r
.68214 .45501 .68292 .45583 .68456 .45553 .68378 .45451 Mtetra
.325 .561 .922 r
.68378 .45451 .68456 .45553 .68632 .45739 .68547 .455 Mtetra
.263 .326 .741 r
.68547 .455 .68632 .45739 .68842 .46614 .68722 .45664 Mtetra
.376 .26 .592 r
.68722 .45664 .68842 .46614 .69974 .65818 .68912 .46128 Mtetra
.081 .001 .455 r
.68912 .46128 .69974 .65818 .70162 .6604 .70047 .65299 Mtetra
.289 .216 .599 r
.70047 .65299 .70162 .6604 .70342 .66095 .70249 .65782 Mtetra
.316 .326 .711 r
.70249 .65782 .70342 .66095 .7052 .66094 .70436 .6597 Mtetra
.373 .555 .903 r
.70436 .6597 .7052 .66094 .70698 .66105 .70617 .66022 Mtetra
.556 .742 .963 r
.70617 .66022 .70698 .66105 .70875 .66085 .70794 .66002 Mtetra
.707 .796 .92 r
.70794 .66002 .70875 .66085 .71049 .66004 .70968 .65928 Mtetra
.835 .828 .841 r
.70968 .65928 .71049 .66004 .71211 .65714 .71138 .65767 Mtetra
.894 .967 .646 r
.71138 .65767 .71211 .65714 .71344 .64883 .71301 .65493 Mtetra
.13 0 .354 r
.71301 .65493 .71344 .64883 .70454 .45394 .71449 .64939 Mtetra
.078 0 .449 r
.71449 .64939 .70454 .45394 .70603 .4505 .70559 .45562 Mtetra
0 0 .285 r
.70559 .45562 .70603 .4505 .70762 .4489 .70695 .44978 Mtetra
.764 .893 .488 r
.70695 .44978 .70762 .4489 .70924 .44789 .70848 .44708 Mtetra
.775 .805 .877 r
.70848 .44708 .70924 .44789 .71089 .44724 .7101 .446 Mtetra
.637 .674 .869 r
.7101 .446 .71089 .44724 .71255 .44681 .71177 .44561 Mtetra
.581 .656 .888 r
.71177 .44561 .71255 .44681 .71421 .44647 .71344 .44546 Mtetra
.686 .736 .889 r
.71344 .44546 .71421 .44647 .71585 .44569 .71509 .44483 Mtetra
.717 .781 .903 r
.71509 .44483 .71585 .44569 .71749 .44489 .71673 .44407 Mtetra
.658 .771 .933 r
.71673 .44407 .71749 .44489 .71916 .44454 .71839 .44357 Mtetra
.271 .542 .921 r
.71839 .44357 .71916 .44454 .72094 .44612 .72012 .44415 Mtetra
.121 .272 .746 r
.72012 .44415 .72094 .44612 .72306 .45313 .72192 .44599 Mtetra
.35 .259 .61 r
.72192 .44599 .72306 .45313 .7366 .64732 .72385 .44992 Mtetra
.562 .355 .557 r
.72385 .44992 .7366 .64732 .73852 .64917 .72571 .45249 Mtetra
.568 .359 .558 r
.72571 .45249 .73852 .64917 .74029 .64871 .72732 .45108 Mtetra
.566 .358 .557 r
.72732 .45108 .74029 .64871 .74204 .64783 .729 .45072 Mtetra
.112 .026 .47 r
.729 .45072 .74204 .64783 .74386 .64812 .74255 .63916 Mtetra
.246 .177 .577 r
.74255 .63916 .74386 .64812 .74572 .6489 .74478 .64581 Mtetra
.207 .257 .694 r
.74478 .64581 .74572 .6489 .74756 .64943 .74675 .64831 Mtetra
.287 .53 .911 r
.74675 .64831 .74756 .64943 .74938 .64963 .7486 .64897 Mtetra
.556 .789 .986 r
.7486 .64897 .74938 .64963 .75118 .64941 .75039 .64869 Mtetra
.721 .829 .932 r
.75039 .64869 .75118 .64941 .75294 .64862 .75215 .64786 Mtetra
.829 .836 .853 r
.75215 .64786 .75294 .64862 .75459 .64612 .75387 .64633 Mtetra
.922 .976 .725 r
.75387 .64633 .75459 .64612 .75597 .63961 .75552 .64381 Mtetra
.027 0 .273 r
.75552 .64381 .75597 .63961 .74455 .4429 .75702 .6392 Mtetra
.103 .016 .462 r
.75702 .6392 .74455 .4429 .74597 .43855 .74578 .44591 Mtetra
.051 0 .359 r
.74578 .44591 .74597 .43855 .74756 .43679 .74696 .43808 Mtetra
0 0 0 r
.74696 .43808 .74756 .43679 .74919 .43572 .74846 .43506 Mtetra
.816 .851 .875 r
.74846 .43506 .74919 .43572 .75086 .43505 .75009 .43376 Mtetra
.641 .669 .862 r
.75009 .43376 .75086 .43505 .75255 .43463 .75177 .43334 Mtetra
.576 .638 .876 r
.75177 .43334 .75255 .43463 .75424 .43435 .75348 .43322 Mtetra
.604 .683 .898 r
.75348 .43322 .75424 .43435 .75593 .43395 .75518 .43296 Mtetra
.657 .734 .907 r
.75518 .43296 .75593 .43395 .75761 .43341 .75686 .43247 Mtetra
.672 .75 .909 r
.75686 .43247 .75761 .43341 .75929 .43283 .75854 .43191 Mtetra
.723 .772 .891 r
.75854 .43191 .75929 .43283 .76094 .43196 .7602 .4311 Mtetra
.738 .791 .895 r
.7602 .4311 .76094 .43196 .7626 .43104 .76186 .43022 Mtetra
.684 .782 .925 r
.76186 .43022 .7626 .43104 .76428 .43057 .76354 .4296 Mtetra
.459 .65 .941 r
.76354 .4296 .76428 .43057 .76609 .43162 .76528 .42976 Mtetra
.275 .385 .794 r
.76528 .42976 .76609 .43162 .76819 .43668 .7671 .43104 Mtetra
.34 .27 .632 r
.7671 .43104 .76819 .43668 .78467 .63286 .76907 .43434 Mtetra
.125 .039 .478 r
.76907 .43434 .78467 .63286 .78679 .63658 .78528 .62602 Mtetra
.281 .195 .577 r
.78528 .62602 .78679 .63658 .78869 .63736 .78767 .63339 Mtetra
.334 .308 .68 r
.78767 .63339 .78869 .63736 .79053 .63746 .7897 .63576 Mtetra
.368 .478 .84 r
.7897 .63576 .79053 .63746 .79238 .63748 .7916 .63659 Mtetra
.512 .71 .961 r
.7916 .63659 .79238 .63748 .79422 .63741 .79345 .63654 Mtetra
.672 .784 .933 r
.79345 .63654 .79422 .63741 .79602 .63677 .79524 .63593 Mtetra
.802 .821 .866 r
.79524 .63593 .79602 .63677 .7977 .63464 .79699 .63458 Mtetra
.93 .961 .769 r
.79699 .63458 .7977 .63464 .79908 .62884 .79865 .63218 Mtetra
0 0 .208 r
.79865 .63218 .79908 .62884 .78513 .43129 .80016 .62792 Mtetra
.131 .039 .475 r
.80016 .62792 .78513 .43129 .78646 .42617 .78669 .43718 Mtetra
.125 0 .418 r
.78669 .43718 .78646 .42617 .78806 .4244 .78757 .42642 Mtetra
0 0 .021 r
.78757 .42642 .78806 .4244 .78971 .42332 .78904 .4231 Mtetra
.868 .963 .86 r
.78904 .4231 .78971 .42332 .7914 .42256 .79065 .42149 Mtetra
.689 .731 .882 r
.79065 .42149 .7914 .42256 .79309 .42197 .79235 .42083 Mtetra
.631 .693 .889 r
.79235 .42083 .79309 .42197 .7948 .42149 .79406 .42045 Mtetra
.699 .741 .884 r
.79406 .42045 .7948 .42149 .79648 .42071 .79575 .41974 Mtetra
.759 .775 .866 r
.79575 .41974 .79648 .42071 .79814 .41971 .79741 .41869 Mtetra
.663 .734 .902 r
.79741 .41869 .79814 .41971 .79985 .4192 .79912 .41816 Mtetra
0 .324 .81 r
.79912 .41816 .79985 .4192 .80171 .42049 .80098 .41946 Mtetra
.95 .601 .225 r
.80098 .41946 .80171 .42049 .80444 .43184 .80383 .43225 Mtetra
.974 .672 .371 r
.80383 .43225 .80444 .43184 .82302 .62638 .82228 .62576 Mtetra
.635 .123 0 r
.82228 .62576 .82302 .62638 .8251 .62888 .82435 .62811 Mtetra
.543 .759 .977 r
.82435 .62811 .8251 .62888 .82697 .62885 .82621 .62791 Mtetra
.748 .791 .888 r
.82621 .62791 .82697 .62885 .82876 .62788 .82799 .6269 Mtetra
.822 .799 .83 r
.82799 .6269 .82876 .62788 .83043 .62559 .82972 .62528 Mtetra
.92 .932 .799 r
.82972 .62528 .83043 .62559 .83182 .62015 .8314 .62303 Mtetra
0 0 .186 r
.8314 .62303 .83182 .62015 .81599 .42276 .83294 .61928 Mtetra
.542 .336 .551 r
.83294 .61928 .81599 .42276 .81723 .41695 .83337 .60322 Mtetra
.129 .041 .478 r
.83337 .60322 .81723 .41695 .81883 .41512 .81843 .41768 Mtetra
0 0 .148 r
.81843 .41768 .81883 .41512 .8205 .41403 .81986 .414 Mtetra
.869 .992 .817 r
.81986 .414 .8205 .41403 .8222 .41334 .82147 .41223 Mtetra
.678 .722 .883 r
.82147 .41223 .8222 .41334 .82393 .41287 .82318 .41162 Mtetra
.605 .664 .881 r
.82318 .41162 .82393 .41287 .82567 .41253 .82493 .41136 Mtetra
.595 .674 .895 r
.82493 .41136 .82567 .41253 .82741 .4122 .82668 .41114 Mtetra
.65 .722 .901 r
.82668 .41114 .82741 .4122 .82914 .41172 .82841 .41066 Mtetra
.658 .726 .899 r
.82841 .41066 .82914 .41172 .83086 .4112 .83014 .41015 Mtetra
.668 .731 .897 r
.83014 .41015 .83086 .4112 .83258 .41063 .83186 .40959 Mtetra
.679 .736 .894 r
.83186 .40959 .83258 .41063 .8343 .41002 .83358 .40898 Mtetra
.689 .74 .89 r
.83358 .40898 .8343 .41002 .83602 .40937 .8353 .40831 Mtetra
.734 .754 .868 r
.8353 .40831 .83602 .40937 .83771 .40849 .83699 .40739 Mtetra
.775 .759 .839 r
.83699 .40739 .83771 .40849 .83938 .40733 .83865 .40617 Mtetra
.693 .719 .869 r
.83865 .40617 .83938 .40733 .8411 .40668 .84036 .40546 Mtetra
.293 .496 .884 r
.84036 .40546 .8411 .40668 .84297 .40753 .84223 .40624 Mtetra
.892 .517 .055 r
.84223 .40624 .84297 .40753 .84564 .41648 .84483 .41453 Mtetra
.975 .669 .339 r
.84483 .41453 .84564 .41648 .86708 .61383 .86634 .61291 Mtetra
.61 .148 0 r
.86634 .61291 .86708 .61383 .86927 .6167 .86854 .6159 Mtetra
.494 .728 .976 r
.86854 .6159 .86927 .6167 .87116 .61655 .87044 .61584 Mtetra
.739 .85 .932 r
.87044 .61584 .87116 .61655 .87298 .61566 .87226 .6149 Mtetra
.857 .855 .838 r
.87226 .6149 .87298 .61566 .87477 .61444 .87399 .61312 Mtetra
.884 .761 .722 r
.87399 .61312 .87477 .61444 .87657 .61342 .87559 .61014 Mtetra
.861 .647 .612 r
.87559 .61014 .87657 .61342 .87832 .61182 .87687 .60393 Mtetra
.973 .672 .378 r
.87687 .60393 .87832 .61182 .87988 .60838 .85857 .40827 Mtetra
.574 .364 .558 r
.85857 .40827 .87988 .60838 .8613 .41142 .8598 .4028 Mtetra
.652 .459 .609 r
.8598 .4028 .8613 .41142 .86217 .40251 .86133 .40013 Mtetra
.725 .607 .725 r
.86133 .40013 .86217 .40251 .86368 .39968 .86297 .39861 Mtetra
.666 .728 .896 r
.86297 .39861 .86368 .39968 .8654 .39894 .86471 .39805 Mtetra
.581 .733 .947 r
.86471 .39805 .8654 .39894 .86718 .3987 .86649 .3978 Mtetra
.584 .733 .946 r
.86649 .3978 .86718 .3987 .86897 .39856 .86827 .39755 Mtetra
.708 .757 .89 r
.86827 .39755 .86897 .39856 .87071 .39794 .86999 .39678 Mtetra
.665 .711 .882 r
.86999 .39678 .87071 .39794 .87245 .39739 .87174 .39623 Mtetra
.531 .645 .907 r
.87174 .39623 .87245 .39739 .87422 .397 .87355 .39624 Mtetra
0 .158 .663 r
.87355 .39624 .87422 .397 .87601 .39686 .87554 .39789 Mtetra
.866 .462 .266 r
.87554 .39789 .87601 .39686 .87787 .39726 .87788 .40275 Mtetra
.972 .66 .35 r
.87788 .40275 .87787 .39726 .8799 .39924 .90115 .59772 Mtetra
.571 .358 .552 r
.90115 .59772 .8799 .39924 .90341 .59511 .90359 .60238 Mtetra
.619 .344 .479 r
.90359 .60238 .90341 .59511 .90628 .60356 .90573 .60424 Mtetra
.563 .051 0 r
.90573 .60424 .90628 .60356 .90847 .60581 .90776 .60501 Mtetra
.481 .724 .978 r
.90776 .60501 .90847 .60581 .9104 .60578 .90969 .60497 Mtetra
.657 .802 .953 r
.90969 .60497 .9104 .60578 .91227 .60512 .91157 .60439 Mtetra
.797 .861 .897 r
.91157 .60439 .91227 .60512 .91409 .60406 .91336 .60311 Mtetra
.91 .82 .746 r
.91336 .60311 .91409 .60406 .91591 .603 .91499 .60034 Mtetra
.875 .672 .625 r
.91499 .60034 .91591 .603 .91766 .60136 .91631 .5949 Mtetra
.975 .669 .354 r
.91631 .5949 .91766 .60136 .91925 .59824 .89559 .398 Mtetra
.576 .365 .557 r
.89559 .398 .91925 .59824 .89857 .40295 .89668 .39161 Mtetra
.637 .438 .597 r
.89668 .39161 .89857 .40295 .89906 .39136 .89818 .38875 Mtetra
.729 .598 .71 r
.89818 .38875 .89906 .39136 .90051 .38812 .89981 .38702 Mtetra
.706 .74 .878 r
.89981 .38702 .90051 .38812 .90223 .3872 .90155 .38624 Mtetra
.638 .746 .926 r
.90155 .38624 .90223 .3872 .90401 .38679 .90333 .3858 Mtetra
.595 .716 .928 r
.90333 .3858 .90401 .38679 .90583 .38665 .90513 .38553 Mtetra
.618 .698 .902 r
.90513 .38553 .90583 .38665 .90762 .38628 .90693 .38519 Mtetra
.617 .704 .907 r
.90693 .38519 .90762 .38628 .90941 .38592 .90872 .38485 Mtetra
.633 .716 .907 r
.90872 .38485 .90941 .38592 .9112 .38551 .91051 .38443 Mtetra
.688 .739 .89 r
.91051 .38443 .9112 .38551 .91297 .38492 .91227 .38376 Mtetra
.697 .727 .873 r
.91227 .38376 .91297 .38492 .91473 .38427 .91402 .38302 Mtetra
.695 .71 .86 r
.91402 .38302 .91473 .38427 .91649 .38361 .91578 .38228 Mtetra
.675 .689 .855 r
.91578 .38228 .91649 .38361 .91826 .38299 .91754 .38164 Mtetra
.671 .684 .854 r
.91754 .38164 .91826 .38299 .92003 .38237 .91931 .38103 Mtetra
.671 .683 .854 r
.91931 .38103 .92003 .38237 .9218 .38175 .92108 .38041 Mtetra
.734 .713 .831 r
.92108 .38041 .9218 .38175 .92351 .38069 .9228 .37938 Mtetra
.681 .694 .856 r
.9228 .37938 .92351 .38069 .92528 .38001 .92457 .37871 Mtetra
.537 .626 .887 r
.92457 .37871 .92528 .38001 .92713 .38004 .92642 .37874 Mtetra
0 0 .383 r
.92642 .37874 .92713 .38004 .92953 .38436 .92879 .38284 Mtetra
.97 .655 .289 r
.92879 .38284 .92953 .38436 .95692 .58584 .95617 .58449 Mtetra
.714 .32 0 r
.95617 .58449 .95692 .58584 .95957 .59115 .95887 .59014 Mtetra
0 .419 .85 r
.34241 .75816 .34337 .75896 .34485 .75967 .34389 .75886 Mtetra
.632 .751 .933 r
.34389 .75886 .34485 .75967 .34638 .75929 .34543 .75849 Mtetra
.805 .775 .825 r
.34543 .75849 .34638 .75929 .34797 .75786 .34701 .75708 Mtetra
.908 .738 .659 r
.34701 .75708 .34797 .75786 .34975 .75261 .34879 .75184 Mtetra
.937 .686 .534 r
.34879 .75184 .34975 .75261 .36057 .56105 .35967 .56024 Mtetra
.91 .728 .644 r
.35967 .56024 .36057 .56105 .36228 .5553 .36139 .55447 Mtetra
.779 .761 .837 r
.36139 .55447 .36228 .5553 .36377 .55418 .36288 .55335 Mtetra
.643 .737 .918 r
.36288 .55335 .36377 .55418 .36523 .55381 .36433 .55297 Mtetra
.512 .692 .95 r
.36433 .55297 .36523 .55381 .36667 .5538 .36577 .55295 Mtetra
.746 .756 .861 r
.36577 .55295 .36667 .5538 .36815 .55292 .36725 .55207 Mtetra
.696 .747 .891 r
.36725 .55207 .36815 .55292 .36962 .55233 .36872 .55148 Mtetra
.481 .677 .951 r
.36872 .55148 .36962 .55233 .37105 .55238 .37016 .55153 Mtetra
.928 .548 .25 r
.37016 .55153 .37105 .55238 .37232 .55639 .37142 .55553 Mtetra
.939 .683 .522 r
.37142 .55553 .37232 .55639 .36522 .74735 .36427 .74653 Mtetra
.935 .579 .319 r
.36427 .74653 .36522 .74735 .36652 .75249 .36557 .7517 Mtetra
0 .341 .79 r
.36557 .7517 .36652 .75249 .36802 .75332 .36707 .75253 Mtetra
.618 .754 .943 r
.36707 .75253 .36802 .75332 .36956 .75299 .36862 .7522 Mtetra
.8 .78 .834 r
.36862 .7522 .36956 .75299 .37116 .75165 .37021 .75086 Mtetra
.906 .743 .67 r
.37021 .75086 .37116 .75165 .37289 .74693 .37195 .74613 Mtetra
.939 .687 .529 r
.37195 .74613 .37289 .74693 .3825 .55529 .38162 .55441 Mtetra
.914 .723 .632 r
.38162 .55441 .3825 .55529 .38423 .54874 .38334 .54788 Mtetra
.799 .758 .816 r
.38334 .54788 .38423 .54874 .38574 .5474 .38485 .54654 Mtetra
.651 .734 .91 r
.38485 .54654 .38574 .5474 .38721 .547 .38632 .54613 Mtetra
.518 .687 .944 r
.38632 .54613 .38721 .547 .38866 .54699 .38777 .54611 Mtetra
.732 .748 .865 r
.38777 .54611 .38866 .54699 .39015 .54619 .38926 .5453 Mtetra
.702 .742 .883 r
.38926 .5453 .39015 .54619 .39163 .54556 .39074 .54466 Mtetra
.519 .681 .939 r
.39074 .54466 .39163 .54556 .39308 .54559 .3922 .54465 Mtetra
.914 .513 .17 r
.3922 .54465 .39308 .54559 .39439 .54949 .39352 .5482 Mtetra
.943 .684 .516 r
.39352 .5482 .39439 .54949 .38851 .74125 .38761 .73948 Mtetra
.946 .592 .21 r
.38761 .73948 .38851 .74125 .38986 .74638 .38894 .74513 Mtetra
.299 .506 .89 r
.38894 .74513 .38986 .74638 .39139 .74696 .39046 .74574 Mtetra
.661 .679 .857 r
.39046 .74574 .39139 .74696 .39295 .74649 .39203 .74525 Mtetra
.725 .696 .823 r
.39203 .74525 .39295 .74649 .39454 .74561 .39362 .74432 Mtetra
.665 .672 .847 r
.39362 .74432 .39454 .74561 .3961 .74522 .39519 .7438 Mtetra
.647 .645 .835 r
.39519 .7438 .3961 .74522 .39767 .74485 .39676 .74336 Mtetra
.658 .642 .823 r
.39676 .74336 .39767 .74485 .39925 .74417 .39833 .74285 Mtetra
.705 .681 .824 r
.39833 .74285 .39925 .74417 .40087 .74228 .39991 .74206 Mtetra
.755 .925 .945 r
.39991 .74206 .40087 .74228 .40253 .73908 .4015 .74112 Mtetra
.302 0 .188 r
.4015 .74112 .40253 .73908 .40428 .73339 .40309 .74018 Mtetra
.547 .288 .475 r
.40309 .74018 .40428 .73339 .40593 .73066 .40465 .74005 Mtetra
.552 .306 .497 r
.40465 .74005 .40593 .73066 .40746 .73133 .40621 .7399 Mtetra
.522 .277 .484 r
.40621 .7399 .40746 .73133 .40904 .73067 .4078 .73909 Mtetra
.264 .058 .401 r
.4078 .73909 .40904 .73067 .41653 .54602 .40952 .73424 Mtetra
0 0 .319 r
.40952 .73424 .41653 .54602 .4182 .53994 .41722 .54247 Mtetra
.904 .86 .415 r
.41722 .54247 .4182 .53994 .41977 .53707 .41887 .5368 Mtetra
.863 .885 .851 r
.41887 .5368 .41977 .53707 .42127 .53604 .4204 .53527 Mtetra
.661 .762 .924 r
.4204 .53527 .42127 .53604 .42276 .53571 .42189 .53481 Mtetra
.551 .694 .934 r
.42189 .53481 .42276 .53571 .42424 .53561 .42337 .53471 Mtetra
.633 .725 .914 r
.42337 .53471 .42424 .53561 .42573 .53517 .42486 .53437 Mtetra
.669 .756 .915 r
.42486 .53437 .42573 .53517 .42723 .53455 .42635 .53388 Mtetra
.668 .788 .938 r
.42635 .53388 .42723 .53455 .42873 .53393 .42785 .53338 Mtetra
.67 .824 .957 r
.42785 .53338 .42873 .53393 .43023 .53325 .42934 .53286 Mtetra
.644 .865 .983 r
.42934 .53286 .43023 .53325 .43173 .53267 .43084 .53236 Mtetra
.59 .872 .994 r
.43084 .53236 .43173 .53267 .43322 .53237 .43234 .53193 Mtetra
.491 .802 1 r
.43234 .53193 .43322 .53237 .43469 .53306 .43383 .53175 Mtetra
.558 .614 .865 r
.43383 .53175 .43469 .53306 .43612 .53493 .43531 .53173 Mtetra
.574 .473 .702 r
.43531 .53173 .43612 .53493 .43751 .53889 .4368 .53174 Mtetra
.6 .43 .624 r
.4368 .53174 .43751 .53889 .43893 .54154 .4383 .53113 Mtetra
.593 .41 .603 r
.4383 .53113 .43893 .54154 .44046 .54027 .43981 .53041 Mtetra
.576 .399 .605 r
.43981 .53041 .44046 .54027 .44195 .54007 .44131 .53025 Mtetra
.444 .3 .59 r
.44131 .53025 .44195 .54007 .43901 .72334 .44273 .53325 Mtetra
0 0 .349 r
.44273 .53325 .43901 .72334 .44044 .72952 .43962 .7244 Mtetra
0 0 .413 r
.43962 .7244 .44044 .72952 .44197 .73195 .44106 .73036 Mtetra
.17 .367 .816 r
.44106 .73036 .44197 .73195 .44354 .73256 .44262 .73147 Mtetra
.61 .69 .899 r
.44262 .73147 .44354 .73256 .44513 .73235 .44422 .7312 Mtetra
.697 .708 .856 r
.44422 .7312 .44513 .73235 .44673 .73186 .44582 .73051 Mtetra
.673 .668 .837 r
.44582 .73051 .44673 .73186 .44833 .7314 .44742 .72992 Mtetra
.649 .641 .829 r
.44742 .72992 .44833 .7314 .44993 .73096 .44902 .72945 Mtetra
.652 .639 .824 r
.44902 .72945 .44993 .73096 .45153 .73048 .45062 .72897 Mtetra
.655 .64 .823 r
.45062 .72897 .45153 .73048 .45313 .72992 .45222 .72847 Mtetra
.657 .649 .83 r
.45222 .72847 .45313 .72992 .45473 .72931 .45383 .72796 Mtetra
.659 .663 .843 r
.45383 .72796 .45473 .72931 .45634 .7287 .45543 .72745 Mtetra
.648 .676 .863 r
.45543 .72745 .45634 .7287 .45794 .7283 .45704 .72702 Mtetra
.643 .667 .858 r
.45704 .72702 .45794 .7283 .45955 .72798 .45864 .72661 Mtetra
.653 .658 .843 r
.45864 .72661 .45955 .72798 .46115 .72742 .46025 .72614 Mtetra
.695 .687 .838 r
.46025 .72614 .46115 .72742 .46278 .72589 .46186 .72542 Mtetra
.759 .865 .927 r
.46186 .72542 .46278 .72589 .46443 .72306 .46347 .72448 Mtetra
.163 0 .01 r
.46347 .72448 .46443 .72306 .4661 .71841 .46509 .72352 Mtetra
.498 .228 .435 r
.46509 .72352 .4661 .71841 .46779 .71284 .4667 .72281 Mtetra
.543 .3 .498 r
.4667 .72281 .46779 .71284 .46941 .7115 .46831 .72237 Mtetra
.547 .307 .503 r
.46831 .72237 .46941 .7115 .47099 .71289 .46992 .72202 Mtetra
.543 .297 .493 r
.46992 .72202 .47099 .71289 .47258 .71343 .47153 .72164 Mtetra
.538 .289 .485 r
.47153 .72164 .47258 .71343 .47418 .7131 .47315 .72122 Mtetra
.538 .288 .485 r
.47315 .72122 .47418 .7131 .47579 .71277 .47476 .72079 Mtetra
.537 .287 .484 r
.47476 .72079 .47579 .71277 .4774 .7124 .47637 .72036 Mtetra
.536 .286 .483 r
.47637 .72036 .4774 .7124 .47901 .71197 .47799 .71992 Mtetra
.47799 .71992 .47901 .71197 .48062 .71153 .47961 .71947 Mtetra
.47961 .71947 .48062 .71153 .48224 .71106 .48122 .71902 Mtetra
.48122 .71902 .48224 .71106 .48385 .71058 .48284 .71857 Mtetra
.48284 .71857 .48385 .71058 .48547 .71008 .48446 .71811 Mtetra
.48446 .71811 .48547 .71008 .48708 .70955 .48608 .71765 Mtetra
.536 .286 .484 r
.48608 .71765 .48708 .70955 .4887 .70901 .48771 .71718 Mtetra
.536 .287 .484 r
.48771 .71718 .4887 .70901 .49032 .70845 .48933 .71671 Mtetra
.536 .287 .485 r
.48933 .71671 .49032 .70845 .49194 .70785 .49095 .71623 Mtetra
.536 .288 .486 r
.49095 .71623 .49194 .70785 .49356 .70722 .49258 .71574 Mtetra
.537 .289 .487 r
.49258 .71574 .49356 .70722 .49518 .70659 .4942 .71526 Mtetra
.537 .29 .489 r
.4942 .71526 .49518 .70659 .49681 .70597 .49583 .71478 Mtetra
.538 .292 .49 r
.49583 .71478 .49681 .70597 .49843 .7054 .49745 .7143 Mtetra
.539 .293 .49 r
.49745 .7143 .49843 .7054 .50005 .70486 .49908 .71383 Mtetra
.539 .293 .491 r
.49908 .71383 .50005 .70486 .50168 .70436 .50071 .71337 Mtetra
.54 .294 .491 r
.50071 .71337 .50168 .70436 .5033 .7039 .50234 .71292 Mtetra
.54 .294 .492 r
.50234 .71292 .5033 .7039 .50493 .70348 .50397 .71247 Mtetra
.541 .295 .491 r
.50397 .71247 .50493 .70348 .50655 .70315 .5056 .71205 Mtetra
.541 .294 .491 r
.5056 .71205 .50655 .70315 .50818 .70288 .50724 .71163 Mtetra
.54 .293 .49 r
.50724 .71163 .50818 .70288 .50981 .70262 .50887 .71121 Mtetra
.549 .3 .491 r
.50887 .71121 .50981 .70262 .51143 .70324 .5105 .71104 Mtetra
.553 .3 .485 r
.5105 .71104 .51143 .70324 .51306 .70413 .51214 .711 Mtetra
.523 .267 .469 r
.51214 .711 .51306 .70413 .51469 .7033 .51378 .71039 Mtetra
.397 .162 .437 r
.51378 .71039 .51469 .7033 .51676 .52617 .51542 .70769 Mtetra
0 0 .362 r
.51542 .70769 .51676 .52617 .51834 .51037 .51748 .51924 Mtetra
0 0 .122 r
.51748 .51924 .51834 .51037 .51989 .50664 .51905 .50684 Mtetra
.956 .923 .733 r
.51905 .50684 .51989 .50664 .52144 .50482 .5206 .50411 Mtetra
.722 .799 .912 r
.5206 .50411 .52144 .50482 .52299 .50419 .52215 .50338 Mtetra
.596 .739 .944 r
.52215 .50338 .52299 .50419 .52453 .50387 .52369 .50312 Mtetra
.567 .745 .96 r
.52369 .50312 .52453 .50387 .52608 .50359 .52524 .50292 Mtetra
.647 .793 .953 r
.52524 .50292 .52608 .50359 .52763 .50314 .52679 .50248 Mtetra
.643 .793 .954 r
.52679 .50248 .52763 .50314 .52918 .5027 .52834 .50204 Mtetra
.642 .794 .955 r
.52834 .50204 .52918 .5027 .53073 .50225 .52989 .50161 Mtetra
.641 .798 .958 r
.52989 .50161 .53073 .50225 .53228 .50179 .53145 .50117 Mtetra
.638 .803 .962 r
.53145 .50117 .53228 .50179 .53383 .50135 .533 .50074 Mtetra
.634 .805 .965 r
.533 .50074 .53383 .50135 .53539 .50097 .53455 .50031 Mtetra
.633 .793 .959 r
.53455 .50031 .53539 .50097 .53694 .50067 .53611 .4999 Mtetra
.643 .766 .938 r
.53611 .4999 .53694 .50067 .5385 .50037 .53767 .49949 Mtetra
.652 .74 .914 r
.53767 .49949 .5385 .50037 .54006 .50001 .53922 .49904 Mtetra
.662 .725 .896 r
.53922 .49904 .54006 .50001 .54161 .49953 .54078 .49857 Mtetra
.667 .727 .894 r
.54078 .49857 .54161 .49953 .54317 .49899 .54234 .49807 Mtetra
.707 .747 .884 r
.54234 .49807 .54317 .49899 .54473 .4982 .5439 .49737 Mtetra
.756 .779 .871 r
.5439 .49737 .54473 .4982 .54628 .49711 .54545 .49642 Mtetra
.662 .792 .944 r
.54545 .49642 .54628 .49711 .54784 .49651 .54702 .49592 Mtetra
0 .284 .712 r
.54702 .49592 .54784 .49651 .54941 .49729 .54859 .4968 Mtetra
.945 .605 .348 r
.54859 .4968 .54941 .49729 .55104 .50492 .55022 .5049 Mtetra
.958 .684 .473 r
.55022 .5049 .55104 .50492 .55422 .69856 .55334 .69751 Mtetra
.783 .327 0 r
.55334 .69751 .55422 .69856 .55592 .70164 .55503 .70045 Mtetra
.545 .649 .903 r
.55503 .70045 .55592 .70164 .55758 .70173 .5567 .70043 Mtetra
.688 .686 .843 r
.5567 .70043 .55758 .70173 .55925 .70103 .55836 .69973 Mtetra
.732 .703 .823 r
.55836 .69973 .55925 .70103 .5609 .69957 .56002 .69872 Mtetra
.745 .785 .885 r
.56002 .69872 .5609 .69957 .56254 .69705 .56169 .69779 Mtetra
0 0 0 r
.56169 .69779 .56254 .69705 .56417 .69306 .56335 .69678 Mtetra
.452 .162 .381 r
.56335 .69678 .56417 .69306 .56576 .68641 .56501 .69589 Mtetra
.539 .295 .494 r
.56501 .69589 .56576 .68641 .5674 .68359 .56668 .69537 Mtetra
.548 .31 .507 r
.56668 .69537 .5674 .68359 .56908 .68462 .56835 .69496 Mtetra
.546 .304 .5 r
.56835 .69496 .56908 .68462 .57077 .68605 .57002 .69459 Mtetra
.539 .291 .488 r
.57002 .69459 .57077 .68605 .57244 .68576 .57169 .69415 Mtetra
.538 .29 .486 r
.57169 .69415 .57244 .68576 .57411 .68548 .57336 .69371 Mtetra
.538 .288 .485 r
.57336 .69371 .57411 .68548 .57578 .68519 .57504 .69326 Mtetra
.537 .287 .484 r
.57504 .69326 .57578 .68519 .57745 .68483 .57671 .69282 Mtetra
.537 .286 .483 r
.57671 .69282 .57745 .68483 .57912 .68444 .57839 .69236 Mtetra
.536 .285 .482 r
.57839 .69236 .57912 .68444 .58079 .68404 .58006 .69191 Mtetra
.58006 .69191 .58079 .68404 .58247 .68361 .58174 .69145 Mtetra
.536 .284 .481 r
.58174 .69145 .58247 .68361 .58414 .68316 .58342 .69099 Mtetra
.535 .284 .481 r
.58342 .69099 .58414 .68316 .58582 .68268 .5851 .69053 Mtetra
.5851 .69053 .58582 .68268 .58749 .68215 .58678 .69006 Mtetra
.535 .284 .482 r
.58678 .69006 .58749 .68215 .58917 .68161 .58846 .68959 Mtetra
.58846 .68959 .58917 .68161 .59084 .68084 .59015 .6891 Mtetra
.533 .285 .484 r
.59015 .6891 .59084 .68084 .59248 .67855 .59183 .68854 Mtetra
.542 .299 .497 r
.59183 .68854 .59248 .67855 .59416 .67797 .59351 .68805 Mtetra
.547 .304 .499 r
.59351 .68805 .59416 .67797 .59591 .6809 .5952 .68774 Mtetra
.555 .294 .475 r
.5952 .68774 .59591 .6809 .59769 .68551 .5969 .68779 Mtetra
.525 .177 .32 r
.5969 .68779 .59769 .68551 .59944 .68786 .5986 .68785 Mtetra
.048 .616 .74 r
.5986 .68785 .59944 .68786 .60116 .68904 .6003 .68781 Mtetra
.622 .676 .88 r
.6003 .68781 .60116 .68904 .60286 .689 .60199 .68748 Mtetra
.639 .638 .834 r
.60199 .68748 .60286 .689 .60456 .68864 .60368 .68705 Mtetra
.641 .631 .825 r
.60368 .68705 .60456 .68864 .60625 .68812 .60537 .68661 Mtetra
.581 .614 .85 r
.60537 .68661 .60625 .68812 .60794 .68779 .60708 .68649 Mtetra
.652 .677 .862 r
.60708 .68649 .60794 .68779 .60964 .68719 .60877 .68601 Mtetra
.768 .734 .821 r
.60877 .68601 .60964 .68719 .61132 .6861 .61045 .68474 Mtetra
.903 .728 .654 r
.61045 .68474 .61132 .6861 .61296 .68352 .61203 .67986 Mtetra
.961 .687 .47 r
.61203 .67986 .61296 .68352 .61454 .67865 .60879 .48487 Mtetra
.577 .367 .558 r
.60879 .48487 .61454 .67865 .61126 .48742 .61023 .47791 Mtetra
.62 .433 .608 r
.61023 .47791 .61126 .48742 .61268 .48021 .6118 .47632 Mtetra
.638 .498 .675 r
.6118 .47632 .61268 .48021 .61422 .47731 .61339 .47546 Mtetra
.645 .596 .784 r
.61339 .47546 .61422 .47731 .61578 .47559 .61499 .47497 Mtetra
.666 .817 .956 r
.61499 .47497 .61578 .47559 .61738 .47498 .61659 .47443 Mtetra
.625 .829 .979 r
.61659 .47443 .61738 .47498 .61899 .47467 .61819 .47398 Mtetra
.633 .791 .958 r
.61819 .47398 .61899 .47467 .6206 .47447 .61979 .47356 Mtetra
.747 .766 .869 r
.61979 .47356 .6206 .47447 .62219 .47358 .62139 .47263 Mtetra
.691 .744 .893 r
.62139 .47263 .62219 .47358 .62379 .47286 .62299 .47201 Mtetra
.508 .696 .954 r
.62299 .47201 .62379 .47286 .6254 .47255 .62461 .47199 Mtetra
.861 .412 .043 r
.62461 .47199 .6254 .47255 .62706 .47381 .62633 .47525 Mtetra
.963 .681 .45 r
.62633 .47525 .62706 .47381 .62878 .47709 .634 .66868 Mtetra
.576 .362 .553 r
.634 .66868 .62878 .47709 .63648 .66699 .63595 .67606 Mtetra
.583 .33 .498 r
.63595 .67606 .63648 .66699 .63844 .67428 .63771 .67688 Mtetra
.52 .186 .342 r
.63771 .67688 .63844 .67428 .64024 .67658 .63943 .67685 Mtetra
0 0 0 r
.63943 .67685 .64024 .67658 .642 .67754 .64115 .67637 Mtetra
.541 .654 .908 r
.64115 .67637 .642 .67754 .64373 .67751 .64288 .67634 Mtetra
.644 .698 .886 r
.64288 .67634 .64373 .67751 .64544 .67691 .6446 .6759 Mtetra
.765 .765 .852 r
.6446 .6759 .64544 .67691 .64713 .67572 .64629 .67476 Mtetra
.927 .764 .66 r
.64629 .67476 .64713 .67572 .64878 .67326 .64786 .67014 Mtetra
.965 .687 .457 r
.64786 .67014 .64878 .67326 .65035 .66863 .64263 .47515 Mtetra
.578 .367 .558 r
.64263 .47515 .65035 .66863 .64514 .4781 .644 .46752 Mtetra
.617 .428 .603 r
.644 .46752 .64514 .4781 .64649 .47009 .64557 .4658 Mtetra
.632 .486 .666 r
.64557 .4658 .64649 .47009 .64801 .46705 .64718 .46495 Mtetra
.635 .571 .765 r
.64718 .46495 .64801 .46705 .64958 .46524 .6488 .46449 Mtetra
.655 .785 .943 r
.6488 .46449 .64958 .46524 .65119 .46457 .65042 .464 Mtetra
.61 .82 .981 r
.65042 .464 .65119 .46457 .65282 .46429 .65204 .4636 Mtetra
.61 .783 .964 r
.65204 .4636 .65282 .46429 .65446 .46418 .65367 .46324 Mtetra
.732 .761 .876 r
.65367 .46324 .65446 .46418 .65607 .46338 .65528 .46239 Mtetra
.689 .737 .888 r
.65528 .46239 .65607 .46338 .65769 .46267 .6569 .46176 Mtetra
.525 .692 .945 r
.6569 .46176 .65769 .46267 .65932 .46235 .65854 .46172 Mtetra
.891 .468 .099 r
.65854 .46172 .65932 .46235 .66104 .46428 .66036 .46589 Mtetra
.966 .68 .438 r
.66036 .46589 .66104 .46428 .66293 .47 .67018 .66178 Mtetra
.572 .358 .552 r
.67018 .66178 .66293 .47 .67263 .65951 .67212 .6664 Mtetra
.35 .128 .429 r
.67212 .6664 .67263 .65951 .66639 .4736 .67373 .6629 Mtetra
.023 0 .425 r
.67373 .6629 .66639 .4736 .6676 .46332 .66702 .46693 Mtetra
0 0 0 r
.66702 .46693 .6676 .46332 .6691 .4597 .66834 .45927 Mtetra
.853 .895 .866 r
.66834 .45927 .6691 .4597 .67071 .45867 .66993 .45778 Mtetra
.656 .75 .919 r
.66993 .45778 .67071 .45867 .67235 .45832 .67156 .4573 Mtetra
.56 .681 .92 r
.67156 .4573 .67235 .45832 .674 .45823 .67321 .45719 Mtetra
.639 .712 .9 r
.67321 .45719 .674 .45823 .67564 .45783 .67485 .45679 Mtetra
.658 .719 .893 r
.67485 .45679 .67564 .45783 .67727 .4573 .67649 .4563 Mtetra
.664 .729 .898 r
.67649 .4563 .67727 .4573 .6789 .45672 .67812 .45579 Mtetra
.695 .755 .898 r
.67812 .45579 .6789 .45672 .68052 .45582 .67975 .45514 Mtetra
.696 .816 .939 r
.67975 .45514 .68052 .45582 .68214 .45501 .68138 .45448 Mtetra
.66 .852 .973 r
.68138 .45448 .68214 .45501 .68378 .45451 .68302 .45391 Mtetra
.672 .835 .962 r
.68302 .45391 .68378 .45451 .68547 .455 .68466 .45333 Mtetra
.616 .601 .813 r
.68466 .45333 .68547 .455 .68722 .45664 .68631 .45304 Mtetra
.541 .445 .694 r
.68631 .45304 .68722 .45664 .68912 .46128 .68799 .4534 Mtetra
.362 .26 .602 r
.68799 .4534 .68912 .46128 .70047 .65299 .68987 .45747 Mtetra
.063 0 .449 r
.68987 .45747 .70047 .65299 .70249 .65782 .70149 .65337 Mtetra
0 .038 .56 r
.70149 .65337 .70249 .65782 .70436 .6597 .70353 .65845 Mtetra
.263 .487 .886 r
.70353 .65845 .70436 .6597 .70617 .66022 .70535 .65925 Mtetra
.616 .732 .929 r
.70535 .65925 .70617 .66022 .70794 .66002 .70711 .6589 Mtetra
.715 .735 .867 r
.70711 .6589 .70794 .66002 .70968 .65928 .70885 .65806 Mtetra
.668 .703 .873 r
.70885 .65806 .70968 .65928 .71138 .65767 .7106 .65748 Mtetra
.634 .937 .964 r
.7106 .65748 .71138 .65767 .71301 .65493 .71234 .65672 Mtetra
.162 0 .113 r
.71234 .65672 .71301 .65493 .71449 .64939 .71405 .65526 Mtetra
.148 0 .356 r
.71405 .65526 .71449 .64939 .70559 .45562 .71555 .65011 Mtetra
.061 0 .444 r
.71555 .65011 .70559 .45562 .70695 .44978 .7064 .45278 Mtetra
0 0 0 r
.7064 .45278 .70695 .44978 .70848 .44708 .70776 .44686 Mtetra
.88 .946 .851 r
.70776 .44686 .70848 .44708 .7101 .446 .70934 .44519 Mtetra
.665 .776 .932 r
.70934 .44519 .7101 .446 .71177 .44561 .711 .44466 Mtetra
.563 .702 .934 r
.711 .44466 .71177 .44561 .71344 .44546 .71268 .44452 Mtetra
.643 .736 .916 r
.71268 .44452 .71344 .44546 .71509 .44483 .71434 .44408 Mtetra
.676 .795 .938 r
.71434 .44408 .71509 .44483 .71673 .44407 .71599 .4435 Mtetra
.642 .836 .975 r
.71599 .4435 .71673 .44407 .71839 .44357 .71765 .44299 Mtetra
.537 .795 .992 r
.71765 .44299 .71839 .44357 .72012 .44415 .71933 .44275 Mtetra
.568 .616 .861 r
.71933 .44275 .72012 .44415 .72192 .44599 .72102 .44269 Mtetra
.578 .478 .705 r
.72102 .44269 .72192 .44599 .72385 .44992 .72271 .44266 Mtetra
.6 .431 .625 r
.72271 .44266 .72385 .44992 .72571 .45249 .72436 .44199 Mtetra
.593 .411 .604 r
.72436 .44199 .72571 .45249 .72732 .45108 .72601 .44119 Mtetra
.578 .402 .607 r
.72601 .44119 .72732 .45108 .729 .45072 .72769 .44097 Mtetra
.465 .323 .603 r
.72769 .44097 .729 .45072 .74255 .63916 .72958 .44388 Mtetra
.082 .005 .46 r
.72958 .44388 .74255 .63916 .74478 .64581 .74368 .6402 Mtetra
0 .04 .547 r
.74368 .6402 .74478 .64581 .74675 .64831 .74589 .64654 Mtetra
.275 .41 .818 r
.74589 .64654 .74675 .64831 .7486 .64897 .74778 .64772 Mtetra
.612 .676 .887 r
.74778 .64772 .7486 .64897 .75039 .64869 .74957 .64741 Mtetra
.705 .711 .853 r
.74957 .64741 .75039 .64869 .75215 .64786 .75133 .6466 Mtetra
.68 .703 .864 r
.75133 .6466 .75215 .64786 .75387 .64633 .7531 .64593 Mtetra
.658 .901 .981 r
.7531 .64593 .75387 .64633 .75552 .64381 .75488 .64523 Mtetra
.111 0 .021 r
.75488 .64523 .75552 .64381 .75702 .6392 .75661 .64392 Mtetra
.168 0 .339 r
.75661 .64392 .75702 .6392 .74578 .44591 .75815 .63983 Mtetra
.082 .001 .455 r
.75815 .63983 .74578 .44591 .74696 .43808 .7466 .44286 Mtetra
0 0 .162 r
.7466 .44286 .74696 .43808 .74846 .43506 .74778 .43506 Mtetra
.917 .972 .782 r
.74778 .43506 .74846 .43506 .75009 .43376 .74935 .43295 Mtetra
.68 .785 .93 r
.74935 .43295 .75009 .43376 .75177 .43334 .75102 .43235 Mtetra
.567 .697 .929 r
.75102 .43235 .75177 .43334 .75348 .43322 .75273 .4322 Mtetra
.6 .703 .916 r
.75273 .4322 .75348 .43322 .75518 .43296 .75443 .43194 Mtetra
.653 .725 .902 r
.75443 .43194 .75518 .43296 .75686 .43247 .75611 .43146 Mtetra
.659 .731 .902 r
.75611 .43146 .75686 .43247 .75854 .43191 .75779 .43096 Mtetra
.684 .752 .903 r
.75779 .43096 .75854 .43191 .7602 .4311 .75947 .43034 Mtetra
.698 .804 .93 r
.75947 .43034 .7602 .4311 .76186 .43022 .76114 .42966 Mtetra
.67 .852 .969 r
.76114 .42966 .76186 .43022 .76354 .4296 .76282 .42904 Mtetra
.665 .851 .971 r
.76282 .42904 .76354 .4296 .76528 .42976 .7645 .42844 Mtetra
.64 .666 .859 r
.7645 .42844 .76528 .42976 .7671 .43104 .7662 .42802 Mtetra
.562 .48 .72 r
.7662 .42802 .7671 .43104 .76907 .43434 .76794 .42815 Mtetra
.431 .326 .634 r
.76794 .42815 .76907 .43434 .78528 .62602 .76985 .43056 Mtetra
.105 .025 .472 r
.76985 .43056 .78528 .62602 .78767 .63339 .78639 .62585 Mtetra
.057 .058 .542 r
.78639 .62585 .78767 .63339 .7897 .63576 .78885 .63398 Mtetra
.15 .329 .789 r
.78885 .63398 .7897 .63576 .7916 .63659 .79082 .63561 Mtetra
.568 .712 .939 r
.79082 .63561 .7916 .63659 .79345 .63654 .79265 .63542 Mtetra
.697 .737 .882 r
.79265 .63542 .79345 .63654 .79524 .63593 .79444 .63467 Mtetra
.687 .71 .865 r
.79444 .63467 .79524 .63593 .79699 .63458 .79623 .63397 Mtetra
.662 .847 .971 r
.79623 .63397 .79699 .63458 .79865 .63218 .79804 .63334 Mtetra
.066 0 0 r
.79804 .63334 .79865 .63218 .80016 .62792 .79979 .63214 Mtetra
.214 0 .342 r
.79979 .63214 .80016 .62792 .78669 .43718 .80137 .62874 Mtetra
.101 .018 .466 r
.80137 .62874 .78669 .43718 .78757 .42642 .78751 .43384 Mtetra
0 0 .283 r
.78751 .43384 .78757 .42642 .78904 .4231 .78838 .423 Mtetra
.952 .937 .737 r
.78838 .423 .78904 .4231 .79065 .42149 .78991 .42041 Mtetra
.704 .736 .876 r
.78991 .42041 .79065 .42149 .79235 .42083 .7916 .41967 Mtetra
.607 .681 .894 r
.7916 .41967 .79235 .42083 .79406 .42045 .79332 .4194 Mtetra
.665 .727 .895 r
.79332 .4194 .79406 .42045 .79575 .41974 .79503 .41886 Mtetra
.744 .791 .89 r
.79503 .41886 .79575 .41974 .79741 .41869 .7967 .41793 Mtetra
.628 .783 .956 r
.7967 .41793 .79741 .41869 .79912 .41816 .79841 .4175 Mtetra
0 .188 .665 r
.79841 .4175 .79912 .41816 .80098 .41946 .80028 .41887 Mtetra
.954 .607 .262 r
.80028 .41887 .80098 .41946 .80383 .43225 .80319 .43238 Mtetra
.975 .673 .37 r
.80319 .43238 .80383 .43225 .82228 .62576 .82149 .62451 Mtetra
0 .077 .629 r
.82149 .62451 .82228 .62576 .82435 .62811 .82356 .62681 Mtetra
.59 .661 .887 r
.82356 .62681 .82435 .62811 .82621 .62791 .82541 .62661 Mtetra
.707 .712 .853 r
.82541 .62661 .82621 .62791 .82799 .6269 .82721 .62576 Mtetra
.716 .744 .874 r
.82721 .62576 .82799 .6269 .82972 .62528 .82901 .6249 Mtetra
.585 .886 .991 r
.82901 .6249 .82972 .62528 .8314 .62303 .83084 .62435 Mtetra
.185 0 .035 r
.83084 .62435 .8314 .62303 .83294 .61928 .83262 .62329 Mtetra
.271 .03 .353 r
.83262 .62329 .83294 .61928 .83337 .60322 .83425 .62046 Mtetra
.122 .009 .44 r
.83425 .62046 .83337 .60322 .81843 .41768 .83456 .60313 Mtetra
.115 .031 .474 r
.83456 .60313 .81843 .41768 .81986 .414 .81925 .41415 Mtetra
.96 .945 .66 r
.81925 .41415 .81986 .414 .82147 .41223 .82074 .41113 Mtetra
.702 .733 .875 r
.82074 .41113 .82147 .41223 .82318 .41162 .82244 .41039 Mtetra
.591 .66 .886 r
.82244 .41039 .82318 .41162 .82493 .41136 .82419 .41019 Mtetra
.57 .661 .899 r
.82419 .41019 .82493 .41136 .82668 .41114 .82596 .41006 Mtetra
.649 .717 .898 r
.82596 .41006 .82668 .41114 .82841 .41066 .82769 .40959 Mtetra
.655 .722 .898 r
.82769 .40959 .82841 .41066 .83014 .41015 .82941 .40909 Mtetra
.668 .73 .896 r
.82941 .40909 .83014 .41015 .83186 .40959 .83114 .40853 Mtetra
.684 .736 .89 r
.83114 .40853 .83186 .40959 .83358 .40898 .83286 .40789 Mtetra
.689 .733 .884 r
.83286 .40789 .83358 .40898 .8353 .40831 .83457 .40723 Mtetra
.722 .744 .869 r
.83457 .40723 .8353 .40831 .83699 .40739 .83627 .40637 Mtetra
.761 .77 .861 r
.83627 .40637 .83699 .40739 .83865 .40617 .83795 .40529 Mtetra
.674 .774 .926 r
.83795 .40529 .83865 .40617 .84036 .40546 .83967 .4047 Mtetra
.049 .45 .878 r
.83967 .4047 .84036 .40546 .84223 .40624 .84154 .40555 Mtetra
.921 .537 .139 r
.84154 .40555 .84223 .40624 .84483 .41453 .84414 .41375 Mtetra
.975 .669 .344 r
.84414 .41375 .84483 .41453 .86634 .61291 .86556 .61158 Mtetra
0 0 .511 r
.86556 .61158 .86634 .61291 .86854 .6159 .86777 .61465 Mtetra
.494 .624 .908 r
.86777 .61465 .86854 .6159 .87044 .61584 .86969 .61481 Mtetra
.714 .768 .895 r
.86969 .61481 .87044 .61584 .87226 .6149 .87152 .61398 Mtetra
.878 .822 .789 r
.87152 .61398 .87226 .6149 .87399 .61312 .8732 .61177 Mtetra
.952 .75 .594 r
.8732 .61177 .87399 .61312 .87559 .61014 .87447 .60539 Mtetra
.976 .674 .369 r
.87447 .60539 .87559 .61014 .87687 .60393 .85589 .40557 Mtetra
.573 .363 .557 r
.85589 .40557 .87687 .60393 .85857 .40827 .85718 .40061 Mtetra
.623 .444 .62 r
.85718 .40061 .85857 .40827 .8598 .4028 .85883 .3992 Mtetra
.634 .506 .689 r
.85883 .3992 .8598 .4028 .86133 .40013 .86055 .39844 Mtetra
.642 .62 .813 r
.86055 .39844 .86133 .40013 .86297 .39861 .8623 .39797 Mtetra
.635 .826 .974 r
.8623 .39797 .86297 .39861 .86471 .39805 .86405 .39746 Mtetra
.598 .826 .987 r
.86405 .39746 .86471 .39805 .86649 .3978 .86581 .39704 Mtetra
.649 .796 .953 r
.86581 .39704 .86649 .3978 .86827 .39755 .86756 .39652 Mtetra
.734 .763 .876 r
.86756 .39652 .86827 .39755 .86999 .39678 .86927 .39561 Mtetra
.664 .706 .879 r
.86927 .39561 .86999 .39678 .87174 .39623 .87102 .39505 Mtetra
.402 .573 .906 r
.87102 .39505 .87174 .39623 .87355 .39624 .87288 .39549 Mtetra
.824 .39 0 r
.87288 .39549 .87355 .39624 .87554 .39789 .8752 .40025 Mtetra
.973 .663 .339 r
.8752 .40025 .87554 .39789 .87788 .40275 .89878 .59936 Mtetra
.571 .358 .552 r
.89878 .59936 .87788 .40275 .90115 .59772 .9012 .60389 Mtetra
.573 .299 .463 r
.9012 .60389 .90115 .59772 .90359 .60238 .90319 .60439 Mtetra
.475 .11 .266 r
.90319 .60439 .90359 .60238 .90573 .60424 .90511 .60417 Mtetra
.348 .824 .872 r
.90511 .60417 .90573 .60424 .90776 .60501 .90699 .60371 Mtetra
.561 .651 .895 r
.90699 .60371 .90776 .60501 .90969 .60497 .90892 .60362 Mtetra
.657 .687 .867 r
.90892 .60362 .90969 .60497 .91157 .60439 .9108 .60306 Mtetra
.789 .744 .811 r
.9108 .60306 .91157 .60439 .91336 .60311 .91257 .60152 Mtetra
.934 .741 .619 r
.91257 .60152 .91336 .60311 .91499 .60034 .91389 .59603 Mtetra
.976 .671 .347 r
.91389 .59603 .91499 .60034 .91631 .5949 .8929 .39549 Mtetra
.575 .364 .557 r
.8929 .39549 .91631 .5949 .89559 .398 .89402 .38931 Mtetra
.621 .437 .612 r
.89402 .38931 .89559 .398 .89668 .39161 .89567 .38775 Mtetra
.636 .501 .681 r
.89567 .38775 .89668 .39161 .89818 .38875 .89739 .38689 Mtetra
.645 .606 .795 r
.89739 .38689 .89818 .38875 .89981 .38702 .89916 .38637 Mtetra
.659 .834 .967 r
.89916 .38637 .89981 .38702 .90155 .38624 .90093 .38578 Mtetra
.592 .864 .994 r
.90093 .38578 .90155 .38624 .90333 .3858 .9027 .38529 Mtetra
.583 .848 .995 r
.9027 .38529 .90333 .3858 .90513 .38553 .90449 .38485 Mtetra
.626 .815 .973 r
.90449 .38485 .90513 .38553 .90693 .38519 .90627 .38437 Mtetra
.641 .782 .949 r
.90627 .38437 .90693 .38519 .90872 .38485 .90805 .38389 Mtetra
.653 .751 .922 r
.90805 .38389 .90872 .38485 .91051 .38443 .90982 .38337 Mtetra
.671 .736 .899 r
.90982 .38337 .91051 .38443 .91227 .38376 .91159 .38279 Mtetra
.677 .758 .912 r
.91159 .38279 .91227 .38376 .91402 .38302 .91336 .38217 Mtetra
.679 .788 .932 r
.91336 .38217 .91402 .38302 .91578 .38228 .91513 .38154 Mtetra
.675 .816 .951 r
.91513 .38154 .91578 .38228 .91754 .38164 .9169 .38091 Mtetra
.673 .819 .953 r
.9169 .38091 .91754 .38164 .91931 .38103 .91867 .38029 Mtetra
.675 .817 .951 r
.91867 .38029 .91931 .38103 .92108 .38041 .92044 .37966 Mtetra
.765 .841 .91 r
.92044 .37966 .92108 .38041 .9228 .37938 .92216 .37862 Mtetra
.684 .816 .946 r
.92216 .37862 .9228 .37938 .92457 .37871 .92392 .37796 Mtetra
.446 .706 .977 r
.92392 .37796 .92457 .37871 .92642 .37874 .92578 .37801 Mtetra
.766 .321 0 r
.92578 .37801 .92642 .37874 .92879 .38284 .92818 .3823 Mtetra
.97 .655 .294 r
.92818 .3823 .92879 .38284 .95617 .58449 .95551 .58379 Mtetra
.819 .384 0 r
.95551 .58379 .95617 .58449 .95887 .59014 .95816 .58914 Mtetra
0 .427 .847 r
.34145 .75742 .34241 .75816 .34389 .75886 .34293 .75808 Mtetra
.594 .748 .95 r
.34293 .75808 .34389 .75886 .34543 .75849 .34446 .75782 Mtetra
.795 .802 .858 r
.34446 .75782 .34543 .75849 .34701 .75708 .34604 .75661 Mtetra
.921 .761 .665 r
.34604 .75661 .34701 .75708 .34879 .75184 .34781 .75162 Mtetra
.937 .687 .533 r
.34781 .75162 .34879 .75184 .35967 .56024 .35875 .55983 Mtetra
.929 .748 .636 r
.35875 .55983 .35967 .56024 .36139 .55447 .36049 .55366 Mtetra
.783 .765 .837 r
.36049 .55366 .36139 .55447 .36288 .55335 .36198 .55251 Mtetra
.645 .736 .916 r
.36198 .55251 .36288 .55335 .36433 .55297 .36344 .55212 Mtetra
.512 .69 .948 r
.36344 .55212 .36433 .55297 .36577 .55295 .36488 .55211 Mtetra
.747 .756 .86 r
.36488 .55211 .36577 .55295 .36725 .55207 .36636 .55122 Mtetra
.697 .747 .89 r
.36636 .55122 .36725 .55207 .36872 .55148 .36783 .55062 Mtetra
.486 .677 .949 r
.36783 .55062 .36872 .55148 .37016 .55153 .36927 .55067 Mtetra
.927 .546 .246 r
.36927 .55067 .37016 .55153 .37142 .55553 .37053 .55464 Mtetra
.939 .683 .522 r
.37053 .55464 .37142 .55553 .36427 .74653 .36333 .7457 Mtetra
.936 .581 .319 r
.36333 .7457 .36427 .74653 .36557 .7517 .36462 .75091 Mtetra
0 .339 .789 r
.36462 .75091 .36557 .7517 .36707 .75253 .36612 .75174 Mtetra
.618 .753 .943 r
.36612 .75174 .36707 .75253 .36862 .7522 .36767 .75141 Mtetra
.8 .78 .834 r
.36767 .75141 .36862 .7522 .37021 .75086 .36926 .75006 Mtetra
.906 .743 .669 r
.36926 .75006 .37021 .75086 .37195 .74613 .371 .74533 Mtetra
.939 .687 .529 r
.371 .74533 .37195 .74613 .38162 .55441 .38072 .55353 Mtetra
.914 .724 .632 r
.38072 .55353 .38162 .55441 .38334 .54788 .38245 .54702 Mtetra
.799 .759 .816 r
.38245 .54702 .38334 .54788 .38485 .54654 .38396 .54567 Mtetra
.652 .735 .91 r
.38396 .54567 .38485 .54654 .38632 .54613 .38543 .54526 Mtetra
.522 .69 .944 r
.38543 .54526 .38632 .54613 .38777 .54611 .38689 .54523 Mtetra
.733 .75 .866 r
.38689 .54523 .38777 .54611 .38926 .5453 .38838 .54442 Mtetra
.704 .744 .882 r
.38838 .54442 .38926 .5453 .39074 .54466 .38986 .54378 Mtetra
.527 .687 .94 r
.38986 .54378 .39074 .54466 .3922 .54465 .39132 .54374 Mtetra
.907 .498 .151 r
.39132 .54374 .3922 .54465 .39352 .5482 .39264 .5471 Mtetra
.942 .684 .516 r
.39264 .5471 .39352 .5482 .38761 .73948 .38669 .73805 Mtetra
.953 .604 .281 r
.38669 .73805 .38761 .73948 .38894 .74513 .38801 .74407 Mtetra
.211 .5 .905 r
.38801 .74407 .38894 .74513 .39046 .74574 .38953 .7447 Mtetra
.667 .714 .883 r
.38953 .7447 .39046 .74574 .39203 .74525 .3911 .74419 Mtetra
.739 .729 .842 r
.3911 .74419 .39203 .74525 .39362 .74432 .39269 .74323 Mtetra
.684 .711 .869 r
.39269 .74323 .39362 .74432 .39519 .7438 .39426 .74263 Mtetra
.657 .689 .868 r
.39426 .74263 .39519 .7438 .39676 .74336 .39583 .74217 Mtetra
.647 .68 .867 r
.39583 .74217 .39676 .74336 .39833 .74285 .3974 .74175 Mtetra
.62 .686 .891 r
.3974 .74175 .39833 .74285 .39991 .74206 .39897 .74145 Mtetra
.564 .786 .982 r
.39897 .74145 .39991 .74206 .4015 .74112 .40053 .74119 Mtetra
.198 .728 .79 r
.40053 .74119 .4015 .74112 .40309 .74018 .4021 .74093 Mtetra
.384 0 0 r
.4021 .74093 .40309 .74018 .40465 .74005 .40366 .74091 Mtetra
.322 0 0 r
.40366 .74091 .40465 .74005 .40621 .7399 .40522 .74069 Mtetra
0 0 0 r
.40522 .74069 .40621 .7399 .4078 .73909 .40681 .73995 Mtetra
.931 .966 .679 r
.40681 .73995 .4078 .73909 .40952 .73424 .40847 .73707 Mtetra
.99 .849 .484 r
.40847 .73707 .40952 .73424 .41722 .54247 .41032 .72822 Mtetra
0 0 .32 r
.41032 .72822 .41722 .54247 .41887 .5368 .41789 .53926 Mtetra
0 0 0 r
.41789 .53926 .41887 .5368 .4204 .53527 .41947 .53613 Mtetra
.513 .835 .533 r
.41947 .53613 .4204 .53527 .42189 .53481 .42099 .53467 Mtetra
.757 .943 .943 r
.42099 .53467 .42189 .53481 .42337 .53471 .42249 .53375 Mtetra
.699 .728 .872 r
.42249 .53375 .42337 .53471 .42486 .53437 .42399 .5331 Mtetra
.656 .662 .844 r
.42399 .5331 .42486 .53437 .42635 .53388 .42549 .53265 Mtetra
.633 .659 .858 r
.42549 .53265 .42635 .53388 .42785 .53338 .42698 .53231 Mtetra
.633 .687 .883 r
.42698 .53231 .42785 .53338 .42934 .53286 .42847 .53197 Mtetra
.635 .728 .915 r
.42847 .53197 .42934 .53286 .43084 .53236 .42996 .53162 Mtetra
.637 .765 .94 r
.42996 .53162 .43084 .53236 .43234 .53193 .43146 .53123 Mtetra
.675 .785 .932 r
.43146 .53123 .43234 .53193 .43383 .53175 .43296 .53071 Mtetra
.688 .712 .867 r
.43296 .53071 .43383 .53175 .43531 .53173 .43446 .53012 Mtetra
.669 .623 .795 r
.43446 .53012 .43531 .53173 .4368 .53174 .43596 .52952 Mtetra
.669 .574 .74 r
.43596 .52952 .4368 .53174 .4383 .53113 .43747 .52875 Mtetra
.653 .557 .734 r
.43747 .52875 .4383 .53113 .43981 .53041 .43898 .5281 Mtetra
.603 .533 .748 r
.43898 .5281 .43981 .53041 .44131 .53025 .44047 .52789 Mtetra
.194 .276 .721 r
.44047 .52789 .44131 .53025 .44273 .53325 .44193 .5295 Mtetra
.797 .527 0 r
.44193 .5295 .44273 .53325 .43962 .7244 .44325 .53664 Mtetra
0 0 .348 r
.44325 .53664 .43962 .7244 .44106 .73036 .44023 .72582 Mtetra
.37 .305 .653 r
.44023 .72582 .44106 .73036 .44262 .73147 .44177 .72783 Mtetra
.6 .482 .691 r
.44177 .72783 .44262 .73147 .44422 .7312 .44336 .72755 Mtetra
.648 .513 .685 r
.44336 .72755 .44422 .7312 .44582 .73051 .44497 .72663 Mtetra
.64 .503 .679 r
.44497 .72663 .44582 .73051 .44742 .72992 .44657 .72576 Mtetra
.62 .483 .674 r
.44657 .72576 .44742 .72992 .44902 .72945 .44818 .72515 Mtetra
.601 .468 .672 r
.44818 .72515 .44902 .72945 .45062 .72897 .44977 .72479 Mtetra
.538 .428 .677 r
.44977 .72479 .45062 .72897 .45222 .72847 .45136 .72521 Mtetra
.487 .424 .711 r
.45136 .72521 .45222 .72847 .45383 .72796 .45293 .72594 Mtetra
.465 .488 .798 r
.45293 .72594 .45383 .72796 .45543 .72745 .45452 .72645 Mtetra
.531 .677 .931 r
.45452 .72645 .45543 .72745 .45704 .72702 .45611 .72642 Mtetra
.62 .81 .973 r
.45611 .72642 .45704 .72702 .45864 .72661 .45772 .72601 Mtetra
.654 .819 .963 r
.45772 .72601 .45864 .72661 .46025 .72614 .45933 .7255 Mtetra
.624 .802 .968 r
.45933 .7255 .46025 .72614 .46186 .72542 .46093 .72509 Mtetra
.5 .845 .996 r
.46093 .72509 .46186 .72542 .46347 .72448 .46254 .72478 Mtetra
0 0 0 r
.46254 .72478 .46347 .72448 .46509 .72352 .46415 .72447 Mtetra
.284 0 0 r
.46415 .72447 .46509 .72352 .4667 .72281 .46576 .72411 Mtetra
.349 0 .09 r
.46576 .72411 .4667 .72281 .46831 .72237 .46737 .7237 Mtetra
.348 0 .096 r
.46737 .7237 .46831 .72237 .46992 .72202 .46898 .72327 Mtetra
.332 0 .067 r
.46898 .72327 .46992 .72202 .47153 .72164 .47059 .72284 Mtetra
.32 0 .046 r
.47059 .72284 .47153 .72164 .47315 .72122 .47221 .72241 Mtetra
.317 0 .042 r
.47221 .72241 .47315 .72122 .47476 .72079 .47382 .72197 Mtetra
.314 0 .038 r
.47382 .72197 .47476 .72079 .47637 .72036 .47544 .72153 Mtetra
.311 0 .035 r
.47544 .72153 .47637 .72036 .47799 .71992 .47705 .72109 Mtetra
.31 0 .034 r
.47705 .72109 .47799 .71992 .47961 .71947 .47867 .72064 Mtetra
.308 0 .033 r
.47867 .72064 .47961 .71947 .48122 .71902 .48029 .72019 Mtetra
.307 0 .032 r
.48029 .72019 .48122 .71902 .48284 .71857 .48191 .71974 Mtetra
.306 0 .032 r
.48191 .71974 .48284 .71857 .48446 .71811 .48353 .71928 Mtetra
.307 0 .033 r
.48353 .71928 .48446 .71811 .48608 .71765 .48516 .71883 Mtetra
.307 0 .035 r
.48516 .71883 .48608 .71765 .48771 .71718 .48678 .71837 Mtetra
.302 0 .034 r
.48678 .71837 .48771 .71718 .48933 .71671 .4884 .71789 Mtetra
.281 0 .02 r
.4884 .71789 .48933 .71671 .49095 .71623 .49003 .71736 Mtetra
.248 0 0 r
.49003 .71736 .49095 .71623 .49258 .71574 .49165 .71679 Mtetra
.216 0 0 r
.49165 .71679 .49258 .71574 .4942 .71526 .49328 .71621 Mtetra
.201 0 0 r
.49328 .71621 .4942 .71526 .49583 .71478 .49491 .71567 Mtetra
.207 0 0 r
.49491 .71567 .49583 .71478 .49745 .7143 .49654 .71519 Mtetra
.215 0 0 r
.49654 .71519 .49745 .7143 .49908 .71383 .49817 .71473 Mtetra
.221 0 0 r
.49817 .71473 .49908 .71383 .50071 .71337 .4998 .71427 Mtetra
.223 0 0 r
.4998 .71427 .50071 .71337 .50234 .71292 .50143 .71381 Mtetra
.226 0 0 r
.50143 .71381 .50234 .71292 .50397 .71247 .50306 .71336 Mtetra
.231 0 0 r
.50306 .71336 .50397 .71247 .5056 .71205 .5047 .71293 Mtetra
.233 0 0 r
.5047 .71293 .5056 .71205 .50724 .71163 .50633 .7125 Mtetra
.228 0 0 r
.50633 .7125 .50724 .71163 .50887 .71121 .50797 .71207 Mtetra
.306 0 0 r
.50797 .71207 .50887 .71121 .5105 .71104 .5096 .71181 Mtetra
.326 0 0 r
.5096 .71181 .5105 .71104 .51214 .711 .51124 .71165 Mtetra
.035 0 0 r
.51124 .71165 .51214 .711 .51378 .71039 .51288 .71109 Mtetra
.752 .962 .67 r
.51288 .71109 .51378 .71039 .51542 .70769 .51452 .70917 Mtetra
.984 .882 .531 r
.51452 .70917 .51542 .70769 .51748 .51924 .51617 .70339 Mtetra
0 0 .358 r
.51617 .70339 .51748 .51924 .51905 .50684 .5182 .51047 Mtetra
0 0 .069 r
.5182 .51047 .51905 .50684 .5206 .50411 .51975 .50585 Mtetra
.294 0 .163 r
.51975 .50585 .5206 .50411 .52215 .50338 .5213 .50499 Mtetra
.466 .084 .23 r
.5213 .50499 .52215 .50338 .52369 .50312 .52285 .50484 Mtetra
.495 .121 .26 r
.52285 .50484 .52369 .50312 .52524 .50292 .5244 .5048 Mtetra
.427 .067 .248 r
.5244 .5048 .52524 .50292 .52679 .50248 .52595 .50438 Mtetra
.433 .074 .255 r
.52595 .50438 .52679 .50248 .52834 .50204 .52751 .50398 Mtetra
.452 .095 .268 r
.52751 .50398 .52834 .50204 .52989 .50161 .52906 .50365 Mtetra
.476 .125 .291 r
.52906 .50365 .52989 .50161 .53145 .50117 .53061 .50342 Mtetra
.449 .11 .299 r
.53061 .50342 .53145 .50117 .533 .50074 .53217 .50297 Mtetra
.322 0 .242 r
.53217 .50297 .533 .50074 .53455 .50031 .53372 .50191 Mtetra
0 0 0 r
.53372 .50191 .53455 .50031 .53611 .4999 .53528 .50025 Mtetra
.771 .995 .795 r
.53528 .50025 .53611 .4999 .53767 .49949 .53683 .49879 Mtetra
.774 .81 .881 r
.53683 .49879 .53767 .49949 .53922 .49904 .53839 .49776 Mtetra
.656 .665 .847 r
.53839 .49776 .53922 .49904 .54078 .49857 .53994 .49729 Mtetra
.627 .654 .857 r
.53994 .49729 .54078 .49857 .54234 .49807 .5415 .49696 Mtetra
.655 .696 .876 r
.5415 .49696 .54234 .49807 .5439 .49737 .54306 .49651 Mtetra
.728 .766 .883 r
.54306 .49651 .5439 .49737 .54545 .49642 .54462 .49572 Mtetra
.65 .787 .947 r
.54462 .49572 .54545 .49642 .54702 .49592 .54619 .49526 Mtetra
.033 .481 .881 r
.54619 .49526 .54702 .49592 .54859 .4968 .54776 .49586 Mtetra
.91 .507 .131 r
.54776 .49586 .54859 .4968 .55022 .5049 .54935 .50016 Mtetra
.965 .691 .465 r
.54935 .50016 .55022 .5049 .55334 .69751 .55243 .69226 Mtetra
.124 .122 .583 r
.55243 .69226 .55334 .69751 .55503 .70045 .55413 .6966 Mtetra
.587 .471 .688 r
.55413 .6966 .55503 .70045 .5567 .70043 .5558 .69645 Mtetra
.63 .495 .68 r
.5558 .69645 .5567 .70043 .55836 .69973 .55746 .69571 Mtetra
.604 .477 .681 r
.55746 .69571 .55836 .69973 .56002 .69872 .55912 .69534 Mtetra
.474 .413 .709 r
.55912 .69534 .56002 .69872 .56169 .69779 .5608 .69623 Mtetra
.365 .491 .853 r
.5608 .69623 .56169 .69779 .56335 .69678 .56248 .69691 Mtetra
.297 0 0 r
.56248 .69691 .56335 .69678 .56501 .69589 .56416 .69718 Mtetra
.378 0 .106 r
.56416 .69718 .56501 .69589 .56668 .69537 .56583 .69685 Mtetra
.359 0 .136 r
.56583 .69685 .56668 .69537 .56835 .69496 .5675 .69635 Mtetra
.328 0 .1 r
.5675 .69635 .56835 .69496 .57002 .69459 .56917 .6958 Mtetra
.324 0 .056 r
.56917 .6958 .57002 .69459 .57169 .69415 .57084 .69535 Mtetra
.32 0 .051 r
.57084 .69535 .57169 .69415 .57336 .69371 .57252 .69489 Mtetra
.317 0 .044 r
.57252 .69489 .57336 .69371 .57504 .69326 .57419 .69444 Mtetra
.314 0 .039 r
.57419 .69444 .57504 .69326 .57671 .69282 .57587 .69398 Mtetra
.312 0 .035 r
.57587 .69398 .57671 .69282 .57839 .69236 .57755 .69352 Mtetra
.31 0 .033 r
.57755 .69352 .57839 .69236 .58006 .69191 .57923 .69306 Mtetra
.309 0 .031 r
.57923 .69306 .58006 .69191 .58174 .69145 .58091 .69261 Mtetra
.307 0 .029 r
.58091 .69261 .58174 .69145 .58342 .69099 .58259 .69214 Mtetra
.58259 .69214 .58342 .69099 .5851 .69053 .58427 .69168 Mtetra
.306 0 .029 r
.58427 .69168 .5851 .69053 .58678 .69006 .58595 .69122 Mtetra
.307 0 .031 r
.58595 .69122 .58678 .69006 .58846 .68959 .58763 .69075 Mtetra
.308 0 .033 r
.58763 .69075 .58846 .68959 .59015 .6891 .58932 .69028 Mtetra
.316 0 .043 r
.58932 .69028 .59015 .6891 .59183 .68854 .591 .68982 Mtetra
.331 0 .077 r
.591 .68982 .59183 .68854 .59351 .68805 .59269 .68934 Mtetra
.328 0 .077 r
.59269 .68934 .59351 .68805 .5952 .68774 .59438 .68885 Mtetra
.292 0 .009 r
.59438 .68885 .5952 .68774 .5969 .68779 .59606 .68837 Mtetra
.001 0 0 r
.59606 .68837 .5969 .68779 .5986 .68785 .59775 .68779 Mtetra
.624 .947 .943 r
.59775 .68779 .5986 .68785 .6003 .68781 .59943 .687 Mtetra
.804 .805 .852 r
.59943 .687 .6003 .68781 .60199 .68748 .60111 .68564 Mtetra
.755 .656 .753 r
.60111 .68564 .60199 .68748 .60368 .68705 .60277 .68406 Mtetra
.701 .568 .701 r
.60277 .68406 .60368 .68705 .60537 .68661 .60444 .68254 Mtetra
.582 .463 .682 r
.60444 .68254 .60537 .68661 .60708 .68649 .60614 .68245 Mtetra
.602 .476 .682 r
.60614 .68245 .60708 .68649 .60877 .68601 .60784 .6821 Mtetra
.674 .525 .675 r
.60784 .6821 .60877 .68601 .61045 .68474 .60951 .68063 Mtetra
.897 .656 .565 r
.60951 .68063 .61045 .68474 .61203 .67986 .61085 .66547 Mtetra
.946 .672 .487 r
.61085 .66547 .61203 .67986 .60879 .48487 .60786 .47899 Mtetra
.714 .52 .626 r
.60786 .47899 .60879 .48487 .61023 .47791 .60938 .47543 Mtetra
.666 .563 .729 r
.60938 .47543 .61023 .47791 .6118 .47632 .61097 .47459 Mtetra
.622 .596 .803 r
.61097 .47459 .6118 .47632 .61339 .47546 .61257 .47426 Mtetra
.57 .648 .887 r
.61257 .47426 .61339 .47546 .61499 .47497 .61419 .47416 Mtetra
.708 .782 .91 r
.61419 .47416 .61499 .47497 .61659 .47443 .61578 .47347 Mtetra
.691 .742 .891 r
.61578 .47347 .61659 .47443 .61819 .47398 .61738 .47284 Mtetra
.653 .693 .875 r
.61738 .47284 .61819 .47398 .61979 .47356 .61898 .47239 Mtetra
.582 .658 .889 r
.61898 .47239 .61979 .47356 .62139 .47263 .6206 .47224 Mtetra
.056 .568 .879 r
.6206 .47224 .62139 .47263 .62299 .47201 .62223 .47257 Mtetra
.701 .233 .137 r
.62223 .47257 .62299 .47201 .62461 .47199 .62389 .47389 Mtetra
.919 .609 .44 r
.62389 .47389 .62461 .47199 .62633 .47525 .62598 .48912 Mtetra
.944 .662 .474 r
.62598 .48912 .62633 .47525 .634 .66868 .63334 .67403 Mtetra
.679 .389 .475 r
.63334 .67403 .634 .66868 .63595 .67606 .63516 .67699 Mtetra
.411 0 .025 r
.63516 .67699 .63595 .67606 .63771 .67688 .63689 .67696 Mtetra
.447 .881 .863 r
.63689 .67696 .63771 .67688 .63943 .67685 .6386 .67631 Mtetra
.753 .871 .933 r
.6386 .67631 .63943 .67685 .64115 .67637 .6403 .67535 Mtetra
.482 .66 .94 r
.6403 .67535 .64115 .67637 .64288 .67634 .64203 .67545 Mtetra
.585 .734 .946 r
.64203 .67545 .64288 .67634 .6446 .6759 .64376 .6752 Mtetra
.76 .829 .905 r
.64376 .6752 .6446 .6759 .64629 .67476 .64546 .67419 Mtetra
.957 .783 .626 r
.64546 .67419 .64629 .67476 .64786 .67014 .647 .66856 Mtetra
.967 .689 .454 r
.647 .66856 .64786 .67014 .64263 .47515 .64171 .47067 Mtetra
.798 .589 .62 r
.64171 .47067 .64263 .47515 .644 .46752 .64315 .465 Mtetra
.689 .575 .722 r
.64315 .465 .644 .46752 .64557 .4658 .64474 .46388 Mtetra
.618 .576 .785 r
.64474 .46388 .64557 .4658 .64718 .46495 .64637 .46357 Mtetra
.532 .598 .865 r
.64637 .46357 .64718 .46495 .6488 .46449 .64801 .46365 Mtetra
.661 .763 .925 r
.64801 .46365 .6488 .46449 .65042 .464 .64963 .46315 Mtetra
.662 .76 .923 r
.64963 .46315 .65042 .464 .65204 .4636 .65125 .46264 Mtetra
.628 .725 .917 r
.65125 .46264 .65204 .4636 .65367 .46324 .65288 .46228 Mtetra
.57 .7 .929 r
.65288 .46228 .65367 .46324 .65528 .46239 .65452 .46212 Mtetra
0 .545 .818 r
.65452 .46212 .65528 .46239 .6569 .46176 .65617 .46242 Mtetra
.689 .223 .141 r
.65617 .46242 .6569 .46176 .65854 .46172 .65787 .46367 Mtetra
.965 .679 .439 r
.65787 .46367 .65854 .46172 .66036 .46589 .66729 .65335 Mtetra
.582 .366 .553 r
.66729 .65335 .66036 .46589 .67018 .66178 .66952 .66499 Mtetra
.689 .365 .421 r
.66952 .66499 .67018 .66178 .67212 .6664 .67136 .66723 Mtetra
.676 .89 .529 r
.67136 .66723 .67212 .6664 .67373 .6629 .67303 .66502 Mtetra
.921 .823 .362 r
.67303 .66502 .67373 .6629 .66702 .46693 .67447 .6578 Mtetra
.03 0 .427 r
.67447 .6578 .66702 .46693 .66834 .45927 .6677 .4618 Mtetra
0 0 .09 r
.6677 .4618 .66834 .45927 .66993 .45778 .66922 .45854 Mtetra
0 0 0 r
.66922 .45854 .66993 .45778 .67156 .4573 .6708 .45699 Mtetra
.76 .929 .943 r
.6708 .45699 .67156 .4573 .67321 .45719 .67242 .45601 Mtetra
.677 .698 .863 r
.67242 .45601 .67321 .45719 .67485 .45679 .67405 .45542 Mtetra
.633 .65 .848 r
.67405 .45542 .67485 .45679 .67649 .4563 .67569 .45504 Mtetra
.613 .659 .871 r
.67569 .45504 .67649 .4563 .67812 .45579 .67734 .45477 Mtetra
.653 .72 .897 r
.67734 .45477 .67812 .45579 .67975 .45514 .67898 .4543 Mtetra
.673 .769 .923 r
.67898 .4543 .67975 .45514 .68138 .45448 .68061 .45375 Mtetra
.681 .798 .938 r
.68061 .45375 .68138 .45448 .68302 .45391 .68225 .45315 Mtetra
.774 .813 .884 r
.68225 .45315 .68302 .45391 .68466 .45333 .68386 .4521 Mtetra
.716 .706 .839 r
.68386 .4521 .68466 .45333 .68631 .45304 .68549 .45125 Mtetra
.604 .583 .803 r
.68549 .45125 .68631 .45304 .68799 .4534 .68715 .45103 Mtetra
0 .068 .618 r
.68715 .45103 .68799 .4534 .68987 .45747 .68896 .45402 Mtetra
.974 .685 .413 r
.68896 .45402 .68987 .45747 .70149 .65337 .70059 .65071 Mtetra
.764 .44 0 r
.70059 .65071 .70149 .65337 .70353 .65845 .70272 .65778 Mtetra
0 .381 .809 r
.70272 .65778 .70353 .65845 .70535 .65925 .70455 .65867 Mtetra
.6 .829 .987 r
.70455 .65867 .70535 .65925 .70711 .6589 .7063 .65824 Mtetra
.738 .846 .931 r
.7063 .65824 .70711 .6589 .70885 .65806 .70804 .65735 Mtetra
.576 .783 .977 r
.70804 .65735 .70885 .65806 .7106 .65748 .70981 .65704 Mtetra
.506 .831 .999 r
.70981 .65704 .7106 .65748 .71234 .65672 .71158 .65674 Mtetra
.55 .93 .892 r
.71158 .65674 .71234 .65672 .71405 .65526 .71332 .65593 Mtetra
.872 .95 .597 r
.71332 .65593 .71405 .65526 .71555 .65011 .71495 .65304 Mtetra
.824 .745 .223 r
.71495 .65304 .71555 .65011 .7064 .45278 .71628 .64473 Mtetra
.06 0 .443 r
.71628 .64473 .7064 .45278 .70776 .44686 .70719 .44956 Mtetra
0 0 .132 r
.70719 .44956 .70776 .44686 .70934 .44519 .70868 .4461 Mtetra
0 0 0 r
.70868 .4461 .70934 .44519 .711 .44466 .71028 .44452 Mtetra
.729 .968 .935 r
.71028 .44452 .711 .44466 .71268 .44452 .71191 .44352 Mtetra
.688 .742 .892 r
.71191 .44352 .71268 .44452 .71434 .44408 .71356 .44289 Mtetra
.642 .685 .875 r
.71356 .44289 .71434 .44408 .71599 .4435 .71522 .44247 Mtetra
.619 .708 .909 r
.71522 .44247 .71599 .4435 .71765 .44299 .71689 .44214 Mtetra
.662 .767 .928 r
.71689 .44214 .71765 .44299 .71933 .44275 .71855 .44163 Mtetra
.686 .715 .871 r
.71855 .44163 .71933 .44275 .72102 .44269 .72021 .44099 Mtetra
.668 .626 .798 r
.72021 .44099 .72102 .44269 .72271 .44266 .72186 .44034 Mtetra
.67 .577 .742 r
.72186 .44034 .72271 .44266 .72436 .44199 .72351 .4395 Mtetra
.654 .559 .735 r
.72351 .4395 .72436 .44199 .72601 .44119 .72516 .43877 Mtetra
.607 .536 .749 r
.72516 .43877 .72601 .44119 .72769 .44097 .72684 .4385 Mtetra
.329 .363 .746 r
.72684 .4385 .72769 .44097 .72958 .44388 .72863 .43994 Mtetra
0 0 .451 r
.72863 .43994 .72958 .44388 .74368 .6402 .73072 .44611 Mtetra
.081 .004 .46 r
.73072 .44611 .74368 .6402 .74589 .64654 .74483 .64153 Mtetra
.317 .27 .646 r
.74483 .64153 .74589 .64654 .74778 .64772 .74684 .64461 Mtetra
.487 .437 .728 r
.74684 .64461 .74778 .64772 .74957 .64741 .7487 .64538 Mtetra
.55 .544 .801 r
.7487 .64538 .74957 .64741 .75133 .6466 .75052 .64549 Mtetra
.519 .663 .926 r
.75052 .64549 .75133 .6466 .7531 .64593 .75234 .64551 Mtetra
.456 .814 .996 r
.75234 .64551 .7531 .64593 .75488 .64523 .75414 .64528 Mtetra
.511 .914 .868 r
.75414 .64528 .75488 .64523 .75661 .64392 .75591 .64449 Mtetra
.821 .956 .618 r
.75591 .64449 .75661 .64392 .75815 .63983 .75756 .64201 Mtetra
.802 .761 .246 r
.75756 .64201 .75815 .63983 .7466 .44286 .75895 .63556 Mtetra
.077 0 .454 r
.75895 .63556 .7466 .44286 .74778 .43506 .74733 .4385 Mtetra
0 0 .205 r
.74733 .4385 .74778 .43506 .74935 .43295 .74874 .43408 Mtetra
0 0 0 r
.74874 .43408 .74935 .43295 .75102 .43235 .75033 .43233 Mtetra
.704 .981 .897 r
.75033 .43233 .75102 .43235 .75273 .4322 .75198 .43126 Mtetra
.696 .759 .901 r
.75198 .43126 .75273 .4322 .75443 .43194 .75365 .43059 Mtetra
.641 .66 .853 r
.75365 .43059 .75443 .43194 .75611 .43146 .75534 .43016 Mtetra
.617 .657 .867 r
.75534 .43016 .75611 .43146 .75779 .43096 .75704 .42986 Mtetra
.638 .704 .894 r
.75704 .42986 .75779 .43096 .75947 .43034 .75873 .42945 Mtetra
.67 .763 .92 r
.75873 .42945 .75947 .43034 .76114 .42966 .76041 .42889 Mtetra
.679 .798 .938 r
.76041 .42889 .76114 .42966 .76282 .42904 .76209 .42829 Mtetra
.754 .822 .905 r
.76209 .42829 .76282 .42904 .7645 .42844 .76375 .42734 Mtetra
.743 .743 .852 r
.76375 .42734 .7645 .42844 .7662 .42802 .7654 .42635 Mtetra
.64 .618 .812 r
.7654 .42635 .7662 .42802 .76794 .42815 .7671 .42591 Mtetra
.249 .331 .753 r
.7671 .42591 .76794 .42815 .76985 .43056 .76895 .42757 Mtetra
.976 .678 .375 r
.76895 .42757 .76985 .43056 .78639 .62585 .78485 .61494 Mtetra
0 0 .36 r
.78485 .61494 .78639 .62585 .78885 .63398 .78807 .63308 Mtetra
0 .087 .606 r
.78807 .63308 .78885 .63398 .79082 .63561 .79006 .63495 Mtetra
.581 .805 .985 r
.79006 .63495 .79082 .63561 .79265 .63542 .79188 .63459 Mtetra
.737 .812 .911 r
.79188 .63459 .79265 .63542 .79444 .63467 .79365 .63367 Mtetra
.647 .742 .919 r
.79365 .63367 .79444 .63467 .79623 .63397 .79547 .63318 Mtetra
.48 .723 .977 r
.79547 .63318 .79623 .63397 .79804 .63334 .79732 .63315 Mtetra
.524 .9 .96 r
.79732 .63315 .79804 .63334 .79979 .63214 .79912 .63257 Mtetra
.882 .967 .643 r
.79912 .63257 .79979 .63214 .80137 .62874 .80076 .62989 Mtetra
.995 .767 .41 r
.80076 .62989 .80137 .62874 .78751 .43384 .80151 .61616 Mtetra
.07 0 .456 r
.80151 .61616 .78751 .43384 .78838 .423 .78764 .42203 Mtetra
.906 .79 .721 r
.78764 .42203 .78838 .423 .78991 .42041 .78915 .41911 Mtetra
.684 .689 .849 r
.78915 .41911 .78991 .42041 .7916 .41967 .79084 .41844 Mtetra
.574 .651 .888 r
.79084 .41844 .7916 .41967 .79332 .4194 .79258 .41831 Mtetra
.621 .702 .903 r
.79258 .41831 .79332 .4194 .79503 .41886 .7943 .41797 Mtetra
.72 .783 .902 r
.7943 .41797 .79503 .41886 .7967 .41793 .79598 .41718 Mtetra
.625 .784 .958 r
.79598 .41718 .7967 .41793 .79841 .4175 .7977 .41676 Mtetra
.006 .426 .861 r
.7977 .41676 .79841 .4175 .80028 .41887 .79953 .41764 Mtetra
.781 .374 0 r
.79953 .41764 .80028 .41887 .80319 .43238 .80169 .42237 Mtetra
.978 .679 .33 r
.80169 .42237 .80319 .43238 .82149 .62451 .82033 .61907 Mtetra
.25 .219 .627 r
.82033 .61907 .82149 .62451 .82356 .62681 .82256 .62326 Mtetra
.496 .427 .709 r
.82256 .62326 .82356 .62681 .82541 .62661 .82451 .62408 Mtetra
.557 .513 .762 r
.82451 .62408 .82541 .62661 .82721 .62576 .82639 .62421 Mtetra
.546 .6 .858 r
.82639 .62421 .82721 .62576 .82901 .6249 .82827 .62425 Mtetra
.392 .718 .988 r
.82827 .62425 .82901 .6249 .83084 .62435 .83016 .62432 Mtetra
.401 .856 .875 r
.83016 .62432 .83084 .62435 .83262 .62329 .83198 .62375 Mtetra
.789 .954 .625 r
.83198 .62375 .83262 .62329 .83425 .62046 .83366 .62145 Mtetra
.99 .799 .413 r
.83366 .62145 .83425 .62046 .83456 .60313 .83469 .61203 Mtetra
.98 .687 .342 r
.83469 .61203 .83456 .60313 .81925 .41415 .81853 .41324 Mtetra
.932 .797 .689 r
.81853 .41324 .81925 .41415 .82074 .41113 .81998 .40977 Mtetra
.686 .682 .84 r
.81998 .40977 .82074 .41113 .82244 .41039 .82169 .40907 Mtetra
.568 .633 .876 r
.82169 .40907 .82244 .41039 .82419 .41019 .82345 .40898 Mtetra
.542 .641 .898 r
.82345 .40898 .82419 .41019 .82596 .41006 .82523 .40897 Mtetra
.646 .713 .897 r
.82523 .40897 .82596 .41006 .82769 .40959 .82696 .40852 Mtetra
.655 .721 .897 r
.82696 .40852 .82769 .40959 .82941 .40909 .82869 .40802 Mtetra
.676 .729 .89 r
.82869 .40802 .82941 .40909 .83114 .40853 .83041 .40742 Mtetra
.698 .73 .875 r
.83041 .40742 .83114 .40853 .83286 .40789 .83212 .4067 Mtetra
.679 .707 .869 r
.83212 .4067 .83286 .40789 .83457 .40723 .83384 .40607 Mtetra
.646 .7 .885 r
.83384 .40607 .83457 .40723 .83627 .40637 .83558 .40561 Mtetra
.54 .748 .972 r
.83558 .40561 .83627 .40637 .83795 .40529 .83734 .40544 Mtetra
.339 0 0 r
.83734 .40544 .83795 .40529 .83967 .4047 .83917 .40584 Mtetra
.758 .334 .244 r
.83917 .40584 .83967 .4047 .84154 .40555 .84118 .40813 Mtetra
.973 .667 .358 r
.84118 .40813 .84154 .40555 .84414 .41375 .86224 .60391 Mtetra
.576 .361 .552 r
.86224 .60391 .84414 .41375 .86556 .61158 .86489 .61145 Mtetra
.706 .169 0 r
.86489 .61145 .86556 .61158 .86777 .61465 .86701 .61358 Mtetra
.426 .623 .935 r
.86701 .61358 .86777 .61465 .86969 .61481 .86895 .61387 Mtetra
.677 .773 .923 r
.86895 .61387 .86969 .61481 .87152 .61398 .87079 .61322 Mtetra
.891 .853 .799 r
.87079 .61322 .87152 .61398 .8732 .61177 .87248 .61103 Mtetra
.985 .766 .526 r
.87248 .61103 .8732 .61177 .87447 .60539 .87352 .60247 Mtetra
.976 .676 .363 r
.87352 .60247 .87447 .60539 .85589 .40557 .85493 .40213 Mtetra
.796 .605 .643 r
.85493 .40213 .85589 .40557 .85718 .40061 .85632 .39819 Mtetra
.663 .571 .741 r
.85632 .39819 .85718 .40061 .85883 .3992 .85804 .39737 Mtetra
.598 .582 .806 r
.85804 .39737 .85883 .3992 .86055 .39844 .85982 .39717 Mtetra
.548 .634 .888 r
.85982 .39717 .86055 .39844 .8623 .39797 .86162 .39716 Mtetra
.644 .783 .948 r
.86162 .39716 .8623 .39797 .86405 .39746 .86337 .39667 Mtetra
.653 .791 .948 r
.86337 .39667 .86405 .39746 .86581 .39704 .86512 .39614 Mtetra
.696 .78 .916 r
.86512 .39614 .86581 .39704 .86756 .39652 .86685 .39545 Mtetra
.758 .763 .856 r
.86685 .39545 .86756 .39652 .86927 .39561 .86854 .39436 Mtetra
.68 .702 .864 r
.86854 .39436 .86927 .39561 .87102 .39505 .87028 .39371 Mtetra
.408 .545 .881 r
.87028 .39371 .87102 .39505 .87288 .39549 .87215 .39424 Mtetra
.834 .444 0 r
.87215 .39424 .87288 .39549 .8752 .40025 .87468 .40087 Mtetra
.974 .664 .332 r
.87468 .40087 .8752 .40025 .89878 .59936 .89833 .60101 Mtetra
.794 .397 .303 r
.89833 .60101 .89878 .59936 .9012 .60389 .90065 .60454 Mtetra
.338 0 0 r
.90065 .60454 .9012 .60389 .90319 .60439 .90258 .6045 Mtetra
.415 .859 .783 r
.90258 .6045 .90319 .60439 .90511 .60417 .90443 .60368 Mtetra
.794 .922 .922 r
.90443 .60368 .90511 .60417 .90699 .60371 .90623 .60243 Mtetra
.725 .73 .854 r
.90623 .60243 .90699 .60371 .90892 .60362 .90806 .60146 Mtetra
.735 .637 .749 r
.90806 .60146 .90892 .60362 .9108 .60306 .90983 .59994 Mtetra
.775 .609 .674 r
.90983 .59994 .9108 .60306 .91257 .60152 .91143 .59695 Mtetra
.976 .671 .35 r
.91143 .59695 .91257 .60152 .91389 .59603 .8912 .40177 Mtetra
.584 .37 .557 r
.8912 .40177 .91389 .59603 .8929 .39549 .89169 .38998 Mtetra
.711 .52 .629 r
.89169 .38998 .8929 .39549 .89402 .38931 .89315 .38677 Mtetra
.66 .564 .735 r
.89315 .38677 .89402 .38931 .89567 .38775 .89488 .38595 Mtetra
.616 .596 .808 r
.89488 .38595 .89567 .38775 .89739 .38689 .89668 .38563 Mtetra
.573 .65 .888 r
.89668 .38563 .89739 .38689 .89916 .38637 .89849 .38551 Mtetra
.673 .783 .932 r
.89849 .38551 .89916 .38637 .90093 .38578 .90026 .3849 Mtetra
.68 .782 .928 r
.90026 .3849 .90093 .38578 .9027 .38529 .90202 .38427 Mtetra
.681 .75 .903 r
.90202 .38427 .9027 .38529 .90449 .38485 .90378 .38364 Mtetra
.683 .712 .87 r
.90378 .38364 .90449 .38485 .90627 .38437 .90554 .38297 Mtetra
.66 .67 .848 r
.90554 .38297 .90627 .38437 .90805 .38389 .90731 .38241 Mtetra
.624 .641 .847 r
.90731 .38241 .90805 .38389 .90982 .38337 .9091 .38205 Mtetra
.476 .587 .886 r
.9091 .38205 .90982 .38337 .91159 .38279 .91098 .38233 Mtetra
.034 .527 .879 r
.91098 .38233 .91159 .38279 .91336 .38217 .91289 .38287 Mtetra
.538 .032 0 r
.91289 .38287 .91336 .38217 .91513 .38154 .91481 .38347 Mtetra
.449 .091 .264 r
.91481 .38347 .91513 .38154 .9169 .38091 .91661 .38309 Mtetra
.417 .081 .286 r
.91661 .38309 .9169 .38091 .91867 .38029 .91837 .38238 Mtetra
.385 .05 .269 r
.91837 .38238 .91867 .38029 .92044 .37966 .92011 .38151 Mtetra
.296 0 .216 r
.92011 .38151 .92044 .37966 .92216 .37862 .92182 .38032 Mtetra
.373 .008 .21 r
.92182 .38032 .92216 .37862 .92392 .37796 .92358 .37962 Mtetra
.532 .14 .245 r
.92358 .37962 .92392 .37796 .92578 .37801 .92547 .37987 Mtetra
.902 .532 .324 r
.92547 .37987 .92578 .37801 .92818 .3823 .92846 .38893 Mtetra
.97 .653 .326 r
.92846 .38893 .92818 .3823 .95551 .58379 .95505 .58477 Mtetra
.813 .374 .198 r
.95505 .58477 .95551 .58379 .95816 .58914 .95746 .58821 Mtetra
.067 .506 .896 r
.34048 .75671 .34145 .75742 .34293 .75808 .34197 .75723 Mtetra
.568 .723 .947 r
.34197 .75723 .34293 .75808 .34446 .75782 .3435 .75706 Mtetra
.764 .785 .87 r
.3435 .75706 .34446 .75782 .34604 .75661 .34507 .75605 Mtetra
.916 .757 .669 r
.34507 .75605 .34604 .75661 .34781 .75162 .34683 .75124 Mtetra
.937 .687 .533 r
.34683 .75124 .34781 .75162 .35875 .55983 .35783 .55938 Mtetra
.928 .743 .632 r
.35783 .55938 .35875 .55983 .36049 .55366 .35959 .55285 Mtetra
.786 .766 .834 r
.35959 .55285 .36049 .55366 .36198 .55251 .36108 .55167 Mtetra
.647 .738 .916 r
.36108 .55167 .36198 .55251 .36344 .55212 .36254 .55128 Mtetra
.513 .691 .949 r
.36254 .55128 .36344 .55212 .36488 .55211 .36398 .55126 Mtetra
.748 .756 .859 r
.36398 .55126 .36488 .55211 .36636 .55122 .36546 .55036 Mtetra
.698 .746 .889 r
.36546 .55036 .36636 .55122 .36783 .55062 .36693 .54976 Mtetra
.489 .677 .948 r
.36693 .54976 .36783 .55062 .36927 .55067 .36837 .5498 Mtetra
.927 .545 .243 r
.36837 .5498 .36927 .55067 .37053 .55464 .36964 .55374 Mtetra
.94 .683 .522 r
.36964 .55374 .37053 .55464 .36333 .7457 .36238 .74486 Mtetra
.937 .582 .32 r
.36238 .74486 .36333 .7457 .36462 .75091 .36367 .75011 Mtetra
0 .336 .787 r
.36367 .75011 .36462 .75091 .36612 .75174 .36517 .75094 Mtetra
.617 .753 .943 r
.36517 .75094 .36612 .75174 .36767 .75141 .36671 .75061 Mtetra
.8 .78 .834 r
.36671 .75061 .36767 .75141 .36926 .75006 .36831 .74927 Mtetra
.906 .743 .669 r
.36831 .74927 .36926 .75006 .371 .74533 .37005 .74453 Mtetra
.939 .687 .529 r
.37005 .74453 .371 .74533 .38072 .55353 .37983 .55266 Mtetra
.914 .724 .632 r
.37983 .55266 .38072 .55353 .38245 .54702 .38156 .54617 Mtetra
.8 .759 .816 r
.38156 .54617 .38245 .54702 .38396 .54567 .38307 .54481 Mtetra
.653 .736 .91 r
.38307 .54481 .38396 .54567 .38543 .54526 .38454 .54439 Mtetra
.524 .692 .944 r
.38454 .54439 .38543 .54526 .38689 .54523 .386 .54436 Mtetra
.734 .751 .866 r
.386 .54436 .38689 .54523 .38838 .54442 .38749 .54354 Mtetra
.705 .745 .883 r
.38749 .54354 .38838 .54442 .38986 .54378 .38897 .54289 Mtetra
.531 .69 .94 r
.38897 .54289 .38986 .54378 .39132 .54374 .39043 .54285 Mtetra
.905 .493 .146 r
.39043 .54285 .39132 .54374 .39264 .5471 .39176 .54615 Mtetra
.942 .684 .516 r
.39176 .54615 .39264 .5471 .38669 .73805 .38576 .73703 Mtetra
.946 .602 .33 r
.38576 .73703 .38669 .73805 .38801 .74407 .38707 .7432 Mtetra
.101 .483 .897 r
.38707 .7432 .38801 .74407 .38953 .7447 .38859 .74383 Mtetra
.67 .752 .912 r
.38859 .74383 .38953 .7447 .3911 .74419 .39016 .74331 Mtetra
.752 .765 .863 r
.39016 .74331 .3911 .74419 .39269 .74323 .39175 .74234 Mtetra
.691 .751 .897 r
.39175 .74234 .39269 .74323 .39426 .74263 .39332 .74173 Mtetra
.659 .74 .91 r
.39332 .74173 .39426 .74263 .39583 .74217 .39489 .74125 Mtetra
.645 .735 .914 r
.39489 .74125 .39583 .74217 .3974 .74175 .39646 .74084 Mtetra
.599 .722 .931 r
.39646 .74084 .3974 .74175 .39897 .74145 .39803 .74058 Mtetra
.575 .725 .945 r
.39803 .74058 .39897 .74145 .40053 .74119 .39959 .74039 Mtetra
.572 .739 .955 r
.39959 .74039 .40053 .74119 .4021 .74093 .40116 .74019 Mtetra
.528 .738 .971 r
.40116 .74019 .4021 .74093 .40366 .74091 .40272 .74007 Mtetra
.597 .738 .942 r
.40272 .74007 .40366 .74091 .40522 .74069 .40429 .7398 Mtetra
.688 .752 .9 r
.40429 .7398 .40522 .74069 .40681 .73995 .40587 .7392 Mtetra
.822 .79 .822 r
.40587 .7392 .40681 .73995 .40847 .73707 .40749 .73765 Mtetra
.947 .955 .726 r
.40749 .73765 .40847 .73707 .41032 .72822 .40914 .73489 Mtetra
.004 0 .271 r
.40914 .73489 .41032 .72822 .41789 .53926 .41089 .72904 Mtetra
0 0 .333 r
.41089 .72904 .41789 .53926 .41947 .53613 .41842 .54069 Mtetra
0 0 .096 r
.41842 .54069 .41947 .53613 .42099 .53467 .42006 .53548 Mtetra
.907 .973 .677 r
.42006 .53548 .42099 .53467 .42249 .53375 .42162 .53296 Mtetra
.78 .777 .85 r
.42162 .53296 .42249 .53375 .42399 .5331 .42313 .53186 Mtetra
.662 .667 .844 r
.42313 .53186 .42399 .5331 .42549 .53265 .42462 .53137 Mtetra
.607 .641 .858 r
.42462 .53137 .42549 .53265 .42698 .53231 .42611 .53115 Mtetra
.609 .662 .876 r
.42611 .53115 .42698 .53231 .42847 .53197 .4276 .53092 Mtetra
.616 .684 .891 r
.4276 .53092 .42847 .53197 .42996 .53162 .42909 .53064 Mtetra
.622 .704 .904 r
.42909 .53064 .42996 .53162 .43146 .53123 .43059 .53034 Mtetra
.672 .737 .899 r
.43059 .53034 .43146 .53123 .43296 .53071 .43209 .52984 Mtetra
.698 .747 .889 r
.43209 .52984 .43296 .53071 .43446 .53012 .43359 .52921 Mtetra
.7 .742 .884 r
.43359 .52921 .43446 .53012 .43596 .52952 .43509 .52858 Mtetra
.708 .736 .872 r
.43509 .52858 .43596 .52952 .43747 .52875 .4366 .52789 Mtetra
.69 .749 .896 r
.4366 .52789 .43747 .52875 .43898 .5281 .43811 .5273 Mtetra
.615 .745 .938 r
.43811 .5273 .43898 .5281 .44047 .52789 .43961 .527 Mtetra
.095 .459 .887 r
.43961 .527 .44047 .52789 .44193 .5295 .44108 .52768 Mtetra
0 .096 .651 r
.44108 .52768 .44193 .5295 .44325 .53664 .44253 .52962 Mtetra
.257 .181 .576 r
.44253 .52962 .44325 .53664 .44023 .72582 .44392 .53388 Mtetra
.552 .347 .555 r
.44392 .53388 .44023 .72582 .44177 .72783 .44525 .54083 Mtetra
.564 .356 .557 r
.44525 .54083 .44177 .72783 .44336 .72755 .44674 .54166 Mtetra
.574 .364 .558 r
.44674 .54166 .44336 .72755 .44497 .72663 .44835 .53703 Mtetra
.571 .362 .558 r
.44835 .53703 .44497 .72663 .44657 .72576 .44992 .5337 Mtetra
.568 .359 .557 r
.44992 .5337 .44657 .72576 .44818 .72515 .45146 .53209 Mtetra
.564 .356 .557 r
.45146 .53209 .44818 .72515 .44977 .72479 .45295 .53269 Mtetra
0 0 .374 r
.45295 .53269 .44977 .72479 .45136 .72521 .45061 .71637 Mtetra
.152 .093 .531 r
.45061 .71637 .45136 .72521 .45293 .72594 .45206 .72293 Mtetra
.076 .162 .652 r
.45206 .72293 .45293 .72594 .45452 .72645 .4536 .72542 Mtetra
.243 .526 .916 r
.4536 .72542 .45452 .72645 .45611 .72642 .45519 .726 Mtetra
.562 .842 .997 r
.45519 .726 .45611 .72642 .45772 .72601 .45679 .72564 Mtetra
.663 .884 .979 r
.45679 .72564 .45772 .72601 .45933 .7255 .4584 .72502 Mtetra
.618 .845 .986 r
.4584 .72502 .45933 .7255 .46093 .72509 .46001 .72457 Mtetra
.548 .81 .994 r
.46001 .72457 .46093 .72509 .46254 .72478 .46162 .7243 Mtetra
.542 .818 .997 r
.46162 .7243 .46254 .72478 .46415 .72447 .46323 .72401 Mtetra
.569 .835 .995 r
.46323 .72401 .46415 .72447 .46576 .72411 .46483 .72366 Mtetra
.596 .846 .992 r
.46483 .72366 .46576 .72411 .46737 .7237 .46645 .72325 Mtetra
.607 .848 .99 r
.46645 .72325 .46737 .7237 .46898 .72327 .46806 .72281 Mtetra
.609 .846 .989 r
.46806 .72281 .46898 .72327 .47059 .72284 .46967 .72237 Mtetra
.608 .844 .988 r
.46967 .72237 .47059 .72284 .47221 .72241 .47129 .72193 Mtetra
.61 .843 .988 r
.47129 .72193 .47221 .72241 .47382 .72197 .4729 .72149 Mtetra
.612 .843 .987 r
.4729 .72149 .47382 .72197 .47544 .72153 .47452 .72105 Mtetra
.613 .843 .987 r
.47452 .72105 .47544 .72153 .47705 .72109 .47614 .72061 Mtetra
.614 .843 .987 r
.47614 .72061 .47705 .72109 .47867 .72064 .47776 .72016 Mtetra
.616 .843 .986 r
.47776 .72016 .47867 .72064 .48029 .72019 .47938 .71971 Mtetra
.617 .844 .986 r
.47938 .71971 .48029 .72019 .48191 .71974 .481 .71926 Mtetra
.619 .844 .985 r
.481 .71926 .48191 .71974 .48353 .71928 .48262 .7188 Mtetra
.618 .843 .985 r
.48262 .7188 .48353 .71928 .48516 .71883 .48424 .71834 Mtetra
.62 .844 .985 r
.48424 .71834 .48516 .71883 .48678 .71837 .48587 .71788 Mtetra
.631 .846 .982 r
.48587 .71788 .48678 .71837 .4884 .71789 .48749 .71739 Mtetra
.66 .851 .973 r
.48749 .71739 .4884 .71789 .49003 .71736 .48912 .71683 Mtetra
.687 .846 .959 r
.48912 .71683 .49003 .71736 .49165 .71679 .49075 .71618 Mtetra
.693 .829 .948 r
.49075 .71618 .49165 .71679 .49328 .71621 .49238 .71553 Mtetra
.678 .807 .944 r
.49238 .71553 .49328 .71621 .49491 .71567 .49401 .71495 Mtetra
.656 .79 .946 r
.49401 .71495 .49491 .71567 .49654 .71519 .49564 .71445 Mtetra
.647 .784 .947 r
.49564 .71445 .49654 .71519 .49817 .71473 .49727 .71398 Mtetra
.645 .783 .947 r
.49727 .71398 .49817 .71473 .4998 .71427 .4989 .71353 Mtetra
.646 .783 .947 r
.4989 .71353 .4998 .71427 .50143 .71381 .50053 .71306 Mtetra
.644 .781 .947 r
.50053 .71306 .50143 .71381 .50306 .71336 .50216 .71261 Mtetra
.641 .779 .947 r
.50216 .71261 .50306 .71336 .5047 .71293 .5038 .71217 Mtetra
.638 .777 .947 r
.5038 .71217 .5047 .71293 .50633 .7125 .50543 .71173 Mtetra
.638 .775 .946 r
.50543 .71173 .50633 .7125 .50797 .71207 .50707 .7113 Mtetra
.605 .764 .955 r
.50707 .7113 .50797 .71207 .5096 .71181 .5087 .71098 Mtetra
.589 .742 .949 r
.5087 .71098 .5096 .71181 .51124 .71165 .51034 .71072 Mtetra
.662 .743 .91 r
.51034 .71072 .51124 .71165 .51288 .71109 .51198 .71021 Mtetra
.79 .779 .843 r
.51198 .71021 .51288 .71109 .51452 .70917 .51362 .70892 Mtetra
.927 .862 .756 r
.51362 .70892 .51452 .70917 .51617 .70339 .51527 .70621 Mtetra
0 0 0 r
.51527 .70621 .51617 .70339 .5182 .51047 .51692 .70174 Mtetra
.553 .343 .55 r
.51692 .70174 .5182 .51047 .51975 .50585 .51857 .69457 Mtetra
.56 .349 .551 r
.51857 .69457 .51975 .50585 .5213 .50499 .52021 .69175 Mtetra
.568 .355 .552 r
.52021 .69175 .5213 .50499 .52285 .50484 .52185 .69365 Mtetra
.567 .355 .552 r
.52185 .69365 .52285 .50484 .5244 .5048 .52349 .69508 Mtetra
.564 .353 .551 r
.52349 .69508 .5244 .5048 .52595 .50438 .52513 .69494 Mtetra
.52513 .69494 .52595 .50438 .52751 .50398 .52677 .69481 Mtetra
.566 .353 .552 r
.52677 .69481 .52751 .50398 .52906 .50365 .52841 .69536 Mtetra
.566 .354 .552 r
.52841 .69536 .52906 .50365 .53061 .50342 .53006 .69634 Mtetra
.564 .352 .551 r
.53006 .69634 .53061 .50342 .53217 .50297 .53171 .69571 Mtetra
.548 .34 .549 r
.53171 .69571 .53217 .50297 .53372 .50191 .53333 .68558 Mtetra
0 0 .386 r
.53333 .68558 .53372 .50191 .53528 .50025 .53445 .50243 Mtetra
0 0 0 r
.53445 .50243 .53528 .50025 .53683 .49879 .536 .49845 Mtetra
.892 .877 .813 r
.536 .49845 .53683 .49879 .53839 .49776 .53755 .49655 Mtetra
.668 .681 .854 r
.53755 .49655 .53839 .49776 .53994 .49729 .53911 .49602 Mtetra
.595 .642 .868 r
.53911 .49602 .53994 .49729 .5415 .49696 .54067 .49584 Mtetra
.601 .671 .889 r
.54067 .49584 .5415 .49696 .54306 .49651 .54223 .49562 Mtetra
.697 .752 .894 r
.54223 .49562 .54306 .49651 .54462 .49572 .54379 .49498 Mtetra
.655 .777 .939 r
.54379 .49498 .54462 .49572 .54619 .49526 .54535 .49451 Mtetra
.425 .684 .971 r
.54535 .49451 .54619 .49526 .54776 .49586 .54692 .49462 Mtetra
0 .201 .728 r
.54692 .49462 .54776 .49586 .54935 .50016 .5485 .49608 Mtetra
.19 .19 .628 r
.5485 .49608 .54935 .50016 .55243 .69226 .55009 .4991 Mtetra
.555 .349 .556 r
.55009 .4991 .55243 .69226 .55413 .6966 .55171 .50472 Mtetra
.568 .359 .557 r
.55171 .50472 .55413 .6966 .5558 .69645 .55327 .50314 Mtetra
.567 .359 .557 r
.55327 .50314 .5558 .69645 .55746 .69571 .55484 .50196 Mtetra
.05 0 .428 r
.55484 .50196 .55746 .69571 .55912 .69534 .5581 .67913 Mtetra
.139 .063 .5 r
.5581 .67913 .55912 .69534 .5608 .69623 .55989 .69224 Mtetra
.139 .166 .627 r
.55989 .69224 .5608 .69623 .56248 .69691 .5616 .69547 Mtetra
.07 .33 .808 r
.5616 .69547 .56248 .69691 .56416 .69718 .56329 .69675 Mtetra
.467 .807 .999 r
.56329 .69675 .56416 .69718 .56583 .69685 .56496 .69655 Mtetra
.607 .895 .988 r
.56496 .69655 .56583 .69685 .5675 .69635 .56663 .69599 Mtetra
.666 .896 .979 r
.56663 .69599 .5675 .69635 .56917 .6958 .5683 .69532 Mtetra
.608 .849 .989 r
.5683 .69532 .56917 .6958 .57084 .69535 .56998 .69487 Mtetra
.611 .848 .989 r
.56998 .69487 .57084 .69535 .57252 .69489 .57165 .6944 Mtetra
.613 .847 .988 r
.57165 .6944 .57252 .69489 .57419 .69444 .57333 .69394 Mtetra
.612 .844 .988 r
.57333 .69394 .57419 .69444 .57587 .69398 .575 .69348 Mtetra
.612 .844 .987 r
.575 .69348 .57587 .69398 .57755 .69352 .57668 .69302 Mtetra
.613 .843 .987 r
.57668 .69302 .57755 .69352 .57923 .69306 .57836 .69256 Mtetra
.57836 .69256 .57923 .69306 .58091 .69261 .58004 .69209 Mtetra
.614 .843 .987 r
.58004 .69209 .58091 .69261 .58259 .69214 .58172 .69163 Mtetra
.614 .843 .986 r
.58172 .69163 .58259 .69214 .58427 .69168 .5834 .69117 Mtetra
.5834 .69117 .58427 .69168 .58595 .69122 .58509 .69071 Mtetra
.614 .843 .987 r
.58509 .69071 .58595 .69122 .58763 .69075 .58677 .69024 Mtetra
.613 .844 .987 r
.58677 .69024 .58763 .69075 .58932 .69028 .58846 .68978 Mtetra
.606 .843 .989 r
.58846 .68978 .58932 .69028 .591 .68982 .59014 .68933 Mtetra
.611 .849 .989 r
.59014 .68933 .591 .68982 .59269 .68934 .59183 .68886 Mtetra
.614 .852 .988 r
.59183 .68886 .59269 .68934 .59438 .68885 .59352 .68838 Mtetra
.571 .841 .996 r
.59352 .68838 .59438 .68885 .59606 .68837 .59521 .68799 Mtetra
.646 .89 .984 r
.59521 .68799 .59606 .68837 .59775 .68779 .5969 .68738 Mtetra
.791 .901 .919 r
.5969 .68738 .59775 .68779 .59943 .687 .59857 .68624 Mtetra
.902 .798 .735 r
.59857 .68624 .59943 .687 .60111 .68564 .60021 .68332 Mtetra
.864 .672 .64 r
.60021 .68332 .60111 .68564 .60277 .68406 .6018 .6779 Mtetra
.957 .683 .477 r
.6018 .6779 .60277 .68406 .60444 .68254 .59927 .48946 Mtetra
.568 .359 .557 r
.59927 .48946 .60444 .68254 .60614 .68245 .60084 .48776 Mtetra
.565 .356 .557 r
.60084 .48776 .60614 .68245 .60784 .6821 .60246 .48828 Mtetra
.569 .36 .557 r
.60246 .48828 .60784 .6821 .60951 .68063 .60403 .48642 Mtetra
.577 .366 .558 r
.60403 .48642 .60951 .68063 .61085 .66547 .60548 .47972 Mtetra
.571 .362 .558 r
.60548 .47972 .61085 .66547 .60786 .47899 .60701 .47641 Mtetra
.747 .602 .697 r
.60701 .47641 .60786 .47899 .60938 .47543 .60857 .47437 Mtetra
.687 .721 .875 r
.60857 .47437 .60938 .47543 .61097 .47459 .61016 .47375 Mtetra
.61 .744 .94 r
.61016 .47375 .61097 .47459 .61257 .47426 .61177 .47344 Mtetra
.578 .735 .949 r
.61177 .47344 .61257 .47426 .61419 .47416 .61338 .47322 Mtetra
.74 .759 .868 r
.61338 .47322 .61419 .47416 .61578 .47347 .61497 .47232 Mtetra
.701 .709 .855 r
.61497 .47232 .61578 .47347 .61738 .47284 .61657 .47161 Mtetra
.619 .663 .87 r
.61657 .47161 .61738 .47284 .61898 .47239 .61817 .47131 Mtetra
0 .285 .784 r
.61817 .47131 .61898 .47239 .6206 .47224 .61983 .47255 Mtetra
.855 .441 .244 r
.61983 .47255 .6206 .47224 .62223 .47257 .62155 .47579 Mtetra
.96 .678 .455 r
.62155 .47579 .62223 .47257 .62389 .47389 .62882 .66546 Mtetra
.576 .362 .552 r
.62882 .66546 .62389 .47389 .62598 .48912 .63077 .67299 Mtetra
.568 .355 .552 r
.63077 .67299 .62598 .48912 .63334 .67403 .63256 .67532 Mtetra
.638 .226 .245 r
.63256 .67532 .63334 .67403 .63516 .67699 .63432 .6763 Mtetra
.58 .784 .976 r
.63432 .6763 .63516 .67699 .63689 .67696 .63604 .67599 Mtetra
.693 .755 .899 r
.63604 .67599 .63689 .67696 .6386 .67631 .63775 .67531 Mtetra
.721 .757 .881 r
.63775 .67531 .6386 .67631 .6403 .67535 .63945 .67448 Mtetra
.414 .661 .962 r
.63945 .67448 .6403 .67535 .64203 .67545 .64119 .67466 Mtetra
.542 .744 .97 r
.64119 .67466 .64203 .67545 .64376 .6752 .64292 .6745 Mtetra
.745 .829 .916 r
.64292 .6745 .64376 .6752 .64546 .67419 .64462 .67358 Mtetra
.954 .781 .63 r
.64462 .67358 .64546 .67419 .647 .66856 .64617 .66808 Mtetra
.968 .69 .452 r
.64617 .66808 .647 .66856 .64171 .47067 .64092 .46982 Mtetra
.944 .756 .618 r
.64092 .46982 .64171 .47067 .64315 .465 .64235 .46399 Mtetra
.766 .753 .841 r
.64235 .46399 .64315 .465 .64474 .46388 .64394 .46287 Mtetra
.608 .704 .913 r
.64394 .46287 .64474 .46388 .64637 .46357 .64557 .46259 Mtetra
.47 .65 .937 r
.64557 .46259 .64637 .46357 .64801 .46365 .64721 .46272 Mtetra
.694 .752 .896 r
.64721 .46272 .64801 .46365 .64963 .46315 .64883 .46208 Mtetra
.675 .716 .88 r
.64883 .46208 .64963 .46315 .65125 .46264 .65045 .46151 Mtetra
.593 .672 .895 r
.65045 .46151 .65125 .46264 .65288 .46228 .65209 .46131 Mtetra
0 .286 .781 r
.65209 .46131 .65288 .46228 .65452 .46212 .65378 .46252 Mtetra
.856 .443 .249 r
.65378 .46252 .65452 .46212 .65617 .46242 .65556 .46591 Mtetra
.963 .677 .443 r
.65556 .46591 .65617 .46242 .65787 .46367 .66487 .65625 Mtetra
.576 .361 .552 r
.66487 .65625 .65787 .46367 .66729 .65335 .66691 .66361 Mtetra
.617 .362 .508 r
.66691 .66361 .66729 .65335 .66952 .66499 .66876 .66586 Mtetra
.59 .124 .116 r
.66876 .66586 .66952 .66499 .67136 .66723 .67054 .66657 Mtetra
.8 .847 .886 r
.67054 .66657 .67136 .66723 .67303 .66502 .67224 .66532 Mtetra
.939 .965 .711 r
.67224 .66532 .67303 .66502 .67447 .6578 .67389 .66259 Mtetra
0 0 .204 r
.67389 .66259 .67447 .6578 .6677 .4618 .67538 .65644 Mtetra
.055 0 .436 r
.67538 .65644 .6677 .4618 .66922 .45854 .66866 .46294 Mtetra
0 0 .219 r
.66866 .46294 .66922 .45854 .6708 .45699 .67009 .45755 Mtetra
.884 .965 .639 r
.67009 .45755 .6708 .45699 .67242 .45601 .67163 .45499 Mtetra
.736 .748 .862 r
.67163 .45499 .67242 .45601 .67405 .45542 .67325 .45409 Mtetra
.622 .651 .857 r
.67325 .45409 .67405 .45542 .67569 .45504 .67489 .45377 Mtetra
.564 .634 .879 r
.67489 .45377 .67569 .45504 .67734 .45477 .67655 .4537 Mtetra
.633 .704 .897 r
.67655 .4537 .67734 .45477 .67898 .4543 .67819 .45332 Mtetra
.664 .734 .902 r
.67819 .45332 .67898 .4543 .68061 .45375 .67983 .45281 Mtetra
.677 .748 .904 r
.67983 .45281 .68061 .45375 .68225 .45315 .68147 .45224 Mtetra
.769 .777 .859 r
.68147 .45224 .68225 .45315 .68386 .4521 .68308 .45114 Mtetra
.737 .762 .874 r
.68308 .45114 .68386 .4521 .68549 .45125 .68471 .45026 Mtetra
.596 .705 .92 r
.68471 .45026 .68549 .45125 .68715 .45103 .68636 .45001 Mtetra
.731 .282 0 r
.68636 .45001 .68715 .45103 .68896 .45402 .68819 .45309 Mtetra
.971 .682 .42 r
.68819 .45309 .68896 .45402 .70059 .65071 .6998 .65042 Mtetra
.928 .549 .249 r
.6998 .65042 .70059 .65071 .70272 .65778 .70192 .6572 Mtetra
0 .369 .782 r
.70192 .6572 .70272 .65778 .70455 .65867 .70374 .65806 Mtetra
.612 .822 .981 r
.70374 .65806 .70455 .65867 .7063 .65824 .7055 .65761 Mtetra
.74 .853 .933 r
.7055 .65761 .7063 .65824 .70804 .65735 .70724 .65671 Mtetra
.617 .817 .977 r
.70724 .65671 .70804 .65735 .70981 .65704 .709 .65626 Mtetra
.615 .777 .958 r
.709 .65626 .70981 .65704 .71158 .65674 .71076 .65586 Mtetra
.696 .781 .917 r
.71076 .65586 .71158 .65674 .71332 .65593 .71251 .65516 Mtetra
.835 .829 .841 r
.71251 .65516 .71332 .65593 .71495 .65304 .71421 .65355 Mtetra
.901 .967 .65 r
.71421 .65355 .71495 .65304 .71628 .64473 .71585 .65078 Mtetra
.125 0 .351 r
.71585 .65078 .71628 .64473 .70719 .44956 .71733 .64525 Mtetra
.078 0 .449 r
.71733 .64525 .70719 .44956 .70868 .4461 .70826 .45133 Mtetra
0 0 .291 r
.70826 .45133 .70868 .4461 .71028 .44452 .70961 .44544 Mtetra
.742 .878 .466 r
.70961 .44544 .71028 .44452 .71191 .44352 .71115 .44274 Mtetra
.778 .811 .879 r
.71115 .44274 .71191 .44352 .71356 .44289 .71277 .44164 Mtetra
.635 .672 .868 r
.71277 .44164 .71356 .44289 .71522 .44247 .71444 .44126 Mtetra
.579 .653 .887 r
.71444 .44126 .71522 .44247 .71689 .44214 .71612 .44112 Mtetra
.648 .72 .901 r
.71612 .44112 .71689 .44214 .71855 .44163 .71779 .44067 Mtetra
.694 .751 .895 r
.71779 .44067 .71855 .44163 .72021 .44099 .71944 .44 Mtetra
.697 .747 .89 r
.71944 .44 .72021 .44099 .72186 .44034 .7211 .43932 Mtetra
.71 .745 .879 r
.7211 .43932 .72186 .44034 .72351 .4395 .72275 .43857 Mtetra
.695 .758 .9 r
.72275 .43857 .72351 .4395 .72516 .43877 .7244 .4379 Mtetra
.625 .748 .935 r
.7244 .4379 .72516 .43877 .72684 .4385 .72608 .43752 Mtetra
.352 .59 .934 r
.72608 .43752 .72684 .4385 .72863 .43994 .7278 .43793 Mtetra
.229 .34 .77 r
.7278 .43793 .72863 .43994 .73072 .44611 .7296 .43945 Mtetra
.314 .239 .61 r
.7296 .43945 .73072 .44611 .74483 .64153 .73156 .44357 Mtetra
.1 .017 .466 r
.73156 .44357 .74483 .64153 .74684 .64461 .7456 .63683 Mtetra
.271 .202 .593 r
.7456 .63683 .74684 .64461 .7487 .64538 .74776 .64227 Mtetra
.296 .315 .711 r
.74776 .64227 .7487 .64538 .75052 .64549 .7497 .6443 Mtetra
.354 .554 .909 r
.7497 .6443 .75052 .64549 .75234 .64551 .75156 .64484 Mtetra
.558 .79 .986 r
.75156 .64484 .75234 .64551 .75414 .64528 .75336 .64456 Mtetra
.722 .83 .932 r
.75336 .64456 .75414 .64528 .75591 .64449 .75512 .64373 Mtetra
.83 .837 .853 r
.75512 .64373 .75591 .64449 .75756 .64201 .75684 .64219 Mtetra
.927 .974 .729 r
.75684 .64219 .75756 .64201 .75895 .63556 .75849 .63965 Mtetra
.002 0 .259 r
.75849 .63965 .75895 .63556 .74733 .4385 .76 .63501 Mtetra
.103 .016 .462 r
.76 .63501 .74733 .4385 .74874 .43408 .74856 .4415 Mtetra
.054 0 .361 r
.74856 .4415 .74874 .43408 .75033 .43233 .74974 .43365 Mtetra
0 0 0 r
.74974 .43365 .75033 .43233 .75198 .43126 .75125 .43062 Mtetra
.82 .856 .875 r
.75125 .43062 .75198 .43126 .75365 .43059 .75287 .42929 Mtetra
.643 .67 .861 r
.75287 .42929 .75365 .43059 .75534 .43016 .75456 .42886 Mtetra
.579 .639 .875 r
.75456 .42886 .75534 .43016 .75704 .42986 .75628 .42873 Mtetra
.607 .684 .897 r
.75628 .42873 .75704 .42986 .75873 .42945 .75798 .42846 Mtetra
.661 .736 .905 r
.75798 .42846 .75873 .42945 .76041 .42889 .75966 .42794 Mtetra
.675 .75 .907 r
.75966 .42794 .76041 .42889 .76209 .42829 .76135 .42736 Mtetra
.75 .778 .876 r
.76135 .42736 .76209 .42829 .76375 .42734 .763 .42639 Mtetra
.759 .775 .867 r
.763 .42639 .76375 .42734 .7654 .42635 .76465 .42535 Mtetra
.653 .73 .906 r
.76465 .42535 .7654 .42635 .7671 .42591 .76635 .42487 Mtetra
0 .166 .695 r
.76635 .42487 .7671 .42591 .76895 .42757 .7682 .42657 Mtetra
.975 .677 .382 r
.7682 .42657 .76895 .42757 .78485 .61494 .78434 .6175 Mtetra
.916 .586 .404 r
.78434 .6175 .78485 .61494 .78807 .63308 .78731 .63248 Mtetra
.516 0 0 r
.78731 .63248 .78807 .63308 .79006 .63495 .78929 .63426 Mtetra
.614 .809 .975 r
.78929 .63426 .79006 .63495 .79188 .63459 .79111 .63381 Mtetra
.755 .829 .91 r
.79111 .63381 .79188 .63459 .79365 .63367 .79288 .6328 Mtetra
.651 .777 .941 r
.79288 .6328 .79365 .63367 .79547 .63318 .79469 .63228 Mtetra
.491 .699 .961 r
.79469 .63228 .79547 .63318 .79732 .63315 .79654 .63228 Mtetra
.657 .779 .939 r
.79654 .63228 .79732 .63315 .79912 .63257 .79835 .63173 Mtetra
.907 .821 .751 r
.79835 .63173 .79912 .63257 .80076 .62989 .79999 .62902 Mtetra
.979 .727 .481 r
.79999 .62902 .80076 .62989 .80151 .61616 .80061 .61356 Mtetra
.975 .682 .396 r
.80061 .61356 .80151 .61616 .78764 .42203 .78688 .42075 Mtetra
.877 .749 .718 r
.78688 .42075 .78764 .42203 .78915 .41911 .7884 .41791 Mtetra
.674 .703 .868 r
.7884 .41791 .78915 .41911 .79084 .41844 .7901 .41732 Mtetra
.545 .658 .91 r
.7901 .41732 .79084 .41844 .79258 .41831 .79184 .41727 Mtetra
.584 .695 .918 r
.79184 .41727 .79258 .41831 .7943 .41797 .79357 .41707 Mtetra
.695 .771 .91 r
.79357 .41707 .7943 .41797 .79598 .41718 .79527 .41639 Mtetra
.644 .783 .948 r
.79527 .41639 .79598 .41718 .7977 .41676 .79698 .41591 Mtetra
.446 .676 .962 r
.79698 .41591 .7977 .41676 .79953 .41764 .79874 .41603 Mtetra
.252 .405 .822 r
.79874 .41603 .79953 .41764 .80169 .42237 .8006 .41721 Mtetra
.348 .285 .644 r
.8006 .41721 .80169 .42237 .82033 .61907 .80261 .42019 Mtetra
.141 .053 .486 r
.80261 .42019 .82033 .61907 .82256 .62326 .82083 .61106 Mtetra
.28 .189 .57 r
.82083 .61106 .82256 .62326 .82451 .62408 .82345 .61975 Mtetra
.342 .304 .671 r
.82345 .61975 .82451 .62408 .82639 .62421 .82554 .62232 Mtetra
.335 .434 .814 r
.82554 .62232 .82639 .62421 .82827 .62425 .82752 .62341 Mtetra
.395 .665 .968 r
.82752 .62341 .82827 .62425 .83016 .62432 .82941 .62362 Mtetra
.662 .827 .963 r
.82941 .62362 .83016 .62432 .83198 .62375 .83124 .62301 Mtetra
.903 .845 .777 r
.83124 .62301 .83198 .62375 .83366 .62145 .8329 .62059 Mtetra
.98 .749 .519 r
.8329 .62059 .83366 .62145 .83469 .61203 .83388 .61055 Mtetra
.977 .68 .377 r
.83388 .61055 .83469 .61203 .81853 .41324 .81777 .41189 Mtetra
.894 .745 .69 r
.81777 .41189 .81853 .41324 .81998 .40977 .81923 .4085 Mtetra
.68 .696 .858 r
.81923 .4085 .81998 .40977 .82169 .40907 .82095 .40786 Mtetra
.546 .644 .897 r
.82095 .40786 .82169 .40907 .82345 .40898 .82272 .40783 Mtetra
.523 .643 .909 r
.82272 .40783 .82345 .40898 .82523 .40897 .82449 .40787 Mtetra
.644 .711 .896 r
.82449 .40787 .82523 .40897 .82696 .40852 .82623 .40742 Mtetra
.655 .717 .893 r
.82623 .40742 .82696 .40852 .82869 .40802 .82796 .40692 Mtetra
.686 .729 .883 r
.82796 .40692 .82869 .40802 .83041 .40742 .82968 .40627 Mtetra
.715 .73 .862 r
.82968 .40627 .83041 .40742 .83212 .4067 .83138 .40544 Mtetra
.667 .691 .863 r
.83138 .40544 .83212 .4067 .83384 .40607 .8331 .40487 Mtetra
.496 .619 .903 r
.8331 .40487 .83384 .40607 .83558 .40561 .8349 .40502 Mtetra
.507 0 0 r
.8349 .40502 .83558 .40561 .83734 .40544 .83686 .40685 Mtetra
.872 .494 .324 r
.83686 .40685 .83734 .40544 .83917 .40584 .83921 .41268 Mtetra
.97 .663 .374 r
.83921 .41268 .83917 .40584 .84118 .40813 .85992 .60621 Mtetra
.57 .357 .552 r
.85992 .60621 .84118 .40813 .86224 .60391 .8622 .61016 Mtetra
.619 .337 .468 r
.8622 .61016 .86224 .60391 .86489 .61145 .86427 .61183 Mtetra
.532 0 0 r
.86427 .61183 .86489 .61145 .86701 .61358 .86626 .61262 Mtetra
.412 .644 .953 r
.86626 .61262 .86701 .61358 .86895 .61387 .86819 .61287 Mtetra
.646 .75 .925 r
.86819 .61287 .86895 .61387 .87079 .61322 .87006 .61237 Mtetra
.869 .835 .81 r
.87006 .61237 .87079 .61322 .87248 .61103 .87177 .61036 Mtetra
.987 .772 .528 r
.87177 .61036 .87248 .61103 .87352 .60247 .87284 .6021 Mtetra
.978 .677 .354 r
.87284 .6021 .87352 .60247 .85493 .40213 .85422 .40112 Mtetra
.941 .786 .66 r
.85422 .40112 .85493 .40213 .85632 .39819 .85561 .39711 Mtetra
.71 .744 .878 r
.85561 .39711 .85632 .39819 .85804 .39737 .85733 .39632 Mtetra
.567 .688 .922 r
.85733 .39632 .85804 .39737 .85982 .39717 .85911 .39617 Mtetra
.51 .67 .936 r
.85911 .39617 .85982 .39717 .86162 .39716 .86092 .39619 Mtetra
.653 .746 .918 r
.86092 .39619 .86162 .39716 .86337 .39667 .86267 .39569 Mtetra
.666 .749 .912 r
.86267 .39569 .86337 .39667 .86512 .39614 .86441 .39513 Mtetra
.706 .757 .892 r
.86441 .39513 .86512 .39614 .86685 .39545 .86614 .39438 Mtetra
.77 .766 .85 r
.86614 .39438 .86685 .39545 .86854 .39436 .86783 .39321 Mtetra
.695 .724 .872 r
.86783 .39321 .86854 .39436 .87028 .39371 .86956 .39249 Mtetra
.408 .566 .899 r
.86956 .39249 .87028 .39371 .87215 .39424 .87142 .39295 Mtetra
.815 .425 0 r
.87142 .39295 .87215 .39424 .87468 .40087 .87391 .39925 Mtetra
.974 .665 .322 r
.87391 .39925 .87468 .40087 .89833 .60101 .8976 .60005 Mtetra
.674 .226 0 r
.8976 .60005 .89833 .60101 .90065 .60454 .89993 .60371 Mtetra
.453 .702 .974 r
.89993 .60371 .90065 .60454 .90258 .6045 .90187 .60377 Mtetra
.719 .844 .941 r
.90187 .60377 .90258 .6045 .90443 .60368 .90372 .60291 Mtetra
.849 .859 .85 r
.90372 .60291 .90443 .60368 .90623 .60243 .90547 .60122 Mtetra
.888 .78 .736 r
.90547 .60122 .90623 .60243 .90806 .60146 .9071 .59841 Mtetra
.859 .653 .623 r
.9071 .59841 .90806 .60146 .90983 .59994 .90842 .59287 Mtetra
.974 .669 .359 r
.90842 .59287 .90983 .59994 .91143 .59695 .8882 .39653 Mtetra
.575 .364 .557 r
.8882 .39653 .91143 .59695 .8912 .40177 .88931 .3902 Mtetra
.636 .437 .596 r
.88931 .3902 .8912 .40177 .89169 .38998 .89081 .38734 Mtetra
.726 .595 .709 r
.89081 .38734 .89169 .38998 .89315 .38677 .89245 .38564 Mtetra
.676 .722 .884 r
.89245 .38564 .89315 .38677 .89488 .38595 .8942 .38502 Mtetra
.599 .736 .94 r
.8942 .38502 .89488 .38595 .89668 .38563 .896 .38472 Mtetra
.579 .728 .945 r
.896 .38472 .89668 .38563 .89849 .38551 .8978 .38448 Mtetra
.691 .751 .897 r
.8978 .38448 .89849 .38551 .90026 .3849 .89956 .38379 Mtetra
.697 .736 .881 r
.89956 .38379 .90026 .3849 .90202 .38427 .90131 .38307 Mtetra
.695 .717 .866 r
.90131 .38307 .90202 .38427 .90378 .38364 .90306 .38233 Mtetra
.706 .705 .847 r
.90306 .38233 .90378 .38364 .90554 .38297 .9048 .38151 Mtetra
.662 .662 .84 r
.9048 .38151 .90554 .38297 .90731 .38241 .90657 .38093 Mtetra
.574 .615 .856 r
.90657 .38093 .90731 .38241 .9091 .38205 .9084 .38084 Mtetra
0 .265 .773 r
.9084 .38084 .9091 .38205 .91098 .38233 .91045 .38257 Mtetra
.866 .421 .111 r
.91045 .38257 .91098 .38233 .91289 .38287 .91282 .38694 Mtetra
.971 .656 .323 r
.91282 .38694 .91289 .38287 .91481 .38347 .93825 .5811 Mtetra
.567 .354 .551 r
.93825 .5811 .91481 .38347 .91661 .38309 .9404 .58267 Mtetra
.563 .352 .551 r
.9404 .58267 .91661 .38309 .91837 .38238 .94224 .58158 Mtetra
.561 .35 .551 r
.94224 .58158 .91837 .38238 .92011 .38151 .94386 .57884 Mtetra
.56 .35 .551 r
.94386 .57884 .92011 .38151 .92182 .38032 .94544 .57568 Mtetra
.563 .351 .551 r
.94544 .57568 .92182 .38032 .92358 .37962 .94721 .57411 Mtetra
.569 .356 .551 r
.94721 .57411 .92358 .37962 .92547 .37987 .94955 .5771 Mtetra
.573 .358 .551 r
.94955 .5771 .92547 .37987 .92846 .38893 .95229 .58316 Mtetra
.568 .355 .551 r
.95229 .58316 .92846 .38893 .95505 .58477 .95461 .5859 Mtetra
.667 .213 .164 r
.95461 .5859 .95505 .58477 .95746 .58821 .95677 .58732 Mtetra
.341 .662 .973 r
.33952 .75599 .34048 .75671 .34197 .75723 .34103 .75619 Mtetra
.608 .693 .903 r
.34103 .75619 .34197 .75723 .3435 .75706 .34256 .75593 Mtetra
.74 .714 .827 r
.34256 .75593 .3435 .75706 .34507 .75605 .34413 .75494 Mtetra
.89 .718 .662 r
.34413 .75494 .34507 .75605 .34683 .75124 .3459 .7499 Mtetra
.936 .686 .534 r
.3459 .7499 .34683 .75124 .35783 .55938 .35695 .55812 Mtetra
.893 .704 .64 r
.35695 .55812 .35783 .55938 .35959 .55285 .35869 .55202 Mtetra
.784 .762 .834 r
.35869 .55202 .35959 .55285 .36108 .55167 .36018 .55086 Mtetra
.65 .744 .919 r
.36018 .55086 .36108 .55167 .36254 .55128 .36164 .55045 Mtetra
.522 .699 .951 r
.36164 .55045 .36254 .55128 .36398 .55126 .36308 .5504 Mtetra
.748 .755 .858 r
.36308 .5504 .36398 .55126 .36546 .55036 .36457 .54951 Mtetra
.698 .746 .888 r
.36457 .54951 .36546 .55036 .36693 .54976 .36604 .54889 Mtetra
.49 .678 .949 r
.36604 .54889 .36693 .54976 .36837 .5498 .36748 .54893 Mtetra
.926 .543 .241 r
.36748 .54893 .36837 .5498 .36964 .55374 .36874 .55285 Mtetra
.939 .683 .522 r
.36874 .55285 .36964 .55374 .36238 .74486 .36143 .74402 Mtetra
.937 .583 .322 r
.36143 .74402 .36238 .74486 .36367 .75011 .36272 .7493 Mtetra
0 .333 .785 r
.36272 .7493 .36367 .75011 .36517 .75094 .36421 .75015 Mtetra
.616 .752 .943 r
.36421 .75015 .36517 .75094 .36671 .75061 .36576 .74982 Mtetra
.8 .78 .834 r
.36576 .74982 .36671 .75061 .36831 .74927 .36736 .74848 Mtetra
.906 .743 .669 r
.36736 .74848 .36831 .74927 .37005 .74453 .3691 .74373 Mtetra
.939 .687 .529 r
.3691 .74373 .37005 .74453 .37983 .55266 .37894 .5518 Mtetra
.914 .725 .632 r
.37894 .5518 .37983 .55266 .38156 .54617 .38067 .54531 Mtetra
.8 .76 .816 r
.38067 .54531 .38156 .54617 .38307 .54481 .38218 .54396 Mtetra
.654 .737 .91 r
.38218 .54396 .38307 .54481 .38454 .54439 .38365 .54353 Mtetra
.526 .693 .945 r
.38365 .54353 .38454 .54439 .386 .54436 .38511 .54349 Mtetra
.735 .752 .867 r
.38511 .54349 .386 .54436 .38749 .54354 .3866 .54267 Mtetra
.706 .747 .883 r
.3866 .54267 .38749 .54354 .38897 .54289 .38808 .54202 Mtetra
.533 .693 .941 r
.38808 .54202 .38897 .54289 .39043 .54285 .38954 .54196 Mtetra
.903 .489 .141 r
.38954 .54196 .39043 .54285 .39176 .54615 .39087 .54521 Mtetra
.942 .684 .516 r
.39087 .54521 .39176 .54615 .38576 .73703 .38482 .73603 Mtetra
.946 .604 .337 r
.38482 .73603 .38576 .73703 .38707 .7432 .38612 .74234 Mtetra
.089 .477 .894 r
.38612 .74234 .38707 .7432 .38859 .74383 .38765 .74298 Mtetra
.671 .754 .913 r
.38765 .74298 .38859 .74383 .39016 .74331 .38922 .74245 Mtetra
.754 .768 .864 r
.38922 .74245 .39016 .74331 .39175 .74234 .39081 .74147 Mtetra
.691 .756 .901 r
.39081 .74147 .39175 .74234 .39332 .74173 .39238 .74086 Mtetra
.659 .749 .917 r
.39238 .74086 .39332 .74173 .39489 .74125 .39396 .74039 Mtetra
.65 .747 .92 r
.39396 .74039 .39489 .74125 .39646 .74084 .39553 .73995 Mtetra
.628 .735 .924 r
.39553 .73995 .39646 .74084 .39803 .74058 .3971 .73959 Mtetra
.62 .71 .91 r
.3971 .73959 .39803 .74058 .39959 .74039 .39866 .73927 Mtetra
.621 .686 .89 r
.39866 .73927 .39959 .74039 .40116 .74019 .40023 .73897 Mtetra
.615 .665 .876 r
.40023 .73897 .40116 .74019 .40272 .74007 .4018 .7387 Mtetra
.626 .645 .849 r
.4018 .7387 .40272 .74007 .40429 .7398 .40337 .73838 Mtetra
.646 .645 .835 r
.40337 .73838 .40429 .7398 .40587 .7392 .40495 .73794 Mtetra
.645 .67 .86 r
.40495 .73794 .40587 .7392 .40749 .73765 .40653 .73753 Mtetra
.658 .936 .968 r
.40653 .73753 .40749 .73765 .40914 .73489 .40811 .73681 Mtetra
.11 0 .067 r
.40811 .73681 .40914 .73489 .41089 .72904 .40973 .73539 Mtetra
.039 0 .281 r
.40973 .73539 .41089 .72904 .41842 .54069 .41146 .73005 Mtetra
0 0 .322 r
.41146 .73005 .41842 .54069 .42006 .53548 .41907 .53804 Mtetra
.864 .847 .385 r
.41907 .53804 .42006 .53548 .42162 .53296 .42072 .53271 Mtetra
.867 .89 .85 r
.42072 .53271 .42162 .53296 .42313 .53186 .42225 .53116 Mtetra
.669 .783 .934 r
.42225 .53116 .42313 .53186 .42462 .53137 .42374 .53066 Mtetra
.534 .738 .969 r
.42374 .53066 .42462 .53137 .42611 .53115 .42523 .53054 Mtetra
.584 .784 .975 r
.42523 .53054 .42611 .53115 .4276 .53092 .42672 .53026 Mtetra
.629 .786 .957 r
.42672 .53026 .4276 .53092 .42909 .53064 .42821 .52989 Mtetra
.639 .76 .936 r
.42821 .52989 .42909 .53064 .43059 .53034 .42971 .5295 Mtetra
.661 .745 .913 r
.42971 .5295 .43059 .53034 .43209 .52984 .43121 .52904 Mtetra
.671 .759 .917 r
.43121 .52904 .43209 .52984 .43359 .52921 .43271 .52854 Mtetra
.672 .791 .938 r
.43271 .52854 .43359 .52921 .43509 .52858 .43421 .52802 Mtetra
.672 .825 .957 r
.43421 .52802 .43509 .52858 .4366 .52789 .43572 .52749 Mtetra
.645 .864 .982 r
.43572 .52749 .4366 .52789 .43811 .5273 .43722 .52698 Mtetra
.589 .871 .994 r
.43722 .52698 .43811 .5273 .43961 .527 .43872 .52656 Mtetra
.475 .797 .999 r
.43872 .52656 .43961 .527 .44108 .52768 .44022 .5264 Mtetra
.542 .613 .874 r
.44022 .5264 .44108 .52768 .44253 .52962 .44171 .52643 Mtetra
.569 .471 .703 r
.44171 .52643 .44253 .52962 .44392 .53388 .44321 .52648 Mtetra
.583 .416 .621 r
.44321 .52648 .44392 .53388 .44525 .54083 .44471 .52624 Mtetra
.58 .39 .589 r
.44471 .52624 .44525 .54083 .44674 .54166 .44622 .52574 Mtetra
.58 .389 .586 r
.44622 .52574 .44674 .54166 .44835 .53703 .44773 .52516 Mtetra
.593 .406 .597 r
.44773 .52516 .44835 .53703 .44992 .5337 .44925 .52429 Mtetra
.596 .416 .608 r
.44925 .52429 .44992 .5337 .45146 .53209 .45076 .52353 Mtetra
.577 .405 .612 r
.45076 .52353 .45146 .53209 .45295 .53269 .45227 .52339 Mtetra
.451 .307 .595 r
.45227 .52339 .45295 .53269 .45061 .71637 .45371 .52612 Mtetra
0 0 .354 r
.45371 .52612 .45061 .71637 .45206 .72293 .45124 .71733 Mtetra
0 0 .415 r
.45124 .71733 .45206 .72293 .4536 .72542 .4527 .72377 Mtetra
.137 .338 .8 r
.4527 .72377 .4536 .72542 .45519 .726 .45427 .725 Mtetra
.613 .71 .914 r
.45427 .725 .45519 .726 .45679 .72564 .45588 .7247 Mtetra
.709 .75 .884 r
.45588 .7247 .45679 .72564 .4584 .72502 .45749 .72397 Mtetra
.681 .721 .88 r
.45749 .72397 .4584 .72502 .46001 .72457 .4591 .72338 Mtetra
.637 .682 .876 r
.4591 .72338 .46001 .72457 .46162 .7243 .46071 .723 Mtetra
.638 .665 .86 r
.46071 .723 .46162 .7243 .46323 .72401 .46232 .72261 Mtetra
.641 .65 .844 r
.46232 .72261 .46323 .72401 .46483 .72366 .46393 .7222 Mtetra
.643 .644 .835 r
.46393 .7222 .46483 .72366 .46645 .72325 .46554 .72178 Mtetra
.644 .643 .834 r
.46554 .72178 .46645 .72325 .46806 .72281 .46716 .72134 Mtetra
.645 .643 .834 r
.46716 .72134 .46806 .72281 .46967 .72237 .46877 .7209 Mtetra
.46877 .7209 .46967 .72237 .47129 .72193 .47039 .72046 Mtetra
.47039 .72046 .47129 .72193 .4729 .72149 .472 .72003 Mtetra
.472 .72003 .4729 .72149 .47452 .72105 .47362 .71958 Mtetra
.646 .644 .834 r
.47362 .71958 .47452 .72105 .47614 .72061 .47524 .71914 Mtetra
.646 .644 .833 r
.47524 .71914 .47614 .72061 .47776 .72016 .47686 .71869 Mtetra
.647 .644 .833 r
.47686 .71869 .47776 .72016 .47938 .71971 .47848 .71824 Mtetra
.648 .644 .832 r
.47848 .71824 .47938 .71971 .481 .71926 .4801 .71778 Mtetra
.649 .644 .832 r
.4801 .71778 .481 .71926 .48262 .7188 .48172 .71731 Mtetra
.65 .644 .831 r
.48172 .71731 .48262 .7188 .48424 .71834 .48334 .71684 Mtetra
.651 .642 .829 r
.48334 .71684 .48424 .71834 .48587 .71788 .48497 .71636 Mtetra
.652 .641 .826 r
.48497 .71636 .48587 .71788 .48749 .71739 .48659 .71587 Mtetra
.656 .642 .824 r
.48659 .71587 .48749 .71739 .48912 .71683 .48822 .71536 Mtetra
.661 .65 .828 r
.48822 .71536 .48912 .71683 .49075 .71618 .48985 .71481 Mtetra
.664 .665 .841 r
.48985 .71481 .49075 .71618 .49238 .71553 .49148 .71427 Mtetra
.663 .681 .857 r
.49148 .71427 .49238 .71553 .49401 .71495 .49311 .71375 Mtetra
.659 .69 .868 r
.49311 .71375 .49401 .71495 .49564 .71445 .49474 .71325 Mtetra
.657 .689 .869 r
.49474 .71325 .49564 .71445 .49727 .71398 .49637 .71276 Mtetra
.655 .685 .867 r
.49637 .71276 .49727 .71398 .4989 .71353 .498 .71229 Mtetra
.653 .682 .865 r
.498 .71229 .4989 .71353 .50053 .71306 .49963 .71182 Mtetra
.651 .68 .864 r
.49963 .71182 .50053 .71306 .50216 .71261 .50126 .71136 Mtetra
.649 .678 .864 r
.50126 .71136 .50216 .71261 .5038 .71217 .5029 .71091 Mtetra
.647 .677 .864 r
.5029 .71091 .5038 .71217 .50543 .71173 .50453 .71047 Mtetra
.646 .675 .863 r
.50453 .71047 .50543 .71173 .50707 .7113 .50617 .71003 Mtetra
.638 .672 .866 r
.50617 .71003 .50707 .7113 .5087 .71098 .50781 .70964 Mtetra
.633 .658 .857 r
.50781 .70964 .5087 .71098 .51034 .71072 .50944 .70927 Mtetra
.645 .648 .838 r
.50944 .70927 .51034 .71072 .51198 .71021 .51108 .70883 Mtetra
.682 .671 .833 r
.51108 .70883 .51198 .71021 .51362 .70892 .51273 .70816 Mtetra
.753 .802 .891 r
.51273 .70816 .51362 .70892 .51527 .70621 .51437 .70721 Mtetra
0 0 0 r
.51437 .70721 .51527 .70621 .51692 .70174 .51601 .70619 Mtetra
.476 .197 .411 r
.51601 .70619 .51692 .70174 .51857 .69457 .51765 .70535 Mtetra
.543 .302 .501 r
.51765 .70535 .51857 .69457 .52021 .69175 .5193 .70486 Mtetra
.55 .314 .511 r
.5193 .70486 .52021 .69175 .52185 .69365 .52094 .70449 Mtetra
.547 .306 .502 r
.52094 .70449 .52185 .69365 .52349 .69508 .52259 .70414 Mtetra
.541 .295 .491 r
.52259 .70414 .52349 .69508 .52513 .69494 .52423 .70373 Mtetra
.54 .293 .489 r
.52423 .70373 .52513 .69494 .52677 .69481 .52588 .70332 Mtetra
.547 .297 .489 r
.52588 .70332 .52677 .69481 .52841 .69536 .52753 .70311 Mtetra
.554 .299 .484 r
.52753 .70311 .52841 .69536 .53006 .69634 .52918 .7031 Mtetra
.525 .267 .467 r
.52918 .7031 .53006 .69634 .53171 .69571 .53083 .70255 Mtetra
.416 .176 .439 r
.53083 .70255 .53171 .69571 .53333 .68558 .53248 .70019 Mtetra
0 0 .245 r
.53248 .70019 .53333 .68558 .53445 .50243 .53409 .68236 Mtetra
0 0 .377 r
.53409 .68236 .53445 .50243 .536 .49845 .53516 .49887 Mtetra
.966 .933 .694 r
.53516 .49887 .536 .49845 .53755 .49655 .53671 .49584 Mtetra
.723 .802 .914 r
.53671 .49584 .53755 .49655 .53911 .49602 .53827 .4951 Mtetra
.595 .713 .926 r
.53827 .4951 .53911 .49602 .54067 .49584 .53983 .49486 Mtetra
.575 .693 .922 r
.53983 .49486 .54067 .49584 .54223 .49562 .5414 .49471 Mtetra
.669 .741 .904 r
.5414 .49471 .54223 .49562 .54379 .49498 .54296 .49419 Mtetra
.656 .768 .932 r
.54296 .49419 .54379 .49498 .54535 .49451 .54452 .49373 Mtetra
.616 .755 .945 r
.54452 .49373 .54535 .49451 .54692 .49462 .54609 .49339 Mtetra
.572 .641 .88 r
.54609 .49339 .54692 .49462 .5485 .49608 .54765 .4933 Mtetra
.579 .496 .725 r
.54765 .4933 .5485 .49608 .55009 .4991 .54922 .49326 Mtetra
.589 .434 .639 r
.54922 .49326 .55009 .4991 .55171 .50472 .55079 .49295 Mtetra
.593 .407 .598 r
.55079 .49295 .55171 .50472 .55327 .50314 .55236 .49205 Mtetra
.583 .401 .6 r
.55236 .49205 .55327 .50314 .55484 .50196 .55392 .49158 Mtetra
.536 .369 .601 r
.55392 .49158 .55484 .50196 .5581 .67913 .55551 .4926 Mtetra
0 0 .408 r
.55551 .4926 .5581 .67913 .55989 .69224 .55886 .6753 Mtetra
0 0 .431 r
.55886 .6753 .55989 .69224 .5616 .69547 .5607 .6928 Mtetra
.033 .16 .665 r
.5607 .6928 .5616 .69547 .56329 .69675 .5624 .69531 Mtetra
.568 .618 .862 r
.5624 .69531 .56329 .69675 .56496 .69655 .56408 .69525 Mtetra
.676 .684 .85 r
.56408 .69525 .56496 .69655 .56663 .69599 .56575 .69463 Mtetra
.699 .684 .832 r
.56575 .69463 .56663 .69599 .5683 .69532 .56742 .69384 Mtetra
.647 .647 .836 r
.56742 .69384 .5683 .69532 .56998 .69487 .56909 .69338 Mtetra
.648 .647 .835 r
.56909 .69338 .56998 .69487 .57165 .6944 .57077 .69291 Mtetra
.648 .646 .835 r
.57077 .69291 .57165 .6944 .57333 .69394 .57244 .69244 Mtetra
.646 .645 .834 r
.57244 .69244 .57333 .69394 .575 .69348 .57412 .69197 Mtetra
.646 .644 .834 r
.57412 .69197 .575 .69348 .57668 .69302 .5758 .69151 Mtetra
.5758 .69151 .57668 .69302 .57836 .69256 .57748 .69105 Mtetra
.57748 .69105 .57836 .69256 .58004 .69209 .57916 .69059 Mtetra
.57916 .69059 .58004 .69209 .58172 .69163 .58084 .69012 Mtetra
.58084 .69012 .58172 .69163 .5834 .69117 .58252 .68966 Mtetra
.58252 .68966 .5834 .69117 .58509 .69071 .58421 .6892 Mtetra
.58421 .6892 .58509 .69071 .58677 .69024 .58589 .68873 Mtetra
.645 .644 .834 r
.58589 .68873 .58677 .69024 .58846 .68978 .58758 .68827 Mtetra
.643 .643 .835 r
.58758 .68827 .58846 .68978 .59014 .68933 .58926 .68782 Mtetra
.645 .644 .834 r
.58926 .68782 .59014 .68933 .59183 .68886 .59095 .68736 Mtetra
.64 .643 .837 r
.59095 .68736 .59183 .68886 .59352 .68838 .59264 .68693 Mtetra
.588 .627 .858 r
.59264 .68693 .59352 .68838 .59521 .68799 .59434 .68678 Mtetra
.659 .693 .87 r
.59434 .68678 .59521 .68799 .5969 .68738 .59603 .68626 Mtetra
.782 .746 .82 r
.59603 .68626 .5969 .68738 .59857 .68624 .5977 .6849 Mtetra
.907 .728 .648 r
.5977 .6849 .59857 .68624 .60021 .68332 .59929 .67973 Mtetra
.96 .687 .473 r
.59929 .67973 .60021 .68332 .6018 .6779 .59675 .48444 Mtetra
.576 .365 .558 r
.59675 .48444 .6018 .6779 .59927 .48946 .59822 .47819 Mtetra
.598 .411 .6 r
.59822 .47819 .59927 .48946 .60084 .48776 .5998 .47715 Mtetra
.58 .4 .602 r
.5998 .47715 .60084 .48776 .60246 .48828 .6014 .47681 Mtetra
.574 .393 .599 r
.6014 .47681 .60246 .48828 .60403 .48642 .60301 .47666 Mtetra
.602 .419 .607 r
.60301 .47666 .60403 .48642 .60548 .47972 .60459 .47564 Mtetra
.644 .498 .669 r
.60459 .47564 .60548 .47972 .60701 .47641 .60618 .47464 Mtetra
.696 .627 .776 r
.60618 .47464 .60701 .47641 .60857 .47437 .60777 .47375 Mtetra
.665 .819 .957 r
.60777 .47375 .60857 .47437 .61016 .47375 .60937 .47321 Mtetra
.628 .832 .979 r
.60937 .47321 .61016 .47375 .61177 .47344 .61097 .47276 Mtetra
.64 .795 .956 r
.61097 .47276 .61177 .47344 .61338 .47322 .61257 .47231 Mtetra
.747 .767 .869 r
.61257 .47231 .61338 .47322 .61497 .47232 .61416 .47137 Mtetra
.69 .745 .893 r
.61416 .47137 .61497 .47232 .61657 .47161 .61576 .47075 Mtetra
.496 .691 .955 r
.61576 .47075 .61657 .47161 .61817 .47131 .61738 .47076 Mtetra
.865 .418 .055 r
.61738 .47076 .61817 .47131 .61983 .47255 .61909 .47405 Mtetra
.963 .681 .452 r
.61909 .47405 .61983 .47255 .62155 .47579 .62634 .66758 Mtetra
.576 .361 .552 r
.62634 .66758 .62155 .47579 .62882 .66546 .62828 .67483 Mtetra
.581 .329 .499 r
.62828 .67483 .62882 .66546 .63077 .67299 .63002 .67563 Mtetra
.519 .187 .344 r
.63002 .67563 .63077 .67299 .63256 .67532 .63175 .67558 Mtetra
0 0 0 r
.63175 .67558 .63256 .67532 .63432 .6763 .63346 .67511 Mtetra
.641 .694 .884 r
.63346 .67511 .63432 .6763 .63604 .67599 .63518 .67468 Mtetra
.66 .681 .859 r
.63518 .67468 .63604 .67599 .63775 .67531 .63689 .67415 Mtetra
.67 .709 .877 r
.63689 .67415 .63775 .67531 .63945 .67448 .6386 .67357 Mtetra
.463 .678 .958 r
.6386 .67357 .63945 .67448 .64119 .67466 .64034 .67366 Mtetra
.598 .715 .926 r
.64034 .67366 .64119 .67466 .64292 .6745 .64207 .67339 Mtetra
.742 .742 .852 r
.64207 .67339 .64292 .6745 .64462 .67358 .64377 .67238 Mtetra
.923 .741 .638 r
.64377 .67238 .64462 .67358 .64617 .66808 .64532 .66693 Mtetra
.967 .69 .453 r
.64532 .66693 .64617 .66808 .64092 .46982 .64013 .4693 Mtetra
.961 .778 .61 r
.64013 .4693 .64092 .46982 .64235 .46399 .64156 .46341 Mtetra
.807 .855 .886 r
.64156 .46341 .64235 .46399 .64394 .46287 .64316 .4622 Mtetra
.617 .794 .967 r
.64316 .4622 .64394 .46287 .64557 .46259 .64478 .46181 Mtetra
.483 .709 .969 r
.64478 .46181 .64557 .46259 .64721 .46272 .64642 .46181 Mtetra
.728 .767 .884 r
.64642 .46181 .64721 .46272 .64883 .46208 .64803 .46099 Mtetra
.684 .717 .874 r
.64803 .46099 .64883 .46208 .65045 .46151 .64965 .46037 Mtetra
.548 .651 .903 r
.64965 .46037 .65045 .46151 .65209 .46131 .65129 .46033 Mtetra
.762 .309 0 r
.65129 .46033 .65209 .46131 .65378 .46252 .65306 .46337 Mtetra
.967 .681 .438 r
.65306 .46337 .65378 .46252 .65556 .46591 .66236 .65709 Mtetra
.576 .361 .552 r
.66236 .65709 .65556 .46591 .66487 .65625 .66441 .66481 Mtetra
.593 .334 .495 r
.66441 .66481 .66487 .65625 .66691 .66361 .66621 .66593 Mtetra
.519 .171 .317 r
.66621 .66593 .66691 .66361 .66876 .66586 .66796 .66595 Mtetra
.327 .812 .814 r
.66796 .66595 .66876 .66586 .67054 .66657 .6697 .66543 Mtetra
.64 .705 .894 r
.6697 .66543 .67054 .66657 .67224 .66532 .67144 .665 Mtetra
.703 .924 .966 r
.67144 .665 .67224 .66532 .67389 .66259 .67316 .66416 Mtetra
.012 0 0 r
.67316 .66416 .67389 .66259 .67538 .65644 .67485 .66252 Mtetra
.046 0 .318 r
.67485 .66252 .67538 .65644 .66866 .46294 .67634 .65643 Mtetra
.038 0 .43 r
.67634 .65643 .66866 .46294 .67009 .45755 .66944 .45971 Mtetra
.735 .748 .235 r
.66944 .45971 .67009 .45755 .67163 .45499 .67087 .45454 Mtetra
.834 .893 .882 r
.67087 .45454 .67163 .45499 .67325 .45409 .67247 .45319 Mtetra
.645 .745 .922 r
.67247 .45319 .67325 .45409 .67489 .45377 .67411 .45275 Mtetra
.546 .677 .924 r
.67411 .45275 .67489 .45377 .67655 .4537 .67576 .45268 Mtetra
.634 .713 .904 r
.67576 .45268 .67655 .4537 .67819 .45332 .67741 .4523 Mtetra
.658 .722 .896 r
.67741 .4523 .67819 .45332 .67983 .45281 .67905 .45181 Mtetra
.662 .729 .899 r
.67905 .45181 .67983 .45281 .68147 .45224 .68069 .45131 Mtetra
.75 .77 .87 r
.68069 .45131 .68147 .45224 .68308 .45114 .68231 .45034 Mtetra
.721 .793 .909 r
.68231 .45034 .68308 .45114 .68471 .45026 .68394 .44957 Mtetra
.523 .755 .981 r
.68394 .44957 .68471 .45026 .68636 .45001 .6856 .44943 Mtetra
.832 .369 0 r
.6856 .44943 .68636 .45001 .68819 .45309 .68743 .45261 Mtetra
.971 .681 .421 r
.68743 .45261 .68819 .45309 .6998 .65042 .69898 .64954 Mtetra
.924 .537 .163 r
.69898 .64954 .6998 .65042 .70192 .6572 .70108 .65603 Mtetra
.222 .481 .891 r
.70108 .65603 .70192 .6572 .70374 .65806 .70291 .65685 Mtetra
.647 .696 .882 r
.70291 .65685 .70374 .65806 .7055 .65761 .70466 .65638 Mtetra
.722 .72 .848 r
.70466 .65638 .7055 .65761 .70724 .65671 .7064 .65546 Mtetra
.666 .698 .87 r
.7064 .65546 .70724 .65671 .709 .65626 .70815 .65489 Mtetra
.643 .669 .859 r
.70815 .65489 .709 .65626 .71076 .65586 .70992 .65443 Mtetra
.659 .666 .846 r
.70992 .65443 .71076 .65586 .71251 .65516 .71167 .65388 Mtetra
.655 .688 .869 r
.71167 .65388 .71251 .65516 .71421 .65355 .71344 .65337 Mtetra
.638 .94 .961 r
.71344 .65337 .71421 .65355 .71585 .65078 .71518 .65259 Mtetra
.168 0 .118 r
.71518 .65259 .71585 .65078 .71733 .64525 .71689 .65113 Mtetra
.162 0 .36 r
.71689 .65113 .71733 .64525 .70826 .45133 .71841 .6461 Mtetra
.062 0 .444 r
.71841 .6461 .70826 .45133 .70961 .44544 .70908 .44859 Mtetra
0 0 0 r
.70908 .44859 .70961 .44544 .71115 .44274 .71042 .44253 Mtetra
.885 .949 .846 r
.71042 .44253 .71115 .44274 .71277 .44164 .71201 .44082 Mtetra
.664 .774 .931 r
.71201 .44082 .71277 .44164 .71444 .44126 .71367 .44029 Mtetra
.56 .698 .933 r
.71367 .44029 .71444 .44126 .71612 .44112 .71536 .44016 Mtetra
.626 .727 .92 r
.71536 .44016 .71612 .44112 .71779 .44067 .71703 .43979 Mtetra
.667 .763 .922 r
.71703 .43979 .71779 .44067 .71944 .44 .71869 .43925 Mtetra
.666 .795 .943 r
.71869 .43925 .71944 .44 .7211 .43932 .72035 .43871 Mtetra
.673 .834 .961 r
.72035 .43871 .7211 .43932 .72275 .43857 .72201 .43811 Mtetra
.65 .873 .982 r
.72201 .43811 .72275 .43857 .7244 .4379 .72367 .43752 Mtetra
.597 .878 .992 r
.72367 .43752 .7244 .4379 .72608 .43752 .72534 .43702 Mtetra
.63 .854 .984 r
.72534 .43702 .72608 .43752 .7278 .43793 .72701 .43651 Mtetra
.616 .637 .848 r
.72701 .43651 .7278 .43793 .7296 .43945 .72869 .43622 Mtetra
.543 .459 .711 r
.72869 .43622 .7296 .43945 .73156 .44357 .73042 .43653 Mtetra
.387 .285 .616 r
.73042 .43653 .73156 .44357 .7456 .63683 .73233 .43989 Mtetra
.085 .007 .461 r
.73233 .43989 .7456 .63683 .74776 .64227 .74666 .63666 Mtetra
.064 .085 .57 r
.74666 .63666 .74776 .64227 .7497 .6443 .74884 .64245 Mtetra
.301 .418 .814 r
.74884 .64245 .7497 .6443 .75156 .64484 .75074 .64359 Mtetra
.613 .678 .888 r
.75074 .64359 .75156 .64484 .75336 .64456 .75253 .64328 Mtetra
.706 .712 .853 r
.75253 .64328 .75336 .64456 .75512 .64373 .7543 .64246 Mtetra
.685 .705 .862 r
.7543 .64246 .75512 .64373 .75684 .64219 .75608 .64176 Mtetra
.669 .898 .978 r
.75608 .64176 .75684 .64219 .75849 .63965 .75785 .64104 Mtetra
.094 0 .006 r
.75785 .64104 .75849 .63965 .76 .63501 .75959 .63971 Mtetra
.173 0 .34 r
.75959 .63971 .76 .63501 .74856 .4415 .76114 .63567 Mtetra
.082 .001 .455 r
.76114 .63567 .74856 .4415 .74974 .43365 .74939 .43859 Mtetra
0 0 .173 r
.74939 .43859 .74974 .43365 .75125 .43062 .75056 .43063 Mtetra
.919 .972 .775 r
.75056 .43063 .75125 .43062 .75287 .42929 .75213 .42848 Mtetra
.682 .786 .928 r
.75213 .42848 .75287 .42929 .75456 .42886 .75381 .42787 Mtetra
.57 .698 .928 r
.75381 .42787 .75456 .42886 .75628 .42873 .75552 .4277 Mtetra
.602 .705 .916 r
.75552 .4277 .75628 .42873 .75798 .42846 .75722 .42743 Mtetra
.659 .728 .901 r
.75722 .42743 .75798 .42846 .75966 .42794 .75891 .42692 Mtetra
.663 .732 .901 r
.75891 .42692 .75966 .42794 .76135 .42736 .7606 .4264 Mtetra
.73 .767 .882 r
.7606 .4264 .76135 .42736 .763 .42639 .76227 .42554 Mtetra
.745 .796 .894 r
.76227 .42554 .763 .42639 .76465 .42535 .76393 .42462 Mtetra
.614 .785 .963 r
.76393 .42462 .76465 .42535 .76635 .42487 .76563 .42423 Mtetra
.516 0 0 r
.76563 .42423 .76635 .42487 .7682 .42657 .76749 .426 Mtetra
.975 .676 .384 r
.76749 .426 .7682 .42657 .78434 .6175 .78363 .61753 Mtetra
.951 .606 .312 r
.78363 .61753 .78434 .6175 .78731 .63248 .78651 .63126 Mtetra
0 .198 .725 r
.78651 .63126 .78731 .63248 .78929 .63426 .78849 .63307 Mtetra
.619 .693 .897 r
.78849 .63307 .78929 .63426 .79111 .63381 .79031 .63272 Mtetra
.725 .752 .874 r
.79031 .63272 .79111 .63381 .79288 .6328 .79209 .63181 Mtetra
.656 .75 .919 r
.79209 .63181 .79288 .6328 .79469 .63228 .7939 .63128 Mtetra
.548 .702 .941 r
.7939 .63128 .79469 .63228 .79654 .63228 .79575 .63115 Mtetra
.683 .732 .887 r
.79575 .63115 .79654 .63228 .79835 .63173 .79755 .63049 Mtetra
.875 .762 .733 r
.79755 .63049 .79835 .63173 .79999 .62902 .79918 .6277 Mtetra
.972 .717 .49 r
.79918 .6277 .79999 .62902 .80061 .61356 .79976 .61176 Mtetra
.976 .683 .394 r
.79976 .61176 .80061 .61356 .78688 .42075 .78617 .42006 Mtetra
.928 .832 .729 r
.78617 .42006 .78688 .42075 .7884 .41791 .78768 .4172 Mtetra
.697 .82 .941 r
.78768 .4172 .7884 .41791 .7901 .41732 .78937 .41651 Mtetra
.543 .736 .965 r
.78937 .41651 .7901 .41732 .79184 .41727 .79111 .41636 Mtetra
.576 .721 .942 r
.79111 .41636 .79184 .41727 .79357 .41707 .79284 .41614 Mtetra
.671 .758 .916 r
.79284 .41614 .79357 .41707 .79527 .41639 .79455 .41558 Mtetra
.657 .78 .939 r
.79455 .41558 .79527 .41639 .79698 .41591 .79626 .41506 Mtetra
.664 .772 .93 r
.79626 .41506 .79698 .41591 .79874 .41603 .79797 .41451 Mtetra
.647 .641 .831 r
.79797 .41451 .79874 .41603 .8006 .41721 .79968 .41403 Mtetra
.573 .481 .713 r
.79968 .41403 .8006 .41721 .80261 .42019 .80144 .41405 Mtetra
.465 .35 .638 r
.80144 .41405 .80261 .42019 .82083 .61106 .80336 .41596 Mtetra
.122 .04 .481 r
.80336 .41596 .82083 .61106 .82345 .61975 .8219 .60984 Mtetra
.088 .065 .534 r
.8219 .60984 .82345 .61975 .82554 .62232 .82468 .62029 Mtetra
.069 .246 .738 r
.82468 .62029 .82554 .62232 .82752 .62341 .82675 .62248 Mtetra
.434 .663 .958 r
.82675 .62248 .82752 .62341 .82941 .62362 .82864 .62265 Mtetra
.709 .777 .905 r
.82864 .62265 .82941 .62362 .83124 .62301 .83045 .62186 Mtetra
.877 .779 .749 r
.83045 .62186 .83124 .62301 .8329 .62059 .83211 .61926 Mtetra
.967 .733 .531 r
.83211 .61926 .8329 .62059 .83388 .61055 .83307 .60909 Mtetra
.977 .68 .377 r
.83307 .60909 .83388 .61055 .81777 .41189 .81707 .41116 Mtetra
.944 .822 .693 r
.81707 .41116 .81777 .41189 .81923 .4085 .81853 .40776 Mtetra
.711 .818 .932 r
.81853 .40776 .81923 .4085 .82095 .40786 .82024 .40701 Mtetra
.551 .728 .957 r
.82024 .40701 .82095 .40786 .82272 .40783 .82199 .40684 Mtetra
.542 .689 .935 r
.82199 .40684 .82272 .40783 .82449 .40787 .82376 .40676 Mtetra
.649 .711 .893 r
.82376 .40676 .82449 .40787 .82623 .40742 .82549 .40629 Mtetra
.653 .708 .888 r
.82549 .40629 .82623 .40742 .82796 .40692 .82723 .4058 Mtetra
.691 .726 .877 r
.82723 .4058 .82796 .40692 .82968 .40627 .82894 .40511 Mtetra
.73 .735 .855 r
.82894 .40511 .82968 .40627 .83138 .40544 .83063 .40418 Mtetra
.657 .688 .868 r
.83063 .40418 .83138 .40544 .8331 .40487 .83237 .40367 Mtetra
.285 .498 .888 r
.83237 .40367 .8331 .40487 .8349 .40502 .83422 .40444 Mtetra
.894 .483 .078 r
.83422 .40444 .8349 .40502 .83686 .40685 .83658 .4104 Mtetra
.973 .666 .363 r
.83658 .4104 .83686 .40685 .83921 .41268 .85757 .60837 Mtetra
.57 .356 .551 r
.85757 .60837 .83921 .41268 .85992 .60621 .85982 .61194 Mtetra
.565 .288 .455 r
.85982 .61194 .85992 .60621 .8622 .61016 .86175 .61227 Mtetra
.465 .107 .273 r
.86175 .61227 .8622 .61016 .86427 .61183 .86363 .61196 Mtetra
.143 .683 .697 r
.86363 .61196 .86427 .61183 .86626 .61262 .8655 .61158 Mtetra
.512 .679 .941 r
.8655 .61158 .86626 .61262 .86819 .61287 .86741 .61158 Mtetra
.656 .697 .876 r
.86741 .61158 .86819 .61287 .87006 .61237 .86927 .61104 Mtetra
.825 .751 .782 r
.86927 .61104 .87006 .61237 .87177 .61036 .87099 .60908 Mtetra
.966 .746 .553 r
.87099 .60908 .87177 .61036 .87284 .6021 .87208 .60096 Mtetra
.977 .677 .357 r
.87208 .60096 .87284 .6021 .85422 .40112 .85355 .40052 Mtetra
.97 .83 .648 r
.85355 .40052 .85422 .40112 .85561 .39711 .85493 .39646 Mtetra
.737 .855 .936 r
.85493 .39646 .85561 .39711 .85733 .39632 .85664 .39558 Mtetra
.567 .768 .973 r
.85664 .39558 .85733 .39632 .85911 .39617 .85842 .39531 Mtetra
.527 .718 .96 r
.85842 .39531 .85911 .39617 .86092 .39619 .86021 .39522 Mtetra
.666 .749 .913 r
.86021 .39522 .86092 .39619 .86267 .39569 .86196 .39466 Mtetra
.671 .739 .901 r
.86196 .39466 .86267 .39569 .86441 .39513 .8637 .39408 Mtetra
.697 .745 .888 r
.8637 .39408 .86441 .39513 .86614 .39438 .86544 .39337 Mtetra
.756 .774 .868 r
.86544 .39337 .86614 .39438 .86783 .39321 .86713 .39232 Mtetra
.678 .775 .923 r
.86713 .39232 .86783 .39321 .86956 .39249 .86888 .3917 Mtetra
.243 .574 .941 r
.86888 .3917 .86956 .39249 .87142 .39295 .87075 .39222 Mtetra
.878 .468 .029 r
.87075 .39222 .87142 .39295 .87391 .39925 .87323 .39844 Mtetra
.974 .664 .326 r
.87323 .39844 .87391 .39925 .8976 .60005 .89682 .59869 Mtetra
0 0 .424 r
.89682 .59869 .8976 .60005 .89993 .60371 .89916 .60242 Mtetra
.464 .601 .903 r
.89916 .60242 .89993 .60371 .90187 .60377 .90113 .6027 Mtetra
.695 .757 .9 r
.90113 .6027 .90187 .60377 .90372 .60291 .90299 .60196 Mtetra
.86 .821 .809 r
.90299 .60196 .90372 .60291 .90547 .60122 .90471 .59998 Mtetra
.956 .765 .606 r
.90471 .59998 .90547 .60122 .9071 .59841 .90601 .59427 Mtetra
.976 .671 .35 r
.90601 .59427 .9071 .59841 .90842 .59287 .88547 .39371 Mtetra
.574 .363 .557 r
.88547 .39371 .90842 .59287 .8882 .39653 .88664 .38787 Mtetra
.62 .437 .612 r
.88664 .38787 .8882 .39653 .88931 .3902 .88829 .38632 Mtetra
.635 .5 .68 r
.88829 .38632 .88931 .3902 .89081 .38734 .89002 .38546 Mtetra
.645 .604 .794 r
.89002 .38546 .89081 .38734 .89245 .38564 .89179 .38493 Mtetra
.65 .816 .963 r
.89179 .38493 .89245 .38564 .8942 .38502 .89356 .38439 Mtetra
.614 .822 .98 r
.89356 .38439 .8942 .38502 .896 .38472 .89534 .38393 Mtetra
.629 .785 .957 r
.89534 .38393 .896 .38472 .8978 .38448 .89712 .38348 Mtetra
.675 .751 .908 r
.89712 .38348 .8978 .38448 .89956 .38379 .89888 .38287 Mtetra
.679 .771 .92 r
.89888 .38287 .89956 .38379 .90131 .38307 .90064 .38225 Mtetra
.685 .799 .936 r
.90064 .38225 .90131 .38307 .90306 .38233 .9024 .38159 Mtetra
.749 .84 .92 r
.9024 .38159 .90306 .38233 .9048 .38151 .90413 .38064 Mtetra
.673 .783 .932 r
.90413 .38064 .9048 .38151 .90657 .38093 .9059 .38004 Mtetra
.447 .669 .957 r
.9059 .38004 .90657 .38093 .9084 .38084 .90775 .38018 Mtetra
.757 .297 0 r
.90775 .38018 .9084 .38084 .91045 .38257 .91005 .38399 Mtetra
.972 .658 .313 r
.91005 .38399 .91045 .38257 .91282 .38694 .936 .58366 Mtetra
.573 .358 .551 r
.936 .58366 .91282 .38694 .93825 .5811 .93869 .58965 Mtetra
.561 .305 .486 r
.93869 .58965 .93825 .5811 .9404 .58267 .94068 .58984 Mtetra
.525 .27 .471 r
.94068 .58984 .9404 .58267 .94224 .58158 .94257 .58917 Mtetra
.51 .262 .474 r
.94257 .58917 .94224 .58158 .94386 .57884 .94441 .58808 Mtetra
.535 .29 .49 r
.94441 .58808 .94386 .57884 .94544 .57568 .94631 .58744 Mtetra
.544 .305 .504 r
.94631 .58744 .94544 .57568 .94721 .57411 .94821 .58686 Mtetra
.548 .311 .508 r
.94821 .58686 .94721 .57411 .94955 .5771 .95013 .58642 Mtetra
.556 .305 .491 r
.95013 .58642 .94955 .5771 .95229 .58316 .95211 .58643 Mtetra
.534 .217 .376 r
.95211 .58643 .95229 .58316 .95461 .5859 .9541 .58646 Mtetra
.304 0 0 r
.9541 .58646 .95461 .5859 .95677 .58732 .95607 .58641 Mtetra
.739 .856 .935 r
.33854 .75553 .33952 .75599 .34103 .75619 .3401 .75472 Mtetra
.746 .673 .779 r
.3401 .75472 .34103 .75619 .34256 .75593 .34168 .75346 Mtetra
.752 .61 .701 r
.34168 .75346 .34256 .75593 .34413 .75494 .34331 .75133 Mtetra
.85 .638 .614 r
.34331 .75133 .34413 .75494 .3459 .7499 .3453 .74205 Mtetra
.927 .676 .539 r
.3453 .74205 .3459 .7499 .35695 .55812 .35616 .555 Mtetra
.788 .606 .655 r
.35616 .555 .35695 .55812 .35869 .55202 .35779 .55113 Mtetra
.76 .748 .841 r
.35779 .55113 .35869 .55202 .36018 .55086 .35928 .55012 Mtetra
.653 .765 .931 r
.35928 .55012 .36018 .55086 .36164 .55045 .36074 .54969 Mtetra
.561 .733 .956 r
.36074 .54969 .36164 .55045 .36308 .5504 .36219 .54953 Mtetra
.76 .753 .846 r
.36219 .54953 .36308 .5504 .36457 .54951 .36368 .54854 Mtetra
.71 .727 .863 r
.36368 .54854 .36457 .54951 .36604 .54889 .36515 .54784 Mtetra
.552 .658 .907 r
.36515 .54784 .36604 .54889 .36748 .54893 .3666 .54779 Mtetra
.918 .522 .154 r
.3666 .54779 .36748 .54893 .36874 .55285 .36787 .55145 Mtetra
.94 .684 .521 r
.36787 .55145 .36874 .55285 .36143 .74402 .3605 .74276 Mtetra
.95 .6 .299 r
.3605 .74276 .36143 .74402 .36272 .7493 .36177 .74848 Mtetra
0 .315 .774 r
.36177 .74848 .36272 .7493 .36421 .75015 .36326 .74936 Mtetra
.613 .754 .945 r
.36326 .74936 .36421 .75015 .36576 .74982 .36481 .74904 Mtetra
.801 .782 .836 r
.36481 .74904 .36576 .74982 .36736 .74848 .36641 .7477 Mtetra
.906 .744 .669 r
.36641 .7477 .36736 .74848 .3691 .74373 .36815 .74295 Mtetra
.939 .687 .529 r
.36815 .74295 .3691 .74373 .37894 .5518 .37804 .55096 Mtetra
.915 .726 .632 r
.37804 .55096 .37894 .5518 .38067 .54531 .37978 .54446 Mtetra
.801 .761 .816 r
.37978 .54446 .38067 .54531 .38218 .54396 .38129 .5431 Mtetra
.655 .738 .911 r
.38129 .5431 .38218 .54396 .38365 .54353 .38276 .54267 Mtetra
.527 .695 .945 r
.38276 .54267 .38365 .54353 .38511 .54349 .38422 .54263 Mtetra
.735 .753 .867 r
.38422 .54263 .38511 .54349 .3866 .54267 .38571 .54181 Mtetra
.707 .748 .884 r
.38571 .54181 .3866 .54267 .38808 .54202 .38719 .54115 Mtetra
.534 .695 .942 r
.38719 .54115 .38808 .54202 .38954 .54196 .38865 .54109 Mtetra
.901 .486 .139 r
.38865 .54109 .38954 .54196 .39087 .54521 .38998 .5443 Mtetra
.942 .684 .516 r
.38998 .5443 .39087 .54521 .38482 .73603 .38388 .7351 Mtetra
.945 .604 .346 r
.38388 .7351 .38482 .73603 .38612 .74234 .38518 .7415 Mtetra
.071 .473 .89 r
.38518 .7415 .38612 .74234 .38765 .74298 .3867 .74214 Mtetra
.671 .759 .916 r
.3867 .74214 .38765 .74298 .38922 .74245 .38828 .74162 Mtetra
.753 .772 .869 r
.38828 .74162 .38922 .74245 .39081 .74147 .38987 .74065 Mtetra
.668 .762 .92 r
.38987 .74065 .39081 .74147 .39238 .74086 .39144 .74014 Mtetra
.618 .774 .955 r
.39144 .74014 .39238 .74086 .39396 .74039 .39301 .73978 Mtetra
.6 .8 .977 r
.39301 .73978 .39396 .74039 .39553 .73995 .39457 .73944 Mtetra
.594 .826 .988 r
.39457 .73944 .39553 .73995 .3971 .73959 .39614 .73907 Mtetra
.6 .824 .986 r
.39614 .73907 .3971 .73959 .39866 .73927 .39771 .7387 Mtetra
.61 .81 .977 r
.39771 .7387 .39866 .73927 .40023 .73897 .39929 .73832 Mtetra
.613 .792 .967 r
.39929 .73832 .40023 .73897 .4018 .7387 .40086 .73796 Mtetra
.621 .77 .952 r
.40086 .73796 .4018 .7387 .40337 .73838 .40243 .73759 Mtetra
.627 .762 .944 r
.40243 .73759 .40337 .73838 .40495 .73794 .40401 .73722 Mtetra
.5 .735 .978 r
.40401 .73722 .40495 .73794 .40653 .73753 .40557 .73715 Mtetra
.475 .82 .998 r
.40557 .73715 .40653 .73753 .40811 .73681 .40715 .73693 Mtetra
.562 .934 .901 r
.40715 .73693 .40811 .73681 .40973 .73539 .40874 .73619 Mtetra
.949 .957 .686 r
.40874 .73619 .40973 .73539 .41146 .73005 .4104 .73315 Mtetra
.996 .834 .482 r
.4104 .73315 .41146 .73005 .41907 .53804 .4123 .72269 Mtetra
0 0 .32 r
.4123 .72269 .41907 .53804 .42072 .53271 .41974 .53502 Mtetra
0 0 .06 r
.41974 .53502 .42072 .53271 .42225 .53116 .42129 .53289 Mtetra
.405 .033 .215 r
.42129 .53289 .42225 .53116 .42374 .53066 .42278 .53245 Mtetra
.492 .125 .271 r
.42278 .53245 .42374 .53066 .42523 .53054 .42427 .53238 Mtetra
.214 0 .129 r
.42427 .53238 .42523 .53054 .42672 .53026 .42579 .53127 Mtetra
0 0 0 r
.42579 .53127 .42672 .53026 .42821 .52989 .42732 .52981 Mtetra
.831 .948 .897 r
.42732 .52981 .42821 .52989 .42971 .5295 .42884 .52855 Mtetra
.721 .737 .864 r
.42884 .52855 .42971 .5295 .43121 .52904 .43035 .52778 Mtetra
.659 .665 .845 r
.43035 .52778 .43121 .52904 .43271 .52854 .43185 .52731 Mtetra
.636 .662 .858 r
.43185 .52731 .43271 .52854 .43421 .52802 .43334 .52696 Mtetra
.634 .69 .884 r
.43334 .52696 .43421 .52802 .43572 .52749 .43484 .52661 Mtetra
.634 .73 .917 r
.43484 .52661 .43572 .52749 .43722 .52698 .43634 .52625 Mtetra
.635 .767 .943 r
.43634 .52625 .43722 .52698 .43872 .52656 .43785 .52587 Mtetra
.668 .787 .937 r
.43785 .52587 .43872 .52656 .44022 .5264 .43935 .52537 Mtetra
.685 .714 .871 r
.43935 .52537 .44022 .5264 .44171 .52643 .44086 .52479 Mtetra
.667 .621 .794 r
.44086 .52479 .44171 .52643 .44321 .52648 .44237 .5242 Mtetra
.643 .558 .743 r
.44237 .5242 .44321 .52648 .44471 .52624 .44388 .52365 Mtetra
.633 .535 .726 r
.44388 .52365 .44471 .52624 .44622 .52574 .44539 .52315 Mtetra
.631 .534 .726 r
.44539 .52315 .44622 .52574 .44773 .52516 .4469 .52266 Mtetra
.655 .552 .726 r
.4469 .52266 .44773 .52516 .44925 .52429 .44841 .52194 Mtetra
.655 .56 .736 r
.44841 .52194 .44925 .52429 .45076 .52353 .44993 .52127 Mtetra
.608 .539 .752 r
.44993 .52127 .45076 .52353 .45227 .52339 .45143 .52102 Mtetra
.244 .31 .733 r
.45143 .52102 .45227 .52339 .45371 .52612 .4529 .52249 Mtetra
.744 .48 0 r
.4529 .52249 .45371 .52612 .45124 .71733 .45427 .52904 Mtetra
0 0 .352 r
.45427 .52904 .45124 .71733 .4527 .72377 .45186 .71917 Mtetra
.337 .281 .646 r
.45186 .71917 .4527 .72377 .45427 .725 .45341 .72145 Mtetra
.596 .483 .695 r
.45341 .72145 .45427 .725 .45588 .7247 .45501 .72122 Mtetra
.648 .518 .691 r
.45501 .72122 .45588 .7247 .45749 .72397 .45663 .72033 Mtetra
.634 .505 .688 r
.45663 .72033 .45749 .72397 .4591 .72338 .45824 .71959 Mtetra
.611 .486 .686 r
.45824 .71959 .4591 .72338 .46071 .723 .45985 .71915 Mtetra
.611 .485 .684 r
.45985 .71915 .46071 .723 .46232 .72261 .46146 .7187 Mtetra
.61 .483 .682 r
.46146 .7187 .46232 .72261 .46393 .7222 .46307 .71826 Mtetra
.609 .481 .681 r
.46307 .71826 .46393 .7222 .46554 .72178 .46468 .71783 Mtetra
.46468 .71783 .46554 .72178 .46716 .72134 .46629 .7174 Mtetra
.609 .481 .682 r
.46629 .7174 .46716 .72134 .46877 .7209 .4679 .71697 Mtetra
.609 .482 .682 r
.4679 .71697 .46877 .7209 .47039 .72046 .46952 .71653 Mtetra
.46952 .71653 .47039 .72046 .472 .72003 .47113 .71609 Mtetra
.61 .482 .682 r
.47113 .71609 .472 .72003 .47362 .71958 .47275 .71565 Mtetra
.47275 .71565 .47362 .71958 .47524 .71914 .47437 .71521 Mtetra
.61 .483 .682 r
.47437 .71521 .47524 .71914 .47686 .71869 .47599 .71475 Mtetra
.611 .483 .682 r
.47599 .71475 .47686 .71869 .47848 .71824 .47761 .71429 Mtetra
.612 .483 .681 r
.47761 .71429 .47848 .71824 .4801 .71778 .47923 .71381 Mtetra
.47923 .71381 .4801 .71778 .48172 .71731 .48085 .71333 Mtetra
.62 .488 .679 r
.48085 .71333 .48172 .71731 .48334 .71684 .48247 .71273 Mtetra
.622 .486 .676 r
.48247 .71273 .48334 .71684 .48497 .71636 .4841 .71209 Mtetra
.605 .472 .673 r
.4841 .71209 .48497 .71636 .48659 .71587 .48572 .71167 Mtetra
.553 .439 .677 r
.48572 .71167 .48659 .71587 .48822 .71536 .48734 .71193 Mtetra
.497 .425 .705 r
.48734 .71193 .48822 .71536 .48985 .71481 .48895 .71262 Mtetra
.478 .482 .783 r
.48895 .71262 .48985 .71481 .49148 .71427 .49057 .71313 Mtetra
.523 .647 .912 r
.49057 .71313 .49148 .71427 .49311 .71375 .4922 .71316 Mtetra
.619 .817 .977 r
.4922 .71316 .49311 .71375 .49474 .71325 .49383 .71274 Mtetra
.657 .848 .973 r
.49383 .71274 .49474 .71325 .49637 .71276 .49546 .71218 Mtetra
.661 .829 .964 r
.49546 .71218 .49637 .71276 .498 .71229 .49709 .71163 Mtetra
.643 .806 .961 r
.49709 .71163 .498 .71229 .49963 .71182 .49873 .71116 Mtetra
.641 .805 .961 r
.49873 .71116 .49963 .71182 .50126 .71136 .50036 .7107 Mtetra
.639 .802 .961 r
.50036 .7107 .50126 .71136 .5029 .71091 .502 .71024 Mtetra
.636 .8 .961 r
.502 .71024 .5029 .71091 .50453 .71047 .50363 .70979 Mtetra
.634 .797 .961 r
.50363 .70979 .50453 .71047 .50617 .71003 .50527 .70935 Mtetra
.634 .796 .96 r
.50527 .70935 .50617 .71003 .50781 .70964 .50691 .70891 Mtetra
.636 .785 .953 r
.50691 .70891 .50781 .70964 .50944 .70927 .50855 .70847 Mtetra
.634 .768 .944 r
.50855 .70847 .50944 .70927 .51108 .70883 .51019 .70806 Mtetra
.616 .769 .953 r
.51019 .70806 .51108 .70883 .51273 .70816 .51183 .70769 Mtetra
.543 .827 .998 r
.51183 .70769 .51273 .70816 .51437 .70721 .51347 .70739 Mtetra
0 0 0 r
.51347 .70739 .51437 .70721 .51601 .70619 .51511 .70706 Mtetra
.239 0 0 r
.51511 .70706 .51601 .70619 .51765 .70535 .51675 .70665 Mtetra
.314 0 .069 r
.51675 .70665 .51765 .70535 .5193 .70486 .5184 .70613 Mtetra
.298 0 .051 r
.5184 .70613 .5193 .70486 .52094 .70449 .52005 .70559 Mtetra
.265 0 0 r
.52005 .70559 .52094 .70449 .52259 .70414 .52169 .70508 Mtetra
.247 0 0 r
.52169 .70508 .52259 .70414 .52423 .70373 .52334 .70463 Mtetra
.24 0 0 r
.52334 .70463 .52423 .70373 .52588 .70332 .52499 .70421 Mtetra
.302 0 0 r
.52499 .70421 .52588 .70332 .52753 .70311 .52664 .70392 Mtetra
.342 0 0 r
.52664 .70392 .52753 .70311 .52918 .7031 .52829 .70377 Mtetra
.077 0 0 r
.52829 .70377 .52918 .7031 .53083 .70255 .52994 .70325 Mtetra
.643 .92 .634 r
.52994 .70325 .53083 .70255 .53248 .70019 .53159 .70157 Mtetra
.966 .9 .532 r
.53159 .70157 .53248 .70019 .53409 .68236 .53324 .69663 Mtetra
.976 .711 .462 r
.53324 .69663 .53409 .68236 .53516 .49887 .53434 .50364 Mtetra
0 0 .095 r
.53434 .50364 .53516 .49887 .53671 .49584 .53589 .49723 Mtetra
0 0 0 r
.53589 .49723 .53671 .49584 .53827 .4951 .53744 .49533 Mtetra
.693 .982 .843 r
.53744 .49533 .53827 .4951 .53983 .49486 .539 .49419 Mtetra
.717 .81 .923 r
.539 .49419 .53983 .49486 .5414 .49471 .54056 .49347 Mtetra
.653 .673 .857 r
.54056 .49347 .5414 .49471 .54296 .49419 .54212 .49302 Mtetra
.625 .673 .875 r
.54212 .49302 .54296 .49419 .54452 .49373 .54369 .4927 Mtetra
.636 .706 .897 r
.54369 .4927 .54452 .49373 .54609 .49339 .54525 .49233 Mtetra
.686 .715 .871 r
.54525 .49233 .54609 .49339 .54765 .4933 .54682 .49172 Mtetra
.672 .634 .804 r
.54682 .49172 .54765 .4933 .54922 .49326 .54838 .49109 Mtetra
.662 .578 .751 r
.54838 .49109 .54922 .49326 .55079 .49295 .54995 .49039 Mtetra
.661 .555 .724 r
.54995 .49039 .55079 .49295 .55236 .49205 .55151 .48959 Mtetra
.628 .541 .737 r
.55151 .48959 .55236 .49205 .55392 .49158 .55308 .48914 Mtetra
.492 .463 .753 r
.55308 .48914 .55392 .49158 .55551 .4926 .55466 .48966 Mtetra
0 0 .485 r
.55466 .48966 .55551 .4926 .55886 .6753 .55627 .49355 Mtetra
0 0 .382 r
.55627 .49355 .55886 .6753 .5607 .6928 .55977 .68631 Mtetra
.151 .122 .568 r
.55977 .68631 .5607 .6928 .5624 .69531 .56149 .69147 Mtetra
.565 .457 .69 r
.56149 .69147 .5624 .69531 .56408 .69525 .56317 .69158 Mtetra
.631 .504 .69 r
.56317 .69158 .56408 .69525 .56575 .69463 .56484 .69088 Mtetra
.648 .512 .684 r
.56484 .69088 .56575 .69463 .56742 .69384 .5665 .68991 Mtetra
.611 .484 .683 r
.5665 .68991 .56742 .69384 .56909 .69338 .56818 .68943 Mtetra
.612 .485 .683 r
.56818 .68943 .56909 .69338 .57077 .69291 .56985 .68895 Mtetra
.612 .484 .683 r
.56985 .68895 .57077 .69291 .57244 .69244 .57153 .68846 Mtetra
.611 .483 .682 r
.57153 .68846 .57244 .69244 .57412 .69197 .5732 .688 Mtetra
.61 .483 .682 r
.5732 .688 .57412 .69197 .5758 .69151 .57488 .68753 Mtetra
.57488 .68753 .5758 .69151 .57748 .69105 .57656 .68706 Mtetra
.57656 .68706 .57748 .69105 .57916 .69059 .57824 .6866 Mtetra
.57824 .6866 .57916 .69059 .58084 .69012 .57992 .68614 Mtetra
.57992 .68614 .58084 .69012 .58252 .68966 .5816 .68567 Mtetra
.5816 .68567 .58252 .68966 .58421 .6892 .58329 .68521 Mtetra
.58329 .68521 .58421 .6892 .58589 .68873 .58497 .68475 Mtetra
.61 .482 .682 r
.58497 .68475 .58589 .68873 .58758 .68827 .58665 .68429 Mtetra
.609 .482 .682 r
.58665 .68429 .58758 .68827 .58926 .68782 .58834 .68384 Mtetra
.609 .482 .683 r
.58834 .68384 .58926 .68782 .59095 .68736 .59003 .68339 Mtetra
.604 .479 .683 r
.59003 .68339 .59095 .68736 .59264 .68693 .59172 .68302 Mtetra
.567 .457 .688 r
.59172 .68302 .59264 .68693 .59434 .68678 .59342 .6831 Mtetra
.612 .492 .692 r
.59342 .6831 .59434 .68678 .59603 .68626 .59511 .68265 Mtetra
.697 .547 .679 r
.59511 .68265 .59603 .68626 .5977 .6849 .59677 .68089 Mtetra
.902 .659 .562 r
.59677 .68089 .5977 .6849 .59929 .67973 .59814 .66494 Mtetra
.944 .671 .49 r
.59814 .66494 .59929 .67973 .59675 .48444 .59584 .47912 Mtetra
.723 .532 .631 r
.59584 .47912 .59675 .48444 .59822 .47819 .59737 .47561 Mtetra
.67 .561 .722 r
.59737 .47561 .59822 .47819 .5998 .47715 .59896 .47469 Mtetra
.622 .54 .74 r
.59896 .47469 .5998 .47715 .6014 .47681 .60055 .47429 Mtetra
.592 .519 .742 r
.60055 .47429 .6014 .47681 .60301 .47666 .60216 .47414 Mtetra
.619 .535 .737 r
.60216 .47414 .60301 .47666 .60459 .47564 .60376 .47376 Mtetra
.628 .585 .786 r
.60376 .47376 .60459 .47564 .60618 .47464 .60536 .47338 Mtetra
.646 .67 .859 r
.60536 .47338 .60618 .47464 .60777 .47375 .60696 .47295 Mtetra
.708 .783 .911 r
.60696 .47295 .60777 .47375 .60937 .47321 .60856 .47226 Mtetra
.692 .744 .891 r
.60856 .47226 .60937 .47321 .61097 .47276 .61015 .47162 Mtetra
.655 .696 .876 r
.61015 .47162 .61097 .47276 .61257 .47231 .61176 .47116 Mtetra
.584 .663 .892 r
.61176 .47116 .61257 .47231 .61416 .47137 .61337 .47099 Mtetra
.057 .572 .878 r
.61337 .47099 .61416 .47137 .61576 .47075 .615 .47131 Mtetra
.704 .237 .139 r
.615 .47131 .61576 .47075 .61738 .47076 .61665 .47265 Mtetra
.925 .619 .443 r
.61665 .47265 .61738 .47076 .61909 .47405 .61877 .49015 Mtetra
.94 .658 .479 r
.61877 .49015 .61909 .47405 .62634 .66758 .62567 .67292 Mtetra
.678 .387 .474 r
.62567 .67292 .62634 .66758 .62828 .67483 .62748 .67583 Mtetra
.407 0 .041 r
.62748 .67583 .62828 .67483 .63002 .67563 .6292 .67575 Mtetra
.433 .874 .836 r
.6292 .67575 .63002 .67563 .63175 .67558 .63091 .67507 Mtetra
.758 .877 .933 r
.63091 .67507 .63175 .67558 .63346 .67511 .63261 .67409 Mtetra
.6 .712 .923 r
.63261 .67409 .63346 .67511 .63518 .67468 .63433 .67382 Mtetra
.605 .75 .947 r
.63433 .67382 .63518 .67468 .63689 .67415 .63605 .67349 Mtetra
.642 .816 .967 r
.63605 .67349 .63689 .67415 .6386 .67357 .63777 .67299 Mtetra
.725 .854 .942 r
.63777 .67299 .6386 .67357 .64034 .67366 .63947 .67216 Mtetra
.754 .69 .791 r
.63947 .67216 .64034 .67366 .64207 .67339 .64116 .67083 Mtetra
.762 .618 .7 r
.64116 .67083 .64207 .67339 .64377 .67238 .64282 .66853 Mtetra
.877 .647 .586 r
.64282 .66853 .64377 .67238 .64532 .66693 .6442 .6582 Mtetra
.958 .68 .467 r
.6442 .6582 .64532 .66693 .64013 .4693 .63927 .4665 Mtetra
.813 .63 .655 r
.63927 .4665 .64013 .4693 .64156 .46341 .64077 .46258 Mtetra
.775 .795 .869 r
.64077 .46258 .64156 .46341 .64316 .4622 .64237 .4615 Mtetra
.642 .793 .955 r
.64237 .4615 .64316 .4622 .64478 .46181 .64399 .46104 Mtetra
.553 .742 .964 r
.64399 .46104 .64478 .46181 .64642 .46181 .64563 .46087 Mtetra
.756 .766 .861 r
.64563 .46087 .64642 .46181 .64803 .46099 .64723 .45986 Mtetra
.704 .716 .859 r
.64723 .45986 .64803 .46099 .64965 .46037 .64884 .45913 Mtetra
.564 .638 .882 r
.64884 .45913 .64965 .46037 .65129 .46033 .65049 .45905 Mtetra
.787 .372 0 r
.65049 .45905 .65129 .46033 .65306 .46337 .65228 .46287 Mtetra
.968 .683 .435 r
.65228 .46287 .65306 .46337 .66236 .65709 .66167 .66003 Mtetra
.808 .481 .435 r
.66167 .66003 .66236 .65709 .66441 .66481 .66364 .66564 Mtetra
.516 .035 .053 r
.66364 .66564 .66441 .66481 .66621 .66593 .66541 .66603 Mtetra
.404 .857 .833 r
.66541 .66603 .66621 .66593 .66796 .66595 .66714 .6654 Mtetra
.772 .873 .922 r
.66714 .6654 .66796 .66595 .6697 .66543 .66885 .66434 Mtetra
.566 .683 .919 r
.66885 .66434 .6697 .66543 .67144 .665 .67061 .6642 Mtetra
.567 .753 .965 r
.67061 .6642 .67144 .665 .67316 .66416 .67235 .66396 Mtetra
.651 .938 .965 r
.67235 .66396 .67316 .66416 .67485 .66252 .67408 .66318 Mtetra
.931 .948 .613 r
.67408 .66318 .67485 .66252 .67634 .65643 .6757 .65989 Mtetra
.901 .767 .273 r
.6757 .65989 .67634 .65643 .66944 .45971 .67698 .64895 Mtetra
.038 0 .43 r
.67698 .64895 .66944 .45971 .67087 .45454 .67022 .45673 Mtetra
0 0 .048 r
.67022 .45673 .67087 .45454 .67247 .45319 .67175 .45387 Mtetra
0 0 0 r
.67175 .45387 .67247 .45319 .67411 .45275 .67335 .45243 Mtetra
.738 .927 .953 r
.67335 .45243 .67411 .45275 .67576 .45268 .67497 .45154 Mtetra
.675 .705 .87 r
.67497 .45154 .67576 .45268 .67741 .4523 .67661 .45096 Mtetra
.635 .655 .853 r
.67661 .45096 .67741 .4523 .67905 .45181 .67825 .45057 Mtetra
.614 .663 .875 r
.67825 .45057 .67905 .45181 .68069 .45131 .67991 .45029 Mtetra
.711 .742 .876 r
.67991 .45029 .68069 .45131 .68231 .45034 .68154 .44954 Mtetra
.698 .785 .918 r
.68154 .44954 .68231 .45034 .68394 .44957 .68317 .44887 Mtetra
.542 .758 .977 r
.68317 .44887 .68394 .44957 .6856 .44943 .68483 .44869 Mtetra
.656 .158 0 r
.68483 .44869 .6856 .44943 .68743 .45261 .68661 .45089 Mtetra
.972 .683 .416 r
.68661 .45089 .68743 .45261 .69898 .64954 .69696 .62457 Mtetra
0 0 .449 r
.69696 .62457 .69898 .64954 .70108 .65603 .7001 .65195 Mtetra
.484 .401 .687 r
.7001 .65195 .70108 .65603 .70291 .65685 .70193 .65297 Mtetra
.618 .492 .687 r
.70193 .65297 .70291 .65685 .70466 .65638 .70369 .6524 Mtetra
.639 .503 .681 r
.70369 .6524 .70466 .65638 .7064 .65546 .70542 .6515 Mtetra
.548 .445 .69 r
.70542 .6515 .7064 .65546 .70815 .65489 .70722 .65182 Mtetra
.499 .446 .729 r
.70722 .65182 .70815 .65489 .70992 .65443 .70904 .65247 Mtetra
.489 .516 .812 r
.70904 .65247 .70992 .65443 .71167 .65388 .71085 .65289 Mtetra
.46 .659 .947 r
.71085 .65289 .71167 .65388 .71344 .65337 .71265 .65303 Mtetra
.451 .831 .989 r
.71265 .65303 .71344 .65337 .71518 .65259 .71443 .65275 Mtetra
.491 .901 .813 r
.71443 .65275 .71518 .65259 .71689 .65113 .71617 .65187 Mtetra
.844 .939 .571 r
.71617 .65187 .71689 .65113 .71841 .6461 .7178 .649 Mtetra
.81 .739 .215 r
.7178 .649 .71841 .6461 .70908 .44859 .71915 .64093 Mtetra
.059 0 .443 r
.71915 .64093 .70908 .44859 .71042 .44253 .70986 .44525 Mtetra
0 0 .128 r
.70986 .44525 .71042 .44253 .71201 .44082 .71135 .44172 Mtetra
0 0 0 r
.71135 .44172 .71201 .44082 .71367 .44029 .71295 .44015 Mtetra
.723 .967 .937 r
.71295 .44015 .71367 .44029 .71536 .44016 .71459 .43917 Mtetra
.686 .743 .894 r
.71459 .43917 .71536 .44016 .71703 .43979 .71624 .43854 Mtetra
.639 .674 .867 r
.71624 .43854 .71703 .43979 .71869 .43925 .71791 .43813 Mtetra
.614 .687 .895 r
.71791 .43813 .71869 .43925 .72035 .43871 .71959 .43783 Mtetra
.636 .752 .932 r
.71959 .43783 .72035 .43871 .72201 .43811 .72126 .43741 Mtetra
.655 .806 .956 r
.72126 .43741 .72201 .43811 .72367 .43752 .72293 .43689 Mtetra
.662 .827 .963 r
.72293 .43689 .72367 .43752 .72534 .43702 .7246 .43633 Mtetra
.745 .832 .918 r
.7246 .43633 .72534 .43702 .72701 .43651 .72624 .43545 Mtetra
.724 .742 .866 r
.72624 .43545 .72701 .43651 .72869 .43622 .72789 .4346 Mtetra
.632 .619 .819 r
.72789 .4346 .72869 .43622 .73042 .43653 .72957 .43421 Mtetra
.317 .368 .757 r
.72957 .43421 .73042 .43653 .73233 .43989 .73136 .43561 Mtetra
0 0 .463 r
.73136 .43561 .73233 .43989 .74666 .63666 .73348 .44204 Mtetra
.082 .005 .46 r
.73348 .44204 .74666 .63666 .74884 .64245 .74778 .63752 Mtetra
.32 .273 .648 r
.74778 .63752 .74884 .64245 .75074 .64359 .74979 .64052 Mtetra
.491 .442 .73 r
.74979 .64052 .75074 .64359 .75253 .64328 .75166 .64125 Mtetra
.555 .547 .8 r
.75166 .64125 .75253 .64328 .7543 .64246 .75349 .64133 Mtetra
.528 .661 .921 r
.75349 .64133 .7543 .64246 .75608 .64176 .75531 .64132 Mtetra
.463 .812 .998 r
.75531 .64132 .75608 .64176 .75785 .64104 .75712 .64109 Mtetra
.502 .909 .864 r
.75712 .64109 .75785 .64104 .75959 .63971 .75889 .6403 Mtetra
.801 .949 .605 r
.75889 .6403 .75959 .63971 .76114 .63567 .76055 .63786 Mtetra
.794 .756 .24 r
.76055 .63786 .76114 .63567 .74939 .43859 .76194 .63145 Mtetra
.076 0 .453 r
.76194 .63145 .74939 .43859 .75056 .43063 .75011 .43406 Mtetra
0 0 .198 r
.75011 .43406 .75056 .43063 .75213 .42848 .75153 .42958 Mtetra
0 0 0 r
.75153 .42958 .75213 .42848 .75381 .42787 .75313 .42785 Mtetra
.699 .98 .897 r
.75313 .42785 .75381 .42787 .75552 .4277 .75477 .42678 Mtetra
.698 .765 .904 r
.75477 .42678 .75552 .4277 .75722 .42743 .75645 .4261 Mtetra
.645 .666 .855 r
.75645 .4261 .75722 .42743 .75891 .42692 .75814 .42565 Mtetra
.621 .664 .87 r
.75814 .42565 .75891 .42692 .7606 .4264 .75984 .42532 Mtetra
.686 .728 .882 r
.75984 .42532 .7606 .4264 .76227 .42554 .76153 .42468 Mtetra
.721 .788 .905 r
.76153 .42468 .76227 .42554 .76393 .42462 .7632 .42389 Mtetra
.614 .785 .963 r
.7632 .42389 .76393 .42462 .76563 .42423 .7649 .4235 Mtetra
0 .29 .761 r
.7649 .4235 .76563 .42423 .76749 .426 .76672 .42465 Mtetra
.846 .455 0 r
.76672 .42465 .76749 .426 .78363 .61753 .76888 .4304 Mtetra
.074 .003 .462 r
.76888 .4304 .78363 .61753 .78651 .63126 .78542 .62639 Mtetra
.274 .245 .643 r
.78542 .62639 .78651 .63126 .78849 .63307 .78753 .62985 Mtetra
.49 .436 .724 r
.78753 .62985 .78849 .63307 .79031 .63272 .78944 .63063 Mtetra
.554 .543 .797 r
.78944 .63063 .79031 .63272 .79209 .63181 .7913 .63072 Mtetra
.554 .684 .925 r
.7913 .63072 .79209 .63181 .7939 .63128 .79314 .63061 Mtetra
.56 .793 .986 r
.79314 .63061 .7939 .63128 .79575 .63115 .79497 .63031 Mtetra
.723 .805 .916 r
.79497 .63031 .79575 .63115 .79755 .63049 .79676 .62946 Mtetra
.871 .793 .77 r
.79676 .62946 .79755 .63049 .79918 .6277 .79843 .62712 Mtetra
.979 .791 .581 r
.79843 .62712 .79918 .6277 .79976 .61176 .79978 .6207 Mtetra
.982 .691 .36 r
.79978 .6207 .79976 .61176 .78617 .42006 .78575 .42313 Mtetra
0 0 .15 r
.78575 .42313 .78617 .42006 .78768 .4172 .78713 .41852 Mtetra
0 0 0 r
.78713 .41852 .78768 .4172 .78937 .41651 .78875 .41687 Mtetra
.388 .811 .626 r
.78875 .41687 .78937 .41651 .79111 .41636 .79041 .41586 Mtetra
.691 .879 .968 r
.79041 .41586 .79111 .41636 .79284 .41614 .79211 .41514 Mtetra
.672 .741 .902 r
.79211 .41514 .79284 .41614 .79455 .41558 .79381 .41456 Mtetra
.651 .731 .908 r
.79381 .41456 .79455 .41558 .79626 .41506 .79552 .41409 Mtetra
.713 .763 .892 r
.79552 .41409 .79626 .41506 .79797 .41451 .79721 .41331 Mtetra
.741 .728 .839 r
.79721 .41331 .79797 .41451 .79968 .41403 .79888 .41229 Mtetra
.648 .615 .803 r
.79888 .41229 .79968 .41403 .80144 .41405 .8006 .41176 Mtetra
.362 .4 .767 r
.8006 .41176 .80144 .41405 .80336 .41596 .80246 .41299 Mtetra
.827 .511 0 r
.80246 .41299 .80336 .41596 .8219 .60984 .80518 .42402 Mtetra
.091 .018 .472 r
.80518 .42402 .8219 .60984 .82468 .62029 .8239 .61923 Mtetra
0 0 .502 r
.8239 .61923 .82468 .62029 .82675 .62248 .826 .62179 Mtetra
.446 .735 .989 r
.826 .62179 .82675 .62248 .82864 .62265 .82788 .62177 Mtetra
.742 .806 .903 r
.82788 .62177 .82864 .62265 .83045 .62186 .82968 .62081 Mtetra
.87 .794 .774 r
.82968 .62081 .83045 .62186 .83211 .61926 .83136 .61851 Mtetra
.971 .794 .607 r
.83136 .61851 .83211 .61926 .83307 .60909 .83274 .61294 Mtetra
.98 .684 .36 r
.83274 .61294 .83307 .60909 .81707 .41116 .81677 .41487 Mtetra
0 0 .198 r
.81677 .41487 .81707 .41116 .81853 .40776 .81803 .40921 Mtetra
0 0 .018 r
.81803 .40921 .81853 .40776 .82024 .40701 .81964 .40743 Mtetra
0 0 0 r
.81964 .40743 .82024 .40701 .82199 .40684 .82132 .40636 Mtetra
.688 .887 .971 r
.82132 .40636 .82199 .40684 .82376 .40676 .82303 .40564 Mtetra
.669 .717 .884 r
.82303 .40564 .82376 .40676 .82549 .40629 .82475 .40507 Mtetra
.644 .687 .876 r
.82475 .40507 .82549 .40629 .82723 .4058 .82649 .40462 Mtetra
.68 .711 .872 r
.82649 .40462 .82723 .4058 .82894 .40511 .82821 .40398 Mtetra
.738 .743 .856 r
.82821 .40398 .82894 .40511 .83063 .40418 .8299 .40301 Mtetra
.653 .702 .882 r
.8299 .40301 .83063 .40418 .83237 .40367 .83163 .40252 Mtetra
.153 .424 .863 r
.83163 .40252 .83237 .40367 .83422 .40444 .83352 .40357 Mtetra
.94 .58 .191 r
.83352 .40357 .83422 .40444 .83658 .4104 .8364 .415 Mtetra
.972 .665 .367 r
.8364 .415 .83658 .4104 .85757 .60837 .85706 .60996 Mtetra
.755 .355 .294 r
.85706 .60996 .85757 .60837 .85982 .61194 .85922 .6126 Mtetra
.288 0 0 r
.85922 .6126 .85982 .61194 .86175 .61227 .86111 .61242 Mtetra
.442 .871 .772 r
.86111 .61242 .86175 .61227 .86363 .61196 .86293 .61152 Mtetra
.781 .93 .931 r
.86293 .61152 .86363 .61196 .8655 .61158 .86473 .61034 Mtetra
.726 .733 .856 r
.86473 .61034 .8655 .61158 .86741 .61158 .86654 .60937 Mtetra
.732 .63 .745 r
.86654 .60937 .86741 .61158 .86927 .61104 .8683 .60786 Mtetra
.781 .61 .668 r
.8683 .60786 .86927 .61104 .87099 .60908 .86989 .60465 Mtetra
.976 .675 .369 r
.86989 .60465 .87099 .60908 .87208 .60096 .85209 .40992 Mtetra
.583 .37 .557 r
.85209 .40992 .87208 .60096 .85355 .40052 .85275 .39865 Mtetra
.844 .693 .695 r
.85275 .39865 .85355 .40052 .85493 .39646 .85425 .39565 Mtetra
.727 .813 .918 r
.85425 .39565 .85493 .39646 .85664 .39558 .85596 .39482 Mtetra
.601 .779 .966 r
.85596 .39482 .85664 .39558 .85842 .39531 .85773 .39446 Mtetra
.592 .748 .952 r
.85773 .39446 .85842 .39531 .86021 .39522 .8595 .39416 Mtetra
.709 .749 .884 r
.8595 .39416 .86021 .39522 .86196 .39466 .86123 .39339 Mtetra
.684 .699 .858 r
.86123 .39339 .86196 .39466 .8637 .39408 .86296 .39271 Mtetra
.647 .667 .855 r
.86296 .39271 .8637 .39408 .86544 .39337 .86472 .39223 Mtetra
.571 .673 .909 r
.86472 .39223 .86544 .39337 .86713 .39232 .86651 .39209 Mtetra
0 .497 .776 r
.86651 .39209 .86713 .39232 .86888 .3917 .86837 .39249 Mtetra
.731 .266 .144 r
.86837 .39249 .86888 .3917 .87075 .39222 .87038 .39435 Mtetra
.973 .663 .339 r
.87038 .39435 .87075 .39222 .87323 .39844 .89311 .58808 Mtetra
.58 .363 .551 r
.89311 .58808 .87323 .39844 .89682 .59869 .89621 .59883 Mtetra
.766 .256 0 r
.89621 .59883 .89682 .59869 .89916 .60242 .89841 .60132 Mtetra
.392 .601 .93 r
.89841 .60132 .89916 .60242 .90113 .6027 .9004 .60172 Mtetra
.657 .76 .926 r
.9004 .60172 .90113 .6027 .90299 .60196 .90227 .60116 Mtetra
.867 .853 .826 r
.90227 .60116 .90299 .60196 .90471 .59998 .90401 .59925 Mtetra
.987 .78 .539 r
.90401 .59925 .90471 .59998 .90601 .59427 .90512 .59182 Mtetra
.976 .672 .344 r
.90512 .59182 .90601 .59427 .88547 .39371 .88445 .38984 Mtetra
.8 .598 .629 r
.88445 .38984 .88547 .39371 .88664 .38787 .88577 .38531 Mtetra
.669 .568 .732 r
.88577 .38531 .88664 .38787 .88829 .38632 .88749 .38438 Mtetra
.61 .58 .795 r
.88749 .38438 .88829 .38632 .89002 .38546 .88929 .3841 Mtetra
.562 .627 .874 r
.88929 .3841 .89002 .38546 .89179 .38493 .89111 .38404 Mtetra
.698 .785 .918 r
.89111 .38404 .89179 .38493 .89356 .38439 .89286 .38333 Mtetra
.682 .741 .896 r
.89286 .38333 .89356 .38439 .89534 .38393 .89462 .38269 Mtetra
.638 .686 .878 r
.89462 .38269 .89534 .38393 .89712 .38348 .8964 .38226 Mtetra
.481 .608 .901 r
.8964 .38226 .89712 .38348 .89888 .38287 .89826 .38247 Mtetra
.035 .543 .874 r
.89826 .38247 .89888 .38287 .90064 .38225 .90015 .38294 Mtetra
.501 0 0 r
.90015 .38294 .90064 .38225 .9024 .38159 .90204 .38338 Mtetra
.33 0 .211 r
.90204 .38338 .9024 .38159 .90413 .38064 .90377 .38242 Mtetra
.382 .022 .224 r
.90377 .38242 .90413 .38064 .9059 .38004 .90553 .38174 Mtetra
.547 .157 .253 r
.90553 .38174 .9059 .38004 .90775 .38018 .90742 .38209 Mtetra
.944 .598 .329 r
.90742 .38209 .90775 .38018 .91005 .38399 .91153 .40098 Mtetra
.962 .646 .375 r
.91153 .40098 .91005 .38399 .936 .58366 .93587 .58751 Mtetra
.701 .37 .413 r
.93587 .58751 .936 .58366 .93869 .58965 .9382 .5905 Mtetra
.387 0 0 r
.9382 .5905 .93869 .58965 .94068 .58984 .94016 .59047 Mtetra
.099 0 0 r
.94016 .59047 .94068 .58984 .94257 .58917 .94206 .58985 Mtetra
.01 0 0 r
.94206 .58985 .94257 .58917 .94441 .58808 .94393 .58897 Mtetra
.281 0 0 r
.94393 .58897 .94441 .58808 .94631 .58744 .94585 .58855 Mtetra
.332 0 .037 r
.94585 .58855 .94631 .58744 .94821 .58686 .94778 .58812 Mtetra
.351 0 .087 r
.94778 .58812 .94821 .58686 .95013 .58642 .9497 .58765 Mtetra
.341 0 .076 r
.9497 .58765 .95013 .58642 .95211 .58643 .95162 .58716 Mtetra
.156 0 0 r
.95162 .58716 .95211 .58643 .9541 .58646 .95352 .58656 Mtetra
.383 .841 .774 r
.95352 .58656 .9541 .58646 .95607 .58641 .95541 .58577 Mtetra
.875 .797 .77 r
.33757 .75496 .33854 .75553 .3401 .75472 .3392 .75264 Mtetra
.834 .662 .669 r
.3392 .75264 .3401 .75472 .34168 .75346 .34094 .74847 Mtetra
.93 .68 .538 r
.34094 .74847 .34168 .75346 .34331 .75133 .35182 .5652 Mtetra
.584 .372 .559 r
.35182 .5652 .34331 .75133 .3453 .74205 .35377 .55506 Mtetra
.571 .361 .557 r
.35377 .55506 .3453 .74205 .35616 .555 .35537 .55199 Mtetra
.716 .566 .685 r
.35537 .55199 .35616 .555 .35779 .55113 .3569 .55019 Mtetra
.723 .734 .86 r
.3569 .55019 .35779 .55113 .35928 .55012 .35837 .54942 Mtetra
.658 .777 .936 r
.35837 .54942 .35928 .55012 .36074 .54969 .35983 .54897 Mtetra
.617 .761 .948 r
.35983 .54897 .36074 .54969 .36219 .54953 .36129 .54866 Mtetra
.768 .753 .839 r
.36129 .54866 .36219 .54953 .36368 .54854 .36278 .54759 Mtetra
.721 .733 .86 r
.36278 .54759 .36368 .54854 .36515 .54784 .36426 .54683 Mtetra
.57 .675 .91 r
.36426 .54683 .36515 .54784 .3666 .54779 .36571 .54672 Mtetra
.912 .51 .145 r
.36571 .54672 .3666 .54779 .36787 .55145 .36699 .55019 Mtetra
.94 .684 .521 r
.36699 .55019 .36787 .55145 .3605 .74276 .35956 .74154 Mtetra
.951 .608 .322 r
.35956 .74154 .3605 .74276 .36177 .74848 .36081 .74765 Mtetra
0 .292 .755 r
.36081 .74765 .36177 .74848 .36326 .74936 .3623 .74857 Mtetra
.61 .752 .946 r
.3623 .74857 .36326 .74936 .36481 .74904 .36385 .74826 Mtetra
.801 .782 .835 r
.36385 .74826 .36481 .74904 .36641 .7477 .36545 .74691 Mtetra
.906 .744 .67 r
.36545 .74691 .36641 .7477 .36815 .74295 .3672 .74218 Mtetra
.939 .687 .529 r
.3672 .74218 .36815 .74295 .37804 .55096 .37715 .55014 Mtetra
.916 .726 .631 r
.37715 .55014 .37804 .55096 .37978 .54446 .37889 .54361 Mtetra
.801 .762 .816 r
.37889 .54361 .37978 .54446 .38129 .5431 .3804 .54225 Mtetra
.656 .739 .911 r
.3804 .54225 .38129 .5431 .38276 .54267 .38187 .54182 Mtetra
.529 .696 .946 r
.38187 .54182 .38276 .54267 .38422 .54263 .38333 .54177 Mtetra
.736 .754 .867 r
.38333 .54177 .38422 .54263 .38571 .54181 .38482 .54094 Mtetra
.707 .749 .884 r
.38482 .54094 .38571 .54181 .38719 .54115 .3863 .54028 Mtetra
.534 .696 .943 r
.3863 .54028 .38719 .54115 .38865 .54109 .38777 .54022 Mtetra
.901 .485 .138 r
.38777 .54022 .38865 .54109 .38998 .5443 .3891 .54341 Mtetra
.942 .684 .516 r
.3891 .54341 .38998 .5443 .38388 .7351 .38294 .73423 Mtetra
.943 .604 .352 r
.38294 .73423 .38388 .7351 .38518 .7415 .38423 .74069 Mtetra
.052 .467 .884 r
.38423 .74069 .38518 .7415 .3867 .74214 .38576 .74133 Mtetra
.669 .765 .922 r
.38576 .74133 .3867 .74214 .38828 .74162 .38733 .74081 Mtetra
.751 .78 .876 r
.38733 .74081 .38828 .74162 .38987 .74065 .38892 .73988 Mtetra
.647 .767 .936 r
.38892 .73988 .38987 .74065 .39144 .74014 .39049 .73944 Mtetra
.584 .769 .967 r
.39049 .73944 .39144 .74014 .39301 .73978 .39206 .73917 Mtetra
.568 .788 .982 r
.39206 .73917 .39301 .73978 .39457 .73944 .39362 .73891 Mtetra
.587 .815 .987 r
.39362 .73891 .39457 .73944 .39614 .73907 .39519 .73857 Mtetra
.597 .827 .987 r
.39519 .73857 .39614 .73907 .39771 .7387 .39676 .73819 Mtetra
.603 .829 .986 r
.39676 .73819 .39771 .7387 .39929 .73832 .39834 .7378 Mtetra
.601 .825 .985 r
.39834 .7378 .39929 .73832 .40086 .73796 .39991 .73742 Mtetra
.604 .821 .983 r
.39991 .73742 .40086 .73796 .40243 .73759 .40148 .73704 Mtetra
.611 .817 .979 r
.40148 .73704 .40243 .73759 .40401 .73722 .40306 .73665 Mtetra
.538 .789 .99 r
.40306 .73665 .40401 .73722 .40557 .73715 .40463 .73643 Mtetra
.6 .77 .961 r
.40463 .73643 .40557 .73715 .40715 .73693 .40621 .73612 Mtetra
.692 .772 .913 r
.40621 .73612 .40715 .73693 .40874 .73619 .40779 .7355 Mtetra
.847 .8 .804 r
.40779 .7355 .40874 .73619 .4104 .73315 .40942 .73367 Mtetra
.965 .923 .709 r
.40942 .73367 .4104 .73315 .4123 .72269 .41109 .73046 Mtetra
.118 0 .336 r
.41109 .73046 .4123 .72269 .41974 .53502 .41285 .72459 Mtetra
.558 .347 .55 r
.41285 .72459 .41974 .53502 .42129 .53289 .41453 .72078 Mtetra
.566 .353 .551 r
.41453 .72078 .42129 .53289 .42278 .53245 .41607 .72157 Mtetra
.563 .351 .551 r
.41607 .72157 .42278 .53245 .42427 .53238 .41766 .72099 Mtetra
0 0 .343 r
.41766 .72099 .42427 .53238 .42579 .53127 .42472 .53674 Mtetra
0 0 .142 r
.42472 .53674 .42579 .53127 .42732 .52981 .42639 .53066 Mtetra
.94 .959 .663 r
.42639 .53066 .42732 .52981 .42884 .52855 .42796 .52775 Mtetra
.793 .776 .838 r
.42796 .52775 .42884 .52855 .43035 .52778 .42948 .52652 Mtetra
.665 .666 .841 r
.42948 .52652 .43035 .52778 .43185 .52731 .43098 .52601 Mtetra
.61 .639 .855 r
.43098 .52601 .43185 .52731 .43334 .52696 .43248 .52578 Mtetra
.609 .659 .874 r
.43248 .52578 .43334 .52696 .43484 .52661 .43398 .52554 Mtetra
.616 .682 .89 r
.43398 .52554 .43484 .52661 .43634 .52625 .43547 .52527 Mtetra
.621 .702 .903 r
.43547 .52527 .43634 .52625 .43785 .52587 .43697 .52497 Mtetra
.667 .735 .901 r
.43697 .52497 .43785 .52587 .43935 .52537 .43848 .52448 Mtetra
.695 .745 .89 r
.43848 .52448 .43935 .52537 .44086 .52479 .43999 .52387 Mtetra
.698 .739 .882 r
.43999 .52387 .44086 .52479 .44237 .5242 .4415 .52323 Mtetra
.681 .725 .884 r
.4415 .52323 .44237 .5242 .44388 .52365 .44301 .52268 Mtetra
.667 .72 .889 r
.44301 .52268 .44388 .52365 .44539 .52315 .44452 .52219 Mtetra
.663 .723 .894 r
.44452 .52219 .44539 .52315 .4469 .52266 .44603 .52172 Mtetra
.695 .736 .882 r
.44603 .52172 .4469 .52266 .44841 .52194 .44754 .5211 Mtetra
.694 .757 .9 r
.44754 .5211 .44841 .52194 .44993 .52127 .44906 .5205 Mtetra
.625 .755 .94 r
.44906 .5205 .44993 .52127 .45143 .52102 .45057 .52015 Mtetra
.141 .494 .905 r
.45057 .52015 .45143 .52102 .4529 .52249 .45205 .52076 Mtetra
0 .09 .647 r
.45205 .52076 .4529 .52249 .45427 .52904 .45352 .52267 Mtetra
.214 .157 .574 r
.45352 .52267 .45427 .52904 .45186 .71917 .45494 .52691 Mtetra
.549 .343 .554 r
.45494 .52691 .45186 .71917 .45341 .72145 .45627 .53556 Mtetra
.559 .351 .556 r
.45627 .53556 .45341 .72145 .45501 .72122 .45772 .5389 Mtetra
.579 .368 .558 r
.45772 .5389 .45501 .72122 .45663 .72033 .45938 .53151 Mtetra
.569 .36 .557 r
.45938 .53151 .45663 .72033 .45824 .71959 .46093 .52935 Mtetra
.566 .357 .557 r
.46093 .52935 .45824 .71959 .45985 .71915 .46246 .52884 Mtetra
.46246 .52884 .45985 .71915 .46146 .7187 .46398 .52834 Mtetra
.46398 .52834 .46146 .7187 .46307 .71826 .46551 .52788 Mtetra
.46551 .52788 .46307 .71826 .46468 .71783 .46704 .52746 Mtetra
.46704 .52746 .46468 .71783 .46629 .7174 .46856 .52706 Mtetra
.46856 .52706 .46629 .7174 .4679 .71697 .47009 .52666 Mtetra
.47009 .52666 .4679 .71697 .46952 .71653 .47162 .52626 Mtetra
.47162 .52626 .46952 .71653 .47113 .71609 .47315 .52584 Mtetra
.47315 .52584 .47113 .71609 .47275 .71565 .47468 .52541 Mtetra
.47468 .52541 .47275 .71565 .47437 .71521 .47621 .52494 Mtetra
.47621 .52494 .47437 .71521 .47599 .71475 .47774 .52441 Mtetra
.47774 .52441 .47599 .71475 .47761 .71429 .47928 .52375 Mtetra
.47928 .52375 .47761 .71429 .47923 .71381 .48082 .52301 Mtetra
.48082 .52301 .47923 .71381 .48085 .71333 .48236 .52228 Mtetra
.569 .359 .557 r
.48236 .52228 .48085 .71333 .48247 .71273 .48391 .52021 Mtetra
.568 .359 .557 r
.48391 .52021 .48247 .71273 .4841 .71209 .48547 .5183 Mtetra
.565 .356 .556 r
.48547 .5183 .4841 .71209 .48572 .71167 .487 .51851 Mtetra
0 0 .392 r
.487 .51851 .48572 .71167 .48734 .71193 .48654 .70105 Mtetra
.161 .09 .522 r
.48654 .70105 .48734 .71193 .48895 .71262 .48807 .70916 Mtetra
.121 .171 .642 r
.48807 .70916 .48895 .71262 .49057 .71313 .48967 .71191 Mtetra
.189 .451 .876 r
.48967 .71191 .49057 .71313 .4922 .71316 .49129 .71273 Mtetra
.541 .835 .999 r
.49129 .71273 .4922 .71316 .49383 .71274 .49292 .71241 Mtetra
.661 .897 .98 r
.49292 .71241 .49383 .71274 .49546 .71218 .49455 .71176 Mtetra
.672 .877 .975 r
.49455 .71176 .49546 .71218 .49709 .71163 .49619 .71113 Mtetra
.625 .842 .983 r
.49619 .71113 .49709 .71163 .49873 .71116 .49782 .71066 Mtetra
.49782 .71066 .49873 .71116 .50036 .7107 .49945 .71019 Mtetra
.622 .84 .983 r
.49945 .71019 .50036 .7107 .502 .71024 .50109 .70972 Mtetra
.619 .838 .984 r
.50109 .70972 .502 .71024 .50363 .70979 .50273 .70927 Mtetra
.617 .836 .984 r
.50273 .70927 .50363 .70979 .50527 .70935 .50437 .70882 Mtetra
.619 .835 .983 r
.50437 .70882 .50527 .70935 .50691 .70891 .506 .70837 Mtetra
.622 .832 .981 r
.506 .70837 .50691 .70891 .50855 .70847 .50764 .70792 Mtetra
.614 .826 .981 r
.50764 .70792 .50855 .70847 .51019 .70806 .50928 .70749 Mtetra
.585 .814 .987 r
.50928 .70749 .51019 .70806 .51183 .70769 .51093 .70714 Mtetra
.546 .805 .993 r
.51093 .70714 .51183 .70769 .51347 .70739 .51257 .70687 Mtetra
.55 .817 .996 r
.51257 .70687 .51347 .70739 .51511 .70706 .51421 .70658 Mtetra
.6 .842 .99 r
.51421 .70658 .51511 .70706 .51675 .70665 .51586 .70615 Mtetra
.666 .855 .972 r
.51586 .70615 .51675 .70665 .5184 .70613 .5175 .70555 Mtetra
.684 .838 .957 r
.5175 .70555 .5184 .70613 .52005 .70559 .51915 .70492 Mtetra
.674 .813 .95 r
.51915 .70492 .52005 .70559 .52169 .70508 .5208 .70434 Mtetra
.646 .787 .95 r
.5208 .70434 .52169 .70508 .52334 .70463 .52245 .70387 Mtetra
.638 .778 .948 r
.52245 .70387 .52334 .70463 .52499 .70421 .5241 .70343 Mtetra
.609 .767 .955 r
.5241 .70343 .52499 .70421 .52664 .70392 .52575 .70309 Mtetra
.585 .744 .952 r
.52575 .70309 .52664 .70392 .52829 .70377 .5274 .70283 Mtetra
.657 .742 .913 r
.5274 .70283 .52829 .70377 .52994 .70325 .52905 .70234 Mtetra
.764 .775 .862 r
.52905 .70234 .52994 .70325 .53159 .70157 .5307 .70126 Mtetra
.906 .875 .795 r
.5307 .70126 .53159 .70157 .53324 .69663 .53235 .69903 Mtetra
0 0 0 r
.53235 .69903 .53324 .69663 .53434 .50364 .534 .69509 Mtetra
0 0 .397 r
.534 .69509 .53434 .50364 .53589 .49723 .53509 .51012 Mtetra
0 0 .335 r
.53509 .51012 .53589 .49723 .53744 .49533 .53661 .49732 Mtetra
0 0 0 r
.53661 .49732 .53744 .49533 .539 .49419 .53817 .49396 Mtetra
.881 .911 .844 r
.53817 .49396 .539 .49419 .54056 .49347 .53972 .49228 Mtetra
.664 .684 .859 r
.53972 .49228 .54056 .49347 .54212 .49302 .54129 .49177 Mtetra
.594 .647 .872 r
.54129 .49177 .54212 .49302 .54369 .4927 .54285 .49159 Mtetra
.597 .674 .894 r
.54285 .49159 .54369 .4927 .54525 .49233 .54442 .49138 Mtetra
.693 .74 .887 r
.54442 .49138 .54525 .49233 .54682 .49172 .54598 .49075 Mtetra
.699 .738 .881 r
.54598 .49075 .54682 .49172 .54838 .49109 .54755 .49009 Mtetra
.702 .732 .874 r
.54755 .49009 .54838 .49109 .54995 .49039 .54911 .48941 Mtetra
.704 .736 .876 r
.54911 .48941 .54995 .49039 .55151 .48959 .55068 .48872 Mtetra
.656 .747 .917 r
.55068 .48872 .55151 .48959 .55308 .48914 .55225 .48825 Mtetra
.457 .665 .952 r
.55225 .48825 .55308 .48914 .55466 .48966 .55383 .48836 Mtetra
0 .198 .727 r
.55383 .48836 .55466 .48966 .55627 .49355 .55541 .48987 Mtetra
.093 .137 .617 r
.55541 .48987 .55627 .49355 .55977 .68631 .55702 .49306 Mtetra
.548 .343 .555 r
.55702 .49306 .55977 .68631 .56149 .69147 .5587 .50228 Mtetra
.07 0 .436 r
.5587 .50228 .56149 .69147 .56317 .69158 .56208 .67062 Mtetra
.928 .659 .509 r
.56208 .67062 .56317 .69158 .56484 .69088 .56191 .50548 Mtetra
.577 .366 .558 r
.56191 .50548 .56484 .69088 .5665 .68991 .56342 .49873 Mtetra
.566 .357 .557 r
.56342 .49873 .5665 .68991 .56818 .68943 .565 .49806 Mtetra
.565 .49806 .56818 .68943 .56985 .68895 .56658 .49737 Mtetra
.56658 .49737 .56985 .68895 .57153 .68846 .56816 .49671 Mtetra
.56816 .49671 .57153 .68846 .5732 .688 .56975 .49615 Mtetra
.56975 .49615 .5732 .688 .57488 .68753 .57133 .49561 Mtetra
.57133 .49561 .57488 .68753 .57656 .68706 .57292 .4951 Mtetra
.57292 .4951 .57656 .68706 .57824 .6866 .57451 .49459 Mtetra
.57451 .49459 .57824 .6866 .57992 .68614 .5761 .4941 Mtetra
.5761 .4941 .57992 .68614 .5816 .68567 .57769 .49361 Mtetra
.57769 .49361 .5816 .68567 .58329 .68521 .57928 .49312 Mtetra
.57928 .49312 .58329 .68521 .58497 .68475 .58087 .49265 Mtetra
.58087 .49265 .58497 .68475 .58665 .68429 .58246 .49222 Mtetra
.58246 .49222 .58665 .68429 .58834 .68384 .58406 .49188 Mtetra
.58406 .49188 .58834 .68384 .59003 .68339 .58566 .49152 Mtetra
.565 .356 .556 r
.58566 .49152 .59003 .68339 .59172 .68302 .58727 .49166 Mtetra
.547 .343 .555 r
.58727 .49166 .59172 .68302 .59342 .6831 .58906 .50151 Mtetra
.554 .348 .556 r
.58906 .50151 .59342 .6831 .59511 .68265 .59079 .50751 Mtetra
.601 .385 .56 r
.59079 .50751 .59511 .68265 .59677 .68089 .592 .48736 Mtetra
.577 .366 .558 r
.592 .48736 .59677 .68089 .59814 .66494 .59346 .48007 Mtetra
.571 .361 .557 r
.59346 .48007 .59814 .66494 .59584 .47912 .59499 .47666 Mtetra
.754 .611 .7 r
.59499 .47666 .59584 .47912 .59737 .47561 .59655 .47459 Mtetra
.714 .735 .867 r
.59655 .47459 .59737 .47561 .59896 .47469 .59814 .47382 Mtetra
.648 .749 .923 r
.59814 .47382 .59896 .47469 .60055 .47429 .59974 .47338 Mtetra
.601 .723 .93 r
.59974 .47338 .60055 .47429 .60216 .47414 .60134 .47311 Mtetra
.628 .705 .901 r
.60134 .47311 .60216 .47414 .60376 .47376 .60294 .47277 Mtetra
.627 .713 .908 r
.60294 .47277 .60376 .47376 .60536 .47338 .60455 .47242 Mtetra
.646 .727 .908 r
.60455 .47242 .60536 .47338 .60696 .47295 .60615 .47199 Mtetra
.739 .756 .866 r
.60615 .47199 .60696 .47295 .60856 .47226 .60774 .47109 Mtetra
.7 .706 .852 r
.60774 .47109 .60856 .47226 .61015 .47162 .60934 .47038 Mtetra
.617 .66 .869 r
.60934 .47038 .61015 .47162 .61176 .47116 .61094 .47009 Mtetra
0 .275 .777 r
.61094 .47009 .61176 .47116 .61337 .47099 .61259 .47134 Mtetra
.855 .444 .253 r
.61259 .47134 .61337 .47099 .615 .47131 .6143 .47461 Mtetra
.96 .678 .457 r
.6143 .47461 .615 .47131 .61665 .47265 .62117 .66445 Mtetra
.576 .361 .552 r
.62117 .66445 .61665 .47265 .61877 .49015 .62309 .67187 Mtetra
.568 .355 .551 r
.62309 .67187 .61877 .49015 .62567 .67292 .62488 .67419 Mtetra
.636 .222 .241 r
.62488 .67419 .62567 .67292 .62748 .67583 .62663 .67516 Mtetra
.589 .794 .977 r
.62663 .67516 .62748 .67583 .6292 .67575 .62835 .67481 Mtetra
.7 .764 .901 r
.62835 .67481 .6292 .67575 .63091 .67507 .63006 .6741 Mtetra
.727 .765 .883 r
.63006 .6741 .63091 .67507 .63261 .67409 .63176 .67324 Mtetra
.505 .711 .964 r
.63176 .67324 .63261 .67409 .63433 .67382 .63349 .6732 Mtetra
.53 .786 .991 r
.63349 .6732 .63433 .67382 .63605 .67349 .63521 .67298 Mtetra
.672 .863 .972 r
.63521 .67298 .63605 .67349 .63777 .67299 .63693 .67233 Mtetra
.893 .83 .778 r
.63693 .67233 .63777 .67299 .63947 .67216 .63858 .66997 Mtetra
.854 .675 .659 r
.63858 .66997 .63947 .67216 .64116 .67083 .64017 .66555 Mtetra
.962 .684 .463 r
.64017 .66555 .64116 .67083 .64282 .66853 .63553 .47548 Mtetra
.58 .368 .558 r
.63553 .47548 .64282 .66853 .6442 .6582 .63686 .46648 Mtetra
.57 .36 .557 r
.63686 .46648 .6442 .6582 .63927 .4665 .6384 .46339 Mtetra
.716 .567 .685 r
.6384 .46339 .63927 .4665 .64077 .46258 .63997 .46154 Mtetra
.721 .738 .865 r
.63997 .46154 .64077 .46258 .64237 .4615 .64158 .46073 Mtetra
.653 .778 .94 r
.64158 .46073 .64237 .4615 .64399 .46104 .6432 .46025 Mtetra
.614 .758 .948 r
.6432 .46025 .64399 .46104 .64563 .46087 .64483 .4599 Mtetra
.768 .764 .85 r
.64483 .4599 .64563 .46087 .64723 .45986 .64643 .4588 Mtetra
.72 .734 .862 r
.64643 .4588 .64723 .45986 .64884 .45913 .64804 .45798 Mtetra
.579 .665 .897 r
.64804 .45798 .64884 .45913 .65049 .45905 .64968 .45783 Mtetra
.78 .357 0 r
.64968 .45783 .65049 .45905 .65228 .46287 .65147 .46147 Mtetra
.969 .684 .433 r
.65147 .46147 .65228 .46287 .66167 .66003 .66082 .65883 Mtetra
.911 .522 .109 r
.66082 .65883 .66167 .66003 .66364 .66564 .66281 .66478 Mtetra
.32 .617 .955 r
.66281 .66478 .66364 .66564 .66541 .66603 .66457 .66514 Mtetra
.697 .777 .913 r
.66457 .66514 .66541 .66603 .66714 .6654 .6663 .66444 Mtetra
.767 .78 .864 r
.6663 .66444 .66714 .6654 .66885 .66434 .66801 .66331 Mtetra
.586 .707 .926 r
.66801 .66331 .66885 .66434 .67061 .6642 .66976 .66308 Mtetra
.586 .688 .912 r
.66976 .66308 .67061 .6642 .67235 .66396 .67151 .66288 Mtetra
.664 .725 .894 r
.67151 .66288 .67235 .66396 .67408 .66318 .67325 .66233 Mtetra
.837 .808 .822 r
.67325 .66233 .67408 .66318 .6757 .65989 .67494 .66062 Mtetra
.889 .951 .6 r
.67494 .66062 .6757 .65989 .67698 .64895 .67657 .65761 Mtetra
.199 .024 .405 r
.67657 .65761 .67698 .64895 .67022 .45673 .67804 .65089 Mtetra
.055 0 .436 r
.67804 .65089 .67022 .45673 .67175 .45387 .67119 .45791 Mtetra
0 0 .209 r
.67119 .45791 .67175 .45387 .67335 .45243 .67263 .45301 Mtetra
.864 .965 .637 r
.67263 .45301 .67335 .45243 .67497 .45154 .67418 .45055 Mtetra
.738 .756 .867 r
.67418 .45055 .67497 .45154 .67661 .45096 .67581 .44964 Mtetra
.623 .655 .861 r
.67581 .44964 .67661 .45096 .67825 .45057 .67746 .44932 Mtetra
.565 .638 .882 r
.67746 .44932 .67825 .45057 .67991 .45029 .67912 .44924 Mtetra
.671 .723 .888 r
.67912 .44924 .67991 .45029 .68154 .44954 .68076 .44869 Mtetra
.68 .772 .92 r
.68076 .44869 .68154 .44954 .68317 .44887 .6824 .4481 Mtetra
.602 .765 .957 r
.6824 .4481 .68317 .44887 .68483 .44869 .68406 .44778 Mtetra
.072 .433 .873 r
.68406 .44778 .68483 .44869 .68661 .45089 .68577 .44864 Mtetra
.078 .216 .706 r
.68577 .44864 .68661 .45089 .69696 .62457 .68755 .45083 Mtetra
.555 .349 .556 r
.68755 .45083 .69696 .62457 .7001 .65195 .68949 .45607 Mtetra
.561 .353 .556 r
.68949 .45607 .7001 .65195 .70193 .65297 .6913 .45853 Mtetra
.569 .359 .557 r
.6913 .45853 .70193 .65297 .70369 .6524 .69286 .45627 Mtetra
.565 .357 .556 r
.69286 .45627 .70369 .6524 .70542 .6515 .69454 .45617 Mtetra
.087 .005 .457 r
.69454 .45617 .70542 .6515 .70722 .65182 .70607 .64451 Mtetra
.252 .192 .592 r
.70607 .64451 .70722 .65182 .70904 .65247 .70813 .64972 Mtetra
.198 .27 .713 r
.70813 .64972 .70904 .65247 .71085 .65289 .71003 .65191 Mtetra
.313 .582 .938 r
.71003 .65191 .71085 .65289 .71265 .65303 .71185 .65239 Mtetra
.577 .803 .985 r
.71185 .65239 .71265 .65303 .71443 .65275 .71362 .65204 Mtetra
.736 .835 .926 r
.71362 .65204 .71443 .65275 .71617 .65187 .71536 .65116 Mtetra
.846 .842 .841 r
.71536 .65116 .71617 .65187 .7178 .649 .71707 .64948 Mtetra
.906 .968 .657 r
.71707 .64948 .7178 .649 .71915 .64093 .71871 .64671 Mtetra
.101 0 .337 r
.71871 .64671 .71915 .64093 .70986 .44525 .72019 .64121 Mtetra
.079 0 .449 r
.72019 .64121 .70986 .44525 .71135 .44172 .71094 .44709 Mtetra
0 0 .297 r
.71094 .44709 .71135 .44172 .71295 .44015 .71229 .4411 Mtetra
.723 .865 .446 r
.71229 .4411 .71295 .44015 .71459 .43917 .71383 .43838 Mtetra
.782 .814 .878 r
.71383 .43838 .71459 .43917 .71624 .43854 .71546 .43726 Mtetra
.635 .668 .865 r
.71546 .43726 .71624 .43854 .71791 .43813 .71713 .43688 Mtetra
.572 .644 .883 r
.71713 .43688 .71791 .43813 .71959 .43783 .71882 .43677 Mtetra
.612 .699 .905 r
.71882 .43677 .71959 .43783 .72126 .43741 .7205 .43646 Mtetra
.654 .741 .913 r
.7205 .43646 .72126 .43741 .72293 .43689 .72217 .43598 Mtetra
.669 .755 .915 r
.72217 .43598 .72293 .43689 .7246 .43633 .72383 .43544 Mtetra
.727 .777 .892 r
.72383 .43544 .7246 .43633 .72624 .43545 .72549 .43461 Mtetra
.732 .792 .9 r
.72549 .43461 .72624 .43545 .72789 .4346 .72714 .43377 Mtetra
.669 .775 .929 r
.72714 .43377 .72789 .4346 .72957 .43421 .72881 .43322 Mtetra
.393 .608 .935 r
.72881 .43322 .72957 .43421 .73136 .43561 .73053 .43355 Mtetra
.234 .339 .766 r
.73053 .43355 .73136 .43561 .73348 .44204 .73234 .43509 Mtetra
.312 .235 .606 r
.73234 .43509 .73348 .44204 .74778 .63752 .73432 .43941 Mtetra
.099 .017 .466 r
.73432 .43941 .74778 .63752 .74979 .64052 .74856 .63288 Mtetra
.279 .209 .597 r
.74856 .63288 .74979 .64052 .75166 .64125 .75072 .63812 Mtetra
.304 .32 .712 r
.75072 .63812 .75166 .64125 .75349 .64133 .75267 .6401 Mtetra
.358 .553 .907 r
.75267 .6401 .75349 .64133 .75531 .64132 .75453 .64065 Mtetra
.555 .79 .986 r
.75453 .64065 .75531 .64132 .75712 .64109 .75633 .64037 Mtetra
.719 .831 .934 r
.75633 .64037 .75712 .64109 .75889 .6403 .7581 .63955 Mtetra
.83 .84 .854 r
.7581 .63955 .75889 .6403 .76055 .63786 .75983 .63801 Mtetra
.93 .972 .732 r
.75983 .63801 .76055 .63786 .76194 .63145 .76148 .63545 Mtetra
0 0 .248 r
.76148 .63545 .76194 .63145 .75011 .43406 .76299 .63078 Mtetra
.103 .016 .462 r
.76299 .63078 .75011 .43406 .75153 .42958 .75136 .43708 Mtetra
.059 0 .363 r
.75136 .43708 .75153 .42958 .75313 .42785 .75254 .4292 Mtetra
0 0 0 r
.75254 .4292 .75313 .42785 .75477 .42678 .75405 .42617 Mtetra
.825 .864 .876 r
.75405 .42617 .75477 .42678 .75645 .4261 .75568 .42482 Mtetra
.646 .675 .863 r
.75568 .42482 .75645 .4261 .75814 .42565 .75737 .42436 Mtetra
.581 .645 .878 r
.75737 .42436 .75814 .42565 .75984 .42532 .75908 .42422 Mtetra
.64 .705 .893 r
.75908 .42422 .75984 .42532 .76153 .42468 .76078 .4238 Mtetra
.698 .774 .91 r
.76078 .4238 .76153 .42468 .7632 .42389 .76246 .42311 Mtetra
.641 .782 .949 r
.76246 .42311 .7632 .42389 .7649 .4235 .76416 .42265 Mtetra
.401 .65 .958 r
.76416 .42265 .7649 .4235 .76672 .42465 .76591 .42287 Mtetra
.24 .374 .798 r
.76591 .42287 .76672 .42465 .76888 .4304 .76774 .4242 Mtetra
.343 .265 .623 r
.76774 .4242 .76888 .4304 .78542 .62639 .76975 .42776 Mtetra
.119 .034 .476 r
.76975 .42776 .78542 .62639 .78753 .62985 .78613 .62077 Mtetra
.28 .201 .586 r
.78613 .62077 .78753 .62985 .78944 .63063 .78846 .6271 Mtetra
.317 .312 .696 r
.78846 .6271 .78944 .63063 .7913 .63072 .79048 .62931 Mtetra
.382 .531 .881 r
.79048 .62931 .7913 .63072 .79314 .63061 .79238 .62991 Mtetra
.596 .803 .979 r
.79238 .62991 .79314 .63061 .79497 .63031 .7942 .62952 Mtetra
.743 .826 .915 r
.7942 .62952 .79497 .63031 .79676 .62946 .79598 .62857 Mtetra
.825 .817 .842 r
.79598 .62857 .79676 .62946 .79843 .62712 .79772 .627 Mtetra
.936 .949 .768 r
.79772 .627 .79843 .62712 .79978 .6207 .79938 .62454 Mtetra
.026 0 .263 r
.79938 .62454 .79978 .6207 .78575 .42313 .80089 .62019 Mtetra
.127 .036 .473 r
.80089 .62019 .78575 .42313 .78713 .41852 .78728 .42859 Mtetra
.135 0 .415 r
.78728 .42859 .78713 .41852 .78875 .41687 .78826 .41896 Mtetra
0 0 .047 r
.78826 .41896 .78875 .41687 .79041 .41586 .78974 .4157 Mtetra
.864 .976 .856 r
.78974 .4157 .79041 .41586 .79211 .41514 .79136 .41408 Mtetra
.689 .736 .886 r
.79136 .41408 .79211 .41514 .79381 .41456 .79306 .41342 Mtetra
.631 .695 .891 r
.79306 .41342 .79381 .41456 .79552 .41409 .79478 .41304 Mtetra
.698 .741 .884 r
.79478 .41304 .79552 .41409 .79721 .41331 .79648 .41233 Mtetra
.763 .775 .863 r
.79648 .41233 .79721 .41331 .79888 .41229 .79815 .41125 Mtetra
.669 .733 .898 r
.79815 .41125 .79888 .41229 .8006 .41176 .79986 .41069 Mtetra
.023 .352 .828 r
.79986 .41069 .8006 .41176 .80246 .41299 .80172 .41192 Mtetra
.946 .593 .208 r
.80172 .41192 .80246 .41299 .80518 .42402 .80452 .42398 Mtetra
.975 .672 .367 r
.80452 .42398 .80518 .42402 .8239 .61923 .82316 .6186 Mtetra
.641 .132 0 r
.82316 .6186 .8239 .61923 .826 .62179 .82525 .62102 Mtetra
.538 .758 .978 r
.82525 .62102 .826 .62179 .82788 .62177 .82712 .62082 Mtetra
.747 .792 .889 r
.82712 .62082 .82788 .62177 .82968 .62081 .82891 .61981 Mtetra
.824 .799 .828 r
.82891 .61981 .82968 .62081 .83136 .61851 .83065 .61815 Mtetra
.925 .921 .791 r
.83065 .61815 .83136 .61851 .83274 .61294 .83232 .61582 Mtetra
0 0 .165 r
.83232 .61582 .83274 .61294 .81677 .41487 .83385 .61183 Mtetra
.159 .062 .486 r
.83385 .61183 .81677 .41487 .81803 .40921 .81897 .42661 Mtetra
.145 .027 .449 r
.81897 .42661 .81803 .40921 .81964 .40743 .81923 .40986 Mtetra
0 0 .127 r
.81923 .40986 .81964 .40743 .82132 .40636 .82068 .4063 Mtetra
.875 .989 .818 r
.82068 .4063 .82132 .40636 .82303 .40564 .82229 .4045 Mtetra
.695 .726 .874 r
.82229 .4045 .82303 .40564 .82475 .40507 .824 .40379 Mtetra
.631 .674 .872 r
.824 .40379 .82475 .40507 .82649 .40462 .82575 .40341 Mtetra
.66 .698 .874 r
.82575 .40341 .82649 .40462 .82821 .40398 .82748 .40288 Mtetra
.739 .747 .858 r
.82748 .40288 .82821 .40398 .8299 .40301 .82917 .4019 Mtetra
.653 .714 .893 r
.82917 .4019 .8299 .40301 .83163 .40252 .8309 .40141 Mtetra
.131 .418 .863 r
.8309 .40141 .83163 .40252 .83352 .40357 .83279 .40247 Mtetra
.937 .578 .172 r
.83279 .40247 .83352 .40357 .8364 .415 .83569 .41405 Mtetra
.975 .669 .346 r
.83569 .41405 .8364 .415 .85706 .60996 .85632 .60914 Mtetra
.595 .114 0 r
.85632 .60914 .85706 .60996 .85922 .6126 .85849 .61181 Mtetra
.509 .74 .978 r
.85849 .61181 .85922 .6126 .86111 .61242 .86038 .6117 Mtetra
.743 .849 .929 r
.86038 .6117 .86111 .61242 .86293 .61152 .8622 .61074 Mtetra
.855 .849 .837 r
.8622 .61074 .86293 .61152 .86473 .61034 .86393 .60896 Mtetra
.877 .754 .723 r
.86393 .60896 .86473 .61034 .86654 .60937 .86555 .60602 Mtetra
.852 .642 .618 r
.86555 .60602 .86654 .60937 .8683 .60786 .86688 .60013 Mtetra
.973 .672 .38 r
.86688 .60013 .8683 .60786 .86989 .60465 .84916 .40476 Mtetra
.574 .363 .557 r
.84916 .40476 .86989 .60465 .85209 .40992 .85038 .399 Mtetra
.637 .439 .599 r
.85038 .399 .85209 .40992 .85275 .39865 .8519 .39628 Mtetra
.73 .61 .724 r
.8519 .39628 .85275 .39865 .85425 .39565 .85354 .39469 Mtetra
.695 .764 .905 r
.85354 .39469 .85425 .39565 .85596 .39482 .85527 .394 Mtetra
.627 .774 .951 r
.85527 .394 .85596 .39482 .85773 .39446 .85703 .39357 Mtetra
.649 .765 .934 r
.85703 .39357 .85773 .39446 .8595 .39416 .85879 .39308 Mtetra
.742 .755 .864 r
.85879 .39308 .8595 .39416 .86123 .39339 .86049 .3921 Mtetra
.692 .7 .852 r
.86049 .3921 .86123 .39339 .86296 .39271 .86222 .39137 Mtetra
.572 .634 .875 r
.86222 .39137 .86296 .39271 .86472 .39223 .86402 .39126 Mtetra
0 .262 .766 r
.86402 .39126 .86472 .39223 .86651 .39209 .86599 .39277 Mtetra
.86 .435 .212 r
.86599 .39277 .86651 .39209 .86837 .39249 .86825 .39697 Mtetra
.972 .662 .349 r
.86825 .39697 .86837 .39249 .87038 .39435 .89101 .59233 Mtetra
.571 .357 .551 r
.89101 .59233 .87038 .39435 .89311 .58808 .8935 .59756 Mtetra
.61 .347 .495 r
.8935 .59756 .89311 .58808 .89621 .59883 .89565 .5995 Mtetra
.583 .072 .003 r
.89565 .5995 .89621 .59883 .89841 .60132 .89768 .60038 Mtetra
.376 .63 .953 r
.89768 .60038 .89841 .60132 .9004 .60172 .89966 .60071 Mtetra
.628 .742 .93 r
.89966 .60071 .9004 .60172 .90227 .60116 .90155 .60028 Mtetra
.842 .834 .839 r
.90155 .60028 .90227 .60116 .90401 .59925 .9033 .59857 Mtetra
.988 .784 .541 r
.9033 .59857 .90401 .59925 .90512 .59182 .90444 .59131 Mtetra
.977 .673 .337 r
.90444 .59131 .90512 .59182 .88445 .38984 .88375 .3888 Mtetra
.954 .782 .631 r
.88375 .3888 .88445 .38984 .88577 .38531 .88506 .38419 Mtetra
.726 .744 .867 r
.88506 .38419 .88577 .38531 .88749 .38438 .88679 .38329 Mtetra
.594 .694 .912 r
.88679 .38329 .88749 .38438 .88929 .3841 .88859 .38304 Mtetra
.539 .675 .926 r
.88859 .38304 .88929 .3841 .89111 .38404 .89041 .38298 Mtetra
.734 .761 .875 r
.89041 .38298 .89111 .38404 .89286 .38333 .89214 .38206 Mtetra
.691 .705 .858 r
.89214 .38206 .89286 .38333 .89462 .38269 .89389 .38133 Mtetra
.594 .645 .871 r
.89389 .38133 .89462 .38269 .8964 .38226 .8957 .38112 Mtetra
0 .263 .771 r
.8957 .38112 .8964 .38226 .89826 .38247 .89773 .38279 Mtetra
.862 .416 .127 r
.89773 .38279 .89826 .38247 .90015 .38294 .90005 .38695 Mtetra
.972 .658 .329 r
.90005 .38695 .90015 .38294 .90204 .38338 .92458 .58005 Mtetra
.565 .352 .551 r
.92458 .58005 .90204 .38338 .90377 .38242 .92657 .58037 Mtetra
.562 .35 .551 r
.92657 .58037 .90377 .38242 .90553 .38174 .92833 .57871 Mtetra
.565 .353 .551 r
.92833 .57871 .90553 .38174 .90742 .38209 .93037 .5794 Mtetra
.573 .358 .551 r
.93037 .5794 .90742 .38209 .91153 .40098 .93308 .58564 Mtetra
.568 .355 .551 r
.93308 .58564 .91153 .40098 .93587 .58751 .93537 .58834 Mtetra
.653 .167 .085 r
.93537 .58834 .93587 .58751 .9382 .5905 .9375 .58965 Mtetra
.558 .753 .968 r
.9375 .58965 .9382 .5905 .94016 .59047 .93944 .58941 Mtetra
.659 .749 .916 r
.93944 .58941 .94016 .59047 .94206 .58985 .94134 .58884 Mtetra
.685 .768 .914 r
.94134 .58884 .94206 .58985 .94393 .58897 .94323 .58813 Mtetra
.583 .767 .966 r
.94323 .58813 .94393 .58897 .94585 .58855 .94517 .58781 Mtetra
.573 .788 .98 r
.94517 .58781 .94585 .58855 .94778 .58812 .94711 .58747 Mtetra
.576 .816 .99 r
.94711 .58747 .94778 .58812 .9497 .58765 .94904 .58707 Mtetra
.55 .825 .997 r
.94904 .58707 .9497 .58765 .95162 .58716 .95097 .5867 Mtetra
.613 .887 .99 r
.95097 .5867 .95162 .58716 .95352 .58656 .95288 .58608 Mtetra
.745 .925 .95 r
.95288 .58608 .95352 .58656 .95541 .58577 .95473 .58503 Mtetra
.88 .719 .678 r
.33662 .75382 .33757 .75496 .3392 .75264 .33836 .74952 Mtetra
.933 .683 .536 r
.33836 .74952 .3392 .75264 .34094 .74847 .34967 .56062 Mtetra
.581 .369 .559 r
.34967 .56062 .34094 .74847 .35182 .5652 .35154 .55215 Mtetra
.608 .415 .595 r
.35154 .55215 .35182 .5652 .35377 .55506 .35306 .55053 Mtetra
.629 .477 .657 r
.35306 .55053 .35377 .55506 .35537 .55199 .35454 .5497 Mtetra
.633 .549 .742 r
.35454 .5497 .35537 .55199 .3569 .55019 .356 .54925 Mtetra
.683 .725 .882 r
.356 .54925 .3569 .55019 .35837 .54942 .35746 .5487 Mtetra
.666 .772 .929 r
.35746 .5487 .35837 .54942 .35983 .54897 .35893 .54823 Mtetra
.656 .764 .929 r
.35893 .54823 .35983 .54897 .36129 .54866 .36039 .54779 Mtetra
.756 .754 .851 r
.36039 .54779 .36129 .54866 .36278 .54759 .36188 .54683 Mtetra
.71 .771 .9 r
.36188 .54683 .36278 .54759 .36426 .54683 .36335 .54617 Mtetra
.469 .727 .982 r
.36335 .54617 .36426 .54683 .36571 .54672 .3648 .54616 Mtetra
.913 .529 .271 r
.3648 .54616 .36571 .54672 .36699 .55019 .36607 .54984 Mtetra
.939 .682 .522 r
.36607 .54984 .36699 .55019 .35956 .74154 .35859 .74118 Mtetra
.921 .581 .376 r
.35859 .74118 .35956 .74154 .36081 .74765 .35986 .74686 Mtetra
0 .294 .751 r
.35986 .74686 .36081 .74765 .3623 .74857 .36135 .74776 Mtetra
.61 .746 .942 r
.36135 .74776 .3623 .74857 .36385 .74826 .3629 .74745 Mtetra
.797 .777 .835 r
.3629 .74745 .36385 .74826 .36545 .74691 .3645 .74612 Mtetra
.906 .744 .67 r
.3645 .74612 .36545 .74691 .3672 .74218 .36625 .74139 Mtetra
.939 .687 .529 r
.36625 .74139 .3672 .74218 .37715 .55014 .37625 .54932 Mtetra
.916 .726 .631 r
.37625 .54932 .37715 .55014 .37889 .54361 .37799 .54277 Mtetra
.802 .762 .816 r
.37799 .54277 .37889 .54361 .3804 .54225 .3795 .5414 Mtetra
.657 .741 .911 r
.3795 .5414 .3804 .54225 .38187 .54182 .38098 .54096 Mtetra
.531 .698 .946 r
.38098 .54096 .38187 .54182 .38333 .54177 .38244 .54091 Mtetra
.736 .755 .867 r
.38244 .54091 .38333 .54177 .38482 .54094 .38393 .54008 Mtetra
.708 .749 .884 r
.38393 .54008 .38482 .54094 .3863 .54028 .38541 .53941 Mtetra
.534 .697 .944 r
.38541 .53941 .3863 .54028 .38777 .54022 .38687 .53935 Mtetra
.9 .484 .137 r
.38687 .53935 .38777 .54022 .3891 .54341 .3882 .54254 Mtetra
.942 .684 .517 r
.3882 .54254 .3891 .54341 .38294 .73423 .382 .7334 Mtetra
.942 .604 .356 r
.382 .7334 .38294 .73423 .38423 .74069 .38329 .73989 Mtetra
.019 .449 .871 r
.38329 .73989 .38423 .74069 .38576 .74133 .38481 .74056 Mtetra
.663 .772 .931 r
.38481 .74056 .38576 .74133 .38733 .74081 .38638 .74006 Mtetra
.754 .791 .883 r
.38638 .74006 .38733 .74081 .38892 .73988 .38797 .73912 Mtetra
.674 .779 .929 r
.38797 .73912 .38892 .73988 .39049 .73944 .38955 .73858 Mtetra
.639 .747 .927 r
.38955 .73858 .39049 .73944 .39206 .73917 .39112 .73818 Mtetra
.639 .718 .905 r
.39112 .73818 .39206 .73917 .39362 .73891 .39269 .73779 Mtetra
.638 .693 .885 r
.39269 .73779 .39362 .73891 .39519 .73857 .39426 .73742 Mtetra
.637 .686 .879 r
.39426 .73742 .39519 .73857 .39676 .73819 .39583 .73704 Mtetra
.39583 .73704 .39676 .73819 .39834 .7378 .39741 .73666 Mtetra
.641 .689 .88 r
.39741 .73666 .39834 .7378 .39991 .73742 .39898 .73627 Mtetra
.642 .688 .878 r
.39898 .73627 .39991 .73742 .40148 .73704 .40056 .73587 Mtetra
.643 .685 .875 r
.40056 .73587 .40148 .73704 .40306 .73665 .40213 .73547 Mtetra
.629 .678 .878 r
.40213 .73547 .40306 .73665 .40463 .73643 .40371 .73513 Mtetra
.634 .66 .858 r
.40371 .73513 .40463 .73643 .40621 .73612 .40529 .73477 Mtetra
.651 .659 .844 r
.40529 .73477 .40621 .73612 .40779 .7355 .40687 .73431 Mtetra
.71 .703 .841 r
.40687 .73431 .40779 .7355 .40942 .73367 .40846 .73352 Mtetra
.761 .941 .941 r
.40846 .73352 .40942 .73367 .41109 .73046 .41006 .73252 Mtetra
.28 0 .177 r
.41006 .73252 .41109 .73046 .41285 .72459 .41167 .73149 Mtetra
.541 .282 .473 r
.41167 .73149 .41285 .72459 .41453 .72078 .41324 .73126 Mtetra
.552 .309 .501 r
.41324 .73126 .41453 .72078 .41607 .72157 .41482 .73109 Mtetra
.526 .284 .49 r
.41482 .73109 .41607 .72157 .41766 .72099 .41642 .73029 Mtetra
.319 .108 .427 r
.41642 .73029 .41766 .72099 .42472 .53674 .41813 .72568 Mtetra
0 0 .322 r
.41813 .72568 .42472 .53674 .42639 .53066 .4254 .53337 Mtetra
.887 .846 .387 r
.4254 .53337 .42639 .53066 .42796 .52775 .42706 .52748 Mtetra
.876 .882 .835 r
.42706 .52748 .42796 .52775 .42948 .52652 .4286 .5258 Mtetra
.676 .781 .929 r
.4286 .5258 .42948 .52652 .43098 .52601 .4301 .52528 Mtetra
.543 .736 .965 r
.4301 .52528 .43098 .52601 .43248 .52578 .4316 .52514 Mtetra
.581 .777 .973 r
.4316 .52514 .43248 .52578 .43398 .52554 .43309 .52488 Mtetra
.627 .785 .957 r
.43309 .52488 .43398 .52554 .43547 .52527 .4346 .5245 Mtetra
.637 .759 .937 r
.4346 .5245 .43547 .52527 .43697 .52497 .4361 .52412 Mtetra
.658 .745 .914 r
.4361 .52412 .43697 .52497 .43848 .52448 .4376 .52367 Mtetra
.669 .757 .916 r
.4376 .52367 .43848 .52448 .43999 .52387 .43911 .52317 Mtetra
.67 .787 .936 r
.43911 .52317 .43999 .52387 .4415 .52323 .44062 .52266 Mtetra
.656 .818 .961 r
.44062 .52266 .4415 .52323 .44301 .52268 .44213 .52218 Mtetra
.643 .835 .974 r
.44213 .52218 .44301 .52268 .44452 .52219 .44364 .52171 Mtetra
.64 .841 .978 r
.44364 .52171 .44452 .52219 .44603 .52172 .44515 .52125 Mtetra
.661 .846 .971 r
.44515 .52125 .44603 .52172 .44754 .5211 .44666 .52072 Mtetra
.649 .871 .982 r
.44666 .52072 .44754 .5211 .44906 .5205 .44817 .52019 Mtetra
.596 .878 .992 r
.44817 .52019 .44906 .5205 .45057 .52015 .44969 .51974 Mtetra
.477 .807 1 r
.44969 .51974 .45057 .52015 .45205 .52076 .45119 .51956 Mtetra
.534 .625 .888 r
.45119 .51956 .45205 .52076 .45352 .52267 .4527 .51959 Mtetra
.566 .473 .709 r
.4527 .51959 .45352 .52267 .45494 .52691 .4542 .51966 Mtetra
.581 .415 .622 r
.4542 .51966 .45494 .52691 .45627 .53556 .45571 .51946 Mtetra
.578 .386 .586 r
.45571 .51946 .45627 .53556 .45772 .5389 .45723 .51898 Mtetra
.577 .381 .58 r
.45723 .51898 .45772 .5389 .45938 .53151 .45875 .5184 Mtetra
.582 .395 .593 r
.45875 .5184 .45938 .53151 .46093 .52935 .46027 .51786 Mtetra
.583 .399 .598 r
.46027 .51786 .46093 .52935 .46246 .52884 .46179 .51737 Mtetra
.46179 .51737 .46246 .52884 .46398 .52834 .46331 .51689 Mtetra
.46331 .51689 .46398 .52834 .46551 .52788 .46483 .51642 Mtetra
.46483 .51642 .46551 .52788 .46704 .52746 .46636 .51595 Mtetra
.46636 .51595 .46704 .52746 .46856 .52706 .46788 .51548 Mtetra
.582 .398 .598 r
.46788 .51548 .46856 .52706 .47009 .52666 .4694 .51501 Mtetra
.582 .398 .597 r
.4694 .51501 .47009 .52666 .47162 .52626 .47093 .51454 Mtetra
.47093 .51454 .47162 .52626 .47315 .52584 .47245 .51407 Mtetra
.47245 .51407 .47315 .52584 .47468 .52541 .47398 .5136 Mtetra
.47398 .5136 .47468 .52541 .47621 .52494 .47551 .51312 Mtetra
.47551 .51312 .47621 .52494 .47774 .52441 .47704 .51264 Mtetra
.583 .398 .597 r
.47704 .51264 .47774 .52441 .47928 .52375 .47857 .51215 Mtetra
.583 .399 .598 r
.47857 .51215 .47928 .52375 .48082 .52301 .4801 .51164 Mtetra
.584 .4 .599 r
.4801 .51164 .48082 .52301 .48236 .52228 .48163 .51113 Mtetra
.591 .406 .6 r
.48163 .51113 .48236 .52228 .48391 .52021 .48317 .51035 Mtetra
.596 .414 .606 r
.48317 .51035 .48391 .52021 .48547 .5183 .4847 .50953 Mtetra
.58 .407 .611 r
.4847 .50953 .48547 .5183 .487 .51851 .48623 .50926 Mtetra
.487 .336 .601 r
.48623 .50926 .487 .51851 .48654 .70105 .48774 .51127 Mtetra
0 0 .37 r
.48774 .51127 .48654 .70105 .48807 .70916 .48724 .70161 Mtetra
0 0 .418 r
.48724 .70161 .48807 .70916 .48967 .71191 .48877 .71003 Mtetra
.031 .237 .739 r
.48877 .71003 .48967 .71191 .49129 .71273 .49038 .71171 Mtetra
.594 .702 .918 r
.49038 .71171 .49129 .71273 .49292 .71241 .49201 .71148 Mtetra
.707 .755 .89 r
.49201 .71148 .49292 .71241 .49455 .71176 .49365 .71075 Mtetra
.704 .738 .878 r
.49365 .71075 .49455 .71176 .49619 .71113 .49528 .71003 Mtetra
.655 .707 .886 r
.49528 .71003 .49619 .71113 .49782 .71066 .49692 .70956 Mtetra
.656 .707 .885 r
.49692 .70956 .49782 .71066 .49945 .71019 .49855 .70908 Mtetra
.654 .706 .885 r
.49855 .70908 .49945 .71019 .50109 .70972 .50019 .70861 Mtetra
.651 .704 .885 r
.50019 .70861 .50109 .70972 .50273 .70927 .50183 .70815 Mtetra
.65 .703 .885 r
.50183 .70815 .50273 .70927 .50437 .70882 .50346 .7077 Mtetra
.65 .702 .884 r
.50346 .7077 .50437 .70882 .506 .70837 .5051 .70724 Mtetra
.65 .701 .884 r
.5051 .70724 .506 .70837 .50764 .70792 .50674 .70679 Mtetra
.648 .701 .885 r
.50674 .70679 .50764 .70792 .50928 .70749 .50839 .70635 Mtetra
.643 .696 .884 r
.50839 .70635 .50928 .70749 .51093 .70714 .51003 .70593 Mtetra
.637 .681 .875 r
.51003 .70593 .51093 .70714 .51257 .70687 .51167 .70553 Mtetra
.639 .661 .856 r
.51167 .70553 .51257 .70687 .51421 .70658 .51331 .70513 Mtetra
.646 .649 .839 r
.51331 .70513 .51421 .70658 .51586 .70615 .51496 .70467 Mtetra
.656 .65 .832 r
.51496 .70467 .51586 .70615 .5175 .70555 .51661 .70416 Mtetra
.66 .662 .841 r
.51661 .70416 .5175 .70555 .51915 .70492 .51825 .70363 Mtetra
.659 .678 .856 r
.51825 .70363 .51915 .70492 .5208 .70434 .5199 .70312 Mtetra
.654 .687 .868 r
.5199 .70312 .5208 .70434 .52245 .70387 .52155 .70264 Mtetra
.651 .684 .868 r
.52155 .70264 .52245 .70387 .5241 .70343 .5232 .70218 Mtetra
.642 .677 .868 r
.5232 .70218 .5241 .70343 .52575 .70309 .52485 .70176 Mtetra
.633 .661 .859 r
.52485 .70176 .52575 .70309 .5274 .70283 .5265 .70138 Mtetra
.644 .648 .84 r
.5265 .70138 .5274 .70283 .52905 .70234 .52816 .70094 Mtetra
.653 .659 .843 r
.52816 .70094 .52905 .70234 .5307 .70126 .52981 .70045 Mtetra
.675 .777 .927 r
.52981 .70045 .5307 .70126 .53235 .69903 .53147 .69987 Mtetra
0 0 0 r
.53147 .69987 .53235 .69903 .534 .69509 .53312 .69878 Mtetra
.156 0 .264 r
.53312 .69878 .534 .69509 .53509 .51012 .53477 .69598 Mtetra
0 0 .383 r
.53477 .69598 .53509 .51012 .53661 .49732 .53582 .5096 Mtetra
0 0 .235 r
.53582 .5096 .53661 .49732 .53817 .49396 .53733 .49449 Mtetra
.955 .951 .684 r
.53733 .49449 .53817 .49396 .53972 .49228 .53889 .49158 Mtetra
.719 .803 .917 r
.53889 .49158 .53972 .49228 .54129 .49177 .54045 .49085 Mtetra
.594 .712 .926 r
.54045 .49085 .54129 .49177 .54285 .49159 .54202 .49062 Mtetra
.571 .692 .923 r
.54202 .49062 .54285 .49159 .54442 .49138 .54358 .49047 Mtetra
.669 .741 .904 r
.54358 .49047 .54442 .49138 .54598 .49075 .54515 .48995 Mtetra
.671 .769 .923 r
.54515 .48995 .54598 .49075 .54755 .49009 .54672 .48943 Mtetra
.671 .804 .947 r
.54672 .48943 .54755 .49009 .54911 .48941 .54828 .48889 Mtetra
.665 .844 .968 r
.54828 .48889 .54911 .48941 .55068 .48872 .54985 .48834 Mtetra
.617 .871 .99 r
.54985 .48834 .55068 .48872 .55225 .48825 .55142 .48785 Mtetra
.54 .839 .999 r
.55142 .48785 .55225 .48825 .55383 .48836 .55299 .48753 Mtetra
.496 .697 .958 r
.55299 .48753 .55383 .48836 .55541 .48987 .55457 .48753 Mtetra
.56 .51 .757 r
.55457 .48753 .55541 .48987 .55702 .49306 .55615 .48761 Mtetra
.575 .429 .646 r
.55615 .48761 .55702 .49306 .5587 .50228 .55773 .48759 Mtetra
.578 .389 .589 r
.55773 .48759 .5587 .50228 .56208 .67062 .5593 .48715 Mtetra
.566 .357 .557 r
.5593 .48715 .56208 .67062 .56191 .50548 .56088 .48659 Mtetra
.578 .383 .581 r
.56088 .48659 .56191 .50548 .56342 .49873 .56245 .48599 Mtetra
.582 .395 .594 r
.56245 .48599 .56342 .49873 .565 .49806 .56403 .48548 Mtetra
.582 .396 .595 r
.56403 .48548 .565 .49806 .56658 .49737 .56561 .48497 Mtetra
.56561 .48497 .56658 .49737 .56816 .49671 .56719 .48447 Mtetra
.582 .397 .596 r
.56719 .48447 .56816 .49671 .56975 .49615 .56877 .48397 Mtetra
.56877 .48397 .56975 .49615 .57133 .49561 .57035 .48347 Mtetra
.57035 .48347 .57133 .49561 .57292 .4951 .57193 .48297 Mtetra
.57193 .48297 .57292 .4951 .57451 .49459 .57352 .48248 Mtetra
.57352 .48248 .57451 .49459 .5761 .4941 .5751 .48198 Mtetra
.5751 .48198 .5761 .4941 .57769 .49361 .57669 .48149 Mtetra
.57669 .48149 .57769 .49361 .57928 .49312 .57827 .48099 Mtetra
.57827 .48099 .57928 .49312 .58087 .49265 .57986 .4805 Mtetra
.57986 .4805 .58087 .49265 .58246 .49222 .58145 .48001 Mtetra
.58145 .48001 .58246 .49222 .58406 .49188 .58304 .47952 Mtetra
.581 .396 .595 r
.58304 .47952 .58406 .49188 .58566 .49152 .58463 .47903 Mtetra
.581 .395 .595 r
.58463 .47903 .58566 .49152 .58727 .49166 .58622 .47856 Mtetra
.578 .392 .593 r
.58622 .47856 .58727 .49166 .58906 .50151 .58781 .47817 Mtetra
.573 .376 .576 r
.58781 .47817 .58906 .50151 .59079 .50751 .5894 .4777 Mtetra
.573 .373 .571 r
.5894 .4777 .59079 .50751 .592 .48736 .59099 .47705 Mtetra
.601 .416 .604 r
.59099 .47705 .592 .48736 .59346 .48007 .59258 .47599 Mtetra
.647 .499 .669 r
.59258 .47599 .59346 .48007 .59499 .47666 .59416 .47494 Mtetra
.702 .635 .779 r
.59416 .47494 .59499 .47666 .59655 .47459 .59575 .47402 Mtetra
.673 .836 .962 r
.59575 .47402 .59655 .47459 .59814 .47382 .59734 .47344 Mtetra
.607 .872 .992 r
.59734 .47344 .59814 .47382 .59974 .47338 .59894 .47296 Mtetra
.596 .857 .993 r
.59894 .47296 .59974 .47338 .60134 .47311 .60054 .47253 Mtetra
.639 .822 .971 r
.60054 .47253 .60134 .47311 .60294 .47277 .60214 .47206 Mtetra
.65 .791 .949 r
.60214 .47206 .60294 .47277 .60455 .47242 .60374 .47158 Mtetra
.667 .763 .922 r
.60374 .47158 .60455 .47242 .60615 .47199 .60534 .47106 Mtetra
.747 .764 .866 r
.60534 .47106 .60615 .47199 .60774 .47109 .60693 .47013 Mtetra
.689 .741 .89 r
.60693 .47013 .60774 .47109 .60934 .47038 .60853 .4695 Mtetra
.483 .683 .954 r
.60853 .4695 .60934 .47038 .61094 .47009 .61014 .46955 Mtetra
.871 .428 .073 r
.61014 .46955 .61094 .47009 .61259 .47134 .61185 .47292 Mtetra
.962 .681 .454 r
.61185 .47292 .61259 .47134 .6143 .47461 .61868 .66673 Mtetra
.575 .36 .552 r
.61868 .66673 .6143 .47461 .62117 .66445 .62059 .67368 Mtetra
.581 .328 .498 r
.62059 .67368 .62117 .66445 .62309 .67187 .62233 .67448 Mtetra
.519 .184 .34 r
.62233 .67448 .62309 .67187 .62488 .67419 .62406 .67444 Mtetra
0 0 0 r
.62406 .67444 .62488 .67419 .62663 .67516 .62577 .67398 Mtetra
.645 .698 .885 r
.62577 .67398 .62663 .67516 .62835 .67481 .62748 .67353 Mtetra
.666 .688 .861 r
.62748 .67353 .62835 .67481 .63006 .6741 .6292 .67297 Mtetra
.676 .717 .88 r
.6292 .67297 .63006 .6741 .63176 .67324 .63091 .67236 Mtetra
.489 .699 .962 r
.63091 .67236 .63176 .67324 .63349 .6732 .63264 .67237 Mtetra
.598 .757 .954 r
.63264 .67237 .63349 .6732 .63521 .67298 .63436 .67205 Mtetra
.745 .779 .88 r
.63436 .67205 .63521 .67298 .63693 .67233 .63606 .67109 Mtetra
.907 .741 .664 r
.63606 .67109 .63693 .67233 .63858 .66997 .63765 .6666 Mtetra
.964 .687 .459 r
.63765 .6666 .63858 .66997 .64017 .66555 .633 .47183 Mtetra
.579 .367 .557 r
.633 .47183 .64017 .66555 .63553 .47548 .63436 .46359 Mtetra
.612 .42 .597 r
.63436 .46359 .63553 .47548 .63686 .46648 .63594 .46187 Mtetra
.628 .478 .659 r
.63594 .46187 .63686 .46648 .6384 .46339 .63755 .461 Mtetra
.632 .551 .744 r
.63755 .461 .6384 .46339 .63997 .46154 .63917 .46051 Mtetra
.678 .725 .886 r
.63917 .46051 .63997 .46154 .64158 .46073 .64079 .45993 Mtetra
.662 .775 .933 r
.64079 .45993 .64158 .46073 .6432 .46025 .64241 .45942 Mtetra
.654 .765 .931 r
.64241 .45942 .6432 .46025 .64483 .4599 .64403 .45894 Mtetra
.755 .763 .86 r
.64403 .45894 .64483 .4599 .64643 .4588 .64564 .45794 Mtetra
.711 .773 .901 r
.64564 .45794 .64643 .4588 .64804 .45798 .64725 .45722 Mtetra
.516 .727 .969 r
.64725 .45722 .64804 .45798 .64968 .45783 .6489 .45713 Mtetra
.858 .414 .012 r
.6489 .45713 .64968 .45783 .65147 .46147 .65068 .46067 Mtetra
.969 .683 .434 r
.65068 .46067 .65147 .46147 .66082 .65883 .65996 .65729 Mtetra
.893 .513 .057 r
.65996 .65729 .66082 .65883 .66281 .66478 .66195 .66344 Mtetra
.411 .557 .89 r
.66195 .66344 .66281 .66478 .66457 .66514 .66372 .66389 Mtetra
.672 .697 .865 r
.66372 .66389 .66457 .66514 .6663 .66444 .66545 .66329 Mtetra
.742 .737 .847 r
.66545 .66329 .6663 .66444 .66801 .66331 .66717 .66225 Mtetra
.639 .721 .907 r
.66717 .66225 .66801 .66331 .66976 .66308 .66891 .66182 Mtetra
.625 .677 .879 r
.66891 .66182 .66976 .66308 .67151 .66288 .67065 .66146 Mtetra
.644 .661 .852 r
.67065 .66146 .67151 .66288 .67325 .66233 .6724 .661 Mtetra
.644 .674 .864 r
.6724 .661 .67325 .66233 .67494 .66062 .67414 .66055 Mtetra
.616 .947 .936 r
.67414 .66055 .67494 .66062 .67657 .65761 .67587 .65973 Mtetra
.194 0 .169 r
.67587 .65973 .67657 .65761 .67804 .65089 .67756 .65815 Mtetra
.142 0 .371 r
.67756 .65815 .67804 .65089 .67119 .45791 .67905 .65188 Mtetra
.04 0 .431 r
.67905 .65188 .67119 .45791 .67263 .45301 .67199 .45516 Mtetra
.715 .738 .224 r
.67199 .45516 .67263 .45301 .67418 .45055 .67342 .45013 Mtetra
.837 .9 .883 r
.67342 .45013 .67418 .45055 .67581 .44964 .67503 .44876 Mtetra
.644 .75 .926 r
.67503 .44876 .67581 .44964 .67746 .44932 .67667 .44832 Mtetra
.545 .682 .928 r
.67667 .44832 .67746 .44932 .67912 .44924 .67833 .44824 Mtetra
.643 .723 .906 r
.67833 .44824 .67912 .44924 .68076 .44869 .67998 .44782 Mtetra
.662 .759 .922 r
.67998 .44782 .68076 .44869 .6824 .4481 .68163 .44731 Mtetra
.642 .771 .942 r
.68163 .44731 .6824 .4481 .68406 .44778 .68328 .44686 Mtetra
.572 .713 .938 r
.68328 .44686 .68406 .44778 .68577 .44864 .68494 .44668 Mtetra
.577 .553 .791 r
.68494 .44668 .68577 .44864 .68755 .45083 .68661 .44662 Mtetra
.578 .453 .674 r
.68661 .44662 .68755 .45083 .68949 .45607 .68828 .44658 Mtetra
.596 .416 .608 r
.68828 .44658 .68949 .45607 .6913 .45853 .68992 .44577 Mtetra
.588 .4 .595 r
.68992 .44577 .6913 .45853 .69286 .45627 .69156 .44499 Mtetra
.574 .394 .6 r
.69156 .44499 .69286 .45627 .69454 .45617 .69323 .44484 Mtetra
.446 .302 .591 r
.69323 .44484 .69454 .45617 .70607 .64451 .6951 .44862 Mtetra
.062 0 .449 r
.6951 .44862 .70607 .64451 .70813 .64972 .70711 .64514 Mtetra
0 .04 .56 r
.70711 .64514 .70813 .64972 .71003 .65191 .70918 .65032 Mtetra
.332 .471 .85 r
.70918 .65032 .71003 .65191 .71185 .65239 .71101 .65117 Mtetra
.627 .688 .888 r
.71101 .65117 .71185 .65239 .71362 .65204 .71278 .6508 Mtetra
.714 .717 .851 r
.71278 .6508 .71362 .65204 .71536 .65116 .71453 .64993 Mtetra
.68 .708 .869 r
.71453 .64993 .71536 .65116 .71707 .64948 .71629 .64927 Mtetra
.652 .94 .964 r
.71629 .64927 .71707 .64948 .71871 .64671 .71804 .64847 Mtetra
.15 0 .102 r
.71804 .64847 .71871 .64671 .72019 .64121 .71976 .647 Mtetra
.164 0 .358 r
.71976 .647 .72019 .64121 .71094 .44709 .72128 .64208 Mtetra
.062 0 .444 r
.72128 .64208 .71094 .44709 .71229 .4411 .71177 .44441 Mtetra
0 0 .004 r
.71177 .44441 .71229 .4411 .71383 .43838 .7131 .43819 Mtetra
.89 .95 .84 r
.7131 .43819 .71383 .43838 .71546 .43726 .7147 .43643 Mtetra
.664 .772 .93 r
.7147 .43643 .71546 .43726 .71713 .43688 .71636 .4359 Mtetra
.556 .694 .932 r
.71636 .4359 .71713 .43688 .71882 .43677 .71805 .43578 Mtetra
.609 .714 .919 r
.71805 .43578 .71882 .43677 .7205 .43646 .71973 .43547 Mtetra
.652 .731 .907 r
.71973 .43547 .7205 .43646 .72217 .43598 .7214 .435 Mtetra
.658 .736 .908 r
.7214 .435 .72217 .43598 .72383 .43544 .72307 .43451 Mtetra
.686 .757 .906 r
.72307 .43451 .72383 .43544 .72549 .43461 .72474 .43388 Mtetra
.694 .809 .937 r
.72474 .43388 .72549 .43461 .72714 .43377 .7264 .43322 Mtetra
.658 .85 .974 r
.7264 .43322 .72714 .43377 .72881 .43322 .72807 .43265 Mtetra
.649 .84 .974 r
.72807 .43265 .72881 .43322 .73053 .43355 .72974 .43211 Mtetra
.615 .634 .847 r
.72974 .43211 .73053 .43355 .73234 .43509 .73143 .43182 Mtetra
.541 .457 .709 r
.73143 .43182 .73234 .43509 .73432 .43941 .73316 .43215 Mtetra
.393 .287 .615 r
.73316 .43215 .73432 .43941 .74856 .63288 .73508 .4355 Mtetra
.086 .008 .462 r
.73508 .4355 .74856 .63288 .75072 .63812 .74961 .63248 Mtetra
.072 .09 .572 r
.74961 .63248 .75072 .63812 .75267 .6401 .75181 .63824 Mtetra
.297 .414 .812 r
.75181 .63824 .75267 .6401 .75453 .64065 .75371 .63941 Mtetra
.611 .679 .89 r
.75371 .63941 .75453 .64065 .75633 .64037 .75551 .6391 Mtetra
.706 .714 .855 r
.75551 .6391 .75633 .64037 .7581 .63955 .75728 .63828 Mtetra
.689 .707 .862 r
.75728 .63828 .7581 .63955 .75983 .63801 .75906 .63756 Mtetra
.677 .895 .976 r
.75906 .63756 .75983 .63801 .76148 .63545 .76084 .63682 Mtetra
.082 0 0 r
.76084 .63682 .76148 .63545 .76299 .63078 .76258 .63548 Mtetra
.181 0 .342 r
.76258 .63548 .76299 .63078 .75136 .43708 .76414 .63151 Mtetra
.083 .002 .456 r
.76414 .63151 .75136 .43708 .75254 .4292 .75221 .43442 Mtetra
0 0 .192 r
.75221 .43442 .75254 .4292 .75405 .42617 .75337 .42622 Mtetra
.92 .975 .763 r
.75337 .42622 .75405 .42617 .75568 .42482 .75494 .42401 Mtetra
.685 .791 .93 r
.75494 .42401 .75568 .42482 .75737 .42436 .75662 .42339 Mtetra
.572 .704 .931 r
.75662 .42339 .75737 .42436 .75908 .42422 .75833 .42321 Mtetra
.615 .715 .917 r
.75833 .42321 .75908 .42422 .76078 .4238 .76004 .42288 Mtetra
.675 .761 .915 r
.76004 .42288 .76078 .4238 .76246 .42311 .76173 .4223 Mtetra
.658 .781 .939 r
.76173 .4223 .76246 .42311 .76416 .42265 .76342 .42178 Mtetra
.667 .769 .926 r
.76342 .42178 .76416 .42265 .76591 .42287 .76511 .42123 Mtetra
.635 .62 .818 r
.76511 .42123 .76591 .42287 .76774 .4242 .76681 .42081 Mtetra
.562 .467 .704 r
.76681 .42081 .76774 .4242 .76975 .42776 .76856 .42094 Mtetra
.437 .323 .626 r
.76856 .42094 .76975 .42776 .78613 .62077 .77049 .42347 Mtetra
.105 .024 .472 r
.77049 .42347 .78613 .62077 .78846 .6271 .78719 .61985 Mtetra
.096 .088 .557 r
.78719 .61985 .78846 .6271 .79048 .62931 .7896 .62719 Mtetra
.259 .363 .779 r
.7896 .62719 .79048 .62931 .79238 .62991 .79157 .62871 Mtetra
.607 .687 .899 r
.79157 .62871 .79238 .62991 .7942 .62952 .79341 .62841 Mtetra
.716 .748 .878 r
.79341 .62841 .7942 .62952 .79598 .62857 .7952 .62756 Mtetra
.707 .765 .897 r
.7952 .62756 .79598 .62857 .79772 .627 .79699 .62677 Mtetra
.559 .909 .969 r
.79699 .62677 .79772 .627 .79938 .62454 .7988 .62615 Mtetra
.223 0 .113 r
.7988 .62615 .79938 .62454 .80089 .62019 .80057 .62499 Mtetra
.272 .045 .375 r
.80057 .62499 .80089 .62019 .78728 .42859 .80216 .62167 Mtetra
.104 .02 .466 r
.80216 .62167 .78728 .42859 .78826 .41896 .78825 .42706 Mtetra
0 0 .302 r
.78825 .42706 .78826 .41896 .78974 .4157 .78908 .41566 Mtetra
.954 .944 .726 r
.78908 .41566 .78974 .4157 .79136 .41408 .79062 .41301 Mtetra
.706 .739 .877 r
.79062 .41301 .79136 .41408 .79306 .41342 .79231 .41225 Mtetra
.609 .681 .893 r
.79231 .41225 .79306 .41342 .79478 .41304 .79404 .41197 Mtetra
.665 .725 .894 r
.79404 .41197 .79478 .41304 .79648 .41233 .79575 .41143 Mtetra
.749 .79 .886 r
.79575 .41143 .79648 .41233 .79815 .41125 .79743 .41047 Mtetra
.638 .783 .951 r
.79743 .41047 .79815 .41125 .79986 .41069 .79915 .41 Mtetra
0 .227 .703 r
.79915 .41 .79986 .41069 .80172 .41192 .80102 .4113 Mtetra
.951 .6 .249 r
.80102 .4113 .80172 .41192 .80452 .42398 .80387 .42393 Mtetra
.975 .672 .366 r
.80387 .42393 .80452 .42398 .82316 .6186 .82237 .61735 Mtetra
0 .058 .613 r
.82237 .61735 .82316 .6186 .82525 .62102 .82445 .61972 Mtetra
.589 .663 .889 r
.82445 .61972 .82525 .62102 .82712 .62082 .82632 .61951 Mtetra
.709 .714 .853 r
.82632 .61951 .82712 .62082 .82891 .61981 .82812 .61865 Mtetra
.723 .744 .869 r
.82812 .61865 .82891 .61981 .83065 .61815 .82993 .61774 Mtetra
.612 .888 .99 r
.82993 .61774 .83065 .61815 .83232 .61582 .83176 .61714 Mtetra
.167 0 .026 r
.83176 .61714 .83232 .61582 .83385 .61183 .83355 .61603 Mtetra
.277 .038 .36 r
.83355 .61603 .83385 .61183 .81897 .42661 .83517 .61313 Mtetra
.52 .32 .549 r
.83517 .61313 .81897 .42661 .81923 .40986 .83459 .58587 Mtetra
.112 .028 .472 r
.83459 .58587 .81923 .40986 .82068 .4063 .82006 .40642 Mtetra
.963 .942 .665 r
.82006 .40642 .82068 .4063 .82229 .4045 .82155 .40337 Mtetra
.716 .735 .865 r
.82155 .40337 .82229 .4045 .824 .40379 .82326 .40254 Mtetra
.619 .671 .878 r
.82326 .40254 .824 .40379 .82575 .40341 .825 .40221 Mtetra
.64 .691 .881 r
.825 .40221 .82575 .40341 .82748 .40288 .82674 .40178 Mtetra
.737 .748 .861 r
.82674 .40178 .82748 .40288 .82917 .4019 .82844 .40082 Mtetra
.652 .719 .897 r
.82844 .40082 .82917 .4019 .8309 .40141 .83017 .40033 Mtetra
.154 .44 .874 r
.83017 .40033 .8309 .40141 .83279 .40247 .83205 .40131 Mtetra
.913 .541 .105 r
.83205 .40131 .83279 .40247 .83569 .41405 .8347 .41034 Mtetra
.976 .671 .335 r
.8347 .41034 .83569 .41405 .85632 .60914 .85552 .60764 Mtetra
0 .01 .581 r
.85552 .60764 .85632 .60914 .85849 .61181 .8577 .61057 Mtetra
.503 .631 .909 r
.8577 .61057 .85849 .61181 .86038 .6117 .85962 .61068 Mtetra
.72 .774 .896 r
.85962 .61068 .86038 .6117 .8622 .61074 .86145 .60981 Mtetra
.88 .822 .786 r
.86145 .60981 .8622 .61074 .86393 .60896 .86314 .60756 Mtetra
.95 .747 .595 r
.86314 .60756 .86393 .60896 .86555 .60602 .86441 .60115 Mtetra
.975 .675 .372 r
.86441 .60115 .86555 .60602 .86688 .60013 .84639 .40125 Mtetra
.572 .362 .556 r
.84639 .40125 .86688 .60013 .84916 .40476 .8477 .39634 Mtetra
.617 .435 .614 r
.8477 .39634 .84916 .40476 .85038 .399 .84936 .39496 Mtetra
.626 .49 .676 r
.84936 .39496 .85038 .399 .8519 .39628 .85108 .39422 Mtetra
.637 .583 .777 r
.85108 .39422 .8519 .39628 .85354 .39469 .85283 .39373 Mtetra
.669 .753 .914 r
.85283 .39373 .85354 .39469 .85527 .394 .85458 .39316 Mtetra
.649 .775 .94 r
.85458 .39316 .85527 .394 .85703 .39357 .85633 .39266 Mtetra
.678 .768 .919 r
.85633 .39266 .85703 .39357 .85879 .39308 .85807 .39204 Mtetra
.743 .765 .871 r
.85807 .39204 .85879 .39308 .86049 .3921 .85978 .39107 Mtetra
.675 .741 .901 r
.85978 .39107 .86049 .3921 .86222 .39137 .86152 .39046 Mtetra
.341 .603 .945 r
.86152 .39046 .86222 .39137 .86402 .39126 .86338 .39087 Mtetra
.851 .404 0 r
.86338 .39087 .86402 .39126 .86599 .39277 .86565 .39527 Mtetra
.973 .663 .342 r
.86565 .39527 .86599 .39277 .86825 .39697 .88869 .59462 Mtetra
.571 .357 .551 r
.88869 .59462 .86825 .39697 .89101 .59233 .89114 .59946 Mtetra
.572 .305 .473 r
.89114 .59946 .89101 .59233 .8935 .59756 .89313 .59999 Mtetra
.493 .149 .311 r
.89313 .59999 .8935 .59756 .89565 .5995 .89505 .59979 Mtetra
0 0 0 r
.89505 .59979 .89565 .5995 .89768 .60038 .89694 .59938 Mtetra
.49 .678 .949 r
.89694 .59938 .89768 .60038 .89966 .60071 .89889 .59943 Mtetra
.644 .695 .883 r
.89889 .59943 .89966 .60071 .90155 .60028 .90078 .59894 Mtetra
.801 .747 .803 r
.90078 .59894 .90155 .60028 .9033 .59857 .90254 .59728 Mtetra
.965 .753 .567 r
.90254 .59728 .9033 .59857 .90444 .59131 .90368 .5901 Mtetra
.977 .673 .339 r
.90368 .5901 .90444 .59131 .88375 .3888 .8831 .38816 Mtetra
.978 .818 .616 r
.8831 .38816 .88375 .3888 .88506 .38419 .8844 .3835 Mtetra
.762 .856 .92 r
.8844 .3835 .88506 .38419 .88679 .38329 .88612 .38249 Mtetra
.604 .771 .96 r
.88612 .38249 .88679 .38329 .88859 .38304 .88791 .38213 Mtetra
.556 .718 .949 r
.88791 .38213 .88859 .38304 .89041 .38298 .88972 .38196 Mtetra
.742 .771 .876 r
.88972 .38196 .89041 .38298 .89214 .38206 .89144 .381 Mtetra
.679 .739 .896 r
.89144 .381 .89214 .38206 .89389 .38133 .8932 .38037 Mtetra
.451 .652 .945 r
.8932 .38037 .89389 .38133 .8957 .38112 .89506 .38054 Mtetra
.784 .322 0 r
.89506 .38054 .8957 .38112 .89773 .38279 .89734 .38442 Mtetra
.972 .659 .32 r
.89734 .38442 .89773 .38279 .90005 .38695 .92248 .58402 Mtetra
.572 .357 .551 r
.92248 .58402 .90005 .38695 .92458 .58005 .92511 .58976 Mtetra
.557 .308 .493 r
.92511 .58976 .92458 .58005 .92657 .58037 .92708 .58982 Mtetra
.533 .288 .49 r
.92708 .58982 .92657 .58037 .92833 .57871 .92896 .5891 Mtetra
.529 .29 .496 r
.92896 .5891 .92833 .57871 .93037 .5794 .93081 .58816 Mtetra
.557 .303 .487 r
.93081 .58816 .93037 .5794 .93308 .58564 .93279 .58825 Mtetra
.529 .187 .333 r
.93279 .58825 .93308 .58564 .93537 .58834 .93477 .58833 Mtetra
.035 .606 .73 r
.93477 .58833 .93537 .58834 .9375 .58965 .93673 .58829 Mtetra
.633 .679 .875 r
.93673 .58829 .9375 .58965 .93944 .58941 .93865 .58785 Mtetra
.648 .656 .844 r
.93865 .58785 .93944 .58941 .94134 .58884 .94056 .58732 Mtetra
.653 .665 .849 r
.94056 .58732 .94134 .58884 .94323 .58813 .94247 .58676 Mtetra
.632 .676 .874 r
.94247 .58676 .94323 .58813 .94517 .58781 .9444 .58633 Mtetra
.632 .661 .86 r
.9444 .58633 .94517 .58781 .94711 .58747 .94632 .5859 Mtetra
.635 .649 .847 r
.94632 .5859 .94711 .58747 .94904 .58707 .94825 .58545 Mtetra
.581 .614 .85 r
.94825 .58545 .94904 .58707 .95097 .5867 .95021 .58531 Mtetra
.642 .679 .87 r
.95021 .58531 .95097 .5867 .95288 .58608 .95213 .58482 Mtetra
.75 .747 .85 r
.95213 .58482 .95288 .58608 .95473 .58503 .95398 .58367 Mtetra
.854 .639 .612 r
.33581 .75015 .33662 .75382 .33836 .74952 .33785 .74025 Mtetra
.924 .674 .541 r
.33785 .74025 .33836 .74952 .34967 .56062 .34909 .55338 Mtetra
.701 .504 .62 r
.34909 .55338 .34967 .56062 .35154 .55215 .35073 .54954 Mtetra
.666 .552 .715 r
.35073 .54954 .35154 .55215 .35306 .55053 .35221 .54868 Mtetra
.62 .575 .782 r
.35221 .54868 .35306 .55053 .35454 .5497 .35366 .54838 Mtetra
.562 .613 .861 r
.35366 .54838 .35454 .5497 .356 .54925 .3551 .54835 Mtetra
.7 .737 .88 r
.3551 .54835 .356 .54925 .35746 .5487 .35657 .54772 Mtetra
.692 .719 .87 r
.35657 .54772 .35746 .5487 .35893 .54823 .35804 .54712 Mtetra
.658 .686 .865 r
.35804 .54712 .35893 .54823 .36039 .54779 .3595 .54667 Mtetra
.595 .662 .885 r
.3595 .54667 .36039 .54779 .36188 .54683 .36095 .54649 Mtetra
.031 .566 .852 r
.36095 .54649 .36188 .54683 .36335 .54617 .36238 .54675 Mtetra
.696 .254 .196 r
.36238 .54675 .36335 .54617 .3648 .54616 .36378 .54785 Mtetra
.869 .572 .483 r
.36378 .54785 .3648 .54616 .36607 .54984 .36484 .55595 Mtetra
.929 .672 .529 r
.36484 .55595 .36607 .54984 .35859 .74118 .35752 .74283 Mtetra
.792 .46 .426 r
.35752 .74283 .35859 .74118 .35986 .74686 .35889 .74618 Mtetra
0 .326 .753 r
.35889 .74618 .35986 .74686 .36135 .74776 .36039 .74696 Mtetra
.574 .742 .955 r
.36039 .74696 .36135 .74776 .3629 .74745 .36194 .74675 Mtetra
.786 .801 .865 r
.36194 .74675 .3629 .74745 .3645 .74612 .36353 .74561 Mtetra
.919 .767 .676 r
.36353 .74561 .3645 .74612 .36625 .74139 .36527 .7411 Mtetra
.94 .688 .528 r
.36527 .7411 .36625 .74139 .37625 .54932 .37533 .54902 Mtetra
.938 .749 .621 r
.37533 .54902 .37625 .54932 .37799 .54277 .37709 .54196 Mtetra
.808 .768 .816 r
.37709 .54196 .37799 .54277 .3795 .5414 .37861 .54055 Mtetra
.659 .74 .91 r
.37861 .54055 .3795 .5414 .38098 .54096 .38008 .5401 Mtetra
.531 .696 .945 r
.38008 .5401 .38098 .54096 .38244 .54091 .38154 .54005 Mtetra
.737 .755 .867 r
.38154 .54005 .38244 .54091 .38393 .54008 .38304 .53921 Mtetra
.708 .749 .884 r
.38304 .53921 .38393 .54008 .38541 .53941 .38452 .53855 Mtetra
.536 .696 .943 r
.38452 .53855 .38541 .53941 .38687 .53935 .38598 .53848 Mtetra
.9 .483 .135 r
.38598 .53848 .38687 .53935 .3882 .54254 .38731 .54166 Mtetra
.942 .684 .517 r
.38731 .54166 .3882 .54254 .382 .7334 .38105 .7326 Mtetra
.941 .603 .359 r
.38105 .7326 .382 .7334 .38329 .73989 .38234 .73911 Mtetra
0 .389 .826 r
.38234 .73911 .38329 .73989 .38481 .74056 .38386 .73987 Mtetra
.646 .789 .95 r
.38386 .73987 .38481 .74056 .38638 .74006 .38543 .73942 Mtetra
.774 .816 .886 r
.38543 .73942 .38638 .74006 .38797 .73912 .38702 .73838 Mtetra
.796 .794 .851 r
.38702 .73838 .38797 .73912 .38955 .73858 .38863 .73712 Mtetra
.767 .683 .771 r
.38863 .73712 .38955 .73858 .39112 .73818 .39024 .73563 Mtetra
.722 .593 .711 r
.39024 .73563 .39112 .73818 .39269 .73779 .39185 .73401 Mtetra
.641 .505 .682 r
.39185 .73401 .39269 .73779 .39426 .73742 .39344 .73315 Mtetra
.601 .468 .672 r
.39344 .73315 .39426 .73742 .39583 .73704 .39501 .73279 Mtetra
.587 .459 .673 r
.39501 .73279 .39583 .73704 .39741 .73666 .39658 .73263 Mtetra
.613 .481 .677 r
.39658 .73263 .39741 .73666 .39898 .73627 .39816 .73213 Mtetra
.61 .477 .675 r
.39816 .73213 .39898 .73627 .40056 .73587 .39973 .73166 Mtetra
.588 .461 .674 r
.39973 .73166 .40056 .73587 .40213 .73547 .4013 .73147 Mtetra
.51 .413 .681 r
.4013 .73147 .40213 .73547 .40371 .73513 .40284 .73214 Mtetra
.468 .422 .723 r
.40284 .73214 .40371 .73513 .40529 .73477 .40438 .7329 Mtetra
.45 .495 .814 r
.40438 .7329 .40529 .73477 .40687 .73431 .40593 .7334 Mtetra
.538 .702 .946 r
.40593 .7334 .40687 .73431 .40846 .73352 .4075 .73332 Mtetra
.496 .87 .98 r
.4075 .73332 .40846 .73352 .41006 .73252 .40908 .73293 Mtetra
0 0 0 r
.40908 .73293 .41006 .73252 .41167 .73149 .41067 .73243 Mtetra
.365 0 0 r
.41067 .73243 .41167 .73149 .41324 .73126 .41225 .73227 Mtetra
.345 0 .009 r
.41225 .73227 .41324 .73126 .41482 .73109 .41383 .73202 Mtetra
.048 0 0 r
.41383 .73202 .41482 .73109 .41642 .73029 .41543 .73128 Mtetra
.911 .964 .648 r
.41543 .73128 .41642 .73029 .41813 .72568 .41709 .72836 Mtetra
.997 .839 .497 r
.41709 .72836 .41813 .72568 .4254 .53337 .41895 .71886 Mtetra
0 0 .321 r
.41895 .71886 .4254 .53337 .42706 .52748 .42609 .5298 Mtetra
0 0 .025 r
.42609 .5298 .42706 .52748 .4286 .5258 .42765 .52747 Mtetra
.389 .011 .196 r
.42765 .52747 .4286 .5258 .4301 .52528 .42915 .52701 Mtetra
.487 .115 .259 r
.42915 .52701 .4301 .52528 .4316 .52514 .43065 .52693 Mtetra
.227 0 .127 r
.43065 .52693 .4316 .52514 .43309 .52488 .43217 .52589 Mtetra
0 0 0 r
.43217 .52589 .43309 .52488 .4346 .5245 .4337 .52444 Mtetra
.827 .955 .899 r
.4337 .52444 .4346 .5245 .4361 .52412 .43523 .52319 Mtetra
.724 .743 .867 r
.43523 .52319 .4361 .52412 .4376 .52367 .43674 .52242 Mtetra
.658 .666 .846 r
.43674 .52242 .4376 .52367 .43911 .52317 .43825 .52194 Mtetra
.635 .662 .859 r
.43825 .52194 .43911 .52317 .44062 .52266 .43975 .52159 Mtetra
.633 .689 .884 r
.43975 .52159 .44062 .52266 .44213 .52218 .44126 .52125 Mtetra
.634 .718 .909 r
.44126 .52125 .44213 .52218 .44364 .52171 .44276 .52089 Mtetra
.632 .745 .929 r
.44276 .52089 .44364 .52171 .44515 .52125 .44427 .52053 Mtetra
.644 .775 .943 r
.44427 .52053 .44515 .52125 .44666 .52072 .44578 .52012 Mtetra
.655 .807 .956 r
.44578 .52012 .44666 .52072 .44817 .52019 .4473 .51964 Mtetra
.664 .826 .961 r
.4473 .51964 .44817 .52019 .44969 .51974 .44881 .51913 Mtetra
.685 .813 .944 r
.44881 .51913 .44969 .51974 .45119 .51956 .45033 .51856 Mtetra
.69 .723 .875 r
.45033 .51856 .45119 .51956 .4527 .51959 .45184 .51795 Mtetra
.668 .622 .794 r
.45184 .51795 .4527 .51959 .4542 .51966 .45336 .51735 Mtetra
.643 .556 .742 r
.45336 .51735 .4542 .51966 .45571 .51946 .45488 .5168 Mtetra
.632 .531 .722 r
.45488 .5168 .45571 .51946 .45723 .51898 .4564 .51628 Mtetra
.629 .529 .721 r
.4564 .51628 .45723 .51898 .45875 .5184 .45792 .51579 Mtetra
.63 .533 .726 r
.45792 .51579 .45875 .5184 .46027 .51786 .45944 .5153 Mtetra
.631 .536 .729 r
.45944 .5153 .46027 .51786 .46179 .51737 .46096 .51482 Mtetra
.63 .536 .729 r
.46096 .51482 .46179 .51737 .46331 .51689 .46248 .51434 Mtetra
.46248 .51434 .46331 .51689 .46483 .51642 .464 .51386 Mtetra
.63 .535 .729 r
.464 .51386 .46483 .51642 .46636 .51595 .46552 .51339 Mtetra
.629 .535 .729 r
.46552 .51339 .46636 .51595 .46788 .51548 .46704 .51292 Mtetra
.46704 .51292 .46788 .51548 .4694 .51501 .46857 .51244 Mtetra
.46857 .51244 .4694 .51501 .47093 .51454 .47009 .51198 Mtetra
.47009 .51198 .47093 .51454 .47245 .51407 .47162 .51151 Mtetra
.47162 .51151 .47245 .51407 .47398 .5136 .47315 .51104 Mtetra
.47315 .51104 .47398 .5136 .47551 .51312 .47467 .51057 Mtetra
.629 .536 .729 r
.47467 .51057 .47551 .51312 .47704 .51264 .4762 .51009 Mtetra
.631 .537 .73 r
.4762 .51009 .47704 .51264 .47857 .51215 .47773 .5096 Mtetra
.632 .538 .73 r
.47773 .5096 .47857 .51215 .4801 .51164 .47926 .50911 Mtetra
.632 .539 .731 r
.47926 .50911 .4801 .51164 .48163 .51113 .48079 .50861 Mtetra
.651 .55 .727 r
.48079 .50861 .48163 .51113 .48317 .51035 .48233 .50793 Mtetra
.657 .558 .732 r
.48233 .50793 .48317 .51035 .4847 .50953 .48386 .50721 Mtetra
.617 .542 .747 r
.48386 .50721 .4847 .50953 .48623 .50926 .48539 .50687 Mtetra
.363 .385 .75 r
.48539 .50687 .48623 .50926 .48774 .51127 .48691 .50796 Mtetra
0 0 .277 r
.48691 .50796 .48774 .51127 .48724 .70161 .48838 .51316 Mtetra
0 0 .364 r
.48838 .51316 .48724 .70161 .48877 .71003 .48791 .705 Mtetra
.252 .214 .619 r
.48791 .705 .48877 .71003 .49038 .71171 .4895 .70816 Mtetra
.587 .478 .697 r
.4895 .70816 .49038 .71171 .49201 .71148 .49113 .70802 Mtetra
.646 .519 .693 r
.49113 .70802 .49201 .71148 .49365 .71075 .49276 .70715 Mtetra
.644 .513 .689 r
.49276 .70715 .49365 .71075 .49528 .71003 .4944 .70628 Mtetra
.615 .491 .688 r
.4944 .70628 .49528 .71003 .49692 .70956 .49603 .70579 Mtetra
.615 .49 .687 r
.49603 .70579 .49692 .70956 .49855 .70908 .49767 .7053 Mtetra
.614 .489 .687 r
.49767 .7053 .49855 .70908 .50019 .70861 .49931 .70481 Mtetra
.612 .488 .686 r
.49931 .70481 .50019 .70861 .50183 .70815 .50094 .70434 Mtetra
.612 .487 .686 r
.50094 .70434 .50183 .70815 .50346 .7077 .50258 .70388 Mtetra
.50258 .70388 .50346 .7077 .5051 .70724 .50422 .70342 Mtetra
.50422 .70342 .5051 .70724 .50674 .70679 .50586 .70296 Mtetra
.612 .486 .685 r
.50586 .70296 .50674 .70679 .50839 .70635 .5075 .7025 Mtetra
.618 .49 .684 r
.5075 .7025 .50839 .70635 .51003 .70593 .50914 .70195 Mtetra
.621 .489 .68 r
.50914 .70195 .51003 .70593 .51167 .70553 .51078 .70133 Mtetra
.604 .473 .675 r
.51078 .70133 .51167 .70553 .51331 .70513 .51243 .70092 Mtetra
.558 .443 .678 r
.51243 .70092 .51331 .70513 .51496 .70467 .51407 .70111 Mtetra
.498 .421 .7 r
.51407 .70111 .51496 .70467 .51661 .70416 .51571 .70183 Mtetra
.48 .473 .772 r
.51571 .70183 .51661 .70416 .51825 .70363 .51736 .70237 Mtetra
.51 .618 .895 r
.51736 .70237 .51825 .70363 .5199 .70312 .519 .70247 Mtetra
.611 .802 .973 r
.519 .70247 .5199 .70312 .52155 .70264 .52065 .70208 Mtetra
.654 .838 .971 r
.52065 .70208 .52155 .70264 .5232 .70218 .52231 .70154 Mtetra
.674 .821 .954 r
.52231 .70154 .5232 .70218 .52485 .70176 .52396 .70095 Mtetra
.67 .777 .93 r
.52396 .70095 .52485 .70176 .5265 .70138 .52561 .7004 Mtetra
.668 .737 .902 r
.52561 .7004 .5265 .70138 .52816 .70094 .52726 .69986 Mtetra
.614 .699 .905 r
.52726 .69986 .52816 .70094 .52981 .70045 .52892 .69956 Mtetra
.499 .696 .957 r
.52892 .69956 .52981 .70045 .53147 .69987 .53058 .69955 Mtetra
.536 .864 .995 r
.53058 .69955 .53147 .69987 .53312 .69878 .53223 .69916 Mtetra
.773 .995 .793 r
.53223 .69916 .53312 .69878 .53477 .69598 .53389 .69759 Mtetra
.942 .892 .493 r
.53389 .69759 .53477 .69598 .53582 .5096 .53553 .69256 Mtetra
0 0 .361 r
.53553 .69256 .53582 .5096 .53733 .49449 .53651 .49912 Mtetra
0 0 .092 r
.53651 .49912 .53733 .49449 .53889 .49158 .53806 .49291 Mtetra
0 0 0 r
.53806 .49291 .53889 .49158 .54045 .49085 .53962 .49107 Mtetra
.686 .98 .846 r
.53962 .49107 .54045 .49085 .54202 .49062 .54118 .48995 Mtetra
.723 .815 .922 r
.54118 .48995 .54202 .49062 .54358 .49047 .54274 .48921 Mtetra
.671 .677 .847 r
.54274 .48921 .54358 .49047 .54515 .48995 .54431 .48865 Mtetra
.643 .659 .851 r
.54431 .48865 .54515 .48995 .54672 .48943 .54588 .48825 Mtetra
.631 .674 .873 r
.54588 .48825 .54672 .48943 .54828 .48889 .54745 .4879 Mtetra
.637 .714 .903 r
.54745 .4879 .54828 .48889 .54985 .48834 .54902 .48752 Mtetra
.635 .754 .934 r
.54902 .48752 .54985 .48834 .55142 .48785 .55059 .48713 Mtetra
.65 .783 .945 r
.55059 .48713 .55142 .48785 .55299 .48753 .55216 .48667 Mtetra
.685 .758 .907 r
.55216 .48667 .55299 .48753 .55457 .48753 .55373 .48608 Mtetra
.673 .651 .82 r
.55373 .48608 .55457 .48753 .55615 .48761 .55531 .48548 Mtetra
.65 .574 .756 r
.55531 .48548 .55615 .48761 .55773 .48759 .55688 .48488 Mtetra
.631 .532 .723 r
.55688 .48488 .55773 .48759 .5593 .48715 .55845 .48436 Mtetra
.628 .526 .719 r
.55845 .48436 .5593 .48715 .56088 .48659 .56003 .48385 Mtetra
.628 .528 .722 r
.56003 .48385 .56088 .48659 .56245 .48599 .56161 .48335 Mtetra
.63 .534 .727 r
.56161 .48335 .56245 .48599 .56403 .48548 .56318 .48284 Mtetra
.56318 .48284 .56403 .48548 .56561 .48497 .56476 .48234 Mtetra
.56476 .48234 .56561 .48497 .56719 .48447 .56634 .48184 Mtetra
.63 .535 .728 r
.56634 .48184 .56719 .48447 .56877 .48397 .56792 .48134 Mtetra
.56792 .48134 .56877 .48397 .57035 .48347 .5695 .48084 Mtetra
.5695 .48084 .57035 .48347 .57193 .48297 .57108 .48035 Mtetra
.57108 .48035 .57193 .48297 .57352 .48248 .57267 .47985 Mtetra
.57267 .47985 .57352 .48248 .5751 .48198 .57425 .47935 Mtetra
.57425 .47935 .5751 .48198 .57669 .48149 .57584 .47886 Mtetra
.629 .535 .728 r
.57584 .47886 .57669 .48149 .57827 .48099 .57742 .47836 Mtetra
.629 .534 .728 r
.57742 .47836 .57827 .48099 .57986 .4805 .57901 .47786 Mtetra
.57901 .47786 .57986 .4805 .58145 .48001 .5806 .47737 Mtetra
.5806 .47737 .58145 .48001 .58304 .47952 .58218 .47688 Mtetra
.58218 .47688 .58304 .47952 .58463 .47903 .58377 .47639 Mtetra
.628 .533 .727 r
.58377 .47639 .58463 .47903 .58622 .47856 .58536 .4759 Mtetra
.628 .532 .726 r
.58536 .4759 .58622 .47856 .58781 .47817 .58696 .4754 Mtetra
.625 .526 .721 r
.58696 .4754 .58781 .47817 .5894 .4777 .58855 .47492 Mtetra
.623 .524 .721 r
.58855 .47492 .5894 .4777 .59099 .47705 .59014 .47447 Mtetra
.618 .531 .733 r
.59014 .47447 .59099 .47705 .59258 .47599 .59174 .47409 Mtetra
.629 .583 .784 r
.59174 .47409 .59258 .47599 .59416 .47494 .59334 .4737 Mtetra
.647 .673 .861 r
.59334 .4737 .59416 .47494 .59575 .47402 .59493 .47327 Mtetra
.68 .788 .931 r
.59493 .47327 .59575 .47402 .59734 .47344 .59653 .47269 Mtetra
.689 .791 .928 r
.59653 .47269 .59734 .47344 .59894 .47296 .59812 .47208 Mtetra
.69 .76 .905 r
.59812 .47208 .59894 .47296 .60054 .47253 .59972 .47147 Mtetra
.692 .722 .873 r
.59972 .47147 .60054 .47253 .60214 .47206 .60132 .47082 Mtetra
.668 .682 .854 r
.60132 .47082 .60214 .47206 .60374 .47158 .60291 .47027 Mtetra
.634 .657 .855 r
.60291 .47027 .60374 .47158 .60534 .47106 .60452 .4699 Mtetra
.582 .66 .891 r
.60452 .4699 .60534 .47106 .60693 .47013 .60613 .46974 Mtetra
.058 .573 .878 r
.60613 .46974 .60693 .47013 .60853 .4695 .60775 .47006 Mtetra
.708 .242 .141 r
.60775 .47006 .60853 .4695 .61014 .46955 .60941 .47142 Mtetra
.961 .68 .455 r
.60941 .47142 .61014 .46955 .61185 .47292 .61554 .64405 Mtetra
.608 .386 .554 r
.61554 .64405 .61185 .47292 .61868 .66673 .61799 .67185 Mtetra
.679 .387 .471 r
.61799 .67185 .61868 .66673 .62059 .67368 .61978 .67472 Mtetra
.439 0 .072 r
.61978 .67472 .62059 .67368 .62233 .67448 .62151 .67473 Mtetra
.25 .751 .695 r
.62151 .67473 .62233 .67448 .62406 .67444 .62322 .67415 Mtetra
.716 .929 .961 r
.62322 .67415 .62406 .67444 .62577 .67398 .62492 .67327 Mtetra
.603 .789 .97 r
.62492 .67327 .62577 .67398 .62748 .67353 .62664 .6729 Mtetra
.624 .818 .975 r
.62664 .6729 .62748 .67353 .6292 .67297 .62835 .67244 Mtetra
.67 .859 .972 r
.62835 .67244 .6292 .67297 .63091 .67236 .63006 .67181 Mtetra
.731 .864 .943 r
.63006 .67181 .63091 .67236 .63264 .67237 .63177 .67095 Mtetra
.762 .703 .797 r
.63177 .67095 .63264 .67237 .63436 .67205 .63346 .6696 Mtetra
.77 .627 .702 r
.63346 .6696 .63436 .67205 .63606 .67109 .63512 .66723 Mtetra
.897 .657 .568 r
.63512 .66723 .63606 .67109 .63765 .6666 .63642 .65386 Mtetra
.952 .674 .475 r
.63642 .65386 .63765 .6666 .633 .47183 .63199 .46456 Mtetra
.696 .498 .615 r
.63199 .46456 .633 .47183 .63436 .46359 .6335 .46087 Mtetra
.668 .554 .716 r
.6335 .46087 .63436 .46359 .63594 .46187 .6351 .45993 Mtetra
.621 .577 .783 r
.6351 .45993 .63594 .46187 .63755 .461 .63673 .45959 Mtetra
.569 .613 .857 r
.63673 .45959 .63755 .461 .63917 .46051 .63837 .45952 Mtetra
.693 .74 .887 r
.63837 .45952 .63917 .46051 .64079 .45993 .63998 .45887 Mtetra
.69 .724 .876 r
.63998 .45887 .64079 .45993 .64241 .45942 .6416 .45822 Mtetra
.66 .688 .866 r
.6416 .45822 .64241 .45942 .64403 .45894 .64322 .45772 Mtetra
.605 .661 .878 r
.64322 .45772 .64403 .45894 .64564 .45794 .64486 .45748 Mtetra
.231 .668 .956 r
.64486 .45748 .64564 .45794 .64725 .45722 .64651 .45766 Mtetra
.638 .131 .027 r
.64651 .45766 .64725 .45722 .6489 .45713 .64819 .45865 Mtetra
.877 .534 .398 r
.64819 .45865 .6489 .45713 .65068 .46067 .6501 .46536 Mtetra
.961 .676 .447 r
.6501 .46536 .65068 .46067 .65996 .65729 .65921 .65873 Mtetra
.812 .44 .353 r
.65921 .65873 .65996 .65729 .66195 .66344 .6611 .66241 Mtetra
.41 .624 .94 r
.6611 .66241 .66195 .66344 .66372 .66389 .66287 .66269 Mtetra
.664 .703 .876 r
.66287 .66269 .66372 .66389 .66545 .66329 .6646 .66214 Mtetra
.724 .733 .858 r
.6646 .66214 .66545 .66329 .66717 .66225 .66633 .66124 Mtetra
.662 .738 .906 r
.66633 .66124 .66717 .66225 .66891 .66182 .66806 .6607 Mtetra
.643 .71 .896 r
.66806 .6607 .66891 .66182 .67065 .66146 .6698 .66025 Mtetra
.636 .691 .884 r
.6698 .66025 .67065 .66146 .6724 .661 .67155 .65984 Mtetra
.516 .647 .915 r
.67155 .65984 .6724 .661 .67414 .66055 .67331 .65989 Mtetra
.511 .769 .989 r
.67331 .65989 .67414 .66055 .67587 .65973 .67507 .65972 Mtetra
.539 .923 .909 r
.67507 .65972 .67587 .65973 .67756 .65815 .67681 .65898 Mtetra
.889 .936 .564 r
.67681 .65898 .67756 .65815 .67905 .65188 .67843 .65572 Mtetra
.873 .747 .237 r
.67843 .65572 .67905 .65188 .67199 .45516 .67969 .6444 Mtetra
.039 0 .431 r
.67969 .6444 .67199 .45516 .67342 .45013 .67278 .45228 Mtetra
0 0 .039 r
.67278 .45228 .67342 .45013 .67503 .44876 .67431 .44944 Mtetra
0 0 0 r
.67431 .44944 .67503 .44876 .67667 .44832 .67592 .44802 Mtetra
.73 .931 .956 r
.67592 .44802 .67667 .44832 .67833 .44824 .67754 .44714 Mtetra
.674 .713 .878 r
.67754 .44714 .67833 .44824 .67998 .44782 .67918 .44657 Mtetra
.635 .671 .867 r
.67918 .44657 .67998 .44782 .68163 .44731 .68084 .44618 Mtetra
.619 .687 .892 r
.68084 .44618 .68163 .44731 .68328 .44686 .68249 .44586 Mtetra
.67 .733 .897 r
.68249 .44586 .68328 .44686 .68494 .44668 .68414 .44531 Mtetra
.68 .673 .836 r
.68414 .44531 .68494 .44668 .68661 .44662 .68578 .44467 Mtetra
.661 .598 .774 r
.68578 .44467 .68661 .44662 .68828 .44658 .68742 .44402 Mtetra
.666 .561 .727 r
.68742 .44402 .68828 .44658 .68992 .44577 .68905 .44314 Mtetra
.649 .548 .727 r
.68905 .44314 .68992 .44577 .69156 .44499 .6907 .44243 Mtetra
.599 .523 .741 r
.6907 .44243 .69156 .44499 .69323 .44484 .69236 .44221 Mtetra
.264 .311 .724 r
.69236 .44221 .69323 .44484 .6951 .44862 .69414 .44401 Mtetra
0 0 .313 r
.69414 .44401 .6951 .44862 .70711 .64514 .69626 .45239 Mtetra
.062 0 .449 r
.69626 .45239 .70711 .64514 .70918 .65032 .70817 .64587 Mtetra
.348 .301 .664 r
.70817 .64587 .70918 .65032 .71101 .65117 .71009 .64829 Mtetra
.498 .455 .74 r
.71009 .64829 .71101 .65117 .71278 .6508 .71191 .6489 Mtetra
.563 .564 .812 r
.71191 .6489 .71278 .6508 .71453 .64993 .71371 .64891 Mtetra
.51 .677 .94 r
.71371 .64891 .71453 .64993 .71629 .64927 .7155 .64891 Mtetra
.46 .831 .992 r
.7155 .64891 .71629 .64927 .71804 .64847 .71728 .64863 Mtetra
.49 .901 .813 r
.71728 .64863 .71804 .64847 .71976 .647 .71903 .64776 Mtetra
.829 .935 .562 r
.71903 .64776 .71976 .647 .72128 .64208 .72067 .64493 Mtetra
.804 .738 .213 r
.72067 .64493 .72128 .64208 .71177 .44441 .72202 .63703 Mtetra
.059 0 .443 r
.72202 .63703 .71177 .44441 .7131 .43819 .71254 .44091 Mtetra
0 0 .121 r
.71254 .44091 .7131 .43819 .7147 .43643 .71403 .43731 Mtetra
0 0 0 r
.71403 .43731 .7147 .43643 .71636 .4359 .71564 .43574 Mtetra
.72 .965 .939 r
.71564 .43574 .71636 .4359 .71805 .43578 .71728 .43478 Mtetra
.684 .741 .894 r
.71728 .43478 .71805 .43578 .71973 .43547 .71894 .43416 Mtetra
.638 .663 .858 r
.71894 .43416 .71973 .43547 .7214 .435 .72062 .43375 Mtetra
.615 .664 .874 r
.72062 .43375 .7214 .435 .72307 .43451 .7223 .43345 Mtetra
.642 .714 .9 r
.7223 .43345 .72307 .43451 .72474 .43388 .72398 .43302 Mtetra
.666 .768 .926 r
.72398 .43302 .72474 .43388 .7264 .43322 .72565 .43248 Mtetra
.673 .801 .943 r
.72565 .43248 .7264 .43322 .72807 .43265 .72732 .4319 Mtetra
.744 .819 .911 r
.72732 .4319 .72807 .43265 .72974 .43211 .72897 .43101 Mtetra
.723 .736 .862 r
.72897 .43101 .72974 .43211 .73143 .43182 .73062 .43016 Mtetra
.632 .615 .815 r
.73062 .43016 .73143 .43182 .73316 .43215 .7323 .42976 Mtetra
.33 .372 .754 r
.7323 .42976 .73316 .43215 .73508 .4355 .7341 .43114 Mtetra
0 0 .467 r
.7341 .43114 .73508 .4355 .74961 .63248 .73624 .43762 Mtetra
.082 .005 .46 r
.73624 .43762 .74961 .63248 .75181 .63824 .75074 .63336 Mtetra
.316 .272 .649 r
.75074 .63336 .75181 .63824 .75371 .63941 .75277 .63637 Mtetra
.493 .445 .732 r
.75277 .63637 .75371 .63941 .75551 .6391 .75464 .63706 Mtetra
.558 .549 .8 r
.75464 .63706 .75551 .6391 .75728 .63828 .75647 .63712 Mtetra
.534 .66 .917 r
.75647 .63712 .75728 .63828 .75906 .63756 .7583 .6371 Mtetra
.464 .809 .998 r
.7583 .6371 .75906 .63756 .76084 .63682 .76011 .63688 Mtetra
.487 .902 .857 r
.76011 .63688 .76084 .63682 .76258 .63548 .76189 .63611 Mtetra
.776 .938 .589 r
.76189 .63611 .76258 .63548 .76414 .63151 .76356 .6337 Mtetra
.783 .751 .233 r
.76356 .6337 .76414 .63151 .75221 .43442 .76495 .62737 Mtetra
.076 0 .453 r
.76495 .62737 .75221 .43442 .75337 .42622 .75293 .42971 Mtetra
0 0 .207 r
.75293 .42971 .75337 .42622 .75494 .42401 .75434 .42522 Mtetra
0 0 0 r
.75434 .42522 .75494 .42401 .75662 .42339 .75595 .42357 Mtetra
.54 .92 .786 r
.75595 .42357 .75662 .42339 .75833 .42321 .7576 .42258 Mtetra
.701 .842 .95 r
.7576 .42258 .75833 .42321 .76004 .42288 .75928 .42187 Mtetra
.671 .736 .899 r
.75928 .42187 .76004 .42288 .76173 .4223 .76097 .4213 Mtetra
.651 .732 .909 r
.76097 .4213 .76173 .4223 .76342 .42178 .76267 .42083 Mtetra
.717 .766 .891 r
.76267 .42083 .76342 .42178 .76511 .42123 .76435 .42004 Mtetra
.729 .723 .845 r
.76435 .42004 .76511 .42123 .76681 .42081 .76601 .41911 Mtetra
.647 .618 .807 r
.76601 .41911 .76681 .42081 .76856 .42094 .76771 .4186 Mtetra
.41 .426 .766 r
.76771 .4186 .76856 .42094 .77049 .42347 .76952 .41959 Mtetra
0 .02 .558 r
.76952 .41959 .77049 .42347 .78719 .61985 .77164 .42458 Mtetra
.097 .019 .469 r
.77164 .42458 .78719 .61985 .7896 .62719 .78846 .62157 Mtetra
.291 .243 .63 r
.78846 .62157 .7896 .62719 .79157 .62871 .7906 .62538 Mtetra
.499 .437 .718 r
.7906 .62538 .79157 .62871 .79341 .62841 .79251 .6261 Mtetra
.563 .531 .777 r
.79251 .6261 .79341 .62841 .7952 .62756 .79438 .62615 Mtetra
.534 .615 .879 r
.79438 .62615 .7952 .62756 .79699 .62677 .79624 .6262 Mtetra
.378 .734 .99 r
.79624 .6262 .79699 .62677 .7988 .62615 .7981 .62623 Mtetra
.359 .831 .81 r
.7981 .62623 .7988 .62615 .80057 .62499 .79991 .62562 Mtetra
.783 .93 .564 r
.79991 .62562 .80057 .62499 .80216 .62167 .80157 .62305 Mtetra
.986 .791 .394 r
.80157 .62305 .80216 .62167 .78825 .42706 .80258 .61242 Mtetra
.068 0 .455 r
.80258 .61242 .78825 .42706 .78908 .41566 .78838 .41515 Mtetra
.953 .853 .705 r
.78838 .41515 .78908 .41566 .79062 .41301 .78988 .41196 Mtetra
.712 .746 .878 r
.78988 .41196 .79062 .41301 .79231 .41225 .79157 .41117 Mtetra
.591 .691 .911 r
.79157 .41117 .79231 .41225 .79404 .41197 .7933 .41094 Mtetra
.634 .722 .911 r
.7933 .41094 .79404 .41197 .79575 .41143 .79503 .41053 Mtetra
.727 .785 .899 r
.79503 .41053 .79575 .41143 .79743 .41047 .79671 .4097 Mtetra
.631 .784 .955 r
.79671 .4097 .79743 .41047 .79915 .41 .79844 .40925 Mtetra
.022 .437 .868 r
.79844 .40925 .79915 .41 .80102 .4113 .80027 .41011 Mtetra
.791 .382 0 r
.80027 .41011 .80102 .4113 .80387 .42393 .80244 .4149 Mtetra
.978 .678 .332 r
.80244 .4149 .80387 .42393 .82237 .61735 .82122 .61208 Mtetra
.239 .215 .629 r
.82122 .61208 .82237 .61735 .82445 .61972 .82346 .61623 Mtetra
.5 .432 .712 r
.82346 .61623 .82445 .61972 .82632 .61951 .82541 .61699 Mtetra
.563 .517 .762 r
.82541 .61699 .82632 .61951 .82812 .61865 .8273 .61706 Mtetra
.557 .602 .854 r
.8273 .61706 .82812 .61865 .82993 .61774 .82918 .61705 Mtetra
.405 .717 .987 r
.82918 .61705 .82993 .61774 .83176 .61714 .83108 .61712 Mtetra
.388 .849 .867 r
.83108 .61712 .83176 .61714 .83355 .61603 .83291 .61656 Mtetra
.733 .929 .589 r
.83291 .61656 .83355 .61603 .83517 .61313 .8346 .61433 Mtetra
.977 .805 .391 r
.8346 .61433 .83517 .61313 .83459 .58587 .83569 .60549 Mtetra
.975 .688 .294 r
.83569 .60549 .83459 .58587 .82006 .40642 .81938 .40595 Mtetra
.969 .85 .669 r
.81938 .40595 .82006 .40642 .82155 .40337 .82082 .40226 Mtetra
.724 .74 .864 r
.82082 .40226 .82155 .40337 .82326 .40254 .82252 .40138 Mtetra
.612 .686 .895 r
.82252 .40138 .82326 .40254 .825 .40221 .82427 .40107 Mtetra
.639 .703 .892 r
.82427 .40107 .825 .40221 .82674 .40178 .82601 .40064 Mtetra
.747 .745 .85 r
.82601 .40064 .82674 .40178 .82844 .40082 .82769 .39961 Mtetra
.668 .701 .871 r
.82769 .39961 .82844 .40082 .83017 .40033 .82942 .39903 Mtetra
.292 .483 .874 r
.82942 .39903 .83017 .40033 .83205 .40131 .83129 .39986 Mtetra
.852 .474 0 r
.83129 .39986 .83205 .40131 .8347 .41034 .83376 .40702 Mtetra
.976 .671 .337 r
.83376 .40702 .8347 .41034 .85552 .60764 .85471 .60617 Mtetra
0 0 .505 r
.85471 .60617 .85552 .60764 .8577 .61057 .85693 .60944 Mtetra
.442 .623 .929 r
.85693 .60944 .8577 .61057 .85962 .61068 .85887 .6097 Mtetra
.711 .778 .905 r
.85887 .6097 .85962 .61068 .86145 .60981 .8607 .60889 Mtetra
.894 .82 .768 r
.8607 .60889 .86145 .60981 .86314 .60756 .86237 .60641 Mtetra
.975 .743 .523 r
.86237 .60641 .86314 .60756 .86441 .60115 .86331 .59661 Mtetra
.976 .675 .371 r
.86331 .59661 .86441 .60115 .84639 .40125 .8454 .39744 Mtetra
.774 .584 .643 r
.8454 .39744 .84639 .40125 .8477 .39634 .84683 .39376 Mtetra
.656 .559 .733 r
.84683 .39376 .8477 .39634 .84936 .39496 .84855 .39297 Mtetra
.596 .567 .791 r
.84855 .39297 .84936 .39496 .85108 .39422 .85033 .39279 Mtetra
.566 .617 .862 r
.85033 .39279 .85108 .39422 .85283 .39373 .85212 .39272 Mtetra
.674 .747 .905 r
.85212 .39272 .85283 .39373 .85458 .39316 .85387 .39213 Mtetra
.659 .735 .906 r
.85387 .39213 .85458 .39316 .85633 .39266 .85562 .3916 Mtetra
.63 .717 .91 r
.85562 .3916 .85633 .39266 .85807 .39204 .85738 .3912 Mtetra
.559 .738 .959 r
.85738 .3912 .85807 .39204 .85978 .39107 .85917 .391 Mtetra
.157 0 0 r
.85917 .391 .85978 .39107 .86152 .39046 .86101 .39133 Mtetra
.736 .28 .167 r
.86101 .39133 .86152 .39046 .86338 .39087 .86303 .39326 Mtetra
.973 .664 .343 r
.86303 .39326 .86338 .39087 .86565 .39527 .88557 .5893 Mtetra
.576 .36 .551 r
.88557 .5893 .86565 .39527 .88869 .59462 .88843 .59808 Mtetra
.677 .343 .403 r
.88843 .59808 .88869 .59462 .89114 .59946 .8906 .6003 Mtetra
.381 0 0 r
.8906 .6003 .89114 .59946 .89313 .59999 .89253 .60025 Mtetra
0 0 0 r
.89253 .60025 .89313 .59999 .89505 .59979 .89439 .59958 Mtetra
.699 .966 .937 r
.89439 .59958 .89505 .59979 .89694 .59938 .89622 .59853 Mtetra
.743 .823 .914 r
.89622 .59853 .89694 .59938 .89889 .59943 .89805 .59756 Mtetra
.752 .667 .768 r
.89805 .59756 .89889 .59943 .90078 .59894 .89983 .59603 Mtetra
.782 .62 .68 r
.89983 .59603 .90078 .59894 .90254 .59728 .90145 .59309 Mtetra
.976 .672 .352 r
.90145 .59309 .90254 .59728 .90368 .5901 .88261 .40556 Mtetra
.596 .379 .556 r
.88261 .40556 .90368 .5901 .8831 .38816 .88227 .38602 Mtetra
.845 .678 .676 r
.88227 .38602 .8831 .38816 .8844 .3835 .88372 .38264 Mtetra
.763 .814 .893 r
.88372 .38264 .8844 .3835 .88612 .38249 .88543 .38159 Mtetra
.637 .76 .937 r
.88543 .38159 .88612 .38249 .88791 .38213 .88721 .38114 Mtetra
.545 .695 .938 r
.88721 .38114 .88791 .38213 .88972 .38196 .88903 .38104 Mtetra
.581 .728 .944 r
.88903 .38104 .88972 .38196 .89144 .381 .89084 .38079 Mtetra
.014 .571 .816 r
.89084 .38079 .89144 .381 .8932 .38037 .8927 .38104 Mtetra
.684 .191 .069 r
.8927 .38104 .8932 .38037 .89506 .38054 .89471 .3825 Mtetra
.972 .659 .323 r
.89471 .3825 .89506 .38054 .89734 .38442 .91872 .57369 Mtetra
.584 .366 .55 r
.91872 .57369 .89734 .38442 .92248 .58402 .92234 .58803 Mtetra
.685 .36 .419 r
.92234 .58803 .92248 .58402 .92511 .58976 .92461 .59071 Mtetra
.397 0 .006 r
.92461 .59071 .92511 .58976 .92708 .58982 .92657 .59065 Mtetra
.173 0 0 r
.92657 .59065 .92708 .58982 .92896 .5891 .92846 .58999 Mtetra
.099 0 0 r
.92846 .58999 .92896 .5891 .93081 .58816 .93032 .58908 Mtetra
.244 0 0 r
.93032 .58908 .93081 .58816 .93279 .58825 .93222 .58853 Mtetra
0 0 0 r
.93222 .58853 .93279 .58825 .93477 .58833 .93413 .58798 Mtetra
.546 .885 .987 r
.93413 .58798 .93477 .58833 .93673 .58829 .93603 .58744 Mtetra
.607 .776 .961 r
.93603 .58744 .93673 .58829 .93865 .58785 .93796 .58703 Mtetra
.628 .793 .961 r
.93796 .58703 .93865 .58785 .94056 .58732 .93987 .58654 Mtetra
.675 .822 .954 r
.93987 .58654 .94056 .58732 .94247 .58676 .94177 .58586 Mtetra
.798 .83 .876 r
.94177 .58586 .94247 .58676 .9444 .58633 .94358 .58451 Mtetra
.761 .679 .772 r
.94358 .58451 .9444 .58633 .94632 .5859 .94536 .58292 Mtetra
.71 .58 .708 r
.94536 .58292 .94632 .5859 .94825 .58545 .94714 .58126 Mtetra
.58 .465 .687 r
.94714 .58126 .94825 .58545 .95021 .58531 .94911 .58118 Mtetra
.598 .477 .686 r
.94911 .58118 .95021 .58531 .95213 .58482 .95105 .58084 Mtetra
.655 .516 .682 r
.95105 .58084 .95213 .58482 .95398 .58367 .95288 .57963 Mtetra
.58 .368 .558 r
.34479 .56233 .33581 .75015 .33785 .74025 .34667 .55409 Mtetra
.571 .361 .557 r
.34667 .55409 .33785 .74025 .34909 .55338 .34828 .55063 Mtetra
.741 .589 .686 r
.34828 .55063 .34909 .55338 .35073 .54954 .34983 .5485 Mtetra
.693 .708 .86 r
.34983 .5485 .35073 .54954 .35221 .54868 .3513 .54789 Mtetra
.607 .739 .938 r
.3513 .54789 .35221 .54868 .35366 .54838 .35275 .54761 Mtetra
.551 .728 .957 r
.35275 .54761 .35366 .54838 .3551 .54835 .3542 .54748 Mtetra
.737 .751 .864 r
.3542 .54748 .3551 .54835 .35657 .54772 .35568 .54665 Mtetra
.705 .706 .848 r
.35568 .54665 .35657 .54772 .35804 .54712 .35715 .54595 Mtetra
.632 .666 .865 r
.35715 .54595 .35804 .54712 .3595 .54667 .35861 .54562 Mtetra
0 .218 .73 r
.35861 .54562 .3595 .54667 .36095 .54649 .36 .54675 Mtetra
.853 .473 .328 r
.36 .54675 .36095 .54649 .36238 .54675 .3613 .54968 Mtetra
.933 .677 .526 r
.3613 .54968 .36238 .54675 .36378 .54785 .35393 .73299 Mtetra
.579 .364 .553 r
.35393 .73299 .36378 .54785 .36484 .55595 .35503 .74199 Mtetra
.568 .355 .551 r
.35503 .74199 .36484 .55595 .35752 .74283 .35645 .74445 Mtetra
.661 .295 .341 r
.35645 .74445 .35752 .74283 .35889 .74618 .35793 .74557 Mtetra
0 .466 .851 r
.35793 .74557 .35889 .74618 .36039 .74696 .35944 .74612 Mtetra
.55 .719 .952 r
.35944 .74612 .36039 .74696 .36194 .74675 .36098 .74599 Mtetra
.755 .786 .878 r
.36098 .74599 .36194 .74675 .36353 .74561 .36256 .74503 Mtetra
.914 .764 .681 r
.36256 .74503 .36353 .74561 .36527 .7411 .3643 .74069 Mtetra
.94 .688 .528 r
.3643 .74069 .36527 .7411 .37533 .54902 .3744 .54872 Mtetra
.939 .745 .615 r
.3744 .54872 .37533 .54902 .37709 .54196 .3762 .54115 Mtetra
.811 .768 .813 r
.3762 .54115 .37709 .54196 .37861 .54055 .37771 .5397 Mtetra
.662 .742 .91 r
.37771 .5397 .37861 .54055 .38008 .5401 .37919 .53925 Mtetra
.531 .697 .945 r
.37919 .53925 .38008 .5401 .38154 .54005 .38065 .53919 Mtetra
.738 .755 .866 r
.38065 .53919 .38154 .54005 .38304 .53921 .38214 .53835 Mtetra
.709 .749 .883 r
.38214 .53835 .38304 .53921 .38452 .53855 .38363 .53768 Mtetra
.537 .696 .942 r
.38363 .53768 .38452 .53855 .38598 .53848 .38509 .53761 Mtetra
.9 .483 .135 r
.38509 .53761 .38598 .53848 .38731 .54166 .38642 .54079 Mtetra
.942 .683 .517 r
.38642 .54079 .38731 .54166 .38105 .7326 .3801 .73182 Mtetra
.94 .603 .36 r
.3801 .73182 .38105 .7326 .38234 .73911 .38139 .73833 Mtetra
0 .299 .752 r
.38139 .73833 .38234 .73911 .38386 .73987 .3829 .73922 Mtetra
.621 .795 .966 r
.3829 .73922 .38386 .73987 .38543 .73942 .38447 .73884 Mtetra
.798 .829 .876 r
.38447 .73884 .38543 .73942 .38702 .73838 .38607 .73765 Mtetra
.875 .778 .751 r
.38607 .73765 .38702 .73838 .38863 .73712 .38773 .7351 Mtetra
.854 .672 .655 r
.38773 .7351 .38863 .73712 .39024 .73563 .38947 .73009 Mtetra
.935 .681 .528 r
.38947 .73009 .39024 .73563 .39185 .73401 .39803 .54434 Mtetra
.572 .362 .557 r
.39803 .54434 .39185 .73401 .39344 .73315 .39966 .54016 Mtetra
.565 .356 .556 r
.39966 .54016 .39344 .73315 .39501 .73279 .40114 .53975 Mtetra
.563 .354 .556 r
.40114 .53975 .39501 .73279 .39658 .73263 .40259 .54056 Mtetra
.567 .357 .556 r
.40259 .54056 .39658 .73263 .39816 .73213 .40411 .53942 Mtetra
.566 .357 .556 r
.40411 .53942 .39816 .73213 .39973 .73166 .40562 .53853 Mtetra
.563 .354 .556 r
.40562 .53853 .39973 .73166 .4013 .73147 .40706 .53958 Mtetra
0 0 .347 r
.40706 .53958 .4013 .73147 .40284 .73214 .40214 .72437 Mtetra
.116 .073 .527 r
.40214 .72437 .40284 .73214 .40438 .7329 .4035 .73024 Mtetra
.011 .14 .653 r
.4035 .73024 .40438 .7329 .40593 .7334 .40499 .73254 Mtetra
.303 .603 .951 r
.40499 .73254 .40593 .7334 .4075 .73332 .40655 .73289 Mtetra
.584 .845 .994 r
.40655 .73289 .4075 .73332 .40908 .73293 .40813 .7325 Mtetra
.689 .868 .966 r
.40813 .7325 .40908 .73293 .41067 .73243 .40973 .73185 Mtetra
.593 .805 .981 r
.40973 .73185 .41067 .73243 .41225 .73227 .41131 .73151 Mtetra
.61 .763 .952 r
.41131 .73151 .41225 .73227 .41383 .73202 .41289 .73118 Mtetra
.693 .765 .907 r
.41289 .73118 .41383 .73202 .41543 .73128 .41449 .73055 Mtetra
.842 .794 .805 r
.41449 .73055 .41543 .73128 .41709 .72836 .41612 .72875 Mtetra
.962 .91 .716 r
.41612 .72875 .41709 .72836 .41895 .71886 .41779 .72556 Mtetra
.013 0 .275 r
.41779 .72556 .41895 .71886 .42609 .5298 .41954 .71973 Mtetra
.556 .345 .549 r
.41954 .71973 .42609 .5298 .42765 .52747 .42124 .71536 Mtetra
.565 .352 .551 r
.42124 .71536 .42765 .52747 .42915 .52701 .42279 .71619 Mtetra
.563 .351 .55 r
.42279 .71619 .42915 .52701 .43065 .52693 .42438 .71577 Mtetra
0 0 .346 r
.42438 .71577 .43065 .52693 .43217 .52589 .4311 .53166 Mtetra
0 0 .164 r
.4311 .53166 .43217 .52589 .4337 .52444 .43277 .52539 Mtetra
.93 .957 .642 r
.43277 .52539 .4337 .52444 .43523 .52319 .43435 .52242 Mtetra
.801 .783 .837 r
.43435 .52242 .43523 .52319 .43674 .52242 .43588 .52114 Mtetra
.666 .666 .84 r
.43588 .52114 .43674 .52242 .43825 .52194 .43738 .52062 Mtetra
.611 .637 .852 r
.43738 .52062 .43825 .52194 .43975 .52159 .43889 .52038 Mtetra
.61 .656 .87 r
.43889 .52038 .43975 .52159 .44126 .52125 .44039 .52014 Mtetra
.616 .677 .885 r
.44039 .52014 .44126 .52125 .44276 .52089 .4419 .51987 Mtetra
.614 .693 .9 r
.4419 .51987 .44276 .52089 .44427 .52053 .4434 .51959 Mtetra
.634 .719 .908 r
.4434 .51959 .44427 .52053 .44578 .52012 .44491 .51924 Mtetra
.656 .739 .911 r
.44491 .51924 .44578 .52012 .4473 .51964 .44642 .51879 Mtetra
.672 .749 .909 r
.44642 .51879 .4473 .51964 .44881 .51913 .44794 .51828 Mtetra
.693 .755 .899 r
.44794 .51828 .44881 .51913 .45033 .51856 .44946 .51768 Mtetra
.704 .75 .888 r
.44946 .51768 .45033 .51856 .45184 .51795 .45098 .51702 Mtetra
.701 .739 .88 r
.45098 .51702 .45184 .51795 .45336 .51735 .4525 .51637 Mtetra
.684 .724 .88 r
.4525 .51637 .45336 .51735 .45488 .5168 .45401 .51579 Mtetra
.67 .716 .883 r
.45401 .51579 .45488 .5168 .4564 .51628 .45553 .51529 Mtetra
.665 .715 .886 r
.45553 .51529 .4564 .51628 .45792 .51579 .45705 .5148 Mtetra
.664 .718 .888 r
.45705 .5148 .45792 .51579 .45944 .5153 .45857 .51432 Mtetra
.665 .719 .889 r
.45857 .51432 .45944 .5153 .46096 .51482 .46009 .51384 Mtetra
.664 .719 .89 r
.46009 .51384 .46096 .51482 .46248 .51434 .46161 .51336 Mtetra
.663 .719 .891 r
.46161 .51336 .46248 .51434 .464 .51386 .46314 .51288 Mtetra
.662 .719 .891 r
.46314 .51288 .464 .51386 .46552 .51339 .46466 .51241 Mtetra
.46466 .51241 .46552 .51339 .46704 .51292 .46618 .51194 Mtetra
.661 .719 .892 r
.46618 .51194 .46704 .51292 .46857 .51244 .46771 .51147 Mtetra
.661 .72 .892 r
.46771 .51147 .46857 .51244 .47009 .51198 .46923 .511 Mtetra
.66 .72 .893 r
.46923 .511 .47009 .51198 .47162 .51151 .47076 .51053 Mtetra
.66 .721 .894 r
.47076 .51053 .47162 .51151 .47315 .51104 .47228 .51007 Mtetra
.659 .722 .895 r
.47228 .51007 .47315 .51104 .47467 .51057 .47381 .50961 Mtetra
.66 .724 .896 r
.47381 .50961 .47467 .51057 .4762 .51009 .47534 .50914 Mtetra
.663 .727 .896 r
.47534 .50914 .4762 .51009 .47773 .5096 .47687 .50866 Mtetra
.666 .729 .897 r
.47687 .50866 .47773 .5096 .47926 .50911 .4784 .50817 Mtetra
.667 .732 .898 r
.4784 .50817 .47926 .50911 .48079 .50861 .47993 .50768 Mtetra
.692 .739 .887 r
.47993 .50768 .48079 .50861 .48233 .50793 .48147 .50707 Mtetra
.7 .757 .895 r
.48147 .50707 .48233 .50793 .48386 .50721 .483 .50642 Mtetra
.641 .76 .935 r
.483 .50642 .48386 .50721 .48539 .50687 .48454 .50602 Mtetra
.278 .58 .942 r
.48454 .50602 .48539 .50687 .48691 .50796 .48606 .50643 Mtetra
0 .119 .671 r
.48606 .50643 .48691 .50796 .48838 .51316 .48757 .50818 Mtetra
.145 .133 .585 r
.48757 .50818 .48838 .51316 .48791 .705 .48906 .51197 Mtetra
.548 .343 .554 r
.48906 .51197 .48791 .705 .4895 .70816 .49051 .52084 Mtetra
.552 .346 .554 r
.49051 .52084 .4895 .70816 .49113 .70802 .49199 .52728 Mtetra
.582 .37 .558 r
.49199 .52728 .49113 .70802 .49276 .70715 .49362 .51798 Mtetra
.57 .36 .557 r
.49362 .51798 .49276 .70715 .4944 .70628 .49519 .51498 Mtetra
.566 .357 .556 r
.49519 .51498 .4944 .70628 .49603 .70579 .49674 .51425 Mtetra
.49674 .51425 .49603 .70579 .49767 .7053 .49829 .51353 Mtetra
.49829 .51353 .49767 .7053 .49931 .70481 .49984 .51289 Mtetra
.565 .356 .556 r
.49984 .51289 .49931 .70481 .50094 .70434 .50139 .51234 Mtetra
.50139 .51234 .50094 .70434 .50258 .70388 .50294 .5118 Mtetra
.565 .357 .556 r
.50294 .5118 .50258 .70388 .50422 .70342 .50449 .51123 Mtetra
.566 .357 .556 r
.50449 .51123 .50422 .70342 .50586 .70296 .50604 .51062 Mtetra
.565 .357 .556 r
.50604 .51062 .50586 .70296 .5075 .7025 .50759 .51004 Mtetra
.567 .358 .556 r
.50759 .51004 .5075 .7025 .50914 .70195 .50915 .50854 Mtetra
.568 .358 .556 r
.50915 .50854 .50914 .70195 .51078 .70133 .51071 .50671 Mtetra
.564 .356 .556 r
.51071 .50671 .51078 .70133 .51243 .70092 .51226 .50673 Mtetra
.01 0 .407 r
.51226 .50673 .51243 .70092 .51407 .70111 .51321 .68725 Mtetra
.147 .071 .506 r
.51321 .68725 .51407 .70111 .51571 .70183 .51482 .69796 Mtetra
.143 .171 .631 r
.51482 .69796 .51571 .70183 .51736 .70237 .51646 .70097 Mtetra
.155 .396 .843 r
.51646 .70097 .51736 .70237 .519 .70247 .51811 .702 Mtetra
.521 .82 .999 r
.51811 .702 .519 .70247 .52065 .70208 .51976 .70173 Mtetra
.656 .893 .982 r
.51976 .70173 .52065 .70208 .52231 .70154 .52141 .7011 Mtetra
.706 .88 .962 r
.52141 .7011 .52231 .70154 .52396 .70095 .52306 .70035 Mtetra
.69 .835 .953 r
.52306 .70035 .52396 .70095 .52561 .7004 .52471 .6997 Mtetra
.689 .809 .939 r
.52471 .6997 .52561 .7004 .52726 .69986 .52637 .69906 Mtetra
.629 .768 .946 r
.52637 .69906 .52726 .69986 .52892 .69956 .52802 .69866 Mtetra
.529 .706 .952 r
.52802 .69866 .52892 .69956 .53058 .69955 .52968 .69858 Mtetra
.608 .72 .925 r
.52968 .69858 .53058 .69955 .53223 .69916 .53134 .69828 Mtetra
.745 .779 .88 r
.53134 .69828 .53223 .69916 .53389 .69759 .533 .69734 Mtetra
.911 .889 .797 r
.533 .69734 .53389 .69759 .53553 .69256 .53465 .6951 Mtetra
0 0 0 r
.53465 .6951 .53553 .69256 .53651 .49912 .5363 .69106 Mtetra
0 0 .395 r
.5363 .69106 .53651 .49912 .53806 .49291 .53727 .5045 Mtetra
0 0 .331 r
.53727 .5045 .53806 .49291 .53962 .49107 .53879 .49307 Mtetra
0 0 0 r
.53879 .49307 .53962 .49107 .54118 .48995 .54035 .48974 Mtetra
.888 .912 .836 r
.54035 .48974 .54118 .48995 .54274 .48921 .54191 .48798 Mtetra
.694 .69 .842 r
.54191 .48798 .54274 .48921 .54431 .48865 .54347 .4873 Mtetra
.63 .645 .847 r
.54347 .4873 .54431 .48865 .54588 .48825 .54504 .48695 Mtetra
.601 .643 .864 r
.54504 .48695 .54588 .48825 .54745 .4879 .54661 .48674 Mtetra
.619 .674 .881 r
.54661 .48674 .54745 .4879 .54902 .48752 .54818 .48645 Mtetra
.619 .691 .895 r
.54818 .48645 .54902 .48752 .55059 .48713 .54976 .48614 Mtetra
.643 .718 .903 r
.54976 .48614 .55059 .48713 .55216 .48667 .55133 .48574 Mtetra
.691 .745 .893 r
.55133 .48574 .55216 .48667 .55373 .48608 .5529 .48512 Mtetra
.698 .74 .883 r
.5529 .48512 .55373 .48608 .55531 .48548 .55447 .48446 Mtetra
.691 .727 .878 r
.55447 .48446 .55531 .48548 .55688 .48488 .55605 .48383 Mtetra
.669 .713 .881 r
.55605 .48383 .55688 .48488 .55845 .48436 .55762 .48331 Mtetra
.664 .712 .884 r
.55762 .48331 .55845 .48436 .56003 .48385 .5592 .48281 Mtetra
.662 .714 .887 r
.5592 .48281 .56003 .48385 .56161 .48335 .56077 .48232 Mtetra
.664 .717 .888 r
.56077 .48232 .56161 .48335 .56318 .48284 .56235 .48182 Mtetra
.664 .718 .889 r
.56235 .48182 .56318 .48284 .56476 .48234 .56393 .48132 Mtetra
.56393 .48132 .56476 .48234 .56634 .48184 .56551 .48082 Mtetra
.664 .719 .89 r
.56551 .48082 .56634 .48184 .56792 .48134 .56709 .48032 Mtetra
.663 .719 .89 r
.56709 .48032 .56792 .48134 .5695 .48084 .56867 .47982 Mtetra
.56867 .47982 .5695 .48084 .57108 .48035 .57026 .47933 Mtetra
.57026 .47933 .57108 .48035 .57267 .47985 .57184 .47883 Mtetra
.57184 .47883 .57267 .47985 .57425 .47935 .57342 .47833 Mtetra
.57342 .47833 .57425 .47935 .57584 .47886 .57501 .47784 Mtetra
.57501 .47784 .57584 .47886 .57742 .47836 .5766 .47734 Mtetra
.5766 .47734 .57742 .47836 .57901 .47786 .57818 .47684 Mtetra
.57818 .47684 .57901 .47786 .5806 .47737 .57977 .47635 Mtetra
.57977 .47635 .5806 .47737 .58218 .47688 .58136 .47585 Mtetra
.662 .718 .89 r
.58136 .47585 .58218 .47688 .58377 .47639 .58295 .47536 Mtetra
.662 .717 .889 r
.58295 .47536 .58377 .47639 .58536 .4759 .58454 .47486 Mtetra
.665 .717 .888 r
.58454 .47486 .58536 .4759 .58696 .4754 .58613 .47435 Mtetra
.661 .713 .887 r
.58613 .47435 .58696 .4754 .58855 .47492 .58773 .47386 Mtetra
.652 .708 .888 r
.58773 .47386 .58855 .47492 .59014 .47447 .58932 .47342 Mtetra
.625 .699 .898 r
.58932 .47342 .59014 .47447 .59174 .47409 .59092 .47308 Mtetra
.625 .71 .906 r
.59092 .47308 .59174 .47409 .59334 .4737 .59252 .47274 Mtetra
.643 .726 .909 r
.59252 .47274 .59334 .4737 .59493 .47327 .59412 .47232 Mtetra
.697 .747 .891 r
.59412 .47232 .59493 .47327 .59653 .47269 .59571 .47167 Mtetra
.703 .733 .874 r
.59571 .47167 .59653 .47269 .59812 .47208 .5973 .47097 Mtetra
.7 .715 .861 r
.5973 .47097 .59812 .47208 .59972 .47147 .5989 .47027 Mtetra
.71 .704 .842 r
.5989 .47027 .59972 .47147 .60132 .47082 .60049 .46948 Mtetra
.667 .666 .84 r
.60049 .46948 .60132 .47082 .60291 .47027 .60209 .46893 Mtetra
.577 .626 .863 r
.60209 .46893 .60291 .47027 .60452 .4699 .6037 .46882 Mtetra
0 .258 .765 r
.6037 .46882 .60452 .4699 .60613 .46974 .60535 .47011 Mtetra
.856 .448 .26 r
.60535 .47011 .60613 .46974 .60775 .47006 .60705 .47343 Mtetra
.959 .678 .459 r
.60705 .47343 .60775 .47006 .60941 .47142 .6135 .66343 Mtetra
.575 .36 .551 r
.6135 .66343 .60941 .47142 .61554 .64405 .6154 .67074 Mtetra
.587 .358 .535 r
.6154 .67074 .61554 .64405 .61799 .67185 .61718 .67307 Mtetra
.641 .223 .233 r
.61718 .67307 .61799 .67185 .61978 .67472 .61893 .67407 Mtetra
.513 .771 .99 r
.61893 .67407 .61978 .67472 .62151 .67473 .62065 .67391 Mtetra
.658 .777 .936 r
.62065 .67391 .62151 .67473 .62322 .67415 .62236 .67338 Mtetra
.701 .802 .928 r
.62236 .67338 .62322 .67415 .62492 .67327 .62407 .67267 Mtetra
.519 .787 .994 r
.62407 .67267 .62492 .67327 .62664 .6729 .62579 .67246 Mtetra
.574 .854 .996 r
.62579 .67246 .62664 .6729 .62835 .67244 .62751 .67204 Mtetra
.719 .901 .96 r
.62751 .67204 .62835 .67244 .63006 .67181 .62922 .67119 Mtetra
.898 .836 .776 r
.62922 .67119 .63006 .67181 .63177 .67095 .63088 .66879 Mtetra
.856 .677 .659 r
.63088 .66879 .63177 .67095 .63346 .6696 .63247 .66435 Mtetra
.961 .684 .464 r
.63247 .66435 .63346 .6696 .63512 .66723 .62823 .47386 Mtetra
.58 .368 .557 r
.62823 .47386 .63512 .66723 .63642 .65386 .62958 .46473 Mtetra
.57 .36 .556 r
.62958 .46473 .63642 .65386 .63199 .46456 .63112 .46158 Mtetra
.721 .574 .689 r
.63112 .46158 .63199 .46456 .6335 .46087 .63269 .45972 Mtetra
.692 .708 .86 r
.63269 .45972 .6335 .46087 .6351 .45993 .6343 .45905 Mtetra
.609 .735 .935 r
.6343 .45905 .6351 .45993 .63673 .45959 .63593 .45874 Mtetra
.559 .723 .951 r
.63593 .45874 .63673 .45959 .63837 .45952 .63756 .45857 Mtetra
.733 .76 .874 r
.63756 .45857 .63837 .45952 .63998 .45887 .63917 .45771 Mtetra
.706 .712 .853 r
.63917 .45771 .63998 .45887 .6416 .45822 .64079 .45696 Mtetra
.638 .668 .862 r
.64079 .45696 .6416 .45822 .64322 .45772 .64242 .45656 Mtetra
.103 .393 .849 r
.64242 .45656 .64322 .45772 .64486 .45748 .6441 .45758 Mtetra
.837 .386 .15 r
.6441 .45758 .64486 .45748 .64651 .45766 .64584 .46031 Mtetra
.964 .678 .443 r
.64584 .46031 .64651 .45766 .64819 .45865 .65436 .64413 Mtetra
.585 .367 .552 r
.65436 .64413 .64819 .45865 .6501 .46536 .65662 .6579 Mtetra
.568 .354 .551 r
.65662 .6579 .6501 .46536 .65921 .65873 .65847 .66058 Mtetra
.643 .267 .316 r
.65847 .66058 .65921 .65873 .6611 .66241 .66027 .6617 Mtetra
.5 .748 .984 r
.66027 .6617 .6611 .66241 .66287 .66269 .66202 .66159 Mtetra
.666 .723 .891 r
.66202 .66159 .66287 .66269 .6646 .66214 .66376 .66103 Mtetra
.703 .734 .874 r
.66376 .66103 .6646 .66214 .66633 .66124 .66548 .66027 Mtetra
.661 .748 .915 r
.66548 .66027 .66633 .66124 .66806 .6607 .66722 .65973 Mtetra
.642 .742 .922 r
.66722 .65973 .66806 .6607 .6698 .66025 .66896 .65928 Mtetra
.629 .736 .924 r
.66896 .65928 .6698 .66025 .67155 .65984 .67071 .65888 Mtetra
.513 .69 .948 r
.67071 .65888 .67155 .65984 .67331 .65989 .67247 .65885 Mtetra
.559 .695 .931 r
.67247 .65885 .67331 .65989 .67507 .65972 .67423 .65872 Mtetra
.655 .739 .911 r
.67423 .65872 .67507 .65972 .67681 .65898 .67598 .65821 Mtetra
.841 .824 .831 r
.67598 .65821 .67681 .65898 .67843 .65572 .67767 .65652 Mtetra
.868 .941 .574 r
.67767 .65652 .67843 .65572 .67969 .6444 .6793 .65349 Mtetra
.216 .039 .413 r
.6793 .65349 .67969 .6444 .67278 .45228 .68077 .64668 Mtetra
.055 0 .436 r
.68077 .64668 .67278 .45228 .67431 .44944 .67376 .45353 Mtetra
0 0 .218 r
.67376 .45353 .67431 .44944 .67592 .44802 .6752 .44864 Mtetra
.845 .957 .617 r
.6752 .44864 .67592 .44802 .67754 .44714 .67676 .44618 Mtetra
.741 .765 .872 r
.67676 .44618 .67754 .44714 .67918 .44657 .67838 .44527 Mtetra
.623 .659 .864 r
.67838 .44527 .67918 .44657 .68084 .44618 .68004 .44494 Mtetra
.572 .646 .885 r
.68004 .44494 .68084 .44618 .68249 .44586 .6817 .44483 Mtetra
.661 .723 .895 r
.6817 .44483 .68249 .44586 .68414 .44531 .68335 .44432 Mtetra
.696 .744 .888 r
.68335 .44432 .68414 .44531 .68578 .44467 .68499 .44365 Mtetra
.698 .739 .883 r
.68499 .44365 .68578 .44467 .68742 .44402 .68664 .44296 Mtetra
.713 .737 .87 r
.68664 .44296 .68742 .44402 .68905 .44314 .68827 .44218 Mtetra
.692 .751 .896 r
.68827 .44218 .68905 .44314 .6907 .44243 .68992 .44153 Mtetra
.617 .737 .932 r
.68992 .44153 .6907 .44243 .69236 .44221 .69158 .44119 Mtetra
.291 .543 .918 r
.69158 .44119 .69236 .44221 .69414 .44401 .69329 .44175 Mtetra
.204 .3 .741 r
.69329 .44175 .69414 .44401 .69626 .45239 .69506 .44352 Mtetra
.32 .224 .587 r
.69506 .44352 .69626 .45239 .70817 .64587 .69702 .44877 Mtetra
.078 0 .454 r
.69702 .44877 .70817 .64587 .71009 .64829 .70896 .64164 Mtetra
.278 .216 .606 r
.70896 .64164 .71009 .64829 .71191 .6489 .71099 .64609 Mtetra
.295 .331 .729 r
.71099 .64609 .71191 .6489 .71371 .64891 .71288 .64787 Mtetra
.363 .597 .936 r
.71288 .64787 .71371 .64891 .7155 .64891 .7147 .64827 Mtetra
.576 .803 .985 r
.7147 .64827 .7155 .64891 .71728 .64863 .71648 .64793 Mtetra
.735 .836 .927 r
.71648 .64793 .71728 .64863 .71903 .64776 .71823 .64704 Mtetra
.846 .842 .841 r
.71823 .64704 .71903 .64776 .72067 .64493 .71993 .64536 Mtetra
.915 .969 .667 r
.71993 .64536 .72067 .64493 .72202 .63703 .72158 .64258 Mtetra
.074 0 .322 r
.72158 .64258 .72202 .63703 .71254 .44091 .72306 .63708 Mtetra
.079 0 .449 r
.72306 .63708 .71254 .44091 .71403 .43731 .71363 .44275 Mtetra
0 0 .3 r
.71363 .44275 .71403 .43731 .71564 .43574 .71498 .43672 Mtetra
.715 .858 .437 r
.71498 .43672 .71564 .43574 .71728 .43478 .71652 .43398 Mtetra
.784 .814 .876 r
.71652 .43398 .71728 .43478 .71894 .43416 .71815 .43285 Mtetra
.634 .664 .861 r
.71815 .43285 .71894 .43416 .72062 .43375 .71983 .43246 Mtetra
.574 .638 .877 r
.71983 .43246 .72062 .43375 .7223 .43345 .72152 .43235 Mtetra
.615 .692 .899 r
.72152 .43235 .7223 .43345 .72398 .43302 .72321 .43204 Mtetra
.659 .735 .906 r
.72321 .43204 .72398 .43302 .72565 .43248 .72488 .43153 Mtetra
.673 .748 .907 r
.72488 .43153 .72565 .43248 .72732 .4319 .72655 .43097 Mtetra
.726 .768 .887 r
.72655 .43097 .72732 .4319 .72897 .43101 .72821 .43014 Mtetra
.731 .784 .895 r
.72821 .43014 .72897 .43101 .73062 .43016 .72986 .42929 Mtetra
.668 .768 .925 r
.72986 .42929 .73062 .43016 .7323 .42976 .73154 .42874 Mtetra
.399 .606 .932 r
.73154 .42874 .7323 .42976 .7341 .43114 .73327 .42907 Mtetra
.228 .334 .765 r
.73327 .42907 .7341 .43114 .73624 .43762 .73508 .43064 Mtetra
.304 .229 .604 r
.73508 .43064 .73624 .43762 .75074 .63336 .73709 .43508 Mtetra
.099 .017 .466 r
.73709 .43508 .75074 .63336 .75277 .63637 .75153 .62877 Mtetra
.283 .212 .598 r
.75153 .62877 .75277 .63637 .75464 .63706 .75369 .63391 Mtetra
.309 .322 .712 r
.75369 .63391 .75464 .63706 .75647 .63712 .75565 .63588 Mtetra
.358 .55 .904 r
.75565 .63588 .75647 .63712 .7583 .6371 .75751 .63644 Mtetra
.548 .789 .988 r
.75751 .63644 .7583 .6371 .76011 .63688 .75933 .63617 Mtetra
.716 .834 .938 r
.75933 .63617 .76011 .63688 .76189 .63611 .7611 .63536 Mtetra
.83 .843 .856 r
.7611 .63536 .76189 .63611 .76356 .6337 .76283 .63382 Mtetra
.932 .97 .735 r
.76283 .63382 .76356 .6337 .76495 .62737 .76449 .63126 Mtetra
0 0 .239 r
.76449 .63126 .76495 .62737 .75293 .42971 .76601 .62667 Mtetra
.108 .019 .463 r
.76601 .62667 .75293 .42971 .75434 .42522 .75428 .43421 Mtetra
.104 0 .392 r
.75428 .43421 .75434 .42522 .75595 .42357 .75539 .42539 Mtetra
0 0 0 r
.75539 .42539 .75595 .42357 .7576 .42258 .7569 .42226 Mtetra
.851 .94 .88 r
.7569 .42226 .7576 .42258 .75928 .42187 .75852 .42079 Mtetra
.681 .726 .884 r
.75852 .42079 .75928 .42187 .76097 .4213 .76021 .42017 Mtetra
.626 .694 .893 r
.76021 .42017 .76097 .4213 .76267 .42083 .76192 .41981 Mtetra
.69 .743 .891 r
.76192 .41981 .76267 .42083 .76435 .42004 .7636 .41915 Mtetra
.74 .787 .89 r
.7636 .41915 .76435 .42004 .76601 .41911 .76527 .41824 Mtetra
.687 .776 .919 r
.76527 .41824 .76601 .41911 .76771 .4186 .76696 .4176 Mtetra
.469 .649 .937 r
.76696 .4176 .76771 .4186 .76952 .41959 .76871 .41774 Mtetra
.257 .377 .794 r
.76871 .41774 .76952 .41959 .77164 .42458 .77055 .41906 Mtetra
.319 .258 .631 r
.77055 .41906 .77164 .42458 .78846 .62157 .77255 .42249 Mtetra
.122 .036 .477 r
.77255 .42249 .78846 .62157 .7906 .62538 .78909 .61494 Mtetra
.287 .199 .578 r
.78909 .61494 .7906 .62538 .79251 .6261 .79149 .62206 Mtetra
.341 .311 .68 r
.79149 .62206 .79251 .6261 .79438 .62615 .79353 .6244 Mtetra
.33 .449 .831 r
.79353 .6244 .79438 .62615 .79624 .6262 .79547 .62539 Mtetra
.406 .68 .973 r
.79547 .62539 .79624 .6262 .7981 .62623 .79734 .62555 Mtetra
.673 .833 .96 r
.79734 .62555 .7981 .62623 .79991 .62562 .79915 .62489 Mtetra
.912 .843 .763 r
.79915 .62489 .79991 .62562 .80157 .62305 .80081 .62229 Mtetra
.98 .75 .519 r
.80081 .62229 .80157 .62305 .80258 .61242 .80184 .61201 Mtetra
.977 .684 .387 r
.80184 .61201 .80258 .61242 .78838 .41515 .78764 .41415 Mtetra
.915 .785 .704 r
.78764 .41415 .78838 .41515 .78988 .41196 .78913 .41093 Mtetra
.71 .75 .883 r
.78913 .41093 .78988 .41196 .79157 .41117 .79083 .41016 Mtetra
.581 .701 .925 r
.79083 .41016 .79157 .41117 .7933 .41094 .79256 .40995 Mtetra
.611 .72 .922 r
.79256 .40995 .7933 .41094 .79503 .41053 .7943 .40963 Mtetra
.705 .776 .907 r
.7943 .40963 .79503 .41053 .79671 .4097 .79599 .4089 Mtetra
.649 .784 .946 r
.79599 .4089 .79671 .4097 .79844 .40925 .79771 .4084 Mtetra
.449 .677 .962 r
.79771 .4084 .79844 .40925 .80027 .41011 .79948 .40851 Mtetra
.239 .399 .822 r
.79948 .40851 .80027 .41011 .80244 .4149 .80135 .40971 Mtetra
.339 .278 .642 r
.80135 .40971 .80244 .4149 .82122 .61208 .80338 .41279 Mtetra
.138 .05 .485 r
.80338 .41279 .82122 .61208 .82346 .61623 .82173 .60423 Mtetra
.287 .195 .572 r
.82173 .60423 .82346 .61623 .82541 .61699 .82434 .61256 Mtetra
.35 .308 .67 r
.82434 .61256 .82541 .61699 .8273 .61706 .82644 .61509 Mtetra
.348 .434 .809 r
.82644 .61509 .8273 .61706 .82918 .61705 .82842 .61618 Mtetra
.399 .659 .964 r
.82842 .61618 .82918 .61705 .83108 .61712 .83033 .61639 Mtetra
.655 .82 .963 r
.83033 .61639 .83108 .61712 .83291 .61656 .83216 .61581 Mtetra
.896 .848 .789 r
.83216 .61581 .83291 .61656 .8346 .61433 .83385 .61351 Mtetra
.98 .76 .533 r
.83385 .61351 .8346 .61433 .83569 .60549 .83494 .6047 Mtetra
.977 .681 .372 r
.83494 .6047 .83569 .60549 .81938 .40595 .81864 .40485 Mtetra
.924 .775 .678 r
.81864 .40485 .81938 .40595 .82082 .40226 .82008 .40115 Mtetra
.723 .742 .867 r
.82008 .40115 .82082 .40226 .82252 .40138 .82178 .40028 Mtetra
.611 .698 .906 r
.82178 .40028 .82252 .40138 .82427 .40107 .82353 .39997 Mtetra
.645 .713 .897 r
.82353 .39997 .82427 .40107 .82601 .40064 .82527 .39952 Mtetra
.756 .749 .847 r
.82527 .39952 .82601 .40064 .82769 .39961 .82695 .39842 Mtetra
.68 .711 .872 r
.82695 .39842 .82769 .39961 .82942 .39903 .82868 .39778 Mtetra
.309 .504 .885 r
.82868 .39778 .82942 .39903 .83129 .39986 .83054 .39852 Mtetra
.839 .452 0 r
.83054 .39852 .83129 .39986 .83376 .40702 .83294 .40495 Mtetra
.976 .67 .342 r
.83294 .40495 .83376 .40702 .85471 .60617 .85393 .60498 Mtetra
.601 .177 0 r
.85393 .60498 .85471 .60617 .85693 .60944 .85617 .60846 Mtetra
.396 .63 .948 r
.85617 .60846 .85693 .60944 .85887 .6097 .85811 .60876 Mtetra
.708 .785 .912 r
.85811 .60876 .85887 .6097 .8607 .60889 .85995 .60796 Mtetra
.894 .819 .767 r
.85995 .60796 .8607 .60889 .86237 .60641 .86162 .60546 Mtetra
.981 .748 .51 r
.86162 .60546 .86237 .60641 .86331 .59661 .86252 .59524 Mtetra
.977 .677 .36 r
.86252 .59524 .86331 .59661 .8454 .39744 .84466 .39624 Mtetra
.917 .768 .68 r
.84466 .39624 .8454 .39744 .84683 .39376 .8461 .39263 Mtetra
.7 .73 .874 r
.8461 .39263 .84683 .39376 .84855 .39297 .84782 .39188 Mtetra
.565 .68 .916 r
.84782 .39188 .84855 .39297 .85033 .39279 .84961 .39175 Mtetra
.538 .678 .928 r
.84961 .39175 .85033 .39279 .85212 .39272 .85141 .39169 Mtetra
.7 .751 .891 r
.85141 .39169 .85212 .39272 .85387 .39213 .85314 .39096 Mtetra
.657 .707 .884 r
.85314 .39096 .85387 .39213 .85562 .3916 .85489 .39044 Mtetra
.516 .641 .911 r
.85489 .39044 .85562 .3916 .85738 .3912 .8567 .3905 Mtetra
0 .151 .645 r
.8567 .3905 .85738 .3912 .85917 .391 .85868 .39209 Mtetra
.856 .453 .271 r
.85868 .39209 .85917 .391 .86101 .39133 .86097 .39666 Mtetra
.972 .662 .355 r
.86097 .39666 .86101 .39133 .86303 .39326 .88326 .59175 Mtetra
.571 .356 .55 r
.88326 .59175 .86303 .39326 .88557 .5893 .88572 .59677 Mtetra
.62 .345 .479 r
.88572 .59677 .88557 .5893 .88843 .59808 .88786 .59874 Mtetra
.566 .051 0 r
.88786 .59874 .88843 .59808 .8906 .6003 .88988 .59953 Mtetra
.481 .734 .982 r
.88988 .59953 .8906 .6003 .89253 .60025 .89181 .59948 Mtetra
.661 .813 .956 r
.89181 .59948 .89253 .60025 .89439 .59958 .89368 .59886 Mtetra
.802 .868 .896 r
.89368 .59886 .89439 .59958 .89622 .59853 .89548 .59755 Mtetra
.904 .815 .749 r
.89548 .59755 .89622 .59853 .89805 .59756 .89713 .59483 Mtetra
.866 .667 .631 r
.89713 .59483 .89805 .59756 .89983 .59603 .8985 .58966 Mtetra
.975 .67 .359 r
.8985 .58966 .89983 .59603 .90145 .59309 .87884 .3934 Mtetra
.575 .363 .556 r
.87884 .3934 .90145 .59309 .88261 .40556 .87989 .38633 Mtetra
.61 .406 .58 r
.87989 .38633 .88261 .40556 .88227 .38602 .88139 .38338 Mtetra
.732 .598 .708 r
.88139 .38338 .88227 .38602 .88372 .38264 .88302 .3816 Mtetra
.748 .769 .87 r
.88302 .3816 .88372 .38264 .88543 .38159 .88474 .38058 Mtetra
.652 .74 .914 r
.88474 .38058 .88543 .38159 .88721 .38114 .88651 .38008 Mtetra
.492 .651 .929 r
.88651 .38008 .88721 .38114 .88903 .38104 .88835 .38018 Mtetra
0 .302 .788 r
.88835 .38018 .88903 .38104 .89084 .38079 .89034 .38152 Mtetra
.837 .399 .189 r
.89034 .38152 .89084 .38079 .8927 .38104 .89259 .38513 Mtetra
.972 .658 .333 r
.89259 .38513 .8927 .38104 .89471 .3825 .91689 .58005 Mtetra
.573 .358 .55 r
.91689 .58005 .89471 .3825 .91872 .57369 .91961 .58668 Mtetra
.604 .353 .509 r
.91961 .58668 .91872 .57369 .92234 .58803 .92183 .58895 Mtetra
.601 .12 .086 r
.92183 .58895 .92234 .58803 .92461 .59071 .9239 .58987 Mtetra
.56 .756 .97 r
.9239 .58987 .92461 .59071 .92657 .59065 .92584 .58962 Mtetra
.665 .757 .919 r
.92584 .58962 .92657 .59065 .92846 .58999 .92774 .58901 Mtetra
.697 .78 .915 r
.92774 .58901 .92846 .58999 .93032 .58908 .92961 .58825 Mtetra
.634 .794 .959 r
.92961 .58825 .93032 .58908 .93222 .58853 .93152 .58774 Mtetra
.631 .802 .965 r
.93152 .58774 .93222 .58853 .93413 .58798 .93343 .58723 Mtetra
.622 .81 .972 r
.93343 .58723 .93413 .58798 .93603 .58744 .93535 .58674 Mtetra
.529 .78 .989 r
.93535 .58674 .93603 .58744 .93796 .58703 .93729 .5865 Mtetra
.574 .85 .996 r
.93729 .5865 .93796 .58703 .93987 .58654 .93921 .58603 Mtetra
.72 .91 .961 r
.93921 .58603 .93987 .58654 .94177 .58586 .94108 .5851 Mtetra
.934 .856 .741 r
.94108 .5851 .94177 .58586 .94358 .58451 .9427 .58221 Mtetra
.892 .695 .629 r
.9427 .58221 .94358 .58451 .94536 .58292 .94404 .57701 Mtetra
.974 .666 .334 r
.94404 .57701 .94536 .58292 .94714 .58126 .92199 .38305 Mtetra
.568 .358 .556 r
.92199 .38305 .94714 .58126 .94911 .58118 .92361 .38104 Mtetra
.563 .355 .556 r
.92361 .38104 .94911 .58118 .95105 .58084 .9256 .382 Mtetra
.566 .357 .556 r
.9256 .382 .95105 .58084 .95288 .57963 .92735 .38105 Mtetra
.597 .409 .598 r
.34445 .5508 .34479 .56233 .34667 .55409 .34594 .54979 Mtetra
.642 .49 .661 r
.34594 .54979 .34667 .55409 .34828 .55063 .34743 .5488 Mtetra
.695 .613 .76 r
.34743 .5488 .34828 .55063 .34983 .5485 .34891 .54791 Mtetra
.671 .807 .948 r
.34891 .54791 .34983 .5485 .3513 .54789 .35038 .5474 Mtetra
.624 .828 .979 r
.35038 .5474 .3513 .54789 .35275 .54761 .35183 .547 Mtetra
.625 .792 .962 r
.35183 .547 .35275 .54761 .3542 .54748 .35329 .54663 Mtetra
.746 .757 .862 r
.35329 .54663 .3542 .54748 .35568 .54665 .35478 .54575 Mtetra
.698 .739 .883 r
.35478 .54575 .35568 .54665 .35715 .54595 .35625 .54513 Mtetra
.522 .704 .953 r
.35625 .54513 .35715 .54595 .35861 .54562 .35769 .54508 Mtetra
.893 .479 .202 r
.35769 .54508 .35861 .54562 .36 .54675 .35899 .54803 Mtetra
.936 .679 .525 r
.35899 .54803 .36 .54675 .3613 .54968 .35126 .7361 Mtetra
.577 .363 .553 r
.35126 .7361 .3613 .54968 .35393 .73299 .35239 .74425 Mtetra
.586 .342 .513 r
.35239 .74425 .35393 .73299 .35503 .74199 .35388 .74526 Mtetra
.539 .23 .392 r
.35388 .74526 .35503 .74199 .35645 .74445 .35541 .7453 Mtetra
.231 0 0 r
.35541 .7453 .35645 .74445 .35793 .74557 .35696 .74493 Mtetra
.333 .682 .979 r
.35696 .74493 .35793 .74557 .35944 .74612 .35849 .74508 Mtetra
.596 .693 .911 r
.35849 .74508 .35944 .74612 .36098 .74599 .36004 .74486 Mtetra
.733 .717 .835 r
.36004 .74486 .36098 .74599 .36256 .74503 .36162 .74393 Mtetra
.887 .723 .673 r
.36162 .74393 .36256 .74503 .3643 .74069 .36336 .73942 Mtetra
.939 .686 .529 r
.36336 .73942 .3643 .74069 .3744 .54872 .37353 .54732 Mtetra
.897 .699 .627 r
.37353 .54732 .3744 .54872 .3762 .54115 .3753 .5403 Mtetra
.806 .762 .812 r
.3753 .5403 .3762 .54115 .37771 .5397 .37682 .53887 Mtetra
.664 .748 .912 r
.37682 .53887 .37771 .5397 .37919 .53925 .37829 .53841 Mtetra
.538 .705 .948 r
.37829 .53841 .37919 .53925 .38065 .53919 .37975 .53832 Mtetra
.739 .755 .866 r
.37975 .53832 .38065 .53919 .38214 .53835 .38125 .53748 Mtetra
.709 .749 .883 r
.38125 .53748 .38214 .53835 .38363 .53768 .38274 .53681 Mtetra
.535 .697 .943 r
.38274 .53681 .38363 .53768 .38509 .53761 .3842 .53674 Mtetra
.901 .484 .139 r
.3842 .53674 .38509 .53761 .38642 .54079 .38553 .53993 Mtetra
.942 .683 .517 r
.38553 .53993 .38642 .54079 .3801 .73182 .37915 .73106 Mtetra
.94 .602 .361 r
.37915 .73106 .3801 .73182 .38139 .73833 .38044 .73755 Mtetra
0 .212 .675 r
.38044 .73755 .38139 .73833 .3829 .73922 .38195 .73857 Mtetra
.599 .788 .971 r
.38195 .73857 .3829 .73922 .38447 .73884 .38351 .73825 Mtetra
.813 .826 .86 r
.38351 .73825 .38447 .73884 .38607 .73765 .38512 .73693 Mtetra
.906 .757 .685 r
.38512 .73693 .38607 .73765 .38773 .7351 .38684 .73279 Mtetra
.94 .686 .525 r
.38684 .73279 .38773 .7351 .38947 .73009 .3957 .54255 Mtetra
.58 .368 .558 r
.3957 .54255 .38947 .73009 .39803 .54434 .39748 .53431 Mtetra
.62 .431 .605 r
.39748 .53431 .39803 .54434 .39966 .54016 .39901 .53265 Mtetra
.591 .421 .62 r
.39901 .53265 .39966 .54016 .40114 .53975 .4005 .53218 Mtetra
.572 .407 .618 r
.4005 .53218 .40114 .53975 .40259 .54056 .40198 .53214 Mtetra
.597 .42 .613 r
.40198 .53214 .40259 .54056 .40411 .53942 .40348 .53144 Mtetra
.596 .422 .616 r
.40348 .53144 .40411 .53942 .40562 .53853 .40497 .53082 Mtetra
.57 .404 .617 r
.40497 .53082 .40562 .53853 .40706 .53958 .40645 .53083 Mtetra
.384 .26 .585 r
.40645 .53083 .40706 .53958 .40214 .72437 .4078 .53436 Mtetra
0 0 .327 r
.4078 .53436 .40214 .72437 .4035 .73024 .40269 .72565 Mtetra
0 0 .393 r
.40269 .72565 .4035 .73024 .40499 .73254 .40407 .73107 Mtetra
.256 .443 .853 r
.40407 .73107 .40499 .73254 .40655 .73289 .40561 .73189 Mtetra
.633 .716 .907 r
.40561 .73189 .40655 .73289 .40813 .7325 .4072 .73153 Mtetra
.717 .743 .872 r
.4072 .73153 .40813 .7325 .40973 .73185 .40879 .73075 Mtetra
.665 .707 .878 r
.40879 .73075 .40973 .73185 .41131 .73151 .41038 .73024 Mtetra
.643 .67 .86 r
.41038 .73024 .41131 .73151 .41289 .73118 .41197 .72983 Mtetra
.66 .663 .842 r
.41197 .72983 .41289 .73118 .41449 .73055 .41356 .72932 Mtetra
.712 .698 .836 r
.41356 .72932 .41449 .73055 .41612 .72875 .41516 .7285 Mtetra
.774 .919 .934 r
.41516 .7285 .41612 .72875 .41779 .72556 .41677 .72748 Mtetra
.244 0 .138 r
.41677 .72748 .41779 .72556 .41954 .71973 .41838 .72642 Mtetra
.537 .277 .469 r
.41838 .72642 .41954 .71973 .42124 .71536 .41997 .72614 Mtetra
.552 .31 .502 r
.41997 .72614 .42124 .71536 .42279 .71619 .42155 .72599 Mtetra
.528 .286 .492 r
.42155 .72599 .42279 .71619 .42438 .71577 .42315 .72523 Mtetra
.342 .127 .436 r
.42315 .72523 .42438 .71577 .4311 .53166 .42486 .72087 Mtetra
0 0 .325 r
.42486 .72087 .4311 .53166 .43277 .52539 .43179 .52838 Mtetra
.857 .822 .344 r
.43179 .52838 .43277 .52539 .43435 .52242 .43345 .52219 Mtetra
.886 .887 .827 r
.43345 .52219 .43435 .52242 .43588 .52114 .435 .52041 Mtetra
.68 .78 .926 r
.435 .52041 .43588 .52114 .43738 .52062 .43651 .51987 Mtetra
.548 .734 .962 r
.43651 .51987 .43738 .52062 .43889 .52038 .43801 .51972 Mtetra
.579 .771 .97 r
.43801 .51972 .43889 .52038 .44039 .52014 .43951 .51947 Mtetra
.627 .783 .956 r
.43951 .51947 .44039 .52014 .4419 .51987 .44102 .51909 Mtetra
.633 .758 .937 r
.44102 .51909 .4419 .51987 .4434 .51959 .44253 .51872 Mtetra
.646 .737 .915 r
.44253 .51872 .4434 .51959 .44491 .51924 .44404 .51831 Mtetra
.656 .728 .902 r
.44404 .51831 .44491 .51924 .44642 .51879 .44555 .51787 Mtetra
.663 .731 .9 r
.44555 .51787 .44642 .51879 .44794 .51828 .44707 .5174 Mtetra
.673 .743 .902 r
.44707 .5174 .44794 .51828 .44946 .51768 .44858 .51688 Mtetra
.681 .765 .915 r
.44858 .51688 .44946 .51768 .45098 .51702 .4501 .51633 Mtetra
.681 .793 .934 r
.4501 .51633 .45098 .51702 .4525 .51637 .45162 .51578 Mtetra
.668 .818 .955 r
.45162 .51578 .4525 .51637 .45401 .51579 .45314 .51526 Mtetra
.655 .83 .967 r
.45314 .51526 .45401 .51579 .45553 .51529 .45466 .51476 Mtetra
.651 .832 .97 r
.45466 .51476 .45553 .51529 .45705 .5148 .45618 .51428 Mtetra
.65 .831 .97 r
.45618 .51428 .45705 .5148 .45857 .51432 .4577 .51379 Mtetra
.649 .831 .97 r
.4577 .51379 .45857 .51432 .46009 .51384 .45922 .51331 Mtetra
.648 .831 .971 r
.45922 .51331 .46009 .51384 .46161 .51336 .46074 .51283 Mtetra
.646 .831 .971 r
.46074 .51283 .46161 .51336 .46314 .51288 .46226 .51236 Mtetra
.645 .831 .972 r
.46226 .51236 .46314 .51288 .46466 .51241 .46379 .51188 Mtetra
.644 .831 .972 r
.46379 .51188 .46466 .51241 .46618 .51194 .46531 .51141 Mtetra
.642 .831 .973 r
.46531 .51141 .46618 .51194 .46771 .51147 .46684 .51095 Mtetra
.64 .832 .974 r
.46684 .51095 .46771 .51147 .46923 .511 .46836 .51049 Mtetra
.639 .833 .975 r
.46836 .51049 .46923 .511 .47076 .51053 .46989 .51003 Mtetra
.636 .834 .977 r
.46989 .51003 .47076 .51053 .47228 .51007 .47142 .50957 Mtetra
.635 .836 .978 r
.47142 .50957 .47228 .51007 .47381 .50961 .47294 .50911 Mtetra
.635 .838 .978 r
.47294 .50911 .47381 .50961 .47534 .50914 .47447 .50865 Mtetra
.638 .841 .978 r
.47447 .50865 .47534 .50914 .47687 .50866 .476 .50818 Mtetra
.641 .844 .978 r
.476 .50818 .47687 .50866 .4784 .50817 .47754 .5077 Mtetra
.643 .847 .979 r
.47754 .5077 .4784 .50817 .47993 .50768 .47907 .50721 Mtetra
.66 .853 .974 r
.47907 .50721 .47993 .50768 .48147 .50707 .4806 .50668 Mtetra
.657 .874 .98 r
.4806 .50668 .48147 .50707 .483 .50642 .48214 .50612 Mtetra
.605 .884 .991 r
.48214 .50612 .483 .50642 .48454 .50602 .48367 .50563 Mtetra
.497 .824 1 r
.48367 .50563 .48454 .50602 .48606 .50643 .4852 .50539 Mtetra
.519 .654 .92 r
.4852 .50539 .48606 .50643 .48757 .50818 .48673 .50541 Mtetra
.563 .486 .727 r
.48673 .50541 .48757 .50818 .48906 .51197 .48827 .5055 Mtetra
.579 .42 .63 r
.48827 .5055 .48906 .51197 .49051 .52084 .4898 .50535 Mtetra
.578 .387 .587 r
.4898 .50535 .49051 .52084 .49199 .52728 .49134 .50487 Mtetra
.575 .378 .577 r
.49134 .50487 .49199 .52728 .49362 .51798 .49288 .50428 Mtetra
.582 .393 .591 r
.49288 .50428 .49362 .51798 .49519 .51498 .49443 .5037 Mtetra
.584 .4 .599 r
.49443 .5037 .49519 .51498 .49674 .51425 .49597 .50319 Mtetra
.584 .401 .6 r
.49597 .50319 .49674 .51425 .49829 .51353 .49751 .50269 Mtetra
.584 .402 .6 r
.49751 .50269 .49829 .51353 .49984 .51289 .49906 .50219 Mtetra
.584 .402 .601 r
.49906 .50219 .49984 .51289 .50139 .51234 .5006 .5017 Mtetra
.5006 .5017 .50139 .51234 .50294 .5118 .50215 .50121 Mtetra
.584 .403 .602 r
.50215 .50121 .50294 .5118 .50449 .51123 .50369 .50071 Mtetra
.585 .403 .602 r
.50369 .50071 .50449 .51123 .50604 .51062 .50524 .5002 Mtetra
.585 .404 .602 r
.50524 .5002 .50604 .51062 .50759 .51004 .50679 .4997 Mtetra
.591 .409 .603 r
.50679 .4997 .50759 .51004 .50915 .50854 .50834 .49899 Mtetra
.598 .416 .607 r
.50834 .49899 .50915 .50854 .51071 .50671 .50989 .49814 Mtetra
.583 .409 .612 r
.50989 .49814 .51071 .50671 .51226 .50673 .51144 .4978 Mtetra
.507 .352 .605 r
.51144 .4978 .51226 .50673 .51321 .68725 .51299 .49934 Mtetra
0 0 .382 r
.51299 .49934 .51321 .68725 .51482 .69796 .51395 .68727 Mtetra
0 0 .415 r
.51395 .68727 .51482 .69796 .51646 .70097 .51556 .69887 Mtetra
0 .167 .691 r
.51556 .69887 .51646 .70097 .51811 .702 .51721 .70094 Mtetra
.579 .688 .916 r
.51721 .70094 .51811 .702 .51976 .70173 .51886 .70076 Mtetra
.703 .749 .888 r
.51886 .70076 .51976 .70173 .52141 .7011 .52051 .70005 Mtetra
.717 .737 .868 r
.52051 .70005 .52141 .7011 .52306 .70035 .52216 .69924 Mtetra
.668 .712 .881 r
.52216 .69924 .52306 .70035 .52471 .6997 .52382 .69869 Mtetra
.668 .733 .898 r
.52382 .69869 .52471 .6997 .52637 .69906 .52547 .69815 Mtetra
.645 .747 .923 r
.52547 .69815 .52637 .69906 .52802 .69866 .52713 .69771 Mtetra
.611 .726 .927 r
.52713 .69771 .52802 .69866 .52968 .69858 .52879 .69739 Mtetra
.632 .686 .883 r
.52879 .69739 .52968 .69858 .53134 .69828 .53044 .69702 Mtetra
.648 .679 .865 r
.53044 .69702 .53134 .69828 .533 .69734 .5321 .69656 Mtetra
.679 .788 .932 r
.5321 .69656 .533 .69734 .53465 .6951 .53376 .69597 Mtetra
0 0 0 r
.53376 .69597 .53465 .6951 .5363 .69106 .53542 .69485 Mtetra
.167 0 .273 r
.53542 .69485 .5363 .69106 .53727 .5045 .53708 .69203 Mtetra
0 0 .385 r
.53708 .69203 .53727 .5045 .53879 .49307 .538 .50477 Mtetra
0 0 .228 r
.538 .50477 .53879 .49307 .54035 .48974 .53951 .49026 Mtetra
.957 .948 .683 r
.53951 .49026 .54035 .48974 .54191 .48798 .54107 .4873 Mtetra
.732 .812 .914 r
.54107 .4873 .54191 .48798 .54347 .4873 .54264 .48651 Mtetra
.6 .75 .949 r
.54264 .48651 .54347 .4873 .54504 .48695 .54421 .48622 Mtetra
.537 .743 .97 r
.54421 .48622 .54504 .48695 .54661 .48674 .54578 .48608 Mtetra
.627 .793 .962 r
.54578 .48608 .54661 .48674 .54818 .48645 .54735 .48568 Mtetra
.635 .768 .943 r
.54735 .48568 .54818 .48645 .54976 .48614 .54892 .48528 Mtetra
.649 .748 .921 r
.54892 .48528 .54976 .48614 .55133 .48574 .55049 .48484 Mtetra
.67 .746 .908 r
.55049 .48484 .55133 .48574 .5529 .48512 .55207 .48432 Mtetra
.674 .771 .923 r
.55207 .48432 .5529 .48512 .55447 .48446 .55364 .48378 Mtetra
.669 .8 .945 r
.55364 .48378 .55447 .48446 .55605 .48383 .55522 .48324 Mtetra
.653 .822 .965 r
.55522 .48324 .55605 .48383 .55762 .48331 .55679 .48274 Mtetra
.648 .828 .969 r
.55679 .48274 .55762 .48331 .5592 .48281 .55837 .48225 Mtetra
.647 .829 .971 r
.55837 .48225 .5592 .48281 .56077 .48232 .55995 .48176 Mtetra
.648 .829 .97 r
.55995 .48176 .56077 .48232 .56235 .48182 .56153 .48126 Mtetra
.648 .831 .971 r
.56153 .48126 .56235 .48182 .56393 .48132 .56311 .48076 Mtetra
.56311 .48076 .56393 .48132 .56551 .48082 .56469 .48027 Mtetra
.647 .832 .971 r
.56469 .48027 .56551 .48082 .56709 .48032 .56627 .47977 Mtetra
.647 .832 .972 r
.56627 .47977 .56709 .48032 .56867 .47982 .56785 .47927 Mtetra
.56785 .47927 .56867 .47982 .57026 .47933 .56943 .47878 Mtetra
.56943 .47878 .57026 .47933 .57184 .47883 .57102 .47828 Mtetra
.57102 .47828 .57184 .47883 .57342 .47833 .5726 .47778 Mtetra
.5726 .47778 .57342 .47833 .57501 .47784 .57419 .47728 Mtetra
.57419 .47728 .57501 .47784 .5766 .47734 .57578 .47679 Mtetra
.57578 .47679 .5766 .47734 .57818 .47684 .57737 .47629 Mtetra
.57737 .47629 .57818 .47684 .57977 .47635 .57895 .47579 Mtetra
.647 .832 .971 r
.57895 .47579 .57977 .47635 .58136 .47585 .58054 .47529 Mtetra
.647 .831 .971 r
.58054 .47529 .58136 .47585 .58295 .47536 .58213 .47479 Mtetra
.58213 .47479 .58295 .47536 .58454 .47486 .58373 .47429 Mtetra
.649 .83 .97 r
.58373 .47429 .58454 .47486 .58613 .47435 .58532 .47379 Mtetra
.648 .83 .97 r
.58532 .47379 .58613 .47435 .58773 .47386 .58691 .47329 Mtetra
.645 .826 .97 r
.58691 .47329 .58773 .47386 .58932 .47342 .58851 .4728 Mtetra
.636 .813 .968 r
.58851 .4728 .58932 .47342 .59092 .47308 .5901 .47235 Mtetra
.647 .784 .947 r
.5901 .47235 .59092 .47308 .59252 .47274 .5917 .47189 Mtetra
.66 .758 .923 r
.5917 .47189 .59252 .47274 .59412 .47232 .5933 .4714 Mtetra
.682 .748 .902 r
.5933 .4714 .59412 .47232 .59571 .47167 .59489 .47082 Mtetra
.685 .767 .913 r
.59489 .47082 .59571 .47167 .5973 .47097 .59649 .47023 Mtetra
.691 .794 .929 r
.59649 .47023 .5973 .47097 .5989 .47027 .59809 .46961 Mtetra
.753 .827 .909 r
.59809 .46961 .5989 .47027 .60049 .46948 .59968 .46871 Mtetra
.678 .783 .929 r
.59968 .46871 .60049 .46948 .60209 .46893 .60128 .46814 Mtetra
.422 .677 .968 r
.60128 .46814 .60209 .46893 .6037 .46882 .6029 .46827 Mtetra
.874 .434 .079 r
.6029 .46827 .6037 .46882 .60535 .47011 .60459 .47168 Mtetra
.962 .681 .456 r
.60459 .47168 .60535 .47011 .60705 .47343 .611 .66571 Mtetra
.574 .359 .551 r
.611 .66571 .60705 .47343 .6135 .66343 .61289 .67251 Mtetra
.582 .327 .496 r
.61289 .67251 .6135 .66343 .6154 .67074 .61463 .67333 Mtetra
.521 .186 .339 r
.61463 .67333 .6154 .67074 .61718 .67307 .61635 .67332 Mtetra
0 0 0 r
.61635 .67332 .61718 .67307 .61893 .67407 .61807 .67291 Mtetra
.63 .695 .892 r
.61807 .67291 .61893 .67407 .62065 .67391 .61978 .67253 Mtetra
.653 .669 .853 r
.61978 .67253 .62065 .67391 .62236 .67338 .62149 .67203 Mtetra
.663 .677 .853 r
.62149 .67203 .62236 .67338 .62407 .67267 .62321 .67147 Mtetra
.551 .654 .904 r
.62321 .67147 .62407 .67267 .62579 .67246 .62493 .67142 Mtetra
.63 .718 .91 r
.62493 .67142 .62579 .67246 .62751 .67204 .62665 .67103 Mtetra
.751 .762 .862 r
.62665 .67103 .62751 .67204 .62922 .67119 .62835 .66999 Mtetra
.909 .744 .664 r
.62835 .66999 .62922 .67119 .63088 .66879 .62995 .66549 Mtetra
.964 .687 .461 r
.62995 .66549 .63088 .66879 .63247 .66435 .62572 .4707 Mtetra
.578 .366 .557 r
.62572 .4707 .63247 .66435 .62823 .47386 .6271 .46231 Mtetra
.614 .422 .598 r
.6271 .46231 .62823 .47386 .62958 .46473 .62867 .46052 Mtetra
.638 .492 .667 r
.62867 .46052 .62958 .46473 .63112 .46158 .63028 .45957 Mtetra
.648 .585 .771 r
.63028 .45957 .63112 .46158 .63269 .45972 .6319 .45901 Mtetra
.665 .801 .947 r
.6319 .45901 .63269 .45972 .6343 .45905 .63351 .45848 Mtetra
.62 .825 .979 r
.63351 .45848 .6343 .45905 .63593 .45874 .63514 .45804 Mtetra
.621 .789 .963 r
.63514 .45804 .63593 .45874 .63756 .45857 .63676 .45765 Mtetra
.744 .768 .872 r
.63676 .45765 .63756 .45857 .63917 .45771 .63837 .45673 Mtetra
.699 .743 .885 r
.63837 .45673 .63917 .45771 .64079 .45696 .63999 .45604 Mtetra
.553 .706 .941 r
.63999 .45604 .64079 .45696 .64242 .45656 .64163 .45592 Mtetra
.799 .322 0 r
.64163 .45592 .64242 .45656 .6441 .45758 .64337 .45866 Mtetra
.966 .681 .44 r
.64337 .45866 .6441 .45758 .64584 .46031 .65204 .65044 Mtetra
.579 .363 .551 r
.65204 .65044 .64584 .46031 .65436 .64413 .65415 .6604 Mtetra
.579 .342 .521 r
.65415 .6604 .65436 .64413 .65662 .6579 .65595 .6615 Mtetra
.533 .229 .396 r
.65595 .6615 .65662 .6579 .65847 .66058 .6577 .66147 Mtetra
.219 0 0 r
.6577 .66147 .65847 .66058 .66027 .6617 .65944 .66097 Mtetra
.636 .799 .961 r
.65944 .66097 .66027 .6617 .66202 .66159 .66117 .66049 Mtetra
.666 .724 .892 r
.66117 .66049 .66202 .66159 .66376 .66103 .66291 .65993 Mtetra
.676 .728 .889 r
.66291 .65993 .66376 .66103 .66548 .66027 .66464 .65933 Mtetra
.655 .753 .922 r
.66464 .65933 .66548 .66027 .66722 .65973 .66638 .65882 Mtetra
.642 .754 .93 r
.66638 .65882 .66722 .65973 .66896 .65928 .66813 .65835 Mtetra
.633 .749 .932 r
.66813 .65835 .66896 .65928 .67071 .65888 .66987 .65793 Mtetra
.593 .728 .938 r
.66987 .65793 .67071 .65888 .67247 .65885 .67162 .65765 Mtetra
.61 .683 .894 r
.67162 .65765 .67247 .65885 .67423 .65872 .67338 .65736 Mtetra
.636 .667 .863 r
.67338 .65736 .67423 .65872 .67598 .65821 .67513 .65694 Mtetra
.644 .685 .874 r
.67513 .65694 .67598 .65821 .67767 .65652 .67687 .65648 Mtetra
.6 .946 .922 r
.67687 .65648 .67767 .65652 .6793 .65349 .67861 .65565 Mtetra
.199 0 .175 r
.67861 .65565 .6793 .65349 .68077 .64668 .68031 .65406 Mtetra
.165 0 .379 r
.68031 .65406 .68077 .64668 .67376 .45353 .6818 .64796 Mtetra
.04 0 .431 r
.6818 .64796 .67376 .45353 .6752 .44864 .67456 .45093 Mtetra
.682 .712 .191 r
.67456 .45093 .6752 .44864 .67676 .44618 .676 .44579 Mtetra
.843 .909 .881 r
.676 .44579 .67676 .44618 .67838 .44527 .6776 .44439 Mtetra
.646 .751 .926 r
.6776 .44439 .67838 .44527 .68004 .44494 .67925 .44393 Mtetra
.549 .683 .927 r
.67925 .44393 .68004 .44494 .6817 .44483 .68092 .44384 Mtetra
.638 .726 .911 r
.68092 .44384 .6817 .44483 .68335 .44432 .68257 .44343 Mtetra
.669 .758 .917 r
.68257 .44343 .68335 .44432 .68499 .44365 .68422 .44289 Mtetra
.67 .792 .94 r
.68422 .44289 .68499 .44365 .68664 .44296 .68587 .44234 Mtetra
.679 .832 .956 r
.68587 .44234 .68664 .44296 .68827 .44218 .68752 .44172 Mtetra
.652 .872 .981 r
.68752 .44172 .68827 .44218 .68992 .44153 .68917 .44114 Mtetra
.598 .873 .993 r
.68917 .44114 .68992 .44153 .69158 .44119 .69082 .44065 Mtetra
.629 .841 .981 r
.69082 .44065 .69158 .44119 .69329 .44175 .69248 .44016 Mtetra
.6 .606 .83 r
.69248 .44016 .69329 .44175 .69506 .44352 .69415 .43996 Mtetra
.53 .439 .697 r
.69415 .43996 .69506 .44352 .69702 .44877 .69586 .44042 Mtetra
.361 .256 .598 r
.69586 .44042 .69702 .44877 .70896 .64164 .69777 .4447 Mtetra
.065 0 .45 r
.69777 .4447 .70896 .64164 .71099 .64609 .70997 .6414 Mtetra
.045 .089 .583 r
.70997 .6414 .71099 .64609 .71288 .64787 .71202 .64622 Mtetra
.347 .473 .845 r
.71202 .64622 .71288 .64787 .7147 .64827 .71386 .64706 Mtetra
.627 .69 .889 r
.71386 .64706 .7147 .64827 .71648 .64793 .71564 .64668 Mtetra
.714 .718 .852 r
.71564 .64668 .71648 .64793 .71823 .64704 .71739 .6458 Mtetra
.685 .709 .867 r
.71739 .6458 .71823 .64704 .71993 .64536 .71916 .64512 Mtetra
.668 .938 .966 r
.71916 .64512 .71993 .64536 .72158 .64258 .72091 .6443 Mtetra
.134 0 .086 r
.72091 .6443 .72158 .64258 .72306 .63708 .72263 .64281 Mtetra
.166 0 .357 r
.72263 .64281 .72306 .63708 .71363 .44275 .72416 .63796 Mtetra
.062 0 .444 r
.72416 .63796 .71363 .44275 .71498 .43672 .71446 .4401 Mtetra
0 0 .015 r
.71446 .4401 .71498 .43672 .71652 .43398 .7158 .43379 Mtetra
.894 .949 .835 r
.7158 .43379 .71652 .43398 .71815 .43285 .71739 .43198 Mtetra
.667 .766 .925 r
.71739 .43198 .71815 .43285 .71983 .43246 .71906 .43144 Mtetra
.561 .688 .925 r
.71906 .43144 .71983 .43246 .72152 .43235 .72075 .43131 Mtetra
.612 .706 .912 r
.72075 .43131 .72152 .43235 .72321 .43204 .72244 .43101 Mtetra
.655 .724 .9 r
.72244 .43101 .72321 .43204 .72488 .43153 .72411 .43052 Mtetra
.66 .731 .901 r
.72411 .43052 .72488 .43153 .72655 .43097 .72579 .43001 Mtetra
.686 .752 .902 r
.72579 .43001 .72655 .43097 .72821 .43014 .72746 .42938 Mtetra
.694 .803 .933 r
.72746 .42938 .72821 .43014 .72986 .42929 .72912 .42872 Mtetra
.658 .844 .971 r
.72912 .42872 .72986 .42929 .73154 .42874 .7308 .42815 Mtetra
.645 .833 .973 r
.7308 .42815 .73154 .42874 .73327 .42907 .73248 .42763 Mtetra
.611 .633 .848 r
.73248 .42763 .73327 .42907 .73508 .43064 .73417 .42735 Mtetra
.539 .455 .709 r
.73417 .42735 .73508 .43064 .73709 .43508 .73591 .4277 Mtetra
.396 .289 .614 r
.73591 .4277 .73709 .43508 .75153 .62877 .73784 .43104 Mtetra
.087 .008 .462 r
.73784 .43104 .75153 .62877 .75369 .63391 .75257 .62823 Mtetra
.076 .092 .573 r
.75257 .62823 .75369 .63391 .75565 .63588 .75478 .634 Mtetra
.29 .408 .81 r
.75478 .634 .75565 .63588 .75751 .63644 .75669 .6352 Mtetra
.608 .68 .893 r
.75669 .6352 .75751 .63644 .75933 .63617 .7585 .63491 Mtetra
.704 .716 .858 r
.7585 .63491 .75933 .63617 .7611 .63536 .76028 .6341 Mtetra
.691 .71 .863 r
.76028 .6341 .7611 .63536 .76283 .63382 .76207 .63337 Mtetra
.677 .894 .976 r
.76207 .63337 .76283 .63382 .76449 .63126 .76385 .63263 Mtetra
.088 0 0 r
.76385 .63263 .76449 .63126 .76601 .62667 .7656 .63131 Mtetra
.198 0 .344 r
.7656 .63131 .76601 .62667 .75428 .43421 .76717 .62754 Mtetra
.082 .001 .455 r
.76717 .62754 .75428 .43421 .75539 .42539 .75513 .43135 Mtetra
0 0 .211 r
.75513 .43135 .75539 .42539 .7569 .42226 .7562 .42204 Mtetra
.936 .927 .773 r
.7562 .42204 .7569 .42226 .75852 .42079 .75776 .4197 Mtetra
.693 .731 .879 r
.75776 .4197 .75852 .42079 .76021 .42017 .75945 .41902 Mtetra
.6 .679 .897 r
.75945 .41902 .76021 .42017 .76192 .41981 .76116 .41877 Mtetra
.639 .719 .906 r
.76116 .41877 .76192 .41981 .7636 .41915 .76287 .41835 Mtetra
.702 .798 .925 r
.76287 .41835 .7636 .41915 .76527 .41824 .76455 .41764 Mtetra
.674 .845 .965 r
.76455 .41764 .76527 .41824 .76696 .4176 .76624 .41702 Mtetra
.658 .844 .971 r
.76624 .41702 .76696 .4176 .76871 .41774 .76794 .41644 Mtetra
.633 .668 .866 r
.76794 .41644 .76871 .41774 .77055 .41906 .76965 .41605 Mtetra
.557 .478 .722 r
.76965 .41605 .77055 .41906 .77255 .42249 .7714 .41621 Mtetra
.437 .328 .633 r
.7714 .41621 .77255 .42249 .78909 .61494 .77332 .41853 Mtetra
.105 .024 .472 r
.77332 .41853 .78909 .61494 .79149 .62206 .79016 .61406 Mtetra
.066 .061 .54 r
.79016 .61406 .79149 .62206 .79353 .6244 .79267 .62254 Mtetra
.069 .267 .757 r
.79267 .62254 .79353 .6244 .79547 .62539 .79468 .62449 Mtetra
.446 .677 .962 r
.79468 .62449 .79547 .62539 .79734 .62555 .79656 .62461 Mtetra
.72 .784 .903 r
.79656 .62461 .79734 .62555 .79915 .62489 .79835 .62376 Mtetra
.887 .778 .735 r
.79835 .62376 .79915 .62489 .80081 .62229 .79999 .62092 Mtetra
.967 .725 .519 r
.79999 .62092 .80081 .62229 .80184 .61201 .8009 .60903 Mtetra
.975 .681 .394 r
.8009 .60903 .80184 .61201 .78764 .41415 .78689 .41299 Mtetra
.897 .766 .709 r
.78689 .41299 .78764 .41415 .78913 .41093 .78839 .40991 Mtetra
.706 .751 .888 r
.78839 .40991 .78913 .41093 .79083 .41016 .79009 .40916 Mtetra
.578 .705 .929 r
.79009 .40916 .79083 .41016 .79256 .40995 .79183 .40896 Mtetra
.591 .712 .928 r
.79183 .40896 .79256 .40995 .7943 .40963 .79356 .40871 Mtetra
.68 .766 .916 r
.79356 .40871 .7943 .40963 .79599 .4089 .79527 .4081 Mtetra
.664 .789 .941 r
.79527 .4081 .79599 .4089 .79771 .4084 .79699 .40755 Mtetra
.666 .776 .932 r
.79699 .40755 .79771 .4084 .79948 .40851 .7987 .40699 Mtetra
.646 .643 .832 r
.7987 .40699 .79948 .40851 .80135 .40971 .80043 .40651 Mtetra
.572 .48 .712 r
.80043 .40651 .80135 .40971 .80338 .41279 .80219 .40653 Mtetra
.47 .352 .637 r
.80219 .40653 .80338 .41279 .82173 .60423 .80412 .40836 Mtetra
.124 .04 .481 r
.80412 .40836 .82173 .60423 .82434 .61256 .8227 .60169 Mtetra
.096 .067 .531 r
.8227 .60169 .82434 .61256 .82644 .61509 .82557 .61296 Mtetra
.077 .242 .732 r
.82557 .61296 .82644 .61509 .82842 .61618 .82765 .61523 Mtetra
.424 .654 .955 r
.82765 .61523 .82842 .61618 .83033 .61639 .82956 .61543 Mtetra
.704 .778 .909 r
.82956 .61543 .83033 .61639 .83216 .61581 .83138 .61465 Mtetra
.876 .78 .753 r
.83138 .61465 .83216 .61581 .83385 .61351 .83304 .6121 Mtetra
.965 .731 .533 r
.83304 .6121 .83385 .61351 .83494 .6047 .83402 .60198 Mtetra
.976 .679 .378 r
.83402 .60198 .83494 .6047 .81864 .40485 .81789 .40356 Mtetra
.903 .753 .686 r
.81789 .40356 .81864 .40485 .82008 .40115 .81935 .40005 Mtetra
.723 .743 .868 r
.81935 .40005 .82008 .40115 .82178 .40028 .82105 .39919 Mtetra
.612 .699 .906 r
.82105 .39919 .82178 .40028 .82353 .39997 .8228 .39887 Mtetra
.635 .708 .899 r
.8228 .39887 .82353 .39997 .82527 .39952 .82454 .39846 Mtetra
.742 .758 .866 r
.82454 .39846 .82527 .39952 .82695 .39842 .82624 .39748 Mtetra
.66 .755 .921 r
.82624 .39748 .82695 .39842 .82868 .39778 .82797 .39695 Mtetra
.092 .463 .888 r
.82797 .39695 .82868 .39778 .83054 .39852 .82984 .39779 Mtetra
.903 .506 .091 r
.82984 .39779 .83054 .39852 .83294 .40495 .83228 .40465 Mtetra
.975 .669 .349 r
.83228 .40465 .83294 .40495 .85393 .60498 .85318 .60409 Mtetra
.688 .226 0 r
.85318 .60409 .85393 .60498 .85617 .60846 .85541 .60745 Mtetra
.4 .627 .945 r
.85541 .60745 .85617 .60846 .85811 .60876 .85735 .60775 Mtetra
.702 .771 .905 r
.85735 .60775 .85811 .60876 .85995 .60796 .85919 .60698 Mtetra
.885 .812 .772 r
.85919 .60698 .85995 .60796 .86162 .60546 .86087 .60457 Mtetra
.981 .756 .524 r
.86087 .60457 .86162 .60546 .86252 .59524 .86189 .59546 Mtetra
.978 .678 .355 r
.86189 .59546 .86252 .59524 .84466 .39624 .84399 .39573 Mtetra
.971 .846 .661 r
.84399 .39573 .84466 .39624 .8461 .39263 .84541 .39192 Mtetra
.729 .839 .933 r
.84541 .39192 .8461 .39263 .84782 .39188 .84713 .39108 Mtetra
.567 .751 .964 r
.84713 .39108 .84782 .39188 .84961 .39175 .84891 .39084 Mtetra
.564 .722 .948 r
.84891 .39084 .84961 .39175 .85141 .39169 .85069 .39065 Mtetra
.726 .758 .879 r
.85069 .39065 .85141 .39169 .85314 .39096 .85241 .38977 Mtetra
.654 .702 .882 r
.85241 .38977 .85314 .39096 .85489 .39044 .85416 .38927 Mtetra
.364 .553 .905 r
.85416 .38927 .85489 .39044 .8567 .3905 .85603 .38981 Mtetra
.841 .409 0 r
.85603 .38981 .8567 .3905 .85868 .39209 .85834 .39466 Mtetra
.973 .664 .345 r
.85834 .39466 .85868 .39209 .86097 .39666 .88091 .59387 Mtetra
.57 .355 .55 r
.88091 .59387 .86097 .39666 .88326 .59175 .8833 .59827 Mtetra
.573 .301 .465 r
.8833 .59827 .88326 .59175 .88572 .59677 .88529 .59881 Mtetra
.48 .114 .266 r
.88529 .59881 .88572 .59677 .88786 .59874 .88721 .59864 Mtetra
.33 .811 .882 r
.88721 .59864 .88786 .59874 .88988 .59953 .8891 .59824 Mtetra
.561 .654 .898 r
.8891 .59824 .88988 .59953 .89181 .59948 .89103 .59814 Mtetra
.66 .694 .871 r
.89103 .59814 .89181 .59948 .89368 .59886 .89291 .59757 Mtetra
.798 .752 .81 r
.89291 .59757 .89368 .59886 .89548 .59755 .89468 .59596 Mtetra
.933 .74 .62 r
.89468 .59596 .89548 .59755 .89713 .59483 .89602 .59047 Mtetra
.976 .672 .353 r
.89602 .59047 .89713 .59483 .8985 .58966 .87603 .3898 Mtetra
.574 .362 .556 r
.87603 .3898 .8985 .58966 .87884 .3934 .87718 .38363 Mtetra
.615 .428 .606 r
.87718 .38363 .87884 .3934 .87989 .38633 .87883 .38205 Mtetra
.631 .488 .67 r
.87883 .38205 .87989 .38633 .88139 .38338 .88056 .38118 Mtetra
.648 .579 .764 r
.88056 .38118 .88139 .38338 .88302 .3816 .88232 .38056 Mtetra
.743 .768 .873 r
.88232 .38056 .88302 .3816 .88474 .38058 .88404 .37958 Mtetra
.663 .745 .911 r
.88404 .37958 .88474 .38058 .88651 .38008 .88581 .37902 Mtetra
.425 .615 .929 r
.88581 .37902 .88651 .38008 .88835 .38018 .88768 .37932 Mtetra
.723 .277 0 r
.88768 .37932 .88835 .38018 .89034 .38152 .88995 .38316 Mtetra
.973 .66 .323 r
.88995 .38316 .89034 .38152 .89259 .38513 .91461 .58257 Mtetra
.572 .357 .55 r
.91461 .58257 .89259 .38513 .91689 .58005 .91724 .58843 Mtetra
.576 .315 .484 r
.91724 .58843 .91689 .58005 .91961 .58668 .91928 .58911 Mtetra
.503 .156 .311 r
.91928 .58911 .91961 .58668 .92183 .58895 .92123 .589 Mtetra
.26 .768 .777 r
.92123 .589 .92183 .58895 .9239 .58987 .92314 .58851 Mtetra
.636 .68 .875 r
.92314 .58851 .9239 .58987 .92584 .58962 .92505 .58806 Mtetra
.652 .658 .843 r
.92505 .58806 .92584 .58962 .92774 .58901 .92695 .5875 Mtetra
.659 .668 .847 r
.92695 .5875 .92774 .58901 .92961 .58825 .92885 .58689 Mtetra
.645 .685 .873 r
.92885 .58689 .92961 .58825 .93152 .58774 .93076 .58639 Mtetra
.644 .686 .875 r
.93076 .58639 .93152 .58774 .93343 .58723 .93267 .5859 Mtetra
.64 .687 .878 r
.93267 .5859 .93343 .58723 .93535 .58674 .93459 .58542 Mtetra
.556 .649 .897 r
.93459 .58542 .93535 .58674 .93729 .5865 .93655 .58535 Mtetra
.631 .717 .909 r
.93655 .58535 .93729 .5865 .93921 .58603 .93848 .58491 Mtetra
.761 .774 .864 r
.93848 .58491 .93921 .58603 .94108 .5851 .94031 .58373 Mtetra
.944 .764 .629 r
.94031 .58373 .94108 .5851 .9427 .58221 .94168 .57873 Mtetra
.975 .667 .325 r
.94168 .57873 .9427 .58221 .94404 .57701 .91894 .37798 Mtetra
.576 .364 .556 r
.91894 .37798 .94404 .57701 .92199 .38305 .91988 .37049 Mtetra
.595 .406 .595 r
.91988 .37049 .92199 .38305 .92361 .38104 .9216 .36932 Mtetra
.579 .397 .599 r
.9216 .36932 .92361 .38104 .9256 .382 .92341 .36891 Mtetra
.571 .388 .595 r
.92341 .36891 .9256 .382 .92735 .38105 .92526 .36879 Mtetra
.617 .526 .729 r
.34364 .54825 .34445 .5508 .34594 .54979 .34509 .54791 Mtetra
.626 .575 .777 r
.34509 .54791 .34594 .54979 .34743 .5488 .34654 .54757 Mtetra
.641 .66 .853 r
.34654 .54757 .34743 .5488 .34891 .54791 .348 .54719 Mtetra
.706 .782 .911 r
.348 .54719 .34891 .54791 .35038 .5474 .34947 .54656 Mtetra
.694 .749 .894 r
.34947 .54656 .35038 .5474 .35183 .547 .35094 .54597 Mtetra
.658 .701 .879 r
.35094 .54597 .35183 .547 .35329 .54663 .3524 .54553 Mtetra
.594 .666 .889 r
.3524 .54553 .35329 .54663 .35478 .54575 .35385 .54535 Mtetra
.074 .582 .886 r
.35385 .54535 .35478 .54575 .35625 .54513 .35528 .54562 Mtetra
.709 .26 .183 r
.35528 .54562 .35625 .54513 .35769 .54508 .35666 .54678 Mtetra
.883 .594 .493 r
.35666 .54678 .35769 .54508 .35899 .54803 .35759 .55727 Mtetra
.923 .667 .532 r
.35759 .55727 .35899 .54803 .35126 .7361 .34995 .74238 Mtetra
.676 .404 .502 r
.34995 .74238 .35126 .7361 .35239 .74425 .35133 .7455 Mtetra
.541 .127 .205 r
.35133 .7455 .35239 .74425 .35388 .74526 .35285 .74581 Mtetra
.017 0 0 r
.35285 .74581 .35388 .74526 .35541 .7453 .35441 .74537 Mtetra
.688 .967 .932 r
.35441 .74537 .35541 .7453 .35696 .74493 .35599 .74447 Mtetra
.728 .859 .943 r
.35599 .74447 .35696 .74493 .35849 .74508 .35756 .7437 Mtetra
.743 .683 .793 r
.35756 .7437 .35849 .74508 .36004 .74486 .35915 .74253 Mtetra
.752 .617 .71 r
.35915 .74253 .36004 .74486 .36162 .74393 .36078 .74055 Mtetra
.841 .635 .625 r
.36078 .74055 .36162 .74393 .36336 .73942 .36266 .73311 Mtetra
.932 .679 .533 r
.36266 .73311 .36336 .73942 .37353 .54732 .37276 .54362 Mtetra
.781 .592 .644 r
.37276 .54362 .37353 .54732 .3753 .5403 .37441 .53932 Mtetra
.777 .739 .818 r
.37441 .53932 .3753 .5403 .37682 .53887 .37592 .53812 Mtetra
.665 .766 .925 r
.37592 .53812 .37682 .53887 .37829 .53841 .37739 .53764 Mtetra
.57 .737 .954 r
.37739 .53764 .37829 .53841 .37975 .53832 .37886 .53746 Mtetra
.752 .756 .855 r
.37886 .53746 .37975 .53832 .38125 .53748 .38036 .53652 Mtetra
.719 .732 .861 r
.38036 .53652 .38125 .53748 .38274 .53681 .38185 .53577 Mtetra
.58 .674 .904 r
.38185 .53577 .38274 .53681 .3842 .53674 .38331 .53562 Mtetra
.873 .447 .029 r
.38331 .53562 .3842 .53674 .38553 .53993 .38465 .53864 Mtetra
.943 .684 .516 r
.38465 .53864 .38553 .53993 .37915 .73106 .37823 .72968 Mtetra
.957 .622 .332 r
.37823 .72968 .37915 .73106 .38044 .73755 .37949 .73674 Mtetra
0 .156 .63 r
.37949 .73674 .38044 .73755 .38195 .73857 .38099 .73787 Mtetra
.589 .771 .966 r
.38099 .73787 .38195 .73857 .38351 .73825 .38256 .73759 Mtetra
.813 .81 .848 r
.38256 .73759 .38351 .73825 .38512 .73693 .38417 .73621 Mtetra
.915 .75 .663 r
.38417 .73621 .38512 .73693 .38684 .73279 .38592 .7312 Mtetra
.941 .687 .524 r
.38592 .7312 .38684 .73279 .3957 .54255 .39496 .53774 Mtetra
.786 .582 .624 r
.39496 .53774 .3957 .54255 .39748 .53431 .39665 .53182 Mtetra
.717 .587 .709 r
.39665 .53182 .39748 .53431 .39901 .53265 .39818 .53033 Mtetra
.634 .549 .741 r
.39818 .53033 .39901 .53265 .4005 .53218 .39967 .52985 Mtetra
.586 .522 .75 r
.39967 .52985 .4005 .53218 .40198 .53214 .40114 .52976 Mtetra
.648 .554 .734 r
.40114 .52976 .40198 .53214 .40348 .53144 .40264 .52915 Mtetra
.647 .558 .74 r
.40264 .52915 .40348 .53144 .40497 .53082 .40414 .52856 Mtetra
.592 .53 .754 r
.40414 .52856 .40497 .53082 .40645 .53083 .40562 .52842 Mtetra
.126 .228 .7 r
.40562 .52842 .40645 .53083 .4078 .53436 .40703 .5302 Mtetra
.791 .536 0 r
.40703 .5302 .4078 .53436 .40269 .72565 .40825 .53769 Mtetra
0 0 .327 r
.40825 .53769 .40269 .72565 .40407 .73107 .40325 .72679 Mtetra
.274 .244 .642 r
.40325 .72679 .40407 .73107 .40561 .73189 .40474 .72922 Mtetra
.478 .446 .744 r
.40474 .72922 .40561 .73189 .4072 .73153 .40628 .72984 Mtetra
.557 .574 .827 r
.40628 .72984 .4072 .73153 .40879 .73075 .40786 .72986 Mtetra
.596 .729 .937 r
.40786 .72986 .40879 .73075 .41038 .73024 .40944 .7296 Mtetra
.635 .804 .964 r
.40944 .7296 .41038 .73024 .41197 .72983 .41102 .72917 Mtetra
.67 .805 .947 r
.41102 .72917 .41197 .72983 .41356 .72932 .41262 .72862 Mtetra
.647 .791 .951 r
.41262 .72862 .41356 .72932 .41516 .7285 .41421 .72816 Mtetra
.567 .865 .996 r
.41421 .72816 .41516 .7285 .41677 .72748 .4158 .72775 Mtetra
0 0 0 r
.4158 .72775 .41677 .72748 .41838 .72642 .41739 .72734 Mtetra
.369 0 0 r
.41739 .72734 .41838 .72642 .41997 .72614 .41897 .7272 Mtetra
.362 0 .032 r
.41897 .7272 .41997 .72614 .42155 .72599 .42056 .72697 Mtetra
.093 0 0 r
.42056 .72697 .42155 .72599 .42315 .72523 .42216 .72625 Mtetra
.882 .963 .632 r
.42216 .72625 .42315 .72523 .42486 .72087 .42383 .72346 Mtetra
.994 .847 .493 r
.42383 .72346 .42486 .72087 .43179 .52838 .42566 .71469 Mtetra
0 0 .323 r
.42566 .71469 .43179 .52838 .43345 .52219 .43248 .52458 Mtetra
0 0 .011 r
.43248 .52458 .43345 .52219 .435 .52041 .43405 .52206 Mtetra
.376 0 .184 r
.43405 .52206 .435 .52041 .43651 .51987 .43556 .52156 Mtetra
.482 .106 .249 r
.43556 .52156 .43651 .51987 .43801 .51972 .43706 .52147 Mtetra
.239 0 .126 r
.43706 .52147 .43801 .51972 .43951 .51947 .43859 .52049 Mtetra
0 0 0 r
.43859 .52049 .43951 .51947 .44102 .51909 .44012 .51905 Mtetra
.826 .96 .898 r
.44012 .51905 .44102 .51909 .44253 .51872 .44165 .51779 Mtetra
.726 .746 .868 r
.44165 .51779 .44253 .51872 .44404 .51831 .44318 .517 Mtetra
.659 .659 .839 r
.44318 .517 .44404 .51831 .44555 .51787 .44469 .51652 Mtetra
.64 .645 .84 r
.44469 .51652 .44555 .51787 .44707 .5174 .4462 .51613 Mtetra
.65 .663 .849 r
.4462 .51613 .44707 .5174 .44858 .51688 .44772 .5157 Mtetra
.661 .682 .858 r
.44772 .5157 .44858 .51688 .4501 .51633 .44923 .51522 Mtetra
.663 .694 .868 r
.44923 .51522 .4501 .51633 .45162 .51578 .45075 .51474 Mtetra
.665 .707 .879 r
.45075 .51474 .45162 .51578 .45314 .51526 .45227 .51425 Mtetra
.665 .714 .885 r
.45227 .51425 .45314 .51526 .45466 .51476 .45379 .51376 Mtetra
.665 .716 .886 r
.45379 .51376 .45466 .51476 .45618 .51428 .45531 .51328 Mtetra
.664 .716 .886 r
.45531 .51328 .45618 .51428 .4577 .51379 .45683 .51279 Mtetra
.664 .715 .887 r
.45683 .51279 .4577 .51379 .45922 .51331 .45835 .51231 Mtetra
.663 .716 .887 r
.45835 .51231 .45922 .51331 .46074 .51283 .45987 .51183 Mtetra
.662 .716 .888 r
.45987 .51183 .46074 .51283 .46226 .51236 .4614 .51136 Mtetra
.661 .716 .889 r
.4614 .51136 .46226 .51236 .46379 .51188 .46292 .51089 Mtetra
.66 .716 .889 r
.46292 .51089 .46379 .51188 .46531 .51141 .46445 .51042 Mtetra
.661 .716 .89 r
.46445 .51042 .46531 .51141 .46684 .51095 .46597 .50995 Mtetra
.66 .716 .89 r
.46597 .50995 .46684 .51095 .46836 .51049 .4675 .50949 Mtetra
.656 .714 .891 r
.4675 .50949 .46836 .51049 .46989 .51003 .46902 .50904 Mtetra
.644 .714 .898 r
.46902 .50904 .46989 .51003 .47142 .50957 .47055 .50864 Mtetra
.633 .723 .912 r
.47055 .50864 .47142 .50957 .47294 .50911 .47208 .50828 Mtetra
.63 .745 .931 r
.47208 .50828 .47294 .50911 .47447 .50865 .47361 .50792 Mtetra
.639 .773 .945 r
.47361 .50792 .47447 .50865 .476 .50818 .47514 .50752 Mtetra
.652 .794 .951 r
.47514 .50752 .476 .50818 .47754 .5077 .47667 .50706 Mtetra
.659 .801 .951 r
.47667 .50706 .47754 .5077 .47907 .50721 .4782 .50657 Mtetra
.661 .803 .951 r
.4782 .50657 .47907 .50721 .4806 .50668 .47974 .50608 Mtetra
.66 .815 .958 r
.47974 .50608 .4806 .50668 .48214 .50612 .48127 .50557 Mtetra
.664 .832 .964 r
.48127 .50557 .48214 .50612 .48367 .50563 .48281 .50505 Mtetra
.683 .824 .951 r
.48281 .50505 .48367 .50563 .4852 .50539 .48435 .50447 Mtetra
.694 .743 .889 r
.48435 .50447 .4852 .50539 .48673 .50541 .48588 .50385 Mtetra
.672 .633 .803 r
.48588 .50385 .48673 .50541 .48827 .5055 .48742 .50323 Mtetra
.646 .562 .745 r
.48742 .50323 .48827 .5055 .4898 .50535 .48896 .50265 Mtetra
.632 .531 .721 r
.48896 .50265 .4898 .50535 .49134 .50487 .4905 .50212 Mtetra
.629 .527 .719 r
.4905 .50212 .49134 .50487 .49288 .50428 .49204 .50161 Mtetra
.63 .531 .724 r
.49204 .50161 .49288 .50428 .49443 .5037 .49359 .50111 Mtetra
.631 .535 .728 r
.49359 .50111 .49443 .5037 .49597 .50319 .49513 .50061 Mtetra
.63 .536 .729 r
.49513 .50061 .49597 .50319 .49751 .50269 .49667 .50012 Mtetra
.49667 .50012 .49751 .50269 .49906 .50219 .49821 .49963 Mtetra
.63 .536 .73 r
.49821 .49963 .49906 .50219 .5006 .5017 .49976 .49915 Mtetra
.63 .537 .731 r
.49976 .49915 .5006 .5017 .50215 .50121 .5013 .49866 Mtetra
.631 .538 .731 r
.5013 .49866 .50215 .50121 .50369 .50071 .50285 .49817 Mtetra
.632 .539 .731 r
.50285 .49817 .50369 .50071 .50524 .5002 .5044 .49767 Mtetra
.632 .539 .732 r
.5044 .49767 .50524 .5002 .50679 .4997 .50595 .49717 Mtetra
.647 .548 .729 r
.50595 .49717 .50679 .4997 .50834 .49899 .5075 .49653 Mtetra
.658 .558 .73 r
.5075 .49653 .50834 .49899 .50989 .49814 .50905 .49578 Mtetra
.622 .544 .745 r
.50905 .49578 .50989 .49814 .51144 .4978 .5106 .49539 Mtetra
.429 .426 .754 r
.5106 .49539 .51144 .4978 .51299 .49934 .51215 .49621 Mtetra
0 0 .392 r
.51215 .49621 .51299 .49934 .51395 .68727 .51368 .50065 Mtetra
0 0 .37 r
.51368 .50065 .51395 .68727 .51556 .69887 .51468 .69332 Mtetra
.194 .164 .594 r
.51468 .69332 .51556 .69887 .51721 .70094 .51631 .69728 Mtetra
.59 .477 .694 r
.51631 .69728 .51721 .70094 .51886 .70076 .51796 .6971 Mtetra
.638 .508 .688 r
.51796 .6971 .51886 .70076 .52051 .70005 .51962 .69629 Mtetra
.605 .485 .689 r
.51962 .69629 .52051 .70005 .52216 .69924 .52127 .69592 Mtetra
.499 .431 .711 r
.52127 .69592 .52216 .69924 .52382 .69869 .52292 .69657 Mtetra
.474 .488 .792 r
.52292 .69657 .52382 .69869 .52547 .69815 .52458 .69708 Mtetra
.48 .643 .929 r
.52458 .69708 .52547 .69815 .52713 .69771 .52623 .6972 Mtetra
.571 .828 .994 r
.52623 .6972 .52713 .69771 .52879 .69739 .52789 .69684 Mtetra
.633 .836 .978 r
.52789 .69684 .52879 .69739 .53044 .69702 .52955 .69635 Mtetra
.607 .797 .972 r
.52955 .69635 .53044 .69702 .5321 .69656 .53121 .69598 Mtetra
.477 .77 .995 r
.53121 .69598 .5321 .69656 .53376 .69597 .53287 .69586 Mtetra
.502 .892 .955 r
.53287 .69586 .53376 .69597 .53542 .69485 .53453 .69535 Mtetra
.749 .981 .739 r
.53453 .69535 .53542 .69485 .53708 .69203 .53619 .69368 Mtetra
.954 .887 .492 r
.53619 .69368 .53708 .69203 .538 .50477 .53784 .68829 Mtetra
0 0 .362 r
.53784 .68829 .538 .50477 .53951 .49026 .53869 .49435 Mtetra
0 0 .086 r
.53869 .49435 .53951 .49026 .54107 .4873 .54024 .48899 Mtetra
.297 0 .153 r
.54024 .48899 .54107 .4873 .54264 .48651 .54181 .48816 Mtetra
.454 .073 .226 r
.54181 .48816 .54264 .48651 .54421 .48622 .54338 .48796 Mtetra
.405 .033 .215 r
.54338 .48796 .54421 .48622 .54578 .48608 .54496 .48751 Mtetra
0 0 0 r
.54496 .48751 .54578 .48608 .54735 .48568 .54652 .48601 Mtetra
.734 .988 .796 r
.54652 .48601 .54735 .48568 .54892 .48528 .54809 .48464 Mtetra
.781 .829 .89 r
.54809 .48464 .54892 .48528 .55049 .48484 .54966 .48359 Mtetra
.673 .681 .849 r
.54966 .48359 .55049 .48484 .55207 .48432 .55123 .48302 Mtetra
.648 .663 .851 r
.55123 .48302 .55207 .48432 .55364 .48378 .55281 .48259 Mtetra
.642 .678 .869 r
.55281 .48259 .55364 .48378 .55522 .48324 .55438 .48218 Mtetra
.661 .71 .884 r
.55438 .48218 .55522 .48324 .55679 .48274 .55596 .4817 Mtetra
.661 .713 .886 r
.55596 .4817 .55679 .48274 .55837 .48225 .55754 .48121 Mtetra
.662 .714 .887 r
.55754 .48121 .55837 .48225 .55995 .48176 .55912 .48072 Mtetra
.662 .715 .887 r
.55912 .48072 .55995 .48176 .56153 .48126 .56069 .48023 Mtetra
.663 .716 .888 r
.56069 .48023 .56153 .48126 .56311 .48076 .56228 .47973 Mtetra
.663 .717 .888 r
.56228 .47973 .56311 .48076 .56469 .48027 .56386 .47924 Mtetra
.663 .717 .889 r
.56386 .47924 .56469 .48027 .56627 .47977 .56544 .47874 Mtetra
.56544 .47874 .56627 .47977 .56785 .47927 .56702 .47824 Mtetra
.56702 .47824 .56785 .47927 .56943 .47878 .56861 .47775 Mtetra
.663 .718 .889 r
.56861 .47775 .56943 .47878 .57102 .47828 .57019 .47725 Mtetra
.57019 .47725 .57102 .47828 .5726 .47778 .57178 .47675 Mtetra
.57178 .47675 .5726 .47778 .57419 .47728 .57336 .47625 Mtetra
.57336 .47625 .57419 .47728 .57578 .47679 .57495 .47575 Mtetra
.57495 .47575 .57578 .47679 .57737 .47629 .57654 .47526 Mtetra
.663 .717 .889 r
.57654 .47526 .57737 .47629 .57895 .47579 .57813 .47476 Mtetra
.57813 .47476 .57895 .47579 .58054 .47529 .57972 .47426 Mtetra
.664 .717 .888 r
.57972 .47426 .58054 .47529 .58213 .47479 .58131 .47375 Mtetra
.664 .716 .888 r
.58131 .47375 .58213 .47479 .58373 .47429 .5829 .47325 Mtetra
.665 .716 .887 r
.5829 .47325 .58373 .47429 .58532 .47379 .58449 .47274 Mtetra
.665 .715 .886 r
.58449 .47274 .58532 .47379 .58691 .47329 .58609 .47223 Mtetra
.667 .715 .884 r
.58609 .47223 .58691 .47329 .58851 .4728 .58768 .47171 Mtetra
.683 .713 .872 r
.58768 .47171 .58851 .4728 .5901 .47235 .58928 .4711 Mtetra
.664 .679 .855 r
.58928 .4711 .5901 .47235 .5917 .47189 .59087 .47058 Mtetra
.626 .653 .857 r
.59087 .47058 .5917 .47189 .5933 .4714 .59247 .47025 Mtetra
.461 .605 .908 r
.59247 .47025 .5933 .4714 .59489 .47082 .59409 .47048 Mtetra
0 .477 .794 r
.59409 .47048 .59489 .47082 .59649 .47023 .59571 .47092 Mtetra
.522 .031 .031 r
.59571 .47092 .59649 .47023 .59809 .46961 .59733 .47133 Mtetra
.286 0 .157 r
.59733 .47133 .59809 .46961 .59968 .46871 .59892 .47042 Mtetra
.359 0 .191 r
.59892 .47042 .59968 .46871 .60128 .46814 .60052 .46978 Mtetra
.555 .172 .27 r
.60052 .46978 .60128 .46814 .6029 .46827 .60215 .47013 Mtetra
.914 .603 .442 r
.60215 .47013 .6029 .46827 .60459 .47168 .6041 .48402 Mtetra
.945 .665 .475 r
.6041 .48402 .60459 .47168 .611 .66571 .61028 .67056 Mtetra
.689 .392 .467 r
.61028 .67056 .611 .66571 .61289 .67251 .61208 .67358 Mtetra
.469 .019 .098 r
.61208 .67358 .61289 .67251 .61463 .67333 .6138 .67369 Mtetra
0 0 0 r
.6138 .67369 .61463 .67333 .61635 .67332 .61551 .67314 Mtetra
.74 .954 .944 r
.61551 .67314 .61635 .67332 .61807 .67291 .61721 .67212 Mtetra
.796 .813 .865 r
.61721 .67212 .61807 .67291 .61978 .67253 .6189 .67084 Mtetra
.76 .673 .767 r
.6189 .67084 .61978 .67253 .62149 .67203 .62059 .66931 Mtetra
.716 .588 .711 r
.62059 .66931 .62149 .67203 .62321 .67147 .62227 .6677 Mtetra
.579 .469 .693 r
.62227 .6677 .62321 .67147 .62493 .67142 .62399 .66764 Mtetra
.599 .482 .691 r
.62399 .66764 .62493 .67142 .62665 .67103 .62572 .66734 Mtetra
.66 .522 .685 r
.62572 .66734 .62665 .67103 .62835 .66999 .62741 .66618 Mtetra
.88 .649 .585 r
.62741 .66618 .62835 .66999 .62995 .66549 .62883 .65556 Mtetra
.955 .678 .472 r
.62883 .65556 .62995 .66549 .62572 .4707 .62472 .46353 Mtetra
.703 .504 .615 r
.62472 .46353 .62572 .4707 .6271 .46231 .62623 .45959 Mtetra
.667 .554 .717 r
.62623 .45959 .6271 .46231 .62867 .46052 .62784 .45865 Mtetra
.624 .585 .79 r
.62784 .45865 .62867 .46052 .63028 .45957 .62946 .45829 Mtetra
.566 .634 .878 r
.62946 .45829 .63028 .45957 .6319 .45901 .6311 .45821 Mtetra
.697 .784 .919 r
.6311 .45821 .6319 .45901 .63351 .45848 .63271 .45756 Mtetra
.69 .755 .901 r
.63271 .45756 .63351 .45848 .63514 .45804 .63433 .45694 Mtetra
.656 .704 .882 r
.63433 .45694 .63514 .45804 .63676 .45765 .63595 .45646 Mtetra
.602 .666 .885 r
.63595 .45646 .63676 .45765 .63837 .45673 .63759 .45622 Mtetra
.242 .663 .961 r
.63759 .45622 .63837 .45673 .63999 .45604 .63924 .45643 Mtetra
.652 .142 .017 r
.63924 .45643 .63999 .45604 .64163 .45592 .64092 .4575 Mtetra
.893 .561 .41 r
.64092 .4575 .64163 .45592 .64337 .45866 .64287 .46601 Mtetra
.957 .672 .454 r
.64287 .46601 .64337 .45866 .65204 .65044 .65152 .65838 Mtetra
.66 .387 .496 r
.65152 .65838 .65204 .65044 .65415 .6604 .65339 .66175 Mtetra
.512 .092 .181 r
.65339 .66175 .65415 .6604 .65595 .6615 .65515 .66196 Mtetra
0 0 0 r
.65515 .66196 .65595 .6615 .6577 .66147 .65689 .66139 Mtetra
.671 .962 .936 r
.65689 .66139 .6577 .66147 .65944 .66097 .65861 .66046 Mtetra
.65 .863 .98 r
.65861 .66046 .65944 .66097 .66117 .66049 .66034 .65987 Mtetra
.647 .829 .97 r
.66034 .65987 .66117 .66049 .66291 .65993 .66208 .65933 Mtetra
.641 .832 .974 r
.66208 .65933 .66291 .65993 .66464 .65933 .66382 .6588 Mtetra
.617 .847 .987 r
.66382 .6588 .66464 .65933 .66638 .65882 .66556 .6583 Mtetra
.604 .847 .99 r
.66556 .6583 .66638 .65882 .66813 .65835 .6673 .65783 Mtetra
.597 .843 .991 r
.6673 .65783 .66813 .65835 .66987 .65793 .66905 .65739 Mtetra
.589 .834 .991 r
.66905 .65739 .66987 .65793 .67162 .65765 .67079 .65697 Mtetra
.608 .802 .974 r
.67079 .65697 .67162 .65765 .67338 .65736 .67254 .65656 Mtetra
.619 .777 .956 r
.67254 .65656 .67338 .65736 .67513 .65694 .67429 .65616 Mtetra
.496 .73 .976 r
.67429 .65616 .67513 .65694 .67687 .65648 .67606 .65609 Mtetra
.475 .828 .996 r
.67606 .65609 .67687 .65648 .67861 .65565 .67782 .65581 Mtetra
.477 .895 .817 r
.67782 .65581 .67861 .65565 .68031 .65406 .67955 .65499 Mtetra
.858 .924 .533 r
.67955 .65499 .68031 .65406 .6818 .64796 .68118 .65174 Mtetra
.852 .739 .22 r
.68118 .65174 .6818 .64796 .67456 .45093 .68247 .64102 Mtetra
.039 0 .431 r
.68247 .64102 .67456 .45093 .676 .44579 .67536 .44798 Mtetra
0 0 .039 r
.67536 .44798 .676 .44579 .6776 .44439 .67689 .44506 Mtetra
0 0 0 r
.67689 .44506 .6776 .44439 .67925 .44393 .6785 .44365 Mtetra
.725 .934 .957 r
.6785 .44365 .67925 .44393 .68092 .44384 .68013 .44277 Mtetra
.676 .72 .883 r
.68013 .44277 .68092 .44384 .68257 .44343 .68178 .44219 Mtetra
.636 .673 .869 r
.68178 .44219 .68257 .44343 .68422 .44289 .68343 .4418 Mtetra
.613 .692 .9 r
.68343 .4418 .68422 .44289 .68587 .44234 .68509 .4415 Mtetra
.642 .762 .936 r
.68509 .4415 .68587 .44234 .68752 .44172 .68675 .44106 Mtetra
.656 .813 .959 r
.68675 .44106 .68752 .44172 .68917 .44114 .6884 .44053 Mtetra
.662 .832 .965 r
.6884 .44053 .68917 .44114 .69082 .44065 .69005 .43997 Mtetra
.754 .833 .912 r
.69005 .43997 .69082 .44065 .69248 .44016 .69169 .43904 Mtetra
.715 .726 .859 r
.69169 .43904 .69248 .44016 .69415 .43996 .69333 .43823 Mtetra
.619 .599 .809 r
.69333 .43823 .69415 .43996 .69586 .44042 .695 .43791 Mtetra
.251 .311 .731 r
.695 .43791 .69586 .44042 .69777 .4447 .69678 .43968 Mtetra
0 0 .328 r
.69678 .43968 .69777 .4447 .70997 .6414 .69893 .44851 Mtetra
.063 0 .449 r
.69893 .44851 .70997 .6414 .71202 .64622 .71101 .64183 Mtetra
.348 .304 .666 r
.71101 .64183 .71202 .64622 .71386 .64706 .71294 .6442 Mtetra
.503 .46 .742 r
.71294 .6442 .71386 .64706 .71564 .64668 .71477 .64477 Mtetra
.568 .566 .811 r
.71477 .64477 .71564 .64668 .71739 .6458 .71657 .64475 Mtetra
.52 .675 .935 r
.71657 .64475 .71739 .6458 .71916 .64512 .71837 .64474 Mtetra
.466 .829 .994 r
.71837 .64474 .71916 .64512 .72091 .6443 .72016 .64446 Mtetra
.483 .897 .81 r
.72016 .64446 .72091 .6443 .72263 .64281 .72191 .64359 Mtetra
.813 .928 .551 r
.72191 .64359 .72263 .64281 .72416 .63796 .72356 .64078 Mtetra
.803 .738 .212 r
.72356 .64078 .72416 .63796 .71446 .4401 .72491 .63292 Mtetra
.058 0 .442 r
.72491 .63292 .71446 .4401 .7158 .43379 .71524 .43644 Mtetra
0 0 .105 r
.71524 .43644 .7158 .43379 .71739 .43198 .71673 .43282 Mtetra
0 0 0 r
.71673 .43282 .71739 .43198 .71906 .43144 .71834 .43126 Mtetra
.727 .962 .941 r
.71834 .43126 .71906 .43144 .72075 .43131 .71998 .43029 Mtetra
.698 .741 .885 r
.71998 .43029 .72075 .43131 .72244 .43101 .72164 .42959 Mtetra
.656 .658 .84 r
.72164 .42959 .72244 .43101 .72411 .43052 .72332 .42907 Mtetra
.634 .644 .842 r
.72332 .42907 .72411 .43052 .72579 .43001 .725 .42868 Mtetra
.638 .663 .858 r
.725 .42868 .72579 .43001 .72746 .42938 .72668 .42827 Mtetra
.645 .705 .89 r
.72668 .42827 .72746 .42938 .72912 .42872 .72836 .42783 Mtetra
.648 .754 .927 r
.72836 .42783 .72912 .42872 .7308 .42815 .73005 .42736 Mtetra
.73 .805 .911 r
.73005 .42736 .7308 .42815 .73248 .42763 .73171 .42653 Mtetra
.722 .737 .863 r
.73171 .42653 .73248 .42763 .73417 .42735 .73336 .42568 Mtetra
.633 .614 .814 r
.73336 .42568 .73417 .42735 .73591 .4277 .73505 .42528 Mtetra
.341 .376 .752 r
.73505 .42528 .73591 .4277 .73784 .43104 .73686 .42663 Mtetra
0 0 .47 r
.73686 .42663 .73784 .43104 .75257 .62823 .739 .43315 Mtetra
.082 .005 .46 r
.739 .43315 .75257 .62823 .75478 .634 .75372 .62918 Mtetra
.31 .269 .65 r
.75372 .62918 .75478 .634 .75669 .6352 .75575 .6322 Mtetra
.493 .447 .734 r
.75575 .6322 .75669 .6352 .7585 .63491 .75763 .63288 Mtetra
.559 .551 .802 r
.75763 .63288 .7585 .63491 .76028 .6341 .75947 .63292 Mtetra
.52 .65 .916 r
.75947 .63292 .76028 .6341 .76207 .63337 .7613 .63295 Mtetra
.403 .791 .99 r
.7613 .63295 .76207 .63337 .76385 .63263 .76313 .6328 Mtetra
.417 .859 .776 r
.76313 .6328 .76385 .63263 .7656 .63131 .76491 .63199 Mtetra
.864 .937 .563 r
.76491 .63199 .7656 .63131 .76717 .62754 .76654 .62894 Mtetra
.995 .76 .41 r
.76654 .62894 .76717 .62754 .75513 .43135 .76725 .61296 Mtetra
.054 0 .446 r
.76725 .61296 .75513 .43135 .7562 .42204 .75545 .42108 Mtetra
.895 .791 .738 r
.75545 .42108 .7562 .42204 .75776 .4197 .75699 .41842 Mtetra
.677 .69 .855 r
.75699 .41842 .75776 .4197 .75945 .41902 .75868 .4178 Mtetra
.565 .65 .892 r
.75868 .4178 .75945 .41902 .76116 .41877 .7604 .4177 Mtetra
.592 .693 .913 r
.7604 .4177 .76116 .41877 .76287 .41835 .76212 .41747 Mtetra
.672 .769 .923 r
.76212 .41747 .76287 .41835 .76455 .41764 .76382 .4169 Mtetra
.678 .805 .943 r
.76382 .4169 .76455 .41764 .76624 .41702 .76551 .41629 Mtetra
.751 .829 .912 r
.76551 .41629 .76624 .41702 .76794 .41644 .76718 .41535 Mtetra
.747 .749 .854 r
.76718 .41535 .76794 .41644 .76965 .41605 .76884 .41434 Mtetra
.645 .617 .808 r
.76884 .41434 .76965 .41605 .7714 .41621 .77055 .41385 Mtetra
.321 .369 .756 r
.77055 .41385 .7714 .41621 .77332 .41853 .7724 .41528 Mtetra
.847 .536 .004 r
.7724 .41528 .77332 .41853 .79016 .61406 .77506 .4272 Mtetra
.08 .007 .464 r
.77506 .4272 .79016 .61406 .79267 .62254 .79185 .62112 Mtetra
0 .062 .623 r
.79185 .62112 .79267 .62254 .79468 .62449 .7939 .62358 Mtetra
.458 .682 .962 r
.7939 .62358 .79468 .62449 .79656 .62461 .79577 .62367 Mtetra
.741 .792 .894 r
.79577 .62367 .79656 .62461 .79835 .62376 .79756 .6227 Mtetra
.903 .788 .724 r
.79756 .6227 .79835 .62376 .79999 .62092 .79918 .61964 Mtetra
.974 .717 .482 r
.79918 .61964 .79999 .62092 .8009 .60903 .7997 .60283 Mtetra
.972 .678 .404 r
.7997 .60283 .8009 .60903 .78689 .41299 .78611 .41152 Mtetra
.863 .728 .712 r
.78611 .41152 .78689 .41299 .78839 .40991 .78763 .40865 Mtetra
.68 .696 .858 r
.78763 .40865 .78839 .40991 .79009 .40916 .78933 .408 Mtetra
.563 .662 .903 r
.78933 .408 .79009 .40916 .79183 .40896 .79108 .4079 Mtetra
.566 .683 .919 r
.79108 .4079 .79183 .40896 .79356 .40871 .79283 .40776 Mtetra
.662 .749 .915 r
.79283 .40776 .79356 .40871 .79527 .4081 .79455 .40722 Mtetra
.672 .771 .925 r
.79455 .40722 .79527 .4081 .79699 .40755 .79626 .40664 Mtetra
.732 .785 .895 r
.79626 .40664 .79699 .40755 .7987 .40699 .79795 .40577 Mtetra
.744 .728 .837 r
.79795 .40577 .7987 .40699 .80043 .40651 .79962 .40472 Mtetra
.653 .614 .798 r
.79962 .40472 .80043 .40651 .80219 .40653 .80134 .40415 Mtetra
.404 .421 .764 r
.80134 .40415 .80219 .40653 .80412 .40836 .8032 .4052 Mtetra
0 0 .232 r
.8032 .4052 .80412 .40836 .8227 .60169 .80568 .41339 Mtetra
.088 .015 .47 r
.80568 .41339 .8227 .60169 .82557 .61296 .82474 .61134 Mtetra
0 .015 .588 r
.82474 .61134 .82557 .61296 .82765 .61523 .82688 .61427 Mtetra
.43 .657 .955 r
.82688 .61427 .82765 .61523 .82956 .61543 .82879 .61446 Mtetra
.726 .784 .899 r
.82879 .61446 .82956 .61543 .83138 .61465 .8306 .61357 Mtetra
.893 .79 .74 r
.8306 .61357 .83138 .61465 .83304 .6121 .83224 .61077 Mtetra
.973 .725 .498 r
.83224 .61077 .83304 .6121 .83402 .60198 .83295 .59758 Mtetra
.975 .678 .384 r
.83295 .59758 .83402 .60198 .81789 .40356 .81711 .40197 Mtetra
.873 .722 .691 r
.81711 .40197 .81789 .40356 .81935 .40005 .81859 .3987 Mtetra
.707 .694 .835 r
.81859 .3987 .81935 .40005 .82105 .39919 .82029 .39785 Mtetra
.596 .648 .872 r
.82029 .39785 .82105 .39919 .8228 .39887 .82205 .39764 Mtetra
.544 .639 .895 r
.82205 .39764 .8228 .39887 .82454 .39846 .82383 .39762 Mtetra
.553 .734 .96 r
.82383 .39762 .82454 .39846 .82624 .39748 .8256 .39744 Mtetra
.175 0 0 r
.8256 .39744 .82624 .39748 .82797 .39695 .82742 .39776 Mtetra
.745 .289 .168 r
.82742 .39776 .82797 .39695 .82984 .39779 .8294 .39974 Mtetra
.974 .668 .358 r
.8294 .39974 .82984 .39779 .83228 .40465 .84965 .59403 Mtetra
.578 .361 .55 r
.84965 .59403 .83228 .40465 .85318 .60409 .85252 .60414 Mtetra
.754 .237 0 r
.85252 .60414 .85318 .60409 .85541 .60745 .85465 .60647 Mtetra
.383 .625 .948 r
.85465 .60647 .85541 .60745 .85735 .60775 .8566 .6068 Mtetra
.672 .771 .925 r
.8566 .6068 .85735 .60775 .85919 .60698 .85845 .60617 Mtetra
.885 .844 .799 r
.85845 .60617 .85919 .60698 .86087 .60457 .86015 .604 Mtetra
.989 .779 .531 r
.86015 .604 .86087 .60457 .86189 .59546 .86128 .59602 Mtetra
.978 .679 .354 r
.86128 .59602 .86189 .59546 .84399 .39573 .84332 .39519 Mtetra
.974 .836 .645 r
.84332 .39519 .84399 .39573 .84541 .39192 .84472 .3911 Mtetra
.743 .813 .907 r
.84472 .3911 .84541 .39192 .84713 .39108 .84643 .39018 Mtetra
.596 .74 .944 r
.84643 .39018 .84713 .39108 .84891 .39084 .8482 .38988 Mtetra
.59 .722 .935 r
.8482 .38988 .84891 .39084 .85069 .39065 .84998 .38961 Mtetra
.74 .765 .874 r
.84998 .38961 .85069 .39065 .85241 .38977 .85168 .38866 Mtetra
.655 .717 .894 r
.85168 .38866 .85241 .38977 .85416 .38927 .85344 .38815 Mtetra
.261 .502 .897 r
.85344 .38815 .85416 .38927 .85603 .38981 .85533 .38892 Mtetra
.907 .522 .093 r
.85533 .38892 .85603 .38981 .85834 .39466 .85798 .3971 Mtetra
.973 .664 .345 r
.85798 .3971 .85834 .39466 .88091 .59387 .88049 .59595 Mtetra
.76 .379 .334 r
.88049 .59595 .88091 .59387 .8833 .59827 .88274 .59908 Mtetra
.354 0 0 r
.88274 .59908 .8833 .59827 .88529 .59881 .88467 .59897 Mtetra
.395 .844 .751 r
.88467 .59897 .88529 .59881 .88721 .59864 .88651 .59813 Mtetra
.788 .915 .925 r
.88651 .59813 .88721 .59864 .8891 .59824 .88832 .59691 Mtetra
.714 .718 .852 r
.88832 .59691 .8891 .59824 .89103 .59814 .89016 .59599 Mtetra
.731 .635 .753 r
.89016 .59599 .89103 .59814 .89291 .59757 .89195 .59454 Mtetra
.779 .614 .676 r
.89195 .59454 .89291 .59757 .89468 .59596 .89357 .59156 Mtetra
.976 .672 .355 r
.89357 .59156 .89468 .59596 .89602 .59047 .87432 .39636 Mtetra
.583 .369 .556 r
.87432 .39636 .89602 .59047 .87603 .3898 .87481 .3841 Mtetra
.707 .515 .627 r
.87481 .3841 .87603 .3898 .87718 .38363 .87629 .38092 Mtetra
.656 .553 .726 r
.87629 .38092 .87718 .38363 .87883 .38205 .87802 .38008 Mtetra
.616 .58 .791 r
.87802 .38008 .87883 .38205 .88056 .38118 .87981 .37975 Mtetra
.601 .638 .86 r
.87981 .37975 .88056 .38118 .88232 .38056 .88162 .37951 Mtetra
.756 .771 .865 r
.88162 .37951 .88232 .38056 .88404 .37958 .88333 .37845 Mtetra
.686 .729 .883 r
.88333 .37845 .88404 .37958 .88581 .37902 .88509 .37777 Mtetra
.461 .594 .898 r
.88509 .37777 .88581 .37902 .88768 .37932 .88695 .37806 Mtetra
.753 .355 0 r
.88695 .37806 .88768 .37932 .88995 .38316 .8894 .38342 Mtetra
.973 .661 .317 r
.8894 .38342 .88995 .38316 .91461 .58257 .91429 .58514 Mtetra
.783 .416 .362 r
.91429 .58514 .91461 .58257 .91724 .58843 .91673 .58933 Mtetra
.384 0 0 r
.91673 .58933 .91724 .58843 .91928 .58911 .91868 .58925 Mtetra
.377 .834 .75 r
.91868 .58925 .91928 .58911 .92123 .589 .92055 .58844 Mtetra
.766 .905 .936 r
.92055 .58844 .92123 .589 .92314 .58851 .92239 .58732 Mtetra
.611 .701 .908 r
.92239 .58732 .92314 .58851 .92505 .58806 .92431 .58698 Mtetra
.623 .729 .922 r
.92431 .58698 .92505 .58806 .92695 .5875 .92623 .58657 Mtetra
.667 .781 .934 r
.92623 .58657 .92695 .5875 .92885 .58689 .92813 .58594 Mtetra
.793 .817 .871 r
.92813 .58594 .92885 .58689 .93076 .58639 .92994 .58461 Mtetra
.763 .683 .774 r
.92994 .58461 .93076 .58639 .93267 .5859 .93172 .58301 Mtetra
.71 .584 .713 r
.93172 .58301 .93267 .5859 .93459 .58542 .9335 .58141 Mtetra
.577 .467 .692 r
.9335 .58141 .93459 .58542 .93655 .58535 .93547 .58137 Mtetra
.598 .481 .691 r
.93547 .58137 .93655 .58535 .93848 .58491 .93741 .58104 Mtetra
.665 .525 .683 r
.93741 .58104 .93848 .58491 .94031 .58373 .93922 .5797 Mtetra
.915 .659 .536 r
.93922 .5797 .94031 .58373 .94168 .57873 .93972 .56761 Mtetra
.972 .663 .353 r
.93972 .56761 .94168 .57873 .91894 .37798 .9176 .3716 Mtetra
.717 .515 .615 r
.9176 .3716 .91894 .37798 .91988 .37049 .91897 .36764 Mtetra
.669 .555 .717 r
.91897 .36764 .91988 .37049 .9216 .36932 .92071 .36661 Mtetra
.622 .534 .734 r
.92071 .36661 .9216 .36932 .92341 .36891 .92251 .36614 Mtetra
.591 .513 .736 r
.92251 .36614 .92341 .36891 .92526 .36879 .92435 .36597 Mtetra
.625 .708 .905 r
.34273 .54731 .34364 .54825 .34509 .54791 .34418 .547 Mtetra
.624 .715 .912 r
.34418 .547 .34509 .54791 .34654 .54757 .34564 .54669 Mtetra
.637 .727 .913 r
.34564 .54669 .34654 .54757 .348 .54719 .34709 .54633 Mtetra
.74 .752 .863 r
.34709 .54633 .348 .54719 .34947 .54656 .34857 .54548 Mtetra
.704 .706 .849 r
.34857 .54548 .34947 .54656 .35094 .54597 .35005 .54479 Mtetra
.63 .665 .865 r
.35005 .54479 .35094 .54597 .3524 .54553 .3515 .54447 Mtetra
0 .215 .728 r
.3515 .54447 .3524 .54553 .35385 .54535 .35289 .5456 Mtetra
.853 .474 .329 r
.35289 .5456 .35385 .54535 .35528 .54562 .35418 .54854 Mtetra
.933 .677 .527 r
.35418 .54854 .35528 .54562 .35666 .54678 .34639 .73243 Mtetra
.578 .363 .552 r
.34639 .73243 .35666 .54678 .35759 .55727 .34747 .74139 Mtetra
.568 .354 .551 r
.34747 .74139 .35759 .55727 .34995 .74238 .34888 .7439 Mtetra
.664 .292 .331 r
.34888 .7439 .34995 .74238 .35133 .7455 .35035 .74502 Mtetra
.22 .662 .952 r
.35035 .74502 .35133 .7455 .35285 .74581 .35188 .7452 Mtetra
.616 .802 .971 r
.35188 .7452 .35285 .74581 .35441 .74537 .35343 .74482 Mtetra
.761 .837 .91 r
.35343 .74482 .35441 .74537 .35599 .74447 .35501 .74389 Mtetra
.868 .804 .786 r
.35501 .74389 .35599 .74447 .35756 .7437 .35665 .74178 Mtetra
.834 .67 .679 r
.35665 .74178 .35756 .7437 .35915 .74253 .35836 .738 Mtetra
.874 .644 .588 r
.35836 .738 .35915 .74253 .36078 .74055 .36066 .72168 Mtetra
.913 .661 .543 r
.36066 .72168 .36078 .74055 .36266 .73311 .37036 .54364 Mtetra
.57 .36 .556 r
.37036 .54364 .36266 .73311 .37276 .54362 .37197 .54021 Mtetra
.711 .554 .673 r
.37197 .54021 .37276 .54362 .37441 .53932 .37352 .53827 Mtetra
.731 .718 .839 r
.37352 .53827 .37441 .53932 .37592 .53812 .37501 .53741 Mtetra
.666 .777 .932 r
.37501 .53741 .37592 .53812 .37739 .53764 .37649 .53693 Mtetra
.621 .764 .948 r
.37649 .53693 .37739 .53764 .37886 .53746 .37796 .53659 Mtetra
.764 .757 .847 r
.37796 .53659 .37886 .53746 .38036 .53652 .37946 .53557 Mtetra
.73 .736 .856 r
.37946 .53557 .38036 .53652 .38185 .53577 .38096 .53475 Mtetra
.598 .685 .903 r
.38096 .53475 .38185 .53577 .38331 .53562 .38243 .53454 Mtetra
.863 .431 .01 r
.38243 .53454 .38331 .53562 .38465 .53864 .38377 .53742 Mtetra
.943 .684 .516 r
.38377 .53742 .38465 .53864 .37823 .72968 .3773 .72828 Mtetra
.958 .63 .348 r
.3773 .72828 .37823 .72968 .37949 .73674 .37853 .73592 Mtetra
0 .121 .597 r
.37853 .73592 .37949 .73674 .38099 .73787 .38004 .73711 Mtetra
.585 .755 .959 r
.38004 .73711 .38099 .73787 .38256 .73759 .3816 .73685 Mtetra
.806 .796 .843 r
.3816 .73685 .38256 .73759 .38417 .73621 .38321 .7355 Mtetra
.915 .75 .663 r
.38321 .7355 .38417 .73621 .38592 .7312 .38497 .73052 Mtetra
.942 .688 .523 r
.38497 .73052 .38592 .7312 .39496 .53774 .39406 .53687 Mtetra
.914 .729 .638 r
.39406 .53687 .39496 .53774 .39665 .53182 .39576 .53091 Mtetra
.807 .753 .802 r
.39576 .53091 .39665 .53182 .39818 .53033 .39729 .52941 Mtetra
.663 .73 .899 r
.39729 .52941 .39818 .53033 .39967 .52985 .39878 .52894 Mtetra
.547 .693 .935 r
.39878 .52894 .39967 .52985 .40114 .52976 .40026 .52886 Mtetra
.675 .736 .897 r
.40026 .52886 .40114 .52976 .40264 .52915 .40175 .52834 Mtetra
.681 .76 .91 r
.40175 .52834 .40264 .52915 .40414 .52856 .40324 .5278 Mtetra
.598 .747 .948 r
.40324 .5278 .40414 .52856 .40562 .52842 .40473 .52753 Mtetra
.138 .488 .902 r
.40473 .52753 .40562 .52842 .40703 .5302 .40618 .52814 Mtetra
.022 .193 .701 r
.40618 .52814 .40703 .5302 .40825 .53769 .4076 .52989 Mtetra
.218 .143 .553 r
.4076 .52989 .40825 .53769 .40325 .72679 .40891 .53486 Mtetra
0 0 .34 r
.40891 .53486 .40325 .72679 .40474 .72922 .40399 .72274 Mtetra
.176 .131 .564 r
.40399 .72274 .40474 .72922 .40628 .72984 .4054 .72721 Mtetra
.185 .261 .709 r
.4054 .72721 .40628 .72984 .40786 .72986 .40692 .72898 Mtetra
.372 .637 .957 r
.40692 .72898 .40786 .72986 .40944 .7296 .40848 .72923 Mtetra
.583 .86 .995 r
.40848 .72923 .40944 .7296 .41102 .72917 .41007 .72881 Mtetra
.687 .889 .972 r
.41007 .72881 .41102 .72917 .41262 .72862 .41167 .72813 Mtetra
.653 .848 .975 r
.41167 .72813 .41262 .72862 .41421 .72816 .41326 .7276 Mtetra
.631 .822 .974 r
.41326 .7276 .41421 .72816 .4158 .72775 .41485 .72715 Mtetra
.634 .813 .969 r
.41485 .72715 .4158 .72775 .41739 .72734 .41644 .7267 Mtetra
.568 .785 .981 r
.41644 .7267 .41739 .72734 .41897 .7272 .41803 .72644 Mtetra
.602 .762 .955 r
.41803 .72644 .41897 .7272 .42056 .72697 .41962 .72613 Mtetra
.687 .765 .911 r
.41962 .72613 .42056 .72697 .42216 .72625 .42122 .72552 Mtetra
.838 .796 .811 r
.42122 .72552 .42216 .72625 .42383 .72346 .42286 .72379 Mtetra
.96 .908 .722 r
.42286 .72379 .42383 .72346 .42566 .71469 .42453 .72066 Mtetra
0 0 .232 r
.42453 .72066 .42566 .71469 .43248 .52458 .42627 .71505 Mtetra
.555 .344 .549 r
.42627 .71505 .43248 .52458 .43405 .52206 .42798 .71044 Mtetra
.564 .352 .55 r
.42798 .71044 .43405 .52206 .43556 .52156 .42954 .71112 Mtetra
.563 .35 .55 r
.42954 .71112 .43556 .52156 .43706 .52147 .43114 .71073 Mtetra
0 0 .35 r
.43114 .71073 .43706 .52147 .43859 .52049 .43753 .52663 Mtetra
0 0 .185 r
.43753 .52663 .43859 .52049 .44012 .51905 .4392 .52007 Mtetra
.921 .954 .621 r
.4392 .52007 .44012 .51905 .44165 .51779 .44078 .51703 Mtetra
.807 .788 .834 r
.44078 .51703 .44165 .51779 .44318 .517 .44231 .5157 Mtetra
.669 .664 .837 r
.44231 .5157 .44318 .517 .44469 .51652 .44383 .51516 Mtetra
.62 .637 .846 r
.44383 .51516 .44469 .51652 .4462 .51613 .44534 .51487 Mtetra
.638 .659 .854 r
.44534 .51487 .4462 .51613 .44772 .5157 .44685 .5145 Mtetra
.66 .677 .855 r
.44685 .5145 .44772 .5157 .44923 .51522 .44837 .51402 Mtetra
.66 .678 .856 r
.44837 .51402 .44923 .51522 .45075 .51474 .44989 .51354 Mtetra
.661 .679 .857 r
.44989 .51354 .45075 .51474 .45227 .51425 .4514 .51306 Mtetra
.661 .68 .857 r
.4514 .51306 .45227 .51425 .45379 .51376 .45292 .51258 Mtetra
.661 .681 .858 r
.45292 .51258 .45379 .51376 .45531 .51328 .45444 .51209 Mtetra
.661 .681 .859 r
.45444 .51209 .45531 .51328 .45683 .51279 .45597 .51161 Mtetra
.661 .682 .859 r
.45597 .51161 .45683 .51279 .45835 .51231 .45749 .51113 Mtetra
.66 .682 .859 r
.45749 .51113 .45835 .51231 .45987 .51183 .45901 .51065 Mtetra
.659 .682 .86 r
.45901 .51065 .45987 .51183 .4614 .51136 .46053 .51018 Mtetra
.659 .681 .86 r
.46053 .51018 .4614 .51136 .46292 .51089 .46206 .50971 Mtetra
.658 .681 .861 r
.46206 .50971 .46292 .51089 .46445 .51042 .46358 .50924 Mtetra
.658 .682 .861 r
.46358 .50924 .46445 .51042 .46597 .50995 .46511 .50878 Mtetra
.657 .682 .862 r
.46511 .50878 .46597 .50995 .4675 .50949 .46664 .50831 Mtetra
.651 .68 .864 r
.46664 .50831 .4675 .50949 .46902 .50904 .46816 .50788 Mtetra
.634 .676 .872 r
.46816 .50788 .46902 .50904 .47055 .50864 .46969 .50752 Mtetra
.617 .677 .885 r
.46969 .50752 .47055 .50864 .47208 .50828 .47122 .50724 Mtetra
.614 .691 .898 r
.47122 .50724 .47208 .50828 .47361 .50792 .47274 .50696 Mtetra
.632 .715 .907 r
.47274 .50696 .47361 .50792 .47514 .50752 .47427 .50661 Mtetra
.654 .734 .908 r
.47427 .50661 .47514 .50752 .47667 .50706 .47581 .50617 Mtetra
.663 .741 .908 r
.47581 .50617 .47667 .50706 .4782 .50657 .47734 .50569 Mtetra
.663 .743 .909 r
.47734 .50569 .4782 .50657 .47974 .50608 .47887 .5052 Mtetra
.664 .746 .911 r
.47887 .5052 .47974 .50608 .48127 .50557 .48041 .50472 Mtetra
.673 .752 .911 r
.48041 .50472 .48127 .50557 .48281 .50505 .48195 .5042 Mtetra
.692 .759 .903 r
.48195 .5042 .48281 .50505 .48435 .50447 .48348 .50359 Mtetra
.707 .756 .89 r
.48348 .50359 .48435 .50447 .48588 .50385 .48502 .50291 Mtetra
.704 .743 .882 r
.48502 .50291 .48588 .50385 .48742 .50323 .48657 .50224 Mtetra
.689 .728 .88 r
.48657 .50224 .48742 .50323 .48896 .50265 .48811 .50163 Mtetra
.672 .717 .883 r
.48811 .50163 .48896 .50265 .4905 .50212 .48965 .50111 Mtetra
.666 .717 .886 r
.48965 .50111 .4905 .50212 .49204 .50161 .49119 .50061 Mtetra
.664 .719 .89 r
.49119 .50061 .49204 .50161 .49359 .50111 .49273 .50012 Mtetra
.665 .722 .891 r
.49273 .50012 .49359 .50111 .49513 .50061 .49427 .49963 Mtetra
.664 .723 .893 r
.49427 .49963 .49513 .50061 .49667 .50012 .49582 .49914 Mtetra
.662 .724 .895 r
.49582 .49914 .49667 .50012 .49821 .49963 .49736 .49866 Mtetra
.661 .725 .897 r
.49736 .49866 .49821 .49963 .49976 .49915 .49891 .49819 Mtetra
.661 .727 .898 r
.49891 .49819 .49976 .49915 .5013 .49866 .50045 .49771 Mtetra
.663 .729 .899 r
.50045 .49771 .5013 .49866 .50285 .49817 .502 .49723 Mtetra
.665 .732 .899 r
.502 .49723 .50285 .49817 .5044 .49767 .50355 .49673 Mtetra
.666 .733 .9 r
.50355 .49673 .5044 .49767 .50595 .49717 .5051 .49624 Mtetra
.687 .74 .892 r
.5051 .49624 .50595 .49717 .5075 .49653 .50665 .49565 Mtetra
.702 .756 .893 r
.50665 .49565 .5075 .49653 .50905 .49578 .5082 .49499 Mtetra
.649 .762 .932 r
.5082 .49499 .50905 .49578 .5106 .49539 .50975 .49455 Mtetra
.365 .63 .955 r
.50975 .49455 .5106 .49539 .51215 .49621 .5113 .49481 Mtetra
0 .153 .695 r
.5113 .49481 .51215 .49621 .51368 .50065 .51284 .49643 Mtetra
.11 .129 .599 r
.51284 .49643 .51368 .50065 .51468 .69332 .51439 .49987 Mtetra
.553 .346 .554 r
.51439 .49987 .51468 .69332 .51631 .69728 .51593 .50609 Mtetra
.567 .357 .556 r
.51593 .50609 .51631 .69728 .51796 .6971 .51749 .50462 Mtetra
.51749 .50462 .51796 .6971 .51962 .69629 .51905 .50318 Mtetra
.014 0 .409 r
.51905 .50318 .51962 .69629 .52127 .69592 .52039 .68238 Mtetra
.16 .082 .512 r
.52039 .68238 .52127 .69592 .52292 .69657 .52203 .69264 Mtetra
.155 .178 .632 r
.52203 .69264 .52292 .69657 .52458 .69708 .52368 .69565 Mtetra
.144 .383 .835 r
.52368 .69565 .52458 .69708 .52623 .6972 .52534 .69673 Mtetra
.504 .814 1 r
.52534 .69673 .52623 .6972 .52789 .69684 .52699 .69649 Mtetra
.635 .888 .986 r
.52699 .69649 .52789 .69684 .52955 .69635 .52865 .69591 Mtetra
.644 .866 .983 r
.52865 .69591 .52955 .69635 .53121 .69598 .53031 .69534 Mtetra
.559 .789 .985 r
.53031 .69534 .53121 .69598 .53287 .69586 .53198 .69508 Mtetra
.655 .781 .941 r
.53198 .69508 .53287 .69586 .53453 .69535 .53364 .69457 Mtetra
.784 .805 .87 r
.53364 .69457 .53453 .69535 .53619 .69368 .5353 .6934 Mtetra
.926 .866 .761 r
.5353 .6934 .53619 .69368 .53784 .68829 .53696 .69073 Mtetra
0 0 0 r
.53696 .69073 .53784 .68829 .53869 .49435 .53861 .68636 Mtetra
.552 .341 .549 r
.53861 .68636 .53869 .49435 .54024 .48899 .54024 .67935 Mtetra
.563 .351 .55 r
.54024 .67935 .54024 .48899 .54181 .48816 .54191 .67931 Mtetra
.564 .351 .55 r
.54191 .67931 .54181 .48816 .54338 .48796 .54357 .67968 Mtetra
.072 0 .426 r
.54357 .67968 .54338 .48796 .54496 .48751 .54425 .51007 Mtetra
0 0 .37 r
.54425 .51007 .54496 .48751 .54652 .48601 .5457 .48827 Mtetra
0 0 0 r
.5457 .48827 .54652 .48601 .54809 .48464 .54726 .48439 Mtetra
.907 .893 .804 r
.54726 .48439 .54809 .48464 .54966 .48359 .54882 .48235 Mtetra
.697 .69 .84 r
.54882 .48235 .54966 .48359 .55123 .48302 .55039 .48164 Mtetra
.637 .646 .842 r
.55039 .48164 .55123 .48302 .55281 .48259 .55197 .48126 Mtetra
.619 .646 .854 r
.55197 .48126 .55281 .48259 .55438 .48218 .55355 .48096 Mtetra
.658 .679 .858 r
.55355 .48096 .55438 .48218 .55596 .4817 .55512 .48047 Mtetra
.657 .679 .859 r
.55512 .48047 .55596 .4817 .55754 .48121 .5567 .47999 Mtetra
.658 .68 .86 r
.5567 .47999 .55754 .48121 .55912 .48072 .55828 .47951 Mtetra
.659 .682 .86 r
.55828 .47951 .55912 .48072 .56069 .48023 .55986 .47902 Mtetra
.66 .683 .861 r
.55986 .47902 .56069 .48023 .56228 .47973 .56144 .47853 Mtetra
.56144 .47853 .56228 .47973 .56386 .47924 .56302 .47803 Mtetra
.56302 .47803 .56386 .47924 .56544 .47874 .5646 .47754 Mtetra
.66 .684 .861 r
.5646 .47754 .56544 .47874 .56702 .47824 .56619 .47704 Mtetra
.56619 .47704 .56702 .47824 .56861 .47775 .56777 .47654 Mtetra
.661 .684 .861 r
.56777 .47654 .56861 .47775 .57019 .47725 .56936 .47604 Mtetra
.56936 .47604 .57019 .47725 .57178 .47675 .57094 .47555 Mtetra
.57094 .47555 .57178 .47675 .57336 .47625 .57253 .47505 Mtetra
.57253 .47505 .57336 .47625 .57495 .47575 .57412 .47455 Mtetra
.57412 .47455 .57495 .47575 .57654 .47526 .57571 .47405 Mtetra
.57571 .47405 .57654 .47526 .57813 .47476 .5773 .47355 Mtetra
.5773 .47355 .57813 .47476 .57972 .47426 .57889 .47304 Mtetra
.661 .684 .86 r
.57889 .47304 .57972 .47426 .58131 .47375 .58048 .47254 Mtetra
.662 .684 .86 r
.58048 .47254 .58131 .47375 .5829 .47325 .58207 .47203 Mtetra
.663 .684 .859 r
.58207 .47203 .5829 .47325 .58449 .47274 .58367 .47152 Mtetra
.663 .682 .858 r
.58367 .47152 .58449 .47274 .58609 .47223 .58526 .471 Mtetra
.667 .683 .855 r
.58526 .471 .58609 .47223 .58768 .47171 .58685 .47046 Mtetra
.699 .692 .84 r
.58685 .47046 .58768 .47171 .58928 .4711 .58845 .46973 Mtetra
.66 .658 .837 r
.58845 .46973 .58928 .4711 .59087 .47058 .59004 .46921 Mtetra
.563 .615 .863 r
.59004 .46921 .59087 .47058 .59247 .47025 .59165 .46916 Mtetra
0 .089 .628 r
.59165 .46916 .59247 .47025 .59409 .47048 .59329 .47083 Mtetra
.877 .486 .292 r
.59329 .47083 .59409 .47048 .59571 .47092 .59499 .47484 Mtetra
.958 .677 .463 r
.59499 .47484 .59571 .47092 .59733 .47133 .60069 .66277 Mtetra
.564 .351 .55 r
.60069 .66277 .59733 .47133 .59892 .47042 .60241 .66325 Mtetra
.561 .349 .55 r
.60241 .66325 .59892 .47042 .60052 .46978 .60409 .6617 Mtetra
.565 .352 .55 r
.60409 .6617 .60052 .46978 .60215 .47013 .60582 .66255 Mtetra
.573 .358 .551 r
.60582 .66255 .60215 .47013 .6041 .48402 .60768 .66889 Mtetra
.568 .354 .55 r
.60768 .66889 .6041 .48402 .61028 .67056 .60947 .6716 Mtetra
.686 .259 .229 r
.60947 .6716 .61028 .67056 .61208 .67358 .61122 .67295 Mtetra
.388 .716 .988 r
.61122 .67295 .61208 .67358 .6138 .67369 .61294 .67301 Mtetra
.638 .809 .965 r
.61294 .67301 .6138 .67369 .61551 .67314 .61466 .67253 Mtetra
.778 .854 .907 r
.61466 .67253 .61551 .67314 .61721 .67212 .61635 .67143 Mtetra
.905 .815 .748 r
.61635 .67143 .61721 .67212 .6189 .67084 .61801 .66868 Mtetra
.866 .68 .648 r
.61801 .66868 .6189 .67084 .62059 .66931 .6196 .6637 Mtetra
.96 .684 .468 r
.6196 .6637 .62059 .66931 .62227 .6677 .6161 .47473 Mtetra
.567 .358 .556 r
.6161 .47473 .62227 .6677 .62399 .66764 .61767 .47271 Mtetra
.562 .354 .555 r
.61767 .47271 .62399 .66764 .62572 .66734 .61933 .47361 Mtetra
.566 .356 .556 r
.61933 .47361 .62572 .66734 .62741 .66618 .62094 .47267 Mtetra
.578 .366 .557 r
.62094 .47267 .62741 .66618 .62883 .65556 .62233 .46429 Mtetra
.57 .36 .556 r
.62233 .46429 .62883 .65556 .62472 .46353 .62386 .46069 Mtetra
.746 .593 .686 r
.62386 .46069 .62472 .46353 .62623 .45959 .62542 .45846 Mtetra
.695 .714 .864 r
.62542 .45846 .62623 .45959 .62784 .45865 .62704 .45778 Mtetra
.612 .741 .937 r
.62704 .45778 .62784 .45865 .62946 .45829 .62866 .45746 Mtetra
.561 .729 .953 r
.62866 .45746 .62946 .45829 .6311 .45821 .63029 .45728 Mtetra
.734 .763 .876 r
.63029 .45728 .6311 .45821 .63271 .45756 .6319 .45641 Mtetra
.703 .713 .857 r
.6319 .45641 .63271 .45756 .63433 .45694 .63352 .45568 Mtetra
.632 .667 .866 r
.63352 .45568 .63433 .45694 .63595 .45646 .63514 .45531 Mtetra
.076 .378 .842 r
.63514 .45531 .63595 .45646 .63759 .45622 .63682 .45636 Mtetra
.841 .398 .169 r
.63682 .45636 .63759 .45622 .63924 .45643 .63856 .45919 Mtetra
.963 .678 .445 r
.63856 .45919 .63924 .45643 .64092 .4575 .64679 .6464 Mtetra
.58 .364 .551 r
.64679 .6464 .64092 .4575 .64287 .46601 .64892 .65743 Mtetra
.567 .354 .55 r
.64892 .65743 .64287 .46601 .65152 .65838 .65077 .66009 Mtetra
.648 .264 .303 r
.65077 .66009 .65152 .65838 .65339 .66175 .65256 .66124 Mtetra
.428 .773 .997 r
.65256 .66124 .65339 .66175 .65515 .66196 .65431 .66114 Mtetra
.66 .783 .94 r
.65431 .66114 .65515 .66196 .65689 .66139 .65605 .6606 Mtetra
.709 .804 .924 r
.65605 .6606 .65689 .66139 .65861 .66046 .65777 .65984 Mtetra
.649 .831 .97 r
.65777 .65984 .65861 .66046 .66034 .65987 .65951 .65929 Mtetra
.633 .838 .979 r
.65951 .65929 .66034 .65987 .66208 .65933 .66125 .65877 Mtetra
.626 .843 .983 r
.66125 .65877 .66208 .65933 .66382 .6588 .66299 .65826 Mtetra
.615 .845 .987 r
.66299 .65826 .66382 .6588 .66556 .6583 .66473 .65778 Mtetra
.608 .845 .989 r
.66473 .65778 .66556 .6583 .6673 .65783 .66648 .6573 Mtetra
.604 .842 .989 r
.66648 .6573 .6673 .65783 .66905 .65739 .66822 .65684 Mtetra
.598 .837 .99 r
.66822 .65684 .66905 .65739 .67079 .65697 .66997 .6564 Mtetra
.599 .831 .988 r
.66997 .6564 .67079 .65697 .67254 .65656 .67172 .65597 Mtetra
.603 .825 .985 r
.67172 .65597 .67254 .65656 .67429 .65616 .67347 .65554 Mtetra
.526 .789 .993 r
.67347 .65554 .67429 .65616 .67606 .65609 .67523 .65531 Mtetra
.6 .774 .963 r
.67523 .65531 .67606 .65609 .67782 .65581 .67699 .65496 Mtetra
.694 .786 .922 r
.67699 .65496 .67782 .65581 .67955 .65499 .67873 .65427 Mtetra
.851 .837 .831 r
.67873 .65427 .67955 .65499 .68118 .65174 .68042 .65252 Mtetra
.874 .944 .58 r
.68042 .65252 .68118 .65174 .68247 .64102 .68206 .64949 Mtetra
.194 .019 .401 r
.68206 .64949 .68247 .64102 .67536 .44798 .68353 .64287 Mtetra
.056 0 .437 r
.68353 .64287 .67536 .44798 .67689 .44506 .67635 .44933 Mtetra
0 0 .23 r
.67635 .44933 .67689 .44506 .6785 .44365 .67779 .44433 Mtetra
.825 .947 .592 r
.67779 .44433 .6785 .44365 .68013 .44277 .67935 .44184 Mtetra
.748 .773 .873 r
.67935 .44184 .68013 .44277 .68178 .44219 .68097 .44088 Mtetra
.626 .659 .863 r
.68097 .44088 .68178 .44219 .68343 .4418 .68263 .44054 Mtetra
.567 .641 .884 r
.68263 .44054 .68343 .4418 .68509 .4415 .68431 .44045 Mtetra
.622 .706 .906 r
.68431 .44045 .68509 .4415 .68675 .44106 .68597 .44011 Mtetra
.655 .742 .913 r
.68597 .44011 .68675 .44106 .6884 .44053 .68762 .43963 Mtetra
.67 .756 .915 r
.68762 .43963 .6884 .44053 .69005 .43997 .68928 .43908 Mtetra
.735 .778 .888 r
.68928 .43908 .69005 .43997 .69169 .43904 .69092 .43821 Mtetra
.729 .792 .902 r
.69092 .43821 .69169 .43904 .69333 .43823 .69256 .43739 Mtetra
.659 .768 .93 r
.69256 .43739 .69333 .43823 .695 .43791 .69421 .43688 Mtetra
.324 .561 .922 r
.69421 .43688 .695 .43791 .69678 .43968 .69593 .43738 Mtetra
.205 .297 .738 r
.69593 .43738 .69678 .43968 .69893 .44851 .69771 .43917 Mtetra
.318 .219 .583 r
.69771 .43917 .69893 .44851 .71101 .64183 .6997 .44472 Mtetra
.078 0 .454 r
.6997 .44472 .71101 .64183 .71294 .6442 .71181 .63763 Mtetra
.285 .222 .609 r
.71181 .63763 .71294 .6442 .71477 .64477 .71384 .64194 Mtetra
.303 .335 .729 r
.71384 .64194 .71477 .64477 .71657 .64475 .71574 .64369 Mtetra
.367 .594 .933 r
.71574 .64369 .71657 .64475 .71837 .64474 .71756 .64409 Mtetra
.573 .803 .986 r
.71756 .64409 .71837 .64474 .72016 .64446 .71935 .64375 Mtetra
.734 .837 .929 r
.71935 .64375 .72016 .64446 .72191 .64359 .72111 .64287 Mtetra
.846 .843 .841 r
.72111 .64287 .72191 .64359 .72356 .64078 .72282 .64118 Mtetra
.923 .968 .673 r
.72282 .64118 .72356 .64078 .72491 .63292 .72446 .63836 Mtetra
.045 0 .309 r
.72446 .63836 .72491 .63292 .71524 .43644 .72594 .63273 Mtetra
.078 0 .449 r
.72594 .63273 .71524 .43644 .71673 .43282 .71633 .43818 Mtetra
0 0 .298 r
.71633 .43818 .71673 .43282 .71834 .43126 .71768 .43222 Mtetra
.721 .861 .441 r
.71768 .43222 .71834 .43126 .71998 .43029 .71922 .42948 Mtetra
.801 .813 .861 r
.71922 .42948 .71998 .43029 .72164 .42959 .72085 .4282 Mtetra
.664 .665 .841 r
.72085 .4282 .72164 .42959 .72332 .42907 .72252 .42764 Mtetra
.612 .635 .849 r
.72252 .42764 .72332 .42907 .725 .42868 .72421 .42736 Mtetra
.612 .653 .867 r
.72421 .42736 .725 .42868 .72668 .42827 .7259 .42708 Mtetra
.622 .68 .884 r
.7259 .42708 .72668 .42827 .72836 .42783 .72759 .42674 Mtetra
.628 .704 .9 r
.72759 .42674 .72836 .42783 .73005 .42736 .72928 .42637 Mtetra
.704 .753 .89 r
.72928 .42637 .73005 .42736 .73171 .42653 .73095 .42565 Mtetra
.728 .782 .896 r
.73095 .42565 .73171 .42653 .73336 .42568 .73261 .42481 Mtetra
.671 .769 .924 r
.73261 .42481 .73336 .42568 .73505 .42528 .73429 .42425 Mtetra
.403 .607 .931 r
.73429 .42425 .73505 .42528 .73686 .42663 .73602 .42457 Mtetra
.216 .328 .764 r
.73602 .42457 .73686 .42663 .739 .43315 .73785 .42617 Mtetra
.292 .22 .602 r
.73785 .42617 .739 .43315 .75372 .62918 .73987 .43076 Mtetra
.099 .017 .466 r
.73987 .43076 .75372 .62918 .75575 .6322 .75451 .62472 Mtetra
.286 .216 .6 r
.75451 .62472 .75575 .6322 .75763 .63288 .75668 .62973 Mtetra
.313 .326 .713 r
.75668 .62973 .75763 .63288 .75947 .63292 .75864 .63167 Mtetra
.303 .516 .896 r
.75864 .63167 .75947 .63292 .7613 .63295 .76053 .63238 Mtetra
.46 .774 .997 r
.76053 .63238 .7613 .63295 .76313 .6328 .76236 .63225 Mtetra
.738 .882 .946 r
.76236 .63225 .76313 .6328 .76491 .63199 .76413 .63132 Mtetra
.934 .833 .722 r
.76413 .63132 .76491 .63199 .76654 .62894 .76575 .62813 Mtetra
.978 .722 .474 r
.76575 .62813 .76654 .62894 .76725 .61296 .7663 .6097 Mtetra
.974 .683 .41 r
.7663 .6097 .76725 .61296 .75545 .42108 .75467 .41981 Mtetra
.865 .747 .732 r
.75467 .41981 .75545 .42108 .75699 .41842 .75622 .41723 Mtetra
.666 .699 .871 r
.75622 .41723 .75699 .41842 .75868 .4178 .75791 .41667 Mtetra
.534 .653 .912 r
.75791 .41667 .75868 .4178 .7604 .4177 .75965 .41666 Mtetra
.569 .689 .922 r
.75965 .41666 .7604 .4177 .76212 .41747 .76137 .4165 Mtetra
.665 .746 .911 r
.76137 .4165 .76212 .41747 .76382 .4169 .76307 .41596 Mtetra
.679 .759 .911 r
.76307 .41596 .76382 .4169 .76551 .41629 .76476 .41536 Mtetra
.75 .782 .879 r
.76476 .41536 .76551 .41629 .76718 .41535 .76643 .41439 Mtetra
.763 .777 .865 r
.76643 .41439 .76718 .41535 .76884 .41434 .76809 .41331 Mtetra
.667 .733 .899 r
.76809 .41331 .76884 .41434 .77055 .41385 .76979 .41276 Mtetra
0 .298 .794 r
.76979 .41276 .77055 .41385 .7724 .41528 .77164 .41413 Mtetra
.945 .59 .202 r
.77164 .41413 .7724 .41528 .77506 .4272 .77423 .42509 Mtetra
.976 .677 .373 r
.77423 .42509 .77506 .4272 .79185 .62112 .79106 .62017 Mtetra
.547 .08 0 r
.79106 .62017 .79185 .62112 .7939 .62358 .79312 .62267 Mtetra
.46 .683 .962 r
.79312 .62267 .7939 .62358 .79577 .62367 .79499 .62275 Mtetra
.746 .797 .894 r
.79499 .62275 .79577 .62367 .79756 .6227 .79678 .62176 Mtetra
.916 .802 .72 r
.79678 .62176 .79756 .6227 .79918 .61964 .79839 .61859 Mtetra
.977 .683 .39 r
.79839 .61859 .79918 .61964 .7997 .60283 .78538 .43271 Mtetra
.604 .385 .557 r
.78538 .43271 .7997 .60283 .78611 .41152 .78534 .41018 Mtetra
.869 .743 .722 r
.78534 .41018 .78611 .41152 .78763 .40865 .78687 .40743 Mtetra
.669 .698 .869 r
.78687 .40743 .78763 .40865 .78933 .408 .78858 .40686 Mtetra
.541 .654 .908 r
.78858 .40686 .78933 .408 .79108 .4079 .79033 .40682 Mtetra
.546 .673 .921 r
.79033 .40682 .79108 .4079 .79283 .40776 .79209 .40675 Mtetra
.655 .736 .909 r
.79209 .40675 .79283 .40776 .79455 .40722 .79381 .40625 Mtetra
.671 .75 .91 r
.79381 .40625 .79455 .40722 .79626 .40664 .79552 .40568 Mtetra
.735 .773 .883 r
.79552 .40568 .79626 .40664 .79795 .40577 .79721 .40478 Mtetra
.767 .775 .86 r
.79721 .40478 .79795 .40577 .79962 .40472 .79888 .40366 Mtetra
.681 .735 .891 r
.79888 .40366 .79962 .40472 .80134 .40415 .80059 .40303 Mtetra
.154 .434 .87 r
.80059 .40303 .80134 .40415 .8032 .4052 .80245 .40402 Mtetra
.902 .523 .079 r
.80245 .40402 .8032 .4052 .80568 .41339 .80488 .41172 Mtetra
.976 .673 .358 r
.80488 .41172 .80568 .41339 .82474 .61134 .82396 .61032 Mtetra
.606 .153 0 r
.82396 .61032 .82474 .61134 .82688 .61427 .82611 .61333 Mtetra
.431 .659 .956 r
.82611 .61333 .82688 .61427 .82879 .61446 .82802 .61351 Mtetra
.732 .789 .898 r
.82802 .61351 .82879 .61446 .8306 .61357 .82983 .61258 Mtetra
.906 .804 .735 r
.82983 .61258 .8306 .61357 .83224 .61077 .83146 .60966 Mtetra
.979 .718 .462 r
.83146 .60966 .83224 .61077 .83295 .59758 .83175 .59181 Mtetra
.974 .676 .388 r
.83175 .59181 .83295 .59758 .81711 .40197 .81634 .40053 Mtetra
.881 .738 .699 r
.81634 .40053 .81711 .40197 .81859 .3987 .81783 .39737 Mtetra
.712 .701 .838 r
.81783 .39737 .81859 .3987 .82029 .39785 .81953 .3965 Mtetra
.578 .636 .872 r
.81953 .3965 .82029 .39785 .82205 .39764 .8213 .39637 Mtetra
.372 .539 .891 r
.8213 .39637 .82205 .39764 .82383 .39762 .82314 .39694 Mtetra
0 .142 .631 r
.82314 .39694 .82383 .39762 .8256 .39744 .82507 .39848 Mtetra
.843 .436 .27 r
.82507 .39848 .8256 .39744 .82742 .39776 .82723 .40249 Mtetra
.972 .665 .369 r
.82723 .40249 .82742 .39776 .8294 .39974 .84733 .59663 Mtetra
.571 .356 .55 r
.84733 .59663 .8294 .39974 .84965 .59403 .84979 .60244 Mtetra
.619 .349 .488 r
.84979 .60244 .84965 .59403 .85252 .60414 .85189 .60453 Mtetra
.574 .026 0 r
.85189 .60453 .85252 .60414 .85465 .60647 .85389 .60549 Mtetra
.397 .632 .949 r
.85389 .60549 .85465 .60647 .8566 .6068 .85584 .60578 Mtetra
.639 .744 .925 r
.85584 .60578 .8566 .6068 .85845 .60617 .8577 .6053 Mtetra
.865 .833 .814 r
.8577 .6053 .85845 .60617 .86015 .604 .85943 .60333 Mtetra
.985 .78 .545 r
.85943 .60333 .86015 .604 .86128 .59602 .8606 .59581 Mtetra
.978 .678 .356 r
.8606 .59581 .86128 .59602 .84332 .39519 .84262 .39437 Mtetra
.959 .804 .646 r
.84262 .39437 .84332 .39519 .84472 .3911 .844 .39012 Mtetra
.74 .776 .882 r
.844 .39012 .84472 .3911 .84643 .39018 .84571 .38917 Mtetra
.605 .719 .925 r
.84571 .38917 .84643 .39018 .8482 .38988 .84748 .38886 Mtetra
.596 .713 .925 r
.84748 .38886 .8482 .38988 .84998 .38961 .84926 .38859 Mtetra
.744 .769 .873 r
.84926 .38859 .84998 .38961 .85168 .38866 .85097 .38761 Mtetra
.658 .732 .904 r
.85097 .38761 .85168 .38866 .85344 .38815 .85272 .38708 Mtetra
.241 .502 .901 r
.85272 .38708 .85344 .38815 .85533 .38892 .85461 .38785 Mtetra
.902 .522 .078 r
.85461 .38785 .85533 .38892 .85798 .3971 .8573 .39634 Mtetra
.974 .666 .332 r
.8573 .39634 .85798 .3971 .88049 .59595 .87976 .59519 Mtetra
.67 .191 0 r
.87976 .59519 .88049 .59595 .88274 .59908 .88202 .59829 Mtetra
.475 .727 .98 r
.88202 .59829 .88274 .59908 .88467 .59897 .88395 .59825 Mtetra
.729 .85 .938 r
.88395 .59825 .88467 .59897 .88651 .59813 .88579 .59735 Mtetra
.849 .856 .847 r
.88579 .59735 .88651 .59813 .88832 .59691 .88755 .59564 Mtetra
.88 .771 .737 r
.88755 .59564 .88832 .59691 .89016 .59599 .88919 .59287 Mtetra
.851 .648 .627 r
.88919 .59287 .89016 .59599 .89195 .59454 .89056 .58753 Mtetra
.974 .671 .364 r
.89056 .58753 .89195 .59454 .89357 .59156 .87134 .39122 Mtetra
.574 .363 .556 r
.87134 .39122 .89357 .59156 .87432 .39636 .87243 .38444 Mtetra
.636 .435 .594 r
.87243 .38444 .87432 .39636 .87481 .3841 .87393 .38147 Mtetra
.728 .597 .71 r
.87393 .38147 .87481 .3841 .87629 .38092 .87557 .37975 Mtetra
.676 .717 .88 r
.87557 .37975 .87629 .38092 .87802 .38008 .87733 .37913 Mtetra
.602 .732 .936 r
.87733 .37913 .87802 .38008 .87981 .37975 .87912 .37881 Mtetra
.608 .738 .937 r
.87912 .37881 .87981 .37975 .88162 .37951 .88091 .37847 Mtetra
.769 .776 .859 r
.88091 .37847 .88162 .37951 .88333 .37845 .88262 .37732 Mtetra
.702 .736 .877 r
.88262 .37732 .88333 .37845 .88509 .37777 .88437 .37655 Mtetra
.481 .612 .904 r
.88437 .37655 .88509 .37777 .88695 .37806 .88622 .37676 Mtetra
.728 .332 0 r
.88622 .37676 .88695 .37806 .8894 .38342 .88864 .38191 Mtetra
.973 .661 .31 r
.88864 .38191 .8894 .38342 .91429 .58514 .91356 .58415 Mtetra
.724 .287 0 r
.91356 .58415 .91429 .58514 .91673 .58933 .91601 .58848 Mtetra
.515 .732 .972 r
.91601 .58848 .91673 .58933 .91868 .58925 .91796 .58836 Mtetra
.719 .809 .92 r
.91796 .58836 .91868 .58925 .92055 .58844 .91983 .58749 Mtetra
.765 .811 .89 r
.91983 .58749 .92055 .58844 .92239 .58732 .92166 .58636 Mtetra
.527 .709 .954 r
.92166 .58636 .92239 .58732 .92431 .58698 .92362 .58627 Mtetra
.556 .79 .986 r
.92362 .58627 .92431 .58698 .92623 .58657 .92555 .58596 Mtetra
.704 .879 .962 r
.92555 .58596 .92623 .58657 .92813 .58594 .92742 .58512 Mtetra
.93 .845 .738 r
.92742 .58512 .92813 .58594 .92994 .58461 .92905 .58219 Mtetra
.891 .689 .624 r
.92905 .58219 .92994 .58461 .93172 .58301 .93037 .57675 Mtetra
.974 .667 .342 r
.93037 .57675 .93172 .58301 .9335 .58141 .90905 .38245 Mtetra
.566 .357 .556 r
.90905 .38245 .9335 .58141 .93547 .58137 .91075 .38108 Mtetra
.562 .354 .556 r
.91075 .38108 .93547 .58137 .93741 .58104 .91276 .38232 Mtetra
.566 .357 .556 r
.91276 .38232 .93741 .58104 .93922 .5797 .91445 .38087 Mtetra
.577 .364 .555 r
.91445 .38087 .93922 .5797 .93972 .56761 .91529 .37248 Mtetra
.57 .359 .556 r
.91529 .37248 .93972 .56761 .9176 .3716 .9167 .36878 Mtetra
.756 .604 .689 r
.9167 .36878 .9176 .3716 .91897 .36764 .91827 .36648 Mtetra
.715 .737 .869 r
.91827 .36648 .91897 .36764 .92071 .36661 .92003 .36563 Mtetra
.649 .748 .922 r
.92003 .36563 .92071 .36661 .92251 .36614 .92183 .36513 Mtetra
.6 .719 .928 r
.92183 .36513 .92251 .36614 .92435 .36597 .92366 .36482 Mtetra
.636 .828 .974 r
.3418 .54681 .34273 .54731 .34418 .547 .34326 .54638 Mtetra
.65 .797 .953 r
.34326 .54638 .34418 .547 .34564 .54669 .34472 .54594 Mtetra
.66 .766 .928 r
.34472 .54594 .34564 .54669 .34709 .54633 .34618 .54549 Mtetra
.749 .759 .86 r
.34618 .54549 .34709 .54633 .34857 .54548 .34767 .54459 Mtetra
.698 .739 .882 r
.34767 .54459 .34857 .54548 .35005 .54479 .34914 .54397 Mtetra
.521 .702 .952 r
.34914 .54397 .35005 .54479 .3515 .54447 .35058 .54392 Mtetra
.895 .483 .207 r
.35058 .54392 .3515 .54447 .35289 .5456 .35187 .5469 Mtetra
.935 .679 .526 r
.35187 .5469 .35289 .5456 .35418 .54854 .34373 .73512 Mtetra
.577 .362 .552 r
.34373 .73512 .35418 .54854 .34639 .73243 .34485 .74318 Mtetra
.588 .341 .511 r
.34485 .74318 .34639 .73243 .34747 .74139 .34632 .74424 Mtetra
.542 .22 .372 r
.34632 .74424 .34747 .74139 .34888 .7439 .34785 .74435 Mtetra
.052 0 0 r
.34785 .74435 .34888 .7439 .35035 .74502 .3494 .74403 Mtetra
.503 .668 .937 r
.3494 .74403 .35035 .74502 .35188 .7452 .35093 .74406 Mtetra
.629 .685 .884 r
.35093 .74406 .35188 .7452 .35343 .74482 .35248 .74373 Mtetra
.74 .723 .836 r
.35248 .74373 .35343 .74482 .35501 .74389 .35407 .74275 Mtetra
.875 .723 .69 r
.35407 .74275 .35501 .74389 .35665 .74178 .35579 .7389 Mtetra
.936 .684 .532 r
.35579 .7389 .35665 .74178 .35836 .738 .36611 .55218 Mtetra
.585 .373 .559 r
.36611 .55218 .35836 .738 .36066 .72168 .36811 .5406 Mtetra
.568 .358 .556 r
.36811 .5406 .36066 .72168 .37036 .54364 .36965 .53866 Mtetra
.629 .471 .649 r
.36965 .53866 .37036 .54364 .37197 .54021 .37115 .53774 Mtetra
.636 .542 .731 r
.37115 .53774 .37197 .54021 .37352 .53827 .37263 .53723 Mtetra
.681 .707 .868 r
.37263 .53723 .37352 .53827 .37501 .53741 .37411 .53667 Mtetra
.67 .773 .927 r
.37411 .53667 .37501 .53741 .37649 .53693 .37559 .53618 Mtetra
.659 .768 .93 r
.37559 .53618 .37649 .53693 .37796 .53659 .37706 .53573 Mtetra
.754 .758 .855 r
.37706 .53573 .37796 .53659 .37946 .53557 .37856 .53478 Mtetra
.721 .769 .891 r
.37856 .53478 .37946 .53557 .38096 .53475 .38005 .53405 Mtetra
.529 .743 .973 r
.38005 .53405 .38096 .53475 .38243 .53454 .38152 .53393 Mtetra
.895 .479 .183 r
.38152 .53393 .38243 .53454 .38377 .53742 .38285 .53698 Mtetra
.941 .683 .517 r
.38285 .53698 .38377 .53742 .3773 .72828 .37632 .72816 Mtetra
.92 .594 .409 r
.37632 .72816 .3773 .72828 .37853 .73592 .37758 .73515 Mtetra
0 .121 .585 r
.37758 .73515 .37853 .73592 .38004 .73711 .37908 .73631 Mtetra
.584 .744 .952 r
.37908 .73631 .38004 .73711 .3816 .73685 .38065 .73606 Mtetra
.796 .785 .843 r
.38065 .73606 .3816 .73685 .38321 .7355 .38226 .73477 Mtetra
.911 .752 .671 r
.38226 .73477 .38321 .7355 .38497 .73052 .384 .73011 Mtetra
.943 .688 .523 r
.384 .73011 .38497 .73052 .39406 .53687 .39313 .53698 Mtetra
.957 .78 .621 r
.39313 .53698 .39406 .53687 .39576 .53091 .39486 .53046 Mtetra
.849 .843 .838 r
.39486 .53046 .39576 .53091 .39729 .52941 .39639 .52893 Mtetra
.639 .836 .976 r
.39639 .52893 .39729 .52941 .39878 .52894 .39788 .52847 Mtetra
.422 .764 .996 r
.39788 .52847 .39878 .52894 .40026 .52886 .39935 .52841 Mtetra
.611 .841 .987 r
.39935 .52841 .40026 .52886 .40175 .52834 .40084 .52801 Mtetra
.629 .877 .988 r
.40084 .52801 .40175 .52834 .40324 .5278 .40233 .52751 Mtetra
.567 .872 .995 r
.40233 .52751 .40324 .5278 .40473 .52753 .40382 .52711 Mtetra
.607 .846 .989 r
.40382 .52711 .40473 .52753 .40618 .52814 .40532 .5267 Mtetra
.588 .61 .841 r
.40532 .5267 .40618 .52814 .4076 .52989 .4068 .52657 Mtetra
.515 .431 .699 r
.4068 .52657 .4076 .52989 .40891 .53486 .40826 .52708 Mtetra
.293 .198 .573 r
.40826 .52708 .40891 .53486 .40399 .72274 .4096 .53128 Mtetra
0 0 .33 r
.4096 .53128 .40399 .72274 .4054 .72721 .40458 .72278 Mtetra
0 0 .463 r
.40458 .72278 .4054 .72721 .40692 .72898 .40599 .72752 Mtetra
.288 .462 .859 r
.40599 .72752 .40692 .72898 .40848 .72923 .40754 .72827 Mtetra
.64 .727 .912 r
.40754 .72827 .40848 .72923 .41007 .72881 .40913 .72787 Mtetra
.723 .751 .875 r
.40913 .72787 .41007 .72881 .41167 .72813 .41073 .72706 Mtetra
.681 .718 .876 r
.41073 .72706 .41167 .72813 .41326 .7276 .41233 .72647 Mtetra
.654 .699 .879 r
.41233 .72647 .41326 .7276 .41485 .72715 .41392 .72601 Mtetra
.653 .696 .878 r
.41392 .72601 .41485 .72715 .41644 .7267 .41552 .72555 Mtetra
.638 .69 .882 r
.41552 .72555 .41644 .7267 .41803 .72644 .41711 .72516 Mtetra
.639 .669 .863 r
.41711 .72516 .41803 .72644 .41962 .72613 .4187 .72477 Mtetra
.655 .662 .845 r
.4187 .72477 .41962 .72613 .42122 .72552 .4203 .72429 Mtetra
.709 .698 .838 r
.4203 .72429 .42122 .72552 .42286 .72379 .42191 .72349 Mtetra
.775 .909 .932 r
.42191 .72349 .42286 .72379 .42453 .72066 .42352 .72247 Mtetra
.217 0 .106 r
.42352 .72247 .42453 .72066 .42627 .71505 .42514 .7214 Mtetra
.532 .269 .462 r
.42514 .7214 .42627 .71505 .42798 .71044 .42673 .72107 Mtetra
.551 .308 .501 r
.42673 .72107 .42798 .71044 .42954 .71112 .42832 .72093 Mtetra
.528 .286 .491 r
.42832 .72093 .42954 .71112 .43114 .71073 .42993 .72017 Mtetra
.357 .139 .44 r
.42993 .72017 .43114 .71073 .43753 .52663 .43163 .71606 Mtetra
0 0 .328 r
.43163 .71606 .43753 .52663 .4392 .52007 .43821 .52337 Mtetra
.828 .798 .303 r
.43821 .52337 .4392 .52007 .44078 .51703 .43988 .51683 Mtetra
.895 .887 .816 r
.43988 .51683 .44078 .51703 .44231 .5157 .44143 .51493 Mtetra
.691 .775 .915 r
.44143 .51493 .44231 .5157 .44383 .51516 .44295 .51434 Mtetra
.577 .729 .946 r
.44295 .51434 .44383 .51516 .44534 .51487 .44446 .51414 Mtetra
.611 .764 .953 r
.44446 .51414 .44534 .51487 .44685 .5145 .44597 .51383 Mtetra
.657 .792 .946 r
.44597 .51383 .44685 .5145 .44837 .51402 .44749 .51335 Mtetra
.656 .793 .948 r
.44749 .51335 .44837 .51402 .44989 .51354 .44901 .51289 Mtetra
.658 .796 .948 r
.44901 .51289 .44989 .51354 .4514 .51306 .45053 .51241 Mtetra
.66 .797 .948 r
.45053 .51241 .4514 .51306 .45292 .51258 .45205 .51192 Mtetra
.66 .798 .949 r
.45205 .51192 .45292 .51258 .45444 .51209 .45357 .51144 Mtetra
.659 .798 .949 r
.45357 .51144 .45444 .51209 .45597 .51161 .45509 .51096 Mtetra
.658 .797 .949 r
.45509 .51096 .45597 .51161 .45749 .51113 .45661 .51048 Mtetra
.657 .797 .949 r
.45661 .51048 .45749 .51113 .45901 .51065 .45814 .51 Mtetra
.656 .797 .95 r
.45814 .51 .45901 .51065 .46053 .51018 .45966 .50952 Mtetra
.654 .797 .951 r
.45966 .50952 .46053 .51018 .46206 .50971 .46119 .50906 Mtetra
.652 .797 .952 r
.46119 .50906 .46206 .50971 .46358 .50924 .46271 .5086 Mtetra
.65 .797 .954 r
.46271 .5086 .46358 .50924 .46511 .50878 .46424 .50814 Mtetra
.646 .8 .957 r
.46424 .50814 .46511 .50878 .46664 .50831 .46577 .50769 Mtetra
.64 .803 .961 r
.46577 .50769 .46664 .50831 .46816 .50788 .46729 .50726 Mtetra
.631 .801 .964 r
.46729 .50726 .46816 .50788 .46969 .50752 .46882 .50685 Mtetra
.628 .785 .957 r
.46882 .50685 .46969 .50752 .47122 .50724 .47035 .50647 Mtetra
.635 .76 .938 r
.47035 .50647 .47122 .50724 .47274 .50696 .47188 .50608 Mtetra
.645 .737 .916 r
.47188 .50608 .47274 .50696 .47427 .50661 .47341 .50567 Mtetra
.654 .727 .903 r
.47341 .50567 .47427 .50661 .47581 .50617 .47494 .50523 Mtetra
.658 .728 .901 r
.47494 .50523 .47581 .50617 .47734 .50569 .47648 .50477 Mtetra
.66 .734 .904 r
.47648 .50477 .47734 .50569 .47887 .5052 .47801 .5043 Mtetra
.663 .738 .906 r
.47801 .5043 .47887 .5052 .48041 .50472 .47955 .50382 Mtetra
.668 .74 .905 r
.47955 .50382 .48041 .50472 .48195 .5042 .48108 .50332 Mtetra
.677 .748 .904 r
.48108 .50332 .48195 .5042 .48348 .50359 .48262 .50278 Mtetra
.685 .765 .913 r
.48262 .50278 .48348 .50359 .48502 .50291 .48416 .50221 Mtetra
.685 .792 .931 r
.48416 .50221 .48502 .50291 .48657 .50224 .4857 .50163 Mtetra
.673 .817 .953 r
.4857 .50163 .48657 .50224 .48811 .50163 .48724 .50109 Mtetra
.657 .831 .967 r
.48724 .50109 .48811 .50163 .48965 .50111 .48878 .50058 Mtetra
.65 .834 .971 r
.48878 .50058 .48965 .50111 .49119 .50061 .49033 .50008 Mtetra
.647 .834 .972 r
.49033 .50008 .49119 .50061 .49273 .50012 .49187 .4996 Mtetra
.646 .834 .973 r
.49187 .4996 .49273 .50012 .49427 .49963 .49341 .49911 Mtetra
.643 .836 .975 r
.49341 .49911 .49427 .49963 .49582 .49914 .49496 .49863 Mtetra
.639 .837 .976 r
.49496 .49863 .49582 .49914 .49736 .49866 .4965 .49816 Mtetra
.637 .838 .978 r
.4965 .49816 .49736 .49866 .49891 .49819 .49805 .49769 Mtetra
.636 .84 .979 r
.49805 .49769 .49891 .49819 .50045 .49771 .49959 .49722 Mtetra
.637 .842 .979 r
.49959 .49722 .50045 .49771 .502 .49723 .50114 .49675 Mtetra
.639 .845 .979 r
.50114 .49675 .502 .49723 .50355 .49673 .50269 .49626 Mtetra
.64 .848 .98 r
.50269 .49626 .50355 .49673 .5051 .49624 .50424 .49577 Mtetra
.655 .853 .976 r
.50424 .49577 .5051 .49624 .50665 .49565 .50579 .49524 Mtetra
.659 .871 .979 r
.50579 .49524 .50665 .49565 .5082 .49499 .50734 .49467 Mtetra
.608 .885 .99 r
.50734 .49467 .5082 .49499 .50975 .49455 .50889 .49417 Mtetra
.513 .836 .999 r
.50889 .49417 .50975 .49455 .5113 .49481 .51045 .49389 Mtetra
.507 .678 .943 r
.51045 .49389 .5113 .49481 .51284 .49643 .512 .4939 Mtetra
.561 .498 .742 r
.512 .4939 .51284 .49643 .51439 .49987 .51355 .49398 Mtetra
.588 .433 .638 r
.51355 .49398 .51439 .49987 .51593 .50609 .51511 .49368 Mtetra
.59 .402 .595 r
.51511 .49368 .51593 .50609 .51749 .50462 .51667 .4928 Mtetra
.58 .396 .596 r
.51667 .4928 .51749 .50462 .51905 .50318 .51822 .49236 Mtetra
.524 .357 .596 r
.51822 .49236 .51905 .50318 .52039 .68238 .51978 .49371 Mtetra
0 0 .386 r
.51978 .49371 .52039 .68238 .52203 .69264 .52114 .68131 Mtetra
0 0 .417 r
.52114 .68131 .52203 .69264 .52368 .69565 .52278 .69351 Mtetra
0 .146 .678 r
.52278 .69351 .52368 .69565 .52534 .69673 .52444 .69568 Mtetra
.567 .688 .922 r
.52444 .69568 .52534 .69673 .52699 .69649 .5261 .69554 Mtetra
.695 .753 .896 r
.5261 .69554 .52699 .69649 .52865 .69591 .52776 .69487 Mtetra
.704 .738 .878 r
.52776 .69487 .52865 .69591 .53031 .69534 .52942 .69413 Mtetra
.636 .684 .879 r
.52942 .69413 .53031 .69534 .53198 .69508 .53108 .69374 Mtetra
.65 .669 .855 r
.53108 .69374 .53198 .69508 .53364 .69457 .53274 .69327 Mtetra
.685 .687 .846 r
.53274 .69327 .53364 .69457 .5353 .6934 .53441 .69259 Mtetra
.758 .798 .885 r
.53441 .69259 .5353 .6934 .53696 .69073 .53607 .69159 Mtetra
0 0 0 r
.53607 .69159 .53696 .69073 .53861 .68636 .53773 .69049 Mtetra
.472 .186 .398 r
.53773 .69049 .53861 .68636 .54024 .67935 .5394 .68971 Mtetra
.554 .309 .499 r
.5394 .68971 .54024 .67935 .54191 .67931 .54107 .68965 Mtetra
.54 .297 .496 r
.54107 .68965 .54191 .67931 .54357 .67968 .54274 .68916 Mtetra
.472 .238 .477 r
.54274 .68916 .54357 .67968 .54425 .51007 .5444 .68705 Mtetra
.532 .326 .546 r
.5444 .68705 .54425 .51007 .5457 .48827 .54597 .67051 Mtetra
0 0 .38 r
.54597 .67051 .5457 .48827 .54726 .48439 .54643 .48487 Mtetra
.969 .932 .675 r
.54643 .48487 .54726 .48439 .54882 .48235 .54798 .48165 Mtetra
.741 .809 .905 r
.54798 .48165 .54882 .48235 .55039 .48164 .54956 .48081 Mtetra
.619 .745 .937 r
.54956 .48081 .55039 .48164 .55197 .48126 .55113 .48047 Mtetra
.564 .738 .958 r
.55113 .48047 .55197 .48126 .55355 .48096 .55271 .48028 Mtetra
.654 .797 .951 r
.55271 .48028 .55355 .48096 .55512 .48047 .55429 .47979 Mtetra
.651 .797 .952 r
.55429 .47979 .55512 .48047 .5567 .47999 .55587 .47932 Mtetra
.651 .798 .953 r
.55587 .47932 .5567 .47999 .55828 .47951 .55745 .47884 Mtetra
.654 .801 .953 r
.55745 .47884 .55828 .47951 .55986 .47902 .55903 .47835 Mtetra
.655 .802 .953 r
.55903 .47835 .55986 .47902 .56144 .47853 .56061 .47786 Mtetra
.656 .802 .953 r
.56061 .47786 .56144 .47853 .56302 .47803 .56219 .47737 Mtetra
.656 .803 .953 r
.56219 .47737 .56302 .47803 .5646 .47754 .56378 .47687 Mtetra
.56378 .47687 .5646 .47754 .56619 .47704 .56536 .47637 Mtetra
.56536 .47637 .56619 .47704 .56777 .47654 .56695 .47588 Mtetra
.56695 .47588 .56777 .47654 .56936 .47604 .56853 .47538 Mtetra
.56853 .47538 .56936 .47604 .57094 .47555 .57012 .47488 Mtetra
.657 .803 .953 r
.57012 .47488 .57094 .47555 .57253 .47505 .57171 .47438 Mtetra
.57171 .47438 .57253 .47505 .57412 .47455 .5733 .47388 Mtetra
.5733 .47388 .57412 .47455 .57571 .47405 .57489 .47338 Mtetra
.57489 .47338 .57571 .47405 .5773 .47355 .57648 .47288 Mtetra
.658 .803 .953 r
.57648 .47288 .5773 .47355 .57889 .47304 .57807 .47237 Mtetra
.658 .803 .952 r
.57807 .47237 .57889 .47304 .58048 .47254 .57966 .47186 Mtetra
.66 .803 .952 r
.57966 .47186 .58048 .47254 .58207 .47203 .58125 .47135 Mtetra
.663 .803 .95 r
.58125 .47135 .58207 .47203 .58367 .47152 .58285 .47083 Mtetra
.663 .801 .949 r
.58285 .47083 .58367 .47152 .58526 .471 .58444 .47031 Mtetra
.674 .803 .944 r
.58444 .47031 .58526 .471 .58685 .47046 .58604 .46975 Mtetra
.742 .813 .908 r
.58604 .46975 .58685 .47046 .58845 .46973 .58763 .4689 Mtetra
.668 .766 .924 r
.58763 .4689 .58845 .46973 .59004 .46921 .58922 .46838 Mtetra
.381 .644 .96 r
.58922 .46838 .59004 .46921 .59165 .46916 .59084 .46861 Mtetra
.892 .467 .125 r
.59084 .46861 .59165 .46916 .59329 .47083 .59253 .47239 Mtetra
.961 .681 .459 r
.59253 .47239 .59329 .47083 .59499 .47484 .59823 .667 Mtetra
.572 .357 .551 r
.59823 .667 .59499 .47484 .60069 .66277 .60006 .67278 Mtetra
.559 .312 .497 r
.60006 .67278 .60069 .66277 .60241 .66325 .60178 .6729 Mtetra
.533 .289 .491 r
.60178 .6729 .60241 .66325 .60409 .6617 .60348 .67227 Mtetra
.529 .289 .495 r
.60348 .67227 .60409 .6617 .60582 .66255 .60518 .67142 Mtetra
.56 .308 .491 r
.60518 .67142 .60582 .66255 .60768 .66889 .6069 .67161 Mtetra
.542 .209 .354 r
.6069 .67161 .60768 .66889 .60947 .6716 .60863 .67176 Mtetra
.147 0 0 r
.60863 .67176 .60947 .6716 .61122 .67295 .61035 .6718 Mtetra
.529 .655 .916 r
.61035 .6718 .61122 .67295 .61294 .67301 .61207 .6718 Mtetra
.644 .691 .879 r
.61207 .6718 .61294 .67301 .61466 .67253 .61379 .67135 Mtetra
.76 .736 .831 r
.61379 .67135 .61466 .67253 .61635 .67143 .61548 .67016 Mtetra
.909 .737 .656 r
.61548 .67016 .61635 .67143 .61801 .66868 .61708 .66537 Mtetra
.963 .687 .464 r
.61708 .66537 .61801 .66868 .6196 .6637 .61354 .46987 Mtetra
.576 .365 .556 r
.61354 .46987 .6196 .6637 .6161 .47473 .61497 .46247 Mtetra
.596 .407 .596 r
.61497 .46247 .6161 .47473 .61767 .47271 .61657 .46137 Mtetra
.579 .397 .599 r
.61657 .46137 .61767 .47271 .61933 .47361 .61819 .461 Mtetra
.57 .387 .594 r
.61819 .461 .61933 .47361 .62094 .47267 .61982 .46092 Mtetra
.597 .408 .597 r
.61982 .46092 .62094 .47267 .62233 .46429 .62142 .45984 Mtetra
.642 .489 .661 r
.62142 .45984 .62233 .46429 .62386 .46069 .62302 .45876 Mtetra
.697 .616 .763 r
.62302 .45876 .62386 .46069 .62542 .45846 .62462 .45779 Mtetra
.67 .811 .95 r
.62462 .45779 .62542 .45846 .62704 .45778 .62624 .45723 Mtetra
.622 .832 .981 r
.62624 .45723 .62704 .45778 .62866 .45746 .62786 .45678 Mtetra
.623 .796 .965 r
.62786 .45678 .62866 .45746 .63029 .45728 .62949 .45638 Mtetra
.746 .773 .875 r
.62949 .45638 .63029 .45728 .6319 .45641 .6311 .45545 Mtetra
.697 .746 .889 r
.6311 .45545 .6319 .45641 .63352 .45568 .63271 .45478 Mtetra
.542 .704 .945 r
.63271 .45478 .63352 .45568 .63514 .45531 .63435 .45467 Mtetra
.816 .345 0 r
.63435 .45467 .63514 .45531 .63682 .45636 .63609 .45754 Mtetra
.965 .681 .442 r
.63609 .45754 .63682 .45636 .63856 .45919 .64437 .65033 Mtetra
.577 .361 .551 r
.64437 .65033 .63856 .45919 .64679 .6464 .64643 .6594 Mtetra
.583 .339 .513 r
.64643 .6594 .64679 .6464 .64892 .65743 .64822 .66053 Mtetra
.536 .217 .373 r
.64822 .66053 .64892 .65743 .65077 .66009 .64997 .66059 Mtetra
.086 0 0 r
.64997 .66059 .65077 .66009 .65256 .66124 .65171 .6602 Mtetra
.637 .725 .912 r
.65171 .6602 .65256 .66124 .65431 .66114 .65345 .65977 Mtetra
.659 .675 .854 r
.65345 .65977 .65431 .66114 .65605 .6606 .65518 .65923 Mtetra
.67 .68 .85 r
.65518 .65923 .65605 .6606 .65777 .65984 .65692 .65862 Mtetra
.657 .698 .877 r
.65692 .65862 .65777 .65984 .65951 .65929 .65866 .6581 Mtetra
.653 .703 .884 r
.65866 .6581 .65951 .65929 .66125 .65877 .6604 .65761 Mtetra
.651 .706 .888 r
.6604 .65761 .66125 .65877 .66299 .65826 .66214 .65712 Mtetra
.65 .71 .892 r
.66214 .65712 .66299 .65826 .66473 .65778 .66388 .65664 Mtetra
.648 .711 .893 r
.66388 .65664 .66473 .65778 .66648 .6573 .66563 .65616 Mtetra
.647 .71 .893 r
.66563 .65616 .66648 .6573 .66822 .65684 .66737 .65569 Mtetra
.646 .708 .892 r
.66737 .65569 .66822 .65684 .66997 .6564 .66912 .65523 Mtetra
.645 .703 .889 r
.66912 .65523 .66997 .6564 .67172 .65597 .67087 .65477 Mtetra
.643 .697 .885 r
.67087 .65477 .67172 .65597 .67347 .65554 .67262 .65432 Mtetra
.626 .686 .887 r
.67262 .65432 .67347 .65554 .67523 .65531 .67437 .65395 Mtetra
.633 .666 .864 r
.67437 .65395 .67523 .65531 .67699 .65496 .67613 .65355 Mtetra
.653 .667 .851 r
.67613 .65355 .67699 .65496 .67873 .65427 .67788 .65303 Mtetra
.658 .697 .875 r
.67788 .65303 .67873 .65427 .68042 .65252 .67963 .6525 Mtetra
.611 .951 .916 r
.67963 .6525 .68042 .65252 .68206 .64949 .68136 .65163 Mtetra
.191 0 .168 r
.68136 .65163 .68206 .64949 .68353 .64287 .68307 .65002 Mtetra
.168 0 .377 r
.68307 .65002 .68353 .64287 .67635 .44933 .68458 .64414 Mtetra
.041 0 .431 r
.68458 .64414 .67635 .44933 .67779 .44433 .67716 .44677 Mtetra
0 0 0 r
.67716 .44677 .67779 .44433 .67935 .44184 .67859 .44147 Mtetra
.851 .915 .876 r
.67859 .44147 .67935 .44184 .68097 .44088 .68019 .44001 Mtetra
.648 .755 .927 r
.68019 .44001 .68097 .44088 .68263 .44054 .68185 .43955 Mtetra
.544 .684 .93 r
.68185 .43955 .68263 .44054 .68431 .44045 .68352 .43946 Mtetra
.619 .718 .917 r
.68352 .43946 .68431 .44045 .68597 .44011 .68518 .43913 Mtetra
.651 .731 .908 r
.68518 .43913 .68597 .44011 .68762 .43963 .68684 .43866 Mtetra
.658 .738 .909 r
.68684 .43866 .68762 .43963 .68928 .43908 .6885 .43816 Mtetra
.692 .762 .905 r
.6885 .43816 .68928 .43908 .69092 .43821 .69015 .43752 Mtetra
.695 .817 .941 r
.69015 .43752 .69092 .43821 .69256 .43739 .6918 .43685 Mtetra
.654 .852 .976 r
.6918 .43685 .69256 .43739 .69421 .43688 .69345 .43629 Mtetra
.642 .832 .974 r
.69345 .43629 .69421 .43688 .69593 .43738 .69511 .43578 Mtetra
.598 .605 .83 r
.69511 .43578 .69593 .43738 .69771 .43917 .69679 .43558 Mtetra
.528 .437 .696 r
.69679 .43558 .69771 .43917 .6997 .44472 .69851 .43606 Mtetra
.37 .26 .597 r
.69851 .43606 .6997 .44472 .71181 .63763 .70043 .44035 Mtetra
.065 0 .45 r
.70043 .44035 .71181 .63763 .71384 .64194 .71282 .63722 Mtetra
.053 .094 .585 r
.71282 .63722 .71384 .64194 .71574 .64369 .71488 .64202 Mtetra
.342 .468 .843 r
.71488 .64202 .71574 .64369 .71756 .64409 .71673 .64288 Mtetra
.626 .691 .891 r
.71673 .64288 .71756 .64409 .71935 .64375 .71851 .6425 Mtetra
.715 .719 .853 r
.71851 .6425 .71935 .64375 .72111 .64287 .72027 .64163 Mtetra
.69 .711 .865 r
.72027 .64163 .72111 .64287 .72282 .64118 .72204 .64091 Mtetra
.684 .937 .966 r
.72204 .64091 .72282 .64118 .72446 .63836 .7238 .64006 Mtetra
.116 0 .074 r
.7238 .64006 .72446 .63836 .72594 .63273 .72552 .63854 Mtetra
.169 0 .359 r
.72552 .63854 .72594 .63273 .71633 .43818 .72704 .63365 Mtetra
.062 0 .444 r
.72704 .63365 .71633 .43818 .71768 .43222 .71716 .43549 Mtetra
0 0 0 r
.71716 .43549 .71768 .43222 .71922 .42948 .71849 .42924 Mtetra
.899 .94 .829 r
.71849 .42924 .71922 .42948 .72085 .4282 .72009 .42738 Mtetra
.678 .782 .928 r
.72009 .42738 .72085 .4282 .72252 .42764 .72176 .42679 Mtetra
.56 .729 .954 r
.72176 .42679 .72252 .42764 .72421 .42736 .72346 .4266 Mtetra
.584 .765 .965 r
.72346 .4266 .72421 .42736 .7259 .42708 .72515 .42632 Mtetra
.63 .782 .954 r
.72515 .42632 .7259 .42708 .72759 .42674 .72683 .42589 Mtetra
.64 .762 .937 r
.72683 .42589 .72759 .42674 .72928 .42637 .72852 .42545 Mtetra
.677 .757 .911 r
.72852 .42545 .72928 .42637 .73095 .42565 .73019 .42486 Mtetra
.691 .795 .929 r
.73019 .42486 .73095 .42565 .73261 .42481 .73187 .42421 Mtetra
.66 .836 .968 r
.73187 .42421 .73261 .42481 .73429 .42425 .73355 .42364 Mtetra
.64 .829 .973 r
.73355 .42364 .73429 .42425 .73602 .42457 .73523 .42313 Mtetra
.606 .633 .851 r
.73523 .42313 .73602 .42457 .73785 .42617 .73693 .42288 Mtetra
.536 .454 .71 r
.73693 .42288 .73785 .42617 .73987 .43076 .73868 .42325 Mtetra
.398 .289 .613 r
.73868 .42325 .73987 .43076 .75451 .62472 .74062 .42661 Mtetra
.087 .008 .462 r
.74062 .42661 .75451 .62472 .75668 .62973 .75556 .62408 Mtetra
.08 .096 .575 r
.75556 .62408 .75668 .62973 .75864 .63167 .75778 .62978 Mtetra
.218 .362 .796 r
.75778 .62978 .75864 .63167 .76053 .63238 .75971 .63123 Mtetra
.549 .672 .919 r
.75971 .63123 .76053 .63238 .76236 .63225 .76155 .63115 Mtetra
.742 .757 .865 r
.76155 .63115 .76236 .63225 .76413 .63132 .76332 .63013 Mtetra
.895 .767 .713 r
.76332 .63013 .76413 .63132 .76575 .62813 .76493 .62691 Mtetra
.972 .717 .488 r
.76493 .62691 .76575 .62813 .7663 .6097 .76556 .6096 Mtetra
.976 .686 .401 r
.76556 .6096 .7663 .6097 .75467 .41981 .75394 .41915 Mtetra
.92 .837 .746 r
.75394 .41915 .75467 .41981 .75622 .41723 .75548 .4165 Mtetra
.687 .814 .943 r
.75548 .4165 .75622 .41723 .75791 .41667 .75717 .41586 Mtetra
.531 .728 .964 r
.75717 .41586 .75791 .41667 .75965 .41666 .7589 .41573 Mtetra
.581 .721 .939 r
.7589 .41573 .75965 .41666 .76137 .4165 .76062 .41551 Mtetra
.663 .739 .906 r
.76062 .41551 .76137 .4165 .76307 .41596 .76232 .41497 Mtetra
.67 .742 .905 r
.76232 .41497 .76307 .41596 .76476 .41536 .76401 .41441 Mtetra
.735 .773 .883 r
.76401 .41441 .76476 .41536 .76643 .41439 .76569 .41351 Mtetra
.754 .796 .887 r
.76569 .41351 .76643 .41439 .76809 .41331 .76736 .41253 Mtetra
.64 .783 .95 r
.76736 .41253 .76809 .41331 .76979 .41276 .76907 .41206 Mtetra
0 .132 .62 r
.76907 .41206 .76979 .41276 .77164 .41413 .77092 .41356 Mtetra
.959 .619 .29 r
.77092 .41356 .77164 .41413 .77423 .42509 .77383 .42874 Mtetra
.971 .671 .392 r
.77383 .42874 .77423 .42509 .79106 .62017 .79029 .61938 Mtetra
.584 .089 0 r
.79029 .61938 .79106 .62017 .79312 .62267 .79233 .62173 Mtetra
.479 .686 .958 r
.79233 .62173 .79312 .62267 .79499 .62275 .7942 .62178 Mtetra
.744 .785 .886 r
.7942 .62178 .79499 .62275 .79678 .62176 .79599 .62078 Mtetra
.91 .798 .724 r
.79599 .62078 .79678 .62176 .79839 .61859 .79761 .61768 Mtetra
.979 .722 .469 r
.79761 .61768 .79839 .61859 .78538 .43271 .79806 .59993 Mtetra
.015 0 .436 r
.79806 .59993 .78538 .43271 .78534 .41018 .78462 .40954 Mtetra
.933 .842 .73 r
.78462 .40954 .78534 .41018 .78687 .40743 .78615 .40668 Mtetra
.692 .81 .938 r
.78615 .40668 .78687 .40743 .78858 .40686 .78785 .406 Mtetra
.54 .724 .959 r
.78785 .406 .78858 .40686 .79033 .40682 .7896 .40587 Mtetra
.558 .706 .939 r
.7896 .40587 .79033 .40682 .79209 .40675 .79135 .40572 Mtetra
.656 .73 .904 r
.79135 .40572 .79209 .40675 .79381 .40625 .79307 .40521 Mtetra
.664 .733 .901 r
.79307 .40521 .79381 .40625 .79552 .40568 .79478 .40467 Mtetra
.72 .76 .884 r
.79478 .40467 .79552 .40568 .79721 .40478 .79648 .40385 Mtetra
.756 .787 .878 r
.79648 .40385 .79721 .40478 .79888 .40366 .79816 .40283 Mtetra
.66 .781 .938 r
.79816 .40283 .79888 .40366 .80059 .40303 .79988 .40229 Mtetra
0 .333 .795 r
.79988 .40229 .80059 .40303 .80245 .40402 .80174 .40339 Mtetra
.934 .559 .186 r
.80174 .40339 .80245 .40402 .80488 .41172 .80427 .41218 Mtetra
.975 .671 .366 r
.80427 .41218 .80488 .41172 .82396 .61032 .8232 .60952 Mtetra
.658 .175 0 r
.8232 .60952 .82396 .61032 .82611 .61333 .82534 .61236 Mtetra
.452 .665 .954 r
.82534 .61236 .82611 .61333 .82802 .61351 .82724 .6125 Mtetra
.734 .778 .888 r
.82724 .6125 .82802 .61351 .82983 .61258 .82905 .61155 Mtetra
.902 .798 .735 r
.82905 .61155 .82983 .61258 .83146 .60966 .83069 .60865 Mtetra
.98 .725 .471 r
.83069 .60865 .83146 .60966 .83175 .59181 .83117 .5929 Mtetra
.978 .682 .367 r
.83117 .5929 .83175 .59181 .81634 .40053 .81563 .39977 Mtetra
.94 .821 .701 r
.81563 .39977 .81634 .40053 .81783 .39737 .81711 .39649 Mtetra
.762 .801 .884 r
.81711 .39649 .81783 .39737 .81953 .3965 .8188 .39544 Mtetra
.58 .693 .919 r
.8188 .39544 .81953 .3965 .8213 .39637 .82056 .39524 Mtetra
.149 .428 .867 r
.82056 .39524 .8213 .39637 .82314 .39694 .82244 .39627 Mtetra
.842 .404 0 r
.82244 .39627 .82314 .39694 .82507 .39848 .82465 .40076 Mtetra
.974 .668 .361 r
.82465 .40076 .82507 .39848 .82723 .40249 .84505 .59969 Mtetra
.569 .355 .55 r
.84505 .59969 .82723 .40249 .84733 .59663 .84738 .60424 Mtetra
.573 .309 .478 r
.84738 .60424 .84733 .59663 .84979 .60244 .84934 .60482 Mtetra
.496 .148 .306 r
.84934 .60482 .84979 .60244 .85189 .60453 .85124 .60467 Mtetra
0 0 0 r
.85124 .60467 .85189 .60453 .85389 .60549 .85313 .60443 Mtetra
.492 .667 .94 r
.85313 .60443 .85389 .60549 .85584 .60578 .85505 .60449 Mtetra
.649 .696 .88 r
.85505 .60449 .85584 .60578 .8577 .6053 .85691 .60398 Mtetra
.826 .753 .782 r
.85691 .60398 .8577 .6053 .85943 .60333 .85863 .60201 Mtetra
.964 .744 .558 r
.85863 .60201 .85943 .60333 .8606 .59581 .85977 .59401 Mtetra
.977 .677 .362 r
.85977 .59401 .8606 .59581 .84262 .39437 .84189 .39324 Mtetra
.934 .773 .658 r
.84189 .39324 .84262 .39437 .844 .39012 .84329 .38914 Mtetra
.741 .778 .883 r
.84329 .38914 .844 .39012 .84571 .38917 .845 .3882 Mtetra
.609 .727 .929 r
.845 .3882 .84571 .38917 .84748 .38886 .84677 .38787 Mtetra
.602 .719 .927 r
.84677 .38787 .84748 .38886 .84926 .38859 .84854 .38757 Mtetra
.745 .769 .873 r
.84854 .38757 .84926 .38859 .85097 .38761 .85025 .38658 Mtetra
.661 .738 .907 r
.85025 .38658 .85097 .38761 .85272 .38708 .852 .38604 Mtetra
.258 .519 .909 r
.852 .38604 .85272 .38708 .85461 .38785 .85389 .38675 Mtetra
.878 .49 .024 r
.85389 .38675 .85461 .38785 .8573 .39634 .85645 .39409 Mtetra
.975 .667 .326 r
.85645 .39409 .8573 .39634 .87976 .59519 .87896 .59368 Mtetra
0 0 .52 r
.87896 .59368 .87976 .59519 .88202 .59829 .88124 .59702 Mtetra
.482 .619 .909 r
.88124 .59702 .88202 .59829 .88395 .59825 .8832 .59722 Mtetra
.707 .769 .901 r
.8832 .59722 .88395 .59825 .88579 .59735 .88505 .59641 Mtetra
.868 .825 .803 r
.88505 .59641 .88579 .59735 .88755 .59564 .88677 .59434 Mtetra
.952 .76 .606 r
.88677 .59434 .88755 .59564 .88919 .59287 .88809 .58854 Mtetra
.976 .673 .356 r
.88809 .58854 .88919 .59287 .89056 .58753 .86855 .38783 Mtetra
.573 .361 .555 r
.86855 .38783 .89056 .58753 .87134 .39122 .86976 .38211 Mtetra
.618 .433 .609 r
.86976 .38211 .87134 .39122 .87243 .38444 .87141 .38052 Mtetra
.638 .5 .679 r
.87141 .38052 .87243 .38444 .87393 .38147 .87314 .37961 Mtetra
.652 .61 .795 r
.87314 .37961 .87393 .38147 .87557 .37975 .8749 .37903 Mtetra
.655 .815 .96 r
.8749 .37903 .87557 .37975 .87733 .37913 .87667 .37847 Mtetra
.62 .819 .977 r
.87667 .37847 .87733 .37913 .87912 .37881 .87844 .378 Mtetra
.655 .79 .947 r
.87844 .378 .87912 .37881 .88091 .37847 .88021 .37746 Mtetra
.758 .78 .871 r
.88021 .37746 .88091 .37847 .88262 .37732 .88193 .3764 Mtetra
.69 .776 .917 r
.88193 .3764 .88262 .37732 .88437 .37655 .88369 .37572 Mtetra
.379 .647 .961 r
.88369 .37572 .88437 .37655 .88622 .37676 .88555 .37598 Mtetra
.822 .393 0 r
.88555 .37598 .88622 .37676 .88864 .38191 .88796 .38101 Mtetra
.973 .661 .312 r
.88796 .38101 .88864 .38191 .91356 .58415 .91277 .5827 Mtetra
0 0 .361 r
.91277 .5827 .91356 .58415 .91601 .58848 .91524 .58712 Mtetra
.539 .632 .892 r
.91524 .58712 .91601 .58848 .91796 .58836 .9172 .58712 Mtetra
.689 .725 .878 r
.9172 .58712 .91796 .58836 .91983 .58749 .91908 .58638 Mtetra
.738 .768 .877 r
.91908 .58638 .91983 .58749 .92166 .58636 .92093 .58537 Mtetra
.513 .695 .951 r
.92093 .58537 .92166 .58636 .92362 .58627 .9229 .58533 Mtetra
.614 .757 .947 r
.9229 .58533 .92362 .58627 .92555 .58596 .92482 .58492 Mtetra
.774 .794 .869 r
.92482 .58492 .92555 .58596 .92742 .58512 .92665 .58368 Mtetra
.943 .756 .621 r
.92665 .58368 .92742 .58512 .92905 .58219 .92799 .57839 Mtetra
.975 .668 .333 r
.92799 .57839 .92905 .58219 .93037 .57675 .90601 .37729 Mtetra
.574 .362 .555 r
.90601 .37729 .93037 .57675 .90905 .38245 .90707 .37064 Mtetra
.595 .407 .598 r
.90707 .37064 .90905 .38245 .91075 .38108 .9088 .36956 Mtetra
.578 .397 .6 r
.9088 .36956 .91075 .38108 .91276 .38232 .91061 .3692 Mtetra
.571 .388 .594 r
.91061 .3692 .91276 .38232 .91445 .38087 .91245 .36909 Mtetra
.596 .408 .598 r
.91245 .36909 .91445 .38087 .91529 .37248 .91417 .36795 Mtetra
.641 .49 .662 r
.91417 .36795 .91529 .37248 .9167 .36878 .9159 .36682 Mtetra
.699 .627 .772 r
.9159 .36682 .9167 .36878 .91827 .36648 .91763 .3658 Mtetra
.669 .837 .964 r
.91763 .3658 .91827 .36648 .92003 .36563 .91942 .36516 Mtetra
.6 .873 .993 r
.91942 .36516 .92003 .36563 .92183 .36513 .92121 .36463 Mtetra
.587 .858 .995 r
.92121 .36463 .92183 .36513 .92366 .36482 .92302 .36415 Mtetra
.719 .797 .913 r
.34088 .54615 .3418 .54681 .34326 .54638 .34236 .54546 Mtetra
.697 .734 .879 r
.34236 .54546 .34326 .54638 .34472 .54594 .34383 .54485 Mtetra
.66 .69 .867 r
.34383 .54485 .34472 .54594 .34618 .54549 .34529 .54439 Mtetra
.602 .67 .888 r
.34529 .54439 .34618 .54549 .34767 .54459 .34674 .54418 Mtetra
.103 .602 .9 r
.34674 .54418 .34767 .54459 .34914 .54397 .34816 .54442 Mtetra
.705 .25 .171 r
.34816 .54442 .34914 .54397 .35058 .54392 .34954 .54556 Mtetra
.884 .595 .493 r
.34954 .54556 .35058 .54392 .35187 .5469 .35045 .55598 Mtetra
.923 .667 .533 r
.35045 .55598 .35187 .5469 .34373 .73512 .34241 .74129 Mtetra
.677 .404 .501 r
.34241 .74129 .34373 .73512 .34485 .74318 .34378 .74442 Mtetra
.535 .119 .198 r
.34378 .74442 .34485 .74318 .34632 .74424 .3453 .7447 Mtetra
0 0 0 r
.3453 .7447 .34632 .74424 .34785 .74435 .34685 .74426 Mtetra
.732 .948 .95 r
.34685 .74426 .34785 .74435 .3494 .74403 .34843 .74335 Mtetra
.726 .804 .913 r
.34843 .74335 .3494 .74403 .35093 .74406 .35 .74259 Mtetra
.74 .673 .785 r
.35 .74259 .35093 .74406 .35248 .74373 .35159 .74141 Mtetra
.756 .62 .708 r
.35159 .74141 .35248 .74373 .35407 .74275 .35323 .73934 Mtetra
.853 .642 .616 r
.35323 .73934 .35407 .74275 .35579 .7389 .35519 .73057 Mtetra
.928 .676 .536 r
.35519 .73057 .35579 .7389 .36611 .55218 .36566 .54169 Mtetra
.671 .469 .604 r
.36566 .54169 .36611 .55218 .36811 .5406 .3673 .53771 Mtetra
.672 .545 .701 r
.3673 .53771 .36811 .5406 .36965 .53866 .3688 .53667 Mtetra
.623 .566 .77 r
.3688 .53667 .36965 .53866 .37115 .53774 .37027 .53633 Mtetra
.567 .603 .849 r
.37027 .53633 .37115 .53774 .37263 .53723 .37173 .53629 Mtetra
.688 .73 .882 r
.37173 .53629 .37263 .53723 .37411 .53667 .37321 .53571 Mtetra
.695 .727 .875 r
.37321 .53571 .37411 .53667 .37559 .53618 .3747 .53509 Mtetra
.666 .695 .868 r
.3747 .53509 .37559 .53618 .37706 .53573 .37618 .53461 Mtetra
.616 .672 .881 r
.37618 .53461 .37706 .53573 .37856 .53478 .37765 .53434 Mtetra
.246 .683 .96 r
.37765 .53434 .37856 .53478 .38005 .53405 .3791 .53447 Mtetra
.652 .167 .088 r
.3791 .53447 .38005 .53405 .38152 .53393 .38053 .53534 Mtetra
.854 .539 .454 r
.38053 .53534 .38152 .53393 .38285 .53698 .38175 .54102 Mtetra
.935 .676 .522 r
.38175 .54102 .38285 .53698 .37632 .72816 .37523 .73061 Mtetra
.779 .465 .456 r
.37523 .73061 .37632 .72816 .37758 .73515 .37662 .73454 Mtetra
.389 0 0 r
.37662 .73454 .37758 .73515 .37908 .73631 .37813 .73551 Mtetra
.546 .734 .962 r
.37813 .73551 .37908 .73631 .38065 .73606 .37969 .73536 Mtetra
.778 .804 .874 r
.37969 .73536 .38065 .73606 .38226 .73477 .38129 .73427 Mtetra
.921 .776 .684 r
.38129 .73427 .38226 .73477 .384 .73011 .38302 .73002 Mtetra
.943 .689 .523 r
.38302 .73002 .384 .73011 .39313 .53698 .39218 .53751 Mtetra
.971 .787 .599 r
.39218 .53751 .39313 .53698 .39486 .53046 .39395 .52993 Mtetra
.847 .824 .825 r
.39395 .52993 .39486 .53046 .39639 .52893 .39548 .52833 Mtetra
.648 .806 .959 r
.39548 .52833 .39639 .52893 .39788 .52847 .39697 .52788 Mtetra
.449 .742 .991 r
.39697 .52788 .39788 .52847 .39935 .52841 .39845 .52785 Mtetra
.598 .805 .979 r
.39845 .52785 .39935 .52841 .40084 .52801 .39993 .52752 Mtetra
.641 .837 .976 r
.39993 .52752 .40084 .52801 .40233 .52751 .40143 .52706 Mtetra
.645 .848 .978 r
.40143 .52706 .40233 .52751 .40382 .52711 .40292 .52658 Mtetra
.754 .839 .916 r
.40292 .52658 .40382 .52711 .40532 .5267 .40443 .52572 Mtetra
.716 .73 .862 r
.40443 .52572 .40532 .5267 .4068 .52657 .40594 .52498 Mtetra
.616 .602 .814 r
.40594 .52498 .4068 .52657 .40826 .52708 .40742 .52471 Mtetra
.064 .19 .685 r
.40742 .52471 .40826 .52708 .4096 .53128 .40884 .52661 Mtetra
.9 .632 .125 r
.40884 .52661 .4096 .53128 .40458 .72278 .40997 .53675 Mtetra
0 0 .328 r
.40997 .53675 .40458 .72278 .40599 .72752 .40516 .72347 Mtetra
.427 .356 .675 r
.40516 .72347 .40599 .72752 .40754 .72827 .40669 .72481 Mtetra
.616 .498 .696 r
.40669 .72481 .40754 .72827 .40913 .72787 .40828 .72434 Mtetra
.646 .515 .69 r
.40828 .72434 .40913 .72787 .41073 .72706 .40988 .72347 Mtetra
.555 .455 .696 r
.40988 .72347 .41073 .72706 .41233 .72647 .41145 .72366 Mtetra
.49 .446 .735 r
.41145 .72366 .41233 .72647 .41392 .72601 .41301 .72424 Mtetra
.471 .52 .826 r
.41301 .72424 .41392 .72601 .41552 .72555 .41458 .72463 Mtetra
.555 .706 .941 r
.41458 .72463 .41552 .72555 .41711 .72516 .41616 .7245 Mtetra
.63 .796 .962 r
.41616 .7245 .41711 .72516 .4187 .72477 .41776 .72408 Mtetra
.658 .796 .949 r
.41776 .72408 .4187 .72477 .4203 .72429 .41936 .72358 Mtetra
.618 .781 .96 r
.41936 .72358 .4203 .72429 .42191 .72349 .42095 .72321 Mtetra
.478 .845 .99 r
.42095 .72321 .42191 .72349 .42352 .72247 .42255 .7229 Mtetra
.045 0 0 r
.42255 .7229 .42352 .72247 .42514 .7214 .42414 .72257 Mtetra
.397 0 .083 r
.42414 .72257 .42514 .7214 .42673 .72107 .42574 .72239 Mtetra
.377 0 .104 r
.42574 .72239 .42673 .72107 .42832 .72093 .42733 .72207 Mtetra
.126 0 0 r
.42733 .72207 .42832 .72093 .42993 .72017 .42895 .72128 Mtetra
.847 .952 .601 r
.42895 .72128 .42993 .72017 .43163 .71606 .43061 .71854 Mtetra
.992 .851 .493 r
.43061 .71854 .43163 .71606 .43821 .52337 .43242 .71017 Mtetra
0 0 .325 r
.43242 .71017 .43821 .52337 .43988 .51683 .43892 .51922 Mtetra
0 0 0 r
.43892 .51922 .43988 .51683 .44143 .51493 .4405 .5164 Mtetra
.294 0 .103 r
.4405 .5164 .44143 .51493 .44295 .51434 .44202 .51575 Mtetra
.467 .065 .193 r
.44202 .51575 .44295 .51434 .44446 .51414 .44353 .51569 Mtetra
.436 .046 .2 r
.44353 .51569 .44446 .51414 .44597 .51383 .44504 .51546 Mtetra
.382 0 .184 r
.44504 .51546 .44597 .51383 .44749 .51335 .44656 .51499 Mtetra
.384 .002 .185 r
.44656 .51499 .44749 .51335 .44901 .51289 .44808 .51453 Mtetra
.38 0 .184 r
.44808 .51453 .44901 .51289 .45053 .51241 .4496 .51405 Mtetra
.376 0 .182 r
.4496 .51405 .45053 .51241 .45205 .51192 .45112 .51356 Mtetra
.374 0 .179 r
.45112 .51356 .45205 .51192 .45357 .51144 .45264 .51306 Mtetra
.374 0 .177 r
.45264 .51306 .45357 .51144 .45509 .51096 .45417 .51257 Mtetra
.375 0 .177 r
.45417 .51257 .45509 .51096 .45661 .51048 .45569 .51209 Mtetra
.376 0 .177 r
.45569 .51209 .45661 .51048 .45814 .51 .45722 .51161 Mtetra
.38 0 .179 r
.45722 .51161 .45814 .51 .45966 .50952 .45874 .51114 Mtetra
.384 0 .182 r
.45874 .51114 .45966 .50952 .46119 .50906 .46027 .51068 Mtetra
.387 .005 .186 r
.46027 .51068 .46119 .50906 .46271 .5086 .46179 .51024 Mtetra
.418 .036 .205 r
.46179 .51024 .46271 .5086 .46424 .50814 .46332 .5099 Mtetra
.436 .063 .231 r
.46332 .5099 .46424 .50814 .46577 .50769 .46485 .50959 Mtetra
.401 .039 .232 r
.46485 .50959 .46577 .50769 .46729 .50726 .46638 .50907 Mtetra
.212 0 .124 r
.46638 .50907 .46729 .50726 .46882 .50685 .46792 .50796 Mtetra
0 0 0 r
.46792 .50796 .46882 .50685 .47035 .50647 .46947 .50651 Mtetra
.819 .979 .89 r
.46947 .50651 .47035 .50647 .47188 .50608 .47101 .50522 Mtetra
.74 .765 .873 r
.47101 .50522 .47188 .50608 .47341 .50567 .47255 .50435 Mtetra
.661 .661 .84 r
.47255 .50435 .47341 .50567 .47494 .50523 .47409 .50385 Mtetra
.639 .644 .839 r
.47409 .50385 .47494 .50523 .47648 .50477 .47562 .50346 Mtetra
.645 .657 .847 r
.47562 .50346 .47648 .50477 .47801 .5043 .47715 .50305 Mtetra
.658 .671 .851 r
.47715 .50305 .47801 .5043 .47955 .50382 .47869 .50257 Mtetra
.659 .672 .851 r
.47869 .50257 .47955 .50382 .48108 .50332 .48023 .50209 Mtetra
.661 .675 .853 r
.48023 .50209 .48108 .50332 .48262 .50278 .48176 .5016 Mtetra
.664 .684 .859 r
.48176 .5016 .48262 .50278 .48416 .50221 .4833 .50109 Mtetra
.666 .697 .869 r
.4833 .50109 .48416 .50221 .4857 .50163 .48484 .50059 Mtetra
.666 .71 .881 r
.48484 .50059 .4857 .50163 .48724 .50109 .48638 .50008 Mtetra
.665 .719 .888 r
.48638 .50008 .48724 .50109 .48878 .50058 .48793 .49959 Mtetra
.664 .721 .891 r
.48793 .49959 .48878 .50058 .49033 .50008 .48947 .4991 Mtetra
.664 .722 .892 r
.48947 .4991 .49033 .50008 .49187 .4996 .49101 .49861 Mtetra
.663 .722 .893 r
.49101 .49861 .49187 .4996 .49341 .49911 .49255 .49813 Mtetra
.658 .721 .895 r
.49255 .49813 .49341 .49911 .49496 .49863 .4941 .49766 Mtetra
.648 .721 .901 r
.4941 .49766 .49496 .49863 .4965 .49816 .49564 .49724 Mtetra
.635 .728 .915 r
.49564 .49724 .4965 .49816 .49805 .49769 .49719 .49687 Mtetra
.631 .749 .933 r
.49719 .49687 .49805 .49769 .49959 .49722 .49874 .4965 Mtetra
.636 .777 .948 r
.49874 .4965 .49959 .49722 .50114 .49675 .50028 .49609 Mtetra
.649 .799 .955 r
.50028 .49609 .50114 .49675 .50269 .49626 .50183 .49563 Mtetra
.655 .807 .956 r
.50183 .49563 .50269 .49626 .50424 .49577 .50338 .49514 Mtetra
.658 .809 .956 r
.50338 .49514 .50424 .49577 .50579 .49524 .50494 .49464 Mtetra
.656 .818 .961 r
.50494 .49464 .50579 .49524 .50734 .49467 .50649 .49415 Mtetra
.659 .838 .969 r
.50649 .49415 .50734 .49467 .50889 .49417 .50804 .49362 Mtetra
.678 .834 .959 r
.50804 .49362 .50889 .49417 .51045 .49389 .50959 .49304 Mtetra
.697 .763 .903 r
.50959 .49304 .51045 .49389 .512 .4939 .51115 .49241 Mtetra
.676 .646 .813 r
.51115 .49241 .512 .4939 .51355 .49398 .51271 .49177 Mtetra
.664 .577 .747 r
.51271 .49177 .51355 .49398 .51511 .49368 .51426 .49104 Mtetra
.659 .55 .72 r
.51426 .49104 .51511 .49368 .51667 .4928 .51582 .49023 Mtetra
.623 .533 .731 r
.51582 .49023 .51667 .4928 .51822 .49236 .51738 .4898 Mtetra
.454 .432 .745 r
.51738 .4898 .51822 .49236 .51978 .49371 .51893 .49054 Mtetra
0 0 .416 r
.51893 .49054 .51978 .49371 .52114 .68131 .52049 .49492 Mtetra
0 0 .371 r
.52049 .49492 .52114 .68131 .52278 .69351 .52189 .68797 Mtetra
.168 .146 .588 r
.52189 .68797 .52278 .69351 .52444 .69568 .52354 .69212 Mtetra
.585 .478 .698 r
.52354 .69212 .52444 .69568 .5261 .69554 .5252 .69199 Mtetra
.637 .51 .692 r
.5252 .69199 .5261 .69554 .52776 .69487 .52686 .69123 Mtetra
.609 .491 .693 r
.52686 .69123 .52776 .69487 .52942 .69413 .52852 .69081 Mtetra
.504 .435 .712 r
.52852 .69081 .52942 .69413 .53108 .69374 .53018 .69142 Mtetra
.487 .48 .775 r
.53018 .69142 .53108 .69374 .53274 .69327 .53185 .69191 Mtetra
.496 .598 .885 r
.53185 .69191 .53274 .69327 .53441 .69259 .53351 .69209 Mtetra
.516 .809 .999 r
.53351 .69209 .53441 .69259 .53607 .69159 .53518 .69184 Mtetra
0 0 0 r
.53518 .69184 .53607 .69159 .53773 .69049 .53685 .69145 Mtetra
.282 0 0 r
.53685 .69145 .53773 .69049 .5394 .68971 .53851 .69108 Mtetra
.415 0 .136 r
.53851 .69108 .5394 .68971 .54107 .68965 .54018 .69085 Mtetra
.256 0 .007 r
.54018 .69085 .54107 .68965 .54274 .68916 .54185 .69025 Mtetra
0 0 0 r
.54185 .69025 .54274 .68916 .5444 .68705 .54352 .68857 Mtetra
.958 .891 .505 r
.54352 .68857 .5444 .68705 .54597 .67051 .54516 .68335 Mtetra
.976 .709 .458 r
.54516 .68335 .54597 .67051 .54643 .48487 .54562 .48907 Mtetra
0 0 .061 r
.54562 .48907 .54643 .48487 .54798 .48165 .54716 .48322 Mtetra
.205 0 .087 r
.54716 .48322 .54798 .48165 .54956 .48081 .54874 .4822 Mtetra
.416 .011 .16 r
.54874 .4822 .54956 .48081 .55113 .48047 .55031 .48195 Mtetra
.481 .084 .21 r
.55031 .48195 .55113 .48047 .55271 .48028 .5519 .48193 Mtetra
.389 .009 .192 r
.5519 .48193 .55271 .48028 .55429 .47979 .55348 .48146 Mtetra
.393 .014 .196 r
.55348 .48146 .55429 .47979 .55587 .47932 .55506 .48099 Mtetra
.394 .016 .198 r
.55506 .48099 .55587 .47932 .55745 .47884 .55664 .48053 Mtetra
.391 .014 .199 r
.55664 .48053 .55745 .47884 .55903 .47835 .55822 .48005 Mtetra
.39 .014 .2 r
.55822 .48005 .55903 .47835 .56061 .47786 .55981 .47956 Mtetra
.55981 .47956 .56061 .47786 .56219 .47737 .56139 .47907 Mtetra
.56139 .47907 .56219 .47737 .56378 .47687 .56298 .47857 Mtetra
.39 .014 .201 r
.56298 .47857 .56378 .47687 .56536 .47637 .56456 .47808 Mtetra
.56456 .47808 .56536 .47637 .56695 .47588 .56615 .47758 Mtetra
.56615 .47758 .56695 .47588 .56853 .47538 .56774 .47708 Mtetra
.389 .014 .201 r
.56774 .47708 .56853 .47538 .57012 .47488 .56933 .47658 Mtetra
.56933 .47658 .57012 .47488 .57171 .47438 .57092 .47608 Mtetra
.57092 .47608 .57171 .47438 .5733 .47388 .57251 .47558 Mtetra
.389 .013 .2 r
.57251 .47558 .5733 .47388 .57489 .47338 .5741 .47508 Mtetra
.388 .013 .2 r
.5741 .47508 .57489 .47338 .57648 .47288 .57569 .47457 Mtetra
.387 .012 .199 r
.57569 .47457 .57648 .47288 .57807 .47237 .57728 .47407 Mtetra
.386 .01 .198 r
.57728 .47407 .57807 .47237 .57966 .47186 .57888 .47355 Mtetra
.384 .008 .196 r
.57888 .47355 .57966 .47186 .58125 .47135 .58047 .47304 Mtetra
.378 .002 .192 r
.58047 .47304 .58125 .47135 .58285 .47083 .58207 .4725 Mtetra
.377 0 .19 r
.58207 .4725 .58285 .47083 .58444 .47031 .58366 .47197 Mtetra
.36 0 .179 r
.58366 .47197 .58444 .47031 .58604 .46975 .58526 .47137 Mtetra
.218 0 .105 r
.58526 .47137 .58604 .46975 .58763 .4689 .58685 .47033 Mtetra
.341 0 .128 r
.58685 .47033 .58763 .4689 .58922 .46838 .58845 .4698 Mtetra
.597 .198 .257 r
.58845 .4698 .58922 .46838 .59084 .46861 .59007 .47044 Mtetra
.93 .629 .45 r
.59007 .47044 .59084 .46861 .59253 .47239 .5921 .49095 Mtetra
.933 .654 .488 r
.5921 .49095 .59253 .47239 .59823 .667 .59746 .671 Mtetra
.701 .393 .452 r
.59746 .671 .59823 .667 .60006 .67278 .59924 .67391 Mtetra
.47 .027 .113 r
.59924 .67391 .60006 .67278 .60178 .6729 .60096 .674 Mtetra
.285 0 0 r
.60096 .674 .60178 .6729 .60348 .67227 .60266 .67352 Mtetra
.22 0 .005 r
.60266 .67352 .60348 .67227 .60518 .67142 .60436 .67276 Mtetra
.347 0 .094 r
.60436 .67276 .60518 .67142 .6069 .67161 .60607 .67231 Mtetra
.086 0 0 r
.60607 .67231 .6069 .67161 .60863 .67176 .60778 .67174 Mtetra
.569 .933 .926 r
.60778 .67174 .60863 .67176 .61035 .6718 .60949 .671 Mtetra
.731 .803 .909 r
.60949 .671 .61035 .6718 .61207 .6718 .61119 .67014 Mtetra
.745 .671 .778 r
.61119 .67014 .61207 .6718 .61379 .67135 .61288 .66881 Mtetra
.766 .621 .699 r
.61288 .66881 .61379 .67135 .61548 .67016 .61455 .66643 Mtetra
.898 .659 .569 r
.61455 .66643 .61548 .67016 .61708 .66537 .61592 .65306 Mtetra
.951 .675 .479 r
.61592 .65306 .61708 .66537 .61354 .46987 .61258 .46341 Mtetra
.708 .511 .621 r
.61258 .46341 .61354 .46987 .61497 .46247 .61411 .45972 Mtetra
.669 .553 .714 r
.61411 .45972 .61497 .46247 .61657 .46137 .61571 .45875 Mtetra
.621 .532 .732 r
.61571 .45875 .61657 .46137 .61819 .461 .61733 .45833 Mtetra
.587 .509 .734 r
.61733 .45833 .61819 .461 .61982 .46092 .61896 .45821 Mtetra
.616 .524 .727 r
.61896 .45821 .61982 .46092 .62142 .45984 .62058 .45782 Mtetra
.626 .574 .776 r
.62058 .45782 .62142 .45984 .62302 .45876 .6222 .45743 Mtetra
.642 .66 .853 r
.6222 .45743 .62302 .45876 .62462 .45779 .62382 .45701 Mtetra
.702 .791 .919 r
.62382 .45701 .62462 .45779 .62624 .45723 .62543 .45633 Mtetra
.692 .76 .904 r
.62543 .45633 .62624 .45723 .62786 .45678 .62705 .4557 Mtetra
.658 .709 .885 r
.62705 .4557 .62786 .45678 .62949 .45638 .62867 .45521 Mtetra
.604 .672 .888 r
.62867 .45521 .62949 .45638 .6311 .45545 .6303 .45496 Mtetra
.228 .66 .956 r
.6303 .45496 .6311 .45545 .63271 .45478 .63195 .45517 Mtetra
.658 .149 .025 r
.63195 .45517 .63271 .45478 .63435 .45467 .63363 .45626 Mtetra
.901 .572 .415 r
.63363 .45626 .63435 .45467 .63609 .45754 .63559 .46578 Mtetra
.955 .671 .457 r
.63559 .46578 .63609 .45754 .64437 .65033 .64379 .65744 Mtetra
.666 .388 .49 r
.64379 .65744 .64437 .65033 .64643 .6594 .64565 .66072 Mtetra
.524 .101 .18 r
.64565 .66072 .64643 .6594 .64822 .66053 .64742 .661 Mtetra
0 0 0 r
.64742 .661 .64822 .66053 .64997 .66059 .64915 .66049 Mtetra
.71 .967 .937 r
.64915 .66049 .64997 .66059 .65171 .6602 .65087 .65948 Mtetra
.803 .835 .876 r
.65087 .65948 .65171 .6602 .65345 .65977 .65258 .65819 Mtetra
.769 .689 .775 r
.65258 .65819 .65345 .65977 .65518 .65923 .65427 .65663 Mtetra
.726 .599 .715 r
.65427 .65663 .65518 .65923 .65692 .65862 .65597 .65493 Mtetra
.642 .512 .689 r
.65597 .65493 .65692 .65862 .65866 .6581 .65769 .65405 Mtetra
.609 .482 .682 r
.65769 .65405 .65866 .6581 .6604 .65761 .65943 .65357 Mtetra
.596 .474 .684 r
.65943 .65357 .6604 .65761 .66214 .65712 .66118 .65327 Mtetra
.609 .487 .688 r
.66118 .65327 .66214 .65712 .66388 .65664 .66292 .65281 Mtetra
.611 .489 .689 r
.66292 .65281 .66388 .65664 .66563 .65616 .66467 .65233 Mtetra
.61 .488 .689 r
.66467 .65233 .66563 .65616 .66737 .65569 .66641 .65187 Mtetra
.623 .496 .688 r
.66641 .65187 .66737 .65569 .66912 .65523 .66815 .65123 Mtetra
.613 .486 .683 r
.66815 .65123 .66912 .65523 .67087 .65477 .6699 .65069 Mtetra
.592 .471 .683 r
.6699 .65069 .67087 .65477 .67262 .65432 .67165 .65045 Mtetra
.519 .43 .694 r
.67165 .65045 .67262 .65432 .67437 .65395 .67345 .65104 Mtetra
.492 .449 .738 r
.67345 .65104 .67437 .65395 .67613 .65355 .67525 .65168 Mtetra
.484 .524 .823 r
.67525 .65168 .67613 .65355 .67788 .65303 .67704 .65208 Mtetra
.45 .665 .954 r
.67704 .65208 .67788 .65303 .67963 .6525 .67882 .65221 Mtetra
.437 .835 .979 r
.67882 .65221 .67963 .6525 .68136 .65163 .68058 .65191 Mtetra
.441 .865 .739 r
.68058 .65191 .68136 .65163 .68307 .65002 .68232 .65099 Mtetra
.836 .915 .516 r
.68232 .65099 .68307 .65002 .68458 .64414 .68395 .64779 Mtetra
.834 .734 .21 r
.68395 .64779 .68458 .64414 .67716 .44677 .68527 .63776 Mtetra
.038 0 .43 r
.68527 .63776 .67716 .44677 .67859 .44147 .67795 .44368 Mtetra
0 0 .037 r
.67795 .44368 .67859 .44147 .68019 .44001 .67948 .44069 Mtetra
0 0 0 r
.67948 .44069 .68019 .44001 .68185 .43955 .68109 .43927 Mtetra
.719 .936 .958 r
.68109 .43927 .68185 .43955 .68352 .43946 .68273 .4384 Mtetra
.674 .723 .886 r
.68273 .4384 .68352 .43946 .68518 .43913 .68438 .43782 Mtetra
.634 .664 .862 r
.68438 .43782 .68518 .43913 .68684 .43866 .68604 .43744 Mtetra
.614 .669 .88 r
.68604 .43744 .68684 .43866 .6885 .43816 .68771 .43715 Mtetra
.646 .723 .904 r
.68771 .43715 .6885 .43816 .69015 .43752 .68937 .4367 Mtetra
.666 .777 .932 r
.68937 .4367 .69015 .43752 .6918 .43685 .69103 .43616 Mtetra
.672 .812 .95 r
.69103 .43616 .6918 .43685 .69345 .43629 .69269 .43558 Mtetra
.754 .828 .909 r
.69269 .43558 .69345 .43629 .69511 .43578 .69432 .43464 Mtetra
.717 .725 .857 r
.69432 .43464 .69511 .43578 .69679 .43558 .69597 .43382 Mtetra
.62 .597 .806 r
.69597 .43382 .69679 .43558 .69851 .43606 .69764 .43349 Mtetra
.266 .317 .729 r
.69764 .43349 .69851 .43606 .70043 .44035 .69943 .43523 Mtetra
0 0 .334 r
.69943 .43523 .70043 .44035 .71282 .63722 .7016 .44415 Mtetra
.063 0 .449 r
.7016 .44415 .71282 .63722 .71488 .64202 .71387 .63767 Mtetra
.345 .302 .667 r
.71387 .63767 .71488 .64202 .71673 .64288 .7158 .64005 Mtetra
.505 .462 .743 r
.7158 .64005 .71673 .64288 .71851 .6425 .71764 .64058 Mtetra
.572 .568 .81 r
.71764 .64058 .71851 .6425 .72027 .64163 .71944 .64054 Mtetra
.529 .673 .929 r
.71944 .64054 .72027 .64163 .72204 .64091 .72125 .64051 Mtetra
.476 .829 .996 r
.72125 .64051 .72204 .64091 .7238 .64006 .72304 .64022 Mtetra
.48 .895 .807 r
.72304 .64022 .7238 .64006 .72552 .63854 .7248 .63935 Mtetra
.819 .923 .538 r
.7248 .63935 .72552 .63854 .72704 .63365 .72644 .63643 Mtetra
.866 .763 .256 r
.72644 .63643 .72704 .63365 .71716 .43549 .72774 .62762 Mtetra
.058 0 .442 r
.72774 .62762 .71716 .43549 .71849 .42924 .71792 .43166 Mtetra
0 0 .146 r
.71792 .43166 .71849 .42924 .72009 .42738 .71947 .42895 Mtetra
.369 0 .173 r
.71947 .42895 .72009 .42738 .72176 .42679 .72115 .4284 Mtetra
.474 .086 .223 r
.72115 .4284 .72176 .42679 .72346 .4266 .72285 .42831 Mtetra
.301 0 .17 r
.72285 .42831 .72346 .4266 .72515 .42632 .72451 .4274 Mtetra
0 0 0 r
.72451 .4274 .72515 .42632 .72683 .42589 .72613 .426 Mtetra
.718 .988 .841 r
.72613 .426 .72683 .42589 .72852 .42545 .72777 .42474 Mtetra
.734 .829 .924 r
.72777 .42474 .72852 .42545 .73019 .42486 .72943 .4239 Mtetra
.671 .749 .909 r
.72943 .4239 .73019 .42486 .73187 .42421 .73111 .42334 Mtetra
.65 .762 .931 r
.73111 .42334 .73187 .42421 .73355 .42364 .73279 .42286 Mtetra
.728 .808 .914 r
.73279 .42286 .73355 .42364 .73523 .42313 .73446 .42203 Mtetra
.723 .738 .863 r
.73446 .42203 .73523 .42313 .73693 .42288 .73612 .42117 Mtetra
.631 .61 .811 r
.73612 .42117 .73693 .42288 .73868 .42325 .73781 .42077 Mtetra
.346 .376 .749 r
.73781 .42077 .73868 .42325 .74062 .42661 .73963 .42212 Mtetra
0 0 .463 r
.73963 .42212 .74062 .42661 .75556 .62408 .7418 .42884 Mtetra
.082 .005 .46 r
.7418 .42884 .75556 .62408 .75778 .62978 .75672 .62503 Mtetra
.281 .251 .647 r
.75672 .62503 .75778 .62978 .75971 .63123 .75877 .62825 Mtetra
.482 .442 .736 r
.75877 .62825 .75971 .63123 .76155 .63115 .76066 .62901 Mtetra
.613 .571 .783 r
.76066 .62901 .76155 .63115 .76332 .63013 .76248 .62868 Mtetra
.827 .729 .757 r
.76248 .62868 .76332 .63013 .76493 .62691 .76417 .62649 Mtetra
.982 .801 .585 r
.76417 .62649 .76493 .62691 .76556 .6096 .76557 .62023 Mtetra
.982 .695 .369 r
.76557 .62023 .76556 .6096 .75394 .41915 .75346 .42217 Mtetra
0 0 .127 r
.75346 .42217 .75394 .41915 .75548 .4165 .75488 .4177 Mtetra
0 0 0 r
.75488 .4177 .75548 .4165 .75717 .41586 .75651 .41612 Mtetra
.447 .863 .714 r
.75651 .41612 .75717 .41586 .7589 .41573 .75817 .41517 Mtetra
.694 .86 .962 r
.75817 .41517 .7589 .41573 .76062 .41551 .75986 .41446 Mtetra
.674 .734 .895 r
.75986 .41446 .76062 .41551 .76232 .41497 .76156 .41388 Mtetra
.652 .715 .894 r
.76156 .41388 .76232 .41497 .76401 .41441 .76326 .4134 Mtetra
.716 .755 .883 r
.76326 .4134 .76401 .41441 .76569 .41351 .76494 .4126 Mtetra
.742 .783 .886 r
.76494 .4126 .76569 .41351 .76736 .41253 .76662 .41167 Mtetra
.628 .759 .941 r
.76662 .41167 .76736 .41253 .76907 .41206 .76833 .41126 Mtetra
0 .134 .64 r
.76833 .41126 .76907 .41206 .77092 .41356 .77019 .41285 Mtetra
.975 .675 .378 r
.77019 .41285 .77092 .41356 .77383 .42874 .78588 .59542 Mtetra
.6 .378 .55 r
.78588 .59542 .77383 .42874 .79029 .61938 .78951 .61854 Mtetra
.526 .038 0 r
.78951 .61854 .79029 .61938 .79233 .62173 .79154 .62075 Mtetra
.511 .694 .951 r
.79154 .62075 .79233 .62173 .7942 .62178 .79341 .62073 Mtetra
.737 .768 .878 r
.79341 .62073 .7942 .62178 .79599 .62078 .7952 .61975 Mtetra
.882 .796 .76 r
.7952 .61975 .79599 .62078 .79761 .61768 .79687 .61725 Mtetra
.985 .798 .57 r
.79687 .61725 .79761 .61768 .79806 .59993 .79821 .61063 Mtetra
.982 .691 .351 r
.79821 .61063 .79806 .59993 .78462 .40954 .78418 .41232 Mtetra
0 0 .098 r
.78418 .41232 .78462 .40954 .78615 .40668 .78558 .40783 Mtetra
0 0 0 r
.78558 .40783 .78615 .40668 .78785 .406 .78721 .40627 Mtetra
.425 .849 .703 r
.78721 .40627 .78785 .406 .7896 .40587 .78889 .40533 Mtetra
.68 .866 .97 r
.78889 .40533 .7896 .40587 .79135 .40572 .7906 .40465 Mtetra
.67 .729 .894 r
.7906 .40465 .79135 .40572 .79307 .40521 .79231 .40408 Mtetra
.649 .707 .889 r
.79231 .40408 .79307 .40521 .79478 .40467 .79404 .4036 Mtetra
.699 .74 .883 r
.79404 .4036 .79478 .40467 .79648 .40385 .79574 .40288 Mtetra
.744 .777 .879 r
.79574 .40288 .79648 .40385 .79816 .40283 .79743 .40193 Mtetra
.647 .758 .93 r
.79743 .40193 .79816 .40283 .79988 .40229 .79916 .40145 Mtetra
0 .329 .804 r
.79916 .40145 .79988 .40229 .80174 .40339 .80103 .40262 Mtetra
.938 .57 .191 r
.80103 .40262 .80174 .40339 .80427 .41218 .80363 .41233 Mtetra
.975 .672 .365 r
.80363 .41233 .80427 .41218 .8232 .60952 .82244 .60867 Mtetra
.609 .131 0 r
.82244 .60867 .8232 .60952 .82534 .61236 .82456 .61136 Mtetra
.488 .678 .95 r
.82456 .61136 .82534 .61236 .82724 .6125 .82646 .61141 Mtetra
.73 .762 .879 r
.82646 .61141 .82724 .6125 .82905 .61155 .82827 .61047 Mtetra
.876 .792 .764 r
.82827 .61047 .82905 .61155 .83069 .60865 .82995 .60803 Mtetra
.983 .786 .563 r
.82995 .60803 .83069 .60865 .83117 .5929 .83122 .6011 Mtetra
.98 .686 .342 r
.83122 .6011 .83117 .5929 .81563 .39977 .81519 .40206 Mtetra
0 0 0 r
.81519 .40206 .81563 .39977 .81711 .39649 .81654 .39726 Mtetra
.81654 .39726 .81711 .39649 .8188 .39544 .81815 .39527 Mtetra
.677 .96 .942 r
.81815 .39527 .8188 .39544 .82056 .39524 .81985 .39436 Mtetra
.182 .511 .913 r
.81985 .39436 .82056 .39524 .82244 .39627 .8217 .39507 Mtetra
.852 .458 0 r
.8217 .39507 .82244 .39627 .82465 .40076 .82406 .40131 Mtetra
.975 .669 .355 r
.82406 .40131 .82465 .40076 .84505 .59969 .84457 .6018 Mtetra
.769 .394 .345 r
.84457 .6018 .84505 .59969 .84738 .60424 .84679 .60515 Mtetra
.386 0 0 r
.84679 .60515 .84738 .60424 .84934 .60482 .8487 .60508 Mtetra
.317 .785 .67 r
.8487 .60508 .84934 .60482 .85124 .60467 .85053 .60425 Mtetra
.762 .931 .942 r
.85053 .60425 .85124 .60467 .85313 .60443 .85234 .60314 Mtetra
.708 .72 .859 r
.85234 .60314 .85313 .60443 .85505 .60449 .85417 .60228 Mtetra
.724 .626 .749 r
.85417 .60228 .85505 .60449 .85691 .60398 .85594 .60086 Mtetra
.782 .612 .67 r
.85594 .60086 .85691 .60398 .85863 .60201 .85755 .59769 Mtetra
.976 .676 .371 r
.85755 .59769 .85863 .60201 .85977 .59401 .84039 .40265 Mtetra
.582 .368 .555 r
.84039 .40265 .85977 .59401 .84189 .39324 .84107 .39117 Mtetra
.831 .675 .69 r
.84107 .39117 .84189 .39324 .84329 .38914 .84257 .38817 Mtetra
.725 .773 .891 r
.84257 .38817 .84329 .38914 .845 .3882 .84429 .38731 Mtetra
.617 .753 .942 r
.84429 .38731 .845 .3882 .84677 .38787 .84606 .38693 Mtetra
.631 .746 .931 r
.84606 .38693 .84677 .38787 .84854 .38757 .84782 .38651 Mtetra
.757 .767 .861 r
.84782 .38651 .84854 .38757 .85025 .38658 .84952 .38544 Mtetra
.679 .721 .881 r
.84952 .38544 .85025 .38658 .852 .38604 .85127 .3848 Mtetra
.37 .542 .895 r
.85127 .3848 .852 .38604 .85389 .38675 .85313 .38537 Mtetra
.805 .418 0 r
.85313 .38537 .85389 .38675 .85645 .39409 .85558 .39156 Mtetra
.975 .667 .325 r
.85558 .39156 .85645 .39409 .87896 .59368 .87816 .59216 Mtetra
0 0 .459 r
.87816 .59216 .87896 .59368 .88124 .59702 .88047 .59587 Mtetra
.419 .605 .924 r
.88047 .59587 .88124 .59702 .8832 .59722 .88245 .59621 Mtetra
.695 .772 .91 r
.88245 .59621 .8832 .59722 .88505 .59641 .88431 .59547 Mtetra
.88 .824 .788 r
.88431 .59547 .88505 .59641 .88677 .59434 .88601 .59322 Mtetra
.976 .753 .536 r
.88601 .59322 .88677 .59434 .88809 .58854 .88705 .58473 Mtetra
.976 .673 .354 r
.88705 .58473 .88809 .58854 .86855 .38783 .86749 .38354 Mtetra
.774 .575 .631 r
.86749 .38354 .86855 .38783 .86976 .38211 .86887 .3794 Mtetra
.661 .556 .726 r
.86887 .3794 .86976 .38211 .87141 .38052 .8706 .37851 Mtetra
.607 .573 .79 r
.8706 .37851 .87141 .38052 .87314 .37961 .87239 .37824 Mtetra
.561 .627 .875 r
.87239 .37824 .87314 .37961 .8749 .37903 .87421 .37818 Mtetra
.676 .789 .934 r
.87421 .37818 .8749 .37903 .87667 .37847 .87597 .37756 Mtetra
.664 .769 .928 r
.87597 .37756 .87667 .37847 .87844 .378 .87774 .377 Mtetra
.638 .736 .919 r
.87774 .377 .87844 .378 .88021 .37746 .87953 .37655 Mtetra
.598 .74 .944 r
.87953 .37655 .88021 .37746 .88193 .3764 .88132 .37623 Mtetra
.046 .604 .813 r
.88132 .37623 .88193 .3764 .88369 .37572 .88317 .37637 Mtetra
.654 .153 .045 r
.88317 .37637 .88369 .37572 .88555 .37598 .88515 .37762 Mtetra
.93 .573 .326 r
.88515 .37762 .88555 .37598 .88796 .38101 .88845 .39055 Mtetra
.969 .655 .355 r
.88845 .39055 .88796 .38101 .91277 .5827 .91219 .583 Mtetra
.798 .311 .041 r
.91219 .583 .91277 .5827 .91524 .58712 .91448 .58593 Mtetra
.511 .65 .92 r
.91448 .58593 .91524 .58712 .9172 .58712 .91645 .58598 Mtetra
.671 .736 .899 r
.91645 .58598 .9172 .58712 .91908 .58638 .91835 .58535 Mtetra
.747 .787 .885 r
.91835 .58535 .91908 .58638 .92093 .58537 .92019 .5843 Mtetra
.706 .765 .898 r
.92019 .5843 .92093 .58537 .9229 .58533 .92207 .58348 Mtetra
.737 .666 .78 r
.92207 .58348 .9229 .58533 .92482 .58492 .92388 .58212 Mtetra
.773 .621 .692 r
.92388 .58212 .92482 .58492 .92665 .58368 .92555 .57952 Mtetra
.975 .669 .337 r
.92555 .57952 .92665 .58368 .92799 .57839 .90559 .39423 Mtetra
.6 .381 .555 r
.90559 .39423 .92799 .57839 .90601 .37729 .90473 .37134 Mtetra
.713 .516 .621 r
.90473 .37134 .90601 .37729 .90707 .37064 .90616 .36779 Mtetra
.664 .552 .718 r
.90616 .36779 .90707 .37064 .9088 .36956 .9079 .36682 Mtetra
.617 .53 .734 r
.9079 .36682 .9088 .36956 .91061 .3692 .90971 .3664 Mtetra
.586 .509 .734 r
.90971 .3664 .91061 .3692 .91245 .36909 .91155 .36627 Mtetra
.615 .525 .729 r
.91155 .36627 .91245 .36909 .91417 .36795 .91336 .36585 Mtetra
.624 .575 .779 r
.91336 .36585 .91417 .36795 .9159 .36682 .91517 .36545 Mtetra
.635 .665 .862 r
.91517 .36545 .9159 .36682 .91763 .3658 .91698 .36502 Mtetra
.645 .798 .957 r
.91698 .36502 .91763 .3658 .91942 .36516 .91878 .3645 Mtetra
.649 .833 .971 r
.91878 .3645 .91942 .36516 .92121 .36463 .92057 .36392 Mtetra
.666 .828 .962 r
.92057 .36392 .92121 .36463 .92302 .36415 .92236 .36331 Mtetra
.749 .751 .854 r
.33997 .54527 .34088 .54615 .34236 .54546 .34146 .54436 Mtetra
.706 .701 .843 r
.34146 .54436 .34236 .54546 .34383 .54485 .34293 .54364 Mtetra
.63 .661 .861 r
.34293 .54364 .34383 .54485 .34529 .54439 .34439 .54333 Mtetra
0 .222 .734 r
.34439 .54333 .34529 .54439 .34674 .54418 .34577 .54444 Mtetra
.851 .47 .327 r
.34577 .54444 .34674 .54418 .34816 .54442 .34706 .54732 Mtetra
.932 .677 .528 r
.34706 .54732 .34816 .54442 .34954 .54556 .3389 .7307 Mtetra
.579 .363 .552 r
.3389 .7307 .34954 .54556 .35045 .55598 .33993 .7402 Mtetra
.567 .354 .55 r
.33993 .7402 .35045 .55598 .34241 .74129 .34132 .74276 Mtetra
.667 .293 .326 r
.34132 .74276 .34241 .74129 .34378 .74442 .3428 .7439 Mtetra
.243 .667 .961 r
.3428 .7439 .34378 .74442 .3453 .7447 .34432 .74408 Mtetra
.618 .799 .969 r
.34432 .74408 .3453 .7447 .34685 .74426 .34587 .7437 Mtetra
.762 .834 .908 r
.34587 .7437 .34685 .74426 .34843 .74335 .34745 .74276 Mtetra
.867 .802 .785 r
.34745 .74276 .34843 .74335 .35 .74259 .34909 .74065 Mtetra
.833 .668 .678 r
.34909 .74065 .35 .74259 .35159 .74141 .35081 .73683 Mtetra
.892 .656 .575 r
.35081 .73683 .35159 .74141 .35323 .73934 .35349 .71339 Mtetra
.901 .65 .548 r
.35349 .71339 .35323 .73934 .35519 .73057 .36325 .54188 Mtetra
.57 .36 .556 r
.36325 .54188 .35519 .73057 .36566 .54169 .36487 .53846 Mtetra
.716 .561 .678 r
.36487 .53846 .36566 .54169 .3673 .53771 .36641 .53654 Mtetra
.7 .69 .837 r
.36641 .53654 .3673 .53771 .3688 .53667 .3679 .53584 Mtetra
.61 .733 .933 r
.3679 .53584 .3688 .53667 .37027 .53633 .36937 .53556 Mtetra
.544 .725 .958 r
.36937 .53556 .37027 .53633 .37173 .53629 .37083 .53544 Mtetra
.729 .756 .874 r
.37083 .53544 .37173 .53629 .37321 .53571 .37232 .53465 Mtetra
.712 .713 .849 r
.37232 .53465 .37321 .53571 .3747 .53509 .37381 .53391 Mtetra
.646 .672 .861 r
.37381 .53391 .3747 .53509 .37618 .53461 .37529 .53352 Mtetra
.025 .364 .835 r
.37529 .53352 .37618 .53461 .37765 .53434 .37671 .53441 Mtetra
.845 .433 .257 r
.37671 .53441 .37765 .53434 .3791 .53447 .37806 .53689 Mtetra
.887 .605 .504 r
.37806 .53689 .3791 .53447 .38053 .53534 .3789 .55128 Mtetra
.915 .656 .533 r
.3789 .55128 .38053 .53534 .38175 .54102 .37272 .72983 Mtetra
.568 .354 .55 r
.37272 .72983 .38175 .54102 .37523 .73061 .37415 .73275 Mtetra
.663 .32 .382 r
.37415 .73275 .37523 .73061 .37662 .73454 .37565 .73404 Mtetra
0 .371 .741 r
.37565 .73404 .37662 .73454 .37813 .73551 .37718 .73467 Mtetra
.52 .711 .959 r
.37718 .73467 .37813 .73551 .37969 .73536 .37873 .7346 Mtetra
.744 .789 .889 r
.37873 .7346 .37969 .73536 .38129 .73427 .38033 .73372 Mtetra
.915 .774 .691 r
.38033 .73372 .38129 .73427 .38302 .73002 .38205 .72971 Mtetra
.943 .688 .523 r
.38205 .72971 .38302 .73002 .39218 .53751 .39124 .53772 Mtetra
.959 .763 .596 r
.39124 .53772 .39218 .53751 .39395 .52993 .39305 .5292 Mtetra
.835 .786 .805 r
.39305 .5292 .39395 .52993 .39548 .52833 .39459 .52755 Mtetra
.656 .761 .927 r
.39459 .52755 .39548 .52833 .39697 .52788 .39608 .52711 Mtetra
.49 .706 .966 r
.39608 .52711 .39697 .52788 .39845 .52785 .39755 .5271 Mtetra
.611 .755 .947 r
.39755 .5271 .39845 .52785 .39993 .52752 .39904 .52679 Mtetra
.655 .773 .936 r
.39904 .52679 .39993 .52752 .40143 .52706 .40053 .52634 Mtetra
.667 .779 .933 r
.40053 .52634 .40143 .52706 .40292 .52658 .40203 .52585 Mtetra
.74 .789 .892 r
.40203 .52585 .40292 .52658 .40443 .52572 .40353 .52504 Mtetra
.734 .799 .904 r
.40353 .52504 .40443 .52572 .40594 .52498 .40504 .52427 Mtetra
.659 .779 .937 r
.40504 .52427 .40594 .52498 .40742 .52471 .40654 .5238 Mtetra
.019 .407 .856 r
.40654 .5238 .40742 .52471 .40884 .52661 .40799 .52457 Mtetra
0 .043 .609 r
.40799 .52457 .40884 .52661 .40997 .53675 .4094 .52675 Mtetra
.289 .181 .554 r
.4094 .52675 .40997 .53675 .40516 .72347 .4107 .53219 Mtetra
.554 .347 .554 r
.4107 .53219 .40516 .72347 .40669 .72481 .41202 .53707 Mtetra
.569 .359 .556 r
.41202 .53707 .40669 .72481 .40828 .72434 .41361 .53429 Mtetra
.564 .355 .555 r
.41361 .53429 .40828 .72434 .40988 .72347 .41511 .53381 Mtetra
0 0 .349 r
.41511 .53381 .40988 .72347 .41145 .72366 .41071 .71647 Mtetra
.158 .11 .549 r
.41071 .71647 .41145 .72366 .41301 .72424 .41213 .72158 Mtetra
.056 .172 .67 r
.41213 .72158 .41301 .72424 .41458 .72463 .41364 .72376 Mtetra
.291 .597 .949 r
.41364 .72376 .41458 .72463 .41616 .7245 .41521 .72413 Mtetra
.566 .857 .997 r
.41521 .72413 .41616 .7245 .41776 .72408 .4168 .72374 Mtetra
.664 .889 .98 r
.4168 .72374 .41776 .72408 .41936 .72358 .41841 .72311 Mtetra
.59 .839 .992 r
.41841 .72311 .41936 .72358 .42095 .72321 .42 .72272 Mtetra
.531 .814 .998 r
.42 .72272 .42095 .72321 .42255 .7229 .4216 .72246 Mtetra
.542 .829 .998 r
.4216 .72246 .42255 .7229 .42414 .72257 .42319 .72215 Mtetra
.544 .837 .999 r
.42319 .72215 .42414 .72257 .42574 .72239 .42479 .72183 Mtetra
.635 .826 .974 r
.42479 .72183 .42574 .72239 .42733 .72207 .42639 .72136 Mtetra
.723 .803 .914 r
.42639 .72136 .42733 .72207 .42895 .72128 .42801 .72059 Mtetra
.846 .805 .81 r
.42801 .72059 .42895 .72128 .43061 .71854 .42965 .7188 Mtetra
.959 .9 .723 r
.42965 .7188 .43061 .71854 .43242 .71017 .43132 .71563 Mtetra
0 0 .177 r
.43132 .71563 .43242 .71017 .43892 .51922 .43306 .70998 Mtetra
.547 .337 .547 r
.43306 .70998 .43892 .51922 .4405 .5164 .43488 .70108 Mtetra
.558 .346 .549 r
.43488 .70108 .4405 .5164 .44202 .51575 .43654 .6981 Mtetra
.571 .356 .55 r
.43654 .6981 .44202 .51575 .44353 .51569 .43802 .70265 Mtetra
.565 .351 .55 r
.43802 .70265 .44353 .51569 .44504 .51546 .43959 .70367 Mtetra
.562 .349 .549 r
.43959 .70367 .44504 .51546 .44656 .51499 .44119 .70326 Mtetra
.44119 .70326 .44656 .51499 .44808 .51453 .4428 .70283 Mtetra
.4428 .70283 .44808 .51453 .4496 .51405 .4444 .70228 Mtetra
.4444 .70228 .4496 .51405 .45112 .51356 .44602 .70162 Mtetra
.44602 .70162 .45112 .51356 .45264 .51306 .44763 .70095 Mtetra
.44763 .70095 .45264 .51306 .45417 .51257 .44924 .70033 Mtetra
.44924 .70033 .45417 .51257 .45569 .51209 .45085 .69978 Mtetra
.45085 .69978 .45569 .51209 .45722 .51161 .45247 .69932 Mtetra
.45247 .69932 .45722 .51161 .45874 .51114 .45407 .69901 Mtetra
.562 .35 .549 r
.45407 .69901 .45874 .51114 .46027 .51068 .45568 .6988 Mtetra
.45568 .6988 .46027 .51068 .46179 .51024 .45729 .6986 Mtetra
.565 .352 .55 r
.45729 .6986 .46179 .51024 .46332 .5099 .45887 .70002 Mtetra
.565 .351 .55 r
.45887 .70002 .46332 .5099 .46485 .50959 .46046 .70106 Mtetra
.561 .348 .549 r
.46046 .70106 .46485 .50959 .46638 .50907 .46209 .69972 Mtetra
0 0 .365 r
.46209 .69972 .46638 .50907 .46792 .50796 .46691 .51542 Mtetra
0 0 .246 r
.46691 .51542 .46792 .50796 .46947 .50651 .46856 .50781 Mtetra
.868 .923 .532 r
.46856 .50781 .46947 .50651 .47101 .50522 .47014 .50456 Mtetra
.835 .812 .828 r
.47014 .50456 .47101 .50522 .47255 .50435 .47169 .50303 Mtetra
.674 .666 .834 r
.47169 .50303 .47255 .50435 .47409 .50385 .47323 .50245 Mtetra
.623 .634 .841 r
.47323 .50245 .47409 .50385 .47562 .50346 .47476 .50215 Mtetra
.63 .649 .85 r
.47476 .50215 .47562 .50346 .47715 .50305 .47629 .50181 Mtetra
.657 .671 .852 r
.47629 .50181 .47715 .50305 .47869 .50257 .47783 .50133 Mtetra
.658 .672 .853 r
.47783 .50133 .47869 .50257 .48023 .50209 .47937 .50086 Mtetra
.66 .675 .853 r
.47937 .50086 .48023 .50209 .48176 .5016 .48091 .50037 Mtetra
.662 .677 .854 r
.48091 .50037 .48176 .5016 .4833 .50109 .48245 .49987 Mtetra
.662 .678 .854 r
.48245 .49987 .4833 .50109 .48484 .50059 .48399 .49937 Mtetra
.662 .679 .856 r
.48399 .49937 .48484 .50059 .48638 .50008 .48553 .49888 Mtetra
.661 .68 .857 r
.48553 .49888 .48638 .50008 .48793 .49959 .48707 .49839 Mtetra
.66 .68 .859 r
.48707 .49839 .48793 .49959 .48947 .4991 .48861 .49791 Mtetra
.66 .682 .86 r
.48861 .49791 .48947 .4991 .49101 .49861 .49015 .49742 Mtetra
.659 .682 .861 r
.49015 .49742 .49101 .49861 .49255 .49813 .4917 .49694 Mtetra
.654 .681 .863 r
.4917 .49694 .49255 .49813 .4941 .49766 .49324 .49649 Mtetra
.638 .677 .871 r
.49324 .49649 .4941 .49766 .49564 .49724 .49479 .49611 Mtetra
.619 .678 .884 r
.49479 .49611 .49564 .49724 .49719 .49687 .49633 .49581 Mtetra
.615 .692 .898 r
.49633 .49581 .49719 .49687 .49874 .4965 .49788 .49553 Mtetra
.629 .715 .909 r
.49788 .49553 .49874 .4965 .50028 .49609 .49943 .49518 Mtetra
.652 .736 .911 r
.49943 .49518 .50028 .49609 .50183 .49563 .50098 .49474 Mtetra
.661 .744 .911 r
.50098 .49474 .50183 .49563 .50338 .49514 .50253 .49426 Mtetra
.662 .746 .913 r
.50253 .49426 .50338 .49514 .50494 .49464 .50408 .49378 Mtetra
.66 .749 .915 r
.50408 .49378 .50494 .49464 .50649 .49415 .50563 .4933 Mtetra
.669 .757 .916 r
.50563 .4933 .50649 .49415 .50804 .49362 .50719 .49279 Mtetra
.689 .764 .909 r
.50719 .49279 .50804 .49362 .50959 .49304 .50874 .49219 Mtetra
.708 .765 .897 r
.50874 .49219 .50959 .49304 .51115 .49241 .5103 .49151 Mtetra
.706 .753 .889 r
.5103 .49151 .51115 .49241 .51271 .49177 .51185 .49082 Mtetra
.71 .743 .878 r
.51185 .49082 .51271 .49177 .51426 .49104 .51341 .4901 Mtetra
.71 .747 .881 r
.51341 .4901 .51426 .49104 .51582 .49023 .51497 .48939 Mtetra
.655 .754 .922 r
.51497 .48939 .51582 .49023 .51738 .4898 .51653 .48893 Mtetra
.394 .637 .953 r
.51653 .48893 .51738 .4898 .51893 .49054 .51809 .48915 Mtetra
0 .153 .695 r
.51809 .48915 .51893 .49054 .52049 .49492 .51964 .49078 Mtetra
.083 .113 .594 r
.51964 .49078 .52049 .49492 .52189 .68797 .5212 .4943 Mtetra
.549 .343 .553 r
.5212 .4943 .52189 .68797 .52354 .69212 .52276 .50209 Mtetra
.566 .356 .555 r
.52276 .50209 .52354 .69212 .5252 .69199 .52433 .5006 Mtetra
.567 .357 .555 r
.52433 .5006 .5252 .69199 .52686 .69123 .5259 .49889 Mtetra
.013 0 .409 r
.5259 .49889 .52686 .69123 .52852 .69081 .52761 .67813 Mtetra
.181 .1 .522 r
.52761 .67813 .52852 .69081 .53018 .69142 .52928 .68743 Mtetra
.171 .187 .635 r
.52928 .68743 .53018 .69142 .53185 .69191 .53095 .69041 Mtetra
.125 .357 .819 r
.53095 .69041 .53185 .69191 .53351 .69209 .53262 .6916 Mtetra
.411 .767 .995 r
.53262 .6916 .53351 .69209 .53518 .69184 .53428 .69153 Mtetra
.546 .869 .994 r
.53428 .69153 .53518 .69184 .53685 .69145 .53595 .6911 Mtetra
.605 .883 .991 r
.53595 .6911 .53685 .69145 .53851 .69108 .53762 .69058 Mtetra
.592 .839 .991 r
.53762 .69058 .53851 .69108 .54018 .69085 .53929 .69016 Mtetra
.694 .815 .94 r
.53929 .69016 .54018 .69085 .54185 .69025 .54096 .68949 Mtetra
.798 .813 .863 r
.54096 .68949 .54185 .69025 .54352 .68857 .54263 .68821 Mtetra
.922 .855 .758 r
.54263 .68821 .54352 .68857 .54516 .68335 .54429 .68552 Mtetra
.72 .785 .299 r
.54429 .68552 .54516 .68335 .54562 .48907 .54594 .68112 Mtetra
.549 .339 .548 r
.54594 .68112 .54562 .48907 .54716 .48322 .54756 .67254 Mtetra
.553 .342 .548 r
.54756 .67254 .54716 .48322 .54874 .4822 .54919 .6667 Mtetra
.568 .354 .55 r
.54919 .6667 .54874 .4822 .55031 .48195 .55088 .66977 Mtetra
.567 .353 .55 r
.55088 .66977 .55031 .48195 .5519 .48193 .55258 .67246 Mtetra
.562 .349 .549 r
.55258 .67246 .5519 .48193 .55348 .48146 .55425 .67215 Mtetra
.562 .35 .549 r
.55425 .67215 .55348 .48146 .55506 .48099 .55593 .67188 Mtetra
.562 .349 .549 r
.55593 .67188 .55506 .48099 .55664 .48053 .5576 .67157 Mtetra
.5576 .67157 .55664 .48053 .55822 .48005 .55928 .67118 Mtetra
.55928 .67118 .55822 .48005 .55981 .47956 .56096 .67077 Mtetra
.56096 .67077 .55981 .47956 .56139 .47907 .56263 .67033 Mtetra
.56263 .67033 .56139 .47907 .56298 .47857 .56431 .66989 Mtetra
.56431 .66989 .56298 .47857 .56456 .47808 .56599 .66943 Mtetra
.56599 .66943 .56456 .47808 .56615 .47758 .56767 .66897 Mtetra
.56767 .66897 .56615 .47758 .56774 .47708 .56936 .6685 Mtetra
.56936 .6685 .56774 .47708 .56933 .47658 .57104 .66803 Mtetra
.57104 .66803 .56933 .47658 .57092 .47608 .57272 .66756 Mtetra
.57272 .66756 .57092 .47608 .57251 .47558 .57441 .66708 Mtetra
.57441 .66708 .57251 .47558 .5741 .47508 .57609 .66659 Mtetra
.57609 .66659 .5741 .47508 .57569 .47457 .57778 .66609 Mtetra
.57778 .66609 .57569 .47457 .57728 .47407 .57947 .66558 Mtetra
.57947 .66558 .57728 .47407 .57888 .47355 .58115 .66505 Mtetra
.58115 .66505 .57888 .47355 .58047 .47304 .58284 .66448 Mtetra
.58284 .66448 .58047 .47304 .58207 .4725 .58453 .66382 Mtetra
.58453 .66382 .58207 .4725 .58366 .47197 .58622 .66317 Mtetra
.561 .349 .549 r
.58622 .66317 .58366 .47197 .58526 .47137 .5879 .6622 Mtetra
.555 .344 .549 r
.5879 .6622 .58526 .47137 .58685 .47033 .58951 .65731 Mtetra
.561 .348 .549 r
.58951 .65731 .58685 .47033 .58845 .4698 .59119 .65607 Mtetra
.573 .358 .55 r
.59119 .65607 .58845 .4698 .59007 .47044 .59302 .66272 Mtetra
.59302 .66272 .59007 .47044 .5921 .49095 .59486 .66914 Mtetra
.567 .353 .55 r
.59486 .66914 .5921 .49095 .59746 .671 .59663 .67189 Mtetra
.691 .251 .201 r
.59663 .67189 .59746 .671 .59924 .67391 .59837 .67324 Mtetra
.441 .733 .989 r
.59837 .67324 .59924 .67391 .60096 .674 .60009 .67323 Mtetra
.607 .774 .96 r
.60009 .67323 .60096 .674 .60266 .67352 .6018 .67287 Mtetra
.657 .821 .962 r
.6018 .67287 .60266 .67352 .60436 .67276 .60351 .67231 Mtetra
.542 .838 .999 r
.60351 .67231 .60436 .67276 .60607 .67231 .60522 .67196 Mtetra
.627 .894 .987 r
.60522 .67196 .60607 .67231 .60778 .67174 .60693 .67136 Mtetra
.768 .912 .937 r
.60693 .67136 .60778 .67174 .60949 .671 .60863 .67032 Mtetra
.892 .823 .773 r
.60863 .67032 .60949 .671 .61119 .67014 .61029 .66791 Mtetra
.849 .671 .661 r
.61029 .66791 .61119 .67014 .61288 .66881 .61191 .6636 Mtetra
.96 .684 .469 r
.61191 .6636 .61288 .66881 .61455 .66643 .60882 .47449 Mtetra
.582 .368 .556 r
.60882 .47449 .61455 .66643 .61592 .65306 .61017 .46384 Mtetra
.569 .359 .556 r
.61017 .46384 .61592 .65306 .61258 .46341 .61172 .46056 Mtetra
.73 .584 .692 r
.61172 .46056 .61258 .46341 .61411 .45972 .61329 .45864 Mtetra
.715 .728 .86 r
.61329 .45864 .61411 .45972 .61571 .45875 .6149 .45784 Mtetra
.647 .743 .92 r
.6149 .45784 .61571 .45875 .61733 .45833 .61652 .4574 Mtetra
.591 .718 .932 r
.61652 .4574 .61733 .45833 .61896 .45821 .61814 .45716 Mtetra
.626 .704 .902 r
.61814 .45716 .61896 .45821 .62058 .45782 .61976 .45681 Mtetra
.625 .713 .909 r
.61976 .45681 .62058 .45782 .6222 .45743 .62139 .45646 Mtetra
.636 .726 .913 r
.62139 .45646 .6222 .45743 .62382 .45701 .62301 .45607 Mtetra
.738 .762 .872 r
.62301 .45607 .62382 .45701 .62543 .45633 .62462 .45517 Mtetra
.704 .712 .855 r
.62462 .45517 .62543 .45633 .62705 .4557 .62623 .45443 Mtetra
.632 .666 .865 r
.62623 .45443 .62705 .4557 .62867 .45521 .62786 .45406 Mtetra
.058 .368 .836 r
.62786 .45406 .62867 .45521 .6303 .45496 .62953 .45514 Mtetra
.843 .404 .182 r
.62953 .45514 .6303 .45496 .63195 .45517 .63127 .45801 Mtetra
.963 .678 .447 r
.63127 .45801 .63195 .45517 .63363 .45626 .63911 .6461 Mtetra
.579 .362 .551 r
.63911 .6461 .63363 .45626 .63559 .46578 .64119 .6564 Mtetra
.567 .353 .55 r
.64119 .6564 .63559 .46578 .64379 .65744 .64303 .65904 Mtetra
.65 .258 .289 r
.64303 .65904 .64379 .65744 .64565 .66072 .64482 .66018 Mtetra
.291 .693 .974 r
.64482 .66018 .64565 .66072 .64742 .661 .64657 .66033 Mtetra
.622 .808 .972 r
.64657 .66033 .64742 .661 .64915 .66049 .64831 .65988 Mtetra
.766 .859 .918 r
.64831 .65988 .64915 .66049 .65087 .65948 .65003 .65884 Mtetra
.906 .833 .763 r
.65003 .65884 .65087 .65948 .65258 .65819 .65169 .65626 Mtetra
.876 .695 .654 r
.65169 .65626 .65258 .65819 .65427 .65663 .65327 .65155 Mtetra
.964 .684 .455 r
.65327 .65155 .65427 .65663 .65597 .65493 .64797 .46325 Mtetra
.575 .363 .556 r
.64797 .46325 .65597 .65493 .65769 .65405 .64939 .45674 Mtetra
.564 .355 .555 r
.64939 .45674 .65769 .65405 .65943 .65357 .65103 .45627 Mtetra
.561 .353 .555 r
.65103 .45627 .65943 .65357 .66118 .65327 .65275 .45764 Mtetra
.564 .355 .555 r
.65275 .45764 .66118 .65327 .66292 .65281 .6544 .45744 Mtetra
.6544 .45744 .66292 .65281 .66467 .65233 .65605 .45695 Mtetra
.65605 .45695 .66467 .65233 .66641 .65187 .6577 .45655 Mtetra
.568 .357 .555 r
.6577 .45655 .66641 .65187 .66815 .65123 .65926 .45415 Mtetra
.565 .356 .555 r
.65926 .45415 .66815 .65123 .6699 .65069 .66089 .45308 Mtetra
.56 .352 .555 r
.66089 .45308 .6699 .65069 .67165 .65045 .66263 .45494 Mtetra
.064 0 .445 r
.66263 .45494 .67165 .65045 .67345 .65104 .67236 .64437 Mtetra
.236 .186 .595 r
.67236 .64437 .67345 .65104 .67525 .65168 .67434 .64917 Mtetra
.167 .267 .723 r
.67434 .64917 .67525 .65168 .67704 .65208 .6762 .65123 Mtetra
.31 .614 .955 r
.6762 .65123 .67704 .65208 .67882 .65221 .67799 .6516 Mtetra
.581 .813 .987 r
.67799 .6516 .67882 .65221 .68058 .65191 .67976 .65123 Mtetra
.743 .841 .925 r
.67976 .65123 .68058 .65191 .68232 .65099 .68149 .65031 Mtetra
.859 .846 .83 r
.68149 .65031 .68232 .65099 .68395 .64779 .68319 .64851 Mtetra
.886 .95 .596 r
.68319 .64851 .68395 .64779 .68527 .63776 .68483 .64549 Mtetra
.156 0 .38 r
.68483 .64549 .68527 .63776 .67795 .44368 .68631 .63898 Mtetra
.056 0 .437 r
.68631 .63898 .67795 .44368 .67948 .44069 .67895 .44509 Mtetra
0 0 .239 r
.67895 .44509 .67948 .44069 .68109 .43927 .68039 .43999 Mtetra
.811 .938 .574 r
.68039 .43999 .68109 .43927 .68273 .4384 .68195 .43748 Mtetra
.751 .776 .874 r
.68195 .43748 .68273 .4384 .68438 .43782 .68358 .4365 Mtetra
.625 .657 .861 r
.68358 .4365 .68438 .43782 .68604 .43744 .68524 .43616 Mtetra
.566 .638 .881 r
.68524 .43616 .68604 .43744 .68771 .43715 .68692 .43608 Mtetra
.621 .702 .903 r
.68692 .43608 .68771 .43715 .68937 .4367 .68859 .43574 Mtetra
.658 .74 .91 r
.68859 .43574 .68937 .4367 .69103 .43616 .69025 .43524 Mtetra
.673 .755 .912 r
.69025 .43524 .69103 .43616 .69269 .43558 .69191 .43467 Mtetra
.736 .777 .886 r
.69191 .43467 .69269 .43558 .69432 .43464 .69355 .4338 Mtetra
.731 .789 .899 r
.69355 .4338 .69432 .43464 .69597 .43382 .69519 .43296 Mtetra
.662 .765 .927 r
.69519 .43296 .69597 .43382 .69764 .43349 .69686 .43244 Mtetra
.332 .562 .921 r
.69686 .43244 .69764 .43349 .69943 .43523 .69857 .43293 Mtetra
.199 .294 .737 r
.69857 .43293 .69943 .43523 .7016 .44415 .70036 .43474 Mtetra
.311 .214 .581 r
.70036 .43474 .7016 .44415 .71387 .63767 .70237 .44044 Mtetra
.078 0 .454 r
.70237 .44044 .71387 .63767 .7158 .64005 .71467 .63347 Mtetra
.289 .226 .61 r
.71467 .63347 .7158 .64005 .71764 .64058 .71671 .63772 Mtetra
.31 .338 .729 r
.71671 .63772 .71764 .64058 .71944 .64054 .71861 .63945 Mtetra
.372 .592 .93 r
.71861 .63945 .71944 .64054 .72125 .64051 .72044 .63986 Mtetra
.573 .803 .986 r
.72044 .63986 .72125 .64051 .72304 .64022 .72223 .63952 Mtetra
.733 .838 .929 r
.72223 .63952 .72304 .64022 .7248 .63935 .724 .63863 Mtetra
.867 .842 .818 r
.724 .63863 .7248 .63935 .72644 .63643 .7257 .6367 Mtetra
.963 .942 .668 r
.7257 .6367 .72644 .63643 .72774 .62762 .72732 .63343 Mtetra
.069 0 .326 r
.72732 .63343 .72774 .62762 .71792 .43166 .72879 .62762 Mtetra
.555 .344 .549 r
.72879 .62762 .71792 .43166 .71947 .42895 .7303 .62258 Mtetra
.564 .351 .549 r
.7303 .62258 .71947 .42895 .72115 .4284 .73216 .62328 Mtetra
.563 .35 .549 r
.73216 .62328 .72115 .4284 .72285 .42831 .73397 .62329 Mtetra
.099 .01 .456 r
.73397 .62329 .72285 .42831 .72451 .4274 .72426 .43502 Mtetra
.081 0 .366 r
.72426 .43502 .72451 .4274 .72613 .426 .72551 .42749 Mtetra
0 0 0 r
.72551 .42749 .72613 .426 .72777 .42474 .72703 .42423 Mtetra
.841 .887 .874 r
.72703 .42423 .72777 .42474 .72943 .4239 .72865 .42279 Mtetra
.676 .719 .881 r
.72865 .42279 .72943 .4239 .73111 .42334 .73033 .4222 Mtetra
.626 .693 .892 r
.73033 .4222 .73111 .42334 .73279 .42286 .73202 .42184 Mtetra
.699 .746 .888 r
.73202 .42184 .73279 .42286 .73446 .42203 .7337 .42114 Mtetra
.731 .782 .893 r
.7337 .42114 .73446 .42203 .73612 .42117 .73536 .42028 Mtetra
.669 .764 .921 r
.73536 .42028 .73612 .42117 .73781 .42077 .73705 .41973 Mtetra
.4 .602 .928 r
.73705 .41973 .73781 .42077 .73963 .42212 .73879 .42006 Mtetra
.201 .318 .761 r
.73879 .42006 .73963 .42212 .7418 .42884 .74062 .42171 Mtetra
.289 .217 .6 r
.74062 .42171 .7418 .42884 .75672 .62503 .74267 .42643 Mtetra
.098 .016 .465 r
.74267 .42643 .75672 .62503 .75877 .62825 .75752 .6207 Mtetra
.306 .229 .603 r
.75752 .6207 .75877 .62825 .76066 .62901 .75968 .62548 Mtetra
.396 .364 .705 r
.75968 .62548 .76066 .62901 .76248 .62868 .76163 .62707 Mtetra
.639 .638 .833 r
.76163 .62707 .76248 .62868 .76417 .62649 .76344 .62661 Mtetra
.904 .985 .763 r
.76344 .62661 .76417 .62649 .76557 .62023 .76513 .62434 Mtetra
.011 0 .261 r
.76513 .62434 .76557 .62023 .75346 .42217 .76665 .61974 Mtetra
.106 .018 .462 r
.76665 .61974 .75346 .42217 .75488 .4177 .75486 .42704 Mtetra
.116 0 .398 r
.75486 .42704 .75488 .4177 .75651 .41612 .75596 .4181 Mtetra
0 0 0 r
.75596 .4181 .75651 .41612 .75817 .41517 .75747 .41493 Mtetra
.856 .959 .873 r
.75747 .41493 .75817 .41517 .75986 .41446 .7591 .4134 Mtetra
.69 .734 .885 r
.7591 .4134 .75986 .41446 .76156 .41388 .76079 .41273 Mtetra
.631 .694 .891 r
.76079 .41273 .76156 .41388 .76326 .4134 .7625 .41234 Mtetra
.7 .741 .884 r
.7625 .41234 .76326 .4134 .76494 .4126 .76419 .41163 Mtetra
.74 .771 .878 r
.76419 .41163 .76494 .4126 .76662 .41167 .76587 .4107 Mtetra
.631 .734 .922 r
.76587 .4107 .76662 .41167 .76833 .41126 .76758 .4103 Mtetra
0 .18 .7 r
.76758 .4103 .76833 .41126 .77019 .41285 .76945 .4119 Mtetra
.975 .676 .377 r
.76945 .4119 .77019 .41285 .78588 .59542 .78531 .59721 Mtetra
.943 .616 .381 r
.78531 .59721 .78588 .59542 .78951 .61854 .78872 .61764 Mtetra
0 .011 .533 r
.78872 .61764 .78951 .61854 .79154 .62075 .79075 .61975 Mtetra
.548 .705 .943 r
.79075 .61975 .79154 .62075 .79341 .62073 .79261 .61962 Mtetra
.726 .755 .875 r
.79261 .61962 .79341 .62073 .7952 .61975 .7944 .6187 Mtetra
.817 .787 .824 r
.7944 .6187 .7952 .61975 .79687 .61725 .79614 .61707 Mtetra
.941 .938 .763 r
.79614 .61707 .79687 .61725 .79821 .61063 .79781 .61451 Mtetra
0 0 .243 r
.79781 .61451 .79821 .61063 .78418 .41232 .7993 .6098 Mtetra
.118 .029 .469 r
.7993 .6098 .78418 .41232 .78558 .40783 .78561 .41647 Mtetra
.135 0 .402 r
.78561 .41647 .78558 .40783 .78721 .40627 .78671 .40829 Mtetra
0 0 .037 r
.78671 .40829 .78721 .40627 .78889 .40533 .78822 .40516 Mtetra
.859 .977 .859 r
.78822 .40516 .78889 .40533 .7906 .40465 .78985 .40356 Mtetra
.69 .732 .883 r
.78985 .40356 .7906 .40465 .79231 .40408 .79156 .40289 Mtetra
.63 .688 .885 r
.79156 .40289 .79231 .40408 .79404 .4036 .79329 .4025 Mtetra
.679 .725 .885 r
.79329 .4025 .79404 .4036 .79574 .40288 .795 .40188 Mtetra
.742 .768 .874 r
.795 .40188 .79574 .40288 .79743 .40193 .79669 .40093 Mtetra
.648 .736 .913 r
.79669 .40093 .79743 .40193 .79916 .40145 .79842 .40045 Mtetra
.001 .358 .831 r
.79842 .40045 .79916 .40145 .80103 .40262 .80029 .40163 Mtetra
.934 .567 .169 r
.80029 .40163 .80103 .40262 .80363 .41233 .8029 .41138 Mtetra
.975 .673 .361 r
.8029 .41138 .80363 .41233 .82244 .60867 .82167 .60772 Mtetra
.557 .091 0 r
.82167 .60772 .82244 .60867 .82456 .61136 .82378 .61035 Mtetra
.529 .694 .944 r
.82378 .61035 .82456 .61136 .82646 .61141 .82567 .61028 Mtetra
.725 .751 .873 r
.82567 .61028 .82646 .61141 .82827 .61047 .82748 .60935 Mtetra
.822 .781 .814 r
.82748 .60935 .82827 .61047 .82995 .60803 .82922 .60763 Mtetra
.947 .898 .744 r
.82922 .60763 .82995 .60803 .83122 .6011 .83087 .60479 Mtetra
0 0 .164 r
.83087 .60479 .83122 .6011 .81519 .40206 .83223 .5989 Mtetra
.119 .033 .473 r
.83223 .5989 .81519 .40206 .81654 .39726 .81636 .40227 Mtetra
.004 0 .31 r
.81636 .40227 .81654 .39726 .81815 .39527 .8176 .39628 Mtetra
0 0 0 r
.8176 .39628 .81815 .39527 .81985 .39436 .81916 .39382 Mtetra
.458 .779 .998 r
.81916 .39382 .81985 .39436 .8217 .39507 .82093 .39369 Mtetra
.779 .386 0 r
.82093 .39369 .8217 .39507 .82406 .40131 .82322 .39905 Mtetra
.976 .671 .345 r
.82322 .39905 .82406 .40131 .84457 .6018 .84379 .60061 Mtetra
.648 .222 0 r
.84379 .60061 .84457 .6018 .84679 .60515 .84604 .60434 Mtetra
.467 .716 .977 r
.84604 .60434 .84679 .60515 .8487 .60508 .84795 .60434 Mtetra
.734 .844 .932 r
.84795 .60434 .8487 .60508 .85053 .60425 .84978 .60342 Mtetra
.85 .842 .837 r
.84978 .60342 .85053 .60425 .85234 .60314 .85152 .60166 Mtetra
.867 .742 .723 r
.85152 .60166 .85234 .60314 .85417 .60228 .85316 .59877 Mtetra
.844 .635 .619 r
.85316 .59877 .85417 .60228 .85594 .60086 .85452 .59296 Mtetra
.973 .673 .383 r
.85452 .59296 .85594 .60086 .85755 .59769 .83745 .39748 Mtetra
.573 .361 .555 r
.83745 .39748 .85755 .59769 .84039 .40265 .83868 .39158 Mtetra
.637 .438 .597 r
.83868 .39158 .84039 .40265 .84107 .39117 .84021 .3888 Mtetra
.732 .612 .724 r
.84021 .3888 .84107 .39117 .84257 .38817 .84186 .38719 Mtetra
.697 .762 .902 r
.84186 .38719 .84257 .38817 .84429 .38731 .84359 .38648 Mtetra
.632 .773 .948 r
.84359 .38648 .84429 .38731 .84606 .38693 .84535 .38603 Mtetra
.669 .77 .926 r
.84535 .38603 .84606 .38693 .84782 .38651 .8471 .38545 Mtetra
.768 .769 .854 r
.8471 .38545 .84782 .38651 .84952 .38544 .84879 .38429 Mtetra
.694 .728 .876 r
.84879 .38429 .84952 .38544 .85127 .3848 .85053 .38358 Mtetra
.394 .562 .901 r
.85053 .38358 .85127 .3848 .85313 .38537 .85239 .38406 Mtetra
.79 .396 0 r
.85239 .38406 .85313 .38537 .85558 .39156 .85479 .38975 Mtetra
.975 .667 .328 r
.85479 .38975 .85558 .39156 .87816 .59216 .87738 .59096 Mtetra
.644 .222 0 r
.87738 .59096 .87816 .59216 .88047 .59587 .87972 .59488 Mtetra
.364 .613 .946 r
.87972 .59488 .88047 .59587 .88245 .59621 .8817 .59526 Mtetra
.693 .783 .92 r
.8817 .59526 .88245 .59621 .88431 .59547 .88356 .59453 Mtetra
.881 .825 .787 r
.88356 .59453 .88431 .59547 .88601 .59322 .88527 .59227 Mtetra
.982 .758 .524 r
.88527 .59227 .88601 .59322 .88705 .58473 .88628 .58347 Mtetra
.977 .674 .345 r
.88628 .58347 .88705 .58473 .86749 .38354 .86675 .3823 Mtetra
.928 .766 .659 r
.86675 .3823 .86749 .38354 .86887 .3794 .86815 .37824 Mtetra
.714 .733 .866 r
.86815 .37824 .86887 .3794 .8706 .37851 .86988 .3774 Mtetra
.585 .686 .911 r
.86988 .3774 .8706 .37851 .87239 .37824 .87168 .37718 Mtetra
.531 .672 .927 r
.87168 .37718 .87239 .37824 .87421 .37818 .87351 .37715 Mtetra
.704 .756 .892 r
.87351 .37715 .87421 .37818 .87597 .37756 .87525 .37639 Mtetra
.667 .713 .883 r
.87525 .37639 .87597 .37756 .87774 .377 .87702 .37581 Mtetra
.561 .661 .904 r
.87702 .37581 .87774 .377 .87953 .37655 .87884 .37571 Mtetra
0 .316 .796 r
.87884 .37571 .87953 .37655 .88132 .37623 .88082 .37699 Mtetra
.824 .381 .185 r
.88082 .37699 .88132 .37623 .88317 .37637 .88303 .3803 Mtetra
.972 .659 .335 r
.88303 .3803 .88317 .37637 .88515 .37762 .90663 .57391 Mtetra
.573 .357 .549 r
.90663 .57391 .88515 .37762 .88845 .39055 .90945 .58163 Mtetra
.566 .352 .549 r
.90945 .58163 .88845 .39055 .91219 .583 .91168 .584 Mtetra
.61 .14 .113 r
.91168 .584 .91219 .583 .91448 .58593 .91376 .58498 Mtetra
.492 .695 .959 r
.91376 .58498 .91448 .58593 .91645 .58598 .91572 .58498 Mtetra
.658 .762 .926 r
.91572 .58498 .91645 .58598 .91835 .58535 .91762 .58441 Mtetra
.78 .816 .881 r
.91762 .58441 .91835 .58535 .92019 .5843 .91945 .58317 Mtetra
.888 .798 .755 r
.91945 .58317 .92019 .5843 .92207 .58348 .92112 .58057 Mtetra
.854 .656 .634 r
.92112 .58057 .92207 .58348 .92388 .58212 .92251 .57562 Mtetra
.974 .667 .345 r
.92251 .57562 .92388 .58212 .92555 .57952 .9014 .37937 Mtetra
.575 .363 .555 r
.9014 .37937 .92555 .57952 .90559 .39423 .90235 .37167 Mtetra
.605 .399 .575 r
.90235 .37167 .90559 .39423 .90473 .37134 .90383 .36853 Mtetra
.732 .592 .699 r
.90383 .36853 .90473 .37134 .90616 .36779 .90546 .36663 Mtetra
.705 .734 .873 r
.90546 .36663 .90616 .36779 .9079 .36682 .90722 .36584 Mtetra
.634 .742 .926 r
.90722 .36584 .9079 .36682 .90971 .3664 .90902 .3654 Mtetra
.584 .714 .932 r
.90902 .3654 .90971 .3664 .91155 .36627 .91085 .36515 Mtetra
.619 .705 .906 r
.91085 .36515 .91155 .36627 .91336 .36585 .91267 .36479 Mtetra
.615 .715 .916 r
.91267 .36479 .91336 .36585 .91517 .36545 .91448 .36444 Mtetra
.621 .73 .924 r
.91448 .36444 .91517 .36545 .91698 .36502 .9163 .36405 Mtetra
.656 .755 .923 r
.9163 .36405 .91698 .36502 .91878 .3645 .9181 .36351 Mtetra
.673 .759 .915 r
.9181 .36351 .91878 .3645 .92057 .36392 .91989 .3629 Mtetra
.686 .756 .904 r
.91989 .3629 .92057 .36392 .92236 .36331 .92167 .36223 Mtetra
.754 .753 .851 r
.33906 .5444 .33997 .54527 .34146 .54436 .34055 .54345 Mtetra
.701 .737 .879 r
.34055 .54345 .34146 .54436 .34293 .54364 .34202 .54281 Mtetra
.524 .701 .95 r
.34202 .54281 .34293 .54364 .34439 .54333 .34346 .54276 Mtetra
.896 .485 .207 r
.34346 .54276 .34439 .54333 .34577 .54444 .34474 .54575 Mtetra
.935 .679 .527 r
.34474 .54575 .34577 .54444 .34706 .54732 .3362 .73387 Mtetra
.577 .361 .552 r
.3362 .73387 .34706 .54732 .3389 .7307 .3373 .74202 Mtetra
.586 .341 .512 r
.3373 .74202 .3389 .7307 .33993 .7402 .33877 .74306 Mtetra
.543 .221 .373 r
.33877 .74306 .33993 .7402 .34132 .74276 .34029 .74319 Mtetra
.045 0 0 r
.34029 .74319 .34132 .74276 .3428 .7439 .34184 .74288 Mtetra
.5 .66 .932 r
.34184 .74288 .3428 .7439 .34432 .74408 .34337 .74293 Mtetra
.629 .683 .882 r
.34337 .74293 .34432 .74408 .34587 .7437 .34492 .74259 Mtetra
.741 .721 .833 r
.34492 .74259 .34587 .7437 .34745 .74276 .3465 .7416 Mtetra
.875 .721 .688 r
.3465 .7416 .34745 .74276 .34909 .74065 .34823 .73768 Mtetra
.935 .684 .533 r
.34823 .73768 .34909 .74065 .35081 .73683 .35899 .55013 Mtetra
.584 .371 .558 r
.35899 .55013 .35081 .73683 .35349 .71339 .36098 .53934 Mtetra
.567 .358 .556 r
.36098 .53934 .35349 .71339 .36325 .54188 .36252 .53737 Mtetra
.638 .484 .658 r
.36252 .53737 .36325 .54188 .36487 .53846 .36402 .53639 Mtetra
.65 .574 .756 r
.36402 .53639 .36487 .53846 .36641 .53654 .3655 .53583 Mtetra
.668 .78 .933 r
.3655 .53583 .36641 .53654 .3679 .53584 .36698 .53534 Mtetra
.617 .825 .98 r
.36698 .53534 .3679 .53584 .36937 .53556 .36845 .53495 Mtetra
.613 .794 .968 r
.36845 .53495 .36937 .53556 .37083 .53544 .36992 .5346 Mtetra
.743 .763 .869 r
.36992 .5346 .37083 .53544 .37232 .53465 .37142 .53374 Mtetra
.709 .741 .877 r
.37142 .53374 .37232 .53465 .37381 .53391 .37291 .53306 Mtetra
.566 .714 .941 r
.37291 .53306 .37381 .53391 .37529 .53352 .37437 .53291 Mtetra
.861 .41 .086 r
.37437 .53291 .37529 .53352 .37671 .53441 .37573 .53536 Mtetra
.939 .68 .519 r
.37573 .53536 .37671 .53441 .37806 .53689 .36906 .72016 Mtetra
.583 .367 .552 r
.36906 .72016 .37806 .53689 .3789 .55128 .37007 .73233 Mtetra
.565 .352 .55 r
.37007 .73233 .3789 .55128 .37272 .72983 .37156 .7337 Mtetra
.55 .254 .417 r
.37156 .7337 .37272 .72983 .37415 .73275 .37311 .73383 Mtetra
.328 0 .013 r
.37311 .73383 .37415 .73275 .37565 .73404 .37468 .73352 Mtetra
.285 .689 .972 r
.37468 .73352 .37565 .73404 .37718 .73467 .37623 .73365 Mtetra
.575 .692 .921 r
.37623 .73365 .37718 .73467 .37873 .7346 .37779 .73349 Mtetra
.723 .719 .846 r
.37779 .73349 .37873 .7346 .38033 .73372 .37938 .73263 Mtetra
.885 .73 .684 r
.37938 .73263 .38033 .73372 .38205 .72971 .38111 .72855 Mtetra
.942 .687 .524 r
.38111 .72855 .38205 .72971 .39124 .53772 .39036 .53648 Mtetra
.911 .706 .614 r
.39036 .53648 .39124 .53772 .39305 .5292 .39215 .52842 Mtetra
.828 .776 .803 r
.39215 .52842 .39305 .5292 .39459 .52755 .39369 .5268 Mtetra
.654 .766 .932 r
.39369 .5268 .39459 .52755 .39608 .52711 .39518 .52636 Mtetra
.484 .71 .97 r
.39518 .52636 .39608 .52711 .39755 .5271 .39665 .52635 Mtetra
.612 .756 .947 r
.39665 .52635 .39755 .5271 .39904 .52679 .39814 .52604 Mtetra
.655 .767 .932 r
.39814 .52604 .39904 .52679 .40053 .52634 .39963 .52559 Mtetra
.663 .77 .929 r
.39963 .52559 .40053 .52634 .40203 .52585 .40113 .52512 Mtetra
.7 .781 .914 r
.40113 .52512 .40203 .52585 .40353 .52504 .40263 .5245 Mtetra
.701 .832 .945 r
.40263 .5245 .40353 .52504 .40504 .52427 .40413 .52386 Mtetra
.658 .865 .978 r
.40413 .52386 .40504 .52427 .40654 .5238 .40563 .52333 Mtetra
.486 .792 .999 r
.40563 .52333 .40654 .5238 .40799 .52457 .40712 .52317 Mtetra
.537 .592 .857 r
.40712 .52317 .40799 .52457 .4094 .52675 .4086 .52323 Mtetra
.561 .455 .691 r
.4086 .52323 .4094 .52675 .4107 .53219 .41008 .52335 Mtetra
.594 .415 .61 r
.41008 .52335 .4107 .53219 .41202 .53707 .41159 .52268 Mtetra
.584 .393 .589 r
.41159 .52268 .41202 .53707 .41361 .53429 .4131 .52193 Mtetra
.572 .388 .593 r
.4131 .52193 .41361 .53429 .41511 .53381 .41459 .52177 Mtetra
.445 .291 .578 r
.41459 .52177 .41511 .53381 .41071 .71647 .41597 .52527 Mtetra
0 0 .331 r
.41597 .52527 .41071 .71647 .41213 .72158 .4113 .71705 Mtetra
0 0 .412 r
.4113 .71705 .41213 .72158 .41364 .72376 .41271 .7223 Mtetra
.215 .422 .849 r
.41271 .7223 .41364 .72376 .41521 .72413 .41427 .7232 Mtetra
.627 .73 .921 r
.41427 .7232 .41521 .72413 .4168 .72374 .41586 .72284 Mtetra
.716 .76 .888 r
.41586 .72284 .4168 .72374 .41841 .72311 .41747 .72208 Mtetra
.67 .723 .889 r
.41747 .72208 .41841 .72311 .42 .72272 .41907 .72155 Mtetra
.636 .685 .88 r
.41907 .72155 .42 .72272 .4216 .72246 .42067 .72117 Mtetra
.639 .667 .86 r
.42067 .72117 .4216 .72246 .42319 .72215 .42227 .72077 Mtetra
.641 .653 .847 r
.42227 .72077 .42319 .72215 .42479 .72183 .42387 .72036 Mtetra
.648 .644 .833 r
.42387 .72036 .42479 .72183 .42639 .72136 .42547 .71989 Mtetra
.665 .652 .827 r
.42547 .71989 .42639 .72136 .42801 .72059 .42708 .71933 Mtetra
.715 .698 .832 r
.42708 .71933 .42801 .72059 .42965 .7188 .4287 .71848 Mtetra
.786 .903 .923 r
.4287 .71848 .42965 .7188 .43132 .71563 .43032 .7174 Mtetra
.185 0 .08 r
.43032 .7174 .43132 .71563 .43306 .70998 .43194 .71628 Mtetra
.504 .243 .453 r
.43194 .71628 .43306 .70998 .43488 .70108 .43356 .71549 Mtetra
.547 .313 .512 r
.43356 .71549 .43488 .70108 .43654 .6981 .43516 .71503 Mtetra
.551 .321 .519 r
.43516 .71503 .43654 .6981 .43802 .70265 .43677 .71468 Mtetra
.545 .306 .504 r
.43677 .71468 .43802 .70265 .43959 .70367 .43838 .71428 Mtetra
.541 .299 .497 r
.43838 .71428 .43959 .70367 .44119 .70326 .43999 .71383 Mtetra
.54 .298 .497 r
.43999 .71383 .44119 .70326 .4428 .70283 .4416 .71337 Mtetra
.4416 .71337 .4428 .70283 .4444 .70228 .44321 .7129 Mtetra
.44321 .7129 .4444 .70228 .44602 .70162 .44483 .71242 Mtetra
.54 .299 .498 r
.44483 .71242 .44602 .70162 .44763 .70095 .44644 .71194 Mtetra
.541 .3 .499 r
.44644 .71194 .44763 .70095 .44924 .70033 .44806 .71147 Mtetra
.541 .301 .5 r
.44806 .71147 .44924 .70033 .45085 .69978 .44967 .71101 Mtetra
.542 .302 .5 r
.44967 .71101 .45085 .69978 .45247 .69932 .45129 .71055 Mtetra
.543 .302 .501 r
.45129 .71055 .45247 .69932 .45407 .69901 .45291 .71012 Mtetra
.543 .302 .5 r
.45291 .71012 .45407 .69901 .45568 .6988 .45452 .70969 Mtetra
.542 .301 .499 r
.45452 .70969 .45568 .6988 .45729 .6986 .45614 .70927 Mtetra
.552 .309 .5 r
.45614 .70927 .45729 .6986 .45887 .70002 .45776 .70917 Mtetra
.551 .302 .492 r
.45776 .70917 .45887 .70002 .46046 .70106 .45937 .70909 Mtetra
.52 .27 .476 r
.45937 .70909 .46046 .70106 .46209 .69972 .461 .70836 Mtetra
.377 .152 .441 r
.461 .70836 .46209 .69972 .46691 .51542 .46268 .70486 Mtetra
0 0 .342 r
.46268 .70486 .46691 .51542 .46856 .50781 .4676 .51228 Mtetra
.702 .692 .156 r
.4676 .51228 .46856 .50781 .47014 .50456 .46926 .50448 Mtetra
.923 .899 .786 r
.46926 .50448 .47014 .50456 .47169 .50303 .47082 .50225 Mtetra
.703 .776 .908 r
.47082 .50225 .47169 .50303 .47323 .50245 .47236 .50159 Mtetra
.59 .726 .938 r
.47236 .50159 .47323 .50245 .47476 .50215 .47389 .50136 Mtetra
.596 .748 .949 r
.47389 .50136 .47476 .50215 .47629 .50181 .47543 .50109 Mtetra
.656 .784 .942 r
.47543 .50109 .47629 .50181 .47783 .50133 .47696 .50062 Mtetra
.655 .784 .943 r
.47696 .50062 .47783 .50133 .47937 .50086 .4785 .50015 Mtetra
.658 .787 .943 r
.4785 .50015 .47937 .50086 .48091 .50037 .48004 .49967 Mtetra
.661 .789 .943 r
.48004 .49967 .48091 .50037 .48245 .49987 .48158 .49918 Mtetra
.661 .791 .944 r
.48158 .49918 .48245 .49987 .48399 .49937 .48312 .49869 Mtetra
.66 .793 .946 r
.48312 .49869 .48399 .49937 .48553 .49888 .48466 .4982 Mtetra
.658 .794 .947 r
.48466 .4982 .48553 .49888 .48707 .49839 .4862 .49771 Mtetra
.656 .795 .949 r
.4862 .49771 .48707 .49839 .48861 .49791 .48775 .49724 Mtetra
.653 .796 .951 r
.48775 .49724 .48861 .49791 .49015 .49742 .48929 .49676 Mtetra
.65 .798 .954 r
.48929 .49676 .49015 .49742 .4917 .49694 .49084 .4963 Mtetra
.644 .802 .959 r
.49084 .4963 .4917 .49694 .49324 .49649 .49238 .49585 Mtetra
.634 .8 .962 r
.49238 .49585 .49324 .49649 .49479 .49611 .49393 .49543 Mtetra
.628 .787 .958 r
.49393 .49543 .49479 .49611 .49633 .49581 .49548 .49504 Mtetra
.633 .763 .941 r
.49548 .49504 .49633 .49581 .49788 .49553 .49702 .49465 Mtetra
.643 .741 .92 r
.49702 .49465 .49788 .49553 .49943 .49518 .49857 .49424 Mtetra
.652 .729 .906 r
.49857 .49424 .49943 .49518 .50098 .49474 .50012 .4938 Mtetra
.656 .73 .904 r
.50012 .4938 .50098 .49474 .50253 .49426 .50167 .49334 Mtetra
.657 .736 .908 r
.50167 .49334 .50253 .49426 .50408 .49378 .50323 .49288 Mtetra
.659 .741 .911 r
.50323 .49288 .50408 .49378 .50563 .4933 .50478 .49241 Mtetra
.663 .744 .91 r
.50478 .49241 .50563 .4933 .50719 .49279 .50633 .49192 Mtetra
.673 .753 .911 r
.50633 .49192 .50719 .49279 .50874 .49219 .50789 .49139 Mtetra
.683 .772 .918 r
.50789 .49139 .50874 .49219 .5103 .49151 .50944 .49082 Mtetra
.683 .801 .938 r
.50944 .49082 .5103 .49151 .51185 .49082 .511 .49024 Mtetra
.683 .83 .954 r
.511 .49024 .51185 .49082 .51341 .4901 .51256 .48965 Mtetra
.674 .863 .971 r
.51256 .48965 .51341 .4901 .51497 .48939 .51412 .48905 Mtetra
.619 .883 .989 r
.51412 .48905 .51497 .48939 .51653 .48893 .51568 .48854 Mtetra
.522 .837 .999 r
.51568 .48854 .51653 .48893 .51809 .48915 .51724 .48825 Mtetra
.498 .679 .946 r
.51724 .48825 .51809 .48915 .51964 .49078 .5188 .48827 Mtetra
.556 .497 .745 r
.5188 .48827 .51964 .49078 .5212 .4943 .52036 .48838 Mtetra
.585 .43 .638 r
.52036 .48838 .5212 .4943 .52276 .50209 .52192 .48814 Mtetra
.587 .396 .59 r
.52192 .48814 .52276 .50209 .52433 .5006 .52348 .48726 Mtetra
.578 .391 .591 r
.52348 .48726 .52433 .5006 .5259 .49889 .52505 .48681 Mtetra
.531 .358 .592 r
.52505 .48681 .5259 .49889 .52761 .67813 .52662 .48807 Mtetra
0 0 .39 r
.52662 .48807 .52761 .67813 .52928 .68743 .52837 .6759 Mtetra
0 0 .423 r
.52837 .6759 .52928 .68743 .53095 .69041 .53005 .6882 Mtetra
0 .132 .668 r
.53005 .6882 .53095 .69041 .53262 .6916 .53172 .69048 Mtetra
.545 .666 .916 r
.53172 .69048 .53262 .6916 .53428 .69153 .53339 .69042 Mtetra
.675 .718 .881 r
.53339 .69042 .53428 .69153 .53595 .6911 .53506 .68983 Mtetra
.693 .696 .848 r
.53506 .68983 .53595 .6911 .53762 .69058 .53672 .68911 Mtetra
.646 .65 .84 r
.53672 .68911 .53762 .69058 .53929 .69016 .53839 .68865 Mtetra
.66 .65 .829 r
.53839 .68865 .53929 .69016 .54096 .68949 .54006 .68809 Mtetra
.692 .677 .831 r
.54006 .68809 .54096 .68949 .54263 .68821 .54174 .68735 Mtetra
.763 .787 .873 r
.54174 .68735 .54263 .68821 .54429 .68552 .54341 .68629 Mtetra
0 0 0 r
.54341 .68629 .54429 .68552 .54594 .68112 .54508 .68515 Mtetra
.445 .16 .384 r
.54508 .68515 .54594 .68112 .54756 .67254 .54675 .68414 Mtetra
.54 .301 .501 r
.54675 .68414 .54756 .67254 .54919 .6667 .54842 .6836 Mtetra
.551 .32 .518 r
.54842 .6836 .54919 .6667 .55088 .66977 .5501 .6832 Mtetra
.548 .312 .509 r
.5501 .6832 .55088 .66977 .55258 .67246 .55178 .68285 Mtetra
.541 .298 .496 r
.55178 .68285 .55258 .67246 .55425 .67215 .55346 .6824 Mtetra
.54 .297 .495 r
.55346 .6824 .55425 .67215 .55593 .67188 .55514 .68195 Mtetra
.54 .296 .494 r
.55514 .68195 .55593 .67188 .5576 .67157 .55682 .6815 Mtetra
.539 .295 .493 r
.55682 .6815 .5576 .67157 .55928 .67118 .5585 .68104 Mtetra
.539 .294 .493 r
.5585 .68104 .55928 .67118 .56096 .67077 .56018 .68058 Mtetra
.539 .294 .492 r
.56018 .68058 .56096 .67077 .56263 .67033 .56186 .68011 Mtetra
.56186 .68011 .56263 .67033 .56431 .66989 .56355 .67965 Mtetra
.56355 .67965 .56431 .66989 .56599 .66943 .56523 .67918 Mtetra
.539 .293 .492 r
.56523 .67918 .56599 .66943 .56767 .66897 .56692 .67871 Mtetra
.56692 .67871 .56767 .66897 .56936 .6685 .56861 .67825 Mtetra
.56861 .67825 .56936 .6685 .57104 .66803 .5703 .67778 Mtetra
.538 .293 .492 r
.5703 .67778 .57104 .66803 .57272 .66756 .57199 .67731 Mtetra
.57199 .67731 .57272 .66756 .57441 .66708 .57368 .67684 Mtetra
.57368 .67684 .57441 .66708 .57609 .66659 .57537 .67637 Mtetra
.57537 .67637 .57609 .66659 .57778 .66609 .57706 .67589 Mtetra
.538 .294 .492 r
.57706 .67589 .57778 .66609 .57947 .66558 .57876 .67542 Mtetra
.539 .294 .492 r
.57876 .67542 .57947 .66558 .58115 .66505 .58045 .67494 Mtetra
.539 .294 .493 r
.58045 .67494 .58115 .66505 .58284 .66448 .58215 .67446 Mtetra
.58215 .67446 .58284 .66448 .58453 .66382 .58384 .67397 Mtetra
.539 .295 .494 r
.58384 .67397 .58453 .66382 .58622 .66317 .58554 .67349 Mtetra
.539 .296 .495 r
.58554 .67349 .58622 .66317 .5879 .6622 .58724 .67298 Mtetra
.537 .296 .497 r
.58724 .67298 .5879 .6622 .58951 .65731 .58894 .67238 Mtetra
.547 .314 .513 r
.58894 .67238 .58951 .65731 .59119 .65607 .59064 .67188 Mtetra
.552 .319 .516 r
.59064 .67188 .59119 .65607 .59302 .66272 .59234 .67159 Mtetra
.56 .308 .49 r
.59234 .67159 .59302 .66272 .59486 .66914 .59406 .67178 Mtetra
.544 .208 .349 r
.59406 .67178 .59486 .66914 .59663 .67189 .59578 .67198 Mtetra
.119 0 0 r
.59578 .67198 .59663 .67189 .59837 .67324 .59749 .67204 Mtetra
.611 .681 .891 r
.59749 .67204 .59837 .67324 .60009 .67323 .59921 .67174 Mtetra
.636 .646 .843 r
.59921 .67174 .60009 .67323 .6018 .67287 .60091 .67133 Mtetra
.644 .643 .834 r
.60091 .67133 .6018 .67287 .60351 .67231 .60262 .67087 Mtetra
.581 .627 .862 r
.60262 .67087 .60351 .67231 .60522 .67196 .60434 .67073 Mtetra
.651 .691 .875 r
.60434 .67073 .60522 .67196 .60693 .67136 .60605 .67025 Mtetra
.764 .747 .837 r
.60605 .67025 .60693 .67136 .60863 .67032 .60775 .66906 Mtetra
.905 .738 .665 r
.60775 .66906 .60863 .67032 .61029 .66791 .60937 .66454 Mtetra
.962 .687 .466 r
.60937 .66454 .61029 .66791 .61191 .6636 .60628 .46991 Mtetra
.578 .365 .556 r
.60628 .46991 .61191 .6636 .60882 .47449 .60769 .4614 Mtetra
.608 .414 .593 r
.60769 .4614 .60882 .47449 .61017 .46384 .60927 .45961 Mtetra
.64 .492 .666 r
.60927 .45961 .61017 .46384 .61172 .46056 .61088 .45862 Mtetra
.654 .594 .775 r
.61088 .45862 .61172 .46056 .61329 .45864 .61249 .45802 Mtetra
.675 .828 .957 r
.61249 .45802 .61329 .45864 .6149 .45784 .6141 .45744 Mtetra
.6 .866 .993 r
.6141 .45744 .6149 .45784 .61652 .4574 .61572 .45697 Mtetra
.576 .852 .996 r
.61572 .45697 .61652 .4574 .61814 .45716 .61734 .45657 Mtetra
.633 .824 .974 r
.61734 .45657 .61814 .45716 .61976 .45681 .61896 .45611 Mtetra
.646 .795 .954 r
.61896 .45611 .61976 .45681 .62139 .45646 .62058 .45564 Mtetra
.657 .766 .93 r
.62058 .45564 .62139 .45646 .62301 .45607 .6222 .45515 Mtetra
.749 .77 .87 r
.6222 .45515 .62301 .45607 .62462 .45517 .62381 .45419 Mtetra
.698 .744 .887 r
.62381 .45419 .62462 .45517 .62623 .45443 .62542 .45352 Mtetra
.54 .701 .944 r
.62542 .45352 .62623 .45443 .62786 .45406 .62706 .45342 Mtetra
.827 .36 0 r
.62706 .45342 .62786 .45406 .62953 .45514 .62879 .45638 Mtetra
.965 .681 .444 r
.62879 .45638 .62953 .45514 .63127 .45801 .63666 .64967 Mtetra
.576 .36 .55 r
.63666 .64967 .63127 .45801 .63911 .6461 .63868 .65828 Mtetra
.583 .337 .509 r
.63868 .65828 .63911 .6461 .64119 .6564 .64047 .65939 Mtetra
.537 .214 .367 r
.64047 .65939 .64119 .6564 .64303 .65904 .64222 .65949 Mtetra
.072 0 0 r
.64222 .65949 .64303 .65904 .64482 .66018 .64396 .65913 Mtetra
.524 .674 .933 r
.64396 .65913 .64482 .66018 .64657 .66033 .64571 .65911 Mtetra
.634 .69 .885 r
.64571 .65911 .64657 .66033 .64831 .65988 .64745 .6587 Mtetra
.747 .736 .842 r
.64745 .6587 .64831 .65988 .65003 .65884 .64917 .65762 Mtetra
.907 .747 .672 r
.64917 .65762 .65003 .65884 .65169 .65626 .65077 .65337 Mtetra
.967 .687 .451 r
.65077 .65337 .65169 .65626 .65327 .65155 .64538 .45867 Mtetra
.579 .366 .556 r
.64538 .45867 .65327 .65155 .64797 .46325 .64668 .44924 Mtetra
.601 .407 .59 r
.64668 .44924 .64797 .46325 .64939 .45674 .64828 .44767 Mtetra
.586 .41 .61 r
.64828 .44767 .64939 .45674 .65103 .45627 .64992 .44717 Mtetra
.571 .399 .61 r
.64992 .44717 .65103 .45627 .65275 .45764 .65157 .44711 Mtetra
.582 .401 .602 r
.65157 .44711 .65275 .45764 .6544 .45744 .65321 .44666 Mtetra
.583 .401 .601 r
.65321 .44666 .6544 .45744 .65605 .45695 .65485 .44615 Mtetra
.65485 .44615 .65605 .45695 .6577 .45655 .6565 .44565 Mtetra
.595 .409 .6 r
.6565 .44565 .6577 .45655 .65926 .45415 .65812 .4447 Mtetra
.591 .412 .608 r
.65812 .4447 .65926 .45415 .66089 .45308 .65976 .44402 Mtetra
.568 .397 .61 r
.65976 .44402 .66089 .45308 .66263 .45494 .66142 .44406 Mtetra
.402 .271 .586 r
.66142 .44406 .66263 .45494 .67236 .64437 .66328 .44862 Mtetra
.04 0 .436 r
.66328 .44862 .67236 .64437 .67434 .64917 .67337 .64515 Mtetra
0 .025 .56 r
.67337 .64515 .67434 .64917 .6762 .65123 .67534 .64979 Mtetra
.365 .517 .876 r
.67534 .64979 .6762 .65123 .67799 .6516 .67714 .65042 Mtetra
.634 .699 .892 r
.67714 .65042 .67799 .6516 .67976 .65123 .6789 .65001 Mtetra
.719 .722 .852 r
.6789 .65001 .67976 .65123 .68149 .65031 .68064 .64911 Mtetra
.681 .713 .873 r
.68064 .64911 .68149 .65031 .68319 .64851 .6824 .64845 Mtetra
.641 .958 .927 r
.6824 .64845 .68319 .64851 .68483 .64549 .68414 .64755 Mtetra
.167 0 .147 r
.68414 .64755 .68483 .64549 .68631 .63898 .68584 .64592 Mtetra
.165 0 .372 r
.68584 .64592 .68631 .63898 .67895 .44509 .68736 .64019 Mtetra
.041 0 .431 r
.68736 .64019 .67895 .44509 .68039 .43999 .67977 .44256 Mtetra
0 0 0 r
.67977 .44256 .68039 .43999 .68195 .43748 .68119 .43712 Mtetra
.857 .918 .871 r
.68119 .43712 .68195 .43748 .68358 .4365 .6828 .43561 Mtetra
.65 .752 .925 r
.6828 .43561 .68358 .4365 .68524 .43616 .68445 .43514 Mtetra
.546 .68 .927 r
.68445 .43514 .68524 .43616 .68692 .43608 .68613 .43506 Mtetra
.618 .713 .913 r
.68613 .43506 .68692 .43608 .68859 .43574 .6878 .43473 Mtetra
.652 .727 .904 r
.6878 .43473 .68859 .43574 .69025 .43524 .68946 .43425 Mtetra
.66 .735 .906 r
.68946 .43425 .69025 .43524 .69191 .43467 .69113 .43375 Mtetra
.693 .76 .903 r
.69113 .43375 .69191 .43467 .69355 .4338 .69278 .43309 Mtetra
.698 .815 .938 r
.69278 .43309 .69355 .4338 .69519 .43296 .69443 .43241 Mtetra
.658 .85 .974 r
.69443 .43241 .69519 .43296 .69686 .43244 .6961 .43184 Mtetra
.64 .829 .973 r
.6961 .43184 .69686 .43244 .69857 .43293 .69776 .43134 Mtetra
.596 .605 .831 r
.69776 .43134 .69857 .43293 .70036 .43474 .69944 .43114 Mtetra
.527 .436 .696 r
.69944 .43114 .70036 .43474 .70237 .44044 .70116 .43163 Mtetra
.376 .264 .597 r
.70116 .43163 .70237 .44044 .71467 .63347 .70309 .43587 Mtetra
.066 0 .45 r
.70309 .43587 .71467 .63347 .71671 .63772 .71567 .63292 Mtetra
.059 .096 .586 r
.71567 .63292 .71671 .63772 .71861 .63945 .71775 .63777 Mtetra
.338 .463 .84 r
.71775 .63777 .71861 .63945 .72044 .63986 .71961 .63865 Mtetra
.626 .692 .891 r
.71961 .63865 .72044 .63986 .72223 .63952 .7214 .63827 Mtetra
.715 .719 .853 r
.7214 .63827 .72223 .63952 .724 .63863 .72316 .63738 Mtetra
.738 .728 .842 r
.72316 .63738 .724 .63863 .7257 .6367 .72491 .63634 Mtetra
.777 .931 .933 r
.72491 .63634 .7257 .6367 .72732 .63343 .72666 .6352 Mtetra
.231 0 .132 r
.72666 .6352 .72732 .63343 .72879 .62762 .72841 .63401 Mtetra
.528 .264 .459 r
.72841 .63401 .72879 .62762 .7303 .62258 .7302 .63359 Mtetra
.55 .307 .499 r
.7302 .63359 .7303 .62258 .73216 .62328 .73201 .63342 Mtetra
.531 .288 .492 r
.73201 .63342 .73216 .62328 .73397 .62329 .73378 .63266 Mtetra
.398 .181 .465 r
.73378 .63266 .73397 .62329 .72426 .43502 .73536 .62874 Mtetra
.061 0 .444 r
.73536 .62874 .72426 .43502 .72551 .42749 .72505 .43142 Mtetra
0 0 .023 r
.72505 .43142 .72551 .42749 .72703 .42423 .72629 .42374 Mtetra
.902 .88 .803 r
.72629 .42374 .72703 .42423 .72865 .42279 .72788 .42167 Mtetra
.683 .719 .877 r
.72788 .42167 .72865 .42279 .73033 .4222 .72955 .42104 Mtetra
.594 .675 .896 r
.72955 .42104 .73033 .4222 .73202 .42184 .73125 .42082 Mtetra
.648 .725 .905 r
.73125 .42082 .73202 .42184 .7337 .42114 .73294 .42035 Mtetra
.695 .799 .929 r
.73294 .42035 .7337 .42114 .73536 .42028 .73462 .41968 Mtetra
.659 .838 .969 r
.73462 .41968 .73536 .42028 .73705 .41973 .73631 .41911 Mtetra
.636 .826 .974 r
.73631 .41911 .73705 .41973 .73879 .42006 .738 .41861 Mtetra
.604 .631 .851 r
.738 .41861 .73879 .42006 .74062 .42171 .7397 .41837 Mtetra
.536 .452 .707 r
.7397 .41837 .74062 .42171 .74267 .42643 .74145 .41874 Mtetra
.405 .292 .612 r
.74145 .41874 .74267 .42643 .75752 .6207 .74341 .42206 Mtetra
.088 .009 .462 r
.74341 .42206 .75752 .6207 .75968 .62548 .75855 .61968 Mtetra
.1 .107 .579 r
.75855 .61968 .75968 .62548 .76163 .62707 .76078 .62535 Mtetra
.257 .41 .824 r
.76078 .62535 .76163 .62707 .76344 .62661 .7627 .62654 Mtetra
.413 .859 .901 r
.7627 .62654 .76344 .62661 .76513 .62434 .76451 .62602 Mtetra
.122 0 .077 r
.76451 .62602 .76513 .62434 .76665 .61974 .76625 .6245 Mtetra
.199 0 .346 r
.76625 .6245 .76665 .61974 .75486 .42704 .76783 .62066 Mtetra
.084 .002 .455 r
.76783 .62066 .75486 .42704 .75596 .4181 .75579 .42533 Mtetra
0 0 .257 r
.75579 .42533 .75596 .4181 .75747 .41493 .75678 .4148 Mtetra
.944 .937 .755 r
.75678 .4148 .75747 .41493 .7591 .4134 .75834 .41233 Mtetra
.705 .74 .879 r
.75834 .41233 .7591 .4134 .76079 .41273 .76002 .41158 Mtetra
.609 .686 .897 r
.76002 .41158 .76079 .41273 .7625 .41234 .76174 .41129 Mtetra
.684 .735 .89 r
.76174 .41129 .7625 .41234 .76419 .41163 .76344 .41066 Mtetra
.738 .77 .879 r
.76344 .41066 .76419 .41163 .76587 .4107 .76512 .40974 Mtetra
.628 .733 .923 r
.76512 .40974 .76587 .4107 .76758 .4103 .76683 .40934 Mtetra
0 .171 .692 r
.76683 .40934 .76758 .4103 .76945 .4119 .7687 .41096 Mtetra
.975 .676 .377 r
.7687 .41096 .76945 .4119 .78531 .59721 .78465 .598 Mtetra
.952 .619 .352 r
.78465 .598 .78531 .59721 .78872 .61764 .78794 .61672 Mtetra
0 .043 .566 r
.78794 .61672 .78872 .61764 .79075 .61975 .78996 .61875 Mtetra
.578 .717 .938 r
.78996 .61875 .79075 .61975 .79261 .61962 .7918 .61851 Mtetra
.716 .75 .879 r
.7918 .61851 .79261 .61962 .7944 .6187 .79361 .61765 Mtetra
.716 .762 .888 r
.79361 .61765 .7944 .6187 .79614 .61707 .79541 .6168 Mtetra
.599 .917 .976 r
.79541 .6168 .79614 .61707 .79781 .61451 .79723 .61612 Mtetra
.199 0 .099 r
.79723 .61612 .79781 .61451 .7993 .6098 .799 .61489 Mtetra
.283 .056 .383 r
.799 .61489 .7993 .6098 .78561 .41647 .8006 .61151 Mtetra
.103 .018 .465 r
.8006 .61151 .78561 .41647 .78671 .40829 .78667 .41594 Mtetra
0 0 .292 r
.78667 .41594 .78671 .40829 .78822 .40516 .78755 .40514 Mtetra
.953 .946 .723 r
.78755 .40514 .78822 .40516 .78985 .40356 .7891 .40247 Mtetra
.707 .739 .876 r
.7891 .40247 .78985 .40356 .79156 .40289 .7908 .4017 Mtetra
.612 .681 .891 r
.7908 .4017 .79156 .40289 .79329 .4025 .79254 .40139 Mtetra
.659 .717 .892 r
.79254 .40139 .79329 .4025 .795 .40188 .79426 .40087 Mtetra
.74 .767 .875 r
.79426 .40087 .795 .40188 .79669 .40093 .79595 .39993 Mtetra
.645 .735 .914 r
.79595 .39993 .79669 .40093 .79842 .40045 .79768 .39947 Mtetra
0 .353 .828 r
.79768 .39947 .79842 .40045 .80029 .40163 .79955 .40065 Mtetra
.934 .568 .171 r
.79955 .40065 .80029 .40163 .8029 .41138 .80217 .41046 Mtetra
.975 .673 .361 r
.80217 .41046 .8029 .41138 .82167 .60772 .82089 .60676 Mtetra
0 0 .459 r
.82089 .60676 .82167 .60772 .82378 .61035 .823 .60932 Mtetra
.565 .709 .938 r
.823 .60932 .82378 .61035 .82567 .61028 .82488 .60914 Mtetra
.72 .748 .874 r
.82488 .60914 .82567 .61028 .82748 .60935 .8267 .60824 Mtetra
.747 .762 .865 r
.8267 .60824 .82748 .60935 .82922 .60763 .8285 .60717 Mtetra
.703 .908 .967 r
.8285 .60717 .82922 .60763 .83087 .60479 .83032 .60631 Mtetra
.106 0 .049 r
.83032 .60631 .83087 .60479 .83223 .5989 .83208 .60482 Mtetra
.254 .049 .397 r
.83208 .60482 .83223 .5989 .81636 .40227 .83359 .60044 Mtetra
.11 .026 .471 r
.83359 .60044 .81636 .40227 .8176 .39628 .81724 .39942 Mtetra
0 0 .108 r
.81724 .39942 .8176 .39628 .81916 .39382 .81852 .39383 Mtetra
.656 .971 .874 r
.81852 .39383 .81916 .39382 .82093 .39369 .82021 .39277 Mtetra
.81 .381 0 r
.82021 .39277 .82093 .39369 .82322 .39905 .82242 .39732 Mtetra
.976 .671 .347 r
.82242 .39732 .82322 .39905 .84379 .60061 .84294 .59875 Mtetra
0 0 .429 r
.84294 .59875 .84379 .60061 .84604 .60434 .84525 .60302 Mtetra
.476 .603 .899 r
.84525 .60302 .84604 .60434 .84795 .60434 .84718 .60326 Mtetra
.709 .758 .89 r
.84718 .60326 .84795 .60434 .84978 .60342 .84901 .60243 Mtetra
.877 .811 .781 r
.84901 .60243 .84978 .60342 .85152 .60166 .85071 .60014 Mtetra
.947 .739 .589 r
.85071 .60014 .85152 .60166 .85316 .59877 .85198 .59336 Mtetra
.975 .675 .376 r
.85198 .59336 .85316 .59877 .85452 .59296 .83464 .39353 Mtetra
.571 .359 .555 r
.83464 .39353 .85452 .59296 .83745 .39748 .83599 .38887 Mtetra
.615 .433 .612 r
.83599 .38887 .83745 .39748 .83868 .39158 .83766 .38749 Mtetra
.627 .489 .675 r
.83766 .38749 .83868 .39158 .84021 .3888 .83939 .38672 Mtetra
.64 .584 .776 r
.83939 .38672 .84021 .3888 .84186 .38719 .84114 .38619 Mtetra
.669 .749 .91 r
.84114 .38619 .84186 .38719 .84359 .38648 .84289 .38561 Mtetra
.651 .773 .938 r
.84289 .38561 .84359 .38648 .84535 .38603 .84464 .3851 Mtetra
.687 .771 .915 r
.84464 .3851 .84535 .38603 .8471 .38545 .84638 .38444 Mtetra
.756 .777 .87 r
.84638 .38444 .8471 .38545 .84879 .38429 .84809 .38339 Mtetra
.679 .774 .923 r
.84809 .38339 .84879 .38429 .85053 .38358 .84983 .38276 Mtetra
.223 .558 .935 r
.84983 .38276 .85053 .38358 .85239 .38406 .8517 .38333 Mtetra
.879 .469 .034 r
.8517 .38333 .85239 .38406 .85479 .38975 .85414 .38943 Mtetra
.974 .666 .334 r
.85414 .38943 .85479 .38975 .87738 .59096 .87665 .59013 Mtetra
.732 .272 0 r
.87665 .59013 .87738 .59096 .87972 .59488 .87897 .59388 Mtetra
.369 .614 .945 r
.87897 .59388 .87972 .59488 .8817 .59526 .88095 .59426 Mtetra
.688 .769 .913 r
.88095 .59426 .8817 .59526 .88356 .59453 .88282 .59354 Mtetra
.872 .817 .791 r
.88282 .59354 .88356 .59453 .88527 .59227 .88453 .59136 Mtetra
.982 .766 .537 r
.88453 .59136 .88527 .59227 .88628 .58347 .88562 .58333 Mtetra
.977 .675 .341 r
.88562 .58333 .88628 .58347 .86675 .3823 .8661 .38179 Mtetra
.98 .84 .631 r
.8661 .38179 .86675 .3823 .86815 .37824 .86747 .37752 Mtetra
.747 .845 .924 r
.86747 .37752 .86815 .37824 .86988 .3774 .86919 .37658 Mtetra
.589 .761 .961 r
.86919 .37658 .86988 .3774 .87168 .37718 .87099 .37627 Mtetra
.55 .718 .951 r
.87099 .37627 .87168 .37718 .87351 .37715 .8728 .37611 Mtetra
.732 .766 .88 r
.8728 .37611 .87351 .37715 .87525 .37639 .87453 .3752 Mtetra
.667 .71 .88 r
.87453 .3752 .87525 .37639 .87702 .37581 .8763 .37462 Mtetra
.462 .607 .909 r
.8763 .37462 .87702 .37581 .87884 .37571 .87816 .37487 Mtetra
.728 .278 0 r
.87816 .37487 .87884 .37571 .88082 .37699 .88042 .37866 Mtetra
.973 .661 .327 r
.88042 .37866 .88082 .37699 .88303 .3803 .90451 .578 Mtetra
.571 .355 .549 r
.90451 .578 .88303 .3803 .90663 .57391 .90713 .58395 Mtetra
.573 .319 .494 r
.90713 .58395 .90663 .57391 .90945 .58163 .90917 .58462 Mtetra
.512 .187 .353 r
.90917 .58462 .90945 .58163 .91168 .584 .91111 .58449 Mtetra
.078 0 0 r
.91111 .58449 .91168 .584 .91376 .58498 .91303 .58402 Mtetra
.507 .702 .958 r
.91303 .58402 .91376 .58498 .91572 .58498 .91499 .58398 Mtetra
.645 .756 .93 r
.91499 .58398 .91572 .58498 .91762 .58441 .9169 .58346 Mtetra
.804 .821 .864 r
.9169 .58346 .91762 .58441 .91945 .58317 .9187 .58204 Mtetra
.961 .78 .614 r
.9187 .58204 .91945 .58317 .92112 .58057 .92005 .57671 Mtetra
.975 .669 .336 r
.92005 .57671 .92112 .58057 .92251 .57562 .89855 .37575 Mtetra
.573 .361 .555 r
.89855 .37575 .92251 .57562 .9014 .37937 .89963 .36917 Mtetra
.615 .426 .603 r
.89963 .36917 .9014 .37937 .90235 .37167 .90128 .36749 Mtetra
.636 .493 .672 r
.90128 .36749 .90235 .37167 .90383 .36853 .90302 .36654 Mtetra
.648 .598 .785 r
.90302 .36654 .90383 .36853 .90546 .36663 .90481 .36596 Mtetra
.652 .832 .97 r
.90481 .36596 .90546 .36663 .90722 .36584 .9066 .36538 Mtetra
.568 .862 .996 r
.9066 .36538 .90722 .36584 .90902 .3654 .9084 .36492 Mtetra
.548 .848 .998 r
.9084 .36492 .90902 .3654 .91085 .36515 .91021 .36452 Mtetra
.608 .828 .984 r
.91021 .36452 .91085 .36515 .91267 .36479 .91202 .36406 Mtetra
.627 .807 .969 r
.91202 .36406 .91267 .36479 .91448 .36444 .91382 .36358 Mtetra
.646 .78 .945 r
.91382 .36358 .91448 .36444 .9163 .36405 .91562 .36307 Mtetra
.672 .76 .916 r
.91562 .36307 .9163 .36405 .9181 .36351 .91741 .36246 Mtetra
.68 .747 .902 r
.91741 .36246 .9181 .36351 .91989 .3629 .9192 .36182 Mtetra
.683 .742 .896 r
.9192 .36182 .91989 .3629 .92167 .36223 .92098 .36116 Mtetra
.612 .67 .882 r
.33816 .54329 .33906 .5444 .34055 .54345 .33961 .54304 Mtetra
.146 .629 .92 r
.33961 .54304 .34055 .54345 .34202 .54281 .34104 .54324 Mtetra
.697 .237 .154 r
.34104 .54324 .34202 .54281 .34346 .54276 .34242 .54432 Mtetra
.884 .595 .492 r
.34242 .54432 .34346 .54276 .34474 .54575 .34331 .55455 Mtetra
.923 .668 .533 r
.34331 .55455 .34474 .54575 .3362 .73387 .33485 .74017 Mtetra
.675 .403 .502 r
.33485 .74017 .3362 .73387 .3373 .74202 .33622 .74329 Mtetra
.509 .092 .184 r
.33622 .74329 .3373 .74202 .33877 .74306 .33774 .74345 Mtetra
0 0 0 r
.33774 .74345 .33877 .74306 .34029 .74319 .3393 .74291 Mtetra
.777 .903 .93 r
.3393 .74291 .34029 .74319 .34184 .74288 .34088 .7419 Mtetra
.704 .735 .875 r
.34088 .7419 .34184 .74288 .34337 .74293 .34245 .74121 Mtetra
.718 .641 .771 r
.34245 .74121 .34337 .74293 .34492 .74259 .34404 .74012 Mtetra
.744 .607 .705 r
.34404 .74012 .34492 .74259 .3465 .7416 .34567 .73816 Mtetra
.855 .642 .614 r
.34567 .73816 .3465 .7416 .34823 .73768 .34766 .729 Mtetra
.927 .676 .537 r
.34766 .729 .34823 .73768 .35899 .55013 .35852 .54039 Mtetra
.676 .475 .607 r
.35852 .54039 .35899 .55013 .36098 .53934 .36017 .53646 Mtetra
.67 .544 .702 r
.36017 .53646 .36098 .53934 .36252 .53737 .36167 .53545 Mtetra
.622 .571 .776 r
.36167 .53545 .36252 .53737 .36402 .53639 .36314 .53513 Mtetra
.551 .62 .874 r
.36314 .53513 .36402 .53639 .3655 .53583 .36459 .53511 Mtetra
.664 .775 .932 r
.36459 .53511 .3655 .53583 .36698 .53534 .36607 .53464 Mtetra
.67 .781 .932 r
.36607 .53464 .36698 .53534 .36845 .53495 .36755 .53414 Mtetra
.641 .747 .926 r
.36755 .53414 .36845 .53495 .36992 .5346 .36902 .53375 Mtetra
.616 .73 .928 r
.36902 .53375 .36992 .5346 .37142 .53374 .37049 .53346 Mtetra
.181 .68 .914 r
.37049 .53346 .37142 .53374 .37291 .53306 .37195 .53353 Mtetra
.647 .168 .102 r
.37195 .53353 .37291 .53306 .37437 .53291 .37337 .53438 Mtetra
.866 .56 .467 r
.37337 .53438 .37437 .53291 .37573 .53536 .37452 .54128 Mtetra
.931 .673 .524 r
.37452 .54128 .37573 .53536 .36906 .72016 .36762 .73032 Mtetra
.651 .396 .52 r
.36762 .73032 .36906 .72016 .37007 .73233 .36901 .73388 Mtetra
.567 .18 .268 r
.36901 .73388 .37007 .73233 .37156 .7337 .37055 .73429 Mtetra
.013 0 0 r
.37055 .73429 .37156 .7337 .37311 .73383 .37212 .7338 Mtetra
.734 .962 .94 r
.37212 .7338 .37311 .73383 .37468 .73352 .37372 .73284 Mtetra
.717 .806 .921 r
.37372 .73284 .37468 .73352 .37623 .73365 .3753 .73211 Mtetra
.717 .66 .792 r
.3753 .73211 .37623 .73365 .37779 .73349 .3769 .73112 Mtetra
.736 .608 .716 r
.3769 .73112 .37779 .73349 .37938 .73263 .37853 .72939 Mtetra
.832 .632 .633 r
.37853 .72939 .37938 .73263 .38111 .72855 .38034 .72314 Mtetra
.936 .681 .528 r
.38034 .72314 .38111 .72855 .39036 .53648 .3896 .53219 Mtetra
.776 .581 .635 r
.3896 .53219 .39036 .53648 .39215 .52842 .39126 .52743 Mtetra
.789 .741 .808 r
.39126 .52743 .39215 .52842 .39369 .5268 .39279 .52609 Mtetra
.647 .777 .943 r
.39279 .52609 .39369 .5268 .39518 .52636 .39428 .52567 Mtetra
.503 .735 .977 r
.39428 .52567 .39518 .52636 .39665 .52635 .39575 .52559 Mtetra
.621 .757 .944 r
.39575 .52559 .39665 .52635 .39814 .52604 .39724 .52526 Mtetra
.657 .761 .926 r
.39724 .52526 .39814 .52604 .39963 .52559 .39874 .52481 Mtetra
.663 .761 .923 r
.39874 .52481 .39963 .52559 .40113 .52512 .40023 .52433 Mtetra
.671 .764 .92 r
.40023 .52433 .40113 .52512 .40263 .5245 .40173 .52383 Mtetra
.677 .795 .937 r
.40173 .52383 .40263 .5245 .40413 .52386 .40323 .52329 Mtetra
.682 .822 .95 r
.40323 .52329 .40413 .52386 .40563 .52333 .40473 .52273 Mtetra
.701 .817 .937 r
.40473 .52273 .40563 .52333 .40712 .52317 .40624 .5221 Mtetra
.695 .711 .86 r
.40624 .5221 .40712 .52317 .4086 .52323 .40774 .52146 Mtetra
.666 .608 .78 r
.40774 .52146 .4086 .52323 .41008 .52335 .40925 .52083 Mtetra
.665 .557 .723 r
.40925 .52083 .41008 .52335 .41159 .52268 .41076 .52 Mtetra
.647 .539 .718 r
.41076 .52 .41159 .52268 .4131 .52193 .41227 .51933 Mtetra
.598 .514 .731 r
.41227 .51933 .4131 .52193 .41459 .52177 .41376 .51913 Mtetra
.169 .239 .693 r
.41376 .51913 .41459 .52177 .41597 .52527 .41519 .52096 Mtetra
.886 .613 .096 r
.41519 .52096 .41597 .52527 .4113 .71705 .41638 .53015 Mtetra
0 0 .329 r
.41638 .53015 .4113 .71705 .41271 .7223 .41187 .71829 Mtetra
.381 .326 .671 r
.41187 .71829 .41271 .7223 .41427 .7232 .4134 .71994 Mtetra
.606 .499 .706 r
.4134 .71994 .41427 .7232 .41586 .72284 .41499 .71961 Mtetra
.656 .53 .699 r
.41499 .71961 .41586 .72284 .41747 .72208 .41661 .71867 Mtetra
.642 .516 .695 r
.41661 .71867 .41747 .72208 .41907 .72155 .41822 .71788 Mtetra
.62 .495 .689 r
.41822 .71788 .41907 .72155 .42067 .72117 .41982 .71732 Mtetra
.601 .478 .685 r
.41982 .71732 .42067 .72117 .42227 .72077 .42142 .71699 Mtetra
.541 .441 .69 r
.42142 .71699 .42227 .72077 .42387 .72036 .42299 .71731 Mtetra
.5 .442 .723 r
.42299 .71731 .42387 .72036 .42547 .71989 .42457 .71787 Mtetra
.486 .502 .799 r
.42457 .71787 .42547 .71989 .42708 .71933 .42615 .71827 Mtetra
.532 .668 .924 r
.42615 .71827 .42708 .71933 .4287 .71848 .42774 .71825 Mtetra
.453 .846 .979 r
.42774 .71825 .4287 .71848 .43032 .7174 .42934 .71794 Mtetra
.047 0 0 r
.42934 .71794 .43032 .7174 .43194 .71628 .43095 .71752 Mtetra
.321 0 .05 r
.43095 .71752 .43194 .71628 .43356 .71549 .43256 .71709 Mtetra
.38 0 .159 r
.43256 .71709 .43356 .71549 .43516 .71503 .43417 .71666 Mtetra
.379 0 .164 r
.43417 .71666 .43516 .71503 .43677 .71468 .43578 .7162 Mtetra
.365 0 .138 r
.43578 .7162 .43677 .71468 .43838 .71428 .43739 .71575 Mtetra
.357 0 .123 r
.43739 .71575 .43838 .71428 .43999 .71383 .439 .7153 Mtetra
.35 0 .119 r
.439 .7153 .43999 .71383 .4416 .71337 .44061 .71483 Mtetra
.331 0 .105 r
.44061 .71483 .4416 .71337 .44321 .7129 .44223 .7143 Mtetra
.308 0 .079 r
.44223 .7143 .44321 .7129 .44483 .71242 .44385 .71374 Mtetra
.289 0 .049 r
.44385 .71374 .44483 .71242 .44644 .71194 .44546 .71318 Mtetra
.287 0 .027 r
.44546 .71318 .44644 .71194 .44806 .71147 .44708 .71266 Mtetra
.294 0 .02 r
.44708 .71266 .44806 .71147 .44967 .71101 .4487 .71219 Mtetra
.3 0 .022 r
.4487 .71219 .44967 .71101 .45129 .71055 .45032 .71174 Mtetra
.306 0 .027 r
.45032 .71174 .45129 .71055 .45291 .71012 .45194 .7113 Mtetra
.308 0 .026 r
.45194 .7113 .45291 .71012 .45452 .70969 .45356 .71086 Mtetra
.304 0 .021 r
.45356 .71086 .45452 .70969 .45614 .70927 .45518 .71043 Mtetra
.386 0 .071 r
.45518 .71043 .45614 .70927 .45776 .70917 .4568 .71022 Mtetra
.37 0 .029 r
.4568 .71022 .45776 .70917 .45937 .70909 .45841 .71002 Mtetra
.121 0 0 r
.45841 .71002 .45937 .70909 .461 .70836 .46004 .70938 Mtetra
.768 .937 .588 r
.46004 .70938 .461 .70836 .46268 .70486 .4617 .70702 Mtetra
.984 .863 .493 r
.4617 .70702 .46268 .70486 .4676 .51228 .46345 .6998 Mtetra
0 0 .337 r
.46345 .6998 .4676 .51228 .46926 .50448 .46833 .50707 Mtetra
0 0 0 r
.46833 .50707 .46926 .50448 .47082 .50225 .46992 .50364 Mtetra
.246 0 .06 r
.46992 .50364 .47082 .50225 .47236 .50159 .47146 .5029 Mtetra
.445 .031 .158 r
.47146 .5029 .47236 .50159 .47389 .50136 .47299 .5028 Mtetra
.444 .043 .182 r
.47299 .5028 .47389 .50136 .47543 .50109 .47452 .50264 Mtetra
.372 0 .163 r
.47452 .50264 .47543 .50109 .47696 .50062 .47606 .50218 Mtetra
.374 0 .166 r
.47606 .50218 .47696 .50062 .4785 .50015 .4776 .50172 Mtetra
.371 0 .166 r
.4776 .50172 .4785 .50015 .48004 .49967 .47914 .50124 Mtetra
.367 0 .164 r
.47914 .50124 .48004 .49967 .48158 .49918 .48068 .50075 Mtetra
.366 0 .163 r
.48068 .50075 .48158 .49918 .48312 .49869 .48223 .50025 Mtetra
.368 0 .163 r
.48223 .50025 .48312 .49869 .48466 .4982 .48377 .49976 Mtetra
.371 0 .166 r
.48377 .49976 .48466 .4982 .4862 .49771 .48531 .49929 Mtetra
.374 0 .169 r
.48531 .49929 .4862 .49771 .48775 .49724 .48686 .49882 Mtetra
.4 .013 .184 r
.48686 .49882 .48775 .49724 .48929 .49676 .4884 .49844 Mtetra
.425 .045 .212 r
.4884 .49844 .48929 .49676 .49084 .4963 .48995 .49811 Mtetra
.396 .028 .217 r
.48995 .49811 .49084 .4963 .49238 .49585 .4915 .49761 Mtetra
.236 0 .128 r
.4915 .49761 .49238 .49585 .49393 .49543 .49305 .49659 Mtetra
0 0 0 r
.49305 .49659 .49393 .49543 .49548 .49504 .49461 .49516 Mtetra
.8 .992 .877 r
.49461 .49516 .49548 .49504 .49702 .49465 .49616 .49386 Mtetra
.752 .787 .881 r
.49616 .49386 .49702 .49465 .49857 .49424 .49772 .49295 Mtetra
.663 .667 .844 r
.49772 .49295 .49857 .49424 .50012 .4938 .49927 .49243 Mtetra
.64 .647 .841 r
.49927 .49243 .50012 .4938 .50167 .49334 .50082 .49204 Mtetra
.641 .657 .85 r
.50082 .49204 .50167 .49334 .50323 .49288 .50237 .49164 Mtetra
.656 .673 .855 r
.50237 .49164 .50323 .49288 .50478 .49241 .50392 .49117 Mtetra
.654 .673 .855 r
.50392 .49117 .50478 .49241 .50633 .49192 .50548 .49071 Mtetra
.649 .675 .862 r
.50548 .49071 .50633 .49192 .50789 .49139 .50703 .49027 Mtetra
.643 .69 .879 r
.50703 .49027 .50789 .49139 .50944 .49082 .50859 .48987 Mtetra
.643 .724 .907 r
.50859 .48987 .50944 .49082 .511 .49024 .51015 .48946 Mtetra
.649 .767 .935 r
.51015 .48946 .511 .49024 .51256 .48965 .5117 .48902 Mtetra
.657 .81 .956 r
.5117 .48902 .51256 .48965 .51412 .48905 .51326 .48852 Mtetra
.661 .838 .968 r
.51326 .48852 .51412 .48905 .51568 .48854 .51482 .48798 Mtetra
.679 .835 .958 r
.51482 .48798 .51568 .48854 .51724 .48825 .51638 .4874 Mtetra
.696 .764 .904 r
.51638 .4874 .51724 .48825 .5188 .48827 .51795 .48676 Mtetra
.675 .644 .812 r
.51795 .48676 .5188 .48827 .52036 .48838 .51951 .48613 Mtetra
.662 .573 .745 r
.51951 .48613 .52036 .48838 .52192 .48814 .52107 .48541 Mtetra
.657 .545 .716 r
.52107 .48541 .52192 .48814 .52348 .48726 .52264 .48459 Mtetra
.622 .528 .726 r
.52264 .48459 .52348 .48726 .52505 .48681 .5242 .48415 Mtetra
.47 .437 .739 r
.5242 .48415 .52505 .48681 .52662 .48807 .52577 .48483 Mtetra
0 0 .435 r
.52577 .48483 .52662 .48807 .52837 .6759 .52734 .48918 Mtetra
0 0 .373 r
.52734 .48918 .52837 .6759 .53005 .6882 .52914 .68268 Mtetra
.148 .133 .583 r
.52914 .68268 .53005 .6882 .53172 .69048 .53082 .68697 Mtetra
.581 .477 .701 r
.53082 .68697 .53172 .69048 .53339 .69042 .53248 .68688 Mtetra
.634 .509 .693 r
.53248 .68688 .53339 .69042 .53506 .68983 .53415 .68615 Mtetra
.613 .492 .691 r
.53415 .68615 .53506 .68983 .53672 .68911 .53582 .68566 Mtetra
.516 .438 .706 r
.53582 .68566 .53672 .68911 .53839 .68865 .53749 .6862 Mtetra
.503 .48 .764 r
.53749 .6862 .53839 .68865 .54006 .68809 .53917 .68664 Mtetra
.512 .59 .869 r
.53917 .68664 .54006 .68809 .54174 .68735 .54084 .68678 Mtetra
.544 .804 .994 r
.54084 .68678 .54174 .68735 .54341 .68629 .54252 .68651 Mtetra
0 0 0 r
.54252 .68651 .54341 .68629 .54508 .68515 .54419 .68611 Mtetra
.247 0 0 r
.54419 .68611 .54508 .68515 .54675 .68414 .54587 .68566 Mtetra
.374 0 .142 r
.54587 .68566 .54675 .68414 .54842 .6836 .54755 .68522 Mtetra
.383 0 .166 r
.54755 .68522 .54842 .6836 .5501 .6832 .54922 .68476 Mtetra
.373 0 .149 r
.54922 .68476 .5501 .6832 .55178 .68285 .5509 .6843 Mtetra
.359 0 .122 r
.5509 .6843 .55178 .68285 .55346 .6824 .55258 .68384 Mtetra
.357 0 .119 r
.55258 .68384 .55346 .6824 .55514 .68195 .55427 .68338 Mtetra
.355 0 .116 r
.55427 .68338 .55514 .68195 .55682 .6815 .55595 .68292 Mtetra
.353 0 .113 r
.55595 .68292 .55682 .6815 .5585 .68104 .55763 .68246 Mtetra
.352 0 .111 r
.55763 .68246 .5585 .68104 .56018 .68058 .55932 .68199 Mtetra
.351 0 .11 r
.55932 .68199 .56018 .68058 .56186 .68011 .561 .68153 Mtetra
.561 .68153 .56186 .68011 .56355 .67965 .56269 .68106 Mtetra
.351 0 .109 r
.56269 .68106 .56355 .67965 .56523 .67918 .56437 .68059 Mtetra
.35 0 .109 r
.56437 .68059 .56523 .67918 .56692 .67871 .56606 .68013 Mtetra
.56606 .68013 .56692 .67871 .56861 .67825 .56775 .67966 Mtetra
.56775 .67966 .56861 .67825 .5703 .67778 .56944 .67919 Mtetra
.56944 .67919 .5703 .67778 .57199 .67731 .57113 .67872 Mtetra
.57113 .67872 .57199 .67731 .57368 .67684 .57283 .67825 Mtetra
.57283 .67825 .57368 .67684 .57537 .67637 .57452 .67778 Mtetra
.57452 .67778 .57537 .67637 .57706 .67589 .57622 .67731 Mtetra
.57622 .67731 .57706 .67589 .57876 .67542 .57791 .67683 Mtetra
.35 0 .11 r
.57791 .67683 .57876 .67542 .58045 .67494 .57961 .67636 Mtetra
.35 0 .111 r
.57961 .67636 .58045 .67494 .58215 .67446 .58131 .67589 Mtetra
.351 0 .112 r
.58131 .67589 .58215 .67446 .58384 .67397 .583 .67541 Mtetra
.352 0 .115 r
.583 .67541 .58384 .67397 .58554 .67349 .5847 .67493 Mtetra
.353 0 .117 r
.5847 .67493 .58554 .67349 .58724 .67298 .5864 .67445 Mtetra
.359 0 .125 r
.5864 .67445 .58724 .67298 .58894 .67238 .58811 .67397 Mtetra
.373 0 .156 r
.58811 .67397 .58894 .67238 .59064 .67188 .58981 .67349 Mtetra
.371 0 .158 r
.58981 .67349 .59064 .67188 .59234 .67159 .59151 .67298 Mtetra
.344 0 .102 r
.59151 .67298 .59234 .67159 .59406 .67178 .59322 .6725 Mtetra
.084 0 0 r
.59322 .6725 .59406 .67178 .59578 .67198 .59492 .67192 Mtetra
.59 .937 .938 r
.59492 .67192 .59578 .67198 .59749 .67204 .59662 .67118 Mtetra
.787 .797 .861 r
.59662 .67118 .59749 .67204 .59921 .67174 .59831 .66993 Mtetra
.744 .656 .763 r
.59831 .66993 .59921 .67174 .60091 .67133 .6 .66851 Mtetra
.698 .573 .712 r
.6 .66851 .60091 .67133 .60262 .67087 .60169 .66712 Mtetra
.579 .47 .694 r
.60169 .66712 .60262 .67087 .60434 .67073 .60341 .66705 Mtetra
.603 .487 .694 r
.60341 .66705 .60434 .67073 .60605 .67025 .60512 .6667 Mtetra
.672 .534 .688 r
.60512 .6667 .60605 .67025 .60775 .66906 .60682 .66539 Mtetra
.88 .651 .587 r
.60682 .66539 .60775 .66906 .60937 .66454 .60829 .65501 Mtetra
.954 .679 .476 r
.60829 .65501 .60937 .66454 .60628 .46991 .6053 .46249 Mtetra
.699 .499 .614 r
.6053 .46249 .60628 .46991 .60769 .4614 .60683 .45858 Mtetra
.661 .546 .713 r
.60683 .45858 .60769 .4614 .60927 .45961 .60843 .45768 Mtetra
.62 .578 .786 r
.60843 .45768 .60927 .45961 .61088 .45862 .61005 .45735 Mtetra
.555 .632 .883 r
.61005 .45735 .61088 .45862 .61249 .45802 .61168 .45731 Mtetra
.644 .792 .954 r
.61168 .45731 .61249 .45802 .6141 .45744 .6133 .45685 Mtetra
.642 .827 .971 r
.6133 .45685 .6141 .45744 .61572 .45697 .61491 .45636 Mtetra
.656 .823 .964 r
.61491 .45636 .61572 .45697 .61734 .45657 .61653 .45583 Mtetra
.712 .804 .922 r
.61653 .45583 .61734 .45657 .61896 .45611 .61814 .45512 Mtetra
.693 .74 .887 r
.61814 .45512 .61896 .45611 .62058 .45564 .61976 .45446 Mtetra
.658 .693 .871 r
.61976 .45446 .62058 .45564 .6222 .45515 .62138 .45397 Mtetra
.608 .672 .886 r
.62138 .45397 .6222 .45515 .62381 .45419 .62301 .4537 Mtetra
.24 .667 .96 r
.62301 .4537 .62381 .45419 .62542 .45352 .62466 .45389 Mtetra
.657 .147 .019 r
.62466 .45389 .62542 .45352 .62706 .45342 .62633 .45499 Mtetra
.906 .58 .418 r
.62633 .45499 .62706 .45342 .62879 .45638 .62829 .4652 Mtetra
.954 .67 .46 r
.62829 .4652 .62879 .45638 .63666 .64967 .63605 .65637 Mtetra
.669 .387 .486 r
.63605 .65637 .63666 .64967 .63868 .65828 .6379 .65959 Mtetra
.52 .096 .176 r
.6379 .65959 .63868 .65828 .64047 .65939 .63966 .65986 Mtetra
0 0 0 r
.63966 .65986 .64047 .65939 .64222 .65949 .64139 .65935 Mtetra
.709 .963 .942 r
.64139 .65935 .64222 .65949 .64396 .65913 .64311 .65837 Mtetra
.724 .816 .922 r
.64311 .65837 .64396 .65913 .64571 .65911 .64484 .65755 Mtetra
.743 .683 .793 r
.64484 .65755 .64571 .65911 .64745 .6587 .64655 .65629 Mtetra
.763 .627 .71 r
.64655 .65629 .64745 .6587 .64917 .65762 .64822 .65412 Mtetra
.879 .652 .591 r
.64822 .65412 .64917 .65762 .65077 .65337 .64964 .64479 Mtetra
.959 .68 .462 r
.64964 .64479 .65077 .65337 .64538 .45867 .64431 .45046 Mtetra
.694 .491 .608 r
.64431 .45046 .64538 .45867 .64668 .44924 .64581 .44635 Mtetra
.683 .556 .705 r
.64581 .44635 .64668 .44924 .64828 .44767 .64742 .44513 Mtetra
.63 .542 .737 r
.64742 .44513 .64828 .44767 .64992 .44717 .64906 .44464 Mtetra
.595 .522 .743 r
.64906 .44464 .64992 .44717 .65157 .44711 .65071 .44445 Mtetra
.625 .533 .73 r
.65071 .44445 .65157 .44711 .65321 .44666 .65235 .44398 Mtetra
.629 .534 .728 r
.65235 .44398 .65321 .44666 .65485 .44615 .65399 .44346 Mtetra
.628 .534 .728 r
.65399 .44346 .65485 .44615 .6565 .44565 .65563 .44296 Mtetra
.658 .55 .722 r
.65563 .44296 .6565 .44565 .65812 .4447 .65726 .44213 Mtetra
.644 .549 .732 r
.65726 .44213 .65812 .4447 .65976 .44402 .65889 .44149 Mtetra
.589 .519 .744 r
.65889 .44149 .65976 .44402 .66142 .44406 .66055 .44135 Mtetra
.187 .254 .701 r
.66055 .44135 .66142 .44406 .66328 .44862 .66231 .44348 Mtetra
.75 .501 0 r
.66231 .44348 .66328 .44862 .67337 .64515 .6645 .45578 Mtetra
.04 0 .437 r
.6645 .45578 .67337 .64515 .67534 .64979 .67437 .64579 Mtetra
.368 .327 .681 r
.67437 .64579 .67534 .64979 .67714 .65042 .67623 .64775 Mtetra
.509 .473 .753 r
.67623 .64775 .67714 .65042 .6789 .65001 .67803 .64822 Mtetra
.577 .583 .823 r
.67803 .64822 .6789 .65001 .68064 .64911 .6798 .64813 Mtetra
.501 .683 .948 r
.6798 .64813 .68064 .64911 .6824 .64845 .68159 .64814 Mtetra
.458 .841 .986 r
.68159 .64814 .6824 .64845 .68414 .64755 .68335 .64782 Mtetra
.451 .871 .747 r
.68335 .64782 .68414 .64755 .68584 .64592 .6851 .64689 Mtetra
.823 .911 .51 r
.6851 .64689 .68584 .64592 .68736 .64019 .68673 .64374 Mtetra
.826 .733 .208 r
.68673 .64374 .68736 .64019 .67977 .44256 .68806 .63408 Mtetra
.038 0 .43 r
.68806 .63408 .67977 .44256 .68119 .43712 .68055 .43933 Mtetra
0 0 .028 r
.68055 .43933 .68119 .43712 .6828 .43561 .68209 .43627 Mtetra
0 0 0 r
.68209 .43627 .6828 .43561 .68445 .43514 .6837 .43485 Mtetra
.718 .934 .96 r
.6837 .43485 .68445 .43514 .68613 .43506 .68534 .43399 Mtetra
.674 .722 .886 r
.68534 .43399 .68613 .43506 .6878 .43473 .687 .43341 Mtetra
.635 .663 .86 r
.687 .43341 .6878 .43473 .68946 .43425 .68867 .43302 Mtetra
.616 .668 .878 r
.68867 .43302 .68946 .43425 .69113 .43375 .69034 .43271 Mtetra
.647 .721 .902 r
.69034 .43271 .69113 .43375 .69278 .43309 .692 .43226 Mtetra
.667 .776 .931 r
.692 .43226 .69278 .43309 .69443 .43241 .69367 .43172 Mtetra
.673 .812 .95 r
.69367 .43172 .69443 .43241 .6961 .43184 .69533 .43113 Mtetra
.754 .829 .91 r
.69533 .43113 .6961 .43184 .69776 .43134 .69697 .43019 Mtetra
.718 .725 .856 r
.69697 .43019 .69776 .43134 .69944 .43114 .69862 .42936 Mtetra
.621 .596 .803 r
.69862 .42936 .69944 .43114 .70116 .43163 .7003 .42901 Mtetra
.281 .324 .729 r
.7003 .42901 .70116 .43163 .70309 .43587 .70209 .43072 Mtetra
0 0 .35 r
.70209 .43072 .70309 .43587 .71567 .63292 .70427 .43947 Mtetra
.062 0 .449 r
.70427 .43947 .71567 .63292 .71775 .63777 .71674 .63343 Mtetra
.341 .3 .667 r
.71674 .63343 .71775 .63777 .71961 .63865 .71868 .63582 Mtetra
.508 .465 .744 r
.71868 .63582 .71961 .63865 .7214 .63827 .72052 .63633 Mtetra
.575 .569 .809 r
.72052 .63633 .7214 .63827 .72316 .63738 .72233 .63627 Mtetra
.605 .702 .912 r
.72233 .63627 .72316 .63738 .72491 .63634 .72413 .63597 Mtetra
.548 .869 .994 r
.72413 .63597 .72491 .63634 .72666 .6352 .72591 .63551 Mtetra
0 0 0 r
.72591 .63551 .72666 .6352 .72841 .63401 .7277 .63495 Mtetra
.359 0 0 r
.7277 .63495 .72841 .63401 .7302 .63359 .72951 .63477 Mtetra
.391 0 .074 r
.72951 .63477 .7302 .63359 .73201 .63342 .73131 .63455 Mtetra
.185 0 0 r
.73131 .63455 .73201 .63342 .73378 .63266 .73309 .63374 Mtetra
.798 .877 .446 r
.73309 .63374 .73378 .63266 .73536 .62874 .7347 .6303 Mtetra
.977 .689 .409 r
.7347 .6303 .73536 .62874 .72505 .43142 .72461 .43584 Mtetra
.836 .7 .166 r
.72461 .43584 .72505 .43142 .72629 .42374 .72551 .42265 Mtetra
.862 .769 .757 r
.72551 .42265 .72629 .42374 .72788 .42167 .72709 .42037 Mtetra
.666 .681 .855 r
.72709 .42037 .72788 .42167 .72955 .42104 .72877 .41981 Mtetra
.557 .644 .891 r
.72877 .41981 .72955 .42104 .73125 .42082 .73048 .41974 Mtetra
.601 .695 .909 r
.73048 .41974 .73125 .42082 .73294 .42035 .73218 .41947 Mtetra
.664 .765 .925 r
.73218 .41947 .73294 .42035 .73462 .41968 .73387 .41894 Mtetra
.667 .8 .947 r
.73387 .41894 .73462 .41968 .73631 .41911 .73556 .41837 Mtetra
.749 .825 .911 r
.73556 .41837 .73631 .41911 .738 .41861 .73722 .41745 Mtetra
.729 .728 .85 r
.73722 .41745 .738 .41861 .7397 .41837 .73888 .41653 Mtetra
.622 .592 .799 r
.73888 .41653 .7397 .41837 .74145 .41874 .74059 .41617 Mtetra
.211 .282 .72 r
.74059 .41617 .74145 .41874 .74341 .42206 .74245 .4182 Mtetra
.977 .681 .381 r
.74245 .4182 .74341 .42206 .75855 .61968 .75741 .61374 Mtetra
0 0 .346 r
.75741 .61374 .75855 .61968 .76078 .62535 .75997 .62433 Mtetra
0 .099 .628 r
.75997 .62433 .76078 .62535 .7627 .62654 .76194 .62624 Mtetra
.251 .727 .937 r
.76194 .62624 .7627 .62654 .76451 .62602 .76379 .62622 Mtetra
.503 .903 .783 r
.76379 .62622 .76451 .62602 .76625 .6245 .76557 .62523 Mtetra
.835 .928 .544 r
.76557 .62523 .76625 .6245 .76783 .62066 .76721 .62224 Mtetra
.986 .793 .396 r
.76721 .62224 .76783 .62066 .75579 .42533 .76829 .61139 Mtetra
.05 0 .444 r
.76829 .61139 .75579 .42533 .75678 .4148 .75605 .41431 Mtetra
.946 .857 .721 r
.75605 .41431 .75678 .4148 .75834 .41233 .75758 .4113 Mtetra
.713 .751 .882 r
.75758 .4113 .75834 .41233 .76002 .41158 .75926 .41052 Mtetra
.594 .696 .914 r
.75926 .41052 .76002 .41158 .76174 .41129 .76099 .41027 Mtetra
.676 .74 .899 r
.76099 .41027 .76174 .41129 .76344 .41066 .76269 .40968 Mtetra
.738 .77 .879 r
.76269 .40968 .76344 .41066 .76512 .40974 .76436 .40876 Mtetra
.624 .73 .923 r
.76436 .40876 .76512 .40974 .76683 .40934 .76608 .40838 Mtetra
0 .134 .66 r
.76608 .40838 .76683 .40934 .7687 .41096 .76796 .41011 Mtetra
.975 .676 .378 r
.76796 .41011 .7687 .41096 .78465 .598 .7843 .60283 Mtetra
.865 .546 .444 r
.7843 .60283 .78465 .598 .78794 .61672 .78718 .61618 Mtetra
.559 .022 0 r
.78718 .61618 .78794 .61672 .78996 .61875 .78918 .61802 Mtetra
.593 .796 .977 r
.78918 .61802 .78996 .61875 .7918 .61851 .79102 .61764 Mtetra
.736 .807 .908 r
.79102 .61764 .7918 .61851 .79361 .61765 .79282 .61671 Mtetra
.656 .766 .93 r
.79282 .61671 .79361 .61765 .79541 .6168 .79464 .61616 Mtetra
.428 .743 .993 r
.79464 .61616 .79541 .6168 .79723 .61612 .79651 .61613 Mtetra
.364 .835 .847 r
.79651 .61613 .79723 .61612 .799 .61489 .79834 .61558 Mtetra
.722 .902 .528 r
.79834 .61558 .799 .61489 .8006 .61151 .80002 .61313 Mtetra
.975 .791 .37 r
.80002 .61313 .8006 .61151 .78667 .41594 .80106 .60274 Mtetra
.066 0 .453 r
.80106 .60274 .78667 .41594 .78755 .40514 .78685 .40468 Mtetra
.959 .86 .698 r
.78685 .40468 .78755 .40514 .7891 .40247 .78835 .40141 Mtetra
.716 .747 .876 r
.78835 .40141 .7891 .40247 .7908 .4017 .79005 .40059 Mtetra
.598 .691 .907 r
.79005 .40059 .7908 .4017 .79254 .40139 .79179 .40033 Mtetra
.647 .722 .903 r
.79179 .40033 .79254 .40139 .79426 .40087 .79352 .39986 Mtetra
.739 .766 .875 r
.79352 .39986 .79426 .40087 .79595 .39993 .79521 .39893 Mtetra
.642 .732 .914 r
.79521 .39893 .79595 .39993 .79768 .39947 .79694 .39847 Mtetra
0 .329 .812 r
.79694 .39847 .79768 .39947 .79955 .40065 .79882 .39973 Mtetra
.946 .59 .212 r
.79882 .39973 .79955 .40065 .80217 .41046 .8016 .41152 Mtetra
.974 .671 .368 r
.8016 .41152 .80217 .41046 .82089 .60676 .82015 .60621 Mtetra
.658 .14 0 r
.82015 .60621 .82089 .60676 .823 .60932 .82225 .60859 Mtetra
.58 .79 .979 r
.82225 .60859 .823 .60932 .82488 .60914 .82411 .60824 Mtetra
.744 .807 .902 r
.82411 .60824 .82488 .60914 .8267 .60824 .82592 .60725 Mtetra
.719 .78 .9 r
.82592 .60725 .8267 .60824 .8285 .60717 .82774 .60639 Mtetra
.543 .761 .978 r
.82774 .60639 .8285 .60717 .83032 .60631 .82962 .60617 Mtetra
.516 .906 .938 r
.82962 .60617 .83032 .60631 .83208 .60482 .83146 .60552 Mtetra
.669 .875 .499 r
.83146 .60552 .83208 .60482 .83359 .60044 .83315 .60316 Mtetra
.892 .738 .232 r
.83315 .60316 .83359 .60044 .81724 .39942 .83402 .59176 Mtetra
.107 .024 .47 r
.83402 .59176 .81724 .39942 .81852 .39383 .81807 .39584 Mtetra
.126 0 .165 r
.81807 .39584 .81852 .39383 .82021 .39277 .81968 .39391 Mtetra
.891 .511 .308 r
.81968 .39391 .82021 .39277 .82242 .39732 .82207 .40039 Mtetra
.973 .667 .364 r
.82207 .40039 .82242 .39732 .84294 .59875 .84223 .59834 Mtetra
.799 .318 0 r
.84223 .59834 .84294 .59875 .84525 .60302 .84445 .60176 Mtetra
.44 .597 .91 r
.84445 .60176 .84525 .60302 .84718 .60326 .8464 .60209 Mtetra
.688 .734 .885 r
.8464 .60209 .84718 .60326 .84901 .60243 .84824 .60137 Mtetra
.883 .798 .761 r
.84824 .60137 .84901 .60243 .85071 .60014 .84992 .59886 Mtetra
.975 .73 .501 r
.84992 .59886 .85071 .60014 .85198 .59336 .85069 .58684 Mtetra
.974 .674 .379 r
.85069 .58684 .85198 .59336 .83464 .39353 .83364 .3896 Mtetra
.761 .575 .645 r
.83364 .3896 .83464 .39353 .83599 .38887 .83511 .38616 Mtetra
.649 .549 .728 r
.83511 .38616 .83599 .38887 .83766 .38749 .83683 .38541 Mtetra
.593 .558 .785 r
.83683 .38541 .83766 .38749 .83939 .38672 .83862 .38524 Mtetra
.568 .612 .857 r
.83862 .38524 .83939 .38672 .84114 .38619 .84042 .38516 Mtetra
.671 .743 .904 r
.84042 .38516 .84114 .38619 .84289 .38561 .84217 .38458 Mtetra
.659 .736 .907 r
.84217 .38458 .84289 .38561 .84464 .3851 .84392 .38404 Mtetra
.636 .722 .91 r
.84392 .38404 .84464 .3851 .84638 .38444 .84568 .38361 Mtetra
.582 .754 .96 r
.84568 .38361 .84638 .38444 .84809 .38339 .84747 .38333 Mtetra
.087 0 0 r
.84747 .38333 .84809 .38339 .84983 .38276 .8493 .38353 Mtetra
.711 .239 .126 r
.8493 .38353 .84983 .38276 .8517 .38333 .85128 .38519 Mtetra
.974 .664 .344 r
.85128 .38519 .8517 .38333 .85414 .38943 .87285 .57825 Mtetra
.58 .362 .549 r
.87285 .57825 .85414 .38943 .87665 .59013 .87603 .59037 Mtetra
.776 .276 .013 r
.87603 .59037 .87665 .59013 .87897 .59388 .87822 .59291 Mtetra
.36 .616 .949 r
.87822 .59291 .87897 .59388 .88095 .59426 .8802 .59329 Mtetra
.66 .767 .929 r
.8802 .59329 .88095 .59426 .88282 .59354 .88208 .59271 Mtetra
.868 .845 .82 r
.88208 .59271 .88282 .59354 .88453 .59136 .88382 .59075 Mtetra
.989 .789 .543 r
.88382 .59075 .88453 .59136 .88562 .58333 .88501 .58358 Mtetra
.977 .675 .34 r
.88501 .58358 .88562 .58333 .8661 .38179 .86545 .38132 Mtetra
.985 .835 .611 r
.86545 .38132 .8661 .38179 .86747 .37752 .86678 .3767 Mtetra
.759 .824 .903 r
.86678 .3767 .86747 .37752 .86919 .37658 .8685 .37569 Mtetra
.615 .754 .944 r
.8685 .37569 .86919 .37658 .87099 .37627 .87029 .37531 Mtetra
.585 .723 .938 r
.87029 .37531 .87099 .37627 .8728 .37611 .87209 .37505 Mtetra
.758 .77 .863 r
.87209 .37505 .8728 .37611 .87453 .3752 .8738 .37397 Mtetra
.683 .709 .868 r
.8738 .37397 .87453 .3752 .8763 .37462 .87556 .3733 Mtetra
.456 .578 .888 r
.87556 .3733 .8763 .37462 .87816 .37487 .87743 .37363 Mtetra
.771 .371 0 r
.87743 .37363 .87816 .37487 .88042 .37866 .87987 .37909 Mtetra
.973 .662 .321 r
.87987 .37909 .88042 .37866 .90451 .578 .90421 .58093 Mtetra
.768 .411 .379 r
.90421 .58093 .90451 .578 .90713 .58395 .90663 .58503 Mtetra
.411 0 .049 r
.90663 .58503 .90713 .58395 .90917 .58462 .90858 .58494 Mtetra
0 0 0 r
.90858 .58494 .90917 .58462 .91111 .58449 .91045 .58412 Mtetra
.731 .947 .951 r
.91045 .58412 .91111 .58449 .91303 .58402 .9123 .58307 Mtetra
.477 .688 .959 r
.9123 .58307 .91303 .58402 .91499 .58398 .91427 .58312 Mtetra
.601 .771 .961 r
.91427 .58312 .91499 .58398 .9169 .58346 .91619 .58274 Mtetra
.814 .872 .889 r
.91619 .58274 .9169 .58346 .9187 .58204 .918 .58134 Mtetra
.989 .788 .542 r
.918 .58134 .9187 .58204 .92005 .57671 .91916 .57428 Mtetra
.975 .669 .331 r
.91916 .57428 .92005 .57671 .89855 .37575 .89744 .37125 Mtetra
.789 .581 .619 r
.89744 .37125 .89855 .37575 .89963 .36917 .89873 .36637 Mtetra
.665 .555 .721 r
.89873 .36637 .89963 .36917 .90128 .36749 .90047 .36541 Mtetra
.606 .568 .785 r
.90047 .36541 .90128 .36749 .90302 .36654 .90229 .36514 Mtetra
.532 .607 .874 r
.90229 .36514 .90302 .36654 .90481 .36596 .90415 .36521 Mtetra
.622 .796 .966 r
.90415 .36521 .90481 .36596 .9066 .36538 .90595 .36475 Mtetra
.614 .83 .983 r
.90595 .36475 .9066 .36538 .9084 .36492 .90776 .36428 Mtetra
.627 .83 .978 r
.90776 .36428 .9084 .36492 .91021 .36452 .90955 .36377 Mtetra
.648 .807 .96 r
.90955 .36377 .91021 .36452 .91202 .36406 .91135 .36323 Mtetra
.663 .792 .943 r
.91135 .36323 .91202 .36406 .91382 .36358 .91314 .36265 Mtetra
.677 .772 .922 r
.91314 .36265 .91382 .36358 .91562 .36307 .91493 .36202 Mtetra
.716 .761 .888 r
.91493 .36202 .91562 .36307 .91741 .36246 .91669 .36118 Mtetra
.695 .709 .859 r
.91669 .36118 .91741 .36246 .9192 .36182 .91847 .36042 Mtetra
.663 .676 .852 r
.91847 .36042 .9192 .36182 .92098 .36116 .92026 .35983 Mtetra
0 .232 .743 r
.33726 .5422 .33816 .54329 .33961 .54304 .33864 .5433 Mtetra
.848 .466 .325 r
.33864 .5433 .33961 .54304 .34104 .54324 .33992 .54611 Mtetra
.932 .677 .529 r
.33992 .54611 .34104 .54324 .34242 .54432 .33141 .72876 Mtetra
.58 .364 .552 r
.33141 .72876 .34242 .54432 .34331 .55455 .33238 .73901 Mtetra
.567 .353 .55 r
.33238 .73901 .34331 .55455 .33485 .74017 .33376 .74162 Mtetra
.666 .289 .323 r
.33376 .74162 .33485 .74017 .33622 .74329 .33523 .74274 Mtetra
.395 .738 .992 r
.33523 .74274 .33622 .74329 .33774 .74345 .33676 .74274 Mtetra
.68 .79 .933 r
.33676 .74274 .33774 .74345 .3393 .74291 .33832 .74218 Mtetra
.781 .795 .864 r
.33832 .74218 .3393 .74291 .34088 .7419 .33991 .74105 Mtetra
.849 .763 .767 r
.33991 .74105 .34088 .7419 .34245 .74121 .34156 .73887 Mtetra
.818 .648 .671 r
.34156 .73887 .34245 .74121 .34404 .74012 .34329 .73497 Mtetra
.932 .68 .535 r
.34329 .73497 .34404 .74012 .34567 .73816 .35394 .55478 Mtetra
.59 .376 .559 r
.35394 .55478 .34567 .73816 .34766 .729 .35611 .5406 Mtetra
.569 .359 .555 r
.35611 .5406 .34766 .729 .35852 .54039 .35773 .53724 Mtetra
.718 .564 .68 r
.35773 .53724 .35852 .54039 .36017 .53646 .35927 .53531 Mtetra
.699 .694 .842 r
.35927 .53531 .36017 .53646 .36167 .53545 .36076 .53463 Mtetra
.604 .733 .936 r
.36076 .53463 .36167 .53545 .36314 .53513 .36223 .53436 Mtetra
.519 .719 .964 r
.36223 .53436 .36314 .53513 .36459 .53511 .36368 .53429 Mtetra
.699 .758 .897 r
.36368 .53429 .36459 .53511 .36607 .53464 .36517 .53367 Mtetra
.682 .724 .881 r
.36517 .53367 .36607 .53464 .36755 .53414 .36665 .53312 Mtetra
.604 .688 .901 r
.36665 .53312 .36755 .53414 .36902 .53375 .36812 .53288 Mtetra
0 .261 .743 r
.36812 .53288 .36902 .53375 .37049 .53346 .36953 .53385 Mtetra
.831 .442 .314 r
.36953 .53385 .37049 .53346 .37195 .53353 .37087 .53644 Mtetra
.935 .677 .522 r
.37087 .53644 .37195 .53353 .37337 .53438 .36423 .71487 Mtetra
.587 .37 .553 r
.36423 .71487 .37337 .53438 .37452 .54128 .36511 .72941 Mtetra
.567 .353 .55 r
.36511 .72941 .37452 .54128 .36762 .73032 .36654 .73226 Mtetra
.663 .312 .367 r
.36654 .73226 .36762 .73032 .36901 .73388 .36803 .7335 Mtetra
.212 .683 .939 r
.36803 .7335 .36901 .73388 .37055 .73429 .36958 .73361 Mtetra
.663 .795 .945 r
.36958 .73361 .37055 .73429 .37212 .7338 .37116 .73309 Mtetra
.774 .803 .876 r
.37116 .73309 .37212 .7338 .37372 .73284 .37276 .73203 Mtetra
.847 .775 .781 r
.37276 .73203 .37372 .73284 .3753 .73211 .3744 .73 Mtetra
.821 .658 .681 r
.3744 .73 .3753 .73211 .3769 .73112 .3761 .72645 Mtetra
.847 .626 .603 r
.3761 .72645 .3769 .73112 .37853 .72939 .37812 .71536 Mtetra
.923 .669 .535 r
.37812 .71536 .37853 .72939 .38034 .72314 .38719 .53208 Mtetra
.57 .359 .555 r
.38719 .53208 .38034 .72314 .3896 .53219 .38882 .52836 Mtetra
.705 .541 .663 r
.38882 .52836 .3896 .53219 .39126 .52743 .39037 .5263 Mtetra
.73 .708 .83 r
.39037 .5263 .39126 .52743 .39279 .52609 .39188 .52541 Mtetra
.637 .783 .951 r
.39188 .52541 .39279 .52609 .39428 .52567 .39337 .52501 Mtetra
.553 .764 .976 r
.39337 .52501 .39428 .52567 .39575 .52559 .39486 .52482 Mtetra
.635 .757 .937 r
.39486 .52482 .39575 .52559 .39724 .52526 .39635 .52445 Mtetra
.66 .754 .92 r
.39635 .52445 .39724 .52526 .39874 .52481 .39784 .52398 Mtetra
.666 .754 .915 r
.39784 .52398 .39874 .52481 .40023 .52433 .39934 .5235 Mtetra
.67 .752 .912 r
.39934 .5235 .40023 .52433 .40173 .52383 .40084 .523 Mtetra
.676 .755 .91 r
.40084 .523 .40173 .52383 .40323 .52329 .40234 .52248 Mtetra
.686 .76 .907 r
.40234 .52248 .40323 .52329 .40473 .52273 .40384 .52191 Mtetra
.709 .764 .895 r
.40384 .52191 .40473 .52273 .40624 .5221 .40534 .52124 Mtetra
.714 .755 .884 r
.40534 .52124 .40624 .5221 .40774 .52146 .40685 .52053 Mtetra
.707 .74 .877 r
.40685 .52053 .40774 .52146 .40925 .52083 .40836 .51985 Mtetra
.716 .731 .863 r
.40836 .51985 .40925 .52083 .41076 .52 .40987 .5191 Mtetra
.695 .743 .888 r
.40987 .5191 .41076 .52 .41227 .51933 .41138 .51849 Mtetra
.615 .735 .932 r
.41138 .51849 .41227 .51933 .41376 .51913 .41288 .51818 Mtetra
.013 .393 .85 r
.41288 .51818 .41376 .51913 .41519 .52096 .41434 .51899 Mtetra
0 .014 .588 r
.41434 .51899 .41519 .52096 .41638 .53015 .41576 .52121 Mtetra
.227 .141 .545 r
.41576 .52121 .41638 .53015 .41187 .71829 .41707 .5268 Mtetra
0 0 .37 r
.41707 .5268 .41187 .71829 .4134 .71994 .413 .70208 Mtetra
.557 .368 .581 r
.413 .70208 .4134 .71994 .41499 .71961 .41456 .70257 Mtetra
.921 .664 .532 r
.41456 .70257 .41499 .71961 .41661 .71867 .42135 .53355 Mtetra
.575 .364 .556 r
.42135 .53355 .41661 .71867 .41822 .71788 .42305 .52704 Mtetra
.567 .356 .555 r
.42305 .52704 .41822 .71788 .41982 .71732 .42461 .52514 Mtetra
.56 .351 .554 r
.42461 .52514 .41982 .71732 .42142 .71699 .42606 .52682 Mtetra
0 0 .354 r
.42606 .52682 .42142 .71699 .42299 .71731 .42224 .70996 Mtetra
.173 .12 .552 r
.42224 .70996 .42299 .71731 .42457 .71787 .42368 .71508 Mtetra
.078 .179 .668 r
.42368 .71508 .42457 .71787 .42615 .71827 .42521 .71731 Mtetra
.205 .526 .92 r
.42521 .71731 .42615 .71827 .42774 .71825 .42679 .71788 Mtetra
.455 .816 .996 r
.42679 .71788 .42774 .71825 .42934 .71794 .42839 .71766 Mtetra
.573 .885 .991 r
.42839 .71766 .42934 .71794 .43095 .71752 .43 .71719 Mtetra
.587 .876 .993 r
.43 .71719 .43095 .71752 .43256 .71709 .43161 .71672 Mtetra
.585 .866 .995 r
.43161 .71672 .43256 .71709 .43417 .71666 .43322 .71628 Mtetra
.601 .869 .993 r
.43322 .71628 .43417 .71666 .43578 .7162 .43483 .71581 Mtetra
.6 .864 .993 r
.43483 .71581 .43578 .7162 .43739 .71575 .43644 .71535 Mtetra
.601 .862 .992 r
.43644 .71535 .43739 .71575 .439 .7153 .43805 .7149 Mtetra
.616 .865 .99 r
.43805 .7149 .439 .7153 .44061 .71483 .43967 .71441 Mtetra
.654 .87 .98 r
.43967 .71441 .44061 .71483 .44223 .7143 .44129 .71383 Mtetra
.682 .862 .967 r
.44129 .71383 .44223 .7143 .44385 .71374 .44291 .71319 Mtetra
.689 .842 .957 r
.44291 .71319 .44385 .71374 .44546 .71318 .44453 .71254 Mtetra
.67 .817 .954 r
.44453 .71254 .44546 .71318 .44708 .71266 .44615 .71198 Mtetra
.649 .8 .955 r
.44615 .71198 .44708 .71266 .4487 .71219 .44777 .71149 Mtetra
.64 .794 .956 r
.44777 .71149 .4487 .71219 .45032 .71174 .44938 .71104 Mtetra
.637 .793 .957 r
.44938 .71104 .45032 .71174 .45194 .7113 .451 .7106 Mtetra
.637 .792 .957 r
.451 .7106 .45194 .7113 .45356 .71086 .45263 .71015 Mtetra
.636 .79 .956 r
.45263 .71015 .45356 .71086 .45518 .71043 .45425 .70972 Mtetra
.586 .774 .969 r
.45425 .70972 .45518 .71043 .4568 .71022 .45587 .70942 Mtetra
.591 .754 .956 r
.45587 .70942 .4568 .71022 .45841 .71002 .45749 .70914 Mtetra
.674 .758 .914 r
.45749 .70914 .45841 .71002 .46004 .70938 .45911 .70858 Mtetra
.82 .794 .827 r
.45911 .70858 .46004 .70938 .4617 .70702 .46076 .70704 Mtetra
.948 .881 .734 r
.46076 .70704 .4617 .70702 .46345 .6998 .46243 .70398 Mtetra
0 0 .018 r
.46243 .70398 .46345 .6998 .46833 .50707 .46415 .6985 Mtetra
.542 .333 .546 r
.46415 .6985 .46833 .50707 .46992 .50364 .46596 .6869 Mtetra
.52 .315 .542 r
.46596 .6869 .46992 .50364 .47146 .5029 .46794 .66456 Mtetra
.605 .384 .554 r
.46794 .66456 .47146 .5029 .47299 .5028 .46916 .68863 Mtetra
.566 .352 .549 r
.46916 .68863 .47299 .5028 .47452 .50264 .47074 .6909 Mtetra
.562 .349 .549 r
.47074 .6909 .47452 .50264 .47606 .50218 .47236 .6906 Mtetra
.47236 .6906 .47606 .50218 .4776 .50172 .47399 .69028 Mtetra
.47399 .69028 .4776 .50172 .47914 .50124 .47562 .68983 Mtetra
.561 .348 .549 r
.47562 .68983 .47914 .50124 .48068 .50075 .47725 .68923 Mtetra
.47725 .68923 .48068 .50075 .48223 .50025 .47888 .68863 Mtetra
.47888 .68863 .48223 .50025 .48377 .49976 .48051 .68815 Mtetra
.562 .349 .549 r
.48051 .68815 .48377 .49976 .48531 .49929 .48214 .68782 Mtetra
.48214 .68782 .48531 .49929 .48686 .49882 .48377 .6875 Mtetra
.564 .351 .549 r
.48377 .6875 .48686 .49882 .4884 .49844 .48539 .68868 Mtetra
.48539 .68868 .4884 .49844 .48995 .49811 .48701 .68997 Mtetra
.56 .348 .549 r
.48701 .68997 .48995 .49811 .4915 .49761 .48865 .68885 Mtetra
0 0 .378 r
.48865 .68885 .4915 .49761 .49305 .49659 .49209 .50538 Mtetra
0 0 .288 r
.49209 .50538 .49305 .49659 .49461 .49516 .49372 .49674 Mtetra
.785 .867 .428 r
.49372 .49674 .49461 .49516 .49616 .49386 .4953 .49333 Mtetra
.86 .838 .824 r
.4953 .49333 .49616 .49386 .49772 .49295 .49686 .49163 Mtetra
.68 .671 .835 r
.49686 .49163 .49772 .49295 .49927 .49243 .49841 .49102 Mtetra
.625 .634 .839 r
.49841 .49102 .49927 .49243 .50082 .49204 .49997 .49069 Mtetra
.623 .644 .85 r
.49997 .49069 .50082 .49204 .50237 .49164 .50152 .49038 Mtetra
.655 .671 .853 r
.50152 .49038 .50237 .49164 .50392 .49117 .50307 .48991 Mtetra
.65 .669 .855 r
.50307 .48991 .50392 .49117 .50548 .49071 .50463 .48947 Mtetra
.638 .668 .862 r
.50463 .48947 .50548 .49071 .50703 .49027 .50618 .48909 Mtetra
.623 .671 .876 r
.50618 .48909 .50703 .49027 .50859 .48987 .50774 .48877 Mtetra
.621 .687 .891 r
.50774 .48877 .50859 .48987 .51015 .48946 .50929 .48846 Mtetra
.633 .712 .904 r
.50929 .48846 .51015 .48946 .5117 .48902 .51085 .4881 Mtetra
.655 .737 .91 r
.51085 .4881 .5117 .48902 .51326 .48852 .51241 .48764 Mtetra
.67 .751 .911 r
.51241 .48764 .51326 .48852 .51482 .48798 .51397 .48712 Mtetra
.689 .76 .906 r
.51397 .48712 .51482 .48798 .51638 .4874 .51553 .48652 Mtetra
.706 .761 .895 r
.51553 .48652 .51638 .4874 .51795 .48676 .5171 .48584 Mtetra
.705 .75 .887 r
.5171 .48584 .51795 .48676 .51951 .48613 .51866 .48515 Mtetra
.708 .739 .876 r
.51866 .48515 .51951 .48613 .52107 .48541 .52022 .48444 Mtetra
.71 .742 .877 r
.52022 .48444 .52107 .48541 .52264 .48459 .52179 .48372 Mtetra
.657 .749 .917 r
.52179 .48372 .52264 .48459 .5242 .48415 .52335 .48325 Mtetra
.416 .642 .95 r
.52335 .48325 .5242 .48415 .52577 .48483 .52492 .48345 Mtetra
0 .15 .693 r
.52492 .48345 .52577 .48483 .52734 .48918 .52649 .48509 Mtetra
.056 .096 .587 r
.52649 .48509 .52734 .48918 .52914 .68268 .52806 .48871 Mtetra
.543 .338 .552 r
.52806 .48871 .52914 .68268 .53082 .68697 .52965 .49963 Mtetra
.566 .356 .555 r
.52965 .49963 .53082 .68697 .53248 .68688 .53123 .49807 Mtetra
.568 .357 .555 r
.53123 .49807 .53248 .68688 .53415 .68615 .5328 .49544 Mtetra
.013 0 .41 r
.5328 .49544 .53415 .68615 .53582 .68566 .53489 .67374 Mtetra
.202 .118 .532 r
.53489 .67374 .53582 .68566 .53749 .6862 .53659 .68216 Mtetra
.191 .2 .639 r
.53659 .68216 .53749 .6862 .53917 .68664 .53827 .68508 Mtetra
.141 .36 .817 r
.53827 .68508 .53917 .68664 .54084 .68678 .53995 .68628 Mtetra
.422 .769 .996 r
.53995 .68628 .54084 .68678 .54252 .68651 .54163 .6862 Mtetra
.534 .867 .993 r
.54163 .6862 .54252 .68651 .54419 .68611 .5433 .68579 Mtetra
.597 .887 .991 r
.5433 .68579 .54419 .68611 .54587 .68566 .54498 .68526 Mtetra
.575 .862 .996 r
.54498 .68526 .54587 .68566 .54755 .68522 .54666 .68482 Mtetra
.59 .867 .994 r
.54666 .68482 .54755 .68522 .54922 .68476 .54834 .68435 Mtetra
.598 .866 .993 r
.54834 .68435 .54922 .68476 .5509 .6843 .55002 .68387 Mtetra
.594 .861 .994 r
.55002 .68387 .5509 .6843 .55258 .68384 .5517 .68341 Mtetra
.595 .86 .993 r
.5517 .68341 .55258 .68384 .55427 .68338 .55338 .68295 Mtetra
.596 .859 .993 r
.55338 .68295 .55427 .68338 .55595 .68292 .55506 .68248 Mtetra
.597 .859 .993 r
.55506 .68248 .55595 .68292 .55763 .68246 .55675 .68202 Mtetra
.598 .859 .993 r
.55675 .68202 .55763 .68246 .55932 .68199 .55843 .68155 Mtetra
.55843 .68155 .55932 .68199 .561 .68153 .56012 .68109 Mtetra
.56012 .68109 .561 .68153 .56269 .68106 .56181 .68062 Mtetra
.599 .859 .993 r
.56181 .68062 .56269 .68106 .56437 .68059 .56349 .68015 Mtetra
.599 .858 .993 r
.56349 .68015 .56437 .68059 .56606 .68013 .56518 .67968 Mtetra
.56518 .67968 .56606 .68013 .56775 .67966 .56687 .67921 Mtetra
.599 .859 .993 r
.56687 .67921 .56775 .67966 .56944 .67919 .56856 .67874 Mtetra
.56856 .67874 .56944 .67919 .57113 .67872 .57026 .67827 Mtetra
.57026 .67827 .57113 .67872 .57283 .67825 .57195 .6778 Mtetra
.57195 .6778 .57283 .67825 .57452 .67778 .57364 .67733 Mtetra
.57364 .67733 .57452 .67778 .57622 .67731 .57534 .67686 Mtetra
.57534 .67686 .57622 .67731 .57791 .67683 .57704 .67639 Mtetra
.57704 .67639 .57791 .67683 .57961 .67636 .57873 .67592 Mtetra
.599 .86 .993 r
.57873 .67592 .57961 .67636 .58131 .67589 .58043 .67544 Mtetra
.58043 .67544 .58131 .67589 .583 .67541 .58213 .67497 Mtetra
.599 .861 .993 r
.58213 .67497 .583 .67541 .5847 .67493 .58383 .67449 Mtetra
.597 .861 .993 r
.58383 .67449 .5847 .67493 .5864 .67445 .58554 .67402 Mtetra
.588 .86 .994 r
.58554 .67402 .5864 .67445 .58811 .67397 .58724 .67356 Mtetra
.593 .866 .994 r
.58724 .67356 .58811 .67397 .58981 .67349 .58894 .67308 Mtetra
.599 .87 .993 r
.58894 .67308 .58981 .67349 .59151 .67298 .59065 .67258 Mtetra
.553 .856 .997 r
.59065 .67258 .59151 .67298 .59322 .6725 .59235 .67218 Mtetra
.628 .901 .985 r
.59235 .67218 .59322 .6725 .59492 .67192 .59406 .67156 Mtetra
.776 .915 .933 r
.59406 .67156 .59492 .67192 .59662 .67118 .59575 .67048 Mtetra
.903 .812 .748 r
.59575 .67048 .59662 .67118 .59831 .66993 .59741 .66772 Mtetra
.859 .675 .652 r
.59741 .66772 .59831 .66993 .6 .66851 .59903 .66296 Mtetra
.958 .684 .473 r
.59903 .66296 .6 .66851 .60169 .66712 .59676 .47943 Mtetra
.57 .359 .555 r
.59676 .47943 .60169 .66712 .60341 .66705 .5983 .47542 Mtetra
.557 .349 .554 r
.5983 .47542 .60341 .66705 .60512 .6667 .6 .47886 Mtetra
.572 .36 .555 r
.6 .47886 .60512 .6667 .60682 .66539 .60152 .47407 Mtetra
.581 .368 .556 r
.60152 .47407 .60682 .66539 .60829 .65501 .6029 .46343 Mtetra
.57 .359 .555 r
.6029 .46343 .60829 .65501 .6053 .46249 .60444 .45969 Mtetra
.748 .595 .687 r
.60444 .45969 .6053 .46249 .60683 .45858 .60601 .45746 Mtetra
.689 .713 .867 r
.60601 .45746 .60683 .45858 .60843 .45768 .60762 .45682 Mtetra
.601 .736 .939 r
.60762 .45682 .60843 .45768 .61005 .45735 .60924 .45653 Mtetra
.536 .721 .959 r
.60924 .45653 .61005 .45735 .61168 .45731 .61086 .45641 Mtetra
.651 .747 .92 r
.61086 .45641 .61168 .45731 .6133 .45685 .61248 .45595 Mtetra
.665 .752 .915 r
.61248 .45595 .6133 .45685 .61491 .45636 .6141 .45543 Mtetra
.678 .75 .905 r
.6141 .45543 .61491 .45636 .61653 .45583 .61572 .45486 Mtetra
.745 .758 .864 r
.61572 .45486 .61653 .45583 .61814 .45512 .61732 .45391 Mtetra
.703 .705 .849 r
.61732 .45391 .61814 .45512 .61976 .45446 .61894 .45316 Mtetra
.629 .66 .861 r
.61894 .45316 .61976 .45446 .62138 .45397 .62056 .45281 Mtetra
.055 .363 .834 r
.62056 .45281 .62138 .45397 .62301 .4537 .62223 .4539 Mtetra
.843 .407 .189 r
.62223 .4539 .62301 .4537 .62466 .45389 .62396 .45678 Mtetra
.962 .678 .449 r
.62396 .45678 .62466 .45389 .62633 .45499 .63139 .64515 Mtetra
.578 .361 .55 r
.63139 .64515 .62633 .45499 .62829 .4652 .63344 .65524 Mtetra
.566 .352 .549 r
.63344 .65524 .62829 .4652 .63605 .65637 .63527 .65788 Mtetra
.652 .255 .279 r
.63527 .65788 .63605 .65637 .6379 .65959 .63705 .65904 Mtetra
.302 .694 .977 r
.63705 .65904 .6379 .65959 .63966 .65986 .63881 .65918 Mtetra
.619 .807 .972 r
.63881 .65918 .63966 .65986 .64139 .65935 .64055 .65874 Mtetra
.762 .856 .92 r
.64055 .65874 .64139 .65935 .64311 .65837 .64227 .65772 Mtetra
.886 .839 .794 r
.64227 .65772 .64311 .65837 .64484 .65755 .64394 .65553 Mtetra
.852 .684 .673 r
.64394 .65553 .64484 .65755 .64655 .65629 .64556 .65164 Mtetra
.903 .653 .551 r
.64556 .65164 .64655 .65629 .64822 .65412 .64671 .63429 Mtetra
.943 .664 .481 r
.64671 .63429 .64822 .65412 .64964 .64479 .6419 .45087 Mtetra
.569 .358 .555 r
.6419 .45087 .64964 .64479 .64431 .45046 .64342 .44723 Mtetra
.725 .569 .679 r
.64342 .44723 .64431 .45046 .64581 .44635 .645 .44515 Mtetra
.726 .716 .841 r
.645 .44515 .64581 .44635 .64742 .44513 .64662 .44425 Mtetra
.655 .754 .923 r
.64662 .44425 .64742 .44513 .64906 .44464 .64826 .44377 Mtetra
.6 .737 .941 r
.64826 .44377 .64906 .44464 .65071 .44445 .64991 .44347 Mtetra
.655 .734 .907 r
.64991 .44347 .65071 .44445 .65235 .44398 .65155 .443 Mtetra
.663 .735 .903 r
.65155 .443 .65235 .44398 .65399 .44346 .65319 .44248 Mtetra
.65319 .44248 .65399 .44346 .65563 .44296 .65483 .44196 Mtetra
.706 .747 .884 r
.65483 .44196 .65563 .44296 .65726 .44213 .65646 .44123 Mtetra
.686 .762 .91 r
.65646 .44123 .65726 .44213 .65889 .44149 .6581 .44062 Mtetra
.603 .739 .941 r
.6581 .44062 .65889 .44149 .66055 .44135 .65975 .44032 Mtetra
.199 .488 .899 r
.65975 .44032 .66055 .44135 .66231 .44348 .66145 .44105 Mtetra
.151 .25 .713 r
.66145 .44105 .66231 .44348 .6645 .45578 .66321 .44309 Mtetra
.329 .213 .565 r
.66321 .44309 .6645 .45578 .67437 .64579 .66518 .45016 Mtetra
.056 0 .442 r
.66518 .45016 .67437 .64579 .67623 .64775 .67517 .64189 Mtetra
.282 .229 .618 r
.67517 .64189 .67623 .64775 .67803 .64822 .67712 .64565 Mtetra
.295 .347 .747 r
.67712 .64565 .67803 .64822 .6798 .64813 .67897 .64722 Mtetra
.365 .633 .957 r
.67897 .64722 .6798 .64813 .68159 .64814 .68076 .64752 Mtetra
.586 .814 .986 r
.68076 .64752 .68159 .64814 .68335 .64782 .68253 .64714 Mtetra
.744 .842 .925 r
.68253 .64714 .68335 .64782 .6851 .64689 .68427 .64621 Mtetra
.859 .846 .83 r
.68427 .64621 .6851 .64689 .68673 .64374 .68597 .6444 Mtetra
.9 .954 .611 r
.68597 .6444 .68673 .64374 .68806 .63408 .68762 .64137 Mtetra
.124 0 .364 r
.68762 .64137 .68806 .63408 .68055 .43933 .6891 .63489 Mtetra
.056 0 .437 r
.6891 .63489 .68055 .43933 .68209 .43627 .68156 .44074 Mtetra
0 0 .244 r
.68156 .44074 .68209 .43627 .6837 .43485 .683 .43559 Mtetra
.801 .932 .563 r
.683 .43559 .6837 .43485 .68534 .43399 .68456 .43307 Mtetra
.755 .779 .873 r
.68456 .43307 .68534 .43399 .687 .43341 .68619 .43207 Mtetra
.626 .656 .859 r
.68619 .43207 .687 .43341 .68867 .43302 .68786 .43172 Mtetra
.568 .636 .879 r
.68786 .43172 .68867 .43302 .69034 .43271 .68955 .43163 Mtetra
.621 .7 .901 r
.68955 .43163 .69034 .43271 .692 .43226 .69122 .43129 Mtetra
.659 .739 .909 r
.69122 .43129 .692 .43226 .69367 .43172 .69288 .43079 Mtetra
.674 .754 .911 r
.69288 .43079 .69367 .43172 .69533 .43113 .69455 .43021 Mtetra
.736 .776 .885 r
.69455 .43021 .69533 .43113 .69697 .43019 .69619 .42933 Mtetra
.733 .788 .897 r
.69619 .42933 .69697 .43019 .69862 .42936 .69784 .42848 Mtetra
.664 .764 .925 r
.69784 .42848 .69862 .42936 .7003 .42901 .69951 .42795 Mtetra
.34 .565 .921 r
.69951 .42795 .7003 .42901 .70209 .43072 .70123 .42843 Mtetra
.193 .292 .737 r
.70123 .42843 .70209 .43072 .70427 .43947 .70303 .43025 Mtetra
.302 .209 .581 r
.70303 .43025 .70427 .43947 .71674 .63343 .70505 .43597 Mtetra
.078 0 .454 r
.70505 .43597 .71674 .63343 .71868 .63582 .71754 .62919 Mtetra
.293 .227 .61 r
.71754 .62919 .71868 .63582 .72052 .63633 .71959 .63343 Mtetra
.313 .339 .727 r
.71959 .63343 .72052 .63633 .72233 .63627 .7215 .63517 Mtetra
.428 .62 .932 r
.7215 .63517 .72233 .63627 .72413 .63597 .72333 .63544 Mtetra
.585 .842 .993 r
.72333 .63544 .72413 .63597 .72591 .63551 .72512 .635 Mtetra
.677 .877 .973 r
.72512 .635 .72591 .63551 .7277 .63495 .7269 .63429 Mtetra
.54 .788 .99 r
.7269 .63429 .7277 .63495 .72951 .63477 .7287 .63403 Mtetra
.546 .77 .981 r
.7287 .63403 .72951 .63477 .73131 .63455 .73051 .6338 Mtetra
.721 .826 .93 r
.73051 .6338 .73131 .63455 .73309 .63374 .73228 .63297 Mtetra
.933 .81 .701 r
.73228 .63297 .73309 .63374 .7347 .6303 .73389 .62943 Mtetra
.974 .687 .415 r
.73389 .62943 .7347 .6303 .72461 .43584 .72371 .43288 Mtetra
.918 .675 .555 r
.72371 .43288 .72461 .43584 .72551 .42265 .72472 .42132 Mtetra
.837 .734 .75 r
.72472 .42132 .72551 .42265 .72709 .42037 .7263 .41913 Mtetra
.653 .685 .868 r
.7263 .41913 .72709 .42037 .72877 .41981 .72799 .41864 Mtetra
.526 .642 .907 r
.72799 .41864 .72877 .41981 .73048 .41974 .72971 .41867 Mtetra
.581 .687 .914 r
.72971 .41867 .73048 .41974 .73218 .41947 .73142 .41847 Mtetra
.657 .735 .907 r
.73142 .41847 .73218 .41947 .73387 .41894 .7331 .41797 Mtetra
.668 .747 .91 r
.7331 .41797 .73387 .41894 .73556 .41837 .73479 .41742 Mtetra
.748 .775 .875 r
.73479 .41742 .73556 .41837 .73722 .41745 .73645 .41645 Mtetra
.748 .765 .867 r
.73645 .41645 .73722 .41745 .73888 .41653 .73811 .41546 Mtetra
.635 .712 .903 r
.73811 .41546 .73888 .41653 .74059 .41617 .73981 .41505 Mtetra
0 .059 .607 r
.73981 .41505 .74059 .41617 .74245 .4182 .74168 .41709 Mtetra
.975 .678 .39 r
.74168 .41709 .74245 .4182 .75741 .61374 .75665 .61346 Mtetra
.945 .585 .272 r
.75665 .61346 .75741 .61374 .75997 .62433 .75919 .6237 Mtetra
.546 .018 0 r
.75919 .6237 .75997 .62433 .76194 .62624 .76116 .62557 Mtetra
.446 .745 .992 r
.76116 .62557 .76194 .62624 .76379 .62622 .763 .62553 Mtetra
.755 .852 .923 r
.763 .62553 .76379 .62622 .76557 .62523 .76478 .62452 Mtetra
.925 .835 .737 r
.76478 .62452 .76557 .62523 .76721 .62224 .76642 .62155 Mtetra
.979 .752 .525 r
.76642 .62155 .76721 .62224 .76829 .61139 .76755 .61132 Mtetra
.977 .686 .398 r
.76755 .61132 .76829 .61139 .75605 .41431 .7553 .41337 Mtetra
.913 .793 .715 r
.7553 .41337 .75605 .41431 .75758 .4113 .75682 .41031 Mtetra
.714 .759 .887 r
.75682 .41031 .75758 .4113 .75926 .41052 .75851 .40952 Mtetra
.585 .709 .928 r
.75851 .40952 .75926 .41052 .76099 .41027 .76023 .40929 Mtetra
.674 .748 .906 r
.76023 .40929 .76099 .41027 .76269 .40968 .76193 .40871 Mtetra
.738 .771 .879 r
.76193 .40871 .76269 .40968 .76436 .40876 .76361 .40779 Mtetra
.621 .729 .924 r
.76361 .40779 .76436 .40876 .76608 .40838 .76533 .40742 Mtetra
0 .097 .627 r
.76533 .40742 .76608 .40838 .76796 .41011 .76721 .40925 Mtetra
.975 .676 .378 r
.76721 .40925 .76796 .41011 .7843 .60283 .78371 .60449 Mtetra
.915 .569 .368 r
.78371 .60449 .7843 .60283 .78718 .61618 .78641 .6156 Mtetra
.508 0 0 r
.78641 .6156 .78718 .61618 .78918 .61802 .78841 .61732 Mtetra
.621 .813 .974 r
.78841 .61732 .78918 .61802 .79102 .61764 .79024 .61685 Mtetra
.755 .829 .909 r
.79024 .61685 .79102 .61764 .79282 .61671 .79203 .61582 Mtetra
.661 .779 .936 r
.79203 .61582 .79282 .61671 .79464 .61616 .79386 .61524 Mtetra
.479 .693 .962 r
.79386 .61524 .79464 .61616 .79651 .61613 .79573 .61527 Mtetra
.636 .778 .949 r
.79573 .61527 .79651 .61613 .79834 .61558 .79757 .61479 Mtetra
.896 .836 .778 r
.79757 .61479 .79834 .61558 .80002 .61313 .79925 .61239 Mtetra
.981 .754 .521 r
.79925 .61239 .80002 .61313 .80106 .60274 .80033 .60243 Mtetra
.977 .683 .384 r
.80033 .60243 .80106 .60274 .78685 .40468 .78611 .40369 Mtetra
.92 .788 .699 r
.78611 .40369 .78685 .40468 .78835 .40141 .7876 .40036 Mtetra
.716 .752 .881 r
.7876 .40036 .78835 .40141 .79005 .40059 .7893 .39956 Mtetra
.591 .703 .921 r
.7893 .39956 .79005 .40059 .79179 .40033 .79105 .39931 Mtetra
.643 .729 .911 r
.79105 .39931 .79179 .40033 .79352 .39986 .79278 .39886 Mtetra
.739 .767 .876 r
.79278 .39886 .79352 .39986 .79521 .39893 .79447 .39792 Mtetra
.639 .731 .916 r
.79447 .39792 .79521 .39893 .79694 .39847 .7962 .39748 Mtetra
0 .303 .795 r
.7962 .39748 .79694 .39847 .79882 .39973 .79809 .39881 Mtetra
.957 .614 .254 r
.79809 .39881 .79882 .39973 .8016 .41152 .80119 .41439 Mtetra
.973 .669 .374 r
.80119 .41439 .8016 .41152 .82015 .60621 .81941 .60564 Mtetra
.619 .098 0 r
.81941 .60564 .82015 .60621 .82225 .60859 .82149 .60787 Mtetra
.613 .807 .974 r
.82149 .60787 .82225 .60859 .82411 .60824 .82335 .60741 Mtetra
.764 .828 .901 r
.82335 .60741 .82411 .60824 .82592 .60725 .82515 .60632 Mtetra
.74 .798 .899 r
.82515 .60632 .82592 .60725 .82774 .60639 .82696 .60535 Mtetra
.587 .716 .933 r
.82696 .60535 .82774 .60639 .82962 .60617 .82883 .60509 Mtetra
.649 .733 .911 r
.82883 .60509 .82962 .60617 .83146 .60552 .83069 .60457 Mtetra
.817 .811 .845 r
.83069 .60457 .83146 .60552 .83315 .60316 .83245 .60303 Mtetra
.986 .884 .639 r
.83245 .60303 .83315 .60316 .83402 .59176 .83399 .59894 Mtetra
0 0 .302 r
.83399 .59894 .83402 .59176 .81807 .39584 .83498 .58898 Mtetra
.149 .053 .481 r
.83498 .58898 .81807 .39584 .81968 .39391 .82009 .40536 Mtetra
.965 .658 .393 r
.82009 .40536 .81968 .39391 .82207 .40039 .8393 .59456 Mtetra
.569 .354 .549 r
.8393 .59456 .82207 .40039 .84223 .59834 .8416 .59893 Mtetra
.713 .221 .072 r
.8416 .59893 .84223 .59834 .84445 .60176 .84368 .60068 Mtetra
.441 .635 .937 r
.84368 .60068 .84445 .60176 .8464 .60209 .84561 .60091 Mtetra
.674 .726 .889 r
.84561 .60091 .8464 .60209 .84824 .60137 .84746 .60027 Mtetra
.876 .792 .765 r
.84746 .60027 .84824 .60137 .84992 .59886 .84915 .59783 Mtetra
.981 .732 .48 r
.84915 .59783 .84992 .59886 .85069 .58684 .84978 .58435 Mtetra
.977 .677 .367 r
.84978 .58435 .85069 .58684 .83364 .3896 .83289 .38832 Mtetra
.902 .76 .694 r
.83289 .38832 .83364 .3896 .83511 .38616 .83437 .38498 Mtetra
.689 .718 .871 r
.83437 .38498 .83511 .38616 .83683 .38541 .8361 .38429 Mtetra
.56 .671 .913 r
.8361 .38429 .83683 .38541 .83862 .38524 .83789 .38417 Mtetra
.539 .674 .925 r
.83789 .38417 .83862 .38524 .84042 .38516 .83969 .38411 Mtetra
.695 .747 .891 r
.83969 .38411 .84042 .38516 .84217 .38458 .84143 .3834 Mtetra
.655 .707 .885 r
.84143 .3834 .84217 .38458 .84392 .38404 .84319 .38289 Mtetra
.517 .644 .912 r
.84319 .38289 .84392 .38404 .84568 .38361 .845 .38293 Mtetra
0 .182 .667 r
.845 .38293 .84568 .38361 .84747 .38333 .84696 .3844 Mtetra
.839 .427 .261 r
.84696 .3844 .84747 .38333 .8493 .38353 .84917 .38837 Mtetra
.972 .662 .356 r
.84917 .38837 .8493 .38353 .85128 .38519 .87076 .58304 Mtetra
.57 .355 .549 r
.87076 .58304 .85128 .38519 .87285 .57825 .87328 .58886 Mtetra
.608 .349 .498 r
.87328 .58886 .87285 .57825 .87603 .59037 .87544 .59099 Mtetra
.594 .075 0 r
.87544 .59099 .87603 .59037 .87822 .59291 .87748 .59195 Mtetra
.38 .631 .953 r
.87748 .59195 .87822 .59291 .8802 .59329 .87945 .59227 Mtetra
.629 .743 .93 r
.87945 .59227 .8802 .59329 .88208 .59271 .88134 .59183 Mtetra
.845 .836 .837 r
.88134 .59183 .88208 .59271 .88382 .59075 .88311 .59008 Mtetra
.987 .791 .556 r
.88311 .59008 .88382 .59075 .88501 .58358 .88433 .5833 Mtetra
.977 .675 .342 r
.88433 .5833 .88501 .58358 .86545 .38132 .86476 .38054 Mtetra
.971 .803 .616 r
.86476 .38054 .86545 .38132 .86678 .3767 .86608 .37571 Mtetra
.753 .781 .875 r
.86608 .37571 .86678 .3767 .8685 .37569 .86779 .37467 Mtetra
.625 .728 .921 r
.86779 .37467 .8685 .37569 .87029 .37531 .86958 .37428 Mtetra
.6 .714 .924 r
.86958 .37428 .87029 .37531 .87209 .37505 .87138 .37399 Mtetra
.772 .773 .854 r
.87138 .37399 .87209 .37505 .8738 .37397 .87308 .3728 Mtetra
.699 .728 .873 r
.87308 .3728 .8738 .37397 .87556 .3733 .87483 .37204 Mtetra
.467 .598 .9 r
.87483 .37204 .87556 .3733 .87743 .37363 .87669 .37231 Mtetra
.739 .344 0 r
.87669 .37231 .87743 .37363 .87987 .37909 .87911 .37758 Mtetra
.973 .662 .313 r
.87911 .37758 .87987 .37909 .90421 .58093 .90348 .57999 Mtetra
.732 .288 0 r
.90348 .57999 .90421 .58093 .90663 .58503 .90591 .58421 Mtetra
.514 .741 .977 r
.90591 .58421 .90663 .58503 .90858 .58494 .90786 .58407 Mtetra
.721 .815 .923 r
.90786 .58407 .90858 .58494 .91045 .58412 .90972 .58319 Mtetra
.757 .813 .897 r
.90972 .58319 .91045 .58412 .9123 .58307 .91157 .58211 Mtetra
.441 .665 .957 r
.91157 .58211 .9123 .58307 .91427 .58312 .91355 .58227 Mtetra
.567 .759 .968 r
.91355 .58227 .91427 .58312 .91619 .58274 .91549 .58199 Mtetra
.798 .866 .899 r
.91549 .58199 .91619 .58274 .918 .58134 .91731 .5807 Mtetra
.991 .795 .545 r
.91731 .5807 .918 .58134 .91916 .57428 .9185 .57387 Mtetra
.976 .67 .323 r
.9185 .57387 .91916 .57428 .89744 .37125 .89675 .37025 Mtetra
.965 .786 .611 r
.89675 .37025 .89744 .37125 .89873 .36637 .89802 .36524 Mtetra
.727 .746 .867 r
.89802 .36524 .89873 .36637 .90047 .36541 .89976 .36432 Mtetra
.58 .692 .918 r
.89976 .36432 .90047 .36541 .90229 .36514 .90159 .36411 Mtetra
.465 .647 .938 r
.90159 .36411 .90229 .36514 .90415 .36521 .90347 .36427 Mtetra
.634 .752 .933 r
.90347 .36427 .90415 .36521 .90595 .36475 .90527 .36382 Mtetra
.646 .758 .931 r
.90527 .36382 .90595 .36475 .90776 .36428 .90707 .36332 Mtetra
.657 .759 .925 r
.90707 .36332 .90776 .36428 .90955 .36377 .90887 .36278 Mtetra
.664 .753 .917 r
.90887 .36278 .90955 .36377 .91135 .36323 .91066 .36221 Mtetra
.675 .751 .909 r
.91066 .36221 .91135 .36323 .91314 .36265 .91245 .36159 Mtetra
.687 .749 .898 r
.91245 .36159 .91314 .36265 .91493 .36202 .91423 .36091 Mtetra
.753 .763 .861 r
.91423 .36091 .91493 .36202 .91669 .36118 .91597 .35983 Mtetra
.707 .704 .844 r
.91597 .35983 .91669 .36118 .91847 .36042 .91773 .35898 Mtetra
.636 .656 .853 r
.91773 .35898 .91847 .36042 .92026 .35983 .91955 .35854 Mtetra
.897 .487 .209 r
.33633 .54161 .33726 .5422 .33864 .5433 .3376 .54462 Mtetra
.934 .679 .528 r
.3376 .54462 .33864 .5433 .33992 .54611 .32866 .73266 Mtetra
.576 .361 .551 r
.32866 .73266 .33992 .54611 .33141 .72876 .32973 .74084 Mtetra
.584 .341 .514 r
.32973 .74084 .33141 .72876 .33238 .73901 .3312 .74187 Mtetra
.543 .22 .371 r
.3312 .74187 .33238 .73901 .33376 .74162 .33272 .742 Mtetra
0 0 0 r
.33272 .742 .33376 .74162 .33523 .74274 .33427 .74168 Mtetra
.526 .663 .923 r
.33427 .74168 .33523 .74274 .33676 .74274 .3358 .74167 Mtetra
.647 .704 .888 r
.3358 .74167 .33676 .74274 .33832 .74218 .33735 .74126 Mtetra
.764 .756 .846 r
.33735 .74126 .33832 .74218 .33991 .74105 .33894 .74017 Mtetra
.894 .741 .684 r
.33894 .74017 .33991 .74105 .34156 .73887 .34069 .73599 Mtetra
.935 .684 .533 r
.34069 .73599 .34156 .73887 .34329 .73497 .35194 .54675 Mtetra
.579 .367 .557 r
.35194 .54675 .34329 .73497 .35394 .55478 .35384 .53799 Mtetra
.602 .403 .585 r
.35384 .53799 .35394 .55478 .35611 .5406 .35538 .53613 Mtetra
.637 .484 .658 r
.35538 .53613 .35611 .5406 .35773 .53724 .35688 .53518 Mtetra
.649 .574 .758 r
.35688 .53518 .35773 .53724 .35927 .53531 .35836 .53463 Mtetra
.662 .785 .939 r
.35836 .53463 .35927 .53531 .36076 .53463 .35983 .53416 Mtetra
.598 .829 .987 r
.35983 .53416 .36076 .53463 .36223 .53436 .3613 .5338 Mtetra
.59 .799 .979 r
.3613 .5338 .36223 .53436 .36368 .53429 .36277 .53349 Mtetra
.735 .769 .88 r
.36277 .53349 .36368 .53429 .36517 .53367 .36427 .53269 Mtetra
.692 .723 .873 r
.36427 .53269 .36517 .53367 .36665 .53312 .36575 .53208 Mtetra
.554 .666 .912 r
.36575 .53208 .36665 .53312 .36812 .53288 .36721 .53201 Mtetra
.866 .423 .044 r
.36721 .53201 .36812 .53288 .36953 .53385 .36855 .53467 Mtetra
.938 .681 .52 r
.36855 .53467 .36953 .53385 .37087 .53644 .36137 .7219 Mtetra
.578 .362 .551 r
.36137 .7219 .37087 .53644 .36423 .71487 .36248 .73142 Mtetra
.584 .348 .524 r
.36248 .73142 .36423 .71487 .36511 .72941 .36397 .73274 Mtetra
.55 .24 .396 r
.36397 .73274 .36511 .72941 .36654 .73226 .36551 .7329 Mtetra
.183 0 0 r
.36551 .7329 .36654 .73226 .36803 .7335 .36707 .7326 Mtetra
.526 .701 .95 r
.36707 .7326 .36803 .7335 .36958 .73361 .36863 .73254 Mtetra
.634 .702 .895 r
.36863 .73254 .36958 .73361 .37116 .73309 .3702 .73217 Mtetra
.752 .758 .857 r
.3702 .73217 .37116 .73309 .37276 .73203 .3718 .73118 Mtetra
.891 .752 .701 r
.3718 .73118 .37276 .73203 .3744 .73 .37351 .72755 Mtetra
.939 .685 .526 r
.37351 .72755 .3744 .73 .3761 .72645 .38286 .54292 Mtetra
.589 .375 .558 r
.38286 .54292 .3761 .72645 .37812 .71536 .38492 .52877 Mtetra
.567 .357 .555 r
.38492 .52877 .37812 .71536 .38719 .53208 .38648 .52662 Mtetra
.624 .462 .642 r
.38648 .52662 .38719 .53208 .38882 .52836 .38799 .52567 Mtetra
.63 .529 .721 r
.38799 .52567 .38882 .52836 .39037 .5263 .38949 .52518 Mtetra
.657 .687 .867 r
.38949 .52518 .39037 .5263 .39188 .52541 .39098 .52472 Mtetra
.631 .777 .951 r
.39098 .52472 .39188 .52541 .39337 .52501 .39247 .52434 Mtetra
.61 .777 .961 r
.39247 .52434 .39337 .52501 .39486 .52482 .39396 .52402 Mtetra
.648 .753 .926 r
.39396 .52402 .39486 .52482 .39635 .52445 .39545 .5236 Mtetra
.663 .747 .913 r
.39545 .5236 .39635 .52445 .39784 .52398 .39695 .52313 Mtetra
.669 .746 .909 r
.39695 .52313 .39784 .52398 .39934 .5235 .39844 .52264 Mtetra
.671 .745 .906 r
.39844 .52264 .39934 .5235 .40084 .523 .39994 .52213 Mtetra
.675 .745 .903 r
.39994 .52213 .40084 .523 .40234 .52248 .40144 .52161 Mtetra
.68 .747 .902 r
.40144 .52161 .40234 .52248 .40384 .52191 .40294 .52107 Mtetra
.69 .755 .902 r
.40294 .52107 .40384 .52191 .40534 .52124 .40445 .52048 Mtetra
.694 .777 .916 r
.40445 .52048 .40534 .52124 .40685 .52053 .40595 .51989 Mtetra
.691 .805 .935 r
.40595 .51989 .40685 .52053 .40836 .51985 .40746 .5193 Mtetra
.691 .83 .95 r
.40746 .5193 .40836 .51985 .40987 .5191 .40896 .5187 Mtetra
.662 .866 .977 r
.40896 .5187 .40987 .5191 .41138 .51849 .41047 .51815 Mtetra
.6 .869 .993 r
.41047 .51815 .41138 .51849 .41288 .51818 .41197 .51771 Mtetra
.443 .775 .998 r
.41197 .51771 .41288 .51818 .41434 .51899 .41346 .51761 Mtetra
.515 .586 .864 r
.41346 .51761 .41434 .51899 .41576 .52121 .41495 .51774 Mtetra
.554 .452 .693 r
.41495 .51774 .41576 .52121 .41707 .5268 .41644 .51792 Mtetra
.577 .402 .609 r
.41644 .51792 .41707 .5268 .413 .70208 .41794 .51771 Mtetra
.564 .354 .554 r
.41794 .51771 .413 .70208 .41456 .70257 .41945 .5172 Mtetra
.41945 .5172 .41456 .70257 .42135 .53355 .42096 .5166 Mtetra
.584 .389 .583 r
.42096 .5166 .42135 .53355 .42305 .52704 .42248 .51569 Mtetra
.589 .403 .598 r
.42248 .51569 .42305 .52704 .42461 .52514 .424 .51495 Mtetra
.571 .393 .601 r
.424 .51495 .42461 .52514 .42606 .52682 .4255 .51487 Mtetra
.452 .297 .579 r
.4255 .51487 .42606 .52682 .42224 .70996 .4269 .51818 Mtetra
0 0 .336 r
.4269 .51818 .42224 .70996 .42368 .71508 .42286 .71032 Mtetra
0 0 .418 r
.42286 .71032 .42368 .71508 .42521 .71731 .42429 .71579 Mtetra
.151 .371 .824 r
.42429 .71579 .42521 .71731 .42679 .71788 .42585 .71686 Mtetra
.602 .705 .916 r
.42585 .71686 .42679 .71788 .42839 .71766 .42746 .7166 Mtetra
.695 .725 .873 r
.42746 .7166 .42839 .71766 .43 .71719 .42907 .71593 Mtetra
.672 .684 .853 r
.42907 .71593 .43 .71719 .43161 .71672 .43068 .71535 Mtetra
.649 .66 .847 r
.43068 .71535 .43161 .71672 .43322 .71628 .43229 .7149 Mtetra
.652 .659 .844 r
.43229 .7149 .43322 .71628 .43483 .71581 .43391 .71442 Mtetra
.652 .658 .843 r
.43391 .71442 .43483 .71581 .43644 .71535 .43552 .71394 Mtetra
.651 .655 .841 r
.43552 .71394 .43644 .71535 .43805 .7149 .43713 .71347 Mtetra
.654 .654 .838 r
.43713 .71347 .43805 .7149 .43967 .71441 .43875 .71298 Mtetra
.66 .656 .835 r
.43875 .71298 .43967 .71441 .44129 .71383 .44036 .71244 Mtetra
.666 .664 .839 r
.44036 .71244 .44129 .71383 .44291 .71319 .44198 .71188 Mtetra
.668 .677 .85 r
.44198 .71188 .44291 .71319 .44453 .71254 .4436 .71132 Mtetra
.664 .689 .864 r
.4436 .71132 .44453 .71254 .44615 .71198 .44522 .7108 Mtetra
.657 .694 .873 r
.44522 .7108 .44615 .71198 .44777 .71149 .44684 .71031 Mtetra
.654 .692 .873 r
.44684 .71031 .44777 .71149 .44938 .71104 .44846 .70984 Mtetra
.651 .688 .871 r
.44846 .70984 .44938 .71104 .451 .7106 .45008 .70938 Mtetra
.649 .684 .87 r
.45008 .70938 .451 .7106 .45263 .71015 .4517 .70893 Mtetra
.647 .682 .869 r
.4517 .70893 .45263 .71015 .45425 .70972 .45333 .70848 Mtetra
.635 .677 .873 r
.45333 .70848 .45425 .70972 .45587 .70942 .45495 .7081 Mtetra
.632 .662 .861 r
.45495 .7081 .45587 .70942 .45749 .70914 .45657 .70773 Mtetra
.648 .655 .843 r
.45657 .70773 .45749 .70914 .45911 .70858 .4582 .70727 Mtetra
.7 .688 .835 r
.4582 .70727 .45911 .70858 .46076 .70704 .45983 .7065 Mtetra
.782 .853 .904 r
.45983 .7065 .46076 .70704 .46243 .70398 .46147 .70542 Mtetra
.072 0 0 r
.46147 .70542 .46243 .70398 .46415 .6985 .46311 .70427 Mtetra
.492 .227 .44 r
.46311 .70427 .46415 .6985 .46596 .6869 .46474 .70341 Mtetra
.548 .317 .516 r
.46474 .70341 .46596 .6869 .46794 .66456 .46637 .70294 Mtetra
.558 .337 .537 r
.46637 .70294 .46794 .66456 .46916 .68863 .468 .7026 Mtetra
.548 .312 .51 r
.468 .7026 .46916 .68863 .47074 .6909 .46963 .70223 Mtetra
.542 .301 .5 r
.46963 .70223 .47074 .6909 .47236 .6906 .47126 .70179 Mtetra
.541 .3 .499 r
.47126 .70179 .47236 .6906 .47399 .69028 .4729 .70134 Mtetra
.4729 .70134 .47399 .69028 .47562 .68983 .47453 .70087 Mtetra
.54 .299 .499 r
.47453 .70087 .47562 .68983 .47725 .68923 .47617 .7004 Mtetra
.541 .3 .499 r
.47617 .7004 .47725 .68923 .47888 .68863 .4778 .69992 Mtetra
.541 .301 .5 r
.4778 .69992 .47888 .68863 .48051 .68815 .47944 .69946 Mtetra
.542 .301 .5 r
.47944 .69946 .48051 .68815 .48214 .68782 .48108 .69902 Mtetra
.48108 .69902 .48214 .68782 .48377 .6875 .48272 .69858 Mtetra
.55 .307 .501 r
.48272 .69858 .48377 .6875 .48539 .68868 .48435 .69841 Mtetra
.552 .305 .494 r
.48435 .69841 .48539 .68868 .48701 .68997 .48599 .69835 Mtetra
.525 .275 .479 r
.48599 .69835 .48701 .68997 .48865 .68885 .48764 .69769 Mtetra
.413 .183 .454 r
.48764 .69769 .48865 .68885 .49209 .50538 .4893 .69469 Mtetra
0 0 .355 r
.4893 .69469 .49209 .50538 .49372 .49674 .49279 .50289 Mtetra
0 0 0 r
.49279 .50289 .49372 .49674 .4953 .49333 .49443 .49339 Mtetra
.944 .912 .756 r
.49443 .49339 .4953 .49333 .49686 .49163 .496 .49084 Mtetra
.714 .78 .904 r
.496 .49084 .49686 .49163 .49841 .49102 .49756 .49013 Mtetra
.597 .725 .934 r
.49756 .49013 .49841 .49102 .49997 .49069 .49911 .48988 Mtetra
.579 .735 .95 r
.49911 .48988 .49997 .49069 .50152 .49038 .50066 .48966 Mtetra
.647 .782 .946 r
.50066 .48966 .50152 .49038 .50307 .48991 .50221 .48921 Mtetra
.641 .785 .951 r
.50221 .48921 .50307 .48991 .50463 .48947 .50377 .48878 Mtetra
.634 .786 .955 r
.50377 .48878 .50463 .48947 .50618 .48909 .50532 .48837 Mtetra
.631 .778 .952 r
.50532 .48837 .50618 .48909 .50774 .48877 .50688 .48797 Mtetra
.637 .758 .936 r
.50688 .48797 .50774 .48877 .50929 .48846 .50844 .48757 Mtetra
.645 .739 .918 r
.50844 .48757 .50929 .48846 .51085 .4881 .51 .48715 Mtetra
.654 .73 .905 r
.51 .48715 .51085 .4881 .51241 .48764 .51156 .4867 Mtetra
.661 .733 .903 r
.51156 .4867 .51241 .48764 .51397 .48712 .51312 .48622 Mtetra
.67 .744 .906 r
.51312 .48622 .51397 .48712 .51553 .48652 .51468 .48569 Mtetra
.681 .765 .915 r
.51468 .48569 .51553 .48652 .5171 .48584 .51624 .48513 Mtetra
.683 .795 .934 r
.51624 .48513 .5171 .48584 .51866 .48515 .51781 .48455 Mtetra
.683 .824 .951 r
.51781 .48455 .51866 .48515 .52022 .48444 .51937 .48396 Mtetra
.676 .857 .968 r
.51937 .48396 .52022 .48444 .52179 .48372 .52094 .48336 Mtetra
.624 .879 .989 r
.52094 .48336 .52179 .48372 .52335 .48325 .5225 .48284 Mtetra
.528 .835 .999 r
.5225 .48284 .52335 .48325 .52492 .48345 .52407 .48254 Mtetra
.486 .677 .949 r
.52407 .48254 .52492 .48345 .52649 .48509 .52564 .48259 Mtetra
.55 .495 .747 r
.52564 .48259 .52649 .48509 .52806 .48871 .52721 .48274 Mtetra
.58 .426 .637 r
.52721 .48274 .52806 .48871 .52965 .49963 .52878 .48256 Mtetra
.583 .388 .583 r
.52878 .48256 .52965 .49963 .53123 .49807 .53035 .48168 Mtetra
.576 .383 .584 r
.53035 .48168 .53123 .49807 .5328 .49544 .53192 .48122 Mtetra
.538 .359 .586 r
.53192 .48122 .5328 .49544 .53489 .67374 .5335 .48239 Mtetra
0 0 .394 r
.5335 .48239 .53489 .67374 .53659 .68216 .53566 .67027 Mtetra
0 0 .428 r
.53566 .67027 .53659 .68216 .53827 .68508 .53737 .68282 Mtetra
0 .124 .661 r
.53737 .68282 .53827 .68508 .53995 .68628 .53905 .68517 Mtetra
.537 .666 .92 r
.53905 .68517 .53995 .68628 .54163 .6862 .54073 .68513 Mtetra
.67 .726 .891 r
.54073 .68513 .54163 .6862 .5433 .68579 .5424 .68457 Mtetra
.694 .706 .857 r
.5424 .68457 .5433 .68579 .54498 .68526 .54408 .68386 Mtetra
.645 .66 .85 r
.54408 .68386 .54498 .68526 .54666 .68482 .54576 .6834 Mtetra
.648 .659 .846 r
.54576 .6834 .54666 .68482 .54834 .68435 .54744 .68293 Mtetra
.649 .658 .845 r
.54744 .68293 .54834 .68435 .55002 .68387 .54912 .68245 Mtetra
.647 .657 .846 r
.54912 .68245 .55002 .68387 .5517 .68341 .5508 .68198 Mtetra
.5508 .68198 .5517 .68341 .55338 .68295 .55248 .68152 Mtetra
.646 .656 .845 r
.55248 .68152 .55338 .68295 .55506 .68248 .55417 .68105 Mtetra
.55417 .68105 .55506 .68248 .55675 .68202 .55585 .68058 Mtetra
.55585 .68058 .55675 .68202 .55843 .68155 .55754 .68012 Mtetra
.55754 .68012 .55843 .68155 .56012 .68109 .55922 .67965 Mtetra
.647 .656 .845 r
.55922 .67965 .56012 .68109 .56181 .68062 .56091 .67918 Mtetra
.56091 .67918 .56181 .68062 .56349 .68015 .5626 .67871 Mtetra
.5626 .67871 .56349 .68015 .56518 .67968 .56429 .67824 Mtetra
.56429 .67824 .56518 .67968 .56687 .67921 .56598 .67777 Mtetra
.56598 .67777 .56687 .67921 .56856 .67874 .56767 .6773 Mtetra
.56767 .6773 .56856 .67874 .57026 .67827 .56937 .67683 Mtetra
.56937 .67683 .57026 .67827 .57195 .6778 .57106 .67636 Mtetra
.57106 .67636 .57195 .6778 .57364 .67733 .57275 .67589 Mtetra
.57275 .67589 .57364 .67733 .57534 .67686 .57445 .67542 Mtetra
.57445 .67542 .57534 .67686 .57704 .67639 .57615 .67495 Mtetra
.57615 .67495 .57704 .67639 .57873 .67592 .57784 .67447 Mtetra
.57784 .67447 .57873 .67592 .58043 .67544 .57954 .674 Mtetra
.647 .657 .845 r
.57954 .674 .58043 .67544 .58213 .67497 .58124 .67353 Mtetra
.647 .657 .846 r
.58124 .67353 .58213 .67497 .58383 .67449 .58295 .67305 Mtetra
.58295 .67305 .58383 .67449 .58554 .67402 .58465 .67258 Mtetra
.644 .656 .847 r
.58465 .67258 .58554 .67402 .58724 .67356 .58635 .67212 Mtetra
.646 .657 .847 r
.58635 .67212 .58724 .67356 .58894 .67308 .58806 .67165 Mtetra
.644 .658 .848 r
.58806 .67165 .58894 .67308 .59065 .67258 .58976 .6712 Mtetra
.589 .64 .869 r
.58976 .6712 .59065 .67258 .59235 .67218 .59147 .67101 Mtetra
.659 .706 .882 r
.59147 .67101 .59235 .67218 .59406 .67156 .59318 .67049 Mtetra
.777 .757 .835 r
.59318 .67049 .59406 .67156 .59575 .67048 .59487 .66922 Mtetra
.908 .736 .657 r
.59487 .66922 .59575 .67048 .59741 .66772 .59649 .66441 Mtetra
.961 .687 .469 r
.59649 .66441 .59741 .66772 .59903 .66296 .5941 .46903 Mtetra
.576 .363 .555 r
.5941 .46903 .59903 .66296 .59676 .47943 .59557 .46165 Mtetra
.585 .389 .582 r
.59557 .46165 .59676 .47943 .5983 .47542 .59716 .46057 Mtetra
.574 .385 .587 r
.59716 .46057 .5983 .47542 .6 .47886 .59878 .46022 Mtetra
.568 .375 .58 r
.59878 .46022 .6 .47886 .60152 .47407 .6004 .46009 Mtetra
.593 .4 .59 r
.6004 .46009 .60152 .47407 .6029 .46343 .602 .45892 Mtetra
.644 .49 .659 r
.602 .45892 .6029 .46343 .60444 .45969 .60359 .45779 Mtetra
.7 .621 .765 r
.60359 .45779 .60444 .45969 .60601 .45746 .6052 .45681 Mtetra
.658 .812 .958 r
.6052 .45681 .60601 .45746 .60762 .45682 .60681 .45629 Mtetra
.602 .831 .987 r
.60681 .45629 .60762 .45682 .60924 .45653 .60843 .45588 Mtetra
.605 .798 .974 r
.60843 .45588 .60924 .45653 .61086 .45641 .61005 .45552 Mtetra
.664 .752 .916 r
.61005 .45552 .61086 .45641 .61248 .45595 .61167 .455 Mtetra
.671 .742 .904 r
.61167 .455 .61248 .45595 .6141 .45543 .61328 .45446 Mtetra
.675 .737 .898 r
.61328 .45446 .6141 .45543 .61572 .45486 .6149 .45389 Mtetra
.75 .761 .861 r
.6149 .45389 .61572 .45486 .61732 .45391 .61651 .45291 Mtetra
.697 .739 .884 r
.61651 .45291 .61732 .45391 .61894 .45316 .61813 .45224 Mtetra
.537 .697 .942 r
.61813 .45224 .61894 .45316 .62056 .45281 .61976 .45215 Mtetra
.832 .37 0 r
.61976 .45215 .62056 .45281 .62223 .4539 .62149 .45517 Mtetra
.964 .681 .446 r
.62149 .45517 .62223 .4539 .62396 .45678 .62893 .64873 Mtetra
.575 .359 .55 r
.62893 .64873 .62396 .45678 .63139 .64515 .63092 .65709 Mtetra
.583 .336 .508 r
.63092 .65709 .63139 .64515 .63344 .65524 .6327 .65817 Mtetra
.538 .212 .363 r
.6327 .65817 .63344 .65524 .63527 .65788 .63445 .65829 Mtetra
.059 0 0 r
.63445 .65829 .63527 .65788 .63705 .65904 .63619 .65795 Mtetra
.519 .667 .93 r
.63619 .65795 .63705 .65904 .63881 .65918 .63794 .65796 Mtetra
.631 .688 .885 r
.63794 .65796 .63881 .65918 .64055 .65874 .63968 .65756 Mtetra
.744 .736 .844 r
.63968 .65756 .64055 .65874 .64227 .65772 .6414 .65651 Mtetra
.902 .748 .681 r
.6414 .65651 .64227 .65772 .64394 .65553 .64302 .65253 Mtetra
.966 .687 .454 r
.64302 .65253 .64394 .65553 .64556 .65164 .63817 .46102 Mtetra
.585 .37 .556 r
.63817 .46102 .64556 .65164 .64671 .63429 .63938 .44831 Mtetra
.567 .356 .555 r
.63938 .44831 .64671 .63429 .6419 .45087 .64096 .44617 Mtetra
.638 .483 .656 r
.64096 .44617 .6419 .45087 .64342 .44723 .64257 .44509 Mtetra
.654 .58 .759 r
.64257 .44509 .64342 .44723 .645 .44515 .6442 .44444 Mtetra
.675 .805 .944 r
.6442 .44444 .645 .44515 .64662 .44425 .64584 .44386 Mtetra
.591 .871 .994 r
.64584 .44386 .64662 .44425 .64826 .44377 .64748 .44339 Mtetra
.554 .862 .997 r
.64748 .44339 .64826 .44377 .64991 .44347 .64912 .44299 Mtetra
.622 .854 .987 r
.64912 .44299 .64991 .44347 .65155 .443 .65076 .4425 Mtetra
.633 .854 .984 r
.65076 .4425 .65155 .443 .65319 .44248 .65241 .44199 Mtetra
.638 .856 .983 r
.65241 .44199 .65319 .44248 .65483 .44196 .65405 .44146 Mtetra
.672 .863 .972 r
.65405 .44146 .65483 .44196 .65646 .44123 .65569 .44084 Mtetra
.642 .886 .985 r
.65569 .44084 .65646 .44123 .6581 .44062 .65733 .44025 Mtetra
.586 .875 .994 r
.65733 .44025 .6581 .44062 .65975 .44032 .65897 .43977 Mtetra
.609 .834 .986 r
.65897 .43977 .65975 .44032 .66145 .44105 .66062 .43934 Mtetra
.579 .582 .82 r
.66062 .43934 .66145 .44105 .66321 .44309 .66229 .43925 Mtetra
.514 .42 .687 r
.66229 .43925 .66321 .44309 .66518 .45016 .66399 .43989 Mtetra
.343 .231 .579 r
.66399 .43989 .66518 .45016 .67517 .64189 .66589 .44534 Mtetra
.043 0 .438 r
.66589 .44534 .67517 .64189 .67712 .64565 .67614 .64158 Mtetra
.028 .093 .596 r
.67614 .64158 .67712 .64565 .67897 .64722 .6781 .64574 Mtetra
.384 .522 .872 r
.6781 .64574 .67897 .64722 .68076 .64752 .67991 .64634 Mtetra
.637 .701 .892 r
.67991 .64634 .68076 .64752 .68253 .64714 .68167 .64591 Mtetra
.72 .723 .852 r
.68167 .64591 .68253 .64714 .68427 .64621 .68342 .645 Mtetra
.687 .715 .87 r
.68342 .645 .68427 .64621 .68597 .6444 .68517 .64431 Mtetra
.663 .961 .936 r
.68517 .64431 .68597 .6444 .68762 .64137 .68692 .64338 Mtetra
.15 0 .132 r
.68692 .64338 .68762 .64137 .6891 .63489 .68863 .64174 Mtetra
.167 0 .371 r
.68863 .64174 .6891 .63489 .68156 .44074 .69015 .63612 Mtetra
.041 0 .431 r
.69015 .63612 .68156 .44074 .683 .43559 .68238 .43825 Mtetra
0 0 0 r
.68238 .43825 .683 .43559 .68456 .43307 .6838 .43272 Mtetra
.862 .919 .866 r
.6838 .43272 .68456 .43307 .68619 .43207 .68541 .43117 Mtetra
.652 .751 .922 r
.68541 .43117 .68619 .43207 .68786 .43172 .68707 .43069 Mtetra
.549 .679 .924 r
.68707 .43069 .68786 .43172 .68955 .43163 .68876 .4306 Mtetra
.617 .71 .912 r
.68876 .4306 .68955 .43163 .69122 .43129 .69043 .43027 Mtetra
.653 .726 .903 r
.69043 .43027 .69122 .43129 .69288 .43079 .6921 .42979 Mtetra
.661 .735 .905 r
.6921 .42979 .69288 .43079 .69455 .43021 .69377 .42928 Mtetra
.694 .759 .902 r
.69377 .42928 .69455 .43021 .69619 .42933 .69542 .42861 Mtetra
.7 .814 .936 r
.69542 .42861 .69619 .42933 .69784 .42848 .69708 .42792 Mtetra
.661 .849 .972 r
.69708 .42792 .69784 .42848 .69951 .42795 .69875 .42734 Mtetra
.638 .827 .973 r
.69875 .42734 .69951 .42795 .70123 .42843 .70042 .42685 Mtetra
.594 .606 .834 r
.70042 .42685 .70123 .42843 .70303 .43025 .70211 .42666 Mtetra
.526 .436 .697 r
.70211 .42666 .70303 .43025 .70505 .43597 .70384 .42715 Mtetra
.382 .267 .597 r
.70384 .42715 .70505 .43597 .71754 .62919 .70577 .43128 Mtetra
.066 0 .45 r
.70577 .43128 .71754 .62919 .71959 .63343 .71854 .62854 Mtetra
.061 .096 .584 r
.71854 .62854 .71959 .63343 .7215 .63517 .72063 .63346 Mtetra
.342 .464 .839 r
.72063 .63346 .7215 .63517 .72333 .63544 .7225 .63434 Mtetra
.63 .717 .909 r
.7225 .63434 .72333 .63544 .72512 .635 .72429 .63393 Mtetra
.714 .753 .883 r
.72429 .63393 .72512 .635 .7269 .63429 .72606 .6331 Mtetra
.613 .691 .899 r
.72606 .6331 .7269 .63429 .7287 .63403 .72786 .63277 Mtetra
.597 .671 .892 r
.72786 .63277 .7287 .63403 .73051 .6338 .72967 .63253 Mtetra
.709 .715 .853 r
.72967 .63253 .73051 .6338 .73228 .63297 .73144 .63167 Mtetra
.896 .752 .695 r
.73144 .63167 .73228 .63297 .73389 .62943 .73305 .6281 Mtetra
.974 .686 .416 r
.73305 .6281 .73389 .62943 .72371 .43288 .72292 .43157 Mtetra
.96 .723 .535 r
.72292 .43157 .72371 .43288 .72472 .42132 .72396 .42055 Mtetra
.887 .822 .777 r
.72396 .42055 .72472 .42132 .7263 .41913 .72554 .41833 Mtetra
.669 .786 .936 r
.72554 .41833 .7263 .41913 .72799 .41864 .72722 .41776 Mtetra
.524 .707 .955 r
.72722 .41776 .72799 .41864 .72971 .41867 .72894 .41768 Mtetra
.59 .712 .928 r
.72894 .41768 .72971 .41867 .73142 .41847 .73064 .41744 Mtetra
.654 .726 .902 r
.73064 .41744 .73142 .41847 .7331 .41797 .73233 .41695 Mtetra
.658 .73 .903 r
.73233 .41695 .7331 .41797 .73479 .41742 .73402 .41644 Mtetra
.73 .764 .88 r
.73402 .41644 .73479 .41742 .73645 .41645 .73569 .41556 Mtetra
.736 .788 .894 r
.73569 .41556 .73645 .41645 .73811 .41546 .73736 .41468 Mtetra
.595 .767 .961 r
.73736 .41468 .73811 .41546 .73981 .41505 .73907 .41436 Mtetra
.61 .104 0 r
.73907 .41436 .73981 .41505 .74168 .41709 .74094 .41648 Mtetra
.974 .678 .391 r
.74094 .41648 .74168 .41709 .75665 .61346 .75587 .61289 Mtetra
.943 .579 .241 r
.75587 .61289 .75665 .61346 .75919 .6237 .75837 .62255 Mtetra
0 .161 .692 r
.75837 .62255 .75919 .6237 .76116 .62557 .76034 .62438 Mtetra
.543 .66 .913 r
.76034 .62438 .76116 .62557 .763 .62553 .76218 .62433 Mtetra
.736 .739 .854 r
.76218 .62433 .763 .62553 .76478 .62452 .76396 .62331 Mtetra
.887 .766 .723 r
.76396 .62331 .76478 .62452 .76642 .62155 .7656 .62028 Mtetra
.965 .729 .531 r
.7656 .62028 .76642 .62155 .76755 .61132 .76666 .60914 Mtetra
.975 .684 .404 r
.76666 .60914 .76755 .61132 .7553 .41337 .75454 .41231 Mtetra
.899 .776 .717 r
.75454 .41231 .7553 .41337 .75682 .41031 .75607 .40934 Mtetra
.713 .762 .891 r
.75607 .40934 .75682 .41031 .75851 .40952 .75775 .40856 Mtetra
.584 .715 .933 r
.75775 .40856 .75851 .40952 .76023 .40929 .75948 .40833 Mtetra
.673 .751 .909 r
.75948 .40833 .76023 .40929 .76193 .40871 .76118 .40775 Mtetra
.736 .773 .883 r
.76118 .40775 .76193 .40871 .76361 .40779 .76286 .40684 Mtetra
.619 .735 .929 r
.76286 .40684 .76361 .40779 .76533 .40742 .76458 .40648 Mtetra
0 .119 .645 r
.76458 .40648 .76533 .40742 .76721 .40925 .76646 .40823 Mtetra
.975 .676 .377 r
.76646 .40823 .76721 .40925 .78371 .60449 .78278 .6017 Mtetra
.896 .566 .075 r
.78278 .6017 .78371 .60449 .78641 .6156 .7856 .61431 Mtetra
0 .207 .733 r
.7856 .61431 .78641 .6156 .78841 .61732 .7876 .61614 Mtetra
.623 .701 .901 r
.7876 .61614 .78841 .61732 .79024 .61685 .78944 .61576 Mtetra
.729 .76 .878 r
.78944 .61576 .79024 .61685 .79203 .61582 .79124 .61483 Mtetra
.663 .756 .919 r
.79124 .61483 .79203 .61582 .79386 .61524 .79307 .61425 Mtetra
.529 .698 .947 r
.79307 .61425 .79386 .61524 .79573 .61527 .79493 .61417 Mtetra
.668 .736 .901 r
.79493 .61417 .79573 .61527 .79757 .61479 .79676 .61357 Mtetra
.868 .769 .751 r
.79676 .61357 .79757 .61479 .79925 .61239 .79843 .61103 Mtetra
.967 .728 .523 r
.79843 .61103 .79925 .61239 .80033 .60243 .7994 .59966 Mtetra
.976 .681 .391 r
.7994 .59966 .80033 .60243 .78611 .40369 .78535 .40251 Mtetra
.9 .765 .704 r
.78535 .40251 .78611 .40369 .7876 .40036 .78686 .39933 Mtetra
.712 .753 .884 r
.78686 .39933 .7876 .40036 .7893 .39956 .78856 .39854 Mtetra
.588 .707 .926 r
.78856 .39854 .7893 .39956 .79105 .39931 .7903 .3983 Mtetra
.64 .731 .914 r
.7903 .3983 .79105 .39931 .79278 .39886 .79204 .39786 Mtetra
.736 .768 .879 r
.79204 .39786 .79278 .39886 .79447 .39792 .79373 .39694 Mtetra
.637 .737 .921 r
.79373 .39694 .79447 .39792 .7962 .39748 .79546 .39651 Mtetra
0 .321 .806 r
.79546 .39651 .7962 .39748 .79809 .39881 .79734 .39778 Mtetra
.945 .59 .205 r
.79734 .39778 .79809 .39881 .80119 .41439 .80013 .40967 Mtetra
.977 .675 .346 r
.80013 .40967 .80119 .41439 .81941 .60564 .81859 .60427 Mtetra
0 .091 .645 r
.81859 .60427 .81941 .60564 .82149 .60787 .82069 .60663 Mtetra
.619 .69 .895 r
.82069 .60663 .82149 .60787 .82335 .60741 .82255 .60626 Mtetra
.736 .753 .866 r
.82255 .60626 .82335 .60741 .82515 .60632 .82436 .60526 Mtetra
.742 .772 .877 r
.82436 .60526 .82515 .60632 .82696 .60535 .82617 .60424 Mtetra
.648 .728 .907 r
.82617 .60424 .82696 .60535 .82883 .60509 .82803 .60373 Mtetra
.662 .69 .866 r
.82803 .60373 .82883 .60509 .83069 .60457 .82987 .60315 Mtetra
.713 .7 .837 r
.82987 .60315 .83069 .60457 .83245 .60303 .83169 .60221 Mtetra
.826 .84 .859 r
.83169 .60221 .83245 .60303 .83399 .59894 .83346 .60068 Mtetra
.138 0 .105 r
.83346 .60068 .83399 .59894 .83498 .58898 .83522 .59907 Mtetra
.527 .285 .491 r
.83522 .59907 .83498 .58898 .82009 .40536 .83704 .5982 Mtetra
.563 .349 .549 r
.83704 .5982 .82009 .40536 .8393 .59456 .83899 .59866 Mtetra
.573 .268 .413 r
.83899 .59866 .8393 .59456 .8416 .59893 .84095 .59919 Mtetra
.366 0 0 r
.84095 .59919 .8416 .59893 .84368 .60068 .8429 .59958 Mtetra
.482 .653 .935 r
.8429 .59958 .84368 .60068 .84561 .60091 .84482 .59969 Mtetra
.656 .712 .889 r
.84482 .59969 .84561 .60091 .84746 .60027 .84668 .59914 Mtetra
.862 .788 .777 r
.84668 .59914 .84746 .60027 .84915 .59783 .84839 .5969 Mtetra
.982 .741 .494 r
.84839 .5969 .84915 .59783 .84978 .58435 .84919 .5852 Mtetra
.978 .68 .356 r
.84919 .5852 .84978 .58435 .83289 .38832 .8322 .3877 Mtetra
.957 .841 .687 r
.8322 .3877 .83289 .38832 .83437 .38498 .83367 .38423 Mtetra
.714 .824 .933 r
.83367 .38423 .83437 .38498 .8361 .38429 .83539 .38344 Mtetra
.559 .74 .961 r
.83539 .38344 .8361 .38429 .83789 .38417 .83718 .38324 Mtetra
.563 .717 .945 r
.83718 .38324 .83789 .38417 .83969 .38411 .83897 .38305 Mtetra
.72 .755 .88 r
.83897 .38305 .83969 .38411 .84143 .3834 .84069 .38221 Mtetra
.65 .7 .883 r
.84069 .38221 .84143 .3834 .84319 .38289 .84245 .38172 Mtetra
.354 .55 .906 r
.84245 .38172 .84319 .38289 .845 .38293 .84431 .38227 Mtetra
.839 .402 0 r
.84431 .38227 .845 .38293 .84696 .3844 .84659 .38693 Mtetra
.973 .665 .348 r
.84659 .38693 .84696 .3844 .84917 .38837 .86851 .58636 Mtetra
.568 .353 .549 r
.86851 .58636 .84917 .38837 .87076 .58304 .8709 .5909 Mtetra
.57 .307 .478 r
.8709 .5909 .87076 .58304 .87328 .58886 .8729 .59144 Mtetra
.499 .158 .32 r
.8729 .59144 .87328 .58886 .87544 .59099 .87482 .59128 Mtetra
.018 0 0 r
.87482 .59128 .87544 .59099 .87748 .59195 .87672 .59095 Mtetra
.483 .676 .95 r
.87672 .59095 .87748 .59195 .87945 .59227 .87867 .59101 Mtetra
.643 .701 .888 r
.87867 .59101 .87945 .59227 .88134 .59183 .88056 .59052 Mtetra
.809 .755 .803 r
.88056 .59052 .88134 .59183 .88311 .59008 .88232 .58879 Mtetra
.964 .754 .571 r
.88232 .58879 .88311 .59008 .88433 .5833 .88352 .58169 Mtetra
.977 .674 .347 r
.88352 .58169 .88433 .5833 .86476 .38054 .86403 .37937 Mtetra
.945 .77 .634 r
.86403 .37937 .86476 .38054 .86608 .37571 .86537 .37471 Mtetra
.756 .782 .874 r
.86537 .37471 .86608 .37571 .86779 .37467 .86708 .37366 Mtetra
.63 .731 .92 r
.86708 .37366 .86779 .37467 .86958 .37428 .86887 .37324 Mtetra
.599 .712 .923 r
.86887 .37324 .86958 .37428 .87138 .37399 .87067 .37295 Mtetra
.76 .777 .867 r
.87067 .37295 .87138 .37399 .87308 .3728 .87238 .37187 Mtetra
.689 .774 .916 r
.87238 .37187 .87308 .3728 .87483 .37204 .87414 .37119 Mtetra
.362 .633 .957 r
.87414 .37119 .87483 .37204 .87669 .37231 .87601 .3715 Mtetra
.826 .399 0 r
.87601 .3715 .87669 .37231 .87911 .37758 .87842 .37663 Mtetra
.973 .662 .316 r
.87842 .37663 .87911 .37758 .90348 .57999 .90269 .57855 Mtetra
0 0 .367 r
.90269 .57855 .90348 .57999 .90591 .58421 .90513 .58286 Mtetra
.542 .637 .894 r
.90513 .58286 .90591 .58421 .90786 .58407 .90709 .58284 Mtetra
.691 .729 .879 r
.90709 .58284 .90786 .58407 .90972 .58319 .90897 .58209 Mtetra
.733 .768 .881 r
.90897 .58209 .90972 .58319 .91157 .58211 .91083 .58111 Mtetra
.478 .676 .952 r
.91083 .58111 .91157 .58211 .91355 .58227 .91281 .58118 Mtetra
.611 .722 .925 r
.91281 .58118 .91355 .58227 .91549 .58199 .91473 .58081 Mtetra
.781 .771 .844 r
.91473 .58081 .91549 .58199 .91731 .5807 .91655 .57946 Mtetra
.967 .763 .575 r
.91655 .57946 .91731 .5807 .9185 .57387 .91776 .57282 Mtetra
.976 .67 .326 r
.91776 .57282 .9185 .57387 .89675 .37025 .89611 .36969 Mtetra
.988 .821 .587 r
.89611 .36969 .89675 .37025 .89802 .36524 .89736 .36457 Mtetra
.756 .866 .929 r
.89736 .36457 .89802 .36524 .89976 .36432 .8991 .36357 Mtetra
.57 .776 .976 r
.8991 .36357 .89976 .36432 .90159 .36411 .90092 .36328 Mtetra
.461 .696 .969 r
.90092 .36328 .90159 .36411 .90347 .36427 .90279 .36333 Mtetra
.643 .758 .932 r
.90279 .36333 .90347 .36427 .90527 .36382 .90459 .36285 Mtetra
.652 .753 .924 r
.90459 .36285 .90527 .36382 .90707 .36332 .90639 .36233 Mtetra
.662 .752 .917 r
.90639 .36233 .90707 .36332 .90887 .36278 .90818 .36177 Mtetra
.676 .754 .91 r
.90818 .36177 .90887 .36278 .91066 .36221 .90997 .36114 Mtetra
.682 .745 .899 r
.90997 .36114 .91066 .36221 .91245 .36159 .91175 .36049 Mtetra
.687 .74 .891 r
.91175 .36049 .91245 .36159 .91423 .36091 .91354 .3598 Mtetra
.758 .766 .859 r
.91354 .3598 .91423 .36091 .91597 .35983 .91527 .35869 Mtetra
.702 .738 .879 r
.91527 .35869 .91597 .35983 .91773 .35898 .91704 .35792 Mtetra
.562 .692 .928 r
.91704 .35792 .91773 .35898 .91955 .35854 .91889 .35777 Mtetra
.885 .595 .492 r
.33528 .54313 .33633 .54161 .3376 .54462 .33615 .55326 Mtetra
.923 .668 .534 r
.33615 .55326 .3376 .54462 .32866 .73266 .32729 .73903 Mtetra
.674 .403 .502 r
.32729 .73903 .32866 .73266 .32973 .74084 .32864 .74215 Mtetra
.478 .062 .17 r
.32864 .74215 .32973 .74084 .3312 .74187 .33017 .74219 Mtetra
.316 .797 .732 r
.33017 .74219 .3312 .74187 .33272 .742 .33173 .7416 Mtetra
.756 .874 .933 r
.33173 .7416 .33272 .742 .33427 .74168 .33331 .7407 Mtetra
.472 .657 .941 r
.33331 .7407 .33427 .74168 .3358 .74167 .33483 .74079 Mtetra
.587 .726 .939 r
.33483 .74079 .3358 .74167 .33735 .74126 .33638 .74056 Mtetra
.758 .803 .889 r
.33638 .74056 .33735 .74126 .33894 .74017 .33796 .73961 Mtetra
.921 .753 .657 r
.33796 .73961 .33894 .74017 .34069 .73599 .33977 .73425 Mtetra
.937 .685 .532 r
.33977 .73425 .34069 .73599 .35194 .54675 .35129 .54086 Mtetra
.759 .555 .621 r
.35129 .54086 .35194 .54675 .35384 .53799 .35302 .53523 Mtetra
.681 .555 .705 r
.35302 .53523 .35384 .53799 .35538 .53613 .35453 .53412 Mtetra
.615 .56 .77 r
.35453 .53412 .35538 .53613 .35688 .53518 .35599 .53383 Mtetra
.523 .593 .866 r
.35599 .53383 .35688 .53518 .35836 .53463 .35744 .53392 Mtetra
.628 .771 .949 r
.35744 .53392 .35836 .53463 .35983 .53416 .35891 .53356 Mtetra
.647 .806 .959 r
.35891 .53356 .35983 .53416 .3613 .5338 .36039 .53312 Mtetra
.663 .787 .94 r
.36039 .53312 .3613 .5338 .36277 .53349 .36186 .53264 Mtetra
.76 .761 .854 r
.36186 .53264 .36277 .53349 .36427 .53269 .36337 .53166 Mtetra
.71 .718 .856 r
.36337 .53166 .36427 .53269 .36575 .53208 .36486 .53094 Mtetra
.562 .648 .893 r
.36486 .53094 .36575 .53208 .36721 .53201 .36632 .53087 Mtetra
.913 .513 .139 r
.36632 .53087 .36721 .53201 .36855 .53467 .36761 .53446 Mtetra
.94 .682 .519 r
.36761 .53446 .36855 .53467 .36137 .7219 .36013 .72704 Mtetra
.754 .473 .505 r
.36013 .72704 .36137 .7219 .36248 .73142 .36141 .73275 Mtetra
.578 .175 .241 r
.36141 .73275 .36248 .73142 .36397 .73274 .36294 .73325 Mtetra
0 0 0 r
.36294 .73325 .36397 .73274 .36551 .7329 .36452 .73269 Mtetra
.765 .925 .94 r
.36452 .73269 .36551 .7329 .36707 .7326 .36611 .73171 Mtetra
.522 .701 .952 r
.36611 .73171 .36707 .7326 .36863 .73254 .36767 .73165 Mtetra
.571 .72 .944 r
.36767 .73165 .36863 .73254 .3702 .73217 .36923 .73147 Mtetra
.74 .804 .903 r
.36923 .73147 .3702 .73217 .3718 .73118 .37083 .73062 Mtetra
.919 .767 .677 r
.37083 .73062 .3718 .73118 .37351 .72755 .37258 .72615 Mtetra
.941 .687 .525 r
.37258 .72615 .37351 .72755 .38286 .54292 .38235 .53267 Mtetra
.72 .508 .602 r
.38235 .53267 .38286 .54292 .38492 .52877 .38411 .52584 Mtetra
.698 .559 .694 r
.38411 .52584 .38492 .52877 .38648 .52662 .38564 .5244 Mtetra
.617 .548 .754 r
.38564 .5244 .38648 .52662 .38799 .52567 .38713 .52408 Mtetra
.533 .562 .83 r
.38713 .52408 .38799 .52567 .38949 .52518 .38859 .52419 Mtetra
.6 .696 .91 r
.38859 .52419 .38949 .52518 .39098 .52472 .39008 .52396 Mtetra
.637 .76 .937 r
.39008 .52396 .39098 .52472 .39247 .52434 .39157 .52357 Mtetra
.65 .763 .931 r
.39157 .52357 .39247 .52434 .39396 .52402 .39306 .52315 Mtetra
.676 .744 .902 r
.39306 .52315 .39396 .52402 .39545 .5236 .39456 .52262 Mtetra
.685 .724 .88 r
.39456 .52262 .39545 .5236 .39695 .52313 .39606 .52205 Mtetra
.684 .705 .863 r
.39606 .52205 .39695 .52313 .39844 .52264 .39756 .52146 Mtetra
.673 .686 .853 r
.39756 .52146 .39844 .52264 .39994 .52213 .39906 .52092 Mtetra
.668 .678 .85 r
.39906 .52092 .39994 .52213 .40144 .52161 .40056 .5204 Mtetra
.667 .677 .851 r
.40056 .5204 .40144 .52161 .40294 .52107 .40206 .51989 Mtetra
.669 .683 .854 r
.40206 .51989 .40294 .52107 .40445 .52048 .40356 .51936 Mtetra
.67 .694 .864 r
.40356 .51936 .40445 .52048 .40595 .51989 .40507 .51885 Mtetra
.668 .708 .878 r
.40507 .51885 .40595 .51989 .40746 .5193 .40657 .51835 Mtetra
.654 .722 .899 r
.40657 .51835 .40746 .5193 .40896 .5187 .40807 .51791 Mtetra
.645 .758 .931 r
.40807 .51791 .40896 .5187 .41047 .51815 .40957 .5175 Mtetra
.644 .793 .954 r
.40957 .5175 .41047 .51815 .41197 .51771 .41107 .51707 Mtetra
.674 .802 .944 r
.41107 .51707 .41197 .51771 .41346 .51761 .41258 .51653 Mtetra
.684 .706 .865 r
.41258 .51653 .41346 .51761 .41495 .51774 .41409 .51595 Mtetra
.661 .604 .78 r
.41409 .51595 .41495 .51774 .41644 .51792 .4156 .51536 Mtetra
.637 .539 .727 r
.4156 .51536 .41644 .51792 .41794 .51771 .41711 .51481 Mtetra
.627 .518 .711 r
.41711 .51481 .41794 .51771 .41945 .5172 .41862 .5143 Mtetra
.625 .517 .711 r
.41862 .5143 .41945 .5172 .42096 .5166 .42013 .5138 Mtetra
.65 .536 .712 r
.42013 .5138 .42096 .5166 .42248 .51569 .42165 .51306 Mtetra
.646 .542 .722 r
.42165 .51306 .42248 .51569 .424 .51495 .42317 .51241 Mtetra
.599 .518 .735 r
.42317 .51241 .424 .51495 .4255 .51487 .42467 .5122 Mtetra
.212 .266 .702 r
.42467 .5122 .4255 .51487 .4269 .51818 .42612 .51392 Mtetra
.856 .587 .051 r
.42612 .51392 .4269 .51818 .42286 .71032 .42737 .5226 Mtetra
0 0 .334 r
.42737 .5226 .42286 .71032 .42429 .71579 .42344 .71179 Mtetra
.348 .305 .668 r
.42344 .71179 .42429 .71579 .42585 .71686 .42498 .71364 Mtetra
.601 .497 .708 r
.42498 .71364 .42585 .71686 .42746 .7166 .42658 .71336 Mtetra
.652 .528 .7 r
.42658 .71336 .42746 .7166 .42907 .71593 .4282 .71247 Mtetra
.634 .511 .695 r
.4282 .71247 .42907 .71593 .43068 .71535 .42982 .71177 Mtetra
.615 .495 .692 r
.42982 .71177 .43068 .71535 .43229 .7149 .43143 .71128 Mtetra
.616 .494 .691 r
.43143 .71128 .43229 .7149 .43391 .71442 .43304 .71078 Mtetra
.624 .499 .69 r
.43304 .71078 .43391 .71442 .43552 .71394 .43466 .71018 Mtetra
.622 .494 .686 r
.43466 .71018 .43552 .71394 .43713 .71347 .43627 .70958 Mtetra
.605 .48 .683 r
.43627 .70958 .43713 .71347 .43875 .71298 .43788 .70918 Mtetra
.552 .448 .69 r
.43788 .70918 .43875 .71298 .44036 .71244 .43948 .70939 Mtetra
.509 .447 .723 r
.43948 .70939 .44036 .71244 .44198 .71188 .44108 .70989 Mtetra
.497 .511 .802 r
.44108 .70989 .44198 .71188 .4436 .71132 .44267 .71023 Mtetra
.558 .674 .915 r
.44267 .71023 .4436 .71132 .44522 .7108 .44428 .71013 Mtetra
.635 .8 .962 r
.44428 .71013 .44522 .7108 .44684 .71031 .4459 .70969 Mtetra
.665 .819 .958 r
.4459 .70969 .44684 .71031 .44846 .70984 .44753 .70914 Mtetra
.659 .798 .949 r
.44753 .70914 .44846 .70984 .45008 .70938 .44915 .70862 Mtetra
.645 .78 .946 r
.44915 .70862 .45008 .70938 .4517 .70893 .45077 .70816 Mtetra
.643 .778 .945 r
.45077 .70816 .4517 .70893 .45333 .70848 .45239 .70771 Mtetra
.641 .775 .945 r
.45239 .70771 .45333 .70848 .45495 .7081 .45402 .70727 Mtetra
.64 .761 .936 r
.45402 .70727 .45495 .7081 .45657 .70773 .45564 .70683 Mtetra
.636 .745 .927 r
.45564 .70683 .45657 .70773 .4582 .70727 .45727 .70642 Mtetra
.619 .752 .941 r
.45727 .70642 .4582 .70727 .45983 .7065 .45889 .70607 Mtetra
.536 .835 .999 r
.45889 .70607 .45983 .7065 .46147 .70542 .46052 .70575 Mtetra
0 0 0 r
.46052 .70575 .46147 .70542 .46311 .70427 .46214 .70543 Mtetra
.328 0 .033 r
.46214 .70543 .46311 .70427 .46474 .70341 .46377 .70506 Mtetra
.392 .002 .174 r
.46377 .70506 .46474 .70341 .46637 .70294 .4654 .70464 Mtetra
.392 .006 .182 r
.4654 .70464 .46637 .70294 .468 .7026 .46704 .7042 Mtetra
.378 0 .158 r
.46704 .7042 .468 .7026 .46963 .70223 .46867 .70376 Mtetra
.367 0 .138 r
.46867 .70376 .46963 .70223 .47126 .70179 .4703 .70331 Mtetra
.36 0 .134 r
.4703 .70331 .47126 .70179 .4729 .70134 .47194 .70284 Mtetra
.344 0 .121 r
.47194 .70284 .4729 .70134 .47453 .70087 .47357 .70233 Mtetra
.321 0 .098 r
.47357 .70233 .47453 .70087 .47617 .7004 .47521 .70177 Mtetra
.304 0 .07 r
.47521 .70177 .47617 .7004 .4778 .69992 .47685 .70121 Mtetra
.301 0 .049 r
.47685 .70121 .4778 .69992 .47944 .69946 .47849 .70069 Mtetra
.309 0 .039 r
.47849 .70069 .47944 .69946 .48108 .69902 .48013 .70023 Mtetra
.31 0 .035 r
.48013 .70023 .48108 .69902 .48272 .69858 .48177 .69978 Mtetra
.377 0 .075 r
.48177 .69978 .48272 .69858 .48435 .69841 .48341 .69952 Mtetra
.388 0 .06 r
.48341 .69952 .48435 .69841 .48599 .69835 .48505 .69934 Mtetra
.174 0 0 r
.48505 .69934 .48599 .69835 .48764 .69769 .4867 .69874 Mtetra
.632 .871 .515 r
.4867 .69874 .48764 .69769 .4893 .69469 .48836 .69665 Mtetra
.974 .872 .49 r
.48836 .69665 .4893 .69469 .49279 .50289 .49006 .69019 Mtetra
0 0 .345 r
.49006 .69019 .49279 .50289 .49443 .49339 .49353 .49624 Mtetra
0 0 0 r
.49353 .49624 .49443 .49339 .496 .49084 .49512 .49218 Mtetra
.201 0 .023 r
.49512 .49218 .496 .49084 .49756 .49013 .49668 .49136 Mtetra
.424 0 .127 r
.49668 .49136 .49756 .49013 .49911 .48988 .49823 .49122 Mtetra
.472 .062 .179 r
.49823 .49122 .49911 .48988 .50066 .48966 .49978 .49121 Mtetra
.419 .028 .188 r
.49978 .49121 .50066 .48966 .50221 .48921 .50134 .49092 Mtetra
.396 .019 .201 r
.50134 .49092 .50221 .48921 .50377 .48878 .50289 .49047 Mtetra
.247 0 .121 r
.50289 .49047 .50377 .48878 .50532 .48837 .50445 .48952 Mtetra
0 0 0 r
.50445 .48952 .50532 .48837 .50688 .48797 .50602 .48811 Mtetra
.791 .994 .872 r
.50602 .48811 .50688 .48797 .50844 .48757 .50758 .48682 Mtetra
.759 .797 .884 r
.50758 .48682 .50844 .48757 .51 .48715 .50914 .48587 Mtetra
.666 .671 .845 r
.50914 .48587 .51 .48715 .51156 .4867 .5107 .48533 Mtetra
.641 .649 .842 r
.5107 .48533 .51156 .4867 .51312 .48622 .51227 .48492 Mtetra
.634 .657 .855 r
.51227 .48492 .51312 .48622 .51468 .48569 .51383 .48455 Mtetra
.642 .687 .877 r
.51383 .48455 .51468 .48569 .51624 .48513 .51539 .48415 Mtetra
.642 .721 .905 r
.51539 .48415 .51624 .48513 .51781 .48455 .51695 .48375 Mtetra
.647 .764 .934 r
.51695 .48375 .51781 .48455 .51937 .48396 .51852 .48331 Mtetra
.657 .807 .955 r
.51852 .48331 .51937 .48396 .52094 .48336 .52009 .48281 Mtetra
.661 .836 .967 r
.52009 .48281 .52094 .48336 .5225 .48284 .52165 .48228 Mtetra
.678 .834 .958 r
.52165 .48228 .5225 .48284 .52407 .48254 .52322 .48169 Mtetra
.696 .764 .905 r
.52322 .48169 .52407 .48254 .52564 .48259 .52479 .48106 Mtetra
.673 .642 .81 r
.52479 .48106 .52564 .48259 .52721 .48274 .52636 .48043 Mtetra
.658 .568 .742 r
.52636 .48043 .52721 .48274 .52878 .48256 .52793 .47972 Mtetra
.655 .539 .711 r
.52793 .47972 .52878 .48256 .53035 .48168 .5295 .4789 Mtetra
.621 .522 .721 r
.5295 .4789 .53035 .48168 .53192 .48122 .53107 .47845 Mtetra
.484 .439 .732 r
.53107 .47845 .53192 .48122 .5335 .48239 .53265 .47907 Mtetra
0 0 .455 r
.53265 .47907 .5335 .48239 .53566 .67027 .53423 .4834 Mtetra
0 0 .375 r
.53423 .4834 .53566 .67027 .53737 .68282 .53645 .67733 Mtetra
.117 .112 .575 r
.53645 .67733 .53737 .68282 .53905 .68517 .53814 .68181 Mtetra
.566 .473 .708 r
.53814 .68181 .53905 .68517 .54073 .68513 .53982 .68187 Mtetra
.637 .52 .704 r
.53982 .68187 .54073 .68513 .5424 .68457 .5415 .68116 Mtetra
.65 .524 .696 r
.5415 .68116 .5424 .68457 .54408 .68386 .54317 .68023 Mtetra
.613 .494 .693 r
.54317 .68023 .54408 .68386 .54576 .6834 .54485 .67975 Mtetra
.614 .494 .693 r
.54485 .67975 .54576 .6834 .54744 .68293 .54653 .67927 Mtetra
.614 .494 .692 r
.54653 .67927 .54744 .68293 .54912 .68245 .54821 .67878 Mtetra
.612 .493 .692 r
.54821 .67878 .54912 .68245 .5508 .68198 .54989 .67831 Mtetra
.612 .492 .692 r
.54989 .67831 .5508 .68198 .55248 .68152 .55157 .67784 Mtetra
.55157 .67784 .55248 .68152 .55417 .68105 .55325 .67737 Mtetra
.55325 .67737 .55417 .68105 .55585 .68058 .55494 .67691 Mtetra
.55494 .67691 .55585 .68058 .55754 .68012 .55662 .67644 Mtetra
.55662 .67644 .55754 .68012 .55922 .67965 .55831 .67597 Mtetra
.55831 .67597 .55922 .67965 .56091 .67918 .55999 .6755 Mtetra
.55999 .6755 .56091 .67918 .5626 .67871 .56168 .67503 Mtetra
.56168 .67503 .5626 .67871 .56429 .67824 .56337 .67456 Mtetra
.56337 .67456 .56429 .67824 .56598 .67777 .56506 .67409 Mtetra
.56506 .67409 .56598 .67777 .56767 .6773 .56675 .67362 Mtetra
.56675 .67362 .56767 .6773 .56937 .67683 .56844 .67315 Mtetra
.56844 .67315 .56937 .67683 .57106 .67636 .57014 .67268 Mtetra
.57014 .67268 .57106 .67636 .57275 .67589 .57183 .67221 Mtetra
.57183 .67221 .57275 .67589 .57445 .67542 .57353 .67173 Mtetra
.57353 .67173 .57445 .67542 .57615 .67495 .57522 .67126 Mtetra
.57522 .67126 .57615 .67495 .57784 .67447 .57692 .67079 Mtetra
.57692 .67079 .57784 .67447 .57954 .674 .57862 .67032 Mtetra
.57862 .67032 .57954 .674 .58124 .67353 .58032 .66984 Mtetra
.612 .492 .693 r
.58032 .66984 .58124 .67353 .58295 .67305 .58202 .66937 Mtetra
.58202 .66937 .58295 .67305 .58465 .67258 .58372 .6689 Mtetra
.611 .492 .693 r
.58372 .6689 .58465 .67258 .58635 .67212 .58542 .66845 Mtetra
.58542 .66845 .58635 .67212 .58806 .67165 .58713 .66799 Mtetra
.607 .49 .694 r
.58713 .66799 .58806 .67165 .58976 .6712 .58883 .66758 Mtetra
.566 .465 .699 r
.58883 .66758 .58976 .6712 .59147 .67101 .59055 .66764 Mtetra
.613 .503 .705 r
.59055 .66764 .59147 .67101 .59318 .67049 .59226 .66721 Mtetra
.696 .556 .691 r
.59226 .66721 .59318 .67049 .59487 .66922 .59394 .66562 Mtetra
.885 .655 .584 r
.59394 .66562 .59487 .66922 .59649 .66441 .59544 .6547 Mtetra
.953 .679 .479 r
.59544 .6547 .59649 .66441 .5941 .46903 .59316 .46256 Mtetra
.711 .514 .62 r
.59316 .46256 .5941 .46903 .59557 .46165 .5947 .45873 Mtetra
.664 .543 .707 r
.5947 .45873 .59557 .46165 .59716 .46057 .5963 .45777 Mtetra
.617 .521 .722 r
.5963 .45777 .59716 .46057 .59878 .46022 .59791 .45736 Mtetra
.586 .5 .723 r
.59791 .45736 .59878 .46022 .6004 .46009 .59953 .45723 Mtetra
.614 .516 .72 r
.59953 .45723 .6004 .46009 .602 .45892 .60115 .45684 Mtetra
.624 .567 .771 r
.60115 .45684 .602 .45892 .60359 .45779 .60276 .45646 Mtetra
.64 .659 .853 r
.60276 .45646 .60359 .45779 .6052 .45681 .60438 .45605 Mtetra
.672 .788 .936 r
.60438 .45605 .6052 .45681 .60681 .45629 .606 .4555 Mtetra
.682 .783 .927 r
.606 .4555 .60681 .45629 .60843 .45588 .60761 .45491 Mtetra
.683 .741 .895 r
.60761 .45491 .60843 .45588 .61005 .45552 .60922 .45431 Mtetra
.687 .698 .855 r
.60922 .45431 .61005 .45552 .61167 .455 .61084 .45365 Mtetra
.668 .669 .842 r
.61084 .45365 .61167 .455 .61328 .45446 .61246 .45309 Mtetra
.639 .653 .848 r
.61246 .45309 .61328 .45446 .6149 .45389 .61408 .45268 Mtetra
.608 .665 .88 r
.61408 .45268 .6149 .45389 .61651 .45291 .61571 .45241 Mtetra
.253 .672 .964 r
.61571 .45241 .61651 .45291 .61813 .45224 .61735 .45259 Mtetra
.653 .138 .007 r
.61735 .45259 .61813 .45224 .61976 .45215 .61902 .45367 Mtetra
.909 .584 .419 r
.61902 .45367 .61976 .45215 .62149 .45517 .62097 .46423 Mtetra
.953 .67 .462 r
.62097 .46423 .62149 .45517 .62893 .64873 .62829 .65522 Mtetra
.67 .387 .483 r
.62829 .65522 .62893 .64873 .63092 .65709 .63013 .65842 Mtetra
.513 .09 .175 r
.63013 .65842 .63092 .65709 .6327 .65817 .63189 .65865 Mtetra
0 0 0 r
.63189 .65865 .6327 .65817 .63445 .65829 .63362 .65814 Mtetra
.712 .96 .945 r
.63362 .65814 .63445 .65829 .63619 .65795 .63534 .65717 Mtetra
.715 .806 .921 r
.63534 .65717 .63619 .65795 .63794 .65796 .63706 .65638 Mtetra
.737 .679 .794 r
.63706 .65638 .63794 .65796 .63968 .65756 .63878 .65518 Mtetra
.759 .627 .713 r
.63878 .65518 .63968 .65756 .6414 .65651 .64046 .65309 Mtetra
.874 .652 .597 r
.64046 .65309 .6414 .65651 .64302 .65253 .64192 .64445 Mtetra
.96 .681 .462 r
.64192 .64445 .64302 .65253 .63817 .46102 .63699 .44945 Mtetra
.664 .458 .595 r
.63699 .44945 .63817 .46102 .63938 .44831 .6385 .44523 Mtetra
.67 .542 .7 r
.6385 .44523 .63938 .44831 .64096 .44617 .64011 .44412 Mtetra
.622 .571 .776 r
.64011 .44412 .64096 .44617 .64257 .44509 .64175 .44376 Mtetra
.554 .622 .874 r
.64175 .44376 .64257 .44509 .6442 .44444 .64341 .44373 Mtetra
.619 .786 .962 r
.64341 .44373 .6442 .44444 .64584 .44386 .64505 .44333 Mtetra
.621 .84 .984 r
.64505 .44333 .64584 .44386 .64748 .44339 .64669 .44287 Mtetra
.627 .843 .983 r
.64669 .44287 .64748 .44339 .64912 .44299 .64833 .44238 Mtetra
.643 .825 .97 r
.64833 .44238 .64912 .44299 .65076 .4425 .64998 .44188 Mtetra
.649 .824 .967 r
.64998 .44188 .65076 .4425 .65241 .44199 .65162 .44137 Mtetra
.654 .826 .966 r
.65162 .44137 .65241 .44199 .65405 .44146 .65326 .44084 Mtetra
.659 .826 .964 r
.65326 .44084 .65405 .44146 .65569 .44084 .6549 .44029 Mtetra
.657 .847 .973 r
.6549 .44029 .65569 .44084 .65733 .44025 .65655 .43973 Mtetra
.66 .855 .975 r
.65655 .43973 .65733 .44025 .65897 .43977 .65819 .43915 Mtetra
.764 .848 .914 r
.65819 .43915 .65897 .43977 .66062 .43934 .65982 .43818 Mtetra
.708 .716 .855 r
.65982 .43818 .66062 .43934 .66229 .43925 .66145 .4374 Mtetra
.606 .581 .798 r
.66145 .4374 .66229 .43925 .66399 .43989 .66311 .43715 Mtetra
.187 .254 .7 r
.66311 .43715 .66399 .43989 .66589 .44534 .66488 .4393 Mtetra
.837 .576 .03 r
.66488 .4393 .66589 .44534 .67614 .64158 .66729 .45627 Mtetra
.041 0 .437 r
.66729 .45627 .67614 .64158 .6781 .64574 .67713 .64183 Mtetra
.373 .333 .685 r
.67713 .64183 .6781 .64574 .67991 .64634 .67899 .6437 Mtetra
.515 .48 .755 r
.67899 .6437 .67991 .64634 .68167 .64591 .6808 .64411 Mtetra
.583 .586 .821 r
.6808 .64411 .68167 .64591 .68342 .645 .68258 .64399 Mtetra
.514 .682 .942 r
.68258 .64399 .68342 .645 .68517 .64431 .68436 .64397 Mtetra
.467 .84 .989 r
.68436 .64397 .68517 .64431 .68692 .64338 .68614 .64365 Mtetra
.444 .868 .745 r
.68614 .64365 .68692 .64338 .68863 .64174 .68788 .64273 Mtetra
.806 .904 .498 r
.68788 .64273 .68863 .64174 .69015 .63612 .68953 .63961 Mtetra
.82 .731 .204 r
.68953 .63961 .69015 .63612 .68238 .43825 .69086 .63013 Mtetra
.037 0 .43 r
.69086 .63013 .68238 .43825 .6838 .43272 .68317 .4349 Mtetra
0 0 .014 r
.68317 .4349 .6838 .43272 .68541 .43117 .6847 .4318 Mtetra
0 0 0 r
.6847 .4318 .68541 .43117 .68707 .43069 .68632 .43039 Mtetra
.715 .932 .961 r
.68632 .43039 .68707 .43069 .68876 .4306 .68797 .42953 Mtetra
.674 .724 .887 r
.68797 .42953 .68876 .4306 .69043 .43027 .68963 .42895 Mtetra
.636 .664 .86 r
.68963 .42895 .69043 .43027 .6921 .42979 .6913 .42855 Mtetra
.617 .669 .877 r
.6913 .42855 .6921 .42979 .69377 .42928 .69298 .42824 Mtetra
.647 .72 .902 r
.69298 .42824 .69377 .42928 .69542 .42861 .69465 .42778 Mtetra
.668 .777 .931 r
.69465 .42778 .69542 .42861 .69708 .42792 .69632 .42723 Mtetra
.674 .814 .95 r
.69632 .42723 .69708 .42792 .69875 .42734 .69798 .42664 Mtetra
.754 .831 .911 r
.69798 .42664 .69875 .42734 .70042 .42685 .69963 .4257 Mtetra
.719 .727 .856 r
.69963 .4257 .70042 .42685 .70211 .42666 .70128 .42485 Mtetra
.623 .595 .801 r
.70128 .42485 .70211 .42666 .70384 .42715 .70296 .4245 Mtetra
.296 .332 .729 r
.70296 .4245 .70384 .42715 .70577 .43128 .70476 .42616 Mtetra
0 0 .368 r
.70476 .42616 .70577 .43128 .71854 .62854 .70694 .43465 Mtetra
.062 0 .449 r
.70694 .43465 .71854 .62854 .72063 .63346 .71962 .62914 Mtetra
.332 .295 .666 r
.71962 .62914 .72063 .63346 .7225 .63434 .72157 .63159 Mtetra
.506 .469 .75 r
.72157 .63159 .7225 .63434 .72429 .63393 .72342 .63209 Mtetra
.579 .582 .82 r
.72342 .63209 .72429 .63393 .72606 .6331 .72523 .63199 Mtetra
.558 .684 .924 r
.72523 .63199 .72606 .6331 .72786 .63277 .72705 .63186 Mtetra
.61 .751 .945 r
.72705 .63186 .72786 .63277 .72967 .63253 .72885 .6315 Mtetra
.735 .768 .879 r
.72885 .6315 .72967 .63253 .73144 .63167 .73061 .63055 Mtetra
.886 .773 .732 r
.73061 .63055 .73144 .63167 .73305 .6281 .73227 .62767 Mtetra
.981 .769 .543 r
.73227 .62767 .73305 .6281 .72292 .43157 .73356 .61884 Mtetra
.038 0 .435 r
.73356 .61884 .72292 .43157 .72396 .42055 .72337 .42257 Mtetra
0 0 0 r
.72337 .42257 .72396 .42055 .72554 .41833 .72488 .4191 Mtetra
.72488 .4191 .72554 .41833 .72722 .41776 .72651 .41763 Mtetra
.678 .962 .939 r
.72651 .41763 .72722 .41776 .72894 .41768 .72817 .41673 Mtetra
.682 .755 .907 r
.72817 .41673 .72894 .41768 .73064 .41744 .72985 .41612 Mtetra
.643 .669 .86 r
.72985 .41612 .73064 .41744 .73233 .41695 .73155 .41567 Mtetra
.621 .667 .873 r
.73155 .41567 .73233 .41695 .73402 .41644 .73325 .41534 Mtetra
.69 .728 .879 r
.73325 .41534 .73402 .41644 .73569 .41556 .73493 .41467 Mtetra
.712 .779 .904 r
.73493 .41467 .73569 .41556 .73736 .41468 .73661 .41391 Mtetra
.59 .768 .964 r
.73661 .41391 .73736 .41468 .73907 .41436 .73832 .4136 Mtetra
0 .14 .635 r
.73832 .4136 .73907 .41436 .74094 .41648 .74015 .4151 Mtetra
.923 .558 .132 r
.74015 .4151 .74094 .41648 .75587 .61289 .74245 .42359 Mtetra
.064 0 .454 r
.74245 .42359 .75587 .61289 .75837 .62255 .75736 .61859 Mtetra
.225 .236 .661 r
.75736 .61859 .75837 .62255 .76034 .62438 .75941 .62164 Mtetra
.463 .444 .752 r
.75941 .62164 .76034 .62438 .76218 .62433 .76131 .62244 Mtetra
.614 .596 .809 r
.76131 .62244 .76218 .62433 .76396 .62331 .76314 .62211 Mtetra
.869 .768 .749 r
.76314 .62211 .76396 .62331 .7656 .62028 .76481 .61954 Mtetra
.977 .752 .53 r
.76481 .61954 .7656 .62028 .76666 .60914 .76596 .60958 Mtetra
.977 .686 .397 r
.76596 .60958 .76666 .60914 .75454 .41231 .75379 .41146 Mtetra
.921 .804 .714 r
.75379 .41146 .75454 .41231 .75607 .40934 .75531 .40837 Mtetra
.713 .765 .893 r
.75531 .40837 .75607 .40934 .75775 .40856 .757 .40759 Mtetra
.583 .715 .934 r
.757 .40759 .75775 .40856 .75948 .40833 .75872 .40736 Mtetra
.661 .747 .914 r
.75872 .40736 .75948 .40833 .76118 .40775 .76043 .40683 Mtetra
.729 .781 .894 r
.76043 .40683 .76118 .40775 .76286 .40684 .76211 .40598 Mtetra
.628 .759 .941 r
.76211 .40598 .76286 .40684 .76458 .40648 .76383 .40557 Mtetra
0 .342 .816 r
.76383 .40557 .76458 .40648 .76646 .40823 .76567 .40671 Mtetra
.841 .46 0 r
.76567 .40671 .76646 .40823 .78278 .6017 .76788 .41291 Mtetra
.07 0 .459 r
.76788 .41291 .78278 .6017 .7856 .61431 .78453 .6098 Mtetra
.266 .248 .652 r
.78453 .6098 .7856 .61431 .7876 .61614 .78664 .61302 Mtetra
.515 .456 .729 r
.78664 .61302 .7876 .61614 .78944 .61576 .78855 .61354 Mtetra
.583 .55 .784 r
.78855 .61354 .78944 .61576 .79124 .61483 .79041 .61343 Mtetra
.569 .638 .88 r
.79041 .61343 .79124 .61483 .79307 .61425 .79228 .61332 Mtetra
.526 .714 .958 r
.79228 .61332 .79307 .61425 .79493 .61417 .79414 .61322 Mtetra
.695 .778 .915 r
.79414 .61322 .79493 .61417 .79676 .61357 .79596 .61249 Mtetra
.887 .789 .746 r
.79596 .61249 .79676 .61357 .79843 .61103 .79762 .60979 Mtetra
.972 .727 .506 r
.79762 .60979 .79843 .61103 .7994 .59966 .79847 .59695 Mtetra
.976 .681 .391 r
.79847 .59695 .7994 .59966 .78535 .40251 .78459 .40138 Mtetra
.9 .771 .71 r
.78459 .40138 .78535 .40251 .78686 .39933 .78611 .3983 Mtetra
.709 .752 .885 r
.78611 .3983 .78686 .39933 .78856 .39854 .78781 .39753 Mtetra
.585 .706 .926 r
.78781 .39753 .78856 .39854 .7903 .3983 .78956 .3973 Mtetra
.629 .727 .918 r
.78956 .3973 .7903 .3983 .79204 .39786 .7913 .3969 Mtetra
.726 .773 .89 r
.7913 .3969 .79204 .39786 .79373 .39694 .793 .39605 Mtetra
.642 .759 .934 r
.793 .39605 .79373 .39694 .79546 .39651 .79473 .39558 Mtetra
.143 .477 .897 r
.79473 .39558 .79546 .39651 .79734 .39778 .79657 .39639 Mtetra
.742 .345 0 r
.79657 .39639 .79734 .39778 .80013 .40967 .79875 .4011 Mtetra
.978 .677 .331 r
.79875 .4011 .80013 .40967 .81859 .60427 .81745 .59905 Mtetra
.225 .206 .627 r
.81745 .59905 .81859 .60427 .82069 .60663 .8197 .60323 Mtetra
.514 .445 .717 r
.8197 .60323 .82069 .60663 .82255 .60626 .82165 .60382 Mtetra
.587 .538 .767 r
.82165 .60382 .82255 .60626 .82436 .60526 .82353 .60368 Mtetra
.64 .647 .841 r
.82353 .60368 .82436 .60526 .82617 .60424 .82539 .6032 Mtetra
.664 .75 .914 r
.82539 .6032 .82617 .60424 .82803 .60373 .82724 .60262 Mtetra
.688 .743 .893 r
.82724 .60262 .82803 .60373 .82987 .60315 .82908 .60191 Mtetra
.681 .718 .877 r
.82908 .60191 .82987 .60315 .83169 .60221 .83092 .60122 Mtetra
.654 .757 .925 r
.83092 .60122 .83169 .60221 .83346 .60068 .83277 .60067 Mtetra
.343 .822 .846 r
.83277 .60067 .83346 .60068 .83522 .59907 .83463 .60016 Mtetra
.295 0 .003 r
.83463 .60016 .83522 .59907 .83704 .5982 .8365 .59967 Mtetra
.371 0 .134 r
.8365 .59967 .83704 .5982 .83899 .59866 .83836 .59919 Mtetra
.095 0 0 r
.83836 .59919 .83899 .59866 .84095 .59919 .84023 .59873 Mtetra
.457 .81 .997 r
.84023 .59873 .84095 .59919 .8429 .59958 .84212 .59849 Mtetra
.496 .663 .936 r
.84212 .59849 .8429 .59958 .84482 .59969 .84404 .59856 Mtetra
.642 .722 .906 r
.84404 .59856 .84482 .59969 .84668 .59914 .84591 .59807 Mtetra
.859 .797 .788 r
.84591 .59807 .84668 .59914 .84839 .5969 .84763 .59594 Mtetra
.981 .745 .504 r
.84763 .59594 .84839 .5969 .84919 .5852 .84852 .58512 Mtetra
.978 .679 .359 r
.84852 .58512 .84919 .5852 .8322 .3877 .8315 .38695 Mtetra
.95 .823 .683 r
.8315 .38695 .8322 .3877 .83367 .38423 .83296 .38339 Mtetra
.727 .806 .914 r
.83296 .38339 .83367 .38423 .83539 .38344 .83468 .38254 Mtetra
.586 .737 .947 r
.83468 .38254 .83539 .38344 .83718 .38324 .83646 .38227 Mtetra
.589 .722 .936 r
.83646 .38227 .83718 .38324 .83897 .38305 .83824 .38201 Mtetra
.733 .762 .876 r
.83824 .38201 .83897 .38305 .84069 .38221 .83996 .38109 Mtetra
.649 .715 .896 r
.83996 .38109 .84069 .38221 .84245 .38172 .84172 .3806 Mtetra
.231 .487 .893 r
.84172 .3806 .84245 .38172 .84431 .38227 .84361 .38143 Mtetra
.913 .529 .11 r
.84361 .38143 .84431 .38227 .84659 .38693 .84626 .38977 Mtetra
.973 .664 .349 r
.84626 .38977 .84659 .38693 .86851 .58636 .86811 .58886 Mtetra
.742 .376 .359 r
.86811 .58886 .86851 .58636 .8709 .5909 .87035 .59193 Mtetra
.393 0 .027 r
.87035 .59193 .8709 .5909 .8729 .59144 .87228 .59181 Mtetra
0 0 0 r
.87228 .59181 .8729 .59144 .87482 .59128 .87413 .59096 Mtetra
.762 .958 .935 r
.87413 .59096 .87482 .59128 .87672 .59095 .87595 .58978 Mtetra
.708 .744 .88 r
.87595 .58978 .87672 .59095 .87867 .59101 .8778 .58894 Mtetra
.725 .64 .763 r
.8778 .58894 .87867 .59101 .88056 .59052 .87961 .5876 Mtetra
.774 .617 .684 r
.87961 .5876 .88056 .59052 .88232 .58879 .88126 .58484 Mtetra
.951 .675 .479 r
.88126 .58484 .88232 .58879 .88352 .58169 .88092 .56307 Mtetra
.964 .659 .401 r
.88092 .56307 .88352 .58169 .86403 .37937 .86319 .37709 Mtetra
.837 .669 .673 r
.86319 .37709 .86403 .37937 .86537 .37471 .86466 .37368 Mtetra
.752 .775 .872 r
.86466 .37368 .86537 .37471 .86708 .37366 .86637 .37265 Mtetra
.638 .735 .918 r
.86637 .37265 .86708 .37366 .86887 .37324 .86816 .3722 Mtetra
.562 .692 .928 r
.86816 .3722 .86887 .37324 .87067 .37295 .86997 .37205 Mtetra
.61 .748 .943 r
.86997 .37205 .87067 .37295 .87238 .37187 .87177 .37169 Mtetra
.088 .634 .839 r
.87177 .37169 .87238 .37187 .87414 .37119 .87361 .37178 Mtetra
.648 .138 .018 r
.87361 .37178 .87414 .37119 .87601 .3715 .87558 .37301 Mtetra
.928 .569 .321 r
.87558 .37301 .87601 .3715 .87842 .37663 .87876 .38514 Mtetra
.97 .656 .353 r
.87876 .38514 .87842 .37663 .90269 .57855 .90208 .57871 Mtetra
.794 .3 .002 r
.90208 .57871 .90269 .57855 .90513 .58286 .90436 .58164 Mtetra
.518 .65 .917 r
.90436 .58164 .90513 .58286 .90709 .58284 .90633 .58168 Mtetra
.672 .733 .896 r
.90633 .58168 .90709 .58284 .90897 .58209 .90823 .58103 Mtetra
.743 .782 .884 r
.90823 .58103 .90897 .58209 .91083 .58111 .91008 .58 Mtetra
.692 .753 .898 r
.91008 .58 .91083 .58111 .91281 .58118 .91196 .57925 Mtetra
.723 .652 .779 r
.91196 .57925 .91281 .58118 .91473 .58081 .91379 .578 Mtetra
.762 .616 .697 r
.91379 .578 .91473 .58081 .91655 .57946 .91549 .5756 Mtetra
.922 .665 .531 r
.91549 .5756 .91655 .57946 .91776 .57282 .916 .56293 Mtetra
.973 .665 .358 r
.916 .56293 .91776 .57282 .89611 .36969 .89528 .36755 Mtetra
.861 .686 .664 r
.89528 .36755 .89611 .36969 .89736 .36457 .8967 .36378 Mtetra
.744 .831 .918 r
.8967 .36378 .89736 .36457 .8991 .36357 .89844 .36284 Mtetra
.594 .79 .974 r
.89844 .36284 .8991 .36357 .90092 .36328 .90025 .36247 Mtetra
.512 .73 .972 r
.90025 .36247 .90092 .36328 .90279 .36333 .9021 .36237 Mtetra
.65 .755 .926 r
.9021 .36237 .90279 .36333 .90459 .36285 .9039 .36186 Mtetra
.659 .753 .919 r
.9039 .36186 .90459 .36285 .90639 .36233 .9057 .36131 Mtetra
.672 .752 .91 r
.9057 .36131 .90639 .36233 .90818 .36177 .90748 .3607 Mtetra
.717 .759 .885 r
.90748 .3607 .90818 .36177 .90997 .36114 .90925 .35986 Mtetra
.697 .71 .858 r
.90925 .35986 .90997 .36114 .91175 .36049 .91102 .35909 Mtetra
.666 .677 .851 r
.91102 .35909 .91175 .36049 .91354 .3598 .91281 .35848 Mtetra
.625 .67 .873 r
.91281 .35848 .91354 .3598 .91527 .35869 .91463 .3581 Mtetra
.36 .711 .986 r
.91463 .3581 .91527 .35869 .91704 .35792 .91652 .35819 Mtetra
.561 0 0 r
.91652 .35819 .91704 .35792 .91889 .35777 .91851 .35921 Mtetra
.58 .364 .551 r
.32388 .72736 .33528 .54313 .33615 .55326 .32481 .73783 Mtetra
.566 .352 .549 r
.32481 .73783 .33615 .55326 .32729 .73903 .32619 .74045 Mtetra
.667 .289 .32 r
.32619 .74045 .32729 .73903 .32864 .74215 .32765 .74158 Mtetra
.554 .795 .989 r
.32765 .74158 .32864 .74215 .33017 .74219 .32919 .74133 Mtetra
.697 .759 .9 r
.32919 .74133 .33017 .74219 .33173 .7416 .33076 .74069 Mtetra
.725 .754 .875 r
.33076 .74069 .33173 .7416 .33331 .7407 .33233 .73989 Mtetra
.37 .654 .967 r
.33233 .73989 .33331 .7407 .33483 .74079 .33385 .74009 Mtetra
.522 .747 .978 r
.33385 .74009 .33483 .74079 .33638 .74056 .33539 .73996 Mtetra
.744 .823 .913 r
.33539 .73996 .33638 .74056 .33796 .73961 .33697 .7391 Mtetra
.922 .757 .66 r
.33697 .7391 .33796 .73961 .33977 .73425 .33878 .73385 Mtetra
.938 .687 .531 r
.33878 .73385 .33977 .73425 .35129 .54086 .35037 .54002 Mtetra
.91 .729 .644 r
.35037 .54002 .35129 .54086 .35302 .53523 .35212 .53424 Mtetra
.761 .734 .828 r
.35212 .53424 .35302 .53523 .35453 .53412 .35362 .53316 Mtetra
.601 .701 .914 r
.35362 .53316 .35453 .53412 .35599 .53383 .35509 .53293 Mtetra
.427 .645 .948 r
.35509 .53293 .35599 .53383 .35744 .53392 .35653 .53309 Mtetra
.632 .741 .926 r
.35653 .53309 .35744 .53392 .35891 .53356 .358 .53274 Mtetra
.663 .751 .915 r
.358 .53274 .35891 .53356 .36039 .53312 .35948 .53227 Mtetra
.678 .748 .904 r
.35948 .53227 .36039 .53312 .36186 .53264 .36096 .53175 Mtetra
.769 .753 .839 r
.36096 .53175 .36186 .53264 .36337 .53166 .36247 .53067 Mtetra
.725 .729 .853 r
.36247 .53067 .36337 .53166 .36486 .53094 .36396 .52987 Mtetra
.581 .669 .899 r
.36396 .52987 .36486 .53094 .36632 .53087 .36542 .52972 Mtetra
.907 .503 .119 r
.36542 .52972 .36632 .53087 .36761 .53446 .36672 .5332 Mtetra
.942 .684 .518 r
.36672 .5332 .36761 .53446 .36013 .72704 .35917 .72615 Mtetra
.941 .596 .338 r
.35917 .72615 .36013 .72704 .36141 .73275 .36044 .73209 Mtetra
.077 .528 .902 r
.36044 .73209 .36141 .73275 .36294 .73325 .36197 .73257 Mtetra
.689 .801 .934 r
.36197 .73257 .36294 .73325 .36452 .73269 .36355 .73195 Mtetra
.768 .796 .876 r
.36355 .73195 .36452 .73269 .36611 .73171 .36515 .73092 Mtetra
.465 .704 .972 r
.36515 .73092 .36611 .73171 .36767 .73165 .3667 .73094 Mtetra
.5 .74 .98 r
.3667 .73094 .36767 .73165 .36923 .73147 .36826 .73086 Mtetra
.723 .824 .928 r
.36826 .73086 .36923 .73147 .37083 .73062 .36985 .7301 Mtetra
.92 .772 .68 r
.36985 .7301 .37083 .73062 .37258 .72615 .3716 .72572 Mtetra
.942 .688 .524 r
.3716 .72572 .37258 .72615 .38235 .53267 .38144 .5319 Mtetra
.923 .729 .623 r
.38144 .5319 .38235 .53267 .38411 .52584 .38321 .52484 Mtetra
.794 .739 .801 r
.38321 .52484 .38411 .52584 .38564 .5244 .38475 .52342 Mtetra
.612 .701 .908 r
.38475 .52342 .38564 .5244 .38713 .52408 .38623 .52315 Mtetra
.427 .638 .945 r
.38623 .52315 .38713 .52408 .38859 .52419 .38769 .52333 Mtetra
.588 .722 .936 r
.38769 .52333 .38859 .52419 .39008 .52396 .38918 .52311 Mtetra
.648 .743 .919 r
.38918 .52311 .39008 .52396 .39157 .52357 .39067 .5227 Mtetra
.667 .741 .906 r
.39067 .5227 .39157 .52357 .39306 .52315 .39216 .52221 Mtetra
.694 .736 .883 r
.39216 .52221 .39306 .52315 .39456 .52262 .39367 .5216 Mtetra
.701 .72 .864 r
.39367 .5216 .39456 .52262 .39606 .52205 .39517 .52093 Mtetra
.697 .702 .851 r
.39517 .52093 .39606 .52205 .39756 .52146 .39668 .52026 Mtetra
.678 .683 .847 r
.39668 .52026 .39756 .52146 .39906 .52092 .39818 .51969 Mtetra
.668 .674 .847 r
.39818 .51969 .39906 .52092 .40056 .5204 .39968 .51917 Mtetra
.664 .673 .848 r
.39968 .51917 .40056 .5204 .40206 .51989 .40118 .51867 Mtetra
.667 .676 .849 r
.40118 .51867 .40206 .51989 .40356 .51936 .40268 .51815 Mtetra
.665 .676 .851 r
.40268 .51815 .40356 .51936 .40507 .51885 .40418 .51764 Mtetra
.659 .676 .855 r
.40418 .51764 .40507 .51885 .40657 .51835 .40569 .51717 Mtetra
.636 .672 .868 r
.40569 .51717 .40657 .51835 .40807 .51791 .40719 .51681 Mtetra
.624 .683 .885 r
.40719 .51681 .40807 .51791 .40957 .5175 .40868 .5165 Mtetra
.631 .705 .9 r
.40868 .5165 .40957 .5175 .41107 .51707 .41018 .51616 Mtetra
.677 .738 .897 r
.41018 .51616 .41107 .51707 .41258 .51653 .41169 .51563 Mtetra
.699 .743 .886 r
.41169 .51563 .41258 .51653 .41409 .51595 .4132 .51499 Mtetra
.699 .733 .876 r
.4132 .51499 .41409 .51595 .4156 .51536 .41472 .51433 Mtetra
.68 .716 .876 r
.41472 .51433 .4156 .51536 .41711 .51481 .41623 .51378 Mtetra
.667 .71 .88 r
.41623 .51378 .41711 .51481 .41862 .5143 .41774 .51328 Mtetra
.662 .712 .886 r
.41774 .51328 .41862 .5143 .42013 .5138 .41925 .51281 Mtetra
.696 .726 .873 r
.41925 .51281 .42013 .5138 .42165 .51306 .42076 .51217 Mtetra
.691 .746 .893 r
.42076 .51217 .42165 .51306 .42317 .51241 .42228 .51157 Mtetra
.617 .739 .933 r
.42228 .51157 .42317 .51241 .42467 .5122 .42379 .51126 Mtetra
.049 .419 .865 r
.42379 .51126 .42467 .5122 .42612 .51392 .42526 .51202 Mtetra
0 0 .57 r
.42526 .51202 .42612 .51392 .42737 .5226 .4267 .51427 Mtetra
.161 .098 .532 r
.4267 .51427 .42737 .5226 .42344 .71179 .42803 .52016 Mtetra
0 0 .366 r
.42803 .52016 .42344 .71179 .42498 .71364 .42443 .69923 Mtetra
.552 .369 .587 r
.42443 .69923 .42498 .71364 .42658 .71336 .426 .69984 Mtetra
.675 .466 .595 r
.426 .69984 .42658 .71336 .4282 .71247 .42774 .69428 Mtetra
.92 .661 .53 r
.42774 .69428 .4282 .71247 .42982 .71177 .43376 .53125 Mtetra
.57 .359 .555 r
.43376 .53125 .42982 .71177 .43143 .71128 .43538 .52753 Mtetra
.567 .357 .555 r
.43538 .52753 .43143 .71128 .43304 .71078 .43695 .52524 Mtetra
.573 .361 .555 r
.43695 .52524 .43304 .71078 .43466 .71018 .43861 .51982 Mtetra
.567 .357 .555 r
.43861 .51982 .43466 .71018 .43627 .70958 .44019 .51726 Mtetra
.56 .351 .554 r
.44019 .51726 .43627 .70958 .43788 .70918 .44168 .51851 Mtetra
0 0 .362 r
.44168 .51851 .43788 .70918 .43948 .70939 .43872 .70148 Mtetra
.185 .124 .55 r
.43872 .70148 .43948 .70939 .44108 .70989 .44019 .70691 Mtetra
.111 .19 .667 r
.44019 .70691 .44108 .70989 .44267 .71023 .44174 .70921 Mtetra
.249 .535 .921 r
.44174 .70921 .44267 .71023 .44428 .71013 .44334 .70975 Mtetra
.551 .853 .998 r
.44334 .70975 .44428 .71013 .4459 .70969 .44496 .70938 Mtetra
.662 .901 .98 r
.44496 .70938 .4459 .70969 .44753 .70914 .44658 .70873 Mtetra
.655 .874 .981 r
.44658 .70873 .44753 .70914 .44915 .70862 .44821 .70814 Mtetra
.618 .846 .986 r
.44821 .70814 .44915 .70862 .45077 .70816 .44983 .70767 Mtetra
.617 .845 .986 r
.44983 .70767 .45077 .70816 .45239 .70771 .45145 .70721 Mtetra
.618 .843 .985 r
.45145 .70721 .45239 .70771 .45402 .70727 .45308 .70676 Mtetra
.615 .838 .985 r
.45308 .70676 .45402 .70727 .45564 .70683 .45471 .70631 Mtetra
.604 .831 .986 r
.45471 .70631 .45564 .70683 .45727 .70642 .45633 .70589 Mtetra
.567 .818 .992 r
.45633 .70589 .45727 .70642 .45889 .70607 .45796 .70557 Mtetra
.527 .813 .998 r
.45796 .70557 .45889 .70607 .46052 .70575 .45958 .70531 Mtetra
.513 .823 1 r
.45958 .70531 .46052 .70575 .46214 .70543 .46121 .70504 Mtetra
.537 .846 .999 r
.46121 .70504 .46214 .70543 .46377 .70506 .46284 .7047 Mtetra
.571 .864 .996 r
.46284 .7047 .46377 .70506 .4654 .70464 .46447 .70427 Mtetra
.588 .867 .994 r
.46447 .70427 .4654 .70464 .46704 .7042 .4661 .70382 Mtetra
.591 .865 .994 r
.4661 .70382 .46704 .7042 .46867 .70376 .46774 .70336 Mtetra
.592 .863 .994 r
.46774 .70336 .46867 .70376 .4703 .70331 .46937 .70291 Mtetra
.607 .866 .992 r
.46937 .70291 .4703 .70331 .47194 .70284 .47101 .70243 Mtetra
.642 .872 .984 r
.47101 .70243 .47194 .70284 .47357 .70233 .47265 .70187 Mtetra
.676 .867 .971 r
.47265 .70187 .47357 .70233 .47521 .70177 .47429 .70123 Mtetra
.685 .847 .961 r
.47429 .70123 .47521 .70177 .47685 .70121 .47593 .70058 Mtetra
.67 .822 .956 r
.47593 .70058 .47685 .70121 .47849 .70069 .47757 .70001 Mtetra
.645 .801 .957 r
.47757 .70001 .47849 .70069 .48013 .70023 .47921 .69953 Mtetra
.637 .793 .957 r
.47921 .69953 .48013 .70023 .48177 .69978 .48085 .69908 Mtetra
.596 .781 .969 r
.48085 .69908 .48177 .69978 .48341 .69952 .48249 .69875 Mtetra
.586 .76 .961 r
.48249 .69875 .48341 .69952 .48505 .69934 .48413 .69847 Mtetra
.668 .761 .92 r
.48413 .69847 .48505 .69934 .4867 .69874 .48578 .69792 Mtetra
.807 .795 .84 r
.48578 .69792 .4867 .69874 .48836 .69665 .48743 .69651 Mtetra
.94 .868 .74 r
.48743 .69651 .48836 .69665 .49006 .69019 .48911 .69353 Mtetra
0 0 0 r
.48911 .69353 .49006 .69019 .49353 .49624 .4908 .68824 Mtetra
.537 .329 .545 r
.4908 .68824 .49353 .49624 .49512 .49218 .49257 .67406 Mtetra
.012 0 .396 r
.49257 .67406 .49512 .49218 .49668 .49136 .49567 .50755 Mtetra
.926 .656 .508 r
.49567 .50755 .49668 .49136 .49823 .49122 .49583 .67513 Mtetra
.572 .356 .549 r
.49583 .67513 .49823 .49122 .49978 .49121 .49743 .68105 Mtetra
.565 .351 .549 r
.49743 .68105 .49978 .49121 .50134 .49092 .49905 .68284 Mtetra
.56 .347 .548 r
.49905 .68284 .50134 .49092 .50289 .49047 .50071 .68201 Mtetra
0 0 .384 r
.50071 .68201 .50289 .49047 .50445 .48952 .50353 .49932 Mtetra
0 0 .308 r
.50353 .49932 .50445 .48952 .50602 .48811 .50514 .48986 Mtetra
.73 .824 .365 r
.50514 .48986 .50602 .48811 .50758 .48682 .50672 .48635 Mtetra
.873 .853 .82 r
.50672 .48635 .50758 .48682 .50914 .48587 .50829 .48456 Mtetra
.685 .675 .835 r
.50829 .48456 .50914 .48587 .5107 .48533 .50985 .48391 Mtetra
.626 .635 .839 r
.50985 .48391 .5107 .48533 .51227 .48492 .51141 .48358 Mtetra
.605 .637 .856 r
.51141 .48358 .51227 .48492 .51383 .48455 .51297 .48335 Mtetra
.622 .668 .873 r
.51297 .48335 .51383 .48455 .51539 .48415 .51454 .48303 Mtetra
.619 .682 .888 r
.51454 .48303 .51539 .48415 .51695 .48375 .5161 .48273 Mtetra
.63 .707 .902 r
.5161 .48273 .51695 .48375 .51852 .48331 .51767 .48238 Mtetra
.654 .734 .908 r
.51767 .48238 .51852 .48331 .52009 .48281 .51923 .48192 Mtetra
.67 .748 .909 r
.51923 .48192 .52009 .48281 .52165 .48228 .5208 .4814 Mtetra
.689 .756 .903 r
.5208 .4814 .52165 .48228 .52322 .48169 .52237 .48079 Mtetra
.706 .756 .891 r
.52237 .48079 .52322 .48169 .52479 .48106 .52394 .4801 Mtetra
.704 .743 .882 r
.52394 .4801 .52479 .48106 .52636 .48043 .52551 .4794 Mtetra
.705 .731 .871 r
.52551 .4794 .52636 .48043 .52793 .47972 .52708 .47869 Mtetra
.707 .732 .871 r
.52708 .47869 .52793 .47972 .5295 .4789 .52865 .47798 Mtetra
.656 .739 .911 r
.52865 .47798 .5295 .4789 .53107 .47845 .53022 .47751 Mtetra
.434 .643 .945 r
.53022 .47751 .53107 .47845 .53265 .47907 .5318 .47769 Mtetra
0 .14 .685 r
.5318 .47769 .53265 .47907 .53423 .4834 .53338 .47936 Mtetra
.013 .069 .575 r
.53338 .47936 .53423 .4834 .53645 .67733 .53497 .48314 Mtetra
.017 0 .411 r
.53497 .48314 .53645 .67733 .53814 .68181 .53719 .66382 Mtetra
.467 .3 .571 r
.53719 .66382 .53814 .68181 .53982 .68187 .53887 .66841 Mtetra
.624 .426 .594 r
.53887 .66841 .53982 .68187 .5415 .68116 .54054 .66579 Mtetra
.767 .533 .579 r
.54054 .66579 .5415 .68116 .54317 .68023 .54213 .64992 Mtetra
.906 .639 .523 r
.54213 .64992 .54317 .68023 .54485 .67975 .543 .50411 Mtetra
.574 .362 .555 r
.543 .50411 .54485 .67975 .54653 .67927 .54457 .49824 Mtetra
.567 .357 .555 r
.54457 .49824 .54653 .67927 .54821 .67878 .54615 .4958 Mtetra
.564 .355 .554 r
.54615 .4958 .54821 .67878 .54989 .67831 .54774 .49478 Mtetra
.564 .354 .554 r
.54774 .49478 .54989 .67831 .55157 .67784 .54933 .49405 Mtetra
.54933 .49405 .55157 .67784 .55325 .67737 .55092 .49346 Mtetra
.55092 .49346 .55325 .67737 .55494 .67691 .55252 .49289 Mtetra
.563 .354 .554 r
.55252 .49289 .55494 .67691 .55662 .67644 .55412 .49238 Mtetra
.55412 .49238 .55662 .67644 .55831 .67597 .55571 .49191 Mtetra
.55571 .49191 .55831 .67597 .55999 .6755 .55731 .49144 Mtetra
.55731 .49144 .55999 .6755 .56168 .67503 .55891 .491 Mtetra
.55891 .491 .56168 .67503 .56337 .67456 .56051 .49056 Mtetra
.56051 .49056 .56337 .67456 .56506 .67409 .56212 .49014 Mtetra
.56212 .49014 .56506 .67409 .56675 .67362 .56372 .48973 Mtetra
.56372 .48973 .56675 .67362 .56844 .67315 .56533 .48933 Mtetra
.56533 .48933 .56844 .67315 .57014 .67268 .56693 .48894 Mtetra
.56693 .48894 .57014 .67268 .57183 .67221 .56854 .48856 Mtetra
.56854 .48856 .57183 .67221 .57353 .67173 .57015 .48819 Mtetra
.57015 .48819 .57353 .67173 .57522 .67126 .57176 .48782 Mtetra
.57176 .48782 .57522 .67126 .57692 .67079 .57337 .48748 Mtetra
.563 .353 .554 r
.57337 .48748 .57692 .67079 .57862 .67032 .57498 .4872 Mtetra
.57498 .4872 .57862 .67032 .58032 .66984 .57659 .48694 Mtetra
.57659 .48694 .58032 .66984 .58202 .66937 .57821 .48693 Mtetra
.561 .352 .554 r
.57821 .48693 .58202 .66937 .58372 .6689 .57985 .48759 Mtetra
.55 .344 .553 r
.57985 .48759 .58372 .6689 .58542 .66845 .58158 .49392 Mtetra
.117 .016 .453 r
.58158 .49392 .58542 .66845 .58713 .66799 .58576 .63939 Mtetra
.488 .308 .563 r
.58576 .63939 .58713 .66799 .58883 .66758 .58757 .64529 Mtetra
.416 .259 .558 r
.58757 .64529 .58883 .66758 .59055 .66764 .58943 .65348 Mtetra
.568 .383 .59 r
.58943 .65348 .59055 .66764 .59226 .66721 .59114 .65343 Mtetra
.946 .672 .487 r
.59114 .65343 .59226 .66721 .59394 .66562 .58937 .47574 Mtetra
.583 .369 .556 r
.58937 .47574 .59394 .66562 .59544 .6547 .59076 .46372 Mtetra
.569 .358 .555 r
.59076 .46372 .59544 .6547 .59316 .46256 .5923 .45988 Mtetra
.754 .604 .69 r
.5923 .45988 .59316 .46256 .5947 .45873 .59387 .45763 Mtetra
.715 .724 .857 r
.59387 .45763 .5947 .45873 .5963 .45777 .59548 .45683 Mtetra
.648 .736 .913 r
.59548 .45683 .5963 .45777 .59791 .45736 .59709 .45638 Mtetra
.596 .709 .922 r
.59709 .45638 .59791 .45736 .59953 .45723 .59871 .45613 Mtetra
.622 .693 .895 r
.59871 .45613 .59953 .45723 .60115 .45684 .60032 .4558 Mtetra
.62 .704 .905 r
.60032 .4558 .60115 .45684 .60276 .45646 .60194 .45547 Mtetra
.633 .721 .911 r
.60194 .45547 .60276 .45646 .60438 .45605 .60356 .45509 Mtetra
.692 .746 .893 r
.60356 .45509 .60438 .45605 .606 .4555 .60517 .45445 Mtetra
.699 .731 .875 r
.60517 .45445 .606 .4555 .60761 .45491 .60679 .45376 Mtetra
.695 .711 .86 r
.60679 .45376 .60761 .45491 .60922 .45431 .6084 .45306 Mtetra
.71 .7 .839 r
.6084 .45306 .60922 .45431 .61084 .45365 .61001 .45226 Mtetra
.669 .662 .834 r
.61001 .45226 .61084 .45365 .61246 .45309 .61163 .45167 Mtetra
.597 .628 .853 r
.61163 .45167 .61246 .45309 .61408 .45268 .61326 .45147 Mtetra
.05 .351 .826 r
.61326 .45147 .61408 .45268 .61571 .45241 .61492 .4526 Mtetra
.843 .407 .189 r
.61492 .4526 .61571 .45241 .61735 .45259 .61664 .45547 Mtetra
.962 .678 .451 r
.61664 .45547 .61735 .45259 .61902 .45367 .62364 .64352 Mtetra
.578 .361 .55 r
.62364 .64352 .61902 .45367 .62097 .46423 .62568 .654 Mtetra
.566 .352 .549 r
.62568 .654 .62097 .46423 .62829 .65522 .6275 .65667 Mtetra
.654 .253 .272 r
.6275 .65667 .62829 .65522 .63013 .65842 .62928 .65784 Mtetra
.317 .698 .98 r
.62928 .65784 .63013 .65842 .63189 .65865 .63103 .65797 Mtetra
.621 .808 .972 r
.63103 .65797 .63189 .65865 .63362 .65814 .63277 .65752 Mtetra
.763 .856 .92 r
.63277 .65752 .63362 .65814 .63534 .65717 .63449 .65651 Mtetra
.884 .838 .796 r
.63449 .65651 .63534 .65717 .63706 .65638 .63617 .65434 Mtetra
.848 .682 .676 r
.63617 .65434 .63706 .65638 .63878 .65518 .6378 .65055 Mtetra
.885 .643 .568 r
.6378 .65055 .63878 .65518 .64046 .65309 .6391 .63695 Mtetra
.948 .669 .476 r
.6391 .63695 .64046 .65309 .64192 .64445 .63457 .44979 Mtetra
.569 .358 .554 r
.63457 .44979 .64192 .64445 .63699 .44945 .6361 .44606 Mtetra
.719 .561 .675 r
.6361 .44606 .63699 .44945 .6385 .44523 .63768 .44399 Mtetra
.7 .698 .845 r
.63768 .44399 .6385 .44523 .64011 .44412 .63931 .44324 Mtetra
.598 .734 .939 r
.63931 .44324 .64011 .44412 .64175 .44376 .64095 .44296 Mtetra
.509 .719 .967 r
.64095 .44296 .64175 .44376 .64341 .44373 .64261 .44289 Mtetra
.627 .757 .94 r
.64261 .44289 .64341 .44373 .64505 .44333 .64425 .4425 Mtetra
.651 .767 .934 r
.64425 .4425 .64505 .44333 .64669 .44287 .64589 .44202 Mtetra
.659 .767 .929 r
.64589 .44202 .64669 .44287 .64833 .44238 .64753 .44151 Mtetra
.659 .761 .925 r
.64753 .44151 .64833 .44238 .64998 .44188 .64918 .44101 Mtetra
.662 .76 .923 r
.64918 .44101 .64998 .44188 .65162 .44137 .65082 .4405 Mtetra
.665 .761 .922 r
.65082 .4405 .65162 .44137 .65326 .44084 .65246 .43997 Mtetra
.664 .761 .923 r
.65246 .43997 .65326 .44084 .6549 .44029 .65411 .43944 Mtetra
.669 .769 .925 r
.65411 .43944 .6549 .44029 .65655 .43973 .65575 .43889 Mtetra
.679 .775 .924 r
.65575 .43889 .65655 .43973 .65819 .43915 .6574 .43831 Mtetra
.749 .792 .888 r
.6574 .43831 .65819 .43915 .65982 .43818 .65903 .43737 Mtetra
.731 .797 .905 r
.65903 .43737 .65982 .43818 .66145 .4374 .66066 .43654 Mtetra
.651 .763 .931 r
.66066 .43654 .66145 .4374 .66311 .43715 .66231 .43607 Mtetra
.246 .505 .903 r
.66231 .43607 .66311 .43715 .66488 .4393 .66401 .43675 Mtetra
.161 .249 .707 r
.66401 .43675 .66488 .4393 .66729 .45627 .66578 .43885 Mtetra
.38 .239 .561 r
.66578 .43885 .66729 .45627 .67713 .64183 .6678 .44683 Mtetra
.056 0 .442 r
.6678 .44683 .67713 .64183 .67899 .6437 .67794 .63794 Mtetra
.293 .237 .622 r
.67794 .63794 .67899 .6437 .6808 .64411 .67988 .64153 Mtetra
.307 .354 .748 r
.67988 .64153 .6808 .64411 .68258 .64399 .68174 .64306 Mtetra
.372 .631 .954 r
.68174 .64306 .68258 .64399 .68436 .64397 .68354 .64335 Mtetra
.584 .813 .987 r
.68354 .64335 .68436 .64397 .68614 .64365 .68531 .64297 Mtetra
.742 .843 .926 r
.68531 .64297 .68614 .64365 .68788 .64273 .68706 .64205 Mtetra
.859 .847 .831 r
.68706 .64205 .68788 .64273 .68953 .63961 .68876 .64024 Mtetra
.909 .956 .621 r
.68876 .64024 .68953 .63961 .69086 .63013 .69041 .63719 Mtetra
.099 0 .352 r
.69041 .63719 .69086 .63013 .68317 .4349 .69189 .63066 Mtetra
.056 0 .437 r
.69189 .63066 .68317 .4349 .6847 .4318 .68418 .43629 Mtetra
0 0 .246 r
.68418 .43629 .6847 .4318 .68632 .43039 .68562 .43114 Mtetra
.791 .926 .553 r
.68562 .43114 .68632 .43039 .68797 .42953 .68718 .42862 Mtetra
.758 .782 .873 r
.68718 .42862 .68797 .42953 .68963 .42895 .68882 .4276 Mtetra
.628 .656 .858 r
.68882 .4276 .68963 .42895 .6913 .42855 .6905 .42724 Mtetra
.57 .636 .877 r
.6905 .42724 .6913 .42855 .69298 .42824 .69219 .42714 Mtetra
.62 .698 .9 r
.69219 .42714 .69298 .42824 .69465 .42778 .69386 .4268 Mtetra
.659 .739 .909 r
.69386 .4268 .69465 .42778 .69632 .42723 .69553 .42629 Mtetra
.675 .754 .911 r
.69553 .42629 .69632 .42723 .69798 .42664 .6972 .42572 Mtetra
.736 .776 .885 r
.6972 .42572 .69798 .42664 .69963 .4257 .69885 .42483 Mtetra
.734 .788 .895 r
.69885 .42483 .69963 .4257 .70128 .42485 .70051 .42397 Mtetra
.666 .764 .923 r
.70051 .42397 .70128 .42485 .70296 .4245 .70218 .42343 Mtetra
.348 .568 .921 r
.70218 .42343 .70296 .4245 .70476 .42616 .70391 .42389 Mtetra
.186 .29 .738 r
.70391 .42389 .70476 .42616 .70694 .43465 .70571 .42572 Mtetra
.29 .202 .58 r
.70571 .42572 .70694 .43465 .71962 .62914 .70774 .43145 Mtetra
.078 0 .454 r
.70774 .43145 .71962 .62914 .72157 .63159 .72043 .62496 Mtetra
.293 .228 .61 r
.72043 .62496 .72157 .63159 .72342 .63209 .72248 .62919 Mtetra
.321 .343 .729 r
.72248 .62919 .72342 .63209 .72523 .63199 .7244 .63088 Mtetra
.412 .61 .931 r
.7244 .63088 .72523 .63199 .72705 .63186 .72624 .6312 Mtetra
.624 .819 .976 r
.72624 .6312 .72705 .63186 .72885 .6315 .72804 .63071 Mtetra
.76 .826 .903 r
.72804 .63071 .72885 .6315 .73061 .63055 .7298 .62967 Mtetra
.843 .815 .822 r
.7298 .62967 .73061 .63055 .73227 .62767 .73152 .62789 Mtetra
.948 .958 .698 r
.73152 .62789 .73227 .62767 .73356 .61884 .73317 .62498 Mtetra
.086 0 .338 r
.73317 .62498 .73356 .61884 .72337 .42257 .73463 .619 Mtetra
.078 0 .449 r
.73463 .619 .72337 .42257 .72488 .4191 .72448 .42426 Mtetra
.015 0 .299 r
.72448 .42426 .72488 .4191 .72651 .41763 .72586 .41866 Mtetra
.658 .823 .396 r
.72586 .41866 .72651 .41763 .72817 .41673 .72741 .41598 Mtetra
.796 .829 .877 r
.72741 .41598 .72817 .41673 .72985 .41612 .72906 .41477 Mtetra
.64 .664 .857 r
.72906 .41477 .72985 .41612 .73155 .41567 .73076 .41434 Mtetra
.581 .639 .873 r
.73076 .41434 .73155 .41567 .73325 .41534 .73247 .41419 Mtetra
.647 .701 .886 r
.73247 .41419 .73325 .41534 .73493 .41467 .73417 .41373 Mtetra
.691 .762 .906 r
.73417 .41373 .73493 .41467 .73661 .41391 .73585 .41307 Mtetra
.626 .762 .944 r
.73585 .41307 .73661 .41391 .73832 .4136 .73755 .41267 Mtetra
.319 .585 .939 r
.73755 .41267 .73832 .4136 .74015 .4151 .73931 .41311 Mtetra
.125 .277 .749 r
.73931 .41311 .74015 .4151 .74245 .42359 .74117 .41494 Mtetra
.272 .193 .581 r
.74117 .41494 .74245 .42359 .75736 .61859 .7433 .42088 Mtetra
.092 .012 .463 r
.7433 .42088 .75736 .61859 .75941 .62164 .75825 .61544 Mtetra
.281 .227 .617 r
.75825 .61544 .75941 .62164 .76131 .62244 .76038 .61962 Mtetra
.395 .397 .743 r
.76038 .61962 .76131 .62244 .76314 .62211 .76231 .62087 Mtetra
.815 .754 .795 r
.76231 .62087 .76314 .62211 .76481 .61954 .76404 .61908 Mtetra
.984 .775 .544 r
.76404 .61908 .76481 .61954 .76596 .60958 .76531 .61079 Mtetra
.978 .687 .395 r
.76531 .61079 .76596 .60958 .75379 .41146 .75305 .41076 Mtetra
.94 .82 .7 r
.75305 .41076 .75379 .41146 .75531 .40837 .75455 .40742 Mtetra
.715 .768 .894 r
.75455 .40742 .75531 .40837 .757 .40759 .75624 .40663 Mtetra
.583 .715 .934 r
.75624 .40663 .757 .40759 .75872 .40736 .75797 .4064 Mtetra
.641 .74 .92 r
.75797 .4064 .75872 .40736 .76043 .40683 .75968 .40595 Mtetra
.713 .784 .908 r
.75968 .40595 .76043 .40683 .76211 .40598 .76137 .40518 Mtetra
.648 .784 .947 r
.76137 .40518 .76211 .40598 .76383 .40557 .76308 .40468 Mtetra
.397 .644 .956 r
.76308 .40468 .76383 .40557 .76567 .40671 .76485 .40492 Mtetra
.195 .347 .79 r
.76485 .40492 .76567 .40671 .76788 .41291 .76671 .40638 Mtetra
.321 .246 .614 r
.76671 .40638 .76788 .41291 .78453 .6098 .76876 .41034 Mtetra
.113 .028 .472 r
.76876 .41034 .78453 .6098 .78664 .61302 .78522 .60374 Mtetra
.312 .222 .59 r
.78522 .60374 .78664 .61302 .78855 .61354 .78752 .60953 Mtetra
.363 .327 .684 r
.78752 .60953 .78855 .61354 .79041 .61343 .78956 .61163 Mtetra
.377 .475 .833 r
.78956 .61163 .79041 .61343 .79228 .61332 .79149 .61246 Mtetra
.483 .711 .971 r
.79149 .61246 .79228 .61332 .79414 .61322 .79337 .61245 Mtetra
.714 .826 .934 r
.79337 .61245 .79414 .61322 .79596 .61249 .79518 .61163 Mtetra
.91 .82 .746 r
.79518 .61163 .79596 .61249 .79762 .60979 .79683 .60882 Mtetra
.978 .733 .496 r
.79683 .60882 .79762 .60979 .79847 .59695 .79766 .59565 Mtetra
.977 .682 .387 r
.79766 .59565 .79847 .59695 .78459 .40138 .78384 .40033 Mtetra
.906 .782 .713 r
.78384 .40033 .78459 .40138 .78611 .3983 .78536 .39727 Mtetra
.706 .751 .887 r
.78536 .39727 .78611 .3983 .78781 .39753 .78706 .39651 Mtetra
.583 .704 .926 r
.78706 .39651 .78781 .39753 .78956 .3973 .78881 .39629 Mtetra
.61 .718 .922 r
.78881 .39629 .78956 .3973 .7913 .3969 .79056 .39596 Mtetra
.706 .772 .904 r
.79056 .39596 .7913 .3969 .793 .39605 .79227 .39522 Mtetra
.653 .78 .941 r
.79227 .39522 .793 .39605 .79473 .39558 .794 .3947 Mtetra
.456 .676 .959 r
.794 .3947 .79473 .39558 .79657 .39639 .79578 .3948 Mtetra
.223 .392 .821 r
.79578 .3948 .79657 .39639 .79875 .4011 .79766 .39603 Mtetra
.329 .273 .643 r
.79766 .39603 .79875 .4011 .81745 .59905 .7997 .39909 Mtetra
.134 .046 .482 r
.7997 .39909 .81745 .59905 .8197 .60323 .81789 .59018 Mtetra
.289 .192 .567 r
.81789 .59018 .8197 .60323 .82165 .60382 .82054 .59906 Mtetra
.369 .313 .663 r
.82054 .59906 .82165 .60382 .82353 .60368 .82265 .60154 Mtetra
.443 .478 .801 r
.82265 .60154 .82353 .60368 .82539 .6032 .82461 .60225 Mtetra
.633 .758 .938 r
.82461 .60225 .82539 .6032 .82724 .60262 .82647 .60179 Mtetra
.712 .815 .929 r
.82647 .60179 .82724 .60262 .82908 .60191 .8283 .60097 Mtetra
.705 .788 .916 r
.8283 .60097 .82908 .60191 .83092 .60122 .83014 .60019 Mtetra
.628 .738 .926 r
.83014 .60019 .83092 .60122 .83277 .60067 .83201 .59976 Mtetra
.617 .76 .947 r
.83201 .59976 .83277 .60067 .83463 .60016 .83388 .59935 Mtetra
.625 .789 .96 r
.83388 .59935 .83463 .60016 .8365 .59967 .83574 .59888 Mtetra
.652 .805 .957 r
.83574 .59888 .8365 .59967 .83836 .59919 .8376 .5983 Mtetra
.657 .784 .942 r
.8376 .5983 .83836 .59919 .84023 .59873 .83946 .59773 Mtetra
.593 .73 .94 r
.83946 .59773 .84023 .59873 .84212 .59849 .84134 .59743 Mtetra
.485 .662 .94 r
.84134 .59743 .84212 .59849 .84404 .59856 .84326 .59751 Mtetra
.633 .738 .924 r
.84326 .59751 .84404 .59856 .84591 .59807 .84514 .59706 Mtetra
.863 .807 .794 r
.84514 .59706 .84591 .59807 .84763 .59594 .84686 .59495 Mtetra
.981 .743 .505 r
.84686 .59495 .84763 .59594 .84852 .58512 .84774 .58407 Mtetra
.977 .678 .362 r
.84774 .58407 .84852 .58512 .8315 .38695 .83077 .38593 Mtetra
.929 .789 .685 r
.83077 .38593 .8315 .38695 .83296 .38339 .83223 .38237 Mtetra
.721 .763 .886 r
.83223 .38237 .83296 .38339 .83468 .38254 .83396 .38152 Mtetra
.595 .712 .926 r
.83396 .38152 .83468 .38254 .83646 .38227 .83573 .38125 Mtetra
.595 .712 .925 r
.83573 .38125 .83646 .38227 .83824 .38201 .83751 .38098 Mtetra
.736 .766 .877 r
.83751 .38098 .83824 .38201 .83996 .38109 .83923 .38004 Mtetra
.65 .731 .908 r
.83923 .38004 .83996 .38109 .84172 .3806 .84099 .37955 Mtetra
.198 .479 .894 r
.84099 .37955 .84172 .3806 .84361 .38143 .84289 .38039 Mtetra
.912 .536 .104 r
.84289 .38039 .84361 .38143 .84626 .38977 .8456 .38937 Mtetra
.975 .666 .337 r
.8456 .38937 .84626 .38977 .86811 .58886 .86738 .58818 Mtetra
.687 .198 0 r
.86738 .58818 .86811 .58886 .87035 .59193 .86962 .59119 Mtetra
.474 .741 .987 r
.86962 .59119 .87035 .59193 .87228 .59181 .87155 .59112 Mtetra
.733 .86 .941 r
.87155 .59112 .87228 .59181 .87413 .59096 .8734 .59019 Mtetra
.85 .86 .849 r
.8734 .59019 .87413 .59096 .87595 .58978 .87516 .58848 Mtetra
.874 .768 .742 r
.87516 .58848 .87595 .58978 .8778 .58894 .87683 .58579 Mtetra
.841 .642 .634 r
.87683 .58579 .8778 .58894 .87961 .5876 .87826 .58083 Mtetra
.974 .671 .366 r
.87826 .58083 .87961 .5876 .88126 .58484 .8598 .38543 Mtetra
.575 .362 .554 r
.8598 .38543 .88126 .58484 .88092 .56307 .86081 .37759 Mtetra
.568 .357 .554 r
.86081 .37759 .88092 .56307 .86319 .37709 .86231 .37448 Mtetra
.738 .603 .708 r
.86231 .37448 .86319 .37709 .86466 .37368 .86394 .37263 Mtetra
.745 .767 .871 r
.86394 .37263 .86466 .37368 .86637 .37265 .86566 .37163 Mtetra
.648 .738 .915 r
.86566 .37163 .86637 .37265 .86816 .3722 .86744 .37114 Mtetra
.487 .651 .932 r
.86744 .37114 .86816 .3722 .86997 .37205 .86929 .37124 Mtetra
0 .32 .795 r
.86929 .37124 .86997 .37205 .87177 .37169 .87125 .37248 Mtetra
.816 .374 .188 r
.87125 .37248 .87177 .37169 .87361 .37178 .87344 .37565 Mtetra
.972 .66 .338 r
.87344 .37565 .87361 .37178 .87558 .37301 .89643 .56876 Mtetra
.574 .357 .548 r
.89643 .56876 .87558 .37301 .87876 .38514 .89932 .57721 Mtetra
.565 .351 .548 r
.89932 .57721 .87876 .38514 .90208 .57871 .90155 .57968 Mtetra
.612 .137 .103 r
.90155 .57968 .90208 .57871 .90436 .58164 .90363 .58067 Mtetra
.5 .697 .957 r
.90363 .58067 .90436 .58164 .90633 .58168 .90559 .58066 Mtetra
.662 .76 .923 r
.90559 .58066 .90633 .58168 .90823 .58103 .90749 .58006 Mtetra
.78 .81 .877 r
.90749 .58006 .90823 .58103 .91008 .58 .90932 .57881 Mtetra
.88 .788 .756 r
.90932 .57881 .91008 .58 .91196 .57925 .911 .57625 Mtetra
.843 .649 .639 r
.911 .57625 .91196 .57925 .91379 .578 .91243 .57154 Mtetra
.975 .668 .348 r
.91243 .57154 .91379 .578 .91549 .5756 .89204 .37666 Mtetra
.576 .363 .554 r
.89204 .37666 .91549 .5756 .916 .56293 .89288 .36787 Mtetra
.568 .357 .554 r
.89288 .36787 .916 .56293 .89528 .36755 .89436 .36465 Mtetra
.728 .587 .697 r
.89436 .36465 .89528 .36755 .8967 .36378 .896 .36276 Mtetra
.699 .761 .9 r
.896 .36276 .8967 .36378 .89844 .36284 .89777 .36202 Mtetra
.611 .775 .959 r
.89777 .36202 .89844 .36284 .90025 .36247 .89958 .36163 Mtetra
.568 .748 .962 r
.89958 .36163 .90025 .36247 .9021 .36237 .90141 .36138 Mtetra
.655 .75 .92 r
.90141 .36138 .9021 .36237 .9039 .36186 .90321 .36085 Mtetra
.667 .751 .913 r
.90321 .36085 .9039 .36186 .9057 .36131 .905 .36026 Mtetra
.684 .75 .901 r
.905 .36026 .9057 .36131 .90748 .3607 .90678 .3596 Mtetra
.755 .765 .861 r
.90678 .3596 .90748 .3607 .90925 .35986 .90852 .35851 Mtetra
.709 .704 .843 r
.90852 .35851 .90925 .35986 .91102 .35909 .91028 .35763 Mtetra
.637 .656 .852 r
.91028 .35763 .91102 .35909 .91281 .35848 .91209 .35719 Mtetra
.218 .441 .862 r
.91209 .35719 .91281 .35848 .91463 .3581 .91409 .35825 Mtetra
.791 .294 0 r
.91409 .35825 .91463 .3581 .91652 .35819 .91631 .3611 Mtetra
.971 .654 .308 r
.91631 .3611 .91652 .35819 .91851 .35921 .94196 .55352 Mtetra
.582 .339 .514 r
.32216 .73973 .32388 .72736 .32481 .73783 .32363 .7407 Mtetra
.54 .218 .37 r
.32363 .7407 .32481 .73783 .32619 .74045 .32515 .74082 Mtetra
0 0 0 r
.32515 .74082 .32619 .74045 .32765 .74158 .32669 .7405 Mtetra
.64 .699 .888 r
.32669 .7405 .32765 .74158 .32919 .74133 .32824 .74011 Mtetra
.664 .682 .857 r
.32824 .74011 .32919 .74133 .33076 .74069 .3298 .7396 Mtetra
.674 .708 .873 r
.3298 .7396 .33076 .74069 .33233 .73989 .33136 .73904 Mtetra
.417 .668 .965 r
.33136 .73904 .33233 .73989 .33385 .74009 .33288 .73918 Mtetra
.579 .718 .937 r
.33288 .73918 .33385 .74009 .33539 .73996 .33442 .73898 Mtetra
.738 .743 .856 r
.33442 .73898 .33539 .73996 .33697 .7391 .33601 .73806 Mtetra
.896 .725 .661 r
.33601 .73806 .33697 .7391 .33878 .73385 .33781 .73292 Mtetra
.938 .686 .532 r
.33781 .73292 .33878 .73385 .35037 .54002 .34943 .53963 Mtetra
.931 .754 .64 r
.34943 .53963 .35037 .54002 .35212 .53424 .35119 .53371 Mtetra
.803 .833 .874 r
.35119 .53371 .35212 .53424 .35362 .53316 .3527 .53256 Mtetra
.603 .793 .972 r
.3527 .53256 .35362 .53316 .35509 .53293 .35417 .53224 Mtetra
.43 .704 .979 r
.35417 .53224 .35509 .53293 .35653 .53309 .35562 .53229 Mtetra
.649 .752 .924 r
.35562 .53229 .35653 .53309 .358 .53274 .35709 .53187 Mtetra
.671 .742 .904 r
.35709 .53187 .358 .53274 .35948 .53227 .35857 .53138 Mtetra
.677 .737 .896 r
.35857 .53138 .35948 .53227 .36096 .53175 .36005 .53085 Mtetra
.758 .752 .847 r
.36005 .53085 .36096 .53175 .36247 .53067 .36155 .52986 Mtetra
.72 .765 .888 r
.36155 .52986 .36247 .53067 .36396 .52987 .36305 .52914 Mtetra
.519 .73 .969 r
.36305 .52914 .36396 .52987 .36542 .52972 .36451 .52905 Mtetra
.909 .509 .219 r
.36451 .52905 .36542 .52972 .36672 .5332 .36581 .53246 Mtetra
.941 .683 .519 r
.36581 .53246 .36672 .5332 .35917 .72615 .35823 .72482 Mtetra
.952 .606 .305 r
.35823 .72482 .35917 .72615 .36044 .73209 .35949 .73093 Mtetra
.276 .517 .904 r
.35949 .73093 .36044 .73209 .36197 .73257 .36102 .7315 Mtetra
.663 .711 .884 r
.36102 .7315 .36197 .73257 .36355 .73195 .36259 .731 Mtetra
.74 .75 .86 r
.36259 .731 .36355 .73195 .36515 .73092 .36419 .73008 Mtetra
.498 .704 .962 r
.36419 .73008 .36515 .73092 .3667 .73094 .36574 .73005 Mtetra
.563 .718 .945 r
.36574 .73005 .3667 .73094 .36826 .73086 .36731 .72989 Mtetra
.725 .746 .869 r
.36731 .72989 .36826 .73086 .36985 .7301 .3689 .72907 Mtetra
.891 .732 .679 r
.3689 .72907 .36985 .7301 .3716 .72572 .37064 .72475 Mtetra
.941 .687 .525 r
.37064 .72475 .3716 .72572 .38144 .5319 .38051 .53161 Mtetra
.941 .75 .616 r
.38051 .53161 .38144 .5319 .38321 .52484 .3823 .52431 Mtetra
.839 .828 .836 r
.3823 .52431 .38321 .52484 .38475 .52342 .38383 .52282 Mtetra
.619 .798 .968 r
.38383 .52282 .38475 .52342 .38623 .52315 .38532 .52245 Mtetra
.428 .701 .978 r
.38532 .52245 .38623 .52315 .38769 .52333 .38679 .52251 Mtetra
.613 .739 .935 r
.38679 .52251 .38769 .52333 .38918 .52311 .38828 .52221 Mtetra
.659 .733 .904 r
.38828 .52221 .38918 .52311 .39067 .5227 .38977 .52175 Mtetra
.667 .726 .894 r
.38977 .52175 .39067 .5227 .39216 .52221 .39127 .52126 Mtetra
.68 .729 .887 r
.39127 .52126 .39216 .52221 .39367 .5216 .39277 .52071 Mtetra
.688 .744 .894 r
.39277 .52071 .39367 .5216 .39517 .52093 .39427 .52013 Mtetra
.69 .766 .91 r
.39427 .52013 .39517 .52093 .39668 .52026 .39577 .51955 Mtetra
.681 .785 .928 r
.39577 .51955 .39668 .52026 .39818 .51969 .39727 .519 Mtetra
.674 .79 .936 r
.39727 .519 .39818 .51969 .39968 .51917 .39878 .51848 Mtetra
.67 .789 .937 r
.39878 .51848 .39968 .51917 .40118 .51867 .40028 .51797 Mtetra
.668 .786 .937 r
.40028 .51797 .40118 .51867 .40268 .51815 .40178 .51746 Mtetra
.664 .788 .941 r
.40178 .51746 .40268 .51815 .40418 .51764 .40328 .51698 Mtetra
.657 .792 .947 r
.40328 .51698 .40418 .51764 .40569 .51717 .40478 .51651 Mtetra
.64 .79 .954 r
.40478 .51651 .40569 .51717 .40719 .51681 .40629 .51609 Mtetra
.637 .773 .945 r
.40629 .51609 .40719 .51681 .40868 .5165 .40779 .51569 Mtetra
.644 .753 .928 r
.40779 .51569 .40868 .5165 .41018 .51616 .40929 .51528 Mtetra
.665 .743 .908 r
.40929 .51528 .41018 .51616 .41169 .51563 .4108 .5148 Mtetra
.676 .757 .912 r
.4108 .5148 .41169 .51563 .4132 .51499 .41231 .51427 Mtetra
.677 .785 .931 r
.41231 .51427 .4132 .51499 .41472 .51433 .41382 .51374 Mtetra
.661 .812 .956 r
.41382 .51374 .41472 .51433 .41623 .51378 .41533 .51324 Mtetra
.648 .826 .969 r
.41533 .51324 .41623 .51378 .41774 .51328 .41684 .51276 Mtetra
.643 .832 .973 r
.41684 .51276 .41774 .51328 .41925 .51281 .41835 .5123 Mtetra
.667 .838 .965 r
.41835 .5123 .41925 .51281 .42076 .51217 .41986 .51176 Mtetra
.653 .864 .979 r
.41986 .51176 .42076 .51217 .42228 .51157 .42137 .51123 Mtetra
.596 .869 .993 r
.42137 .51123 .42228 .51157 .42379 .51126 .42288 .51079 Mtetra
.432 .775 .997 r
.42288 .51079 .42379 .51126 .42526 .51202 .42439 .5107 Mtetra
.497 .589 .877 r
.42439 .5107 .42526 .51202 .4267 .51427 .42588 .51087 Mtetra
.547 .45 .696 r
.42588 .51087 .4267 .51427 .42803 .52016 .42738 .5111 Mtetra
.573 .399 .607 r
.42738 .5111 .42803 .52016 .42443 .69923 .42889 .51097 Mtetra
.563 .353 .554 r
.42889 .51097 .42443 .69923 .426 .69984 .4304 .51048 Mtetra
.564 .354 .554 r
.4304 .51048 .426 .69984 .42774 .69428 .43193 .50987 Mtetra
.563 .354 .554 r
.43193 .50987 .42774 .69428 .43376 .53125 .43345 .5093 Mtetra
.573 .375 .575 r
.43345 .5093 .43376 .53125 .43538 .52753 .43497 .50877 Mtetra
.575 .379 .579 r
.43497 .50877 .43538 .52753 .43695 .52524 .43649 .50825 Mtetra
.582 .387 .583 r
.43649 .50825 .43695 .52524 .43861 .51982 .43803 .5074 Mtetra
.588 .399 .594 r
.43803 .5074 .43861 .51982 .44019 .51726 .43956 .5066 Mtetra
.572 .392 .599 r
.43956 .5066 .44019 .51726 .44168 .51851 .44107 .50644 Mtetra
.473 .313 .582 r
.44107 .50644 .44168 .51851 .43872 .70148 .44252 .50927 Mtetra
0 0 .344 r
.44252 .50927 .43872 .70148 .44019 .70691 .43937 .70149 Mtetra
0 0 .422 r
.43937 .70149 .44019 .70691 .44174 .70921 .44083 .70759 Mtetra
.115 .333 .802 r
.44083 .70759 .44174 .70921 .44334 .70975 .4424 .70881 Mtetra
.611 .726 .928 r
.4424 .70881 .44334 .70975 .44496 .70938 .44402 .7085 Mtetra
.714 .768 .895 r
.44402 .7085 .44496 .70938 .44658 .70873 .44565 .70775 Mtetra
.694 .744 .89 r
.44565 .70775 .44658 .70873 .44821 .70814 .44728 .70709 Mtetra
.653 .718 .896 r
.44728 .70709 .44821 .70814 .44983 .70767 .4489 .70662 Mtetra
.4489 .70662 .44983 .70767 .45145 .70721 .45053 .70616 Mtetra
.651 .715 .895 r
.45053 .70616 .45145 .70721 .45308 .70676 .45215 .7057 Mtetra
.648 .714 .896 r
.45215 .7057 .45308 .70676 .45471 .70631 .45378 .70525 Mtetra
.644 .713 .898 r
.45378 .70525 .45471 .70631 .45633 .70589 .4554 .70482 Mtetra
.635 .707 .898 r
.4554 .70482 .45633 .70589 .45796 .70557 .45703 .70443 Mtetra
.628 .693 .891 r
.45703 .70443 .45796 .70557 .45958 .70531 .45866 .70407 Mtetra
.63 .676 .875 r
.45866 .70407 .45958 .70531 .46121 .70504 .46029 .70371 Mtetra
.637 .664 .859 r
.46029 .70371 .46121 .70504 .46284 .7047 .46192 .70332 Mtetra
.644 .659 .849 r
.46192 .70332 .46284 .7047 .46447 .70427 .46355 .70288 Mtetra
.647 .658 .846 r
.46355 .70288 .46447 .70427 .4661 .70382 .46518 .70242 Mtetra
.648 .658 .846 r
.46518 .70242 .4661 .70382 .46774 .70336 .46682 .70196 Mtetra
.649 .657 .844 r
.46682 .70196 .46774 .70336 .46937 .70291 .46845 .70149 Mtetra
.652 .656 .841 r
.46845 .70149 .46937 .70291 .47101 .70243 .47009 .701 Mtetra
.658 .658 .838 r
.47009 .701 .47101 .70243 .47265 .70187 .47173 .70047 Mtetra
.665 .665 .84 r
.47173 .70047 .47265 .70187 .47429 .70123 .47337 .69991 Mtetra
.667 .677 .85 r
.47337 .69991 .47429 .70123 .47593 .70058 .47501 .69934 Mtetra
.663 .689 .864 r
.47501 .69934 .47593 .70058 .47757 .70001 .47665 .69881 Mtetra
.655 .693 .873 r
.47665 .69881 .47757 .70001 .47921 .69953 .47829 .69833 Mtetra
.651 .691 .874 r
.47829 .69833 .47921 .69953 .48085 .69908 .47993 .69786 Mtetra
.641 .684 .875 r
.47993 .69786 .48085 .69908 .48249 .69875 .48158 .69744 Mtetra
.635 .667 .864 r
.48158 .69744 .48249 .69875 .48413 .69847 .48322 .69705 Mtetra
.649 .657 .844 r
.48322 .69705 .48413 .69847 .48578 .69792 .48486 .69658 Mtetra
.696 .684 .835 r
.48486 .69658 .48578 .69792 .48743 .69651 .48651 .69582 Mtetra
.78 .822 .885 r
.48651 .69582 .48743 .69651 .48911 .69353 .48817 .69471 Mtetra
0 0 0 r
.48817 .69471 .48911 .69353 .4908 .68824 .48982 .6935 Mtetra
.477 .208 .426 r
.48982 .6935 .4908 .68824 .49257 .67406 .49147 .69255 Mtetra
.549 .319 .52 r
.49147 .69255 .49257 .67406 .49567 .50755 .49312 .69207 Mtetra
.561 .348 .548 r
.49312 .69207 .49567 .50755 .49583 .67513 .49477 .69173 Mtetra
.555 .322 .517 r
.49477 .69173 .49583 .67513 .49743 .68105 .49642 .69164 Mtetra
.554 .309 .498 r
.49642 .69164 .49743 .68105 .49905 .68284 .49807 .69163 Mtetra
.528 .28 .482 r
.49807 .69163 .49905 .68284 .50071 .68201 .49972 .69102 Mtetra
.431 .199 .46 r
.49972 .69102 .50071 .68201 .50353 .49932 .50139 .68828 Mtetra
0 0 .362 r
.50139 .68828 .50353 .49932 .50514 .48986 .50423 .49774 Mtetra
0 0 .082 r
.50423 .49774 .50514 .48986 .50672 .48635 .50586 .48651 Mtetra
.954 .919 .737 r
.50586 .48651 .50672 .48635 .50829 .48456 .50743 .48378 Mtetra
.72 .786 .904 r
.50743 .48378 .50829 .48456 .50985 .48391 .50899 .48304 Mtetra
.598 .73 .937 r
.50899 .48304 .50985 .48391 .51141 .48358 .51056 .48277 Mtetra
.558 .732 .957 r
.51056 .48277 .51141 .48358 .51297 .48335 .51212 .4826 Mtetra
.631 .773 .949 r
.51212 .4826 .51297 .48335 .51454 .48303 .51368 .48221 Mtetra
.633 .753 .934 r
.51368 .48221 .51454 .48303 .5161 .48273 .51525 .48182 Mtetra
.642 .736 .917 r
.51525 .48182 .5161 .48273 .51767 .48238 .51681 .48141 Mtetra
.655 .728 .903 r
.51681 .48141 .51767 .48238 .51923 .48192 .51838 .48095 Mtetra
.662 .73 .9 r
.51838 .48095 .51923 .48192 .5208 .4814 .51995 .48046 Mtetra
.672 .74 .902 r
.51995 .48046 .5208 .4814 .52237 .48079 .52152 .47993 Mtetra
.683 .76 .91 r
.52152 .47993 .52237 .48079 .52394 .4801 .52309 .47935 Mtetra
.685 .788 .928 r
.52309 .47935 .52394 .4801 .52551 .4794 .52466 .47876 Mtetra
.684 .815 .946 r
.52466 .47876 .52551 .4794 .52708 .47869 .52623 .47817 Mtetra
.676 .846 .964 r
.52623 .47817 .52708 .47869 .52865 .47798 .5278 .47758 Mtetra
.625 .869 .988 r
.5278 .47758 .52865 .47798 .53022 .47751 .52937 .47708 Mtetra
.529 .827 .999 r
.52937 .47708 .53022 .47751 .5318 .47769 .53095 .47679 Mtetra
.463 .668 .952 r
.53095 .47679 .5318 .47769 .53338 .47936 .53253 .47688 Mtetra
.541 .491 .75 r
.53253 .47688 .53338 .47936 .53497 .48314 .5341 .47709 Mtetra
.566 .415 .636 r
.5341 .47709 .53497 .48314 .53719 .66382 .53568 .47716 Mtetra
.563 .353 .554 r
.53568 .47716 .53719 .66382 .53887 .66841 .53726 .47674 Mtetra
.53726 .47674 .53887 .66841 .54054 .66579 .53884 .47615 Mtetra
.563 .354 .554 r
.53884 .47615 .54054 .66579 .54213 .64992 .54042 .47554 Mtetra
.54042 .47554 .54213 .64992 .543 .50411 .542 .47502 Mtetra
.57 .369 .57 r
.542 .47502 .543 .50411 .54457 .49824 .54359 .4745 Mtetra
.572 .373 .574 r
.54359 .4745 .54457 .49824 .54615 .4958 .54517 .47399 Mtetra
.573 .375 .576 r
.54517 .47399 .54615 .4958 .54774 .49478 .54675 .47349 Mtetra
.573 .376 .576 r
.54675 .47349 .54774 .49478 .54933 .49405 .54834 .47298 Mtetra
.54834 .47298 .54933 .49405 .55092 .49346 .54992 .47248 Mtetra
.573 .376 .577 r
.54992 .47248 .55092 .49346 .55252 .49289 .55151 .47198 Mtetra
.55151 .47198 .55252 .49289 .55412 .49238 .5531 .47147 Mtetra
.5531 .47147 .55412 .49238 .55571 .49191 .55469 .47097 Mtetra
.55469 .47097 .55571 .49191 .55731 .49144 .55628 .47047 Mtetra
.55628 .47047 .55731 .49144 .55891 .491 .55787 .46997 Mtetra
.55787 .46997 .55891 .491 .56051 .49056 .55946 .46946 Mtetra
.573 .376 .576 r
.55946 .46946 .56051 .49056 .56212 .49014 .56105 .46896 Mtetra
.56105 .46896 .56212 .49014 .56372 .48973 .56265 .46846 Mtetra
.56265 .46846 .56372 .48973 .56533 .48933 .56424 .46796 Mtetra
.56424 .46796 .56533 .48933 .56693 .48894 .56583 .46746 Mtetra
.56583 .46746 .56693 .48894 .56854 .48856 .56743 .46696 Mtetra
.572 .376 .576 r
.56743 .46696 .56854 .48856 .57015 .48819 .56903 .46645 Mtetra
.572 .375 .576 r
.56903 .46645 .57015 .48819 .57176 .48782 .57063 .46595 Mtetra
.57063 .46595 .57176 .48782 .57337 .48748 .57222 .46545 Mtetra
.572 .375 .575 r
.57222 .46545 .57337 .48748 .57498 .4872 .57382 .46495 Mtetra
.57382 .46495 .57498 .4872 .57659 .48694 .57543 .46444 Mtetra
.57543 .46444 .57659 .48694 .57821 .48693 .57703 .46394 Mtetra
.572 .374 .574 r
.57703 .46394 .57821 .48693 .57985 .48759 .57863 .46345 Mtetra
.571 .373 .573 r
.57863 .46345 .57985 .48759 .58158 .49392 .58023 .46295 Mtetra
.569 .368 .568 r
.58023 .46295 .58158 .49392 .58576 .63939 .58184 .46246 Mtetra
.563 .354 .554 r
.58184 .46246 .58576 .63939 .58757 .64529 .58344 .46198 Mtetra
.563 .353 .554 r
.58344 .46198 .58757 .64529 .58943 .65348 .58505 .46161 Mtetra
.58505 .46161 .58943 .65348 .59114 .65343 .58666 .46115 Mtetra
.564 .354 .554 r
.58666 .46115 .59114 .65343 .58937 .47574 .58827 .46046 Mtetra
.591 .397 .587 r
.58827 .46046 .58937 .47574 .59076 .46372 .58986 .45923 Mtetra
.647 .492 .659 r
.58986 .45923 .59076 .46372 .5923 .45988 .59146 .45804 Mtetra
.708 .629 .767 r
.59146 .45804 .5923 .45988 .59387 .45763 .59306 .457 Mtetra
.68 .826 .953 r
.59306 .457 .59387 .45763 .59548 .45683 .59466 .4564 Mtetra
.612 .864 .991 r
.59466 .4564 .59548 .45683 .59709 .45638 .59628 .45592 Mtetra
.59 .847 .993 r
.59628 .45592 .59709 .45638 .59871 .45613 .59789 .45551 Mtetra
.628 .812 .971 r
.59789 .45551 .59871 .45613 .60032 .4558 .59951 .45507 Mtetra
.639 .786 .952 r
.59951 .45507 .60032 .4558 .60194 .45547 .60112 .45463 Mtetra
.653 .76 .928 r
.60112 .45463 .60194 .45547 .60356 .45509 .60274 .45415 Mtetra
.682 .748 .901 r
.60274 .45415 .60356 .45509 .60517 .45445 .60435 .45356 Mtetra
.687 .76 .908 r
.60435 .45356 .60517 .45445 .60679 .45376 .60597 .45295 Mtetra
.687 .78 .922 r
.60597 .45295 .60679 .45376 .6084 .45306 .60758 .45233 Mtetra
.753 .814 .901 r
.60758 .45233 .6084 .45306 .61001 .45226 .60919 .45141 Mtetra
.685 .771 .916 r
.60919 .45141 .61001 .45226 .61163 .45167 .61081 .4508 Mtetra
.503 .697 .956 r
.61081 .4508 .61163 .45167 .61326 .45147 .61245 .45079 Mtetra
.833 .372 0 r
.61245 .45079 .61326 .45147 .61492 .4526 .61416 .45383 Mtetra
.964 .681 .448 r
.61416 .45383 .61492 .4526 .61664 .45547 .62117 .64736 Mtetra
.575 .358 .549 r
.62117 .64736 .61664 .45547 .62364 .64352 .62315 .65583 Mtetra
.582 .336 .509 r
.62315 .65583 .62364 .64352 .62568 .654 .62492 .65691 Mtetra
.54 .212 .361 r
.62492 .65691 .62568 .654 .6275 .65667 .62667 .65705 Mtetra
.051 0 0 r
.62667 .65705 .6275 .65667 .62928 .65784 .62841 .65674 Mtetra
.517 .662 .927 r
.62841 .65674 .62928 .65784 .63103 .65797 .63016 .65675 Mtetra
.632 .689 .886 r
.63016 .65675 .63103 .65797 .63277 .65752 .6319 .65636 Mtetra
.745 .737 .845 r
.6319 .65636 .63277 .65752 .63449 .65651 .63362 .65529 Mtetra
.901 .748 .681 r
.63362 .65529 .63449 .65651 .63617 .65434 .63524 .65131 Mtetra
.965 .687 .455 r
.63524 .65131 .63617 .65434 .6378 .65055 .63083 .4603 Mtetra
.585 .37 .556 r
.63083 .4603 .6378 .65055 .6391 .63695 .63205 .44709 Mtetra
.566 .356 .554 r
.63205 .44709 .6391 .63695 .63457 .44979 .63363 .44495 Mtetra
.636 .48 .653 r
.63363 .44495 .63457 .44979 .6361 .44606 .63525 .44386 Mtetra
.651 .575 .756 r
.63525 .44386 .6361 .44606 .63768 .44399 .63688 .44323 Mtetra
.655 .787 .945 r
.63688 .44323 .63768 .44399 .63931 .44324 .63852 .44273 Mtetra
.577 .83 .993 r
.63852 .44273 .63931 .44324 .64095 .44296 .64016 .44236 Mtetra
.564 .801 .988 r
.64016 .44236 .64095 .44296 .64261 .44289 .64181 .44207 Mtetra
.641 .765 .938 r
.64181 .44207 .64261 .44289 .64425 .4425 .64345 .44162 Mtetra
.655 .757 .925 r
.64345 .44162 .64425 .4425 .64589 .44202 .64509 .44113 Mtetra
.66 .756 .921 r
.64509 .44113 .64589 .44202 .64753 .44151 .64673 .44062 Mtetra
.64673 .44062 .64753 .44151 .64918 .44101 .64838 .44012 Mtetra
.662 .756 .92 r
.64838 .44012 .64918 .44101 .65082 .4405 .65002 .4396 Mtetra
.664 .757 .919 r
.65002 .4396 .65082 .4405 .65246 .43997 .65166 .43907 Mtetra
.664 .757 .92 r
.65166 .43907 .65246 .43997 .65411 .43944 .65331 .43855 Mtetra
.668 .759 .919 r
.65331 .43855 .65411 .43944 .65575 .43889 .65495 .43801 Mtetra
.674 .763 .918 r
.65495 .43801 .65575 .43889 .6574 .43831 .6566 .43744 Mtetra
.708 .778 .907 r
.6566 .43744 .6574 .43831 .65903 .43737 .65824 .43672 Mtetra
.703 .831 .944 r
.65824 .43672 .65903 .43737 .66066 .43654 .65988 .43603 Mtetra
.654 .855 .977 r
.65988 .43603 .66066 .43654 .66231 .43607 .66153 .43546 Mtetra
.628 .821 .974 r
.66153 .43546 .66231 .43607 .66401 .43675 .66318 .435 Mtetra
.579 .578 .816 r
.66318 .435 .66401 .43675 .66578 .43885 .66485 .43491 Mtetra
.513 .417 .683 r
.66485 .43491 .66578 .43885 .6678 .44683 .66656 .43557 Mtetra
.363 .241 .577 r
.66656 .43557 .6678 .44683 .67794 .63794 .66848 .44113 Mtetra
.044 0 .438 r
.66848 .44113 .67794 .63794 .67988 .64153 .6789 .63744 Mtetra
.039 .1 .6 r
.6789 .63744 .67988 .64153 .68174 .64306 .68087 .64156 Mtetra
.38 .517 .87 r
.68087 .64156 .68174 .64306 .68354 .64335 .68269 .64217 Mtetra
.636 .702 .894 r
.68269 .64217 .68354 .64335 .68531 .64297 .68446 .64175 Mtetra
.72 .724 .853 r
.68446 .64175 .68531 .64297 .68706 .64205 .68621 .64084 Mtetra
.691 .717 .869 r
.68621 .64084 .68706 .64205 .68876 .64024 .68797 .64012 Mtetra
.679 .962 .94 r
.68797 .64012 .68876 .64024 .69041 .63719 .68971 .63917 Mtetra
.138 0 .121 r
.68971 .63917 .69041 .63719 .69189 .63066 .69143 .63751 Mtetra
.173 0 .373 r
.69143 .63751 .69189 .63066 .68418 .43629 .69296 .63195 Mtetra
.041 0 .432 r
.69296 .63195 .68418 .43629 .68562 .43114 .68501 .43386 Mtetra
0 0 0 r
.68501 .43386 .68562 .43114 .68718 .42862 .68643 .42827 Mtetra
.867 .921 .862 r
.68643 .42827 .68718 .42862 .68882 .4276 .68804 .42668 Mtetra
.654 .75 .92 r
.68804 .42668 .68882 .4276 .6905 .42724 .68971 .42619 Mtetra
.551 .678 .923 r
.68971 .42619 .6905 .42724 .69219 .42714 .6914 .4261 Mtetra
.615 .709 .912 r
.6914 .4261 .69219 .42714 .69386 .4268 .69308 .42578 Mtetra
.653 .726 .902 r
.69308 .42578 .69386 .4268 .69553 .42629 .69475 .42529 Mtetra
.661 .735 .904 r
.69475 .42529 .69553 .42629 .6972 .42572 .69642 .42477 Mtetra
.695 .759 .901 r
.69642 .42477 .6972 .42572 .69885 .42483 .69808 .4241 Mtetra
.702 .813 .934 r
.69808 .4241 .69885 .42483 .70051 .42397 .69975 .4234 Mtetra
.663 .848 .971 r
.69975 .4234 .70051 .42397 .70218 .42343 .70142 .42281 Mtetra
.635 .825 .974 r
.70142 .42281 .70218 .42343 .70391 .42389 .70309 .42233 Mtetra
.592 .608 .837 r
.70309 .42233 .70391 .42389 .70571 .42572 .70479 .42215 Mtetra
.524 .436 .698 r
.70479 .42215 .70571 .42572 .70774 .43145 .70652 .42265 Mtetra
.384 .269 .598 r
.70652 .42265 .70774 .43145 .72043 .62496 .70846 .42672 Mtetra
.067 0 .45 r
.70846 .42672 .72043 .62496 .72248 .62919 .72143 .6242 Mtetra
.069 .099 .585 r
.72143 .6242 .72248 .62919 .7244 .63088 .72353 .62916 Mtetra
.332 .456 .837 r
.72353 .62916 .7244 .63088 .72624 .6312 .72541 .63008 Mtetra
.634 .715 .906 r
.72541 .63008 .72624 .6312 .72804 .63071 .72721 .62965 Mtetra
.733 .761 .875 r
.72721 .62965 .72804 .63071 .7298 .62967 .72898 .6287 Mtetra
.708 .773 .903 r
.72898 .6287 .7298 .62967 .73152 .62789 .73076 .62792 Mtetra
.545 .929 .883 r
.73076 .62792 .73152 .62789 .73317 .62498 .73253 .62708 Mtetra
.22 0 .177 r
.73253 .62708 .73317 .62498 .73463 .619 .73427 .62559 Mtetra
.241 .04 .394 r
.73427 .62559 .73463 .619 .72448 .42426 .73581 .62086 Mtetra
.065 0 .445 r
.73581 .62086 .72448 .42426 .72586 .41866 .72537 .42219 Mtetra
0 0 .044 r
.72537 .42219 .72586 .41866 .72741 .41598 .72669 .41581 Mtetra
.906 .952 .818 r
.72669 .41581 .72741 .41598 .72906 .41477 .72829 .41386 Mtetra
.673 .763 .918 r
.72829 .41386 .72906 .41477 .73076 .41434 .72998 .41329 Mtetra
.569 .687 .92 r
.72998 .41329 .73076 .41434 .73247 .41419 .7317 .41313 Mtetra
.622 .708 .908 r
.7317 .41313 .73247 .41419 .73417 .41373 .7334 .41277 Mtetra
.671 .75 .91 r
.7334 .41277 .73417 .41373 .73585 .41307 .73509 .4122 Mtetra
.647 .764 .934 r
.73509 .4122 .73585 .41307 .73755 .41267 .73679 .41173 Mtetra
.635 .741 .925 r
.73679 .41173 .73755 .41267 .73931 .41311 .73849 .41131 Mtetra
.594 .583 .81 r
.73849 .41131 .73931 .41311 .74117 .41494 .74021 .41112 Mtetra
.532 .434 .689 r
.74021 .41112 .74117 .41494 .7433 .42088 .74198 .41158 Mtetra
.37 .258 .594 r
.74198 .41158 .7433 .42088 .75825 .61544 .74403 .41623 Mtetra
.083 .005 .46 r
.74403 .41623 .75825 .61544 .76038 .61962 .75933 .61513 Mtetra
.163 .178 .628 r
.75933 .61513 .76038 .61962 .76231 .62087 .76145 .61905 Mtetra
.71 .65 .787 r
.76145 .61905 .76231 .62087 .76404 .61908 .76323 .61798 Mtetra
.962 .749 .57 r
.76323 .61798 .76404 .61908 .76531 .61079 .76452 .61005 Mtetra
.976 .685 .4 r
.76452 .61005 .76531 .61079 .75305 .41076 .75229 .40986 Mtetra
.926 .794 .696 r
.75229 .40986 .75305 .41076 .75455 .40742 .75379 .40647 Mtetra
.715 .769 .895 r
.75379 .40647 .75455 .40742 .75624 .40663 .75548 .40568 Mtetra
.586 .721 .937 r
.75548 .40568 .75624 .40663 .75797 .4064 .75721 .40544 Mtetra
.623 .734 .926 r
.75721 .40544 .75797 .4064 .75968 .40595 .75893 .40506 Mtetra
.694 .776 .915 r
.75893 .40506 .75968 .40595 .76137 .40518 .76063 .40438 Mtetra
.673 .792 .938 r
.76063 .40438 .76137 .40518 .76308 .40468 .76233 .40379 Mtetra
.667 .768 .925 r
.76233 .40379 .76308 .40468 .76485 .40492 .76404 .40323 Mtetra
.63 .615 .816 r
.76404 .40323 .76485 .40492 .76671 .40638 .76576 .40283 Mtetra
.559 .46 .699 r
.76576 .40283 .76671 .40638 .76876 .41034 .76753 .40298 Mtetra
.455 .33 .621 r
.76753 .40298 .76876 .41034 .78522 .60374 .76946 .40532 Mtetra
.101 .02 .469 r
.76946 .40532 .78522 .60374 .78752 .60953 .7862 .60163 Mtetra
.083 .073 .546 r
.7862 .60163 .78752 .60953 .78956 .61163 .78869 .60971 Mtetra
.1 .282 .761 r
.78869 .60971 .78956 .61163 .79149 .61246 .79071 .6116 Mtetra
.454 .696 .971 r
.79071 .6116 .79149 .61246 .79337 .61245 .79259 .61166 Mtetra
.733 .828 .924 r
.79259 .61166 .79337 .61245 .79518 .61163 .79439 .61075 Mtetra
.913 .817 .738 r
.79439 .61075 .79518 .61163 .79683 .60882 .79604 .60784 Mtetra
.978 .731 .494 r
.79604 .60784 .79683 .60882 .79766 .59565 .79685 .59432 Mtetra
.977 .682 .387 r
.79685 .59432 .79766 .59565 .78384 .40033 .78309 .39929 Mtetra
.907 .784 .714 r
.78309 .39929 .78384 .40033 .78536 .39727 .78461 .39624 Mtetra
.705 .753 .889 r
.78461 .39624 .78536 .39727 .78706 .39651 .78632 .39549 Mtetra
.581 .704 .927 r
.78632 .39549 .78706 .39651 .78881 .39629 .78807 .39527 Mtetra
.591 .71 .926 r
.78807 .39527 .78881 .39629 .79056 .39596 .78982 .39502 Mtetra
.682 .763 .913 r
.78982 .39502 .79056 .39596 .79227 .39522 .79154 .39439 Mtetra
.667 .785 .937 r
.79154 .39439 .79227 .39522 .794 .3947 .79326 .39381 Mtetra
.662 .769 .929 r
.79326 .39381 .794 .3947 .79578 .3948 .79499 .39327 Mtetra
.64 .641 .835 r
.79499 .39327 .79578 .3948 .79766 .39603 .79673 .39281 Mtetra
.571 .48 .713 r
.79673 .39281 .79766 .39603 .7997 .39909 .79851 .39282 Mtetra
.48 .358 .637 r
.79851 .39282 .7997 .39909 .81789 .59018 .80043 .39446 Mtetra
.143 .053 .485 r
.80043 .39446 .81789 .59018 .82054 .59906 .81805 .57825 Mtetra
.109 .051 .504 r
.81805 .57825 .82054 .59906 .82265 .60154 .82175 .59914 Mtetra
.159 .275 .734 r
.82175 .59914 .82265 .60154 .82461 .60225 .82384 .60132 Mtetra
.596 .748 .949 r
.82384 .60132 .82461 .60225 .82647 .60179 .82571 .60099 Mtetra
.736 .829 .922 r
.82571 .60099 .82647 .60179 .8283 .60097 .82753 .60005 Mtetra
.745 .804 .9 r
.82753 .60005 .8283 .60097 .83014 .60019 .82935 .59906 Mtetra
.659 .729 .902 r
.82935 .59906 .83014 .60019 .83201 .59976 .83121 .59849 Mtetra
.652 .702 .883 r
.83121 .59849 .83201 .59976 .83388 .59935 .83306 .59796 Mtetra
.645 .679 .868 r
.83306 .59796 .83388 .59935 .83574 .59888 .83493 .59747 Mtetra
.64 .672 .865 r
.83493 .59747 .83574 .59888 .8376 .5983 .8368 .597 Mtetra
.634 .687 .882 r
.8368 .597 .8376 .5983 .83946 .59773 .83867 .59656 Mtetra
.574 .685 .916 r
.83867 .59656 .83946 .59773 .84134 .59743 .84056 .59637 Mtetra
.468 .656 .943 r
.84056 .59637 .84134 .59743 .84326 .59751 .84249 .5965 Mtetra
.627 .743 .931 r
.84249 .5965 .84326 .59751 .84514 .59706 .84437 .59607 Mtetra
.864 .811 .796 r
.84437 .59607 .84514 .59706 .84686 .59495 .84609 .59396 Mtetra
.981 .743 .505 r
.84609 .59396 .84686 .59495 .84774 .58407 .84698 .58307 Mtetra
.977 .678 .362 r
.84698 .58307 .84774 .58407 .83077 .38593 .83004 .38492 Mtetra
.93 .791 .685 r
.83004 .38492 .83077 .38593 .83223 .38237 .83151 .38135 Mtetra
.722 .765 .887 r
.83151 .38135 .83223 .38237 .83396 .38152 .83323 .38051 Mtetra
.596 .714 .926 r
.83323 .38051 .83396 .38152 .83573 .38125 .83501 .38023 Mtetra
.596 .713 .925 r
.83501 .38023 .83573 .38125 .83751 .38098 .83679 .37995 Mtetra
.736 .767 .878 r
.83679 .37995 .83751 .38098 .83923 .38004 .83851 .37902 Mtetra
.651 .736 .912 r
.83851 .37902 .83923 .38004 .84099 .37955 .84027 .37851 Mtetra
.215 .495 .901 r
.84027 .37851 .84099 .37955 .84289 .38039 .84216 .3793 Mtetra
.892 .508 .055 r
.84216 .3793 .84289 .38039 .8456 .38937 .84475 .38715 Mtetra
.975 .667 .329 r
.84475 .38715 .8456 .38937 .86738 .58818 .86658 .58674 Mtetra
0 0 .519 r
.86658 .58674 .86738 .58818 .86962 .59119 .86884 .58996 Mtetra
.488 .63 .915 r
.86884 .58996 .86962 .59119 .87155 .59112 .87079 .59011 Mtetra
.713 .778 .903 r
.87079 .59011 .87155 .59112 .8734 .59019 .87265 .58926 Mtetra
.872 .828 .802 r
.87265 .58926 .8734 .59019 .87516 .58848 .87437 .58716 Mtetra
.95 .76 .61 r
.87437 .58716 .87516 .58848 .87683 .58579 .87573 .58144 Mtetra
.976 .673 .359 r
.87573 .58144 .87683 .58579 .87826 .58083 .85685 .38058 Mtetra
.571 .359 .554 r
.85685 .38058 .87826 .58083 .8598 .38543 .85808 .37476 Mtetra
.61 .421 .6 r
.85808 .37476 .8598 .38543 .86081 .37759 .85973 .37316 Mtetra
.63 .484 .666 r
.85973 .37316 .86081 .37759 .86231 .37448 .86147 .37225 Mtetra
.653 .581 .761 r
.86147 .37225 .86231 .37448 .86394 .37263 .86322 .37157 Mtetra
.739 .765 .874 r
.86322 .37157 .86394 .37263 .86566 .37163 .86495 .37061 Mtetra
.657 .742 .912 r
.86495 .37061 .86566 .37163 .86744 .37114 .86673 .37008 Mtetra
.398 .602 .929 r
.86673 .37008 .86744 .37114 .86929 .37124 .8686 .37044 Mtetra
.745 .294 0 r
.8686 .37044 .86929 .37124 .87125 .37248 .87085 .37427 Mtetra
.973 .662 .33 r
.87085 .37427 .87125 .37248 .87344 .37565 .89439 .57373 Mtetra
.57 .354 .548 r
.89439 .57373 .87344 .37565 .89643 .56876 .89699 .57958 Mtetra
.572 .32 .497 r
.89699 .57958 .89643 .56876 .89932 .57721 .89902 .58026 Mtetra
.513 .189 .354 r
.89902 .58026 .89932 .57721 .90155 .57968 .90097 .58014 Mtetra
.075 0 0 r
.90097 .58014 .90155 .57968 .90363 .58067 .90289 .5797 Mtetra
.517 .703 .955 r
.90289 .5797 .90363 .58067 .90559 .58066 .90485 .57964 Mtetra
.651 .755 .925 r
.90485 .57964 .90559 .58066 .90749 .58006 .90675 .57909 Mtetra
.809 .817 .857 r
.90675 .57909 .90749 .58006 .90932 .57881 .90856 .57761 Mtetra
.957 .774 .614 r
.90856 .57761 .90932 .57881 .911 .57625 .90992 .57221 Mtetra
.975 .669 .34 r
.90992 .57221 .911 .57625 .91243 .57154 .88897 .37122 Mtetra
.572 .36 .554 r
.88897 .37122 .91243 .57154 .89204 .37666 .89009 .36476 Mtetra
.606 .414 .596 r
.89009 .36476 .89204 .37666 .89288 .36787 .89176 .36315 Mtetra
.625 .476 .66 r
.89176 .36315 .89288 .36787 .89436 .36465 .89351 .36226 Mtetra
.632 .559 .755 r
.89351 .36226 .89436 .36465 .896 .36276 .8953 .36174 Mtetra
.655 .744 .915 r
.8953 .36174 .896 .36276 .89777 .36202 .8971 .36121 Mtetra
.621 .78 .958 r
.8971 .36121 .89777 .36202 .89958 .36163 .89891 .36078 Mtetra
.618 .77 .953 r
.89891 .36078 .89958 .36163 .90141 .36138 .90072 .36037 Mtetra
.665 .75 .913 r
.90072 .36037 .90141 .36138 .90321 .36085 .90251 .35979 Mtetra
.675 .744 .903 r
.90251 .35979 .90321 .36085 .905 .36026 .9043 .35917 Mtetra
.685 .741 .893 r
.9043 .35917 .905 .36026 .90678 .3596 .90608 .35849 Mtetra
.761 .768 .858 r
.90608 .35849 .90678 .3596 .90852 .35851 .90781 .35737 Mtetra
.705 .74 .879 r
.90781 .35737 .90852 .35851 .91028 .35763 .90958 .35658 Mtetra
.557 .691 .929 r
.90958 .35658 .91028 .35763 .91209 .35719 .91144 .35644 Mtetra
.647 .178 0 r
.91144 .35644 .91209 .35719 .91409 .35825 .91369 .35957 Mtetra
.971 .655 .302 r
.91369 .35957 .91409 .35825 .91631 .3611 .93995 .55823 Mtetra
.573 .356 .548 r
.93995 .55823 .91631 .3611 .94196 .55352 .94297 .56652 Mtetra
.46 .045 .164 r
.32105 .74108 .32216 .73973 .32363 .7407 .32258 .74104 Mtetra
.339 .81 .734 r
.32258 .74104 .32363 .7407 .32515 .74082 .32414 .74041 Mtetra
.763 .872 .927 r
.32414 .74041 .32515 .74082 .32669 .7405 .32572 .73947 Mtetra
.609 .701 .909 r
.32572 .73947 .32669 .7405 .32824 .74011 .32727 .7392 Mtetra
.612 .728 .928 r
.32727 .7392 .32824 .74011 .3298 .7396 .32881 .7389 Mtetra
.644 .787 .95 r
.32881 .7389 .3298 .7396 .33136 .73904 .33037 .73846 Mtetra
.693 .824 .946 r
.33037 .73846 .33136 .73904 .33288 .73918 .33193 .73783 Mtetra
.736 .686 .803 r
.33193 .73783 .33288 .73918 .33442 .73898 .33352 .73676 Mtetra
.753 .623 .716 r
.33352 .73676 .33442 .73898 .33601 .73806 .33516 .73484 Mtetra
.85 .643 .621 r
.33516 .73484 .33601 .73806 .33781 .73292 .33712 .72678 Mtetra
.931 .679 .536 r
.33712 .72678 .33781 .73292 .34943 .53963 .3486 .53718 Mtetra
.819 .64 .66 r
.3486 .53718 .34943 .53963 .35119 .53371 .35027 .53303 Mtetra
.78 .798 .867 r
.35027 .53303 .35119 .53371 .3527 .53256 .35177 .53197 Mtetra
.63 .804 .966 r
.35177 .53197 .3527 .53256 .35417 .53224 .35324 .53158 Mtetra
.516 .748 .98 r
.35324 .53158 .35417 .53224 .35562 .53229 .3547 .53146 Mtetra
.7 .757 .897 r
.3547 .53146 .35562 .53229 .35709 .53187 .35619 .53084 Mtetra
.693 .714 .864 r
.35619 .53084 .35709 .53187 .35857 .53138 .35767 .53022 Mtetra
.664 .683 .858 r
.35767 .53022 .35857 .53138 .36005 .53085 .35915 .52973 Mtetra
.628 .677 .878 r
.35915 .52973 .36005 .53085 .36155 .52986 .36062 .52941 Mtetra
.299 .712 .975 r
.36062 .52941 .36155 .52986 .36305 .52914 .36208 .52948 Mtetra
.635 .134 .043 r
.36208 .52948 .36305 .52914 .36451 .52905 .3635 .5303 Mtetra
.861 .545 .452 r
.3635 .5303 .36451 .52905 .36581 .53246 .36468 .53608 Mtetra
.934 .676 .523 r
.36468 .53608 .36581 .53246 .35823 .72482 .35717 .72608 Mtetra
.824 .487 .417 r
.35717 .72608 .35823 .72482 .35949 .73093 .35853 .73 Mtetra
.161 .508 .912 r
.35853 .73 .35949 .73093 .36102 .7315 .36005 .73058 Mtetra
.614 .727 .926 r
.36005 .73058 .36102 .7315 .36259 .731 .36162 .73027 Mtetra
.726 .795 .907 r
.36162 .73027 .36259 .731 .36419 .73008 .36321 .72949 Mtetra
.704 .827 .941 r
.36321 .72949 .36419 .73008 .36574 .73005 .3648 .72881 Mtetra
.736 .702 .819 r
.3648 .72881 .36574 .73005 .36731 .72989 .3664 .72779 Mtetra
.752 .63 .725 r
.3664 .72779 .36731 .72989 .3689 .72907 .36803 .72599 Mtetra
.838 .639 .634 r
.36803 .72599 .3689 .72907 .37064 .72475 .36987 .71965 Mtetra
.936 .682 .528 r
.36987 .71965 .37064 .72475 .38051 .53161 .37972 .52828 Mtetra
.803 .612 .643 r
.37972 .52828 .38051 .53161 .3823 .52431 .38139 .52354 Mtetra
.803 .78 .831 r
.38139 .52354 .3823 .52431 .38383 .52282 .38292 .52221 Mtetra
.643 .805 .961 r
.38292 .52221 .38383 .52282 .38532 .52245 .38441 .52178 Mtetra
.514 .746 .979 r
.38441 .52178 .38532 .52245 .38679 .52251 .38589 .52167 Mtetra
.676 .752 .908 r
.38589 .52167 .38679 .52251 .38828 .52221 .38739 .52115 Mtetra
.689 .709 .864 r
.38739 .52115 .38828 .52221 .38977 .52175 .38889 .52054 Mtetra
.661 .674 .852 r
.38889 .52054 .38977 .52175 .39127 .52126 .39038 .52006 Mtetra
.535 .626 .888 r
.39038 .52006 .39127 .52126 .39277 .52071 .39186 .52008 Mtetra
.206 .605 .948 r
.39186 .52008 .39277 .52071 .39427 .52013 .39333 .52039 Mtetra
.474 0 0 r
.39333 .52039 .39427 .52013 .39577 .51955 .39479 .52081 Mtetra
.427 .007 .137 r
.39479 .52081 .39577 .51955 .39727 .519 .39628 .52067 Mtetra
.362 0 .174 r
.39628 .52067 .39727 .519 .39878 .51848 .39778 .52014 Mtetra
.319 0 .149 r
.39778 .52014 .39878 .51848 .40028 .51797 .39929 .51948 Mtetra
.37 0 .152 r
.39929 .51948 .40028 .51797 .40178 .51746 .40079 .51905 Mtetra
.385 0 .173 r
.40079 .51905 .40178 .51746 .40328 .51698 .40229 .51863 Mtetra
.337 0 .157 r
.40229 .51863 .40328 .51698 .40478 .51651 .4038 .51803 Mtetra
.055 0 0 r
.4038 .51803 .40478 .51651 .40629 .51609 .40533 .51682 Mtetra
.543 .876 .612 r
.40533 .51682 .40629 .51609 .40779 .51569 .40687 .51548 Mtetra
.817 .92 .906 r
.40687 .51548 .40779 .51569 .40929 .51528 .4084 .51431 Mtetra
.713 .733 .867 r
.4084 .51431 .40929 .51528 .4108 .5148 .40992 .51358 Mtetra
.659 .673 .853 r
.40992 .51358 .4108 .5148 .41231 .51427 .41142 .5131 Mtetra
.638 .675 .869 r
.41142 .5131 .41231 .51427 .41382 .51374 .41293 .51273 Mtetra
.636 .706 .897 r
.41293 .51273 .41382 .51374 .41533 .51324 .41443 .51237 Mtetra
.634 .736 .921 r
.41443 .51237 .41533 .51324 .41684 .51276 .41594 .512 Mtetra
.632 .761 .94 r
.41594 .512 .41684 .51276 .41835 .5123 .41745 .51162 Mtetra
.643 .788 .952 r
.41745 .51162 .41835 .5123 .41986 .51176 .41896 .5112 Mtetra
.65 .82 .965 r
.41896 .5112 .41986 .51176 .42137 .51123 .42047 .51072 Mtetra
.657 .838 .97 r
.42047 .51072 .42137 .51123 .42288 .51079 .42199 .51021 Mtetra
.679 .821 .952 r
.42199 .51021 .42288 .51079 .42439 .5107 .4235 .50965 Mtetra
.684 .713 .871 r
.4235 .50965 .42439 .5107 .42588 .51087 .42502 .50907 Mtetra
.66 .603 .781 r
.42502 .50907 .42588 .51087 .42738 .5111 .42654 .50848 Mtetra
.635 .536 .725 r
.42654 .50848 .42738 .5111 .42889 .51097 .42806 .50794 Mtetra
.625 .512 .706 r
.42806 .50794 .42889 .51097 .4304 .51048 .42958 .50743 Mtetra
.623 .511 .705 r
.42958 .50743 .4304 .51048 .43193 .50987 .4311 .50692 Mtetra
.625 .516 .71 r
.4311 .50692 .43193 .50987 .43345 .5093 .43262 .50642 Mtetra
.627 .52 .713 r
.43262 .50642 .43345 .5093 .43497 .50877 .43414 .50591 Mtetra
.626 .52 .714 r
.43414 .50591 .43497 .50877 .43649 .50825 .43566 .50541 Mtetra
.647 .534 .711 r
.43566 .50541 .43649 .50825 .43803 .5074 .43719 .50468 Mtetra
.647 .539 .718 r
.43719 .50468 .43803 .5074 .43956 .5066 .43872 .50399 Mtetra
.604 .518 .731 r
.43872 .50399 .43956 .5066 .44107 .50644 .44024 .50373 Mtetra
.288 .314 .715 r
.44024 .50373 .44107 .50644 .44252 .50927 .44171 .50522 Mtetra
.743 .492 0 r
.44171 .50522 .44252 .50927 .43937 .70149 .44305 .5124 Mtetra
0 0 .34 r
.44305 .5124 .43937 .70149 .44083 .70759 .43997 .70343 Mtetra
.303 .269 .655 r
.43997 .70343 .44083 .70759 .4424 .70881 .44152 .70565 Mtetra
.598 .498 .712 r
.44152 .70565 .4424 .70881 .44402 .7085 .44314 .7054 Mtetra
.655 .535 .706 r
.44314 .7054 .44402 .7085 .44565 .70775 .44477 .7045 Mtetra
.642 .522 .702 r
.44477 .7045 .44565 .70775 .44728 .70709 .4464 .70373 Mtetra
.617 .503 .701 r
.4464 .70373 .44728 .70709 .4489 .70662 .44802 .70325 Mtetra
.44802 .70325 .4489 .70662 .45053 .70616 .44965 .70277 Mtetra
.615 .501 .701 r
.44965 .70277 .45053 .70616 .45215 .7057 .45127 .70231 Mtetra
.614 .5 .701 r
.45127 .70231 .45215 .7057 .45378 .70525 .4529 .70186 Mtetra
.613 .5 .701 r
.4529 .70186 .45378 .70525 .4554 .70482 .45452 .70143 Mtetra
.612 .499 .701 r
.45452 .70143 .4554 .70482 .45703 .70443 .45615 .701 Mtetra
.611 .498 .7 r
.45615 .701 .45703 .70443 .45866 .70407 .45778 .70058 Mtetra
.611 .495 .697 r
.45778 .70058 .45866 .70407 .46029 .70371 .45941 .70015 Mtetra
.611 .494 .695 r
.45941 .70015 .46029 .70371 .46192 .70332 .46104 .69972 Mtetra
.612 .493 .693 r
.46104 .69972 .46192 .70332 .46355 .70288 .46267 .69926 Mtetra
.613 .493 .693 r
.46267 .69926 .46355 .70288 .46518 .70242 .4643 .6988 Mtetra
.62 .498 .692 r
.4643 .6988 .46518 .70242 .46682 .70196 .46594 .69824 Mtetra
.622 .496 .688 r
.46594 .69824 .46682 .70196 .46845 .70149 .46758 .69764 Mtetra
.607 .483 .686 r
.46758 .69764 .46845 .70149 .47009 .701 .46921 .69722 Mtetra
.563 .456 .691 r
.46921 .69722 .47009 .701 .47173 .70047 .47084 .69732 Mtetra
.515 .448 .719 r
.47084 .69732 .47173 .70047 .47337 .69991 .47246 .69779 Mtetra
.503 .505 .791 r
.47246 .69779 .47337 .69991 .47501 .69934 .47409 .69813 Mtetra
.548 .648 .9 r
.47409 .69813 .47501 .69934 .47665 .69881 .47572 .69809 Mtetra
.63 .787 .957 r
.47572 .69809 .47665 .69881 .47829 .69833 .47737 .69766 Mtetra
.661 .811 .955 r
.47737 .69766 .47829 .69833 .47993 .69786 .47901 .69712 Mtetra
.661 .793 .945 r
.47901 .69712 .47993 .69786 .48158 .69744 .48065 .69659 Mtetra
.647 .762 .933 r
.48065 .69659 .48158 .69744 .48322 .69705 .4823 .69613 Mtetra
.644 .744 .922 r
.4823 .69613 .48322 .69705 .48486 .69658 .48394 .69569 Mtetra
.628 .747 .933 r
.48394 .69569 .48486 .69658 .48651 .69582 .48559 .6953 Mtetra
.566 .823 .994 r
.48559 .6953 .48651 .69582 .48817 .69471 .48724 .69497 Mtetra
0 0 0 r
.48724 .69497 .48817 .69471 .48982 .6935 .48888 .69462 Mtetra
.299 0 0 r
.48888 .69462 .48982 .6935 .49147 .69255 .49053 .6942 Mtetra
.37 0 .16 r
.49053 .6942 .49147 .69255 .49312 .69207 .49218 .6937 Mtetra
.361 0 .153 r
.49218 .6937 .49312 .69207 .49477 .69173 .49384 .69318 Mtetra
.389 0 .134 r
.49384 .69318 .49477 .69173 .49642 .69164 .49549 .69285 Mtetra
.406 0 .092 r
.49549 .69285 .49642 .69164 .49807 .69163 .49714 .69268 Mtetra
.216 0 0 r
.49714 .69268 .49807 .69163 .49972 .69102 .4988 .69211 Mtetra
0 0 0 r
.4988 .69211 .49972 .69102 .50139 .68828 .50046 .69018 Mtetra
.963 .878 .484 r
.50046 .69018 .50139 .68828 .50423 .49774 .50215 .68415 Mtetra
0 0 .347 r
.50215 .68415 .50423 .49774 .50586 .48651 .50497 .48963 Mtetra
0 0 0 r
.50497 .48963 .50586 .48651 .50743 .48378 .50656 .48517 Mtetra
.238 0 .056 r
.50656 .48517 .50743 .48378 .50899 .48304 .50813 .4844 Mtetra
.426 .016 .155 r
.50813 .4844 .50899 .48304 .51056 .48277 .50969 .48421 Mtetra
.341 0 .123 r
.50969 .48421 .51056 .48277 .51212 .4826 .51125 .4837 Mtetra
0 0 0 r
.51125 .4837 .51212 .4826 .51368 .48221 .51282 .48233 Mtetra
.78 .994 .876 r
.51282 .48233 .51368 .48221 .51525 .48182 .51439 .48108 Mtetra
.758 .801 .887 r
.51439 .48108 .51525 .48182 .51681 .48141 .51596 .48013 Mtetra
.667 .674 .847 r
.51596 .48013 .51681 .48141 .51838 .48095 .51753 .47959 Mtetra
.645 .652 .843 r
.51753 .47959 .51838 .48095 .51995 .48046 .5191 .47916 Mtetra
.644 .661 .852 r
.5191 .47916 .51995 .48046 .52152 .47993 .52066 .47874 Mtetra
.662 .686 .863 r
.52066 .47874 .52152 .47993 .52309 .47935 .52223 .47823 Mtetra
.662 .7 .875 r
.52223 .47823 .52309 .47935 .52466 .47876 .52381 .47774 Mtetra
.656 .716 .892 r
.52381 .47774 .52466 .47876 .52623 .47817 .52538 .47727 Mtetra
.644 .74 .919 r
.52538 .47727 .52623 .47817 .5278 .47758 .52695 .47685 Mtetra
.64 .781 .949 r
.52695 .47685 .5278 .47758 .52937 .47708 .52853 .47642 Mtetra
.654 .804 .955 r
.52853 .47642 .52937 .47708 .53095 .47679 .5301 .47593 Mtetra
.685 .76 .908 r
.5301 .47593 .53095 .47679 .53253 .47688 .53168 .47534 Mtetra
.669 .639 .811 r
.53168 .47534 .53253 .47688 .5341 .47709 .53325 .47473 Mtetra
.644 .557 .742 r
.53325 .47473 .5341 .47709 .53568 .47716 .53483 .47414 Mtetra
.626 .515 .708 r
.53483 .47414 .53568 .47716 .53726 .47674 .53641 .4736 Mtetra
.623 .509 .704 r
.53641 .4736 .53726 .47674 .53884 .47615 .53799 .47308 Mtetra
.623 .512 .707 r
.53799 .47308 .53884 .47615 .54042 .47554 .53957 .47257 Mtetra
.625 .517 .711 r
.53957 .47257 .54042 .47554 .542 .47502 .54115 .47206 Mtetra
.624 .517 .712 r
.54115 .47206 .542 .47502 .54359 .4745 .54273 .47155 Mtetra
.54273 .47155 .54359 .4745 .54517 .47399 .54431 .47104 Mtetra
.624 .518 .712 r
.54431 .47104 .54517 .47399 .54675 .47349 .5459 .47054 Mtetra
.5459 .47054 .54675 .47349 .54834 .47298 .54748 .47003 Mtetra
.624 .518 .713 r
.54748 .47003 .54834 .47298 .54992 .47248 .54907 .46953 Mtetra
.54907 .46953 .54992 .47248 .55151 .47198 .55065 .46902 Mtetra
.624 .517 .713 r
.55065 .46902 .55151 .47198 .5531 .47147 .55224 .46852 Mtetra
.55224 .46852 .5531 .47147 .55469 .47097 .55383 .46802 Mtetra
.55383 .46802 .55469 .47097 .55628 .47047 .55542 .46751 Mtetra
.55542 .46751 .55628 .47047 .55787 .46997 .55701 .46701 Mtetra
.55701 .46701 .55787 .46997 .55946 .46946 .5586 .46651 Mtetra
.5586 .46651 .55946 .46946 .56105 .46896 .56019 .46601 Mtetra
.56019 .46601 .56105 .46896 .56265 .46846 .56178 .4655 Mtetra
.56178 .4655 .56265 .46846 .56424 .46796 .56338 .465 Mtetra
.56338 .465 .56424 .46796 .56583 .46746 .56497 .4645 Mtetra
.56497 .4645 .56583 .46746 .56743 .46696 .56657 .46399 Mtetra
.56657 .46399 .56743 .46696 .56903 .46645 .56817 .46349 Mtetra
.56817 .46349 .56903 .46645 .57063 .46595 .56976 .46299 Mtetra
.623 .517 .713 r
.56976 .46299 .57063 .46595 .57222 .46545 .57136 .46249 Mtetra
.57136 .46249 .57222 .46545 .57382 .46495 .57296 .46198 Mtetra
.57296 .46198 .57382 .46495 .57543 .46444 .57456 .46148 Mtetra
.57456 .46148 .57543 .46444 .57703 .46394 .57616 .46098 Mtetra
.623 .517 .712 r
.57616 .46098 .57703 .46394 .57863 .46345 .57777 .46047 Mtetra
.57777 .46047 .57863 .46345 .58023 .46295 .57937 .45997 Mtetra
.623 .516 .712 r
.57937 .45997 .58023 .46295 .58184 .46246 .58097 .45947 Mtetra
.622 .516 .712 r
.58097 .45947 .58184 .46246 .58344 .46198 .58258 .45898 Mtetra
.622 .515 .711 r
.58258 .45898 .58344 .46198 .58505 .46161 .58418 .45848 Mtetra
.619 .508 .706 r
.58418 .45848 .58505 .46161 .58666 .46115 .58579 .45799 Mtetra
.617 .507 .705 r
.58579 .45799 .58666 .46115 .58827 .46046 .5874 .45753 Mtetra
.614 .513 .716 r
.5874 .45753 .58827 .46046 .58986 .45923 .58901 .45712 Mtetra
.627 .567 .768 r
.58901 .45712 .58986 .45923 .59146 .45804 .59062 .45672 Mtetra
.646 .664 .853 r
.59062 .45672 .59146 .45804 .59306 .457 .59223 .45628 Mtetra
.675 .796 .94 r
.59223 .45628 .59306 .457 .59466 .4564 .59384 .45571 Mtetra
.681 .807 .942 r
.59384 .45571 .59466 .4564 .59628 .45592 .59545 .45511 Mtetra
.684 .778 .922 r
.59545 .45511 .59628 .45592 .59789 .45551 .59707 .45451 Mtetra
.687 .737 .889 r
.59707 .45451 .59789 .45551 .59951 .45507 .59868 .45389 Mtetra
.666 .695 .867 r
.59868 .45389 .59951 .45507 .60112 .45463 .60029 .45335 Mtetra
.635 .666 .863 r
.60029 .45335 .60112 .45463 .60274 .45415 .60191 .45297 Mtetra
.496 .62 .904 r
.60191 .45297 .60274 .45415 .60435 .45356 .60354 .45309 Mtetra
.127 .601 .918 r
.60354 .45309 .60435 .45356 .60597 .45295 .60518 .4534 Mtetra
.459 0 0 r
.60518 .4534 .60597 .45295 .60758 .45233 .60682 .45376 Mtetra
.206 0 .056 r
.60682 .45376 .60758 .45233 .60919 .45141 .60843 .45283 Mtetra
.295 0 .099 r
.60843 .45283 .60919 .45141 .61081 .4508 .61005 .45216 Mtetra
.497 .085 .187 r
.61005 .45216 .61081 .4508 .61245 .45079 .61169 .45227 Mtetra
.897 .565 .412 r
.61169 .45227 .61245 .45079 .61416 .45383 .61356 .46096 Mtetra
.956 .673 .46 r
.61356 .46096 .61416 .45383 .62117 .64736 .62051 .65377 Mtetra
.678 .393 .483 r
.62051 .65377 .62117 .64736 .62315 .65583 .62235 .65719 Mtetra
.51 .09 .179 r
.62235 .65719 .62315 .65583 .62492 .65691 .6241 .6574 Mtetra
0 0 0 r
.6241 .6574 .62492 .65691 .62667 .65705 .62583 .65689 Mtetra
.715 .958 .947 r
.62583 .65689 .62667 .65705 .62841 .65674 .62755 .65592 Mtetra
.709 .797 .919 r
.62755 .65592 .62841 .65674 .63016 .65675 .62928 .65516 Mtetra
.734 .676 .794 r
.62928 .65516 .63016 .65675 .6319 .65636 .63099 .65397 Mtetra
.758 .627 .714 r
.63099 .65397 .6319 .65636 .63362 .65529 .63268 .65191 Mtetra
.875 .653 .597 r
.63268 .65191 .63362 .65529 .63524 .65131 .63416 .64325 Mtetra
.959 .681 .464 r
.63416 .64325 .63524 .65131 .63083 .4603 .62966 .44813 Mtetra
.66 .453 .593 r
.62966 .44813 .63083 .4603 .63205 .44709 .63117 .44392 Mtetra
.665 .536 .697 r
.63117 .44392 .63205 .44709 .63363 .44495 .63279 .44284 Mtetra
.62 .565 .771 r
.63279 .44284 .63363 .44495 .63525 .44386 .63443 .44249 Mtetra
.553 .614 .868 r
.63443 .44249 .63525 .44386 .63688 .44323 .63608 .44247 Mtetra
.618 .774 .955 r
.63608 .44247 .63688 .44323 .63852 .44273 .63772 .44209 Mtetra
.629 .812 .97 r
.63772 .44209 .63852 .44273 .64016 .44236 .63936 .44164 Mtetra
.646 .795 .954 r
.63936 .44164 .64016 .44236 .64181 .44207 .641 .44116 Mtetra
.674 .757 .913 r
.641 .44116 .64181 .44207 .64345 .44162 .64264 .4406 Mtetra
.679 .732 .891 r
.64264 .4406 .64345 .44162 .64509 .44113 .64428 .44001 Mtetra
.677 .712 .874 r
.64428 .44001 .64509 .44113 .64673 .44062 .64592 .43941 Mtetra
.666 .692 .865 r
.64592 .43941 .64673 .44062 .64838 .44012 .64756 .43887 Mtetra
.66 .684 .861 r
.64756 .43887 .64838 .44012 .65002 .4396 .6492 .43834 Mtetra
.656 .681 .862 r
.6492 .43834 .65002 .4396 .65166 .43907 .65085 .43785 Mtetra
.647 .682 .869 r
.65085 .43785 .65166 .43907 .65331 .43855 .6525 .4374 Mtetra
.645 .695 .882 r
.6525 .4374 .65331 .43855 .65495 .43801 .65415 .43696 Mtetra
.649 .716 .897 r
.65415 .43696 .65495 .43801 .6566 .43744 .6558 .4365 Mtetra
.667 .746 .909 r
.6558 .4365 .6566 .43744 .65824 .43672 .65745 .43596 Mtetra
.675 .793 .937 r
.65745 .43596 .65824 .43672 .65988 .43603 .65909 .43538 Mtetra
.678 .825 .954 r
.65909 .43538 .65988 .43603 .66153 .43546 .66074 .43477 Mtetra
.764 .834 .906 r
.66074 .43477 .66153 .43546 .66318 .435 .66237 .43379 Mtetra
.708 .71 .849 r
.66237 .43379 .66318 .435 .66485 .43491 .66401 .43299 Mtetra
.607 .576 .793 r
.66401 .43299 .66485 .43491 .66656 .43557 .66568 .43273 Mtetra
.208 .262 .699 r
.66568 .43273 .66656 .43557 .66848 .44113 .66745 .43487 Mtetra
.864 .597 .066 r
.66745 .43487 .66848 .44113 .6789 .63744 .66996 .45368 Mtetra
.041 0 .437 r
.66996 .45368 .6789 .63744 .68087 .64156 .6799 .63769 Mtetra
.37 .333 .686 r
.6799 .63769 .68087 .64156 .68269 .64217 .68177 .63955 Mtetra
.518 .483 .757 r
.68177 .63955 .68269 .64217 .68446 .64175 .68358 .63994 Mtetra
.586 .588 .82 r
.68358 .63994 .68446 .64175 .68621 .64084 .68536 .63979 Mtetra
.521 .679 .937 r
.68536 .63979 .68621 .64084 .68797 .64012 .68715 .63976 Mtetra
.471 .838 .992 r
.68715 .63976 .68797 .64012 .68971 .63917 .68893 .63945 Mtetra
.431 .86 .737 r
.68893 .63945 .68971 .63917 .69143 .63751 .69069 .63853 Mtetra
.785 .894 .483 r
.69069 .63853 .69143 .63751 .69296 .63195 .69234 .63544 Mtetra
.813 .728 .199 r
.69234 .63544 .69296 .63195 .68501 .43386 .69367 .62603 Mtetra
.037 0 .43 r
.69367 .62603 .68501 .43386 .68643 .42827 .68579 .43042 Mtetra
0 0 0 r
.68579 .43042 .68643 .42827 .68804 .42668 .68733 .42728 Mtetra
.47 .821 .544 r
.68733 .42728 .68804 .42668 .68971 .42619 .68895 .42588 Mtetra
.712 .929 .962 r
.68895 .42588 .68971 .42619 .6914 .4261 .69061 .42504 Mtetra
.674 .727 .889 r
.69061 .42504 .6914 .4261 .69308 .42578 .69227 .42446 Mtetra
.637 .666 .861 r
.69227 .42446 .69308 .42578 .69475 .42529 .69395 .42405 Mtetra
.619 .67 .877 r
.69395 .42405 .69475 .42529 .69642 .42477 .69563 .42373 Mtetra
.648 .72 .901 r
.69563 .42373 .69642 .42477 .69808 .4241 .69731 .42327 Mtetra
.669 .777 .93 r
.69731 .42327 .69808 .4241 .69975 .4234 .69898 .42271 Mtetra
.674 .815 .951 r
.69898 .42271 .69975 .4234 .70142 .42281 .70065 .42212 Mtetra
.753 .833 .913 r
.70065 .42212 .70142 .42281 .70309 .42233 .7023 .42118 Mtetra
.72 .728 .857 r
.7023 .42118 .70309 .42233 .70479 .42215 .70396 .42033 Mtetra
.624 .594 .8 r
.70396 .42033 .70479 .42215 .70652 .42265 .70564 .41996 Mtetra
.308 .338 .73 r
.70564 .41996 .70652 .42265 .70846 .42672 .70744 .42158 Mtetra
0 0 .383 r
.70744 .42158 .70846 .42672 .72143 .6242 .70963 .4299 Mtetra
.062 0 .449 r
.70963 .4299 .72143 .6242 .72353 .62916 .72252 .62486 Mtetra
.326 .292 .667 r
.72252 .62486 .72353 .62916 .72541 .63008 .72448 .62735 Mtetra
.507 .471 .751 r
.72448 .62735 .72541 .63008 .72721 .62965 .72633 .62784 Mtetra
.578 .584 .823 r
.72633 .62784 .72721 .62965 .72898 .6287 .72815 .62774 Mtetra
.52 .7 .951 r
.72815 .62774 .72898 .6287 .73076 .62792 .72998 .62768 Mtetra
.365 .809 .953 r
.72998 .62768 .73076 .62792 .73253 .62708 .73179 .62743 Mtetra
.303 .771 .644 r
.73179 .62743 .73253 .62708 .73427 .62559 .73357 .62659 Mtetra
.674 .847 .434 r
.73357 .62659 .73427 .62559 .73581 .62086 .73524 .62387 Mtetra
.761 .708 .171 r
.73524 .62387 .73581 .62086 .72537 .42219 .73658 .61591 Mtetra
.058 0 .442 r
.73658 .61591 .72537 .42219 .72669 .41581 .72613 .41824 Mtetra
0 0 .047 r
.72613 .41824 .72669 .41581 .72829 .41386 .72763 .41456 Mtetra
0 0 0 r
.72763 .41456 .72829 .41386 .72998 .41329 .72926 .41306 Mtetra
.715 .953 .951 r
.72926 .41306 .72998 .41329 .7317 .41313 .73093 .41213 Mtetra
.697 .752 .894 r
.73093 .41213 .7317 .41313 .7334 .41277 .73261 .41144 Mtetra
.664 .677 .852 r
.73261 .41144 .7334 .41277 .73509 .4122 .7343 .41088 Mtetra
.643 .669 .86 r
.7343 .41088 .73509 .4122 .73679 .41173 .736 .41043 Mtetra
.686 .693 .851 r
.736 .41043 .73679 .41173 .73849 .41131 .73769 .40975 Mtetra
.681 .654 .816 r
.73769 .40975 .73849 .41131 .74021 .41112 .73937 .40903 Mtetra
.607 .563 .778 r
.73937 .40903 .74021 .41112 .74198 .41158 .74109 .40875 Mtetra
.286 .316 .718 r
.74109 .40875 .74198 .41158 .74403 .41623 .74295 .41061 Mtetra
.978 .682 .369 r
.74295 .41061 .74403 .41623 .75933 .61513 .75662 .58617 Mtetra
.087 .024 .482 r
.75662 .58617 .75933 .61513 .76145 .61905 .76042 .61494 Mtetra
.617 .487 .682 r
.76042 .61494 .76145 .61905 .76323 .61798 .76223 .61431 Mtetra
.936 .675 .517 r
.76223 .61431 .76323 .61798 .76452 .61005 .76279 .59571 Mtetra
.961 .67 .434 r
.76279 .59571 .76452 .61005 .75229 .40986 .75149 .40828 Mtetra
.849 .714 .713 r
.75149 .40828 .75229 .40986 .75379 .40647 .75304 .40552 Mtetra
.705 .766 .9 r
.75304 .40552 .75379 .40647 .75548 .40568 .75473 .40478 Mtetra
.597 .738 .943 r
.75473 .40478 .75548 .40568 .75721 .40544 .75645 .40448 Mtetra
.622 .736 .928 r
.75645 .40448 .75721 .40544 .75893 .40506 .75817 .40411 Mtetra
.68 .758 .91 r
.75817 .40411 .75893 .40506 .76063 .40438 .75988 .40349 Mtetra
.685 .774 .919 r
.75988 .40349 .76063 .40438 .76233 .40379 .76158 .40286 Mtetra
.745 .782 .883 r
.76158 .40286 .76233 .40379 .76404 .40323 .76326 .40191 Mtetra
.736 .709 .825 r
.76326 .40191 .76404 .40323 .76576 .40283 .76494 .40086 Mtetra
.642 .593 .783 r
.76494 .40086 .76576 .40283 .76753 .40298 .76665 .40034 Mtetra
.365 .379 .742 r
.76665 .40034 .76753 .40298 .76946 .40532 .76851 .40169 Mtetra
.763 .474 0 r
.76851 .40169 .76946 .40532 .7862 .60163 .77109 .41248 Mtetra
.075 .002 .461 r
.77109 .41248 .7862 .60163 .78869 .60971 .78785 .60817 Mtetra
0 .066 .628 r
.78785 .60817 .78869 .60971 .79071 .6116 .78992 .61071 Mtetra
.446 .683 .966 r
.78992 .61071 .79071 .6116 .79259 .61166 .7918 .61081 Mtetra
.743 .814 .908 r
.7918 .61081 .79259 .61166 .79439 .61075 .79361 .60984 Mtetra
.915 .81 .728 r
.79361 .60984 .79439 .61075 .79604 .60784 .79524 .60678 Mtetra
.978 .721 .473 r
.79524 .60678 .79604 .60784 .79685 .59432 .79576 .58957 Mtetra
.974 .679 .397 r
.79576 .58957 .79685 .59432 .78309 .39929 .78231 .39791 Mtetra
.874 .742 .713 r
.78231 .39791 .78309 .39929 .78461 .39624 .78384 .395 Mtetra
.684 .703 .862 r
.78384 .395 .78461 .39624 .78632 .39549 .78556 .39433 Mtetra
.568 .667 .905 r
.78556 .39433 .78632 .39549 .78807 .39527 .78732 .39419 Mtetra
.568 .684 .919 r
.78732 .39419 .78807 .39527 .78982 .39502 .78907 .39404 Mtetra
.664 .748 .913 r
.78907 .39404 .78982 .39502 .79154 .39439 .7908 .39349 Mtetra
.676 .771 .922 r
.7908 .39349 .79154 .39439 .79326 .39381 .79253 .39288 Mtetra
.731 .782 .894 r
.79253 .39288 .79326 .39381 .79499 .39327 .79423 .39201 Mtetra
.744 .725 .834 r
.79423 .39201 .79499 .39327 .79673 .39281 .79591 .39093 Mtetra
.656 .609 .79 r
.79591 .39093 .79673 .39281 .79851 .39282 .79764 .39031 Mtetra
.444 .438 .758 r
.79764 .39031 .79851 .39282 .80043 .39446 .79949 .39117 Mtetra
0 0 .418 r
.79949 .39117 .80043 .39446 .81805 .57825 .80181 .39741 Mtetra
.05 0 .457 r
.80181 .39741 .81805 .57825 .82175 .59914 .82089 .59727 Mtetra
0 .027 .599 r
.82089 .59727 .82175 .59914 .82384 .60132 .82307 .6004 Mtetra
.579 .741 .953 r
.82307 .6004 .82384 .60132 .82571 .60099 .82494 .60012 Mtetra
.749 .816 .905 r
.82494 .60012 .82571 .60099 .82753 .60005 .82676 .59911 Mtetra
.767 .803 .883 r
.82676 .59911 .82753 .60005 .82935 .59906 .82856 .59796 Mtetra
.683 .747 .9 r
.82856 .59796 .82935 .59906 .83121 .59849 .83041 .59728 Mtetra
.672 .72 .885 r
.83041 .59728 .83121 .59849 .83306 .59796 .83226 .59665 Mtetra
.65 .692 .876 r
.83226 .59665 .83306 .59796 .83493 .59747 .83412 .59612 Mtetra
.622 .675 .879 r
.83412 .59612 .83493 .59747 .8368 .597 .836 .59575 Mtetra
.609 .685 .896 r
.836 .59575 .8368 .597 .83867 .59656 .83788 .59542 Mtetra
.546 .678 .925 r
.83788 .59542 .83867 .59656 .84056 .59637 .83979 .59533 Mtetra
.452 .652 .945 r
.83979 .59533 .84056 .59637 .84249 .5965 .84172 .5955 Mtetra
.623 .743 .933 r
.84172 .5955 .84249 .5965 .84437 .59607 .8436 .59508 Mtetra
.864 .812 .797 r
.8436 .59508 .84437 .59607 .84609 .59396 .84532 .59298 Mtetra
.981 .743 .504 r
.84532 .59298 .84609 .59396 .84698 .58307 .84621 .58207 Mtetra
.977 .678 .362 r
.84621 .58207 .84698 .58307 .83004 .38492 .82931 .3839 Mtetra
.93 .79 .685 r
.82931 .3839 .83004 .38492 .83151 .38135 .83078 .38034 Mtetra
.722 .764 .886 r
.83078 .38034 .83151 .38135 .83323 .38051 .8325 .37949 Mtetra
.597 .714 .926 r
.8325 .37949 .83323 .38051 .83501 .38023 .83428 .3792 Mtetra
.597 .713 .925 r
.83428 .3792 .83501 .38023 .83679 .37995 .83606 .37892 Mtetra
.736 .767 .878 r
.83606 .37892 .83679 .37995 .83851 .37902 .83778 .37799 Mtetra
.653 .737 .911 r
.83778 .37799 .83851 .37902 .84027 .37851 .83954 .37748 Mtetra
.231 .506 .906 r
.83954 .37748 .84027 .37851 .84216 .3793 .84143 .37823 Mtetra
.881 .49 .03 r
.84143 .37823 .84216 .3793 .84475 .38715 .84396 .38543 Mtetra
.975 .667 .331 r
.84396 .38543 .84475 .38715 .86658 .58674 .86579 .58541 Mtetra
0 0 .453 r
.86579 .58541 .86658 .58674 .86884 .58996 .86806 .58879 Mtetra
.433 .614 .926 r
.86806 .58879 .86884 .58996 .87079 .59011 .87003 .58909 Mtetra
.7 .772 .907 r
.87003 .58909 .87079 .59011 .87265 .58926 .87189 .58831 Mtetra
.883 .823 .784 r
.87189 .58831 .87265 .58926 .87437 .58716 .8736 .58601 Mtetra
.975 .751 .535 r
.8736 .58601 .87437 .58716 .87573 .58144 .87465 .5773 Mtetra
.976 .673 .358 r
.87465 .5773 .87573 .58144 .85685 .38058 .85576 .37592 Mtetra
.76 .561 .628 r
.85576 .37592 .85685 .38058 .85808 .37476 .85716 .37185 Mtetra
.656 .544 .716 r
.85716 .37185 .85808 .37476 .85973 .37316 .8589 .37095 Mtetra
.605 .556 .773 r
.8589 .37095 .85973 .37316 .86147 .37225 .8607 .37068 Mtetra
.583 .611 .845 r
.8607 .37068 .86147 .37225 .86322 .37157 .86251 .37054 Mtetra
.738 .769 .878 r
.86251 .37054 .86322 .37157 .86495 .37061 .86424 .36958 Mtetra
.663 .743 .91 r
.86424 .36958 .86495 .37061 .86673 .37008 .86601 .36902 Mtetra
.346 .572 .924 r
.86601 .36902 .86673 .37008 .8686 .37044 .8679 .36952 Mtetra
.857 .45 0 r
.8679 .36952 .8686 .37044 .87085 .37427 .87041 .37576 Mtetra
.973 .662 .329 r
.87041 .37576 .87085 .37427 .89439 .57373 .89412 .57708 Mtetra
.741 .395 .395 r
.89412 .57708 .89439 .57373 .89699 .57958 .89648 .58079 Mtetra
.414 0 .084 r
.89648 .58079 .89699 .57958 .89902 .58026 .89843 .58065 Mtetra
0 0 0 r
.89843 .58065 .89902 .58026 .90097 .58014 .9003 .57979 Mtetra
.738 .951 .947 r
.9003 .57979 .90097 .58014 .90289 .5797 .90215 .5787 Mtetra
.524 .702 .951 r
.90215 .5787 .90289 .5797 .90485 .57964 .9041 .57862 Mtetra
.642 .754 .93 r
.9041 .57862 .90485 .57964 .90675 .57909 .90602 .57811 Mtetra
.822 .819 .847 r
.90602 .57811 .90675 .57909 .90856 .57761 .90781 .57653 Mtetra
.979 .761 .539 r
.90781 .57653 .90856 .57761 .90992 .57221 .90888 .56859 Mtetra
.976 .67 .338 r
.90888 .56859 .90992 .57221 .88897 .37122 .88782 .36626 Mtetra
.765 .56 .62 r
.88782 .36626 .88897 .37122 .89009 .36476 .88917 .36178 Mtetra
.655 .541 .714 r
.88917 .36178 .89009 .36476 .89176 .36315 .89091 .36088 Mtetra
.6 .549 .77 r
.89091 .36088 .89176 .36315 .89351 .36226 .89274 .36064 Mtetra
.538 .58 .845 r
.89274 .36064 .89351 .36226 .8953 .36174 .89461 .36073 Mtetra
.63 .736 .924 r
.89461 .36073 .8953 .36174 .8971 .36121 .89642 .36031 Mtetra
.635 .763 .94 r
.89642 .36031 .8971 .36121 .89891 .36078 .89822 .35984 Mtetra
.65 .762 .931 r
.89822 .35984 .89891 .36078 .90072 .36037 .90002 .35933 Mtetra
.689 .754 .901 r
.90002 .35933 .90072 .36037 .90251 .35979 .9018 .35864 Mtetra
.679 .726 .886 r
.9018 .35864 .90251 .35979 .9043 .35917 .90359 .35799 Mtetra
.655 .71 .888 r
.90359 .35799 .9043 .35917 .90608 .35849 .90539 .35745 Mtetra
.637 .732 .917 r
.90539 .35745 .90608 .35849 .90781 .35737 .9072 .357 Mtetra
.287 .735 .96 r
.9072 .357 .90781 .35737 .90958 .35658 .90907 .357 Mtetra
.569 .019 0 r
.90907 .357 .90958 .35658 .91144 .35644 .91105 .35793 Mtetra
.927 .56 .301 r
.91105 .35793 .91144 .35644 .91369 .35957 .91435 .36961 Mtetra
.969 .65 .339 r
.91435 .36961 .91369 .35957 .93995 .55823 .94014 .56464 Mtetra
.664 .367 .459 r
.94014 .56464 .93995 .55823 .94297 .56652 .94253 .5678 Mtetra
.586 .803 .982 r
.32006 .7405 .32105 .74108 .32258 .74104 .3216 .74019 Mtetra
.707 .761 .894 r
.3216 .74019 .32258 .74104 .32414 .74041 .32317 .73949 Mtetra
.732 .753 .87 r
.32317 .73949 .32414 .74041 .32572 .73947 .32474 .73864 Mtetra
.498 .706 .963 r
.32474 .73864 .32572 .73947 .32727 .7392 .32627 .73862 Mtetra
.515 .779 .992 r
.32627 .73862 .32727 .7392 .32881 .7389 .32781 .73845 Mtetra
.662 .854 .973 r
.32781 .73845 .32881 .7389 .33037 .73846 .32938 .73789 Mtetra
.866 .807 .79 r
.32938 .73789 .33037 .73846 .33193 .73783 .33102 .73582 Mtetra
.829 .664 .679 r
.33102 .73582 .33193 .73783 .33352 .73676 .33276 .73207 Mtetra
.872 .643 .589 r
.33276 .73207 .33352 .73676 .33516 .73484 .33517 .71554 Mtetra
.911 .66 .545 r
.33517 .71554 .33516 .73484 .33712 .72678 .34617 .53751 Mtetra
.569 .358 .554 r
.34617 .53751 .33712 .72678 .3486 .53718 .3478 .53404 Mtetra
.72 .566 .68 r
.3478 .53404 .3486 .53718 .35027 .53303 .34936 .53208 Mtetra
.724 .735 .86 r
.34936 .53208 .35027 .53303 .35177 .53197 .35085 .53129 Mtetra
.644 .782 .947 r
.35085 .53129 .35177 .53197 .35324 .53158 .35232 .53088 Mtetra
.594 .764 .96 r
.35232 .53088 .35324 .53158 .3547 .53146 .35379 .53061 Mtetra
.741 .758 .866 r
.35379 .53061 .3547 .53146 .35619 .53084 .35529 .52975 Mtetra
.711 .708 .845 r
.35529 .52975 .35619 .53084 .35767 .53022 .35678 .529 Mtetra
.643 .666 .858 r
.35678 .529 .35767 .53022 .35915 .52973 .35825 .52861 Mtetra
.034 .367 .837 r
.35825 .52861 .35915 .52973 .36062 .52941 .35967 .5295 Mtetra
.839 .425 .253 r
.35967 .5295 .36062 .52941 .36208 .52948 .36101 .53189 Mtetra
.874 .587 .5 r
.36101 .53189 .36208 .52948 .3635 .5303 .36192 .54321 Mtetra
.919 .661 .532 r
.36192 .54321 .3635 .5303 .36468 .53608 .35466 .72499 Mtetra
.567 .352 .549 r
.35466 .72499 .36468 .53608 .35717 .72608 .35607 .72806 Mtetra
.671 .322 .373 r
.35607 .72806 .35717 .72608 .35853 .73 .35755 .72941 Mtetra
.072 .545 .898 r
.35755 .72941 .35853 .73 .36005 .73058 .35908 .72983 Mtetra
.549 .748 .969 r
.35908 .72983 .36005 .73058 .36162 .73027 .36064 .72965 Mtetra
.717 .822 .93 r
.36064 .72965 .36162 .73027 .36321 .72949 .36223 .72892 Mtetra
.859 .817 .806 r
.36223 .72892 .36321 .72949 .3648 .72881 .36387 .72702 Mtetra
.833 .678 .69 r
.36387 .72702 .3648 .72881 .3664 .72779 .36558 .7236 Mtetra
.845 .629 .609 r
.36558 .7236 .3664 .72779 .36803 .72599 .36757 .71393 Mtetra
.926 .672 .534 r
.36757 .71393 .36803 .72599 .36987 .71965 .37729 .52841 Mtetra
.569 .358 .554 r
.37729 .52841 .36987 .71965 .37972 .52828 .37894 .52452 Mtetra
.709 .545 .664 r
.37894 .52452 .37972 .52828 .38139 .52354 .3805 .52241 Mtetra
.732 .709 .83 r
.3805 .52241 .38139 .52354 .38292 .52221 .38201 .5215 Mtetra
.65 .777 .941 r
.38201 .5215 .38292 .52221 .38441 .52178 .3835 .52107 Mtetra
.59 .761 .96 r
.3835 .52107 .38441 .52178 .38589 .52167 .38499 .5208 Mtetra
.726 .756 .876 r
.38499 .5208 .38589 .52167 .38739 .52115 .38649 .52003 Mtetra
.712 .706 .843 r
.38649 .52003 .38739 .52115 .38889 .52054 .388 .51927 Mtetra
.647 .661 .849 r
.388 .51927 .38889 .52054 .39038 .52006 .3895 .51885 Mtetra
.02 .335 .817 r
.3895 .51885 .39038 .52006 .39186 .52008 .39093 .51985 Mtetra
.872 .455 .223 r
.39093 .51985 .39186 .52008 .39333 .52039 .3923 .52266 Mtetra
.893 .608 .497 r
.3923 .52266 .39333 .52039 .39479 .52081 .39321 .53731 Mtetra
.916 .655 .529 r
.39321 .53731 .39479 .52081 .39628 .52067 .38799 .71056 Mtetra
.561 .347 .548 r
.38799 .71056 .39628 .52067 .39778 .52014 .38957 .71014 Mtetra
.556 .344 .547 r
.38957 .71014 .39778 .52014 .39929 .51948 .39125 .70722 Mtetra
.563 .349 .548 r
.39125 .70722 .39929 .51948 .40079 .51905 .39279 .70802 Mtetra
.562 .348 .548 r
.39279 .70802 .40079 .51905 .40229 .51863 .39434 .70854 Mtetra
.556 .343 .547 r
.39434 .70854 .40229 .51863 .4038 .51803 .39603 .70551 Mtetra
0 0 .324 r
.39603 .70551 .4038 .51803 .40533 .51682 .40424 .52141 Mtetra
0 0 .076 r
.40424 .52141 .40533 .51682 .40687 .51548 .40592 .51616 Mtetra
.946 .959 .703 r
.40592 .51616 .40687 .51548 .4084 .51431 .40751 .51341 Mtetra
.78 .759 .834 r
.40751 .51341 .4084 .51431 .40992 .51358 .40904 .51223 Mtetra
.661 .656 .834 r
.40904 .51223 .40992 .51358 .41142 .5131 .41055 .51172 Mtetra
.61 .631 .846 r
.41055 .51172 .41142 .5131 .41293 .51273 .41205 .51148 Mtetra
.612 .651 .865 r
.41205 .51148 .41293 .51273 .41443 .51237 .41355 .51122 Mtetra
.615 .672 .881 r
.41355 .51122 .41443 .51237 .41594 .512 .41506 .51095 Mtetra
.613 .689 .897 r
.41506 .51095 .41594 .512 .41745 .51162 .41656 .51067 Mtetra
.634 .718 .908 r
.41656 .51067 .41745 .51162 .41896 .5112 .41807 .51031 Mtetra
.655 .739 .911 r
.41807 .51031 .41896 .5112 .42047 .51072 .41958 .50986 Mtetra
.671 .75 .91 r
.41958 .50986 .42047 .51072 .42199 .51021 .4211 .50935 Mtetra
.693 .755 .899 r
.4211 .50935 .42199 .51021 .4235 .50965 .42262 .50875 Mtetra
.702 .747 .886 r
.42262 .50875 .4235 .50965 .42502 .50907 .42414 .50809 Mtetra
.698 .731 .876 r
.42414 .50809 .42502 .50907 .42654 .50848 .42566 .50744 Mtetra
.68 .714 .874 r
.42566 .50744 .42654 .50848 .42806 .50794 .42718 .50687 Mtetra
.667 .705 .876 r
.42718 .50687 .42806 .50794 .42958 .50743 .4287 .50637 Mtetra
.663 .705 .879 r
.4287 .50637 .42958 .50743 .4311 .50692 .43022 .50588 Mtetra
.664 .709 .881 r
.43022 .50588 .4311 .50692 .43262 .50642 .43174 .50539 Mtetra
.666 .713 .884 r
.43174 .50539 .43262 .50642 .43414 .50591 .43326 .5049 Mtetra
.665 .716 .886 r
.43326 .5049 .43414 .50591 .43566 .50541 .43478 .50441 Mtetra
.696 .726 .874 r
.43478 .50441 .43566 .50541 .43719 .50468 .43631 .50377 Mtetra
.695 .744 .889 r
.43631 .50377 .43719 .50468 .43872 .50399 .43783 .50314 Mtetra
.628 .741 .929 r
.43783 .50314 .43872 .50399 .44024 .50373 .43935 .50278 Mtetra
.141 .479 .898 r
.43935 .50278 .44024 .50373 .44171 .50522 .44085 .50343 Mtetra
0 .015 .589 r
.44085 .50343 .44171 .50522 .44305 .5124 .44231 .50556 Mtetra
.104 .071 .533 r
.44231 .50556 .44305 .5124 .43997 .70343 .4437 .51088 Mtetra
0 0 .373 r
.4437 .51088 .43997 .70343 .44152 .70565 .44093 .69048 Mtetra
.543 .361 .584 r
.44093 .69048 .44152 .70565 .44314 .7054 .44251 .69143 Mtetra
.687 .474 .593 r
.44251 .69143 .44314 .7054 .44477 .7045 .44427 .68483 Mtetra
.92 .66 .528 r
.44427 .68483 .44477 .7045 .4464 .70373 .44961 .51873 Mtetra
.565 .354 .554 r
.44961 .51873 .4464 .70373 .44802 .70325 .45117 .51736 Mtetra
.564 .354 .554 r
.45117 .51736 .44802 .70325 .44965 .70277 .45273 .51622 Mtetra
.563 .353 .554 r
.45273 .51622 .44965 .70277 .45127 .70231 .45427 .51552 Mtetra
.45427 .51552 .45127 .70231 .4529 .70186 .45581 .51518 Mtetra
.562 .352 .554 r
.45581 .51518 .4529 .70186 .45452 .70143 .45735 .51506 Mtetra
.562 .352 .553 r
.45735 .51506 .45452 .70143 .45615 .701 .45888 .51525 Mtetra
.561 .351 .553 r
.45888 .51525 .45615 .701 .45778 .70058 .4604 .51576 Mtetra
.4604 .51576 .45778 .70058 .45941 .70015 .46193 .5164 Mtetra
.562 .353 .554 r
.46193 .5164 .45941 .70015 .46104 .69972 .46347 .51624 Mtetra
.564 .354 .554 r
.46347 .51624 .46104 .69972 .46267 .69926 .46503 .51513 Mtetra
.46503 .51513 .46267 .69926 .4643 .6988 .46659 .51399 Mtetra
.573 .361 .555 r
.46659 .51399 .4643 .6988 .46594 .69824 .46823 .50833 Mtetra
.568 .357 .554 r
.46823 .50833 .46594 .69824 .46758 .69764 .46982 .50507 Mtetra
.56 .351 .553 r
.46982 .50507 .46758 .69764 .46921 .69722 .47135 .50596 Mtetra
0 0 .376 r
.47135 .50596 .46921 .69722 .47084 .69732 .47004 .68846 Mtetra
.2 .129 .547 r
.47004 .68846 .47084 .69732 .47246 .69779 .47157 .69448 Mtetra
.148 .198 .659 r
.47157 .69448 .47246 .69779 .47409 .69813 .47317 .69693 Mtetra
.212 .475 .888 r
.47317 .69693 .47409 .69813 .47572 .69809 .47479 .69767 Mtetra
.534 .84 .999 r
.47479 .69767 .47572 .69809 .47737 .69766 .47643 .69734 Mtetra
.649 .899 .983 r
.47643 .69734 .47737 .69766 .47901 .69712 .47808 .69671 Mtetra
.665 .879 .978 r
.47808 .69671 .47901 .69712 .48065 .69659 .47973 .69608 Mtetra
.623 .843 .984 r
.47973 .69608 .48065 .69659 .4823 .69613 .48137 .69561 Mtetra
.616 .837 .984 r
.48137 .69561 .4823 .69613 .48394 .69569 .48302 .69515 Mtetra
.581 .823 .99 r
.48302 .69515 .48394 .69569 .48559 .6953 .48467 .69479 Mtetra
.535 .814 .997 r
.48467 .69479 .48559 .6953 .48724 .69497 .48631 .69451 Mtetra
.529 .828 .999 r
.48631 .69451 .48724 .69497 .48888 .69462 .48796 .69421 Mtetra
.579 .859 .996 r
.48796 .69421 .48888 .69462 .49053 .6942 .48961 .69378 Mtetra
.65 .875 .982 r
.48961 .69378 .49053 .6942 .49218 .6937 .49126 .6932 Mtetra
.673 .857 .969 r
.49126 .6932 .49218 .6937 .49384 .69318 .49292 .69257 Mtetra
.632 .82 .973 r
.49292 .69257 .49384 .69318 .49549 .69285 .49457 .6921 Mtetra
.583 .769 .968 r
.49457 .6921 .49549 .69285 .49714 .69268 .49622 .69182 Mtetra
.661 .764 .926 r
.49622 .69182 .49714 .69268 .4988 .69211 .49788 .6913 Mtetra
.798 .797 .851 r
.49788 .6913 .4988 .69211 .50046 .69018 .49954 .68998 Mtetra
.935 .865 .746 r
.49954 .68998 .50046 .69018 .50215 .68415 .50121 .68708 Mtetra
0 0 0 r
.50121 .68708 .50215 .68415 .50497 .48963 .5029 .68203 Mtetra
.546 .335 .546 r
.5029 .68203 .50497 .48963 .50656 .48517 .50461 .67272 Mtetra
.562 .348 .548 r
.50461 .67272 .50656 .48517 .50813 .4844 .50626 .67308 Mtetra
.563 .349 .548 r
.50626 .67308 .50813 .4844 .50969 .48421 .5079 .67394 Mtetra
0 0 .386 r
.5079 .67394 .50969 .48421 .51125 .4837 .51035 .49309 Mtetra
0 0 .311 r
.51035 .49309 .51125 .4837 .51282 .48233 .51195 .48413 Mtetra
.698 .803 .339 r
.51195 .48413 .51282 .48233 .51439 .48108 .51353 .48064 Mtetra
.878 .861 .819 r
.51353 .48064 .51439 .48108 .51596 .48013 .5151 .47882 Mtetra
.686 .676 .834 r
.5151 .47882 .51596 .48013 .51753 .47959 .51667 .47815 Mtetra
.632 .637 .837 r
.51667 .47815 .51753 .47959 .5191 .47916 .51824 .47779 Mtetra
.623 .643 .849 r
.51824 .47779 .5191 .47916 .52066 .47874 .51981 .47747 Mtetra
.659 .673 .852 r
.51981 .47747 .52066 .47874 .52223 .47823 .52138 .47697 Mtetra
.655 .672 .855 r
.52138 .47697 .52223 .47823 .52381 .47774 .52295 .47649 Mtetra
.643 .671 .862 r
.52295 .47649 .52381 .47774 .52538 .47727 .52453 .47608 Mtetra
.623 .673 .877 r
.52453 .47608 .52538 .47727 .52695 .47685 .5261 .47576 Mtetra
.625 .692 .893 r
.5261 .47576 .52695 .47685 .52853 .47642 .52767 .47542 Mtetra
.651 .722 .901 r
.52767 .47542 .52853 .47642 .5301 .47593 .52925 .47498 Mtetra
.695 .745 .89 r
.52925 .47498 .5301 .47593 .53168 .47534 .53083 .47434 Mtetra
.7 .736 .879 r
.53083 .47434 .53168 .47534 .53325 .47473 .5324 .47366 Mtetra
.691 .72 .871 r
.5324 .47366 .53325 .47473 .53483 .47414 .53398 .47302 Mtetra
.669 .703 .873 r
.53398 .47302 .53483 .47414 .53641 .4736 .53556 .47248 Mtetra
.663 .701 .875 r
.53556 .47248 .53641 .4736 .53799 .47308 .53714 .47198 Mtetra
.662 .703 .877 r
.53714 .47198 .53799 .47308 .53957 .47257 .53872 .47148 Mtetra
.664 .706 .879 r
.53872 .47148 .53957 .47257 .54115 .47206 .5403 .47097 Mtetra
.664 .707 .879 r
.5403 .47097 .54115 .47206 .54273 .47155 .54188 .47046 Mtetra
.663 .707 .88 r
.54188 .47046 .54273 .47155 .54431 .47104 .54347 .46995 Mtetra
.54347 .46995 .54431 .47104 .5459 .47054 .54505 .46945 Mtetra
.54505 .46945 .5459 .47054 .54748 .47003 .54664 .46894 Mtetra
.54664 .46894 .54748 .47003 .54907 .46953 .54822 .46844 Mtetra
.54822 .46844 .54907 .46953 .55065 .46902 .54981 .46793 Mtetra
.54981 .46793 .55065 .46902 .55224 .46852 .5514 .46743 Mtetra
.5514 .46743 .55224 .46852 .55383 .46802 .55299 .46692 Mtetra
.662 .707 .88 r
.55299 .46692 .55383 .46802 .55542 .46751 .55458 .46642 Mtetra
.55458 .46642 .55542 .46751 .55701 .46701 .55617 .46592 Mtetra
.662 .706 .88 r
.55617 .46592 .55701 .46701 .5586 .46651 .55776 .46541 Mtetra
.55776 .46541 .5586 .46651 .56019 .46601 .55935 .46491 Mtetra
.55935 .46491 .56019 .46601 .56178 .4655 .56094 .46441 Mtetra
.662 .707 .88 r
.56094 .46441 .56178 .4655 .56338 .465 .56254 .4639 Mtetra
.56254 .4639 .56338 .465 .56497 .4645 .56413 .4634 Mtetra
.662 .707 .881 r
.56413 .4634 .56497 .4645 .56657 .46399 .56573 .4629 Mtetra
.56573 .4629 .56657 .46399 .56817 .46349 .56733 .46239 Mtetra
.56733 .46239 .56817 .46349 .56976 .46299 .56893 .46189 Mtetra
.56893 .46189 .56976 .46299 .57136 .46249 .57053 .46139 Mtetra
.57053 .46139 .57136 .46249 .57296 .46198 .57213 .46089 Mtetra
.57213 .46089 .57296 .46198 .57456 .46148 .57373 .46038 Mtetra
.57373 .46038 .57456 .46148 .57616 .46098 .57533 .45988 Mtetra
.57533 .45988 .57616 .46098 .57777 .46047 .57693 .45938 Mtetra
.661 .707 .881 r
.57693 .45938 .57777 .46047 .57937 .45997 .57853 .45887 Mtetra
.57853 .45887 .57937 .45997 .58097 .45947 .58014 .45837 Mtetra
.661 .706 .881 r
.58014 .45837 .58097 .45947 .58258 .45898 .58174 .45787 Mtetra
.663 .706 .879 r
.58174 .45787 .58258 .45898 .58418 .45848 .58335 .45736 Mtetra
.66 .702 .878 r
.58335 .45736 .58418 .45848 .58579 .45799 .58496 .45686 Mtetra
.652 .697 .879 r
.58496 .45686 .58579 .45799 .5874 .45753 .58657 .4564 Mtetra
.624 .688 .889 r
.58657 .4564 .5874 .45753 .58901 .45712 .58818 .45606 Mtetra
.624 .701 .901 r
.58818 .45606 .58901 .45712 .59062 .45672 .58979 .45572 Mtetra
.639 .721 .907 r
.58979 .45572 .59062 .45672 .59223 .45628 .59141 .45531 Mtetra
.695 .747 .892 r
.59141 .45531 .59223 .45628 .59384 .45571 .59302 .45466 Mtetra
.7 .731 .874 r
.59302 .45466 .59384 .45571 .59545 .45511 .59463 .45396 Mtetra
.696 .71 .859 r
.59463 .45396 .59545 .45511 .59707 .45451 .59623 .45326 Mtetra
.705 .698 .84 r
.59623 .45326 .59707 .45451 .59868 .45389 .59784 .45248 Mtetra
.664 .659 .835 r
.59784 .45248 .59868 .45389 .60029 .45335 .59946 .45193 Mtetra
.586 .621 .854 r
.59946 .45193 .60029 .45335 .60191 .45297 .60108 .45178 Mtetra
0 .204 .729 r
.60108 .45178 .60191 .45297 .60354 .45309 .60275 .45326 Mtetra
.866 .448 .226 r
.60275 .45326 .60354 .45309 .60518 .4534 .60446 .45666 Mtetra
.96 .678 .455 r
.60446 .45666 .60518 .4534 .60682 .45376 .61072 .64317 Mtetra
.563 .349 .548 r
.61072 .64317 .60682 .45376 .60843 .45283 .61248 .6444 Mtetra
.558 .345 .547 r
.61248 .6444 .60843 .45283 .61005 .45216 .61415 .64205 Mtetra
.563 .349 .548 r
.61415 .64205 .61005 .45216 .61169 .45227 .6159 .64293 Mtetra
.575 .359 .549 r
.6159 .64293 .61169 .45227 .61356 .46096 .61788 .65196 Mtetra
.566 .351 .548 r
.61788 .65196 .61356 .46096 .62051 .65377 .61971 .65507 Mtetra
.695 .288 .271 r
.61971 .65507 .62051 .65377 .62235 .65719 .62149 .6566 Mtetra
.325 .699 .981 r
.62149 .6566 .62235 .65719 .6241 .6574 .62324 .65673 Mtetra
.622 .81 .972 r
.62324 .65673 .6241 .6574 .62583 .65689 .62497 .65628 Mtetra
.763 .857 .92 r
.62497 .65628 .62583 .65689 .62755 .65592 .62669 .65526 Mtetra
.883 .837 .796 r
.62669 .65526 .62755 .65592 .62928 .65516 .62838 .65309 Mtetra
.846 .679 .676 r
.62838 .65309 .62928 .65516 .63099 .65397 .63001 .64931 Mtetra
.882 .642 .571 r
.63001 .64931 .63099 .65397 .63268 .65191 .63136 .63605 Mtetra
.948 .67 .477 r
.63136 .63605 .63268 .65191 .63416 .64325 .62723 .44849 Mtetra
.569 .357 .554 r
.62723 .44849 .63416 .64325 .62966 .44813 .62877 .44473 Mtetra
.719 .561 .674 r
.62877 .44473 .62966 .44813 .63117 .44392 .63035 .44265 Mtetra
.697 .694 .844 r
.63035 .44265 .63117 .44392 .63279 .44284 .63198 .44192 Mtetra
.6 .726 .933 r
.63198 .44192 .63279 .44284 .63443 .44249 .63362 .44164 Mtetra
.517 .71 .959 r
.63362 .44164 .63443 .44249 .63608 .44247 .63527 .44157 Mtetra
.627 .742 .93 r
.63527 .44157 .63608 .44247 .63772 .44209 .63691 .44119 Mtetra
.652 .751 .922 r
.63691 .44119 .63772 .44209 .63936 .44164 .63855 .44071 Mtetra
.668 .75 .911 r
.63855 .44071 .63936 .44164 .641 .44116 .64019 .44017 Mtetra
.693 .745 .891 r
.64019 .44017 .641 .44116 .64264 .4406 .64183 .43951 Mtetra
.697 .727 .873 r
.64183 .43951 .64264 .4406 .64428 .44001 .64346 .43882 Mtetra
.691 .706 .86 r
.64346 .43882 .64428 .44001 .64592 .43941 .6451 .43814 Mtetra
.671 .685 .854 r
.6451 .43814 .64592 .43941 .64756 .43887 .64674 .43756 Mtetra
.66 .674 .853 r
.64674 .43756 .64756 .43887 .6492 .43834 .64839 .43703 Mtetra
.65 .67 .855 r
.64839 .43703 .6492 .43834 .65085 .43785 .65003 .43656 Mtetra
.631 .666 .865 r
.65003 .43656 .65085 .43785 .6525 .4374 .65169 .43618 Mtetra
.624 .676 .879 r
.65169 .43618 .6525 .4374 .65415 .43696 .65334 .43584 Mtetra
.626 .695 .894 r
.65334 .43584 .65415 .43696 .6558 .4365 .655 .43548 Mtetra
.651 .726 .904 r
.655 .43548 .6558 .4365 .65745 .43596 .65665 .43502 Mtetra
.668 .748 .91 r
.65665 .43502 .65745 .43596 .65909 .43538 .6583 .43447 Mtetra
.682 .761 .911 r
.6583 .43447 .65909 .43538 .66074 .43477 .65994 .43387 Mtetra
.745 .779 .88 r
.65994 .43387 .66074 .43477 .66237 .43379 .66158 .43294 Mtetra
.73 .787 .898 r
.66158 .43294 .66237 .43379 .66401 .43299 .66322 .4321 Mtetra
.652 .755 .925 r
.66322 .4321 .66401 .43299 .66568 .43273 .66488 .43162 Mtetra
.259 .506 .9 r
.66488 .43162 .66568 .43273 .66745 .43487 .66658 .4323 Mtetra
.156 .245 .705 r
.66658 .4323 .66745 .43487 .66996 .45368 .66836 .43444 Mtetra
.391 .244 .56 r
.66836 .43444 .66996 .45368 .6799 .63769 .67041 .4428 Mtetra
.056 0 .442 r
.67041 .4428 .6799 .63769 .68177 .63955 .68071 .63379 Mtetra
.298 .241 .624 r
.68071 .63379 .68177 .63955 .68358 .63994 .68266 .63733 Mtetra
.314 .357 .747 r
.68266 .63733 .68358 .63994 .68536 .63979 .68452 .63884 Mtetra
.374 .627 .952 r
.68452 .63884 .68536 .63979 .68715 .63976 .68633 .63914 Mtetra
.579 .813 .988 r
.68633 .63914 .68715 .63976 .68893 .63945 .68811 .63877 Mtetra
.74 .845 .929 r
.68811 .63877 .68893 .63945 .69069 .63853 .68986 .63785 Mtetra
.86 .849 .831 r
.68986 .63785 .69069 .63853 .69234 .63544 .69157 .63604 Mtetra
.916 .957 .626 r
.69157 .63604 .69234 .63544 .69367 .62603 .69322 .63296 Mtetra
.078 0 .342 r
.69322 .63296 .69367 .62603 .68579 .43042 .6947 .62633 Mtetra
.056 0 .437 r
.6947 .62633 .68579 .43042 .68733 .42728 .68681 .43177 Mtetra
0 0 .247 r
.68681 .43177 .68733 .42728 .68895 .42588 .68825 .42665 Mtetra
.781 .921 .545 r
.68825 .42665 .68895 .42588 .69061 .42504 .68982 .42414 Mtetra
.761 .786 .873 r
.68982 .42414 .69061 .42504 .69227 .42446 .69146 .4231 Mtetra
.629 .655 .857 r
.69146 .4231 .69227 .42446 .69395 .42405 .69314 .42273 Mtetra
.572 .636 .876 r
.69314 .42273 .69395 .42405 .69563 .42373 .69484 .42262 Mtetra
.619 .696 .899 r
.69484 .42262 .69563 .42373 .69731 .42327 .69652 .42228 Mtetra
.66 .739 .908 r
.69652 .42228 .69731 .42327 .69898 .42271 .69819 .42177 Mtetra
.675 .754 .911 r
.69819 .42177 .69898 .42271 .70065 .42212 .69987 .42119 Mtetra
.735 .776 .885 r
.69987 .42119 .70065 .42212 .7023 .42118 .70152 .42031 Mtetra
.735 .787 .894 r
.70152 .42031 .7023 .42118 .70396 .42033 .70318 .41943 Mtetra
.668 .763 .922 r
.70318 .41943 .70396 .42033 .70564 .41996 .70486 .41888 Mtetra
.354 .57 .921 r
.70486 .41888 .70564 .41996 .70744 .42158 .70659 .41934 Mtetra
.177 .286 .738 r
.70659 .41934 .70744 .42158 .70963 .4299 .7084 .42117 Mtetra
.275 .193 .579 r
.7084 .42117 .70963 .4299 .72252 .62486 .71045 .42699 Mtetra
.078 0 .454 r
.71045 .42699 .72252 .62486 .72448 .62735 .72333 .62066 Mtetra
.297 .23 .61 r
.72333 .62066 .72448 .62735 .72633 .62784 .72539 .62488 Mtetra
.321 .341 .726 r
.72539 .62488 .72633 .62784 .72815 .62774 .72732 .6266 Mtetra
.363 .577 .923 r
.72732 .6266 .72815 .62774 .72998 .62768 .72918 .62705 Mtetra
.547 .802 .993 r
.72918 .62705 .72998 .62768 .73179 .62743 .73099 .62676 Mtetra
.723 .849 .941 r
.73099 .62676 .73179 .62743 .73357 .62659 .73277 .6259 Mtetra
.851 .856 .846 r
.73277 .6259 .73357 .62659 .73524 .62387 .7345 .6242 Mtetra
.938 .962 .676 r
.7345 .6242 .73524 .62387 .73658 .61591 .73615 .62125 Mtetra
0 0 .281 r
.73615 .62125 .73658 .61591 .72613 .41824 .7376 .61516 Mtetra
.077 0 .449 r
.7376 .61516 .72613 .41824 .72763 .41456 .72724 .41969 Mtetra
.008 0 .296 r
.72724 .41969 .72763 .41456 .72926 .41306 .72861 .41407 Mtetra
.672 .833 .407 r
.72861 .41407 .72926 .41306 .73093 .41213 .73017 .41136 Mtetra
.812 .828 .863 r
.73017 .41136 .73093 .41213 .73261 .41144 .73181 .41003 Mtetra
.67 .668 .839 r
.73181 .41003 .73261 .41144 .7343 .41088 .7335 .40942 Mtetra
.623 .639 .846 r
.7335 .40942 .7343 .41088 .736 .41043 .73521 .40907 Mtetra
.658 .67 .85 r
.73521 .40907 .736 .41043 .73769 .40975 .7369 .40854 Mtetra
.68 .704 .866 r
.7369 .40854 .73769 .40975 .73937 .40903 .73859 .4079 Mtetra
.625 .697 .896 r
.73859 .4079 .73937 .40903 .74109 .40875 .7403 .40754 Mtetra
.257 .482 .883 r
.7403 .40754 .74109 .40875 .74295 .41061 .74209 .40833 Mtetra
0 .133 .663 r
.74209 .40833 .74295 .41061 .75662 .58617 .74402 .41105 Mtetra
.548 .342 .553 r
.74402 .41105 .75662 .58617 .76042 .61494 .74626 .41848 Mtetra
.562 .352 .553 r
.74626 .41848 .76042 .61494 .76223 .61431 .74801 .41855 Mtetra
.576 .363 .554 r
.74801 .41855 .76223 .61431 .76279 .59571 .74918 .41012 Mtetra
.569 .357 .554 r
.74918 .41012 .76279 .59571 .75149 .40828 .75066 .4063 Mtetra
.762 .65 .738 r
.75066 .4063 .75149 .40828 .75304 .40552 .75228 .40456 Mtetra
.685 .759 .907 r
.75228 .40456 .75304 .40552 .75473 .40478 .75398 .40392 Mtetra
.62 .757 .944 r
.75398 .40392 .75473 .40478 .75645 .40448 .7557 .40354 Mtetra
.638 .743 .924 r
.7557 .40354 .75645 .40448 .75817 .40411 .75741 .4031 Mtetra
.675 .743 .902 r
.75741 .4031 .75817 .40411 .75988 .40349 .75912 .4025 Mtetra
.683 .751 .902 r
.75912 .4025 .75988 .40349 .76158 .40286 .76082 .40187 Mtetra
.749 .772 .872 r
.76082 .40187 .76158 .40286 .76326 .40191 .7625 .40087 Mtetra
.764 .768 .855 r
.7625 .40087 .76326 .40191 .76494 .40086 .76417 .39976 Mtetra
.673 .723 .887 r
.76417 .39976 .76494 .40086 .76665 .40034 .76588 .39917 Mtetra
.033 .343 .822 r
.76588 .39917 .76665 .40034 .76851 .40169 .76773 .40044 Mtetra
.932 .57 .159 r
.76773 .40044 .76851 .40169 .77109 .41248 .77022 .41007 Mtetra
.976 .676 .369 r
.77022 .41007 .77109 .41248 .78785 .60817 .78705 .60715 Mtetra
0 0 .441 r
.78705 .60715 .78785 .60817 .78992 .61071 .78913 .60978 Mtetra
.455 .678 .961 r
.78913 .60978 .78992 .61071 .7918 .61081 .79101 .60988 Mtetra
.744 .797 .895 r
.79101 .60988 .7918 .61081 .79361 .60984 .79281 .60888 Mtetra
.916 .803 .721 r
.79281 .60888 .79361 .60984 .79524 .60678 .79444 .60571 Mtetra
.977 .683 .388 r
.79444 .60571 .79524 .60678 .79576 .58957 .78135 .41658 Mtetra
.598 .379 .555 r
.78135 .41658 .79576 .58957 .78231 .39791 .78153 .39654 Mtetra
.869 .741 .719 r
.78153 .39654 .78231 .39791 .78384 .395 .78307 .39374 Mtetra
.67 .696 .866 r
.78307 .39374 .78384 .395 .78556 .39433 .7848 .39315 Mtetra
.546 .654 .906 r
.7848 .39315 .78556 .39433 .78732 .39419 .78656 .3931 Mtetra
.547 .672 .919 r
.78656 .3931 .78732 .39419 .78907 .39404 .78833 .39302 Mtetra
.657 .737 .908 r
.78833 .39302 .78907 .39404 .7908 .39349 .79006 .3925 Mtetra
.675 .751 .908 r
.79006 .3925 .7908 .39349 .79253 .39288 .79178 .3919 Mtetra
.736 .772 .882 r
.79178 .3919 .79253 .39288 .79423 .39201 .79348 .39098 Mtetra
.769 .774 .857 r
.79348 .39098 .79423 .39201 .79591 .39093 .79516 .38984 Mtetra
.69 .734 .885 r
.79516 .38984 .79591 .39093 .79764 .39031 .79688 .38916 Mtetra
.247 .488 .891 r
.79688 .38916 .79764 .39031 .79949 .39117 .79873 .38995 Mtetra
.849 .453 0 r
.79873 .38995 .79949 .39117 .80181 .39741 .80102 .39592 Mtetra
.976 .672 .356 r
.80102 .39592 .80181 .39741 .82089 .59727 .82011 .59624 Mtetra
.642 .19 0 r
.82011 .59624 .82089 .59727 .82307 .6004 .82229 .59946 Mtetra
.583 .742 .952 r
.82229 .59946 .82307 .6004 .82494 .60012 .82417 .59918 Mtetra
.751 .8 .892 r
.82417 .59918 .82494 .60012 .82676 .59911 .82598 .59813 Mtetra
.771 .798 .874 r
.82598 .59813 .82676 .59911 .82856 .59796 .82778 .59694 Mtetra
.69 .764 .908 r
.82778 .59694 .82856 .59796 .83041 .59728 .82963 .59622 Mtetra
.679 .752 .906 r
.82963 .59622 .83041 .59728 .83226 .59665 .83147 .59555 Mtetra
.652 .735 .91 r
.83147 .59555 .83226 .59665 .83412 .59612 .83334 .59502 Mtetra
.611 .716 .92 r
.83334 .59502 .83412 .59612 .836 .59575 .83522 .59466 Mtetra
.595 .713 .927 r
.83522 .59466 .836 .59575 .83788 .59542 .8371 .59437 Mtetra
.528 .688 .94 r
.8371 .59437 .83788 .59542 .83979 .59533 .83901 .59431 Mtetra
.441 .65 .948 r
.83901 .59431 .83979 .59533 .84172 .5955 .84095 .5945 Mtetra
.619 .742 .934 r
.84095 .5945 .84172 .5955 .8436 .59508 .84283 .59409 Mtetra
.864 .813 .797 r
.84283 .59409 .8436 .59508 .84532 .59298 .84455 .592 Mtetra
.981 .743 .504 r
.84455 .592 .84532 .59298 .84621 .58207 .84544 .58105 Mtetra
.977 .678 .362 r
.84544 .58105 .84621 .58207 .82931 .3839 .82858 .38287 Mtetra
.929 .789 .685 r
.82858 .38287 .82931 .3839 .83078 .38034 .83005 .37931 Mtetra
.722 .763 .885 r
.83005 .37931 .83078 .38034 .8325 .37949 .83177 .37846 Mtetra
.598 .713 .925 r
.83177 .37846 .8325 .37949 .83428 .3792 .83355 .37818 Mtetra
.597 .713 .925 r
.83355 .37818 .83428 .3792 .83606 .37892 .83534 .37789 Mtetra
.736 .767 .878 r
.83534 .37789 .83606 .37892 .83778 .37799 .83706 .37696 Mtetra
.654 .736 .91 r
.83706 .37696 .83778 .37799 .83954 .37748 .83882 .37644 Mtetra
.233 .507 .906 r
.83882 .37644 .83954 .37748 .84143 .37823 .8407 .37719 Mtetra
.882 .491 .034 r
.8407 .37719 .84143 .37823 .84396 .38543 .84323 .38435 Mtetra
.975 .667 .334 r
.84323 .38435 .84396 .38543 .86579 .58541 .86503 .58442 Mtetra
.649 .197 0 r
.86503 .58442 .86579 .58541 .86806 .58879 .8673 .58782 Mtetra
.384 .632 .952 r
.8673 .58782 .86806 .58879 .87003 .58909 .86928 .58813 Mtetra
.7 .786 .918 r
.86928 .58813 .87003 .58909 .87189 .58831 .87114 .58736 Mtetra
.884 .823 .782 r
.87114 .58736 .87189 .58831 .8736 .58601 .87285 .58503 Mtetra
.982 .755 .52 r
.87285 .58503 .8736 .58601 .87465 .5773 .87385 .57586 Mtetra
.977 .675 .349 r
.87385 .57586 .87465 .5773 .85576 .37592 .85501 .3746 Mtetra
.921 .759 .664 r
.85501 .3746 .85576 .37592 .85716 .37185 .85643 .37063 Mtetra
.71 .724 .862 r
.85643 .37063 .85716 .37185 .8589 .37095 .85817 .36981 Mtetra
.582 .681 .908 r
.85817 .36981 .8589 .37095 .8607 .37068 .85997 .3696 Mtetra
.546 .677 .924 r
.85997 .3696 .8607 .37068 .86251 .37054 .8618 .36952 Mtetra
.741 .773 .879 r
.8618 .36952 .86251 .37054 .86424 .36958 .86353 .36855 Mtetra
.667 .743 .908 r
.86353 .36855 .86424 .36958 .86601 .36902 .8653 .36798 Mtetra
.343 .572 .925 r
.8653 .36798 .86601 .36902 .8679 .36952 .86719 .36847 Mtetra
.854 .455 0 r
.86719 .36847 .8679 .36952 .87041 .37576 .86973 .37504 Mtetra
.973 .663 .32 r
.86973 .37504 .87041 .37576 .89412 .57708 .89341 .57642 Mtetra
.741 .267 0 r
.89341 .57642 .89412 .57708 .89648 .58079 .89576 .58001 Mtetra
.532 .762 .981 r
.89576 .58001 .89648 .58079 .89843 .58065 .8977 .5798 Mtetra
.733 .823 .921 r
.8977 .5798 .89843 .58065 .9003 .57979 .89956 .57885 Mtetra
.769 .815 .889 r
.89956 .57885 .9003 .57979 .90215 .5787 .9014 .57769 Mtetra
.522 .697 .949 r
.9014 .57769 .90215 .5787 .9041 .57862 .90336 .57763 Mtetra
.636 .754 .934 r
.90336 .57763 .9041 .57862 .90602 .57811 .90528 .57714 Mtetra
.821 .818 .847 r
.90528 .57714 .90602 .57811 .90781 .57653 .90707 .57555 Mtetra
.983 .764 .528 r
.90707 .57555 .90781 .57653 .90888 .56859 .90811 .56728 Mtetra
.976 .671 .33 r
.90811 .56728 .90888 .56859 .88782 .36626 .88709 .36494 Mtetra
.933 .761 .645 r
.88709 .36494 .88782 .36626 .88917 .36178 .88844 .36056 Mtetra
.71 .726 .863 r
.88844 .36056 .88917 .36178 .89091 .36088 .8902 .35973 Mtetra
.571 .676 .911 r
.8902 .35973 .89091 .36088 .89274 .36064 .89204 .35957 Mtetra
.467 .638 .93 r
.89204 .35957 .89274 .36064 .89461 .36073 .89391 .35973 Mtetra
.63 .738 .925 r
.89391 .35973 .89461 .36073 .89642 .36031 .89572 .35931 Mtetra
.644 .744 .922 r
.89572 .35931 .89642 .36031 .89822 .35984 .89752 .35882 Mtetra
.66 .746 .914 r
.89752 .35882 .89822 .35984 .90002 .35933 .89932 .35827 Mtetra
.72 .762 .886 r
.89932 .35827 .90002 .35933 .9018 .35864 .90108 .35741 Mtetra
.682 .715 .873 r
.90108 .35741 .9018 .35864 .90359 .35799 .90287 .35674 Mtetra
.6 .673 .891 r
.90287 .35674 .90359 .35799 .90539 .35745 .9047 .35647 Mtetra
.062 .402 .857 r
.9047 .35647 .90539 .35745 .9072 .357 .9067 .3576 Mtetra
.809 .344 .122 r
.9067 .3576 .9072 .357 .90907 .357 .90894 .36062 Mtetra
.971 .655 .315 r
.90894 .36062 .90907 .357 .91105 .35793 .93427 .55413 Mtetra
.574 .357 .548 r
.93427 .55413 .91105 .35793 .91435 .36961 .93738 .56333 Mtetra
.565 .35 .548 r
.93738 .56333 .91435 .36961 .94014 .56464 .9397 .56594 Mtetra
.625 .182 .178 r
.9397 .56594 .94014 .56464 .94253 .5678 .94183 .56704 Mtetra
.652 .7 .882 r
.31909 .7394 .32006 .7405 .3216 .74019 .32064 .73896 Mtetra
.674 .685 .853 r
.32064 .73896 .3216 .74019 .32317 .73949 .3222 .73839 Mtetra
.683 .709 .868 r
.3222 .73839 .32317 .73949 .32474 .73864 .32377 .73779 Mtetra
.462 .686 .963 r
.32377 .73779 .32474 .73864 .32627 .73862 .32529 .73785 Mtetra
.576 .75 .96 r
.32529 .73785 .32627 .73862 .32781 .73845 .32684 .73762 Mtetra
.734 .772 .883 r
.32684 .73762 .32781 .73845 .32938 .73789 .32841 .73677 Mtetra
.879 .724 .685 r
.32841 .73677 .32938 .73789 .33102 .73582 .33017 .73272 Mtetra
.934 .683 .535 r
.33017 .73272 .33102 .73582 .33276 .73207 .34194 .5442 Mtetra
.58 .367 .556 r
.34194 .5442 .33276 .73207 .33517 .71554 .34392 .53443 Mtetra
.566 .355 .554 r
.34392 .53443 .33517 .71554 .34617 .53751 .34547 .5326 Mtetra
.629 .472 .65 r
.34547 .5326 .34617 .53751 .3478 .53404 .34697 .53167 Mtetra
.639 .55 .737 r
.34697 .53167 .3478 .53404 .34936 .53208 .34845 .53113 Mtetra
.678 .727 .887 r
.34845 .53113 .34936 .53208 .35085 .53129 .34993 .5306 Mtetra
.654 .781 .941 r
.34993 .5306 .35085 .53129 .35232 .53088 .3514 .53016 Mtetra
.644 .771 .94 r
.3514 .53016 .35232 .53088 .35379 .53061 .35287 .52975 Mtetra
.749 .758 .86 r
.35287 .52975 .35379 .53061 .35529 .52975 .35438 .52883 Mtetra
.71 .74 .875 r
.35438 .52883 .35529 .52975 .35678 .529 .35587 .52814 Mtetra
.566 .711 .94 r
.35587 .52814 .35678 .529 .35825 .52861 .35733 .52798 Mtetra
.866 .419 .096 r
.35733 .52798 .35825 .52861 .35967 .5295 .35866 .53048 Mtetra
.938 .68 .522 r
.35866 .53048 .35967 .5295 .36101 .53189 .35104 .71539 Mtetra
.582 .365 .551 r
.35104 .71539 .36101 .53189 .36192 .54321 .35198 .72757 Mtetra
.564 .349 .548 r
.35198 .72757 .36192 .54321 .35466 .72499 .35347 .72892 Mtetra
.552 .255 .417 r
.35347 .72892 .35466 .72499 .35607 .72806 .35501 .72909 Mtetra
.324 0 0 r
.35501 .72909 .35607 .72806 .35755 .72941 .35657 .7288 Mtetra
.355 .705 .985 r
.35657 .7288 .35755 .72941 .35908 .72983 .35812 .7289 Mtetra
.586 .717 .934 r
.35812 .7289 .35908 .72983 .36064 .72965 .35968 .72868 Mtetra
.729 .746 .865 r
.35968 .72868 .36064 .72965 .36223 .72892 .36128 .72783 Mtetra
.874 .732 .702 r
.36128 .72783 .36223 .72892 .36387 .72702 .36299 .72434 Mtetra
.913 .678 .57 r
.36299 .72434 .36387 .72702 .36558 .7236 .36551 .70295 Mtetra
.912 .659 .541 r
.36551 .70295 .36558 .7236 .36757 .71393 .37502 .52515 Mtetra
.566 .355 .554 r
.37502 .52515 .36757 .71393 .37729 .52841 .37659 .5229 Mtetra
.627 .463 .641 r
.37659 .5229 .37729 .52841 .37894 .52452 .37811 .52188 Mtetra
.638 .536 .722 r
.37811 .52188 .37894 .52452 .3805 .52241 .3796 .5213 Mtetra
.672 .697 .865 r
.3796 .5213 .3805 .52241 .38201 .5215 .3811 .52078 Mtetra
.655 .775 .937 r
.3811 .52078 .38201 .5215 .3835 .52107 .38259 .52033 Mtetra
.641 .768 .94 r
.38259 .52033 .3835 .52107 .38499 .5208 .38408 .51992 Mtetra
.739 .756 .867 r
.38408 .51992 .38499 .5208 .38649 .52003 .3856 .51907 Mtetra
.714 .735 .868 r
.3856 .51907 .38649 .52003 .388 .51927 .3871 .51834 Mtetra
.59 .707 .924 r
.3871 .51834 .388 .51927 .3895 .51885 .38859 .51813 Mtetra
.827 .355 0 r
.38859 .51813 .3895 .51885 .39093 .51985 .38998 .52039 Mtetra
.942 .682 .514 r
.38998 .52039 .39093 .51985 .3923 .52266 .38412 .70416 Mtetra
.585 .367 .551 r
.38412 .70416 .3923 .52266 .39321 .53731 .38513 .71814 Mtetra
.563 .349 .548 r
.38513 .71814 .39321 .53731 .38799 .71056 .38666 .7193 Mtetra
.536 .286 .483 r
.38666 .7193 .38799 .71056 .38957 .71014 .38825 .7189 Mtetra
.512 .265 .477 r
.38825 .7189 .38957 .71014 .39125 .70722 .38986 .71796 Mtetra
.548 .304 .498 r
.38986 .71796 .39125 .70722 .39279 .70802 .39144 .71776 Mtetra
.545 .298 .492 r
.39144 .71776 .39279 .70802 .39434 .70854 .39302 .71754 Mtetra
.512 .266 .479 r
.39302 .71754 .39434 .70854 .39603 .70551 .39464 .71656 Mtetra
.327 .118 .436 r
.39464 .71656 .39603 .70551 .40424 .52141 .3964 .71137 Mtetra
0 0 .305 r
.3964 .71137 .40424 .52141 .40592 .51616 .40491 .51837 Mtetra
.934 .883 .469 r
.40491 .51837 .40592 .51616 .40751 .51341 .4066 .513 Mtetra
.859 .856 .837 r
.4066 .513 .40751 .51341 .40904 .51223 .40814 .5114 Mtetra
.674 .756 .913 r
.40814 .5114 .40904 .51223 .41055 .51172 .40965 .51088 Mtetra
.556 .716 .947 r
.40965 .51088 .41055 .51172 .41205 .51148 .41115 .51074 Mtetra
.59 .755 .956 r
.41115 .51074 .41205 .51148 .41355 .51122 .41265 .51048 Mtetra
.624 .764 .946 r
.41265 .51048 .41355 .51122 .41506 .51095 .41416 .51012 Mtetra
.627 .745 .932 r
.41416 .51012 .41506 .51095 .41656 .51067 .41567 .50977 Mtetra
.642 .731 .913 r
.41567 .50977 .41656 .51067 .41807 .51031 .41718 .50937 Mtetra
.654 .727 .903 r
.41718 .50937 .41807 .51031 .41958 .50986 .41869 .50893 Mtetra
.661 .731 .901 r
.41869 .50893 .41958 .50986 .4211 .50935 .42021 .50846 Mtetra
.674 .743 .903 r
.42021 .50846 .4211 .50935 .42262 .50875 .42172 .50794 Mtetra
.681 .764 .914 r
.42172 .50794 .42262 .50875 .42414 .50809 .42324 .50738 Mtetra
.681 .79 .932 r
.42324 .50738 .42414 .50809 .42566 .50744 .42476 .50683 Mtetra
.667 .812 .953 r
.42476 .50683 .42566 .50744 .42718 .50687 .42628 .50631 Mtetra
.654 .823 .965 r
.42628 .50631 .42718 .50687 .4287 .50637 .4278 .50582 Mtetra
.649 .827 .969 r
.4278 .50582 .4287 .50637 .43022 .50588 .42932 .50534 Mtetra
.648 .828 .969 r
.42932 .50534 .43022 .50588 .43174 .50539 .43084 .50486 Mtetra
.649 .831 .97 r
.43084 .50486 .43174 .50539 .43326 .5049 .43236 .50438 Mtetra
.648 .834 .972 r
.43236 .50438 .43326 .5049 .43478 .50441 .43388 .50389 Mtetra
.67 .84 .965 r
.43388 .50389 .43478 .50441 .43631 .50377 .43541 .50334 Mtetra
.661 .864 .977 r
.43541 .50334 .43631 .50377 .43783 .50314 .43694 .50279 Mtetra
.606 .871 .992 r
.43694 .50279 .43783 .50314 .43935 .50278 .43846 .50233 Mtetra
.451 .787 .998 r
.43846 .50233 .43935 .50278 .44085 .50343 .43998 .5022 Mtetra
.49 .603 .892 r
.43998 .5022 .44085 .50343 .44231 .50556 .44149 .50236 Mtetra
.545 .456 .706 r
.44149 .50236 .44231 .50556 .4437 .51088 .443 .5026 Mtetra
.572 .402 .612 r
.443 .5026 .4437 .51088 .44093 .69048 .44452 .50249 Mtetra
.563 .353 .553 r
.44452 .50249 .44093 .69048 .44251 .69143 .44605 .502 Mtetra
.44605 .502 .44251 .69143 .44427 .68483 .44758 .50138 Mtetra
.44758 .50138 .44427 .68483 .44961 .51873 .44912 .50081 Mtetra
.574 .38 .58 r
.44912 .50081 .44961 .51873 .45117 .51736 .45065 .5003 Mtetra
.575 .381 .582 r
.45065 .5003 .45117 .51736 .45273 .51622 .45218 .4998 Mtetra
.575 .382 .583 r
.45218 .4998 .45273 .51622 .45427 .51552 .45372 .49931 Mtetra
.575 .383 .583 r
.45372 .49931 .45427 .51552 .45581 .51518 .45525 .49883 Mtetra
.575 .382 .583 r
.45525 .49883 .45581 .51518 .45735 .51506 .45679 .49835 Mtetra
.575 .382 .582 r
.45679 .49835 .45735 .51506 .45888 .51525 .45832 .49788 Mtetra
.574 .38 .581 r
.45832 .49788 .45888 .51525 .4604 .51576 .45986 .49741 Mtetra
.574 .379 .579 r
.45986 .49741 .4604 .51576 .46193 .5164 .4614 .49694 Mtetra
.573 .377 .578 r
.4614 .49694 .46193 .5164 .46347 .51624 .46294 .49645 Mtetra
.573 .377 .577 r
.46294 .49645 .46347 .51624 .46503 .51513 .46448 .49594 Mtetra
.574 .378 .578 r
.46448 .49594 .46503 .51513 .46659 .51399 .46602 .49544 Mtetra
.579 .383 .58 r
.46602 .49544 .46659 .51399 .46823 .50833 .46757 .49465 Mtetra
.586 .395 .59 r
.46757 .49465 .46823 .50833 .46982 .50507 .46912 .49381 Mtetra
.574 .392 .597 r
.46912 .49381 .46982 .50507 .47135 .50596 .47066 .49355 Mtetra
.499 .332 .585 r
.47066 .49355 .47135 .50596 .47004 .68846 .47216 .49575 Mtetra
0 0 .36 r
.47216 .49575 .47004 .68846 .47157 .69448 .47074 .68781 Mtetra
0 0 .427 r
.47074 .68781 .47157 .69448 .47317 .69693 .47226 .69512 Mtetra
.03 .248 .75 r
.47226 .69512 .47317 .69693 .47479 .69767 .47387 .69671 Mtetra
.591 .716 .931 r
.47387 .69671 .47479 .69767 .47643 .69734 .47551 .69646 Mtetra
.706 .769 .902 r
.47551 .69646 .47643 .69734 .47808 .69671 .47716 .69574 Mtetra
.703 .751 .889 r
.47716 .69574 .47808 .69671 .47973 .69608 .47881 .69503 Mtetra
.654 .72 .897 r
.47881 .69503 .47973 .69608 .48137 .69561 .48045 .69455 Mtetra
.653 .719 .897 r
.48045 .69455 .48137 .69561 .48302 .69515 .4821 .69407 Mtetra
.644 .712 .897 r
.4821 .69407 .48302 .69515 .48467 .69479 .48375 .69364 Mtetra
.634 .695 .889 r
.48375 .69364 .48467 .69479 .48631 .69451 .48539 .69325 Mtetra
.636 .676 .871 r
.48539 .69325 .48631 .69451 .48796 .69421 .48704 .69286 Mtetra
.647 .665 .854 r
.48704 .69286 .48796 .69421 .48961 .69378 .48869 .6924 Mtetra
.66 .666 .845 r
.48869 .6924 .48961 .69378 .49126 .6932 .49035 .69187 Mtetra
.663 .676 .852 r
.49035 .69187 .49126 .6932 .49292 .69257 .492 .69132 Mtetra
.652 .685 .868 r
.492 .69132 .49292 .69257 .49457 .6921 .49366 .69084 Mtetra
.636 .677 .872 r
.49366 .69084 .49457 .6921 .49622 .69182 .49531 .69044 Mtetra
.649 .664 .851 r
.49531 .69044 .49622 .69182 .49788 .6913 .49697 .68997 Mtetra
.693 .687 .84 r
.49697 .68997 .49788 .6913 .49954 .68998 .49862 .68923 Mtetra
.776 .812 .881 r
.49862 .68923 .49954 .68998 .50121 .68708 .50029 .68813 Mtetra
0 0 0 r
.50029 .68813 .50121 .68708 .5029 .68203 .50195 .68691 Mtetra
.484 .207 .418 r
.50195 .68691 .5029 .68203 .50461 .67272 .50361 .68613 Mtetra
.554 .315 .508 r
.50361 .68613 .50461 .67272 .50626 .67308 .50527 .68606 Mtetra
.541 .304 .505 r
.50527 .68606 .50626 .67308 .5079 .67394 .50693 .68552 Mtetra
.471 .242 .484 r
.50693 .68552 .5079 .67394 .51035 .49309 .5086 .68297 Mtetra
0 0 .367 r
.5086 .68297 .51035 .49309 .51195 .48413 .51106 .49257 Mtetra
0 0 .11 r
.51106 .49257 .51195 .48413 .51353 .48064 .51267 .48085 Mtetra
.958 .921 .727 r
.51267 .48085 .51353 .48064 .5151 .47882 .51425 .47802 Mtetra
.726 .784 .899 r
.51425 .47802 .5151 .47882 .51667 .47815 .51582 .47724 Mtetra
.612 .726 .927 r
.51582 .47724 .51667 .47815 .51824 .47779 .51739 .47694 Mtetra
.579 .729 .945 r
.51739 .47694 .51824 .47779 .51981 .47747 .51896 .47672 Mtetra
.654 .78 .941 r
.51896 .47672 .51981 .47747 .52138 .47697 .52053 .47624 Mtetra
.648 .785 .947 r
.52053 .47624 .52138 .47697 .52295 .47649 .5221 .47579 Mtetra
.639 .787 .952 r
.5221 .47579 .52295 .47649 .52453 .47608 .52367 .47535 Mtetra
.631 .779 .952 r
.52367 .47535 .52453 .47608 .5261 .47576 .52525 .47495 Mtetra
.639 .76 .936 r
.52525 .47495 .5261 .47576 .52767 .47542 .52682 .47453 Mtetra
.654 .746 .917 r
.52682 .47453 .52767 .47542 .52925 .47498 .5284 .47407 Mtetra
.675 .748 .905 r
.5284 .47407 .52925 .47498 .53083 .47434 .52998 .47352 Mtetra
.68 .771 .919 r
.52998 .47352 .53083 .47434 .5324 .47366 .53155 .47295 Mtetra
.675 .797 .94 r
.53155 .47295 .5324 .47366 .53398 .47302 .53313 .47239 Mtetra
.658 .815 .959 r
.53313 .47239 .53398 .47302 .53556 .47248 .53471 .47188 Mtetra
.653 .819 .963 r
.53471 .47188 .53556 .47248 .53714 .47198 .53629 .47137 Mtetra
.652 .82 .964 r
.53629 .47137 .53714 .47198 .53872 .47148 .53787 .47087 Mtetra
.654 .82 .963 r
.53787 .47087 .53872 .47148 .5403 .47097 .53946 .47036 Mtetra
.654 .821 .964 r
.53946 .47036 .5403 .47097 .54188 .47046 .54104 .46985 Mtetra
.653 .821 .964 r
.54104 .46985 .54188 .47046 .54347 .46995 .54262 .46935 Mtetra
.54262 .46935 .54347 .46995 .54505 .46945 .54421 .46884 Mtetra
.54421 .46884 .54505 .46945 .54664 .46894 .54579 .46833 Mtetra
.54579 .46833 .54664 .46894 .54822 .46844 .54738 .46783 Mtetra
.653 .82 .964 r
.54738 .46783 .54822 .46844 .54981 .46793 .54897 .46732 Mtetra
.652 .82 .964 r
.54897 .46732 .54981 .46793 .5514 .46743 .55056 .46682 Mtetra
.55056 .46682 .5514 .46743 .55299 .46692 .55215 .46631 Mtetra
.55215 .46631 .55299 .46692 .55458 .46642 .55374 .46581 Mtetra
.55374 .46581 .55458 .46642 .55617 .46592 .55533 .46531 Mtetra
.55533 .46531 .55617 .46592 .55776 .46541 .55692 .4648 Mtetra
.651 .82 .964 r
.55692 .4648 .55776 .46541 .55935 .46491 .55852 .4643 Mtetra
.55852 .4643 .55935 .46491 .56094 .46441 .56011 .4638 Mtetra
.651 .82 .965 r
.56011 .4638 .56094 .46441 .56254 .4639 .5617 .46329 Mtetra
.5617 .46329 .56254 .4639 .56413 .4634 .5633 .46279 Mtetra
.65 .82 .965 r
.5633 .46279 .56413 .4634 .56573 .4629 .5649 .46229 Mtetra
.65 .821 .965 r
.5649 .46229 .56573 .4629 .56733 .46239 .5665 .46179 Mtetra
.5665 .46179 .56733 .46239 .56893 .46189 .56809 .46128 Mtetra
.65 .821 .966 r
.56809 .46128 .56893 .46189 .57053 .46139 .56969 .46078 Mtetra
.65 .822 .966 r
.56969 .46078 .57053 .46139 .57213 .46089 .57129 .46028 Mtetra
.57129 .46028 .57213 .46089 .57373 .46038 .5729 .45978 Mtetra
.5729 .45978 .57373 .46038 .57533 .45988 .5745 .45927 Mtetra
.5745 .45927 .57533 .45988 .57693 .45938 .5761 .45877 Mtetra
.5761 .45877 .57693 .45938 .57853 .45887 .57771 .45827 Mtetra
.57771 .45827 .57853 .45887 .58014 .45837 .57931 .45776 Mtetra
.57931 .45776 .58014 .45837 .58174 .45787 .58092 .45726 Mtetra
.652 .821 .964 r
.58092 .45726 .58174 .45787 .58335 .45736 .58253 .45674 Mtetra
.65 .821 .965 r
.58253 .45674 .58335 .45736 .58496 .45686 .58413 .45624 Mtetra
.646 .818 .965 r
.58413 .45624 .58496 .45686 .58657 .4564 .58574 .45574 Mtetra
.633 .804 .965 r
.58574 .45574 .58657 .4564 .58818 .45606 .58735 .4553 Mtetra
.643 .779 .946 r
.58735 .4553 .58818 .45606 .58979 .45572 .58897 .45485 Mtetra
.656 .756 .924 r
.58897 .45485 .58979 .45572 .59141 .45531 .59058 .45437 Mtetra
.683 .748 .9 r
.59058 .45437 .59141 .45531 .59302 .45466 .59219 .45377 Mtetra
.688 .761 .908 r
.59219 .45377 .59302 .45466 .59463 .45396 .5938 .45315 Mtetra
.69 .781 .921 r
.5938 .45315 .59463 .45396 .59623 .45326 .59541 .45253 Mtetra
.749 .812 .902 r
.59541 .45253 .59623 .45326 .59784 .45248 .59702 .45163 Mtetra
.678 .766 .917 r
.59702 .45163 .59784 .45248 .59946 .45193 .59864 .45105 Mtetra
.474 .681 .956 r
.59864 .45105 .59946 .45193 .60108 .45178 .60027 .4511 Mtetra
.86 .413 .027 r
.60027 .4511 .60108 .45178 .60275 .45326 .60198 .45445 Mtetra
.963 .681 .451 r
.60198 .45445 .60275 .45326 .60446 .45666 .60828 .64896 Mtetra
.572 .356 .549 r
.60828 .64896 .60446 .45666 .61072 .64317 .61019 .65613 Mtetra
.56 .319 .507 r
.61019 .65613 .61072 .64317 .61248 .6444 .61193 .65632 Mtetra
.537 .298 .5 r
.61193 .65632 .61248 .6444 .61415 .64205 .61365 .6557 Mtetra
.534 .299 .505 r
.61365 .6557 .61415 .64205 .6159 .64293 .61537 .6548 Mtetra
.562 .318 .504 r
.61537 .6548 .6159 .64293 .61788 .65196 .61712 .65509 Mtetra
.554 .232 .377 r
.61712 .65509 .61788 .65196 .61971 .65507 .61887 .65537 Mtetra
.274 0 0 r
.61887 .65537 .61971 .65507 .62149 .6566 .62062 .65548 Mtetra
.512 .657 .925 r
.62062 .65548 .62149 .6566 .62324 .65673 .62236 .65551 Mtetra
.632 .691 .886 r
.62236 .65551 .62324 .65673 .62497 .65628 .6241 .65511 Mtetra
.746 .738 .845 r
.6241 .65511 .62497 .65628 .62669 .65526 .62582 .65405 Mtetra
.902 .748 .68 r
.62582 .65405 .62669 .65526 .62838 .65309 .62745 .65001 Mtetra
.965 .687 .457 r
.62745 .65001 .62838 .65309 .63001 .64931 .62344 .4584 Mtetra
.584 .369 .555 r
.62344 .4584 .63001 .64931 .63136 .63605 .62471 .44575 Mtetra
.566 .355 .554 r
.62471 .44575 .63136 .63605 .62723 .44849 .6263 .44364 Mtetra
.637 .48 .653 r
.6263 .44364 .62723 .44849 .62877 .44473 .62791 .44253 Mtetra
.653 .576 .755 r
.62791 .44253 .62877 .44473 .63035 .44265 .62954 .44188 Mtetra
.659 .784 .941 r
.62954 .44188 .63035 .44265 .63198 .44192 .63118 .44137 Mtetra
.589 .822 .988 r
.63118 .44137 .63198 .44192 .63362 .44164 .63282 .44099 Mtetra
.579 .792 .98 r
.63282 .44099 .63362 .44164 .63527 .44157 .63446 .44068 Mtetra
.648 .753 .925 r
.63446 .44068 .63527 .44157 .63691 .44119 .6361 .44022 Mtetra
.662 .739 .907 r
.6361 .44022 .63691 .44119 .63855 .44071 .63774 .43971 Mtetra
.669 .733 .898 r
.63774 .43971 .63855 .44071 .64019 .44017 .63938 .43916 Mtetra
.678 .735 .893 r
.63938 .43916 .64019 .44017 .64183 .43951 .64102 .43857 Mtetra
.682 .752 .904 r
.64102 .43857 .64183 .43951 .64346 .43882 .64266 .43797 Mtetra
.68 .772 .92 r
.64266 .43797 .64346 .43882 .6451 .43814 .6443 .43737 Mtetra
.668 .79 .939 r
.6443 .43737 .6451 .43814 .64674 .43756 .64595 .43682 Mtetra
.658 .796 .948 r
.64595 .43682 .64674 .43756 .64839 .43703 .64759 .4363 Mtetra
.651 .794 .951 r
.64759 .4363 .64839 .43703 .65003 .43656 .64924 .43581 Mtetra
.638 .784 .952 r
.64924 .43581 .65003 .43656 .65169 .43618 .65089 .43535 Mtetra
.638 .765 .94 r
.65089 .43535 .65169 .43618 .65334 .43584 .65254 .43492 Mtetra
.642 .744 .923 r
.65254 .43492 .65334 .43584 .655 .43548 .65419 .43448 Mtetra
.653 .73 .905 r
.65419 .43448 .655 .43548 .65665 .43502 .65584 .434 Mtetra
.661 .73 .901 r
.65584 .434 .65665 .43502 .6583 .43447 .65749 .43349 Mtetra
.669 .74 .903 r
.65749 .43349 .6583 .43447 .65994 .43387 .65915 .43294 Mtetra
.703 .764 .899 r
.65915 .43294 .65994 .43387 .66158 .43294 .66079 .43224 Mtetra
.701 .819 .938 r
.66079 .43224 .66158 .43294 .66322 .4321 .66244 .43155 Mtetra
.656 .846 .973 r
.66244 .43155 .66322 .4321 .66488 .43162 .66409 .43098 Mtetra
.625 .813 .972 r
.66409 .43098 .66488 .43162 .66658 .4323 .66575 .43054 Mtetra
.575 .575 .816 r
.66575 .43054 .66658 .4323 .66836 .43444 .66743 .43046 Mtetra
.511 .415 .683 r
.66743 .43046 .66836 .43444 .67041 .4428 .66914 .43114 Mtetra
.372 .246 .577 r
.66914 .43114 .67041 .4428 .68071 .63379 .67107 .43666 Mtetra
.044 0 .438 r
.67107 .43666 .68071 .63379 .68266 .63733 .68167 .63319 Mtetra
.045 .104 .6 r
.68167 .63319 .68266 .63733 .68452 .63884 .68365 .63732 Mtetra
.372 .51 .867 r
.68365 .63732 .68452 .63884 .68633 .63914 .68548 .63797 Mtetra
.634 .703 .896 r
.68548 .63797 .68633 .63914 .68811 .63877 .68725 .63755 Mtetra
.72 .726 .855 r
.68725 .63755 .68811 .63877 .68986 .63785 .68901 .63664 Mtetra
.695 .719 .868 r
.68901 .63664 .68986 .63785 .69157 .63604 .69077 .63589 Mtetra
.692 .962 .943 r
.69077 .63589 .69157 .63604 .69322 .63296 .69253 .63493 Mtetra
.127 0 .113 r
.69253 .63493 .69322 .63296 .6947 .62633 .69425 .63325 Mtetra
.181 0 .376 r
.69425 .63325 .6947 .62633 .68681 .43177 .69577 .62773 Mtetra
.042 0 .432 r
.69577 .62773 .68681 .43177 .68825 .42665 .68765 .42942 Mtetra
0 0 0 r
.68765 .42942 .68825 .42665 .68982 .42414 .68906 .4238 Mtetra
.871 .922 .858 r
.68906 .4238 .68982 .42414 .69146 .4231 .69068 .42217 Mtetra
.655 .749 .919 r
.69068 .42217 .69146 .4231 .69314 .42273 .69235 .42167 Mtetra
.553 .678 .921 r
.69235 .42167 .69314 .42273 .69484 .42262 .69405 .42157 Mtetra
.614 .707 .911 r
.69405 .42157 .69484 .42262 .69652 .42228 .69573 .42125 Mtetra
.654 .726 .902 r
.69573 .42125 .69652 .42228 .69819 .42177 .69741 .42076 Mtetra
.662 .735 .904 r
.69741 .42076 .69819 .42177 .69987 .42119 .69908 .42024 Mtetra
.695 .759 .901 r
.69908 .42024 .69987 .42119 .70152 .42031 .70075 .41956 Mtetra
.703 .811 .932 r
.70075 .41956 .70152 .42031 .70318 .41943 .70242 .41886 Mtetra
.665 .846 .969 r
.70242 .41886 .70318 .41943 .70486 .41888 .70409 .41826 Mtetra
.631 .823 .974 r
.70409 .41826 .70486 .41888 .70659 .41934 .70578 .41778 Mtetra
.588 .609 .84 r
.70578 .41778 .70659 .41934 .7084 .42117 .70748 .41762 Mtetra
.522 .435 .699 r
.70748 .41762 .7084 .42117 .71045 .42699 .70922 .41813 Mtetra
.388 .272 .598 r
.70922 .41813 .71045 .42699 .72333 .62066 .71116 .42214 Mtetra
.067 0 .451 r
.71116 .42214 .72333 .62066 .72539 .62488 .72433 .61983 Mtetra
.067 .097 .583 r
.72433 .61983 .72539 .62488 .72732 .6266 .72645 .62486 Mtetra
.305 .439 .832 r
.72645 .62486 .72732 .6266 .72918 .62705 .72834 .62587 Mtetra
.614 .696 .902 r
.72834 .62587 .72918 .62705 .73099 .62676 .73015 .62553 Mtetra
.713 .727 .861 r
.73015 .62553 .73099 .62676 .73277 .6259 .73193 .62467 Mtetra
.704 .722 .863 r
.73193 .62467 .73277 .6259 .7345 .6242 .73371 .62386 Mtetra
.718 .93 .96 r
.73371 .62386 .7345 .6242 .73615 .62125 .73549 .62293 Mtetra
.079 0 .049 r
.73549 .62293 .73615 .62125 .7376 .61516 .73723 .62132 Mtetra
.204 .007 .375 r
.73723 .62132 .7376 .61516 .72724 .41969 .73876 .61652 Mtetra
.064 0 .444 r
.73876 .61652 .72724 .41969 .72861 .41407 .72812 .41751 Mtetra
0 0 .032 r
.72812 .41751 .72861 .41407 .73017 .41136 .72945 .41116 Mtetra
.912 .944 .811 r
.72945 .41116 .73017 .41136 .73181 .41003 .73105 .40915 Mtetra
.692 .776 .916 r
.73105 .40915 .73181 .41003 .7335 .40942 .73273 .40848 Mtetra
.587 .725 .939 r
.73273 .40848 .7335 .40942 .73521 .40907 .73445 .40823 Mtetra
.62 .762 .947 r
.73445 .40823 .73521 .40907 .7369 .40854 .73615 .40784 Mtetra
.661 .815 .958 r
.73615 .40784 .7369 .40854 .73859 .4079 .73785 .40728 Mtetra
.619 .823 .979 r
.73785 .40728 .73859 .4079 .7403 .40754 .73956 .40682 Mtetra
.489 .741 .983 r
.73956 .40682 .7403 .40754 .74209 .40833 .74129 .40674 Mtetra
.496 .557 .848 r
.74129 .40674 .74209 .40833 .74402 .41105 .74304 .40701 Mtetra
.549 .439 .682 r
.74304 .40701 .74402 .41105 .74626 .41848 .7448 .40729 Mtetra
.579 .397 .599 r
.7448 .40729 .74626 .41848 .74801 .41855 .74651 .40684 Mtetra
.596 .408 .597 r
.74651 .40684 .74801 .41855 .74918 .41012 .74817 .40567 Mtetra
.647 .494 .661 r
.74817 .40567 .74918 .41012 .75066 .4063 .74983 .40446 Mtetra
.689 .627 .782 r
.74983 .40446 .75066 .4063 .75228 .40456 .75152 .40359 Mtetra
.664 .748 .913 r
.75152 .40359 .75228 .40456 .75398 .40392 .75322 .40305 Mtetra
.644 .764 .935 r
.75322 .40305 .75398 .40392 .7557 .40354 .75494 .40257 Mtetra
.657 .748 .917 r
.75494 .40257 .7557 .40354 .75741 .4031 .75665 .40206 Mtetra
.674 .737 .898 r
.75665 .40206 .75741 .4031 .75912 .4025 .75836 .40147 Mtetra
.68 .74 .897 r
.75836 .40147 .75912 .4025 .76082 .40187 .76006 .40085 Mtetra
.737 .763 .873 r
.76006 .40085 .76082 .40187 .7625 .40087 .76175 .39992 Mtetra
.755 .782 .875 r
.76175 .39992 .7625 .40087 .76417 .39976 .76342 .3989 Mtetra
.652 .771 .936 r
.76342 .3989 .76417 .39976 .76588 .39917 .76514 .39839 Mtetra
0 .209 .7 r
.76514 .39839 .76588 .39917 .76773 .40044 .767 .39977 Mtetra
.95 .595 .246 r
.767 .39977 .76773 .40044 .77022 .41007 .76963 .41121 Mtetra
.974 .673 .381 r
.76963 .41121 .77022 .41007 .78705 .60715 .78626 .60632 Mtetra
.599 .111 0 r
.78626 .60632 .78705 .60715 .78913 .60978 .78833 .60881 Mtetra
.47 .679 .956 r
.78833 .60881 .78913 .60978 .79101 .60988 .79021 .60889 Mtetra
.742 .785 .887 r
.79021 .60889 .79101 .60988 .79281 .60888 .79202 .60789 Mtetra
.911 .8 .724 r
.79202 .60789 .79281 .60888 .79444 .60571 .79365 .60478 Mtetra
.98 .718 .459 r
.79365 .60478 .79444 .60571 .78135 .41658 .79396 .5849 Mtetra
.017 0 .435 r
.79396 .5849 .78135 .41658 .78153 .39654 .7808 .39582 Mtetra
.929 .833 .729 r
.7808 .39582 .78153 .39654 .78307 .39374 .78234 .39293 Mtetra
.691 .799 .932 r
.78234 .39293 .78307 .39374 .7848 .39315 .78406 .39226 Mtetra
.543 .719 .954 r
.78406 .39226 .7848 .39315 .78656 .3931 .78582 .39212 Mtetra
.556 .703 .938 r
.78582 .39212 .78656 .3931 .78833 .39302 .78758 .39197 Mtetra
.659 .732 .904 r
.78758 .39197 .78833 .39302 .79006 .3925 .78931 .39145 Mtetra
.669 .735 .899 r
.78931 .39145 .79006 .3925 .79178 .3919 .79103 .39087 Mtetra
.722 .76 .883 r
.79103 .39087 .79178 .3919 .79348 .39098 .79274 .39003 Mtetra
.76 .786 .875 r
.79274 .39003 .79348 .39098 .79516 .38984 .79443 .38898 Mtetra
.674 .781 .93 r
.79443 .38898 .79516 .38984 .79688 .38916 .79616 .38838 Mtetra
.013 .426 .862 r
.79616 .38838 .79688 .38916 .79873 .38995 .79802 .38927 Mtetra
.906 .507 .106 r
.79802 .38927 .79873 .38995 .80102 .39592 .80036 .39582 Mtetra
.975 .671 .361 r
.80036 .39582 .80102 .39592 .82011 .59624 .81935 .59551 Mtetra
.706 .22 0 r
.81935 .59551 .82011 .59624 .82229 .59946 .82151 .59853 Mtetra
.593 .746 .95 r
.82151 .59853 .82229 .59946 .82417 .59918 .82339 .59821 Mtetra
.753 .796 .887 r
.82339 .59821 .82417 .59918 .82598 .59813 .8252 .59714 Mtetra
.775 .798 .871 r
.8252 .59714 .82598 .59813 .82778 .59694 .827 .59592 Mtetra
.699 .77 .906 r
.827 .59592 .82778 .59694 .82963 .59622 .82884 .59516 Mtetra
.687 .756 .904 r
.82884 .59516 .82963 .59622 .83147 .59555 .83069 .59445 Mtetra
.655 .735 .909 r
.83069 .59445 .83147 .59555 .83334 .59502 .83255 .59391 Mtetra
.605 .712 .92 r
.83255 .59391 .83334 .59502 .83522 .59466 .83443 .59358 Mtetra
.585 .709 .929 r
.83443 .59358 .83522 .59466 .8371 .59437 .83632 .59333 Mtetra
.516 .685 .943 r
.83632 .59333 .8371 .59437 .83901 .59431 .83824 .5933 Mtetra
.431 .648 .95 r
.83824 .5933 .83901 .59431 .84095 .5945 .84017 .59351 Mtetra
.616 .744 .937 r
.84017 .59351 .84095 .5945 .84283 .59409 .84206 .59311 Mtetra
.864 .814 .798 r
.84206 .59311 .84283 .59409 .84455 .592 .84378 .59102 Mtetra
.981 .743 .503 r
.84378 .59102 .84455 .592 .84544 .58105 .84467 .58005 Mtetra
.977 .678 .362 r
.84467 .58005 .84544 .58105 .82858 .38287 .82785 .38185 Mtetra
.929 .79 .685 r
.82785 .38185 .82858 .38287 .83005 .37931 .82932 .37829 Mtetra
.722 .763 .885 r
.82932 .37829 .83005 .37931 .83177 .37846 .83105 .37744 Mtetra
.598 .713 .925 r
.83105 .37744 .83177 .37846 .83355 .37818 .83283 .37715 Mtetra
.83283 .37715 .83355 .37818 .83534 .37789 .83461 .37686 Mtetra
.736 .768 .878 r
.83461 .37686 .83534 .37789 .83706 .37696 .83633 .37592 Mtetra
.654 .737 .91 r
.83633 .37592 .83706 .37696 .83882 .37644 .83809 .37541 Mtetra
.234 .508 .907 r
.83809 .37541 .83882 .37644 .8407 .37719 .83998 .37615 Mtetra
.881 .489 .032 r
.83998 .37615 .8407 .37719 .84323 .38435 .8425 .38326 Mtetra
.975 .667 .334 r
.8425 .38326 .84323 .38435 .86503 .58442 .86427 .58342 Mtetra
.647 .197 0 r
.86427 .58342 .86503 .58442 .8673 .58782 .86654 .58684 Mtetra
.387 .63 .951 r
.86654 .58684 .8673 .58782 .86928 .58813 .86852 .58714 Mtetra
.697 .779 .915 r
.86852 .58714 .86928 .58813 .87114 .58736 .87038 .58638 Mtetra
.879 .82 .786 r
.87038 .58638 .87114 .58736 .87285 .58503 .8721 .58412 Mtetra
.982 .763 .532 r
.8721 .58412 .87285 .58503 .87385 .57586 .87318 .57573 Mtetra
.977 .676 .344 r
.87318 .57573 .87385 .57586 .85501 .3746 .85434 .37404 Mtetra
.976 .837 .641 r
.85434 .37404 .85501 .3746 .85643 .37063 .85574 .36988 Mtetra
.741 .836 .923 r
.85574 .36988 .85643 .37063 .85817 .36981 .85747 .36896 Mtetra
.583 .755 .959 r
.85747 .36896 .85817 .36981 .85997 .3696 .85927 .36867 Mtetra
.556 .718 .949 r
.85927 .36867 .85997 .3696 .8618 .36952 .86108 .3685 Mtetra
.744 .775 .878 r
.86108 .3685 .8618 .36952 .86353 .36855 .86281 .36752 Mtetra
.669 .744 .907 r
.86281 .36752 .86353 .36855 .8653 .36798 .86458 .36693 Mtetra
.358 .582 .928 r
.86458 .36693 .8653 .36798 .86719 .36847 .86647 .36738 Mtetra
.826 .422 0 r
.86647 .36738 .86719 .36847 .86973 .37504 .86894 .37333 Mtetra
.973 .663 .316 r
.86894 .37333 .86973 .37504 .89341 .57642 .8926 .57486 Mtetra
0 0 .462 r
.8926 .57486 .89341 .57642 .89576 .58001 .89498 .57869 Mtetra
.562 .654 .898 r
.89498 .57869 .89576 .58001 .8977 .5798 .89693 .57857 Mtetra
.705 .737 .876 r
.89693 .57857 .8977 .5798 .89956 .57885 .8988 .57773 Mtetra
.744 .77 .874 r
.8988 .57773 .89956 .57885 .9014 .57769 .90065 .57667 Mtetra
.515 .693 .949 r
.90065 .57667 .9014 .57769 .90336 .57763 .90262 .57663 Mtetra
.632 .754 .936 r
.90262 .57663 .90336 .57763 .90528 .57714 .90454 .57616 Mtetra
.816 .817 .851 r
.90454 .57616 .90528 .57714 .90707 .57555 .90634 .57462 Mtetra
.983 .771 .54 r
.90634 .57462 .90707 .57555 .90811 .56728 .90745 .56698 Mtetra
.976 .671 .326 r
.90745 .56698 .90811 .56728 .88709 .36494 .88644 .36441 Mtetra
.985 .835 .611 r
.88644 .36441 .88709 .36494 .88844 .36056 .88777 .35982 Mtetra
.74 .842 .927 r
.88777 .35982 .88844 .36056 .8902 .35973 .88952 .3589 Mtetra
.564 .752 .965 r
.88952 .3589 .8902 .35973 .89204 .35957 .89135 .35866 Mtetra
.466 .679 .958 r
.89135 .35866 .89204 .35957 .89391 .35973 .89322 .35873 Mtetra
.639 .742 .923 r
.89322 .35873 .89391 .35973 .89572 .35931 .89502 .35827 Mtetra
.648 .737 .914 r
.89502 .35827 .89572 .35931 .89752 .35882 .89682 .35777 Mtetra
.663 .74 .907 r
.89682 .35777 .89752 .35882 .89932 .35827 .89862 .3572 Mtetra
.746 .769 .872 r
.89862 .3572 .89932 .35827 .90108 .35741 .90036 .35619 Mtetra
.685 .716 .872 r
.90036 .35619 .90108 .35741 .90287 .35674 .90215 .3555 Mtetra
.538 .642 .9 r
.90215 .3555 .90287 .35674 .9047 .35647 .90401 .35548 Mtetra
.627 .191 0 r
.90401 .35548 .9047 .35647 .9067 .3576 .9063 .35901 Mtetra
.971 .656 .306 r
.9063 .35901 .9067 .3576 .90894 .36062 .93223 .55866 Mtetra
.57 .354 .547 r
.93223 .55866 .90894 .36062 .93427 .55413 .93503 .56536 Mtetra
.574 .323 .497 r
.93503 .56536 .93427 .55413 .93738 .56333 .93713 .56619 Mtetra
.519 .184 .34 r
.93713 .56619 .93738 .56333 .9397 .56594 .93913 .56618 Mtetra
0 0 0 r
.93913 .56618 .9397 .56594 .94183 .56704 .94107 .56572 Mtetra
.646 .707 .892 r
.31812 .73835 .31909 .7394 .32064 .73896 .31967 .73793 Mtetra
.654 .715 .893 r
.31967 .73793 .32064 .73896 .3222 .73839 .32123 .73748 Mtetra
.679 .745 .901 r
.32123 .73748 .3222 .73839 .32377 .73779 .32279 .73692 Mtetra
.685 .755 .905 r
.32279 .73692 .32377 .73779 .32529 .73785 .32435 .73633 Mtetra
.722 .664 .792 r
.32435 .73633 .32529 .73785 .32684 .73762 .32594 .73532 Mtetra
.749 .618 .713 r
.32594 .73532 .32684 .73762 .32841 .73677 .32757 .73341 Mtetra
.863 .648 .61 r
.32757 .73341 .32841 .73677 .33017 .73272 .32966 .72329 Mtetra
.925 .674 .539 r
.32966 .72329 .33017 .73272 .34194 .5442 .34146 .53525 Mtetra
.68 .481 .61 r
.34146 .53525 .34194 .5442 .34392 .53443 .34312 .53143 Mtetra
.66 .534 .7 r
.34312 .53143 .34392 .53443 .34547 .5326 .34462 .53051 Mtetra
.613 .554 .765 r
.34462 .53051 .34547 .5326 .34697 .53167 .34608 .53023 Mtetra
.548 .592 .85 r
.34608 .53023 .34697 .53167 .34845 .53113 .34753 .53025 Mtetra
.666 .739 .904 r
.34753 .53025 .34845 .53113 .34993 .5306 .34901 .52978 Mtetra
.669 .752 .913 r
.34901 .52978 .34993 .5306 .3514 .53016 .35049 .52929 Mtetra
.643 .735 .916 r
.35049 .52929 .3514 .53016 .35287 .52975 .35196 .5289 Mtetra
.633 .737 .923 r
.35196 .5289 .35287 .52975 .35438 .52883 .35343 .52854 Mtetra
.249 .721 .941 r
.35343 .52854 .35438 .52883 .35587 .52814 .35489 .52854 Mtetra
.627 .132 .058 r
.35489 .52854 .35587 .52814 .35733 .52798 .35631 .52932 Mtetra
.87 .563 .465 r
.35631 .52932 .35733 .52798 .35866 .53048 .35742 .53624 Mtetra
.93 .673 .526 r
.35742 .53624 .35866 .53048 .35104 .71539 .34952 .72569 Mtetra
.65 .394 .519 r
.34952 .72569 .35104 .71539 .35198 .72757 .35089 .72926 Mtetra
.555 .174 .275 r
.35089 .72926 .35198 .72757 .35347 .72892 .35242 .72959 Mtetra
.031 0 0 r
.35242 .72959 .35347 .72892 .35501 .72909 .354 .72907 Mtetra
.744 .963 .937 r
.354 .72907 .35501 .72909 .35657 .7288 .3556 .72807 Mtetra
.706 .792 .918 r
.3556 .72807 .35657 .7288 .35812 .7289 .35718 .72738 Mtetra
.717 .664 .796 r
.35718 .72738 .35812 .7289 .35968 .72868 .35878 .72641 Mtetra
.743 .617 .719 r
.35878 .72641 .35968 .72868 .36128 .72783 .36042 .72464 Mtetra
.846 .641 .625 r
.36042 .72464 .36128 .72783 .36299 .72434 .36231 .7173 Mtetra
.933 .679 .531 r
.36231 .7173 .36299 .72434 .36551 .70295 .37256 .52623 Mtetra
.571 .359 .555 r
.37256 .52623 .36551 .70295 .37502 .52515 .37422 .52189 Mtetra
.673 .534 .687 r
.37422 .52189 .37502 .52515 .37659 .5229 .37574 .52069 Mtetra
.619 .55 .755 r
.37574 .52069 .37659 .5229 .37811 .52188 .37723 .52035 Mtetra
.558 .584 .836 r
.37723 .52035 .37811 .52188 .3796 .5213 .3787 .52034 Mtetra
.648 .718 .899 r
.3787 .52034 .3796 .5213 .3811 .52078 .38019 .51993 Mtetra
.67 .75 .91 r
.38019 .51993 .3811 .52078 .38259 .52033 .38169 .51943 Mtetra
.646 .732 .912 r
.38169 .51943 .38259 .52033 .38408 .51992 .38318 .51903 Mtetra
.634 .729 .916 r
.38318 .51903 .38408 .51992 .3856 .51907 .38467 .51867 Mtetra
.361 .757 .986 r
.38467 .51867 .3856 .51907 .3871 .51834 .38615 .51863 Mtetra
.587 .061 0 r
.38615 .51863 .3871 .51834 .38859 .51813 .3876 .51931 Mtetra
.861 .539 .44 r
.3876 .51931 .38859 .51813 .38998 .52039 .38886 .52485 Mtetra
.936 .676 .518 r
.38886 .52485 .38998 .52039 .38412 .70416 .38266 .71582 Mtetra
.649 .396 .523 r
.38266 .71582 .38412 .70416 .38513 .71814 .38407 .7198 Mtetra
.593 .213 .292 r
.38407 .7198 .38513 .71814 .38666 .7193 .38562 .7204 Mtetra
.28 0 0 r
.38562 .7204 .38666 .7193 .38825 .7189 .38721 .71997 Mtetra
.073 0 0 r
.38721 .71997 .38825 .7189 .38986 .71796 .38882 .71917 Mtetra
.369 0 .071 r
.38882 .71917 .38986 .71796 .39144 .71776 .39041 .7189 Mtetra
.348 0 .037 r
.39041 .7189 .39144 .71776 .39302 .71754 .392 .71861 Mtetra
.07 0 0 r
.392 .71861 .39302 .71754 .39464 .71656 .3936 .7178 Mtetra
.896 .95 .599 r
.3936 .7178 .39464 .71656 .3964 .71137 .3953 .71462 Mtetra
1 .812 .496 r
.3953 .71462 .3964 .71137 .40491 .51837 .39736 .70149 Mtetra
0 0 .303 r
.39736 .70149 .40491 .51837 .4066 .513 .40561 .5147 Mtetra
0 0 0 r
.40561 .5147 .4066 .513 .40814 .5114 .40717 .51259 Mtetra
.293 0 .032 r
.40717 .51259 .40814 .5114 .40965 .51088 .40868 .51212 Mtetra
.443 .021 .141 r
.40868 .51212 .40965 .51088 .41115 .51074 .41018 .51204 Mtetra
.134 0 0 r
.41018 .51204 .41115 .51074 .41265 .51048 .41171 .51116 Mtetra
.514 .866 .619 r
.41171 .51116 .41265 .51048 .41416 .51012 .41324 .50991 Mtetra
.805 .925 .916 r
.41324 .50991 .41416 .51012 .41567 .50977 .41478 .5088 Mtetra
.71 .735 .87 r
.41478 .5088 .41567 .50977 .41718 .50937 .4163 .50808 Mtetra
.655 .663 .845 r
.4163 .50808 .41718 .50937 .41869 .50893 .41781 .50762 Mtetra
.639 .652 .847 r
.41781 .50762 .41869 .50893 .42021 .50846 .41933 .50724 Mtetra
.65 .671 .857 r
.41933 .50724 .42021 .50846 .42172 .50794 .42084 .5068 Mtetra
.659 .69 .868 r
.42084 .5068 .42172 .50794 .42324 .50738 .42236 .50633 Mtetra
.661 .706 .881 r
.42236 .50633 .42324 .50738 .42476 .50683 .42387 .50586 Mtetra
.663 .723 .894 r
.42387 .50586 .42476 .50683 .42628 .50631 .42539 .50538 Mtetra
.662 .731 .901 r
.42539 .50538 .42628 .50631 .4278 .50582 .42691 .5049 Mtetra
.659 .733 .904 r
.42691 .5049 .4278 .50582 .42932 .50534 .42843 .50444 Mtetra
.648 .733 .912 r
.42843 .50444 .42932 .50534 .43084 .50486 .42995 .50402 Mtetra
.639 .745 .926 r
.42995 .50402 .43084 .50486 .43236 .50438 .43147 .50363 Mtetra
.637 .768 .942 r
.43147 .50363 .43236 .50438 .43388 .50389 .43299 .50323 Mtetra
.646 .793 .953 r
.43299 .50323 .43388 .50389 .43541 .50334 .43451 .50278 Mtetra
.653 .825 .966 r
.43451 .50278 .43541 .50334 .43694 .50279 .43604 .50229 Mtetra
.659 .843 .971 r
.43604 .50229 .43694 .50279 .43846 .50233 .43757 .50177 Mtetra
.68 .829 .955 r
.43757 .50177 .43846 .50233 .43998 .5022 .43909 .50119 Mtetra
.687 .724 .878 r
.43909 .50119 .43998 .5022 .44149 .50236 .44063 .50059 Mtetra
.662 .609 .785 r
.44063 .50059 .44149 .50236 .443 .5026 .44216 .49999 Mtetra
.636 .538 .726 r
.44216 .49999 .443 .5026 .44452 .50249 .44369 .49943 Mtetra
.625 .512 .705 r
.44369 .49943 .44452 .50249 .44605 .502 .44522 .49891 Mtetra
.623 .51 .704 r
.44522 .49891 .44605 .502 .44758 .50138 .44675 .4984 Mtetra
.624 .514 .709 r
.44675 .4984 .44758 .50138 .44912 .50081 .44828 .49789 Mtetra
.625 .518 .712 r
.44828 .49789 .44912 .50081 .45065 .5003 .44981 .49739 Mtetra
.624 .518 .713 r
.44981 .49739 .45065 .5003 .45218 .4998 .45135 .4969 Mtetra
.45135 .4969 .45218 .4998 .45372 .49931 .45288 .49642 Mtetra
.623 .518 .713 r
.45288 .49642 .45372 .49931 .45525 .49883 .45442 .49593 Mtetra
.623 .517 .713 r
.45442 .49593 .45525 .49883 .45679 .49835 .45595 .49545 Mtetra
.45595 .49545 .45679 .49835 .45832 .49788 .45749 .49498 Mtetra
.622 .517 .713 r
.45749 .49498 .45832 .49788 .45986 .49741 .45902 .4945 Mtetra
.623 .517 .713 r
.45902 .4945 .45986 .49741 .4614 .49694 .46056 .49403 Mtetra
.624 .517 .713 r
.46056 .49403 .4614 .49694 .46294 .49645 .4621 .49354 Mtetra
.625 .518 .712 r
.4621 .49354 .46294 .49645 .46448 .49594 .46364 .49304 Mtetra
.625 .518 .713 r
.46364 .49304 .46448 .49594 .46602 .49544 .46518 .49254 Mtetra
.642 .529 .71 r
.46518 .49254 .46602 .49544 .46757 .49465 .46673 .49185 Mtetra
.648 .537 .714 r
.46673 .49185 .46757 .49465 .46912 .49381 .46828 .49111 Mtetra
.61 .519 .726 r
.46828 .49111 .46912 .49381 .47066 .49355 .46982 .49078 Mtetra
.377 .37 .725 r
.46982 .49078 .47066 .49355 .47216 .49575 .47133 .49195 Mtetra
0 0 .247 r
.47133 .49195 .47216 .49575 .47074 .68781 .47278 .49785 Mtetra
0 0 .352 r
.47278 .49785 .47074 .68781 .47226 .69512 .47139 .69069 Mtetra
.223 .208 .63 r
.47139 .69069 .47226 .69512 .47387 .69671 .47298 .69357 Mtetra
.588 .494 .715 r
.47298 .69357 .47387 .69671 .47551 .69646 .47461 .69341 Mtetra
.652 .536 .71 r
.47461 .69341 .47551 .69646 .47716 .69574 .47626 .69257 Mtetra
.65 .53 .705 r
.47626 .69257 .47716 .69574 .47881 .69503 .47791 .69172 Mtetra
.619 .507 .704 r
.47791 .69172 .47881 .69503 .48045 .69455 .47956 .69122 Mtetra
.619 .506 .703 r
.47956 .69122 .48045 .69455 .4821 .69407 .48121 .69072 Mtetra
.624 .508 .702 r
.48121 .69072 .4821 .69407 .48375 .69364 .48285 .69016 Mtetra
.624 .504 .696 r
.48285 .69016 .48375 .69364 .48539 .69325 .4845 .68956 Mtetra
.608 .488 .691 r
.4845 .68956 .48539 .69325 .48704 .69286 .48615 .68914 Mtetra
.566 .461 .694 r
.48615 .68914 .48704 .69286 .48869 .6924 .4878 .68921 Mtetra
.516 .447 .718 r
.4878 .68921 .48869 .6924 .49035 .69187 .48944 .68967 Mtetra
.503 .5 .786 r
.48944 .68967 .49035 .69187 .492 .69132 .49109 .69003 Mtetra
.539 .631 .891 r
.49109 .69003 .492 .69132 .49366 .69084 .49274 .69003 Mtetra
.627 .767 .947 r
.49274 .69003 .49366 .69084 .49531 .69044 .49439 .68963 Mtetra
.655 .775 .937 r
.49439 .68963 .49531 .69044 .49697 .68997 .49605 .68913 Mtetra
.644 .765 .936 r
.49605 .68913 .49697 .68997 .49862 .68923 .49771 .68867 Mtetra
.572 .814 .99 r
.49771 .68867 .49862 .68923 .50029 .68813 .49936 .68833 Mtetra
0 0 0 r
.49936 .68833 .50029 .68813 .50195 .68691 .50102 .68798 Mtetra
.345 0 .016 r
.50102 .68798 .50195 .68691 .50361 .68613 .50268 .68771 Mtetra
.431 .032 .18 r
.50268 .68771 .50361 .68613 .50527 .68606 .50434 .68749 Mtetra
.288 0 .071 r
.50434 .68749 .50527 .68606 .50693 .68552 .50601 .68684 Mtetra
0 0 0 r
.50601 .68684 .50693 .68552 .5086 .68297 .50768 .68492 Mtetra
.954 .876 .471 r
.50768 .68492 .5086 .68297 .51106 .49257 .50937 .67892 Mtetra
0 0 .348 r
.50937 .67892 .51106 .49257 .51267 .48085 .5118 .48393 Mtetra
0 0 0 r
.5118 .48393 .51267 .48085 .51425 .47802 .51338 .47927 Mtetra
.126 0 0 r
.51338 .47927 .51425 .47802 .51582 .47724 .51496 .47835 Mtetra
.379 0 .065 r
.51496 .47835 .51582 .47724 .51739 .47694 .51653 .47813 Mtetra
.452 .023 .132 r
.51653 .47813 .51739 .47694 .51896 .47672 .5181 .47811 Mtetra
.386 0 .137 r
.5181 .47811 .51896 .47672 .52053 .47624 .51967 .47778 Mtetra
.369 0 .154 r
.51967 .47778 .52053 .47624 .5221 .47579 .52124 .47731 Mtetra
.239 0 .085 r
.52124 .47731 .5221 .47579 .52367 .47535 .52282 .47645 Mtetra
0 0 0 r
.52282 .47645 .52367 .47535 .52525 .47495 .52439 .4751 Mtetra
.772 .995 .869 r
.52439 .4751 .52525 .47495 .52682 .47453 .52597 .47383 Mtetra
.766 .813 .89 r
.52597 .47383 .52682 .47453 .5284 .47407 .52755 .47285 Mtetra
.673 .686 .854 r
.52755 .47285 .5284 .47407 .52998 .47352 .52912 .47228 Mtetra
.651 .675 .86 r
.52912 .47228 .52998 .47352 .53155 .47295 .5307 .47182 Mtetra
.647 .695 .88 r
.5307 .47182 .53155 .47295 .53313 .47239 .53228 .4714 Mtetra
.663 .726 .896 r
.53228 .4714 .53313 .47239 .53471 .47188 .53386 .4709 Mtetra
.663 .729 .899 r
.53386 .4709 .53471 .47188 .53629 .47137 .53544 .4704 Mtetra
.664 .731 .9 r
.53544 .4704 .53629 .47137 .53787 .47087 .53703 .46989 Mtetra
.664 .731 .899 r
.53703 .46989 .53787 .47087 .53946 .47036 .53861 .46939 Mtetra
.664 .732 .9 r
.53861 .46939 .53946 .47036 .54104 .46985 .54019 .46888 Mtetra
.665 .732 .9 r
.54019 .46888 .54104 .46985 .54262 .46935 .54178 .46837 Mtetra
.664 .732 .9 r
.54178 .46837 .54262 .46935 .54421 .46884 .54336 .46787 Mtetra
.54336 .46787 .54421 .46884 .54579 .46833 .54495 .46736 Mtetra
.54495 .46736 .54579 .46833 .54738 .46783 .54654 .46685 Mtetra
.54654 .46685 .54738 .46783 .54897 .46732 .54812 .46635 Mtetra
.664 .731 .9 r
.54812 .46635 .54897 .46732 .55056 .46682 .54971 .46584 Mtetra
.54971 .46584 .55056 .46682 .55215 .46631 .5513 .46534 Mtetra
.663 .731 .9 r
.5513 .46534 .55215 .46631 .55374 .46581 .5529 .46483 Mtetra
.5529 .46483 .55374 .46581 .55533 .46531 .55449 .46433 Mtetra
.55449 .46433 .55533 .46531 .55692 .4648 .55608 .46382 Mtetra
.55608 .46382 .55692 .4648 .55852 .4643 .55767 .46332 Mtetra
.55767 .46332 .55852 .4643 .56011 .4638 .55927 .46282 Mtetra
.55927 .46282 .56011 .4638 .5617 .46329 .56086 .46231 Mtetra
.662 .731 .901 r
.56086 .46231 .5617 .46329 .5633 .46279 .56246 .46181 Mtetra
.56246 .46181 .5633 .46279 .5649 .46229 .56406 .46131 Mtetra
.662 .732 .901 r
.56406 .46131 .5649 .46229 .5665 .46179 .56566 .46081 Mtetra
.56566 .46081 .5665 .46179 .56809 .46128 .56726 .46031 Mtetra
.662 .732 .902 r
.56726 .46031 .56809 .46128 .56969 .46078 .56886 .45981 Mtetra
.56886 .45981 .56969 .46078 .57129 .46028 .57046 .4593 Mtetra
.662 .733 .902 r
.57046 .4593 .57129 .46028 .5729 .45978 .57206 .4588 Mtetra
.57206 .4588 .5729 .45978 .5745 .45927 .57366 .4583 Mtetra
.57366 .4583 .5745 .45927 .5761 .45877 .57527 .45779 Mtetra
.663 .733 .902 r
.57527 .45779 .5761 .45877 .57771 .45827 .57687 .45729 Mtetra
.57687 .45729 .57771 .45827 .57931 .45776 .57848 .45678 Mtetra
.663 .733 .901 r
.57848 .45678 .57931 .45776 .58092 .45726 .58009 .45627 Mtetra
.664 .732 .9 r
.58009 .45627 .58092 .45726 .58253 .45674 .58169 .45576 Mtetra
.665 .732 .9 r
.58169 .45576 .58253 .45674 .58413 .45624 .5833 .45524 Mtetra
.666 .731 .898 r
.5833 .45524 .58413 .45624 .58574 .45574 .58491 .45472 Mtetra
.683 .73 .886 r
.58491 .45472 .58574 .45574 .58735 .4553 .58652 .45412 Mtetra
.665 .693 .867 r
.58652 .45412 .58735 .4553 .58897 .45485 .58813 .45358 Mtetra
.633 .667 .865 r
.58813 .45358 .58897 .45485 .59058 .45437 .58975 .45321 Mtetra
.497 .625 .907 r
.58975 .45321 .59058 .45437 .59219 .45377 .59137 .45332 Mtetra
.132 .609 .919 r
.59137 .45332 .59219 .45377 .5938 .45315 .593 .45361 Mtetra
.428 0 0 r
.593 .45361 .5938 .45315 .59541 .45253 .59464 .45388 Mtetra
.187 0 .028 r
.59464 .45388 .59541 .45253 .59702 .45163 .59624 .45297 Mtetra
.286 0 .075 r
.59624 .45297 .59702 .45163 .59864 .45105 .59786 .45233 Mtetra
.516 .096 .182 r
.59786 .45233 .59864 .45105 .60027 .4511 .5995 .45256 Mtetra
.903 .576 .417 r
.5995 .45256 .60027 .4511 .60198 .45445 .60135 .46206 Mtetra
.954 .672 .464 r
.60135 .46206 .60198 .45445 .60828 .64896 .60756 .65419 Mtetra
.692 .396 .47 r
.60756 .65419 .60828 .64896 .61019 .65613 .60937 .65752 Mtetra
.497 .079 .177 r
.60937 .65752 .61019 .65613 .61193 .65632 .61111 .65765 Mtetra
.335 0 .08 r
.61111 .65765 .61193 .65632 .61365 .6557 .61284 .65718 Mtetra
.261 0 .075 r
.61284 .65718 .61365 .6557 .61537 .6548 .61456 .65638 Mtetra
.378 0 .152 r
.61456 .65638 .61537 .6548 .61712 .65509 .6163 .65593 Mtetra
.154 0 0 r
.6163 .65593 .61712 .65509 .61887 .65537 .61803 .65537 Mtetra
.529 .918 .91 r
.61803 .65537 .61887 .65537 .62062 .65548 .61975 .65466 Mtetra
.707 .795 .919 r
.61975 .65466 .62062 .65548 .62236 .65551 .62148 .65391 Mtetra
.732 .674 .794 r
.62148 .65391 .62236 .65551 .6241 .65511 .62319 .65274 Mtetra
.757 .626 .715 r
.62319 .65274 .6241 .65511 .62582 .65405 .62488 .6507 Mtetra
.878 .655 .596 r
.62488 .6507 .62582 .65405 .62745 .65001 .62637 .64184 Mtetra
.959 .681 .466 r
.62637 .64184 .62745 .65001 .62344 .4584 .62231 .44673 Mtetra
.663 .456 .595 r
.62231 .44673 .62344 .4584 .62471 .44575 .62383 .44254 Mtetra
.663 .533 .696 r
.62383 .44254 .62471 .44575 .6263 .44364 .62545 .44149 Mtetra
.62 .562 .768 r
.62545 .44149 .6263 .44364 .62791 .44253 .62708 .44113 Mtetra
.558 .612 .863 r
.62708 .44113 .62791 .44253 .62954 .44188 .62873 .44109 Mtetra
.628 .77 .948 r
.62873 .44109 .62954 .44188 .63118 .44137 .63037 .44069 Mtetra
.638 .803 .962 r
.63037 .44069 .63118 .44137 .63282 .44099 .63201 .44022 Mtetra
.654 .784 .943 r
.63201 .44022 .63282 .44099 .63446 .44068 .63365 .43972 Mtetra
.698 .752 .894 r
.63365 .43972 .63446 .44068 .6361 .44022 .63529 .43904 Mtetra
.685 .706 .863 r
.63529 .43904 .6361 .44022 .63774 .43971 .63692 .4384 Mtetra
.657 .673 .854 r
.63692 .4384 .63774 .43971 .63938 .43916 .63856 .43789 Mtetra
.524 .619 .889 r
.63856 .43789 .63938 .43916 .64102 .43857 .64023 .43795 Mtetra
.223 .619 .954 r
.64023 .43795 .64102 .43857 .64266 .43797 .6419 .43828 Mtetra
.444 0 0 r
.6419 .43828 .64266 .43797 .6443 .43737 .64358 .4387 Mtetra
.454 .037 .157 r
.64358 .4387 .6443 .43737 .64595 .43682 .64524 .43864 Mtetra
.409 .039 .222 r
.64524 .43864 .64595 .43682 .64759 .4363 .64689 .43818 Mtetra
.331 0 .198 r
.64689 .43818 .64759 .4363 .64924 .43581 .64853 .43734 Mtetra
.077 0 .026 r
.64853 .43734 .64924 .43581 .65089 .43535 .65014 .43594 Mtetra
.513 .853 .581 r
.65014 .43594 .65089 .43535 .65254 .43492 .65176 .43453 Mtetra
.811 .914 .909 r
.65176 .43453 .65254 .43492 .65419 .43448 .65338 .43332 Mtetra
.685 .71 .868 r
.65338 .43332 .65419 .43448 .65584 .434 .65503 .43268 Mtetra
.639 .664 .858 r
.65503 .43268 .65584 .434 .65749 .43349 .65668 .43227 Mtetra
.623 .674 .878 r
.65668 .43227 .65749 .43349 .65915 .43294 .65834 .43192 Mtetra
.656 .728 .902 r
.65834 .43192 .65915 .43294 .66079 .43224 .66 .43143 Mtetra
.671 .782 .933 r
.66 .43143 .66079 .43224 .66244 .43155 .66165 .43087 Mtetra
.674 .817 .952 r
.66165 .43087 .66244 .43155 .66409 .43098 .6633 .43028 Mtetra
.76 .83 .906 r
.6633 .43028 .66409 .43098 .66575 .43054 .66494 .42931 Mtetra
.707 .708 .848 r
.66494 .42931 .66575 .43054 .66743 .43046 .66659 .42852 Mtetra
.607 .573 .79 r
.66659 .42852 .66743 .43046 .66914 .43114 .66826 .42825 Mtetra
.224 .269 .7 r
.66826 .42825 .66914 .43114 .67107 .43666 .67003 .43036 Mtetra
.841 .581 .036 r
.67003 .43036 .67107 .43666 .68167 .63319 .67253 .44841 Mtetra
.041 0 .437 r
.67253 .44841 .68167 .63319 .68365 .63732 .68268 .63348 Mtetra
.365 .33 .687 r
.68268 .63348 .68365 .63732 .68548 .63797 .68456 .63537 Mtetra
.52 .485 .758 r
.68456 .63537 .68548 .63797 .68725 .63755 .68637 .63573 Mtetra
.589 .589 .82 r
.68637 .63573 .68725 .63755 .68901 .63664 .68816 .63556 Mtetra
.528 .677 .932 r
.68816 .63556 .68901 .63664 .69077 .63589 .68996 .63552 Mtetra
.474 .836 .993 r
.68996 .63552 .69077 .63589 .69253 .63493 .69175 .63521 Mtetra
.417 .851 .727 r
.69175 .63521 .69253 .63493 .69425 .63325 .69351 .6343 Mtetra
.762 .881 .464 r
.69351 .6343 .69425 .63325 .69577 .62773 .69516 .63124 Mtetra
.806 .723 .192 r
.69516 .63124 .69577 .62773 .68765 .42942 .69649 .62185 Mtetra
.037 0 .43 r
.69649 .62185 .68765 .42942 .68906 .4238 .68843 .42589 Mtetra
0 0 0 r
.68843 .42589 .68906 .4238 .69068 .42217 .68997 .42274 Mtetra
.487 .837 .567 r
.68997 .42274 .69068 .42217 .69235 .42167 .6916 .42135 Mtetra
.709 .926 .964 r
.6916 .42135 .69235 .42167 .69405 .42157 .69326 .42052 Mtetra
.673 .729 .891 r
.69326 .42052 .69405 .42157 .69573 .42125 .69493 .41994 Mtetra
.639 .668 .862 r
.69493 .41994 .69573 .42125 .69741 .42076 .69661 .41952 Mtetra
.62 .671 .877 r
.69661 .41952 .69741 .42076 .69908 .42024 .69829 .41918 Mtetra
.648 .72 .901 r
.69829 .41918 .69908 .42024 .70075 .41956 .69998 .41872 Mtetra
.669 .777 .93 r
.69998 .41872 .70075 .41956 .70242 .41886 .70165 .41816 Mtetra
.674 .816 .951 r
.70165 .41816 .70242 .41886 .70409 .41826 .70333 .41756 Mtetra
.751 .834 .915 r
.70333 .41756 .70409 .41826 .70578 .41778 .70499 .41663 Mtetra
.721 .729 .857 r
.70499 .41663 .70578 .41778 .70748 .41762 .70665 .41577 Mtetra
.624 .593 .798 r
.70665 .41577 .70748 .41762 .70922 .41813 .70834 .4154 Mtetra
.319 .343 .729 r
.70834 .4154 .70922 .41813 .71116 .42214 .71014 .41699 Mtetra
0 0 .391 r
.71014 .41699 .71116 .42214 .72433 .61983 .71233 .42523 Mtetra
.062 0 .449 r
.71233 .42523 .72433 .61983 .72645 .62486 .72543 .62059 Mtetra
.318 .288 .667 r
.72543 .62059 .72645 .62486 .72834 .62587 .72741 .62312 Mtetra
.509 .47 .75 r
.72741 .62312 .72834 .62587 .73015 .62553 .72927 .62359 Mtetra
.581 .573 .809 r
.72927 .62359 .73015 .62553 .73193 .62467 .73109 .62348 Mtetra
.55 .665 .913 r
.73109 .62348 .73193 .62467 .73371 .62386 .73292 .62339 Mtetra
.48 .818 .999 r
.73292 .62339 .73371 .62386 .73549 .62293 .73474 .62314 Mtetra
.417 .857 .763 r
.73474 .62314 .73549 .62293 .73723 .62132 .73653 .62229 Mtetra
.71 .865 .453 r
.73653 .62229 .73723 .62132 .73876 .61652 .73819 .61948 Mtetra
.823 .737 .212 r
.73819 .61948 .73876 .61652 .72812 .41751 .73948 .61071 Mtetra
.057 0 .442 r
.73948 .61071 .72812 .41751 .72945 .41116 .72887 .41337 Mtetra
0 0 .065 r
.72887 .41337 .72945 .41116 .73105 .40915 .73042 .4104 Mtetra
.279 0 .058 r
.73042 .4104 .73105 .40915 .73273 .40848 .73211 .40975 Mtetra
.413 0 .121 r
.73211 .40975 .73273 .40848 .73445 .40823 .73383 .40955 Mtetra
.231 0 .055 r
.73383 .40955 .73445 .40823 .73615 .40784 .73551 .4087 Mtetra
0 0 0 r
.73551 .4087 .73615 .40784 .73785 .40728 .73715 .40732 Mtetra
.739 .992 .865 r
.73715 .40732 .73785 .40728 .73956 .40682 .7388 .40606 Mtetra
.744 .821 .912 r
.7388 .40606 .73956 .40682 .74129 .40674 .74048 .40515 Mtetra
.666 .644 .818 r
.74048 .40515 .74129 .40674 .74304 .40701 .74218 .40453 Mtetra
.63 .549 .745 r
.74218 .40453 .74304 .40701 .7448 .40729 .74388 .40403 Mtetra
.613 .503 .705 r
.74388 .40403 .7448 .40729 .74651 .40684 .74559 .40358 Mtetra
.611 .502 .705 r
.74559 .40358 .74651 .40684 .74817 .40567 .7473 .40315 Mtetra
.619 .54 .744 r
.7473 .40315 .74817 .40567 .74983 .40446 .74902 .40274 Mtetra
.637 .615 .811 r
.74902 .40274 .74983 .40446 .75152 .40359 .75073 .40229 Mtetra
.653 .679 .863 r
.75073 .40229 .75152 .40359 .75322 .40305 .75244 .40179 Mtetra
.656 .688 .868 r
.75244 .40179 .75322 .40305 .75494 .40257 .75415 .40128 Mtetra
.654 .68 .863 r
.75415 .40128 .75494 .40257 .75665 .40206 .75587 .40077 Mtetra
.653 .681 .864 r
.75587 .40077 .75665 .40206 .75836 .40147 .75758 .40027 Mtetra
.657 .699 .877 r
.75758 .40027 .75836 .40147 .76006 .40085 .7593 .39975 Mtetra
.716 .74 .871 r
.7593 .39975 .76006 .40085 .76175 .39992 .76099 .39893 Mtetra
.739 .769 .877 r
.76099 .39893 .76175 .39992 .76342 .3989 .76267 .39799 Mtetra
.636 .753 .933 r
.76267 .39799 .76342 .3989 .76514 .39839 .7644 .39755 Mtetra
0 .199 .7 r
.7644 .39755 .76514 .39839 .767 .39977 .76626 .39901 Mtetra
.955 .609 .262 r
.76626 .39901 .767 .39977 .76963 .41121 .76904 .41248 Mtetra
.973 .673 .381 r
.76904 .41248 .76963 .41121 .78626 .60632 .78547 .60543 Mtetra
.546 .066 0 r
.78547 .60543 .78626 .60632 .78833 .60881 .78753 .6078 Mtetra
.5 .683 .948 r
.78753 .6078 .78833 .60881 .79021 .60889 .78941 .60781 Mtetra
.734 .766 .878 r
.78941 .60781 .79021 .60889 .79202 .60789 .79122 .60684 Mtetra
.884 .796 .758 r
.79122 .60684 .79202 .60789 .79365 .60478 .7929 .60429 Mtetra
.985 .789 .559 r
.7929 .60429 .79365 .60478 .79396 .5849 .79421 .59711 Mtetra
.981 .692 .343 r
.79421 .59711 .79396 .5849 .7808 .39582 .78031 .39808 Mtetra
0 0 0 r
.78031 .39808 .7808 .39582 .78234 .39293 .78174 .39385 Mtetra
.78174 .39385 .78234 .39293 .78406 .39226 .7834 .39239 Mtetra
.482 .896 .8 r
.7834 .39239 .78406 .39226 .78582 .39212 .7851 .39153 Mtetra
.67 .853 .97 r
.7851 .39153 .78582 .39212 .78758 .39197 .78682 .39089 Mtetra
.672 .731 .894 r
.78682 .39089 .78758 .39197 .78931 .39145 .78855 .3903 Mtetra
.655 .711 .889 r
.78855 .3903 .78931 .39145 .79103 .39087 .79028 .38979 Mtetra
.701 .741 .882 r
.79028 .38979 .79103 .39087 .79274 .39003 .792 .38905 Mtetra
.747 .778 .878 r
.792 .38905 .79274 .39003 .79443 .38898 .79369 .38807 Mtetra
.658 .764 .928 r
.79369 .38807 .79443 .38898 .79616 .38838 .79543 .38754 Mtetra
.007 .405 .854 r
.79543 .38754 .79616 .38838 .79802 .38927 .79729 .38851 Mtetra
.912 .52 .116 r
.79729 .38851 .79802 .38927 .80036 .39582 .79968 .39561 Mtetra
.975 .671 .361 r
.79968 .39561 .80036 .39582 .81935 .59551 .81858 .59472 Mtetra
.663 .179 0 r
.81858 .59472 .81935 .59551 .82151 .59853 .82073 .59759 Mtetra
.599 .747 .948 r
.82073 .59759 .82151 .59853 .82339 .59821 .82261 .59724 Mtetra
.756 .797 .887 r
.82261 .59724 .82339 .59821 .8252 .59714 .82442 .59616 Mtetra
.778 .8 .871 r
.82442 .59616 .8252 .59714 .827 .59592 .82622 .59493 Mtetra
.707 .776 .906 r
.82622 .59493 .827 .59592 .82884 .59516 .82806 .59412 Mtetra
.693 .763 .905 r
.82806 .59412 .82884 .59516 .83069 .59445 .8299 .59339 Mtetra
.656 .743 .913 r
.8299 .59339 .83069 .59445 .83255 .59391 .83176 .59283 Mtetra
.597 .715 .927 r
.83176 .59283 .83255 .59391 .83443 .59358 .83365 .59253 Mtetra
.574 .71 .935 r
.83365 .59253 .83443 .59358 .83632 .59333 .83554 .59231 Mtetra
.504 .684 .947 r
.83554 .59231 .83632 .59333 .83824 .5933 .83746 .59231 Mtetra
.422 .647 .951 r
.83746 .59231 .83824 .5933 .84017 .59351 .8394 .59253 Mtetra
.613 .745 .939 r
.8394 .59253 .84017 .59351 .84206 .59311 .84128 .59214 Mtetra
.865 .815 .799 r
.84128 .59214 .84206 .59311 .84378 .59102 .84301 .59005 Mtetra
.981 .744 .503 r
.84301 .59005 .84378 .59102 .84467 .58005 .8439 .57907 Mtetra
.977 .678 .362 r
.8439 .57907 .84467 .58005 .82785 .38185 .82712 .38082 Mtetra
.929 .79 .685 r
.82712 .38082 .82785 .38185 .82932 .37829 .82859 .37726 Mtetra
.722 .763 .885 r
.82859 .37726 .82932 .37829 .83105 .37744 .83032 .37641 Mtetra
.598 .714 .925 r
.83032 .37641 .83105 .37744 .83283 .37715 .8321 .37612 Mtetra
.598 .713 .925 r
.8321 .37612 .83283 .37715 .83461 .37686 .83388 .37583 Mtetra
.737 .768 .878 r
.83388 .37583 .83461 .37686 .83633 .37592 .8356 .37489 Mtetra
.654 .737 .911 r
.8356 .37489 .83633 .37592 .83809 .37541 .83736 .37438 Mtetra
.234 .509 .907 r
.83736 .37438 .83809 .37541 .83998 .37615 .83925 .37511 Mtetra
.881 .488 .031 r
.83925 .37511 .83998 .37615 .8425 .38326 .84177 .38219 Mtetra
.975 .667 .334 r
.84177 .38219 .8425 .38326 .86427 .58342 .8635 .58243 Mtetra
.652 .2 0 r
.8635 .58243 .86427 .58342 .86654 .58684 .86578 .58585 Mtetra
.386 .631 .951 r
.86578 .58585 .86654 .58684 .86852 .58714 .86776 .58616 Mtetra
.695 .779 .916 r
.86776 .58616 .86852 .58714 .87038 .58638 .86963 .58541 Mtetra
.876 .82 .79 r
.86963 .58541 .87038 .58638 .8721 .58412 .87135 .58319 Mtetra
.98 .767 .543 r
.87135 .58319 .8721 .58412 .87318 .57573 .87249 .57532 Mtetra
.977 .676 .345 r
.87249 .57532 .87318 .57573 .85434 .37404 .85366 .37338 Mtetra
.973 .824 .636 r
.85366 .37338 .85434 .37404 .85574 .36988 .85504 .36906 Mtetra
.753 .824 .907 r
.85504 .36906 .85574 .36988 .85747 .36896 .85677 .36808 Mtetra
.608 .754 .947 r
.85677 .36808 .85747 .36896 .85927 .36867 .85856 .36771 Mtetra
.579 .723 .941 r
.85856 .36771 .85927 .36867 .86108 .3685 .86037 .36747 Mtetra
.746 .775 .877 r
.86037 .36747 .86108 .3685 .86281 .36752 .8621 .36648 Mtetra
.671 .745 .906 r
.8621 .36648 .86281 .36752 .86458 .36693 .86387 .36588 Mtetra
.369 .589 .929 r
.86387 .36588 .86458 .36693 .86647 .36738 .86575 .36631 Mtetra
.809 .399 0 r
.86575 .36631 .86647 .36738 .86894 .37333 .86818 .37183 Mtetra
.973 .663 .317 r
.86818 .37183 .86894 .37333 .8926 .57486 .8918 .57341 Mtetra
0 0 .402 r
.8918 .57341 .8926 .57486 .89498 .57869 .8942 .57744 Mtetra
.538 .655 .912 r
.8942 .57744 .89498 .57869 .89693 .57857 .89616 .57741 Mtetra
.694 .743 .889 r
.89616 .57741 .89693 .57857 .8988 .57773 .89805 .57664 Mtetra
.733 .773 .885 r
.89805 .57664 .8988 .57773 .90065 .57667 .89991 .57566 Mtetra
.508 .691 .951 r
.89991 .57566 .90065 .57667 .90262 .57663 .90188 .57564 Mtetra
.629 .753 .937 r
.90188 .57564 .90262 .57663 .90454 .57616 .9038 .57517 Mtetra
.812 .816 .853 r
.9038 .57517 .90454 .57616 .90634 .57462 .9056 .57366 Mtetra
.981 .774 .551 r
.9056 .57366 .90634 .57462 .90745 .56698 .90676 .56646 Mtetra
.976 .671 .327 r
.90676 .56646 .90745 .56698 .88644 .36441 .88578 .36378 Mtetra
.982 .822 .608 r
.88578 .36378 .88644 .36441 .88777 .35982 .88709 .35901 Mtetra
.752 .828 .911 r
.88709 .35901 .88777 .35982 .88952 .3589 .88884 .35802 Mtetra
.591 .75 .954 r
.88884 .35802 .88952 .3589 .89135 .35866 .89066 .35771 Mtetra
.497 .687 .952 r
.89066 .35771 .89135 .35866 .89322 .35873 .89252 .35772 Mtetra
.646 .742 .919 r
.89252 .35772 .89322 .35873 .89502 .35827 .89432 .35723 Mtetra
.652 .738 .913 r
.89432 .35723 .89502 .35827 .89682 .35777 .89612 .35671 Mtetra
.665 .74 .906 r
.89612 .35671 .89682 .35777 .89862 .3572 .89792 .35613 Mtetra
.759 .774 .865 r
.89792 .35613 .89862 .3572 .90036 .35619 .89965 .35503 Mtetra
.69 .73 .881 r
.89965 .35503 .90036 .35619 .90215 .3555 .90143 .35432 Mtetra
.496 .633 .914 r
.90143 .35432 .90215 .3555 .90401 .35548 .90331 .35444 Mtetra
.79 .379 0 r
.90331 .35444 .90401 .35548 .9063 .35901 .90585 .35999 Mtetra
.971 .656 .304 r
.90585 .35999 .9063 .35901 .93223 .55866 .93206 .56233 Mtetra
.751 .406 .399 r
.93206 .56233 .93223 .55866 .93503 .56536 .93457 .5666 Mtetra
.431 0 .096 r
.93457 .5666 .93503 .56536 .93713 .56619 .93656 .56653 Mtetra
0 0 0 r
.93656 .56653 .93713 .56619 .93913 .56618 .93846 .5657 Mtetra
.784 .934 .929 r
.93846 .5657 .93913 .56618 .94107 .56572 .94031 .56445 Mtetra
.597 .737 .942 r
.31714 .7375 .31812 .73835 .31967 .73793 .31868 .73724 Mtetra
.635 .785 .954 r
.31868 .73724 .31967 .73793 .32123 .73748 .32023 .73682 Mtetra
.728 .809 .915 r
.32023 .73682 .32123 .73748 .32279 .73692 .32181 .73605 Mtetra
.847 .76 .767 r
.32181 .73605 .32279 .73692 .32435 .73633 .32346 .73388 Mtetra
.815 .642 .668 r
.32346 .73388 .32435 .73633 .32594 .73532 .32521 .7299 Mtetra
.93 .68 .537 r
.32521 .7299 .32594 .73532 .32757 .73341 .33694 .54718 Mtetra
.584 .37 .556 r
.33694 .54718 .32757 .73341 .32966 .72329 .33903 .53551 Mtetra
.568 .357 .554 r
.33903 .53551 .32966 .72329 .34146 .53525 .34066 .5322 Mtetra
.72 .569 .683 r
.34066 .5322 .34146 .53525 .34312 .53143 .34222 .53029 Mtetra
.688 .694 .85 r
.34222 .53029 .34312 .53143 .34462 .53051 .3437 .52968 Mtetra
.586 .725 .939 r
.3437 .52968 .34462 .53051 .34608 .53023 .34516 .52946 Mtetra
.493 .709 .967 r
.34516 .52946 .34608 .53023 .34753 .53025 .34661 .52944 Mtetra
.698 .76 .9 r
.34661 .52944 .34753 .53025 .34901 .52978 .3481 .52882 Mtetra
.679 .727 .886 r
.3481 .52882 .34901 .52978 .35049 .52929 .34958 .52828 Mtetra
.6 .692 .907 r
.34958 .52828 .35049 .52929 .35196 .5289 .35104 .52805 Mtetra
0 .247 .725 r
.35104 .52805 .35196 .5289 .35343 .52854 .35245 .52901 Mtetra
.822 .435 .319 r
.35245 .52901 .35343 .52854 .35489 .52854 .35378 .53152 Mtetra
.934 .676 .524 r
.35378 .53152 .35489 .52854 .35631 .52932 .34642 .70571 Mtetra
.594 .374 .552 r
.34642 .70571 .35631 .52932 .35742 .53624 .34701 .72463 Mtetra
.566 .351 .548 r
.34701 .72463 .35742 .53624 .34952 .72569 .34841 .72757 Mtetra
.667 .312 .362 r
.34841 .72757 .34952 .72569 .35089 .72926 .3499 .72885 Mtetra
.273 .713 .963 r
.3499 .72885 .35089 .72926 .35242 .72959 .35144 .7289 Mtetra
.677 .798 .939 r
.35144 .7289 .35242 .72959 .354 .72907 .35302 .72834 Mtetra
.78 .798 .867 r
.35302 .72834 .354 .72907 .3556 .72807 .35463 .72721 Mtetra
.844 .767 .777 r
.35463 .72721 .3556 .72807 .35718 .72738 .35628 .72516 Mtetra
.817 .652 .678 r
.35628 .72516 .35718 .72738 .35878 .72641 .358 .72157 Mtetra
.854 .63 .597 r
.358 .72157 .35878 .72641 .36042 .72464 .36015 .7089 Mtetra
.92 .666 .538 r
.36015 .7089 .36042 .72464 .36231 .7173 .37013 .52636 Mtetra
.569 .357 .554 r
.37013 .52636 .36231 .7173 .37256 .52623 .37177 .52265 Mtetra
.712 .551 .668 r
.37177 .52265 .37256 .52623 .37422 .52189 .37333 .52059 Mtetra
.704 .676 .82 r
.37333 .52059 .37422 .52189 .37574 .52069 .37484 .51982 Mtetra
.602 .723 .93 r
.37484 .51982 .37574 .52069 .37723 .52035 .37632 .51956 Mtetra
.505 .71 .963 r
.37632 .51956 .37723 .52035 .3787 .52034 .37779 .51952 Mtetra
.682 .757 .909 r
.37779 .51952 .3787 .52034 .38019 .51993 .37929 .51897 Mtetra
.685 .728 .883 r
.37929 .51897 .38019 .51993 .38169 .51943 .38079 .5184 Mtetra
.615 .692 .899 r
.38079 .5184 .38169 .51943 .38318 .51903 .38228 .51812 Mtetra
0 .387 .843 r
.38228 .51812 .38318 .51903 .38467 .51867 .38372 .51891 Mtetra
.823 .407 .256 r
.38372 .51891 .38467 .51867 .38615 .51863 .3851 .52118 Mtetra
.868 .577 .494 r
.3851 .52118 .38615 .51863 .3876 .51931 .38615 .53163 Mtetra
.923 .663 .526 r
.38615 .53163 .3876 .51931 .38886 .52485 .38014 .71475 Mtetra
.566 .352 .548 r
.38014 .71475 .38886 .52485 .38266 .71582 .38158 .718 Mtetra
.671 .327 .383 r
.38158 .718 .38266 .71582 .38407 .7198 .3831 .71942 Mtetra
.2 .678 .934 r
.3831 .71942 .38407 .7198 .38562 .7204 .38466 .71954 Mtetra
.652 .754 .925 r
.38466 .71954 .38562 .7204 .38721 .71997 .38626 .71907 Mtetra
.704 .758 .894 r
.38626 .71907 .38721 .71997 .38882 .71917 .38786 .71837 Mtetra
.614 .759 .948 r
.38786 .71837 .38882 .71917 .39041 .7189 .38945 .71803 Mtetra
.617 .743 .936 r
.38945 .71803 .39041 .7189 .392 .71861 .39104 .71769 Mtetra
.697 .753 .895 r
.39104 .71769 .392 .71861 .3936 .7178 .39264 .71703 Mtetra
.85 .786 .789 r
.39264 .71703 .3936 .7178 .3953 .71462 .3943 .71504 Mtetra
.969 .889 .694 r
.3943 .71504 .3953 .71462 .39736 .70149 .39601 .71135 Mtetra
0 0 .295 r
.39601 .71135 .39736 .70149 .40561 .5147 .3979 .70273 Mtetra
0 0 .351 r
.3979 .70273 .40561 .5147 .40717 .51259 .40569 .52813 Mtetra
.917 .655 .525 r
.40569 .52813 .40717 .51259 .40868 .51212 .40145 .69157 Mtetra
.565 .35 .548 r
.40145 .69157 .40868 .51212 .41018 .51204 .40295 .69392 Mtetra
0 0 .327 r
.40295 .69392 .41018 .51204 .41171 .51116 .41063 .51564 Mtetra
0 0 .091 r
.41063 .51564 .41171 .51116 .41324 .50991 .4123 .51064 Mtetra
.938 .965 .694 r
.4123 .51064 .41324 .50991 .41478 .5088 .41388 .50792 Mtetra
.784 .765 .836 r
.41388 .50792 .41478 .5088 .4163 .50808 .41542 .50673 Mtetra
.661 .655 .833 r
.41542 .50673 .4163 .50808 .41781 .50762 .41694 .50622 Mtetra
.617 .631 .842 r
.41694 .50622 .41781 .50762 .41933 .50724 .41845 .50594 Mtetra
.638 .655 .85 r
.41845 .50594 .41933 .50724 .42084 .5068 .41996 .50556 Mtetra
.656 .67 .852 r
.41996 .50556 .42084 .5068 .42236 .50633 .42148 .50509 Mtetra
.656 .671 .853 r
.42148 .50509 .42236 .50633 .42387 .50586 .42299 .50463 Mtetra
.658 .674 .854 r
.42299 .50463 .42387 .50586 .42539 .50538 .42451 .50415 Mtetra
.657 .674 .855 r
.42451 .50415 .42539 .50538 .42691 .5049 .42603 .50368 Mtetra
.652 .674 .858 r
.42603 .50368 .42691 .5049 .42843 .50444 .42755 .50324 Mtetra
.634 .67 .868 r
.42755 .50324 .42843 .50444 .42995 .50402 .42907 .50288 Mtetra
.62 .677 .882 r
.42907 .50288 .42995 .50402 .43147 .50363 .43059 .50258 Mtetra
.619 .694 .898 r
.43059 .50258 .43147 .50363 .43299 .50323 .43211 .50228 Mtetra
.638 .721 .908 r
.43211 .50228 .43299 .50323 .43451 .50278 .43363 .5019 Mtetra
.658 .742 .911 r
.43363 .5019 .43451 .50278 .43604 .50229 .43515 .50143 Mtetra
.674 .752 .91 r
.43515 .50143 .43604 .50229 .43757 .50177 .43668 .50091 Mtetra
.695 .757 .9 r
.43668 .50091 .43757 .50177 .43909 .50119 .43821 .50029 Mtetra
.705 .749 .886 r
.43821 .50029 .43909 .50119 .44063 .50059 .43974 .49961 Mtetra
.701 .733 .876 r
.43974 .49961 .44063 .50059 .44216 .49999 .44128 .49894 Mtetra
.684 .715 .872 r
.44128 .49894 .44216 .49999 .44369 .49943 .44281 .49835 Mtetra
.669 .705 .874 r
.44281 .49835 .44369 .49943 .44522 .49891 .44434 .49783 Mtetra
.664 .704 .877 r
.44434 .49783 .44522 .49891 .44675 .4984 .44587 .49733 Mtetra
.664 .707 .88 r
.44587 .49733 .44675 .4984 .44828 .49789 .4474 .49684 Mtetra
.664 .709 .881 r
.4474 .49684 .44828 .49789 .44981 .49739 .44894 .49635 Mtetra
.663 .71 .883 r
.44894 .49635 .44981 .49739 .45135 .4969 .45047 .49586 Mtetra
.662 .71 .884 r
.45047 .49586 .45135 .4969 .45288 .49642 .452 .49537 Mtetra
.661 .711 .884 r
.452 .49537 .45288 .49642 .45442 .49593 .45354 .49489 Mtetra
.66 .711 .885 r
.45354 .49489 .45442 .49593 .45595 .49545 .45507 .49442 Mtetra
.659 .711 .886 r
.45507 .49442 .45595 .49545 .45749 .49498 .45661 .49395 Mtetra
.659 .712 .887 r
.45661 .49395 .45749 .49498 .45902 .4945 .45815 .49348 Mtetra
.659 .713 .888 r
.45815 .49348 .45902 .4945 .46056 .49403 .45969 .493 Mtetra
.662 .715 .888 r
.45969 .493 .46056 .49403 .4621 .49354 .46123 .49252 Mtetra
.664 .717 .888 r
.46123 .49252 .4621 .49354 .46364 .49304 .46277 .49203 Mtetra
.665 .719 .889 r
.46277 .49203 .46364 .49304 .46518 .49254 .46431 .49153 Mtetra
.691 .727 .878 r
.46431 .49153 .46518 .49254 .46673 .49185 .46585 .49091 Mtetra
.699 .743 .885 r
.46585 .49091 .46673 .49185 .46828 .49111 .4674 .49025 Mtetra
.64 .744 .924 r
.4674 .49025 .46828 .49111 .46982 .49078 .46894 .48985 Mtetra
.261 .552 .929 r
.46894 .48985 .46982 .49078 .47133 .49195 .47047 .49032 Mtetra
0 .037 .606 r
.47047 .49032 .47133 .49195 .47278 .49785 .47198 .49233 Mtetra
.019 .032 .529 r
.47198 .49233 .47278 .49785 .47139 .69069 .47344 .49721 Mtetra
0 0 .381 r
.47344 .49721 .47139 .69069 .47298 .69357 .47225 .6792 Mtetra
.531 .353 .585 r
.47225 .6792 .47298 .69357 .47461 .69341 .47386 .68058 Mtetra
.65 .448 .596 r
.47386 .68058 .47461 .69341 .47626 .69257 .47555 .67674 Mtetra
.928 .665 .518 r
.47555 .67674 .47626 .69257 .47791 .69172 .47931 .52025 Mtetra
.586 .371 .556 r
.47931 .52025 .47791 .69172 .47956 .69122 .48103 .50811 Mtetra
.567 .356 .554 r
.48103 .50811 .47956 .69122 .48121 .69072 .48263 .50522 Mtetra
.571 .359 .554 r
.48263 .50522 .48121 .69072 .48285 .69016 .48425 .49995 Mtetra
.568 .357 .554 r
.48425 .49995 .48285 .69016 .4845 .68956 .48584 .49655 Mtetra
.56 .35 .553 r
.48584 .49655 .4845 .68956 .48615 .68914 .48739 .49726 Mtetra
0 0 .384 r
.48739 .49726 .48615 .68914 .4878 .68921 .48697 .67966 Mtetra
.203 .127 .543 r
.48697 .67966 .4878 .68921 .48944 .68967 .48855 .68616 Mtetra
.162 .199 .653 r
.48855 .68616 .48944 .68967 .49109 .69003 .49017 .68873 Mtetra
.193 .442 .869 r
.49017 .68873 .49109 .69003 .49274 .69003 .49181 .68959 Mtetra
.527 .83 .999 r
.49181 .68959 .49274 .69003 .49439 .68963 .49347 .68928 Mtetra
.636 .89 .986 r
.49347 .68928 .49439 .68963 .49605 .68913 .49513 .68869 Mtetra
.629 .866 .987 r
.49513 .68869 .49605 .68913 .49771 .68867 .49678 .68816 Mtetra
.531 .814 .998 r
.49678 .68816 .49771 .68867 .49936 .68833 .49844 .68788 Mtetra
.529 .829 .999 r
.49844 .68788 .49936 .68833 .50102 .68798 .5001 .68758 Mtetra
.531 .843 .999 r
.5001 .68758 .50102 .68798 .50268 .68771 .50176 .68724 Mtetra
.587 .845 .993 r
.50176 .68724 .50268 .68771 .50434 .68749 .50342 .68682 Mtetra
.699 .822 .941 r
.50342 .68682 .50434 .68749 .50601 .68684 .50509 .68613 Mtetra
.817 .819 .851 r
.50509 .68613 .50601 .68684 .50768 .68492 .50676 .6847 Mtetra
.937 .862 .741 r
.50676 .6847 .50768 .68492 .50937 .67892 .50844 .68173 Mtetra
.69 .74 .233 r
.50844 .68173 .50937 .67892 .5118 .48393 .51012 .67653 Mtetra
.524 .318 .542 r
.51012 .67653 .5118 .48393 .51338 .47927 .51186 .65562 Mtetra
.003 0 .394 r
.51186 .65562 .51338 .47927 .51496 .47835 .51405 .49106 Mtetra
.675 .418 .525 r
.51405 .49106 .51496 .47835 .51653 .47813 .51561 .49707 Mtetra
.924 .652 .505 r
.51561 .49707 .51653 .47813 .5181 .47811 .5168 .66664 Mtetra
.565 .35 .548 r
.5168 .66664 .5181 .47811 .51967 .47778 .51846 .66933 Mtetra
.56 .346 .547 r
.51846 .66933 .51967 .47778 .52124 .47731 .52013 .66856 Mtetra
0 0 .39 r
.52013 .66856 .52124 .47731 .52282 .47645 .52195 .48627 Mtetra
0 0 .322 r
.52195 .48627 .52282 .47645 .52439 .4751 .52354 .47701 Mtetra
.652 .766 .292 r
.52354 .47701 .52439 .4751 .52597 .47383 .52512 .47346 Mtetra
.89 .873 .814 r
.52512 .47346 .52597 .47383 .52755 .47285 .52669 .47154 Mtetra
.692 .681 .835 r
.52669 .47154 .52755 .47285 .52912 .47228 .52827 .47084 Mtetra
.637 .64 .837 r
.52827 .47084 .52912 .47228 .5307 .47182 .52985 .47045 Mtetra
.624 .643 .849 r
.52985 .47045 .5307 .47182 .53228 .4714 .53143 .47012 Mtetra
.658 .673 .853 r
.53143 .47012 .53228 .4714 .53386 .4709 .53301 .46962 Mtetra
.658 .673 .854 r
.53301 .46962 .53386 .4709 .53544 .4704 .53459 .46913 Mtetra
.658 .675 .854 r
.53459 .46913 .53544 .4704 .53703 .46989 .53617 .46863 Mtetra
.66 .676 .855 r
.53617 .46863 .53703 .46989 .53861 .46939 .53776 .46813 Mtetra
.53776 .46813 .53861 .46939 .54019 .46888 .53934 .46762 Mtetra
.66 .677 .855 r
.53934 .46762 .54019 .46888 .54178 .46837 .54093 .46711 Mtetra
.54093 .46711 .54178 .46837 .54336 .46787 .54251 .4666 Mtetra
.66 .676 .855 r
.54251 .4666 .54336 .46787 .54495 .46736 .5441 .4661 Mtetra
.5441 .4661 .54495 .46736 .54654 .46685 .54569 .46559 Mtetra
.54569 .46559 .54654 .46685 .54812 .46635 .54728 .46508 Mtetra
.54728 .46508 .54812 .46635 .54971 .46584 .54887 .46457 Mtetra
.54887 .46457 .54971 .46584 .5513 .46534 .55046 .46407 Mtetra
.659 .676 .855 r
.55046 .46407 .5513 .46534 .5529 .46483 .55205 .46356 Mtetra
.55205 .46356 .5529 .46483 .55449 .46433 .55364 .46306 Mtetra
.55364 .46306 .55449 .46433 .55608 .46382 .55523 .46255 Mtetra
.55523 .46255 .55608 .46382 .55767 .46332 .55683 .46205 Mtetra
.55683 .46205 .55767 .46332 .55927 .46282 .55842 .46155 Mtetra
.55842 .46155 .55927 .46282 .56086 .46231 .56002 .46104 Mtetra
.658 .676 .855 r
.56002 .46104 .56086 .46231 .56246 .46181 .56162 .46054 Mtetra
.56162 .46054 .56246 .46181 .56406 .46131 .56322 .46004 Mtetra
.658 .676 .856 r
.56322 .46004 .56406 .46131 .56566 .46081 .56481 .45954 Mtetra
.56481 .45954 .56566 .46081 .56726 .46031 .56641 .45904 Mtetra
.56641 .45904 .56726 .46031 .56886 .45981 .56802 .45854 Mtetra
.658 .677 .856 r
.56802 .45854 .56886 .45981 .57046 .4593 .56962 .45804 Mtetra
.56962 .45804 .57046 .4593 .57206 .4588 .57122 .45754 Mtetra
.659 .677 .856 r
.57122 .45754 .57206 .4588 .57366 .4583 .57282 .45703 Mtetra
.57282 .45703 .57366 .4583 .57527 .45779 .57443 .45653 Mtetra
.659 .678 .856 r
.57443 .45653 .57527 .45779 .57687 .45729 .57603 .45602 Mtetra
.57603 .45602 .57687 .45729 .57848 .45678 .57764 .45551 Mtetra
.66 .678 .856 r
.57764 .45551 .57848 .45678 .58009 .45627 .57925 .455 Mtetra
.662 .678 .855 r
.57925 .455 .58009 .45627 .58169 .45576 .58086 .45448 Mtetra
.661 .676 .854 r
.58086 .45448 .58169 .45576 .5833 .45524 .58246 .45396 Mtetra
.664 .677 .852 r
.58246 .45396 .5833 .45524 .58491 .45472 .58407 .45342 Mtetra
.696 .687 .837 r
.58407 .45342 .58491 .45472 .58652 .45412 .58568 .45269 Mtetra
.66 .654 .833 r
.58568 .45269 .58652 .45412 .58813 .45358 .58729 .45215 Mtetra
.579 .617 .854 r
.58729 .45215 .58813 .45358 .58975 .45321 .58891 .45203 Mtetra
0 .188 .716 r
.58891 .45203 .58975 .45321 .59137 .45332 .59057 .45353 Mtetra
.865 .45 .237 r
.59057 .45353 .59137 .45332 .593 .45361 .59226 .45693 Mtetra
.959 .678 .458 r
.59226 .45693 .593 .45361 .59464 .45388 .59779 .64204 Mtetra
.563 .349 .547 r
.59779 .64204 .59464 .45388 .59624 .45297 .59954 .64346 Mtetra
.556 .343 .547 r
.59954 .64346 .59624 .45297 .59786 .45233 .6012 .64064 Mtetra
.565 .35 .548 r
.6012 .64064 .59786 .45233 .5995 .45256 .60298 .64295 Mtetra
.575 .358 .549 r
.60298 .64295 .5995 .45256 .60135 .46206 .60492 .6522 Mtetra
.566 .351 .548 r
.60492 .6522 .60135 .46206 .60756 .65419 .60673 .65533 Mtetra
.702 .285 .252 r
.60673 .65533 .60756 .65419 .60937 .65752 .60851 .65689 Mtetra
.402 .729 .99 r
.60851 .65689 .60937 .65752 .61111 .65765 .61025 .65691 Mtetra
.598 .783 .969 r
.61025 .65691 .61111 .65765 .61284 .65718 .61198 .65656 Mtetra
.66 .833 .966 r
.61198 .65656 .61284 .65718 .61456 .65638 .61371 .65597 Mtetra
.529 .846 .999 r
.61371 .65597 .61456 .65638 .6163 .65593 .61544 .65561 Mtetra
.608 .898 .987 r
.61544 .65561 .6163 .65593 .61803 .65537 .61717 .65502 Mtetra
.747 .921 .949 r
.61717 .65502 .61803 .65537 .61975 .65466 .61889 .65403 Mtetra
.888 .842 .794 r
.61889 .65403 .61975 .65466 .62148 .65391 .62058 .65182 Mtetra
.845 .678 .676 r
.62058 .65182 .62148 .65391 .62319 .65274 .62222 .64804 Mtetra
.879 .64 .573 r
.62222 .64804 .62319 .65274 .62488 .6507 .6236 .63507 Mtetra
.948 .67 .478 r
.6236 .63507 .62488 .6507 .62637 .64184 .61988 .44715 Mtetra
.568 .357 .553 r
.61988 .44715 .62637 .64184 .62231 .44673 .62142 .44337 Mtetra
.721 .564 .675 r
.62142 .44337 .62231 .44673 .62383 .44254 .623 .44128 Mtetra
.697 .694 .844 r
.623 .44128 .62383 .44254 .62545 .44149 .62463 .44054 Mtetra
.607 .723 .927 r
.62463 .44054 .62545 .44149 .62708 .44113 .62627 .44024 Mtetra
.532 .708 .952 r
.62627 .44024 .62708 .44113 .62873 .44109 .62792 .44015 Mtetra
.636 .736 .92 r
.62792 .44015 .62873 .44109 .63037 .44069 .62956 .43974 Mtetra
.658 .742 .912 r
.62956 .43974 .63037 .44069 .63201 .44022 .6312 .43924 Mtetra
.671 .74 .902 r
.6312 .43924 .63201 .44022 .63365 .43972 .63284 .43869 Mtetra
.736 .748 .862 r
.63284 .43869 .63365 .43972 .63529 .43904 .63446 .43777 Mtetra
.703 .697 .842 r
.63446 .43777 .63529 .43904 .63692 .4384 .6361 .437 Mtetra
.636 .65 .847 r
.6361 .437 .63692 .4384 .63856 .43789 .63774 .4366 Mtetra
.05 .334 .814 r
.63774 .4366 .63856 .43789 .64023 .43795 .63945 .43783 Mtetra
.86 .413 .128 r
.63945 .43783 .64023 .43795 .6419 .43828 .64122 .44101 Mtetra
.964 .678 .44 r
.64122 .44101 .6419 .43828 .64358 .4387 .64962 .62708 Mtetra
.573 .357 .548 r
.64962 .62708 .64358 .4387 .64524 .43864 .65167 .63509 Mtetra
.561 .347 .547 r
.65167 .63509 .64524 .43864 .64689 .43818 .65344 .63504 Mtetra
.554 .342 .547 r
.65344 .63504 .64689 .43818 .64853 .43734 .65505 .63094 Mtetra
.04 0 .426 r
.65505 .63094 .64853 .43734 .65014 .43594 .64954 .44021 Mtetra
0 0 .191 r
.64954 .44021 .65014 .43594 .65176 .43453 .65101 .43496 Mtetra
.934 .964 .677 r
.65101 .43496 .65176 .43453 .65338 .43332 .65257 .43221 Mtetra
.734 .736 .852 r
.65257 .43221 .65338 .43332 .65503 .43268 .6542 .43128 Mtetra
.623 .645 .851 r
.6542 .43128 .65503 .43268 .65668 .43227 .65586 .43094 Mtetra
.571 .633 .874 r
.65586 .43094 .65668 .43227 .65834 .43192 .65753 .43084 Mtetra
.632 .704 .898 r
.65753 .43084 .65834 .43192 .66 .43143 .65919 .43045 Mtetra
.661 .738 .906 r
.65919 .43045 .66 .43143 .66165 .43087 .66085 .42993 Mtetra
.676 .753 .909 r
.66085 .42993 .66165 .43087 .6633 .43028 .6625 .42935 Mtetra
.741 .774 .88 r
.6625 .42935 .6633 .43028 .66494 .42931 .66414 .42844 Mtetra
.729 .783 .896 r
.66414 .42844 .66494 .42931 .66659 .42852 .66579 .42761 Mtetra
.652 .752 .922 r
.66579 .42761 .66659 .42852 .66826 .42825 .66745 .42712 Mtetra
.265 .507 .9 r
.66745 .42712 .66826 .42825 .67003 .43036 .66916 .4278 Mtetra
.147 .239 .704 r
.66916 .4278 .67003 .43036 .67253 .44841 .67095 .42996 Mtetra
.374 .233 .558 r
.67095 .42996 .67253 .44841 .68268 .63348 .67302 .43858 Mtetra
.056 0 .442 r
.67302 .43858 .68268 .63348 .68456 .63537 .68349 .6296 Mtetra
.301 .244 .624 r
.68349 .6296 .68456 .63537 .68637 .63573 .68545 .6331 Mtetra
.319 .359 .747 r
.68545 .6331 .68637 .63573 .68816 .63556 .68732 .63459 Mtetra
.374 .623 .949 r
.68732 .63459 .68816 .63556 .68996 .63552 .68913 .6349 Mtetra
.574 .813 .989 r
.68913 .6349 .68996 .63552 .69175 .63521 .69092 .63454 Mtetra
.738 .847 .931 r
.69092 .63454 .69175 .63521 .69351 .6343 .69268 .63363 Mtetra
.861 .852 .832 r
.69268 .63363 .69351 .6343 .69516 .63124 .69439 .63181 Mtetra
.922 .956 .631 r
.69439 .63181 .69516 .63124 .69649 .62185 .69605 .6287 Mtetra
.057 0 .333 r
.69605 .6287 .69649 .62185 .68843 .42589 .69751 .62194 Mtetra
.055 0 .436 r
.69751 .62194 .68843 .42589 .68997 .42274 .68945 .42719 Mtetra
0 0 .247 r
.68945 .42719 .68997 .42274 .6916 .42135 .6909 .42213 Mtetra
.772 .917 .538 r
.6909 .42213 .6916 .42135 .69326 .42052 .69247 .41962 Mtetra
.764 .789 .873 r
.69247 .41962 .69326 .42052 .69493 .41994 .69412 .41857 Mtetra
.63 .655 .856 r
.69412 .41857 .69493 .41994 .69661 .41952 .6958 .41818 Mtetra
.574 .636 .874 r
.6958 .41818 .69661 .41952 .69829 .41918 .6975 .41806 Mtetra
.619 .695 .898 r
.6975 .41806 .69829 .41918 .69998 .41872 .69919 .41773 Mtetra
.66 .738 .907 r
.69919 .41773 .69998 .41872 .70165 .41816 .70087 .41721 Mtetra
.675 .753 .91 r
.70087 .41721 .70165 .41816 .70333 .41756 .70255 .41663 Mtetra
.734 .774 .885 r
.70255 .41663 .70333 .41756 .70499 .41663 .70421 .41574 Mtetra
.735 .785 .892 r
.70421 .41574 .70499 .41663 .70665 .41577 .70587 .41487 Mtetra
.669 .761 .919 r
.70587 .41487 .70665 .41577 .70834 .4154 .70755 .41431 Mtetra
.361 .571 .919 r
.70755 .41431 .70834 .4154 .71014 .41699 .70929 .41475 Mtetra
.17 .282 .738 r
.70929 .41475 .71014 .41699 .71233 .42523 .71111 .41661 Mtetra
.263 .185 .577 r
.71111 .41661 .71233 .42523 .72543 .62059 .71317 .42253 Mtetra
.077 0 .454 r
.71317 .42253 .72543 .62059 .72741 .62312 .72625 .61643 Mtetra
.3 .232 .611 r
.72625 .61643 .72741 .62312 .72927 .62359 .72832 .6206 Mtetra
.326 .343 .725 r
.72832 .6206 .72927 .62359 .73109 .62348 .73026 .62231 Mtetra
.37 .576 .92 r
.73026 .62231 .73109 .62348 .73292 .62339 .73212 .62276 Mtetra
.549 .802 .992 r
.73212 .62276 .73292 .62339 .73474 .62314 .73394 .62246 Mtetra
.724 .848 .941 r
.73394 .62246 .73474 .62314 .73653 .62229 .73572 .6216 Mtetra
.869 .854 .825 r
.73572 .6216 .73653 .62229 .73819 .61948 .73744 .61969 Mtetra
.969 .934 .666 r
.73744 .61969 .73819 .61948 .73948 .61071 .73907 .61629 Mtetra
0 0 .281 r
.73907 .61629 .73948 .61071 .72887 .41337 .7405 .6098 Mtetra
.545 .335 .546 r
.7405 .6098 .72887 .41337 .73042 .4104 .74168 .59947 Mtetra
.563 .349 .547 r
.74168 .59947 .73042 .4104 .73211 .40975 .74362 .60104 Mtetra
.561 .347 .547 r
.74362 .60104 .73211 .40975 .73383 .40955 .74546 .60113 Mtetra
.092 .005 .454 r
.74546 .60113 .73383 .40955 .73551 .4087 .73517 .41447 Mtetra
.037 0 .321 r
.73517 .41447 .73551 .4087 .73715 .40732 .73651 .40837 Mtetra
.739 .848 .408 r
.73651 .40837 .73715 .40732 .7388 .40606 .73805 .40527 Mtetra
.838 .826 .836 r
.73805 .40527 .7388 .40606 .74048 .40515 .73968 .40368 Mtetra
.691 .67 .825 r
.73968 .40368 .74048 .40515 .74218 .40453 .74137 .40292 Mtetra
.645 .631 .821 r
.74137 .40292 .74218 .40453 .74388 .40403 .74307 .40243 Mtetra
.63 .626 .828 r
.74307 .40243 .74388 .40403 .74559 .40358 .74479 .40204 Mtetra
.626 .631 .836 r
.74479 .40204 .74559 .40358 .7473 .40315 .7465 .40167 Mtetra
.62 .636 .845 r
.7465 .40167 .7473 .40315 .74902 .40274 .74822 .40133 Mtetra
.635 .654 .852 r
.74822 .40133 .74902 .40274 .75073 .40229 .74994 .40092 Mtetra
.652 .668 .853 r
.74994 .40092 .75073 .40229 .75244 .40179 .75165 .40042 Mtetra
.654 .668 .852 r
.75165 .40042 .75244 .40179 .75415 .40128 .75336 .3999 Mtetra
.644 .664 .855 r
.75336 .3999 .75415 .40128 .75587 .40077 .75508 .39944 Mtetra
.634 .667 .864 r
.75508 .39944 .75587 .40077 .75758 .40027 .7568 .39903 Mtetra
.636 .684 .878 r
.7568 .39903 .75758 .40027 .7593 .39975 .75852 .39862 Mtetra
.702 .73 .872 r
.75852 .39862 .7593 .39975 .76099 .39893 .76022 .39786 Mtetra
.732 .753 .87 r
.76022 .39786 .76099 .39893 .76267 .39799 .76191 .39695 Mtetra
.638 .724 .91 r
.76191 .39695 .76267 .39799 .7644 .39755 .76364 .39652 Mtetra
0 .256 .762 r
.76364 .39652 .7644 .39755 .76626 .39901 .7655 .39797 Mtetra
.953 .605 .237 r
.7655 .39797 .76626 .39901 .76904 .41248 .76823 .41084 Mtetra
.976 .676 .372 r
.76823 .41084 .76904 .41248 .78547 .60543 .78467 .60443 Mtetra
0 0 .512 r
.78467 .60443 .78547 .60543 .78753 .6078 .78673 .60675 Mtetra
.535 .691 .939 r
.78673 .60675 .78753 .6078 .78941 .60781 .7886 .60667 Mtetra
.722 .749 .874 r
.7886 .60667 .78941 .60781 .79122 .60684 .79041 .60576 Mtetra
.82 .785 .819 r
.79041 .60576 .79122 .60684 .7929 .60429 .79216 .60407 Mtetra
.949 .925 .747 r
.79216 .60407 .7929 .60429 .79421 .59711 .79383 .60131 Mtetra
0 0 .234 r
.79383 .60131 .79421 .59711 .78031 .39808 .79529 .59593 Mtetra
.106 .019 .464 r
.79529 .59593 .78031 .39808 .78174 .39385 .78163 .40086 Mtetra
.132 0 .38 r
.78163 .40086 .78174 .39385 .7834 .39239 .78288 .39427 Mtetra
0 0 .006 r
.78288 .39427 .7834 .39239 .7851 .39153 .78442 .39136 Mtetra
.852 .977 .866 r
.78442 .39136 .7851 .39153 .78682 .39089 .78607 .38979 Mtetra
.692 .734 .883 r
.78607 .38979 .78682 .39089 .78855 .3903 .78778 .3891 Mtetra
.637 .692 .884 r
.78778 .3891 .78855 .3903 .79028 .38979 .78953 .38867 Mtetra
.681 .726 .884 r
.78953 .38867 .79028 .38979 .792 .38905 .79125 .38803 Mtetra
.744 .768 .872 r
.79125 .38803 .792 .38905 .79369 .38807 .79295 .38705 Mtetra
.658 .738 .909 r
.79295 .38705 .79369 .38807 .79543 .38754 .79468 .38652 Mtetra
.101 .426 .87 r
.79468 .38652 .79543 .38754 .79729 .38851 .79655 .3875 Mtetra
.901 .512 .079 r
.79655 .3875 .79729 .38851 .79968 .39561 .79894 .39466 Mtetra
.975 .672 .358 r
.79894 .39466 .79968 .39561 .81858 .59472 .81781 .59378 Mtetra
.61 .143 0 r
.81781 .59378 .81858 .59472 .82073 .59759 .81995 .59664 Mtetra
.602 .746 .946 r
.81995 .59664 .82073 .59759 .82261 .59724 .82183 .59629 Mtetra
.758 .8 .887 r
.82183 .59629 .82261 .59724 .82442 .59616 .82364 .5952 Mtetra
.781 .803 .871 r
.82364 .5952 .82442 .59616 .82622 .59493 .82544 .59394 Mtetra
.711 .78 .906 r
.82544 .59394 .82622 .59493 .82806 .59412 .82728 .59312 Mtetra
.698 .771 .908 r
.82728 .59312 .82806 .59412 .8299 .59339 .82912 .59236 Mtetra
.657 .752 .92 r
.82912 .59236 .8299 .59339 .83176 .59283 .83098 .5918 Mtetra
.59 .722 .935 r
.83098 .5918 .83176 .59283 .83365 .59253 .83287 .59151 Mtetra
.565 .715 .942 r
.83287 .59151 .83365 .59253 .83554 .59231 .83477 .59131 Mtetra
.495 .685 .951 r
.83477 .59131 .83554 .59231 .83746 .59231 .83669 .59132 Mtetra
.416 .647 .953 r
.83669 .59132 .83746 .59231 .8394 .59253 .83863 .59155 Mtetra
.611 .746 .941 r
.83863 .59155 .8394 .59253 .84128 .59214 .84051 .59117 Mtetra
.865 .816 .799 r
.84051 .59117 .84128 .59214 .84301 .59005 .84224 .58908 Mtetra
.981 .744 .503 r
.84224 .58908 .84301 .59005 .8439 .57907 .84314 .5781 Mtetra
.977 .678 .362 r
.84314 .5781 .8439 .57907 .82712 .38082 .82639 .3798 Mtetra
.93 .79 .685 r
.82639 .3798 .82712 .38082 .82859 .37726 .82786 .37624 Mtetra
.722 .764 .885 r
.82786 .37624 .82859 .37726 .83032 .37641 .82958 .37538 Mtetra
.598 .714 .925 r
.82958 .37538 .83032 .37641 .8321 .37612 .83137 .37509 Mtetra
.83137 .37509 .8321 .37612 .83388 .37583 .83315 .3748 Mtetra
.737 .768 .878 r
.83315 .3748 .83388 .37583 .8356 .37489 .83487 .37386 Mtetra
.654 .738 .911 r
.83487 .37386 .8356 .37489 .83736 .37438 .83664 .37334 Mtetra
.234 .509 .907 r
.83664 .37334 .83736 .37438 .83925 .37511 .83852 .37408 Mtetra
.881 .488 .031 r
.83852 .37408 .83925 .37511 .84177 .38219 .84104 .38115 Mtetra
.975 .667 .334 r
.84104 .38115 .84177 .38219 .8635 .58243 .86274 .58146 Mtetra
.656 .203 0 r
.86274 .58146 .8635 .58243 .86578 .58585 .86502 .58488 Mtetra
.383 .631 .952 r
.86502 .58488 .86578 .58585 .86776 .58616 .867 .58519 Mtetra
.695 .782 .918 r
.867 .58519 .86776 .58616 .86963 .58541 .86887 .58444 Mtetra
.876 .821 .791 r
.86887 .58444 .86963 .58541 .87135 .58319 .87059 .58222 Mtetra
.979 .766 .545 r
.87059 .58222 .87135 .58319 .87249 .57532 .87174 .5744 Mtetra
.977 .675 .347 r
.87174 .5744 .87249 .57532 .85366 .37338 .85294 .37238 Mtetra
.951 .789 .645 r
.85294 .37238 .85366 .37338 .85504 .36906 .85432 .36804 Mtetra
.745 .775 .877 r
.85432 .36804 .85504 .36906 .85677 .36808 .85605 .36705 Mtetra
.617 .724 .923 r
.85605 .36705 .85677 .36808 .85856 .36771 .85784 .36669 Mtetra
.585 .709 .929 r
.85784 .36669 .85856 .36771 .86037 .36747 .85965 .36644 Mtetra
.747 .774 .875 r
.85965 .36644 .86037 .36747 .8621 .36648 .86138 .36544 Mtetra
.672 .745 .905 r
.86138 .36544 .8621 .36648 .86387 .36588 .86315 .36484 Mtetra
.371 .591 .93 r
.86315 .36484 .86387 .36588 .86575 .36631 .86503 .36525 Mtetra
.81 .399 0 r
.86503 .36525 .86575 .36631 .86818 .37183 .86746 .37073 Mtetra
.973 .663 .318 r
.86746 .37073 .86818 .37183 .8918 .57341 .89105 .57238 Mtetra
.696 .258 0 r
.89105 .57238 .8918 .57341 .8942 .57744 .89345 .57643 Mtetra
.51 .693 .951 r
.89345 .57643 .8942 .57744 .89616 .57741 .89542 .5764 Mtetra
.696 .777 .914 r
.89542 .5764 .89616 .57741 .89805 .57664 .8973 .57564 Mtetra
.736 .791 .897 r
.8973 .57564 .89805 .57664 .89991 .57566 .89916 .57466 Mtetra
.503 .691 .952 r
.89916 .57466 .89991 .57566 .90188 .57564 .90113 .57464 Mtetra
.627 .753 .937 r
.90113 .57464 .90188 .57564 .9038 .57517 .90305 .57419 Mtetra
.811 .816 .854 r
.90305 .57419 .9038 .57517 .9056 .57366 .90486 .57269 Mtetra
.98 .773 .553 r
.90486 .57269 .9056 .57366 .90676 .56646 .90603 .56552 Mtetra
.976 .671 .329 r
.90603 .56552 .90676 .56646 .88578 .36378 .88508 .36278 Mtetra
.962 .788 .621 r
.88508 .36278 .88578 .36378 .88709 .35901 .88639 .35798 Mtetra
.743 .776 .88 r
.88639 .35798 .88709 .35901 .88884 .35802 .88813 .357 Mtetra
.602 .719 .927 r
.88813 .357 .88884 .35802 .89066 .35771 .88996 .35668 Mtetra
.511 .674 .938 r
.88996 .35668 .89066 .35771 .89252 .35772 .89182 .35669 Mtetra
.649 .74 .916 r
.89182 .35669 .89252 .35772 .89432 .35723 .89362 .35619 Mtetra
.655 .74 .913 r
.89362 .35619 .89432 .35723 .89612 .35671 .89542 .35566 Mtetra
.668 .743 .906 r
.89542 .35566 .89612 .35671 .89792 .35613 .89721 .35506 Mtetra
.763 .775 .863 r
.89721 .35506 .89792 .35613 .89965 .35503 .89895 .35393 Mtetra
.694 .746 .891 r
.89895 .35393 .89965 .35503 .90143 .35432 .90073 .35321 Mtetra
.487 .643 .926 r
.90073 .35321 .90143 .35432 .90331 .35444 .90261 .35333 Mtetra
.79 .384 0 r
.90261 .35333 .90331 .35444 .90585 .35999 .90517 .35908 Mtetra
.971 .656 .295 r
.90517 .35908 .90585 .35999 .93206 .56233 .93137 .56162 Mtetra
.757 .298 0 r
.93137 .56162 .93206 .56233 .93457 .5666 .93387 .5658 Mtetra
.51 .747 .981 r
.93387 .5658 .93457 .5666 .93656 .56653 .93585 .56565 Mtetra
.725 .821 .925 r
.93585 .56565 .93656 .56653 .93846 .5657 .93774 .56474 Mtetra
.793 .823 .875 r
.93774 .56474 .93846 .5657 .94031 .56445 .93958 .5634 Mtetra
.526 .71 .956 r
.31616 .73664 .31714 .7375 .31868 .73724 .31769 .73656 Mtetra
.62 .788 .962 r
.31769 .73656 .31868 .73724 .32023 .73682 .31924 .73619 Mtetra
.769 .816 .89 r
.31924 .73619 .32023 .73682 .32181 .73605 .32083 .73518 Mtetra
.898 .74 .677 r
.32083 .73518 .32181 .73605 .32346 .73388 .32261 .73069 Mtetra
.934 .683 .535 r
.32261 .73069 .32346 .73388 .32521 .7299 .33489 .54038 Mtetra
.576 .363 .555 r
.33489 .54038 .32521 .7299 .33694 .54718 .33676 .5329 Mtetra
.605 .409 .589 r
.33676 .5329 .33694 .54718 .33903 .53551 .33831 .53114 Mtetra
.637 .486 .66 r
.33831 .53114 .33903 .53551 .34066 .5322 .33981 .53019 Mtetra
.65 .579 .762 r
.33981 .53019 .34066 .5322 .34222 .53029 .34129 .52963 Mtetra
.648 .789 .949 r
.34129 .52963 .34222 .53029 .3437 .52968 .34276 .5292 Mtetra
.572 .821 .992 r
.34276 .5292 .3437 .52968 .34516 .52946 .34422 .52889 Mtetra
.565 .792 .985 r
.34422 .52889 .34516 .52946 .34661 .52944 .34569 .52864 Mtetra
.734 .77 .882 r
.34569 .52864 .34661 .52944 .3481 .52882 .34718 .52785 Mtetra
.688 .724 .877 r
.34718 .52785 .3481 .52882 .34958 .52828 .34867 .52726 Mtetra
.543 .666 .917 r
.34867 .52726 .34958 .52828 .35104 .52805 .35012 .52721 Mtetra
.882 .449 .094 r
.35012 .52721 .35104 .52805 .35245 .52901 .35143 .53001 Mtetra
.937 .68 .523 r
.35143 .53001 .35245 .52901 .35378 .53152 .34325 .718 Mtetra
.576 .359 .55 r
.34325 .718 .35378 .53152 .34642 .70571 .34434 .72675 Mtetra
.577 .346 .528 r
.34434 .72675 .34642 .70571 .34701 .72463 .34583 .728 Mtetra
.55 .24 .395 r
.34583 .728 .34701 .72463 .34841 .72757 .34737 .72819 Mtetra
.171 0 0 r
.34737 .72819 .34841 .72757 .3499 .72885 .34893 .7279 Mtetra
.537 .695 .941 r
.34893 .7279 .3499 .72885 .35144 .7289 .35048 .72782 Mtetra
.647 .705 .889 r
.35048 .72782 .35144 .7289 .35302 .72834 .35205 .72739 Mtetra
.76 .755 .848 r
.35205 .72739 .35302 .72834 .35463 .72721 .35366 .72632 Mtetra
.891 .746 .694 r
.35366 .72632 .35463 .72721 .35628 .72516 .3554 .72247 Mtetra
.938 .685 .528 r
.3554 .72247 .35628 .72516 .358 .72157 .36585 .53449 Mtetra
.582 .368 .556 r
.36585 .53449 .358 .72157 .36015 .7089 .36784 .52358 Mtetra
.566 .355 .553 r
.36784 .52358 .36015 .7089 .37013 .52636 .36941 .52143 Mtetra
.635 .475 .65 r
.36941 .52143 .37013 .52636 .37177 .52265 .37092 .52038 Mtetra
.649 .562 .743 r
.37092 .52038 .37177 .52265 .37333 .52059 .37242 .51978 Mtetra
.658 .756 .922 r
.37242 .51978 .37333 .52059 .37484 .51982 .37391 .51932 Mtetra
.584 .821 .989 r
.37391 .51932 .37484 .51982 .37632 .51956 .3754 .519 Mtetra
.567 .795 .985 r
.3754 .519 .37632 .51956 .37779 .51952 .37688 .51873 Mtetra
.724 .774 .892 r
.37688 .51873 .37779 .51952 .37929 .51897 .37839 .51798 Mtetra
.697 .727 .873 r
.37839 .51798 .37929 .51897 .38079 .5184 .37989 .51734 Mtetra
.575 .673 .906 r
.37989 .51734 .38079 .5184 .38228 .51812 .38137 .5172 Mtetra
.805 .335 0 r
.38137 .5172 .38228 .51812 .38372 .51891 .38275 .51949 Mtetra
.941 .681 .515 r
.38275 .51949 .38372 .51891 .3851 .52118 .37648 .7036 Mtetra
.583 .366 .551 r
.37648 .7036 .3851 .52118 .38615 .53163 .37749 .71693 Mtetra
.563 .349 .547 r
.37749 .71693 .38615 .53163 .38014 .71475 .37899 .71854 Mtetra
.556 .255 .413 r
.37899 .71854 .38014 .71475 .38158 .718 .38055 .71877 Mtetra
.261 0 0 r
.38055 .71877 .38158 .718 .3831 .71942 .38214 .71851 Mtetra
.637 .739 .922 r
.38214 .71851 .3831 .71942 .38466 .71954 .38373 .71811 Mtetra
.658 .655 .836 r
.38373 .71811 .38466 .71954 .38626 .71907 .38532 .7176 Mtetra
.668 .652 .825 r
.38532 .7176 .38626 .71907 .38786 .71837 .38692 .717 Mtetra
.642 .657 .849 r
.38692 .717 .38786 .71837 .38945 .71803 .38851 .71658 Mtetra
.636 .643 .84 r
.38851 .71658 .38945 .71803 .39104 .71769 .39011 .71619 Mtetra
.653 .643 .827 r
.39011 .71619 .39104 .71769 .39264 .71703 .39171 .71569 Mtetra
.719 .688 .819 r
.39171 .71569 .39264 .71703 .3943 .71504 .39332 .71477 Mtetra
.807 .91 .911 r
.39332 .71477 .3943 .71504 .39601 .71135 .39494 .71358 Mtetra
.228 0 .16 r
.39494 .71358 .39601 .71135 .3979 .70273 .39657 .71232 Mtetra
.542 .294 .49 r
.39657 .71232 .3979 .70273 .40569 .52813 .39817 .71203 Mtetra
.56 .347 .547 r
.39817 .71203 .40569 .52813 .40145 .69157 .39975 .71193 Mtetra
.544 .316 .52 r
.39975 .71193 .40145 .69157 .40295 .69392 .40137 .71117 Mtetra
.435 .222 .489 r
.40137 .71117 .40295 .69392 .41063 .51564 .40312 .70621 Mtetra
0 0 .309 r
.40312 .70621 .41063 .51564 .4123 .51064 .41129 .51302 Mtetra
.913 .871 .437 r
.41129 .51302 .4123 .51064 .41388 .50792 .41297 .50755 Mtetra
.868 .862 .832 r
.41297 .50755 .41388 .50792 .41542 .50673 .41453 .50587 Mtetra
.679 .753 .907 r
.41453 .50587 .41542 .50673 .41694 .50622 .41604 .50533 Mtetra
.575 .713 .936 r
.41604 .50533 .41694 .50622 .41845 .50594 .41755 .50514 Mtetra
.617 .751 .941 r
.41755 .50514 .41845 .50594 .41996 .50556 .41906 .50481 Mtetra
.654 .774 .937 r
.41906 .50481 .41996 .50556 .42148 .50509 .42058 .50436 Mtetra
.652 .776 .94 r
.42058 .50436 .42148 .50509 .42299 .50463 .4221 .50391 Mtetra
.653 .78 .942 r
.4221 .50391 .42299 .50463 .42451 .50415 .42362 .50345 Mtetra
.651 .785 .945 r
.42362 .50345 .42451 .50415 .42603 .50368 .42514 .503 Mtetra
.647 .788 .95 r
.42514 .503 .42603 .50368 .42755 .50324 .42666 .50256 Mtetra
.634 .786 .954 r
.42666 .50256 .42755 .50324 .42907 .50288 .42818 .50215 Mtetra
.63 .772 .948 r
.42818 .50215 .42907 .50288 .43059 .50258 .4297 .50177 Mtetra
.635 .753 .933 r
.4297 .50177 .43059 .50258 .43211 .50228 .43122 .50138 Mtetra
.647 .737 .914 r
.43122 .50138 .43211 .50228 .43363 .5019 .43274 .50096 Mtetra
.657 .731 .903 r
.43274 .50096 .43363 .5019 .43515 .50143 .43427 .5005 Mtetra
.665 .734 .901 r
.43427 .5005 .43515 .50143 .43668 .50091 .43579 .50001 Mtetra
.677 .745 .902 r
.43579 .50001 .43668 .50091 .43821 .50029 .43732 .49947 Mtetra
.685 .765 .912 r
.43732 .49947 .43821 .50029 .43974 .49961 .43885 .49889 Mtetra
.686 .789 .929 r
.43885 .49889 .43974 .49961 .44128 .49894 .44038 .49832 Mtetra
.673 .811 .949 r
.44038 .49832 .44128 .49894 .44281 .49835 .44192 .49777 Mtetra
.66 .822 .961 r
.44192 .49777 .44281 .49835 .44434 .49783 .44345 .49726 Mtetra
.654 .824 .965 r
.44345 .49726 .44434 .49783 .44587 .49733 .44498 .49677 Mtetra
.653 .824 .965 r
.44498 .49677 .44587 .49733 .4474 .49684 .44651 .49628 Mtetra
.652 .824 .966 r
.44651 .49628 .4474 .49684 .44894 .49635 .44805 .49579 Mtetra
.65 .824 .967 r
.44805 .49579 .44894 .49635 .45047 .49586 .44958 .4953 Mtetra
.648 .825 .968 r
.44958 .4953 .45047 .49586 .452 .49537 .45111 .49482 Mtetra
.645 .826 .969 r
.45111 .49482 .452 .49537 .45354 .49489 .45265 .49434 Mtetra
.643 .827 .971 r
.45265 .49434 .45354 .49489 .45507 .49442 .45419 .49387 Mtetra
.641 .827 .972 r
.45419 .49387 .45507 .49442 .45661 .49395 .45572 .4934 Mtetra
.639 .828 .973 r
.45572 .4934 .45661 .49395 .45815 .49348 .45726 .49294 Mtetra
.639 .83 .974 r
.45726 .49294 .45815 .49348 .45969 .493 .4588 .49247 Mtetra
.642 .832 .974 r
.4588 .49247 .45969 .493 .46123 .49252 .46034 .492 Mtetra
.645 .835 .974 r
.46034 .492 .46123 .49252 .46277 .49203 .46188 .49151 Mtetra
.647 .838 .974 r
.46188 .49151 .46277 .49203 .46431 .49153 .46343 .49102 Mtetra
.666 .843 .968 r
.46343 .49102 .46431 .49153 .46585 .49091 .46497 .49047 Mtetra
.665 .864 .975 r
.46497 .49047 .46585 .49091 .4674 .49025 .46652 .48989 Mtetra
.612 .874 .991 r
.46652 .48989 .4674 .49025 .46894 .48985 .46806 .48941 Mtetra
.472 .803 .999 r
.46806 .48941 .46894 .48985 .47047 .49032 .4696 .48923 Mtetra
.467 .622 .918 r
.4696 .48923 .47047 .49032 .47198 .49233 .47114 .4894 Mtetra
.538 .464 .721 r
.47114 .4894 .47198 .49233 .47344 .49721 .47267 .48966 Mtetra
.569 .404 .618 r
.47267 .48966 .47344 .49721 .47225 .6792 .47421 .48965 Mtetra
.562 .352 .553 r
.47421 .48965 .47225 .6792 .47386 .68058 .47576 .48917 Mtetra
.563 .352 .553 r
.47576 .48917 .47386 .68058 .47555 .67674 .47732 .48854 Mtetra
.47732 .48854 .47555 .67674 .47931 .52025 .47887 .48792 Mtetra
.569 .366 .567 r
.47887 .48792 .47931 .52025 .48103 .50811 .48042 .48738 Mtetra
.573 .376 .576 r
.48042 .48738 .48103 .50811 .48263 .50522 .48198 .48685 Mtetra
.578 .382 .58 r
.48198 .48685 .48263 .50522 .48425 .49995 .48354 .48608 Mtetra
.586 .395 .589 r
.48354 .48608 .48425 .49995 .48584 .49655 .4851 .48521 Mtetra
.575 .392 .596 r
.4851 .48521 .48584 .49655 .48739 .49726 .48665 .48491 Mtetra
.509 .34 .587 r
.48665 .48491 .48739 .49726 .48697 .67966 .48818 .48678 Mtetra
0 0 .367 r
.48818 .48678 .48697 .67966 .48855 .68616 .4877 .67847 Mtetra
0 0 .427 r
.4877 .67847 .48855 .68616 .49017 .68873 .48926 .68679 Mtetra
0 .203 .719 r
.48926 .68679 .49017 .68873 .49181 .68959 .49089 .6886 Mtetra
.577 .709 .932 r
.49089 .6886 .49181 .68959 .49347 .68928 .49255 .6884 Mtetra
.698 .77 .908 r
.49255 .6884 .49347 .68928 .49513 .68869 .49421 .68772 Mtetra
.697 .751 .893 r
.49421 .68772 .49513 .68869 .49678 .68816 .49587 .68703 Mtetra
.633 .7 .894 r
.49587 .68703 .49678 .68816 .49844 .68788 .49753 .68664 Mtetra
.637 .681 .875 r
.49753 .68664 .49844 .68788 .5001 .68758 .49919 .68623 Mtetra
.641 .667 .859 r
.49919 .68623 .5001 .68758 .50176 .68724 .50085 .6858 Mtetra
.647 .656 .845 r
.50085 .6858 .50176 .68724 .50342 .68682 .50251 .68533 Mtetra
.663 .655 .832 r
.50251 .68533 .50342 .68682 .50509 .68613 .50418 .68476 Mtetra
.703 .686 .831 r
.50418 .68476 .50509 .68613 .50676 .6847 .50584 .68394 Mtetra
.785 .811 .873 r
.50584 .68394 .50676 .6847 .50844 .68173 .50751 .68276 Mtetra
0 0 0 r
.50751 .68276 .50844 .68173 .51012 .67653 .50918 .68147 Mtetra
.459 .186 .411 r
.50918 .68147 .51012 .67653 .51186 .65562 .51085 .68039 Mtetra
.551 .325 .526 r
.51085 .68039 .51186 .65562 .51405 .49106 .51252 .67985 Mtetra
.56 .346 .547 r
.51252 .67985 .51405 .49106 .51561 .49707 .51419 .67948 Mtetra
.51419 .67948 .51561 .49707 .5168 .66664 .51586 .67932 Mtetra
.555 .314 .506 r
.51586 .67932 .5168 .66664 .51846 .66933 .51753 .67933 Mtetra
.533 .288 .49 r
.51753 .67933 .51846 .66933 .52013 .66856 .5192 .67876 Mtetra
.461 .229 .474 r
.5192 .67876 .52013 .66856 .52195 .48627 .52088 .67632 Mtetra
0 0 .374 r
.52088 .67632 .52195 .48627 .52354 .47701 .52268 .4872 Mtetra
0 0 .165 r
.52268 .4872 .52354 .47701 .52512 .47346 .52426 .47374 Mtetra
.964 .923 .711 r
.52426 .47374 .52512 .47346 .52669 .47154 .52584 .47075 Mtetra
.733 .788 .896 r
.52584 .47075 .52669 .47154 .52827 .47084 .52742 .46993 Mtetra
.622 .73 .924 r
.52742 .46993 .52827 .47084 .52985 .47045 .529 .46958 Mtetra
.581 .728 .944 r
.529 .46958 .52985 .47045 .53143 .47012 .53058 .46936 Mtetra
.659 .78 .938 r
.53058 .46936 .53143 .47012 .53301 .46962 .53216 .46886 Mtetra
.658 .78 .939 r
.53216 .46886 .53301 .46962 .53459 .46913 .53374 .46837 Mtetra
.658 .781 .939 r
.53374 .46837 .53459 .46913 .53617 .46863 .53533 .46788 Mtetra
.661 .783 .938 r
.53533 .46788 .53617 .46863 .53776 .46813 .53691 .46737 Mtetra
.662 .783 .938 r
.53691 .46737 .53776 .46813 .53934 .46762 .53849 .46686 Mtetra
.53849 .46686 .53934 .46762 .54093 .46711 .54008 .46635 Mtetra
.662 .782 .938 r
.54008 .46635 .54093 .46711 .54251 .4666 .54167 .46584 Mtetra
.662 .782 .937 r
.54167 .46584 .54251 .4666 .5441 .4661 .54325 .46533 Mtetra
.662 .781 .937 r
.54325 .46533 .5441 .4661 .54569 .46559 .54484 .46482 Mtetra
.54484 .46482 .54569 .46559 .54728 .46508 .54643 .46431 Mtetra
.54643 .46431 .54728 .46508 .54887 .46457 .54802 .46381 Mtetra
.661 .78 .937 r
.54802 .46381 .54887 .46457 .55046 .46407 .54961 .4633 Mtetra
.54961 .4633 .55046 .46407 .55205 .46356 .55121 .46279 Mtetra
.55121 .46279 .55205 .46356 .55364 .46306 .5528 .46229 Mtetra
.66 .78 .937 r
.5528 .46229 .55364 .46306 .55523 .46255 .55439 .46178 Mtetra
.55439 .46178 .55523 .46255 .55683 .46205 .55599 .46128 Mtetra
.66 .78 .938 r
.55599 .46128 .55683 .46205 .55842 .46155 .55758 .46078 Mtetra
.659 .78 .938 r
.55758 .46078 .55842 .46155 .56002 .46104 .55918 .46028 Mtetra
.55918 .46028 .56002 .46104 .56162 .46054 .56078 .45978 Mtetra
.658 .781 .939 r
.56078 .45978 .56162 .46054 .56322 .46004 .56238 .45928 Mtetra
.56238 .45928 .56322 .46004 .56481 .45954 .56398 .45878 Mtetra
.658 .782 .94 r
.56398 .45878 .56481 .45954 .56641 .45904 .56558 .45828 Mtetra
.56558 .45828 .56641 .45904 .56802 .45854 .56718 .45778 Mtetra
.658 .783 .941 r
.56718 .45778 .56802 .45854 .56962 .45804 .56878 .45728 Mtetra
.658 .784 .941 r
.56878 .45728 .56962 .45804 .57122 .45754 .57039 .45678 Mtetra
.57039 .45678 .57122 .45754 .57282 .45703 .57199 .45628 Mtetra
.659 .785 .942 r
.57199 .45628 .57282 .45703 .57443 .45653 .5736 .45578 Mtetra
.659 .786 .942 r
.5736 .45578 .57443 .45653 .57603 .45602 .5752 .45527 Mtetra
.66 .786 .941 r
.5752 .45527 .57603 .45602 .57764 .45551 .57681 .45476 Mtetra
.661 .786 .941 r
.57681 .45476 .57764 .45551 .57925 .455 .57842 .45424 Mtetra
.665 .787 .939 r
.57842 .45424 .57925 .455 .58086 .45448 .58003 .45372 Mtetra
.664 .785 .938 r
.58003 .45372 .58086 .45448 .58246 .45396 .58164 .45319 Mtetra
.671 .786 .935 r
.58164 .45319 .58246 .45396 .58407 .45342 .58325 .45264 Mtetra
.739 .799 .9 r
.58325 .45264 .58407 .45342 .58568 .45269 .58485 .45179 Mtetra
.671 .753 .912 r
.58485 .45179 .58568 .45269 .58729 .45215 .58646 .45124 Mtetra
.447 .66 .952 r
.58646 .45124 .58729 .45215 .58891 .45203 .58809 .45137 Mtetra
.868 .426 .049 r
.58809 .45137 .58891 .45203 .59057 .45353 .58978 .45479 Mtetra
.962 .681 .455 r
.58978 .45479 .59057 .45353 .59226 .45693 .59536 .64944 Mtetra
.571 .355 .548 r
.59536 .64944 .59226 .45693 .59779 .64204 .59723 .65629 Mtetra
.559 .32 .51 r
.59723 .65629 .59779 .64204 .59954 .64346 .59896 .65646 Mtetra
.538 .301 .503 r
.59896 .65646 .59954 .64346 .6012 .64064 .60068 .65582 Mtetra
.537 .304 .509 r
.60068 .65582 .6012 .64064 .60298 .64295 .6024 .65495 Mtetra
.562 .318 .504 r
.6024 .65495 .60298 .64295 .60492 .6522 .60414 .65527 Mtetra
.555 .23 .373 r
.60414 .65527 .60492 .6522 .60673 .65533 .60588 .65556 Mtetra
.262 0 0 r
.60588 .65556 .60673 .65533 .60851 .65689 .60762 .65572 Mtetra
.6 .686 .902 r
.60762 .65572 .60851 .65689 .61025 .65691 .60936 .65545 Mtetra
.632 .651 .851 r
.60936 .65545 .61025 .65691 .61198 .65656 .61109 .65505 Mtetra
.648 .652 .84 r
.61109 .65505 .61198 .65656 .61371 .65597 .61282 .65455 Mtetra
.58 .635 .87 r
.61282 .65455 .61371 .65597 .61544 .65561 .61456 .6544 Mtetra
.647 .698 .884 r
.61456 .6544 .61544 .65561 .61717 .65502 .61629 .65393 Mtetra
.752 .753 .853 r
.61629 .65393 .61717 .65502 .61889 .65403 .61801 .65285 Mtetra
.905 .75 .679 r
.61801 .65285 .61889 .65403 .62058 .65182 .61965 .64876 Mtetra
.965 .687 .459 r
.61965 .64876 .62058 .65182 .62222 .64804 .61606 .4569 Mtetra
.583 .368 .554 r
.61606 .4569 .62222 .64804 .6236 .63507 .61736 .44444 Mtetra
.565 .354 .553 r
.61736 .44444 .6236 .63507 .61988 .44715 .61895 .44232 Mtetra
.639 .481 .653 r
.61895 .44232 .61988 .44715 .62142 .44337 .62056 .44118 Mtetra
.657 .579 .756 r
.62056 .44118 .62142 .44337 .623 .44128 .62219 .4405 Mtetra
.666 .786 .938 r
.62219 .4405 .623 .44128 .62463 .44054 .62383 .43996 Mtetra
.603 .82 .983 r
.62383 .43996 .62463 .44054 .62627 .44024 .62547 .43956 Mtetra
.593 .788 .974 r
.62547 .43956 .62627 .44024 .62792 .44015 .62711 .43923 Mtetra
.656 .748 .917 r
.62711 .43923 .62792 .44015 .62956 .43974 .62875 .43874 Mtetra
.667 .734 .9 r
.62875 .43874 .62956 .43974 .6312 .43924 .63038 .4382 Mtetra
.672 .727 .891 r
.63038 .4382 .6312 .43924 .63284 .43869 .63202 .43764 Mtetra
.743 .748 .856 r
.63202 .43764 .63284 .43869 .63446 .43777 .63365 .43668 Mtetra
.701 .726 .87 r
.63365 .43668 .63446 .43777 .6361 .437 .63528 .43595 Mtetra
.57 .687 .919 r
.63528 .43595 .6361 .437 .63774 .4366 .63694 .4358 Mtetra
.769 .295 0 r
.63694 .4358 .63774 .4366 .63945 .43783 .63869 .43857 Mtetra
.967 .681 .436 r
.63869 .43857 .63945 .43783 .64122 .44101 .64721 .632 Mtetra
.575 .358 .548 r
.64721 .632 .64122 .44101 .64962 .62708 .64931 .64135 Mtetra
.581 .338 .513 r
.64931 .64135 .64962 .62708 .65167 .63509 .65112 .64255 Mtetra
.534 .276 .47 r
.65112 .64255 .65167 .63509 .65344 .63504 .65288 .64221 Mtetra
.471 .222 .454 r
.65288 .64221 .65344 .63504 .65505 .63094 .6546 .64066 Mtetra
.27 .079 .428 r
.6546 .64066 .65505 .63094 .64954 .44021 .65614 .63449 Mtetra
.014 0 .417 r
.65614 .63449 .64954 .44021 .65101 .43496 .65031 .43679 Mtetra
.842 .821 .341 r
.65031 .43679 .65101 .43496 .65257 .43221 .65178 .43163 Mtetra
.825 .862 .874 r
.65178 .43163 .65257 .43221 .6542 .43128 .6534 .43028 Mtetra
.642 .727 .91 r
.6534 .43028 .6542 .43128 .65586 .43094 .65506 .42985 Mtetra
.546 .666 .916 r
.65506 .42985 .65586 .43094 .65753 .43084 .65673 .42978 Mtetra
.628 .709 .905 r
.65673 .42978 .65753 .43084 .65919 .43045 .65839 .42941 Mtetra
.653 .723 .899 r
.65839 .42941 .65919 .43045 .66085 .42993 .66005 .42893 Mtetra
.661 .733 .903 r
.66005 .42893 .66085 .42993 .6625 .42935 .6617 .42841 Mtetra
.699 .759 .899 r
.6617 .42841 .6625 .42935 .66414 .42844 .66335 .42772 Mtetra
.699 .814 .936 r
.66335 .42772 .66414 .42844 .66579 .42761 .66501 .42703 Mtetra
.656 .842 .972 r
.66501 .42703 .66579 .42761 .66745 .42712 .66666 .42647 Mtetra
.619 .809 .973 r
.66666 .42647 .66745 .42712 .66916 .4278 .66833 .42605 Mtetra
.571 .575 .818 r
.66833 .42605 .66916 .4278 .67095 .42996 .67001 .42599 Mtetra
.509 .414 .683 r
.67001 .42599 .67095 .42996 .67302 .43858 .67173 .42668 Mtetra
.379 .25 .577 r
.67173 .42668 .67302 .43858 .68349 .6296 .67367 .43215 Mtetra
.045 0 .438 r
.67367 .43215 .68349 .6296 .68545 .6331 .68446 .6289 Mtetra
.05 .106 .601 r
.68446 .6289 .68545 .6331 .68732 .63459 .68645 .63305 Mtetra
.364 .504 .865 r
.68645 .63305 .68732 .63459 .68913 .6349 .68828 .63373 Mtetra
.632 .704 .898 r
.68828 .63373 .68913 .6349 .69092 .63454 .69007 .63332 Mtetra
.72 .727 .857 r
.69007 .63332 .69092 .63454 .69268 .63363 .69183 .63241 Mtetra
.699 .722 .867 r
.69183 .63241 .69268 .63363 .69439 .63181 .69359 .63164 Mtetra
.705 .961 .944 r
.69359 .63164 .69439 .63181 .69605 .6287 .69535 .63065 Mtetra
.117 0 .106 r
.69535 .63065 .69605 .6287 .69751 .62194 .69707 .62895 Mtetra
.189 .001 .379 r
.69707 .62895 .69751 .62194 .68945 .42719 .69861 .62345 Mtetra
.042 0 .432 r
.69861 .62345 .68945 .42719 .6909 .42213 .6903 .42493 Mtetra
0 0 0 r
.6903 .42493 .6909 .42213 .69247 .41962 .69172 .41928 Mtetra
.875 .923 .854 r
.69172 .41928 .69247 .41962 .69412 .41857 .69333 .41762 Mtetra
.657 .747 .916 r
.69333 .41762 .69412 .41857 .6958 .41818 .69501 .41711 Mtetra
.555 .677 .92 r
.69501 .41711 .6958 .41818 .6975 .41806 .69671 .417 Mtetra
.613 .705 .911 r
.69671 .417 .6975 .41806 .69919 .41773 .6984 .41669 Mtetra
.655 .726 .901 r
.6984 .41669 .69919 .41773 .70087 .41721 .70008 .41619 Mtetra
.663 .734 .903 r
.70008 .41619 .70087 .41721 .70255 .41663 .70176 .41566 Mtetra
.695 .757 .899 r
.70176 .41566 .70255 .41663 .70421 .41574 .70344 .41498 Mtetra
.704 .808 .929 r
.70344 .41498 .70421 .41574 .70587 .41487 .70511 .41427 Mtetra
.667 .842 .967 r
.70511 .41427 .70587 .41487 .70755 .41431 .70679 .41367 Mtetra
.628 .818 .973 r
.70679 .41367 .70755 .41431 .70929 .41475 .70848 .4132 Mtetra
.584 .608 .842 r
.70848 .4132 .70929 .41475 .71111 .41661 .71018 .41306 Mtetra
.519 .434 .699 r
.71018 .41306 .71111 .41661 .71317 .42253 .71193 .41359 Mtetra
.392 .274 .598 r
.71193 .41359 .71317 .42253 .72625 .61643 .71388 .41755 Mtetra
.067 0 .451 r
.71388 .41755 .72625 .61643 .72832 .6206 .72725 .61547 Mtetra
.074 .1 .583 r
.72725 .61547 .72832 .6206 .73026 .62231 .72939 .62054 Mtetra
.304 .434 .828 r
.72939 .62054 .73026 .62231 .73212 .62276 .73128 .62158 Mtetra
.615 .696 .901 r
.73128 .62158 .73212 .62276 .73394 .62246 .7331 .62123 Mtetra
.713 .727 .861 r
.7331 .62123 .73394 .62246 .73572 .6216 .73488 .62036 Mtetra
.746 .736 .843 r
.73488 .62036 .73572 .6216 .73744 .61969 .73665 .61925 Mtetra
.8 .919 .918 r
.73665 .61925 .73744 .61969 .73907 .61629 .73842 .618 Mtetra
.169 0 .092 r
.73842 .618 .73907 .61629 .7405 .6098 .74017 .61665 Mtetra
.519 .259 .46 r
.74017 .61665 .7405 .6098 .74168 .59947 .74198 .61605 Mtetra
.552 .318 .514 r
.74198 .61605 .74168 .59947 .74362 .60104 .74381 .61585 Mtetra
.538 .305 .509 r
.74381 .61585 .74362 .60104 .74546 .60113 .7456 .61506 Mtetra
.452 .236 .494 r
.7456 .61506 .74546 .60113 .73517 .41447 .74719 .611 Mtetra
.066 0 .446 r
.74719 .611 .73517 .41447 .73651 .40837 .73604 .41193 Mtetra
0 0 .019 r
.73604 .41193 .73651 .40837 .73805 .40527 .73733 .40503 Mtetra
.925 .931 .792 r
.73733 .40503 .73805 .40527 .73968 .40368 .73892 .40283 Mtetra
.712 .791 .914 r
.73892 .40283 .73968 .40368 .74137 .40292 .74061 .40208 Mtetra
.605 .757 .951 r
.74061 .40208 .74137 .40292 .74307 .40243 .74233 .40173 Mtetra
.586 .789 .976 r
.74233 .40173 .74307 .40243 .74479 .40204 .74404 .4014 Mtetra
.615 .817 .978 r
.74404 .4014 .74479 .40204 .7465 .40167 .74576 .40096 Mtetra
.617 .797 .968 r
.74576 .40096 .7465 .40167 .74822 .40133 .74747 .40054 Mtetra
.635 .781 .951 r
.74747 .40054 .74822 .40133 .74994 .40092 .74919 .40008 Mtetra
.651 .775 .94 r
.74919 .40008 .74994 .40092 .75165 .40042 .7509 .39958 Mtetra
.653 .777 .939 r
.7509 .39958 .75165 .40042 .75336 .3999 .75261 .39906 Mtetra
.65 .776 .94 r
.75261 .39906 .75336 .3999 .75508 .39944 .75433 .39856 Mtetra
.648 .765 .934 r
.75433 .39856 .75508 .39944 .7568 .39903 .75604 .39807 Mtetra
.653 .747 .919 r
.75604 .39807 .7568 .39903 .75852 .39862 .75776 .39757 Mtetra
.712 .751 .882 r
.75776 .39757 .75852 .39862 .76022 .39786 .75946 .39678 Mtetra
.729 .749 .868 r
.75946 .39678 .76022 .39786 .76191 .39695 .76115 .39589 Mtetra
.634 .716 .907 r
.76115 .39589 .76191 .39695 .76364 .39652 .76287 .39547 Mtetra
0 .259 .765 r
.76287 .39547 .76364 .39652 .7655 .39797 .76474 .39692 Mtetra
.951 .601 .229 r
.76474 .39692 .7655 .39797 .76823 .41084 .76742 .40921 Mtetra
.976 .676 .372 r
.76742 .40921 .76823 .41084 .78467 .60443 .78387 .60343 Mtetra
0 0 .531 r
.78387 .60343 .78467 .60443 .78673 .60675 .78592 .6057 Mtetra
.564 .703 .935 r
.78592 .6057 .78673 .60675 .7886 .60667 .78779 .60552 Mtetra
.711 .744 .878 r
.78779 .60552 .7886 .60667 .79041 .60576 .7896 .60467 Mtetra
.721 .76 .883 r
.7896 .60467 .79041 .60576 .79216 .60407 .79142 .60377 Mtetra
.633 .925 .974 r
.79142 .60377 .79216 .60407 .79383 .60131 .79324 .60302 Mtetra
.19 0 .108 r
.79324 .60302 .79383 .60131 .79529 .59593 .79502 .60169 Mtetra
.305 .08 .4 r
.79502 .60169 .79529 .59593 .78163 .40086 .79663 .59816 Mtetra
.097 .013 .461 r
.79663 .59816 .78163 .40086 .78288 .39427 .78274 .40088 Mtetra
0 0 .265 r
.78274 .40088 .78288 .39427 .78442 .39136 .78375 .39134 Mtetra
.951 .95 .724 r
.78375 .39134 .78442 .39136 .78607 .38979 .78531 .38869 Mtetra
.711 .741 .875 r
.78531 .38869 .78607 .38979 .78778 .3891 .78702 .38789 Mtetra
.62 .685 .889 r
.78702 .38789 .78778 .3891 .78953 .38867 .78877 .38754 Mtetra
.662 .718 .89 r
.78877 .38754 .78953 .38867 .79125 .38803 .7905 .387 Mtetra
.743 .767 .872 r
.7905 .387 .79125 .38803 .79295 .38705 .7922 .38603 Mtetra
.656 .738 .91 r
.7922 .38603 .79295 .38705 .79468 .38652 .79394 .38551 Mtetra
.095 .423 .868 r
.79394 .38551 .79468 .38652 .79655 .3875 .7958 .3865 Mtetra
.902 .514 .082 r
.7958 .3865 .79655 .3875 .79894 .39466 .7982 .3937 Mtetra
.975 .672 .358 r
.7982 .3937 .79894 .39466 .81781 .59378 .81702 .59284 Mtetra
.605 .138 0 r
.81702 .59284 .81781 .59378 .81995 .59664 .81917 .59568 Mtetra
.603 .746 .945 r
.81917 .59568 .81995 .59664 .82183 .59629 .82105 .59533 Mtetra
.758 .799 .886 r
.82105 .59533 .82183 .59629 .82364 .5952 .82286 .59423 Mtetra
.783 .804 .87 r
.82286 .59423 .82364 .5952 .82544 .59394 .82466 .59296 Mtetra
.714 .783 .907 r
.82466 .59296 .82544 .59394 .82728 .59312 .8265 .59212 Mtetra
.7 .776 .91 r
.8265 .59212 .82728 .59312 .82912 .59236 .82834 .59136 Mtetra
.657 .757 .924 r
.82834 .59136 .82912 .59236 .83098 .5918 .8302 .59079 Mtetra
.584 .726 .941 r
.8302 .59079 .83098 .5918 .83287 .59151 .83209 .59052 Mtetra
.558 .717 .947 r
.83209 .59052 .83287 .59151 .83477 .59131 .83399 .59033 Mtetra
.488 .686 .955 r
.83399 .59033 .83477 .59131 .83669 .59132 .83591 .59035 Mtetra
.411 .648 .955 r
.83591 .59035 .83669 .59132 .83863 .59155 .83785 .59059 Mtetra
.61 .748 .943 r
.83785 .59059 .83863 .59155 .84051 .59117 .83974 .5902 Mtetra
.865 .817 .8 r
.83974 .5902 .84051 .59117 .84224 .58908 .84147 .58812 Mtetra
.981 .744 .503 r
.84147 .58812 .84224 .58908 .84314 .5781 .84237 .57717 Mtetra
.977 .678 .362 r
.84237 .57717 .84314 .5781 .82639 .3798 .82565 .37878 Mtetra
.93 .791 .685 r
.82565 .37878 .82639 .3798 .82786 .37624 .82713 .37521 Mtetra
.722 .764 .886 r
.82713 .37521 .82786 .37624 .82958 .37538 .82885 .37435 Mtetra
.598 .714 .925 r
.82885 .37435 .82958 .37538 .83137 .37509 .83064 .37406 Mtetra
.83064 .37406 .83137 .37509 .83315 .3748 .83242 .37377 Mtetra
.737 .769 .878 r
.83242 .37377 .83315 .3748 .83487 .37386 .83414 .37283 Mtetra
.655 .738 .911 r
.83414 .37283 .83487 .37386 .83664 .37334 .83591 .37231 Mtetra
.233 .509 .907 r
.83591 .37231 .83664 .37334 .83852 .37408 .8378 .37304 Mtetra
.881 .488 .032 r
.8378 .37304 .83852 .37408 .84104 .38115 .84031 .38011 Mtetra
.975 .667 .334 r
.84031 .38011 .84104 .38115 .86274 .58146 .86198 .58048 Mtetra
.657 .204 0 r
.86198 .58048 .86274 .58146 .86502 .58488 .86426 .58391 Mtetra
.382 .631 .952 r
.86426 .58391 .86502 .58488 .867 .58519 .86624 .58422 Mtetra
.694 .781 .918 r
.86624 .58422 .867 .58519 .86887 .58444 .86811 .58347 Mtetra
.875 .821 .791 r
.86811 .58347 .86887 .58444 .87059 .58222 .86983 .58126 Mtetra
.979 .766 .546 r
.86983 .58126 .87059 .58222 .87174 .5744 .87099 .57349 Mtetra
.977 .675 .347 r
.87099 .57349 .87174 .5744 .85294 .37238 .85222 .37138 Mtetra
.952 .79 .644 r
.85222 .37138 .85294 .37238 .85432 .36804 .8536 .36703 Mtetra
.746 .776 .878 r
.8536 .36703 .85432 .36804 .85605 .36705 .85533 .36603 Mtetra
.618 .726 .923 r
.85533 .36603 .85605 .36705 .85784 .36669 .85712 .36566 Mtetra
.587 .71 .928 r
.85712 .36566 .85784 .36669 .85965 .36644 .85893 .36541 Mtetra
.747 .773 .874 r
.85893 .36541 .85965 .36644 .86138 .36544 .86066 .3644 Mtetra
.673 .745 .905 r
.86066 .3644 .86138 .36544 .86315 .36484 .86243 .36379 Mtetra
.374 .593 .93 r
.86243 .36379 .86315 .36484 .86503 .36525 .86431 .3642 Mtetra
.808 .396 0 r
.86431 .3642 .86503 .36525 .86746 .37073 .86674 .36963 Mtetra
.973 .663 .318 r
.86674 .36963 .86746 .37073 .89105 .57238 .8903 .57133 Mtetra
.696 .259 0 r
.8903 .57133 .89105 .57238 .89345 .57643 .8927 .57542 Mtetra
.509 .691 .95 r
.8927 .57542 .89345 .57643 .89542 .5764 .89467 .57539 Mtetra
.695 .776 .914 r
.89467 .57539 .89542 .5764 .8973 .57564 .89655 .57463 Mtetra
.735 .791 .897 r
.89655 .57463 .8973 .57564 .89916 .57466 .89842 .57366 Mtetra
.5 .69 .953 r
.89842 .57366 .89916 .57466 .90113 .57464 .90039 .57365 Mtetra
.625 .752 .938 r
.90039 .57365 .90113 .57464 .90305 .57419 .90231 .5732 Mtetra
.81 .815 .855 r
.90231 .5732 .90305 .57419 .90486 .57269 .90412 .57171 Mtetra
.98 .774 .555 r
.90412 .57171 .90486 .57269 .90603 .56552 .9053 .56459 Mtetra
.976 .671 .329 r
.9053 .56459 .90603 .56552 .88508 .36278 .88438 .36178 Mtetra
.962 .789 .62 r
.88438 .36178 .88508 .36278 .88639 .35798 .88569 .35695 Mtetra
.744 .777 .88 r
.88569 .35695 .88639 .35798 .88813 .357 .88743 .35597 Mtetra
.602 .719 .927 r
.88743 .35597 .88813 .357 .88996 .35668 .88925 .35565 Mtetra
.513 .674 .937 r
.88925 .35565 .88996 .35668 .89182 .35669 .89111 .35565 Mtetra
.651 .739 .914 r
.89111 .35565 .89182 .35669 .89362 .35619 .89291 .35514 Mtetra
.657 .74 .911 r
.89291 .35514 .89362 .35619 .89542 .35566 .89472 .3546 Mtetra
.671 .743 .905 r
.89472 .3546 .89542 .35566 .89721 .35506 .89651 .35399 Mtetra
.763 .775 .863 r
.89651 .35399 .89721 .35506 .89895 .35393 .89824 .35286 Mtetra
.696 .752 .894 r
.89824 .35286 .89895 .35393 .90073 .35321 .90002 .35213 Mtetra
.495 .653 .93 r
.90002 .35213 .90073 .35321 .90261 .35333 .9019 .35221 Mtetra
.757 .347 0 r
.9019 .35221 .90261 .35333 .90517 .35908 .90439 .35743 Mtetra
.97 .656 .292 r
.90439 .35743 .90517 .35908 .93137 .56162 .93056 .55998 Mtetra
0 0 .423 r
.93056 .55998 .93137 .56162 .93387 .5658 .9331 .56444 Mtetra
.547 .643 .896 r
.9331 .56444 .93387 .5658 .93585 .56565 .93509 .5644 Mtetra
.699 .732 .876 r
.93509 .5644 .93585 .56565 .93774 .56474 .937 .56358 Mtetra
.766 .774 .859 r
.937 .56358 .93774 .56474 .93958 .5634 .93885 .56234 Mtetra
.468 .692 .964 r
.31517 .7358 .31616 .73664 .31769 .73656 .3167 .73584 Mtetra
.615 .773 .956 r
.3167 .73584 .31769 .73656 .31924 .73619 .31825 .73549 Mtetra
.782 .801 .868 r
.31825 .73549 .31924 .73619 .32083 .73518 .31984 .73436 Mtetra
.913 .73 .641 r
.31984 .73436 .32083 .73518 .32261 .73069 .32174 .72795 Mtetra
.934 .684 .535 r
.32174 .72795 .32261 .73069 .33489 .54038 .33423 .53485 Mtetra
.75 .551 .626 r
.33423 .53485 .33489 .54038 .33676 .5329 .33595 .53004 Mtetra
.666 .542 .704 r
.33595 .53004 .33676 .5329 .33831 .53114 .33745 .52908 Mtetra
.607 .553 .768 r
.33745 .52908 .33831 .53114 .33981 .53019 .33891 .52884 Mtetra
.509 .588 .869 r
.33891 .52884 .33981 .53019 .34129 .52963 .34035 .52897 Mtetra
.614 .78 .96 r
.34035 .52897 .34129 .52963 .34276 .5292 .34182 .52863 Mtetra
.625 .81 .971 r
.34182 .52863 .34276 .5292 .34422 .52889 .34329 .52824 Mtetra
.642 .79 .953 r
.34329 .52824 .34422 .52889 .34569 .52864 .34477 .52783 Mtetra
.751 .768 .867 r
.34477 .52783 .34569 .52864 .34718 .52785 .34627 .52692 Mtetra
.696 .736 .881 r
.34627 .52692 .34718 .52785 .34867 .52726 .34775 .5263 Mtetra
.498 .662 .935 r
.34775 .5263 .34867 .52726 .35012 .52721 .34921 .52634 Mtetra
.931 .557 .266 r
.34921 .52634 .35012 .52721 .35143 .53001 .35044 .53057 Mtetra
.938 .681 .522 r
.35044 .53057 .35143 .53001 .34325 .718 .34196 .72336 Mtetra
.734 .453 .502 r
.34196 .72336 .34325 .718 .34434 .72675 .34325 .72826 Mtetra
.55 .156 .247 r
.34325 .72826 .34434 .72675 .34583 .728 .34478 .72859 Mtetra
0 0 0 r
.34478 .72859 .34583 .728 .34737 .72819 .34636 .72797 Mtetra
.78 .923 .931 r
.34636 .72797 .34737 .72819 .34893 .7279 .34796 .72693 Mtetra
.561 .698 .932 r
.34796 .72693 .34893 .7279 .35048 .72782 .34952 .72679 Mtetra
.62 .706 .907 r
.34952 .72679 .35048 .72782 .35205 .72739 .35109 .72647 Mtetra
.754 .759 .857 r
.35109 .72647 .35205 .72739 .35366 .72632 .35269 .72546 Mtetra
.908 .738 .66 r
.35269 .72546 .35366 .72632 .3554 .72247 .35449 .72027 Mtetra
.939 .685 .528 r
.35449 .72027 .3554 .72247 .36585 .53449 .36529 .52625 Mtetra
.725 .518 .609 r
.36529 .52625 .36585 .53449 .36784 .52358 .36703 .52053 Mtetra
.685 .548 .693 r
.36703 .52053 .36784 .52358 .36941 .52143 .36856 .51924 Mtetra
.615 .549 .757 r
.36856 .51924 .36941 .52143 .37092 .52038 .37004 .51893 Mtetra
.529 .581 .852 r
.37004 .51893 .37092 .52038 .37242 .51978 .37151 .51902 Mtetra
.599 .752 .951 r
.37151 .51902 .37242 .51978 .37391 .51932 .37299 .51874 Mtetra
.627 .808 .969 r
.37299 .51874 .37391 .51932 .3754 .519 .37448 .51834 Mtetra
.643 .792 .954 r
.37448 .51834 .3754 .519 .37688 .51873 .37597 .51792 Mtetra
.745 .771 .874 r
.37597 .51792 .37688 .51873 .37839 .51798 .37748 .51704 Mtetra
.708 .738 .875 r
.37748 .51704 .37839 .51798 .37989 .51734 .37899 .51635 Mtetra
.547 .677 .924 r
.37899 .51635 .37989 .51734 .38137 .5172 .38047 .51628 Mtetra
.904 .491 .139 r
.38047 .51628 .38137 .5172 .38275 .51949 .3818 .51962 Mtetra
.942 .682 .514 r
.3818 .51962 .38275 .51949 .37648 .7036 .37511 .7126 Mtetra
.705 .44 .521 r
.37511 .7126 .37648 .7036 .37749 .71693 .37642 .71853 Mtetra
.602 .22 .29 r
.37642 .71853 .37749 .71693 .37899 .71854 .37797 .7192 Mtetra
0 0 0 r
.37797 .7192 .37899 .71854 .38055 .71877 .37956 .7186 Mtetra
.782 .935 .931 r
.37956 .7186 .38055 .71877 .38214 .71851 .38118 .71752 Mtetra
.709 .741 .876 r
.38118 .71752 .38214 .71851 .38373 .71811 .38278 .71678 Mtetra
.667 .672 .845 r
.38278 .71678 .38373 .71811 .38532 .7176 .38438 .71622 Mtetra
.66 .664 .842 r
.38438 .71622 .38532 .7176 .38692 .717 .38598 .7157 Mtetra
.653 .671 .855 r
.38598 .7157 .38692 .717 .38851 .71658 .38757 .71523 Mtetra
.643 .66 .851 r
.38757 .71523 .38851 .71658 .39011 .71619 .38917 .7148 Mtetra
.634 .651 .85 r
.38917 .7148 .39011 .71619 .39171 .71569 .39076 .71442 Mtetra
.618 .664 .872 r
.39076 .71442 .39171 .71569 .39332 .71477 .39235 .71412 Mtetra
.569 .784 .98 r
.39235 .71412 .39332 .71477 .39494 .71358 .39395 .71385 Mtetra
0 0 0 r
.39395 .71385 .39494 .71358 .39657 .71232 .39554 .71357 Mtetra
.45 .02 .13 r
.39554 .71357 .39657 .71232 .39817 .71203 .39712 .71354 Mtetra
.432 .028 .169 r
.39712 .71354 .39817 .71203 .39975 .71193 .39872 .71335 Mtetra
.234 0 .031 r
.39872 .71335 .39975 .71193 .40137 .71117 .40033 .71262 Mtetra
.805 .914 .52 r
.40033 .71262 .40137 .71117 .40312 .70621 .40202 .70958 Mtetra
.998 .825 .479 r
.40202 .70958 .40312 .70621 .41129 .51302 .40402 .69777 Mtetra
0 0 .306 r
.40402 .69777 .41129 .51302 .41297 .50755 .41199 .5093 Mtetra
0 0 0 r
.41199 .5093 .41297 .50755 .41453 .50587 .41357 .50694 Mtetra
.204 0 0 r
.41357 .50694 .41453 .50587 .41604 .50533 .41509 .50636 Mtetra
.429 0 .081 r
.41509 .50636 .41604 .50533 .41755 .50514 .41659 .50633 Mtetra
.379 0 .084 r
.41659 .50633 .41755 .50514 .41906 .50481 .4181 .50608 Mtetra
.322 0 .068 r
.4181 .50608 .41906 .50481 .42058 .50436 .41962 .50564 Mtetra
.329 0 .077 r
.41962 .50564 .42058 .50436 .4221 .50391 .42114 .50521 Mtetra
.366 0 .104 r
.42114 .50521 .4221 .50391 .42362 .50345 .42265 .50487 Mtetra
.379 0 .137 r
.42265 .50487 .42362 .50345 .42514 .503 .42417 .50452 Mtetra
.338 0 .132 r
.42417 .50452 .42514 .503 .42666 .50256 .4257 .50399 Mtetra
.093 0 0 r
.4257 .50399 .42666 .50256 .42818 .50215 .42724 .50292 Mtetra
.467 .824 .557 r
.42724 .50292 .42818 .50215 .4297 .50177 .42878 .50163 Mtetra
.81 .942 .912 r
.42878 .50163 .4297 .50177 .43122 .50138 .43033 .50046 Mtetra
.722 .749 .874 r
.43033 .50046 .43122 .50138 .43274 .50096 .43186 .49969 Mtetra
.66 .668 .847 r
.43186 .49969 .43274 .50096 .43427 .5005 .43339 .49919 Mtetra
.643 .656 .848 r
.43339 .49919 .43427 .5005 .43579 .50001 .43491 .49878 Mtetra
.652 .673 .857 r
.43491 .49878 .43579 .50001 .43732 .49947 .43644 .49834 Mtetra
.663 .693 .868 r
.43644 .49834 .43732 .49947 .43885 .49889 .43797 .49784 Mtetra
.665 .709 .881 r
.43797 .49784 .43885 .49889 .44038 .49832 .4395 .49734 Mtetra
.666 .726 .894 r
.4395 .49734 .44038 .49832 .44192 .49777 .44103 .49685 Mtetra
.666 .736 .902 r
.44103 .49685 .44192 .49777 .44345 .49726 .44256 .49635 Mtetra
.665 .738 .904 r
.44256 .49635 .44345 .49726 .44498 .49677 .4441 .49585 Mtetra
.664 .738 .905 r
.4441 .49585 .44498 .49677 .44651 .49628 .44563 .49536 Mtetra
.663 .738 .906 r
.44563 .49536 .44651 .49628 .44805 .49579 .44716 .49488 Mtetra
.662 .739 .907 r
.44716 .49488 .44805 .49579 .44958 .4953 .4487 .49439 Mtetra
.662 .74 .908 r
.4487 .49439 .44958 .4953 .45111 .49482 .45023 .49391 Mtetra
.66 .739 .908 r
.45023 .49391 .45111 .49482 .45265 .49434 .45177 .49344 Mtetra
.656 .738 .91 r
.45177 .49344 .45265 .49434 .45419 .49387 .45331 .49298 Mtetra
.645 .738 .917 r
.45331 .49298 .45419 .49387 .45572 .4934 .45484 .49256 Mtetra
.634 .747 .93 r
.45484 .49256 .45572 .4934 .45726 .49294 .45638 .49218 Mtetra
.63 .766 .945 r
.45638 .49218 .45726 .49294 .4588 .49247 .45792 .4918 Mtetra
.637 .791 .956 r
.45792 .4918 .4588 .49247 .46034 .492 .45946 .49138 Mtetra
.648 .809 .96 r
.45946 .49138 .46034 .492 .46188 .49151 .461 .49091 Mtetra
.654 .815 .961 r
.461 .49091 .46188 .49151 .46343 .49102 .46254 .49041 Mtetra
.657 .816 .96 r
.46254 .49041 .46343 .49102 .46497 .49047 .46409 .48991 Mtetra
.656 .83 .967 r
.46409 .48991 .46497 .49047 .46652 .48989 .46563 .4894 Mtetra
.656 .848 .973 r
.46563 .4894 .46652 .48989 .46806 .48941 .46718 .48887 Mtetra
.675 .838 .961 r
.46718 .48887 .46806 .48941 .4696 .48923 .46873 .4883 Mtetra
.689 .743 .892 r
.46873 .4883 .4696 .48923 .47114 .4894 .47027 .48769 Mtetra
.665 .618 .793 r
.47027 .48769 .47114 .4894 .47267 .48966 .47182 .48708 Mtetra
.638 .541 .729 r
.47182 .48708 .47267 .48966 .47421 .48965 .47337 .48651 Mtetra
.624 .509 .702 r
.47337 .48651 .47421 .48965 .47576 .48917 .47492 .48597 Mtetra
.622 .506 .7 r
.47492 .48597 .47576 .48917 .47732 .48854 .47648 .48545 Mtetra
.623 .511 .705 r
.47648 .48545 .47732 .48854 .47887 .48792 .47803 .48493 Mtetra
.625 .515 .709 r
.47803 .48493 .47887 .48792 .48042 .48738 .47958 .48441 Mtetra
.624 .516 .71 r
.47958 .48441 .48042 .48738 .48198 .48685 .48113 .48389 Mtetra
.639 .526 .709 r
.48113 .48389 .48198 .48685 .48354 .48608 .48269 .48322 Mtetra
.648 .535 .711 r
.48269 .48322 .48354 .48608 .4851 .48521 .48425 .48247 Mtetra
.613 .519 .724 r
.48425 .48247 .4851 .48521 .48665 .48491 .4858 .4821 Mtetra
.417 .395 .727 r
.4858 .4821 .48665 .48491 .48818 .48678 .48734 .48309 Mtetra
0 0 .326 r
.48734 .48309 .48818 .48678 .4877 .67847 .48884 .48843 Mtetra
0 0 .357 r
.48884 .48843 .4877 .67847 .48926 .68679 .48838 .68218 Mtetra
.173 .169 .612 r
.48838 .68218 .48926 .68679 .49089 .6886 .48999 .68549 Mtetra
.581 .491 .718 r
.48999 .68549 .49089 .6886 .49255 .6884 .49164 .6854 Mtetra
.649 .537 .714 r
.49164 .6854 .49255 .6884 .49421 .68772 .49331 .6846 Mtetra
.657 .537 .706 r
.49331 .6846 .49421 .68772 .49587 .68703 .49497 .68367 Mtetra
.626 .51 .702 r
.49497 .68367 .49587 .68703 .49753 .68664 .49663 .68307 Mtetra
.611 .494 .695 r
.49663 .68307 .49753 .68664 .49919 .68623 .49829 .68262 Mtetra
.574 .469 .697 r
.49829 .68262 .49919 .68623 .50085 .6858 .49995 .68259 Mtetra
.523 .451 .717 r
.49995 .68259 .50085 .6858 .50251 .68533 .5016 .683 Mtetra
.513 .495 .774 r
.5016 .683 .50251 .68533 .50418 .68476 .50326 .68333 Mtetra
.533 .606 .872 r
.50326 .68333 .50418 .68476 .50584 .68394 .50492 .68338 Mtetra
.556 .812 .993 r
.50492 .68338 .50584 .68394 .50751 .68276 .50659 .68308 Mtetra
0 0 0 r
.50659 .68308 .50751 .68276 .50918 .68147 .50826 .68265 Mtetra
.28 0 .003 r
.50826 .68265 .50918 .68147 .51085 .68039 .50993 .68215 Mtetra
.377 0 .178 r
.50993 .68215 .51085 .68039 .51252 .67985 .5116 .68163 Mtetra
.373 0 .18 r
.5116 .68163 .51252 .67985 .51419 .67948 .51327 .68108 Mtetra
.392 0 .162 r
.51327 .68108 .51419 .67948 .51586 .67932 .51494 .68069 Mtetra
.426 .005 .136 r
.51494 .68069 .51586 .67932 .51753 .67933 .51661 .68053 Mtetra
.269 0 .004 r
.51661 .68053 .51753 .67933 .5192 .67876 .51829 .67999 Mtetra
0 0 0 r
.51829 .67999 .5192 .67876 .52088 .67632 .51996 .67823 Mtetra
.944 .876 .463 r
.51996 .67823 .52088 .67632 .52268 .4872 .52164 .67244 Mtetra
0 0 .349 r
.52164 .67244 .52268 .4872 .52426 .47374 .5234 .47692 Mtetra
0 0 0 r
.5234 .47692 .52426 .47374 .52584 .47075 .52499 .47193 Mtetra
.076 0 0 r
.52499 .47193 .52584 .47075 .52742 .46993 .52657 .47096 Mtetra
.346 0 .022 r
.52657 .47096 .52742 .46993 .529 .46958 .52815 .47069 Mtetra
.423 0 .091 r
.52815 .47069 .529 .46958 .53058 .46936 .52973 .47061 Mtetra
.309 0 .06 r
.52973 .47061 .53058 .46936 .53216 .46886 .53131 .47012 Mtetra
.312 0 .063 r
.53131 .47012 .53216 .46886 .53374 .46837 .5329 .46963 Mtetra
.311 0 .064 r
.5329 .46963 .53374 .46837 .53533 .46788 .53448 .46914 Mtetra
.304 0 .06 r
.53448 .46914 .53533 .46788 .53691 .46737 .53607 .46862 Mtetra
.3 0 .056 r
.53607 .46862 .53691 .46737 .53849 .46686 .53765 .46811 Mtetra
.297 0 .052 r
.53765 .46811 .53849 .46686 .54008 .46635 .53924 .46758 Mtetra
.296 0 .048 r
.53924 .46758 .54008 .46635 .54167 .46584 .54083 .46707 Mtetra
.295 0 .046 r
.54083 .46707 .54167 .46584 .54325 .46533 .54242 .46655 Mtetra
.294 0 .043 r
.54242 .46655 .54325 .46533 .54484 .46482 .54401 .46603 Mtetra
.293 0 .042 r
.54401 .46603 .54484 .46482 .54643 .46431 .5456 .46552 Mtetra
.293 0 .041 r
.5456 .46552 .54643 .46431 .54802 .46381 .54719 .46501 Mtetra
.293 0 .04 r
.54719 .46501 .54802 .46381 .54961 .4633 .54878 .4645 Mtetra
.294 0 .04 r
.54878 .4645 .54961 .4633 .55121 .46279 .55038 .46399 Mtetra
.295 0 .04 r
.55038 .46399 .55121 .46279 .5528 .46229 .55197 .46349 Mtetra
.296 0 .04 r
.55197 .46349 .5528 .46229 .55439 .46178 .55357 .46298 Mtetra
.297 0 .042 r
.55357 .46298 .55439 .46178 .55599 .46128 .55517 .46248 Mtetra
.299 0 .043 r
.55517 .46248 .55599 .46128 .55758 .46078 .55676 .46199 Mtetra
.301 0 .046 r
.55676 .46199 .55758 .46078 .55918 .46028 .55836 .46149 Mtetra
.303 0 .048 r
.55836 .46149 .55918 .46028 .56078 .45978 .55996 .461 Mtetra
.306 0 .052 r
.55996 .461 .56078 .45978 .56238 .45928 .56156 .4605 Mtetra
.309 0 .056 r
.56156 .4605 .56238 .45928 .56398 .45878 .56316 .46002 Mtetra
.312 0 .06 r
.56316 .46002 .56398 .45878 .56558 .45828 .56477 .45953 Mtetra
.315 0 .065 r
.56477 .45953 .56558 .45828 .56718 .45778 .56637 .45905 Mtetra
.318 0 .07 r
.56637 .45905 .56718 .45778 .56878 .45728 .56797 .45856 Mtetra
.319 0 .074 r
.56797 .45856 .56878 .45728 .57039 .45678 .56958 .45807 Mtetra
.32 0 .077 r
.56958 .45807 .57039 .45678 .57199 .45628 .57118 .45757 Mtetra
.32 0 .078 r
.57118 .45757 .57199 .45628 .5736 .45578 .57279 .45707 Mtetra
.319 0 .079 r
.57279 .45707 .5736 .45578 .5752 .45527 .5744 .45657 Mtetra
.318 0 .08 r
.5744 .45657 .5752 .45527 .57681 .45476 .57601 .45606 Mtetra
.316 0 .078 r
.57601 .45606 .57681 .45476 .57842 .45424 .57762 .45554 Mtetra
.308 0 .074 r
.57762 .45554 .57842 .45424 .58003 .45372 .57923 .45501 Mtetra
.308 0 .071 r
.57923 .45501 .58003 .45372 .58164 .45319 .58084 .45447 Mtetra
.293 0 .062 r
.58084 .45447 .58164 .45319 .58325 .45264 .58245 .4539 Mtetra
.099 0 0 r
.58245 .4539 .58325 .45264 .58485 .45179 .58406 .45287 Mtetra
.245 0 0 r
.58406 .45287 .58485 .45179 .58646 .45124 .58567 .45231 Mtetra
.555 .115 .158 r
.58567 .45231 .58646 .45124 .58809 .45137 .5873 .45277 Mtetra
.906 .582 .42 r
.5873 .45277 .58809 .45137 .58978 .45479 .58912 .46272 Mtetra
.953 .672 .467 r
.58912 .46272 .58978 .45479 .59536 .64944 .5946 .65452 Mtetra
.691 .394 .467 r
.5946 .65452 .59536 .64944 .59723 .65629 .5964 .65775 Mtetra
.496 .084 .188 r
.5964 .65775 .59723 .65629 .59896 .65646 .59813 .65787 Mtetra
.341 0 .098 r
.59813 .65787 .59896 .65646 .60068 .65582 .59986 .65738 Mtetra
.273 0 .094 r
.59986 .65738 .60068 .65582 .6024 .65495 .60158 .65658 Mtetra
.378 0 .158 r
.60158 .65658 .6024 .65495 .60414 .65527 .6033 .65611 Mtetra
.147 0 0 r
.6033 .65611 .60414 .65527 .60588 .65556 .60503 .65554 Mtetra
.548 .925 .923 r
.60503 .65554 .60588 .65556 .60762 .65572 .60675 .65483 Mtetra
.773 .794 .87 r
.60675 .65483 .60762 .65572 .60936 .65545 .60846 .65367 Mtetra
.736 .658 .773 r
.60846 .65367 .60936 .65545 .61109 .65505 .61017 .65236 Mtetra
.698 .581 .72 r
.61017 .65236 .61109 .65505 .61282 .65455 .61188 .65103 Mtetra
.578 .478 .704 r
.61188 .65103 .61282 .65455 .61456 .6544 .61362 .65096 Mtetra
.601 .494 .704 r
.61362 .65096 .61456 .6544 .61629 .65393 .61536 .65062 Mtetra
.666 .538 .699 r
.61536 .65062 .61629 .65393 .61801 .65285 .61708 .6495 Mtetra
.87 .651 .603 r
.61708 .6495 .61801 .65285 .61965 .64876 .6186 .64139 Mtetra
.959 .682 .466 r
.6186 .64139 .61965 .64876 .61606 .4569 .61495 .44558 Mtetra
.669 .462 .595 r
.61495 .44558 .61606 .4569 .61736 .44444 .61648 .4412 Mtetra
.661 .531 .695 r
.61648 .4412 .61736 .44444 .61895 .44232 .6181 .44016 Mtetra
.622 .562 .766 r
.6181 .44016 .61895 .44232 .62056 .44118 .61973 .43978 Mtetra
.567 .618 .862 r
.61973 .43978 .62056 .44118 .62219 .4405 .62138 .4397 Mtetra
.661 .779 .936 r
.62138 .4397 .62219 .4405 .62383 .43996 .62301 .43918 Mtetra
.675 .788 .934 r
.62301 .43918 .62383 .43996 .62547 .43956 .62465 .43861 Mtetra
.678 .747 .903 r
.62465 .43861 .62547 .43956 .62711 .43923 .62628 .43802 Mtetra
.685 .701 .859 r
.62628 .43802 .62711 .43923 .62875 .43874 .62792 .43738 Mtetra
.668 .67 .842 r
.62792 .43738 .62875 .43874 .63038 .4382 .62956 .43679 Mtetra
.643 .652 .844 r
.62956 .43679 .63038 .4382 .63202 .43764 .6312 .43635 Mtetra
.625 .663 .867 r
.6312 .43635 .63202 .43764 .63365 .43668 .63284 .43601 Mtetra
.416 .714 .985 r
.63284 .43601 .63365 .43668 .63528 .43595 .63451 .43605 Mtetra
.553 0 0 r
.63451 .43605 .63528 .43595 .63694 .4358 .6362 .43691 Mtetra
.896 .548 .378 r
.6362 .43691 .63694 .4358 .63869 .43857 .63811 .4441 Mtetra
.961 .674 .446 r
.63811 .4441 .63869 .43857 .64721 .632 .64664 .63918 Mtetra
.673 .392 .487 r
.64664 .63918 .64721 .632 .64931 .64135 .64854 .64282 Mtetra
.588 .178 .233 r
.64854 .64282 .64931 .64135 .65112 .64255 .65033 .64349 Mtetra
.278 0 0 r
.65033 .64349 .65112 .64255 .65288 .64221 .65209 .64311 Mtetra
0 0 0 r
.65209 .64311 .65288 .64221 .6546 .64066 .65382 .64186 Mtetra
.826 .89 .465 r
.65382 .64186 .6546 .64066 .65614 .63449 .65547 .63828 Mtetra
.951 .774 .318 r
.65547 .63828 .65614 .63449 .65031 .43679 .6567 .62422 Mtetra
.013 0 .416 r
.6567 .62422 .65031 .43679 .65178 .43163 .65107 .43321 Mtetra
0 0 0 r
.65107 .43321 .65178 .43163 .6534 .43028 .65265 .43063 Mtetra
.606 .936 .735 r
.65265 .43063 .6534 .43028 .65506 .42985 .65427 .42938 Mtetra
.705 .883 .963 r
.65427 .42938 .65506 .42985 .65673 .42978 .65592 .42863 Mtetra
.665 .705 .877 r
.65592 .42863 .65673 .42978 .65839 .42941 .65757 .42809 Mtetra
.633 .663 .861 r
.65757 .42809 .65839 .42941 .66005 .42893 .65923 .42769 Mtetra
.617 .671 .879 r
.65923 .42769 .66005 .42893 .6617 .42841 .6609 .42738 Mtetra
.651 .724 .902 r
.6609 .42738 .6617 .42841 .66335 .42772 .66256 .42691 Mtetra
.667 .78 .934 r
.66256 .42691 .66335 .42772 .66501 .42703 .66422 .42636 Mtetra
.671 .817 .954 r
.66422 .42636 .66501 .42703 .66666 .42647 .66588 .42577 Mtetra
.757 .831 .909 r
.66588 .42577 .66666 .42647 .66833 .42605 .66752 .42482 Mtetra
.708 .708 .848 r
.66752 .42482 .66833 .42605 .67001 .42599 .66917 .42402 Mtetra
.608 .572 .788 r
.66917 .42402 .67001 .42599 .67173 .42668 .67084 .42375 Mtetra
.238 .277 .7 r
.67084 .42375 .67173 .42668 .67367 .43215 .67263 .42582 Mtetra
.812 .559 .001 r
.67263 .42582 .67367 .43215 .68446 .6289 .6751 .44292 Mtetra
.041 0 .437 r
.6751 .44292 .68446 .6289 .68645 .63305 .68547 .62924 Mtetra
.359 .328 .688 r
.68547 .62924 .68645 .63305 .68828 .63373 .68736 .63115 Mtetra
.522 .488 .76 r
.68736 .63115 .68828 .63373 .69007 .63332 .68918 .63149 Mtetra
.592 .59 .819 r
.68918 .63149 .69007 .63332 .69183 .63241 .69098 .63131 Mtetra
.535 .675 .928 r
.69098 .63131 .69183 .63241 .69359 .63164 .69278 .63125 Mtetra
.476 .834 .995 r
.69278 .63125 .69359 .63164 .69535 .63065 .69457 .63095 Mtetra
.403 .841 .716 r
.69457 .63095 .69535 .63065 .69707 .62895 .69634 .63005 Mtetra
.737 .866 .444 r
.69634 .63005 .69707 .62895 .69861 .62345 .698 .627 Mtetra
.799 .718 .185 r
.698 .627 .69861 .62345 .6903 .42493 .69933 .61758 Mtetra
.037 0 .43 r
.69933 .61758 .6903 .42493 .69172 .41928 .69108 .42132 Mtetra
0 0 0 r
.69108 .42132 .69172 .41928 .69333 .41762 .69262 .41815 Mtetra
.509 .856 .595 r
.69262 .41815 .69333 .41762 .69501 .41711 .69426 .41677 Mtetra
.707 .923 .965 r
.69426 .41677 .69501 .41711 .69671 .417 .69592 .41595 Mtetra
.673 .73 .893 r
.69592 .41595 .69671 .417 .6984 .41669 .69759 .41537 Mtetra
.64 .669 .862 r
.69759 .41537 .6984 .41669 .70008 .41619 .69928 .41494 Mtetra
.623 .672 .876 r
.69928 .41494 .70008 .41619 .70176 .41566 .70097 .41459 Mtetra
.649 .718 .899 r
.70097 .41459 .70176 .41566 .70344 .41498 .70266 .41412 Mtetra
.671 .774 .927 r
.70266 .41412 .70344 .41498 .70511 .41427 .70434 .41355 Mtetra
.674 .812 .949 r
.70434 .41355 .70511 .41427 .70679 .41367 .70602 .41295 Mtetra
.748 .83 .915 r
.70602 .41295 .70679 .41367 .70848 .4132 .70768 .41204 Mtetra
.719 .726 .856 r
.70768 .41204 .70848 .4132 .71018 .41306 .70935 .41118 Mtetra
.623 .59 .796 r
.70935 .41118 .71018 .41306 .71193 .41359 .71105 .41081 Mtetra
.331 .348 .728 r
.71105 .41081 .71193 .41359 .71388 .41755 .71286 .41236 Mtetra
0 0 .404 r
.71286 .41236 .71388 .41755 .72725 .61547 .71505 .42048 Mtetra
.061 0 .449 r
.71505 .42048 .72725 .61547 .72939 .62054 .72837 .61628 Mtetra
.314 .286 .667 r
.72837 .61628 .72939 .62054 .73128 .62158 .73035 .61882 Mtetra
.512 .473 .751 r
.73035 .61882 .73128 .62158 .7331 .62123 .73221 .61927 Mtetra
.582 .573 .808 r
.73221 .61927 .7331 .62123 .73488 .62036 .73405 .61915 Mtetra
.602 .686 .901 r
.73405 .61915 .73488 .62036 .73665 .61925 .73587 .61886 Mtetra
.51 .851 .995 r
.73587 .61886 .73665 .61925 .73842 .618 .73769 .61848 Mtetra
.018 0 0 r
.73769 .61848 .73842 .618 .74017 .61665 .7395 .61798 Mtetra
.384 0 .103 r
.7395 .61798 .74017 .61665 .74198 .61605 .74132 .61766 Mtetra
.409 .012 .172 r
.74132 .61766 .74198 .61605 .74381 .61585 .74315 .61731 Mtetra
.262 0 .079 r
.74315 .61731 .74381 .61585 .7456 .61506 .74494 .61647 Mtetra
0 0 0 r
.74494 .61647 .7456 .61506 .74719 .611 .74661 .61372 Mtetra
.851 .754 .24 r
.74661 .61372 .74719 .611 .73604 .41193 .74789 .60503 Mtetra
.057 0 .443 r
.74789 .60503 .73604 .41193 .73733 .40503 .73676 .40713 Mtetra
0 0 .015 r
.73676 .40713 .73733 .40503 .73892 .40283 .73829 .40396 Mtetra
.2 0 0 r
.73829 .40396 .73892 .40283 .74061 .40208 .73998 .40318 Mtetra
.398 0 .071 r
.73998 .40318 .74061 .40208 .74233 .40173 .74171 .40302 Mtetra
.405 0 .121 r
.74171 .40302 .74233 .40173 .74404 .4014 .74344 .40279 Mtetra
.353 0 .122 r
.74344 .40279 .74404 .4014 .74576 .40096 .74515 .4023 Mtetra
.349 0 .109 r
.74515 .4023 .74576 .40096 .74747 .40054 .74686 .40182 Mtetra
.359 0 .099 r
.74686 .40182 .74747 .40054 .74919 .40008 .74858 .40142 Mtetra
.369 0 .116 r
.74858 .40142 .74919 .40008 .7509 .39958 .7503 .40101 Mtetra
.337 0 .126 r
.7503 .40101 .7509 .39958 .75261 .39906 .75201 .40043 Mtetra
.161 0 .038 r
.75201 .40043 .75261 .39906 .75433 .39856 .75369 .39933 Mtetra
0 0 0 r
.75369 .39933 .75433 .39856 .75604 .39807 .75534 .3979 Mtetra
.803 .977 .902 r
.75534 .3979 .75604 .39807 .75776 .39757 .757 .3966 Mtetra
.771 .782 .862 r
.757 .3966 .75776 .39757 .75946 .39678 .75867 .39546 Mtetra
.709 .7 .839 r
.75867 .39546 .75946 .39678 .76115 .39589 .76037 .39461 Mtetra
.607 .664 .879 r
.76037 .39461 .76115 .39589 .76287 .39547 .7621 .39433 Mtetra
0 .252 .764 r
.7621 .39433 .76287 .39547 .76474 .39692 .76397 .39585 Mtetra
.949 .596 .22 r
.76397 .39585 .76474 .39692 .76742 .40921 .76662 .40762 Mtetra
.976 .676 .372 r
.76662 .40762 .76742 .40921 .78387 .60343 .78307 .60243 Mtetra
0 .005 .539 r
.78307 .60243 .78387 .60343 .78592 .6057 .78512 .60467 Mtetra
.576 .715 .937 r
.78512 .60467 .78592 .6057 .78779 .60552 .78698 .60443 Mtetra
.707 .756 .891 r
.78698 .60443 .78779 .60552 .7896 .60467 .7888 .60363 Mtetra
.64 .739 .921 r
.7888 .60363 .7896 .60467 .79142 .60377 .79065 .60315 Mtetra
.403 .735 .992 r
.79065 .60315 .79142 .60377 .79324 .60302 .79253 .60315 Mtetra
.263 .768 .751 r
.79253 .60315 .79324 .60302 .79502 .60169 .79438 .60261 Mtetra
.584 .807 .407 r
.79438 .60261 .79502 .60169 .79663 .59816 .79607 .60017 Mtetra
.952 .782 .329 r
.79607 .60017 .79663 .59816 .78274 .40088 .79713 .58974 Mtetra
.063 0 .45 r
.79713 .58974 .78274 .40088 .78375 .39134 .78305 .39096 Mtetra
.966 .87 .692 r
.78305 .39096 .78375 .39134 .78531 .38869 .78455 .38762 Mtetra
.721 .75 .875 r
.78455 .38762 .78531 .38869 .78702 .38789 .78626 .38677 Mtetra
.608 .694 .904 r
.78626 .38677 .78702 .38789 .78877 .38754 .78801 .38646 Mtetra
.65 .721 .901 r
.78801 .38646 .78877 .38754 .7905 .387 .78975 .38597 Mtetra
.742 .766 .873 r
.78975 .38597 .7905 .387 .7922 .38603 .79145 .38501 Mtetra
.655 .737 .91 r
.79145 .38501 .7922 .38603 .79394 .38551 .79319 .38449 Mtetra
.094 .422 .868 r
.79319 .38449 .79394 .38551 .7958 .3865 .79506 .38549 Mtetra
.902 .514 .081 r
.79506 .38549 .7958 .3865 .7982 .3937 .79746 .39271 Mtetra
.975 .672 .358 r
.79746 .39271 .7982 .3937 .81702 .59284 .81624 .59188 Mtetra
.599 .134 0 r
.81624 .59188 .81702 .59284 .81917 .59568 .81839 .59472 Mtetra
.604 .745 .944 r
.81839 .59472 .81917 .59568 .82105 .59533 .82027 .59436 Mtetra
.759 .799 .885 r
.82027 .59436 .82105 .59533 .82286 .59423 .82208 .59326 Mtetra
.783 .804 .87 r
.82208 .59326 .82286 .59423 .82466 .59296 .82388 .59199 Mtetra
.714 .785 .907 r
.82388 .59199 .82466 .59296 .8265 .59212 .82572 .59115 Mtetra
.701 .78 .913 r
.82572 .59115 .8265 .59212 .82834 .59136 .82756 .59038 Mtetra
.656 .763 .928 r
.82756 .59038 .82834 .59136 .8302 .59079 .82942 .58981 Mtetra
.579 .731 .947 r
.82942 .58981 .8302 .59079 .83209 .59052 .83132 .58955 Mtetra
.554 .721 .951 r
.83132 .58955 .83209 .59052 .83399 .59033 .83322 .58936 Mtetra
.483 .688 .958 r
.83322 .58936 .83399 .59033 .83591 .59035 .83514 .5894 Mtetra
.407 .649 .956 r
.83514 .5894 .83591 .59035 .83785 .59059 .83708 .58963 Mtetra
.61 .749 .944 r
.83708 .58963 .83785 .59059 .83974 .5902 .83897 .58924 Mtetra
.866 .819 .801 r
.83897 .58924 .83974 .5902 .84147 .58812 .8407 .58716 Mtetra
.981 .745 .504 r
.8407 .58716 .84147 .58812 .84237 .57717 .84161 .57627 Mtetra
.977 .678 .362 r
.84161 .57627 .84237 .57717 .82565 .37878 .82492 .37776 Mtetra
.93 .791 .685 r
.82492 .37776 .82565 .37878 .82713 .37521 .82639 .37418 Mtetra
.723 .764 .886 r
.82639 .37418 .82713 .37521 .82885 .37435 .82812 .37333 Mtetra
.598 .714 .925 r
.82812 .37333 .82885 .37435 .83064 .37406 .82991 .37304 Mtetra
.82991 .37304 .83064 .37406 .83242 .37377 .83169 .37274 Mtetra
.737 .769 .878 r
.83169 .37274 .83242 .37377 .83414 .37283 .83341 .3718 Mtetra
.655 .738 .911 r
.83341 .3718 .83414 .37283 .83591 .37231 .83518 .37128 Mtetra
.233 .51 .908 r
.83518 .37128 .83591 .37231 .8378 .37304 .83707 .37201 Mtetra
.881 .488 .032 r
.83707 .37201 .8378 .37304 .84031 .38011 .83958 .37908 Mtetra
.975 .667 .334 r
.83958 .37908 .84031 .38011 .86198 .58048 .86122 .5795 Mtetra
.658 .204 0 r
.86122 .5795 .86198 .58048 .86426 .58391 .8635 .58293 Mtetra
.381 .63 .952 r
.8635 .58293 .86426 .58391 .86624 .58422 .86548 .58324 Mtetra
.694 .781 .918 r
.86548 .58324 .86624 .58422 .86811 .58347 .86735 .5825 Mtetra
.875 .82 .791 r
.86735 .5825 .86811 .58347 .86983 .58126 .86907 .58029 Mtetra
.979 .766 .547 r
.86907 .58029 .86983 .58126 .87099 .57349 .87024 .57255 Mtetra
.977 .675 .347 r
.87024 .57255 .87099 .57349 .85222 .37138 .8515 .37038 Mtetra
.951 .788 .644 r
.8515 .37038 .85222 .37138 .8536 .36703 .85288 .366 Mtetra
.746 .775 .876 r
.85288 .366 .8536 .36703 .85533 .36603 .85461 .365 Mtetra
.619 .725 .922 r
.85461 .365 .85533 .36603 .85712 .36566 .85641 .36463 Mtetra
.588 .71 .927 r
.85641 .36463 .85712 .36566 .85893 .36541 .85821 .36437 Mtetra
.748 .773 .874 r
.85821 .36437 .85893 .36541 .86066 .3644 .85994 .36336 Mtetra
.674 .745 .905 r
.85994 .36336 .86066 .3644 .86243 .36379 .86171 .36274 Mtetra
.375 .594 .93 r
.86171 .36274 .86243 .36379 .86431 .3642 .8636 .36315 Mtetra
.806 .393 0 r
.8636 .36315 .86431 .3642 .86674 .36963 .86601 .36854 Mtetra
.973 .663 .318 r
.86601 .36854 .86674 .36963 .8903 .57133 .88954 .5703 Mtetra
.703 .265 0 r
.88954 .5703 .8903 .57133 .8927 .57542 .89195 .57441 Mtetra
.507 .691 .951 r
.89195 .57441 .8927 .57542 .89467 .57539 .89392 .57438 Mtetra
.694 .777 .915 r
.89392 .57438 .89467 .57539 .89655 .57463 .8958 .57363 Mtetra
.734 .792 .899 r
.8958 .57363 .89655 .57463 .89842 .57366 .89767 .57266 Mtetra
.498 .69 .954 r
.89767 .57266 .89842 .57366 .90039 .57365 .89964 .57266 Mtetra
.624 .752 .938 r
.89964 .57266 .90039 .57365 .90231 .5732 .90157 .57221 Mtetra
.809 .815 .855 r
.90157 .57221 .90231 .5732 .90412 .57171 .90338 .57072 Mtetra
.98 .774 .556 r
.90338 .57072 .90412 .57171 .9053 .56459 .90456 .56364 Mtetra
.976 .671 .329 r
.90456 .56364 .9053 .56459 .88438 .36178 .88367 .36076 Mtetra
.962 .787 .62 r
.88367 .36076 .88438 .36178 .88569 .35695 .88498 .35592 Mtetra
.744 .776 .879 r
.88498 .35592 .88569 .35695 .88743 .35597 .88673 .35493 Mtetra
.604 .718 .926 r
.88673 .35493 .88743 .35597 .88925 .35565 .88855 .35461 Mtetra
.515 .674 .936 r
.88855 .35461 .88925 .35565 .89111 .35565 .89041 .35461 Mtetra
.652 .739 .913 r
.89041 .35461 .89111 .35565 .89291 .35514 .89221 .35409 Mtetra
.659 .74 .91 r
.89221 .35409 .89291 .35514 .89472 .3546 .89401 .35354 Mtetra
.672 .744 .904 r
.89401 .35354 .89472 .3546 .89651 .35399 .8958 .35293 Mtetra
.763 .776 .864 r
.8958 .35293 .89651 .35399 .89824 .35286 .89754 .3518 Mtetra
.698 .753 .894 r
.89754 .3518 .89824 .35286 .90002 .35213 .89932 .35105 Mtetra
.503 .659 .931 r
.89932 .35105 .90002 .35213 .9019 .35221 .90119 .3511 Mtetra
.734 .32 0 r
.90119 .3511 .9019 .35221 .90439 .35743 .90364 .35596 Mtetra
.97 .656 .293 r
.90364 .35596 .90439 .35743 .93056 .55998 .92977 .55842 Mtetra
0 0 .366 r
.92977 .55842 .93056 .55998 .9331 .56444 .93233 .56315 Mtetra
.522 .641 .908 r
.93233 .56315 .9331 .56444 .93509 .5644 .93434 .56319 Mtetra
.687 .736 .889 r
.93434 .56319 .93509 .5644 .937 .56358 .93625 .56245 Mtetra
.757 .778 .87 r
.93625 .56245 .937 .56358 .93885 .56234 .93812 .56129 Mtetra
.449 .69 .969 r
.31419 .73498 .31517 .7358 .3167 .73584 .31571 .73504 Mtetra
.615 .756 .946 r
.31571 .73504 .3167 .73584 .31825 .73549 .31726 .73471 Mtetra
.777 .785 .86 r
.31726 .73471 .31825 .73549 .31984 .73436 .31885 .73358 Mtetra
.916 .731 .637 r
.31885 .73358 .31984 .73436 .32174 .72795 .32077 .72693 Mtetra
.936 .686 .534 r
.32077 .72693 .32174 .72795 .33423 .53485 .33333 .53367 Mtetra
.885 .713 .664 r
.33333 .53367 .33423 .53485 .33595 .53004 .33504 .52899 Mtetra
.734 .72 .838 r
.33504 .52899 .33595 .53004 .33745 .52908 .33654 .5281 Mtetra
.579 .689 .917 r
.33654 .5281 .33745 .52908 .33891 .52884 .33799 .52793 Mtetra
.396 .63 .948 r
.33799 .52793 .33891 .52884 .34035 .52897 .33943 .52815 Mtetra
.62 .74 .933 r
.33943 .52815 .34035 .52897 .34182 .52863 .3409 .52783 Mtetra
.644 .751 .927 r
.3409 .52783 .34182 .52863 .34329 .52824 .34237 .52743 Mtetra
.656 .751 .92 r
.34237 .52743 .34329 .52824 .34477 .52783 .34385 .52699 Mtetra
.754 .763 .861 r
.34385 .52699 .34477 .52783 .34627 .52692 .34535 .52605 Mtetra
.702 .749 .889 r
.34535 .52605 .34627 .52692 .34775 .5263 .34684 .52541 Mtetra
.487 .676 .948 r
.34684 .52541 .34775 .5263 .34921 .52634 .34829 .52544 Mtetra
.933 .564 .275 r
.34829 .52544 .34921 .52634 .35044 .53057 .34952 .52985 Mtetra
.94 .683 .521 r
.34952 .52985 .35044 .53057 .34196 .72336 .34096 .72292 Mtetra
.917 .557 .334 r
.34096 .72292 .34196 .72336 .34325 .72826 .34226 .72766 Mtetra
.217 .634 .954 r
.34226 .72766 .34325 .72826 .34478 .72859 .34379 .72792 Mtetra
.71 .808 .926 r
.34379 .72792 .34478 .72859 .34636 .72797 .34538 .72722 Mtetra
.78 .794 .864 r
.34538 .72722 .34636 .72797 .34796 .72693 .34699 .72608 Mtetra
.547 .725 .956 r
.34699 .72608 .34796 .72693 .34952 .72679 .34854 .72594 Mtetra
.605 .744 .942 r
.34854 .72594 .34952 .72679 .35109 .72647 .35011 .72564 Mtetra
.758 .778 .87 r
.35011 .72564 .35109 .72647 .35269 .72546 .35171 .72464 Mtetra
.911 .74 .656 r
.35171 .72464 .35269 .72546 .35449 .72027 .35353 .71927 Mtetra
.94 .687 .527 r
.35353 .71927 .35449 .72027 .36529 .52625 .3644 .52496 Mtetra
.891 .707 .647 r
.3644 .52496 .36529 .52625 .36703 .52053 .36613 .51945 Mtetra
.77 .725 .81 r
.36613 .51945 .36703 .52053 .36856 .51924 .36765 .51824 Mtetra
.602 .693 .907 r
.36765 .51824 .36856 .51924 .37004 .51893 .36913 .518 Mtetra
.426 .638 .945 r
.36913 .518 .37004 .51893 .37151 .51902 .37059 .51817 Mtetra
.598 .729 .936 r
.37059 .51817 .37151 .51902 .37299 .51874 .37208 .51792 Mtetra
.646 .749 .925 r
.37208 .51792 .37299 .51874 .37448 .51834 .37357 .51751 Mtetra
.657 .75 .918 r
.37357 .51751 .37448 .51834 .37597 .51792 .37506 .51706 Mtetra
.748 .762 .865 r
.37506 .51706 .37597 .51792 .37748 .51704 .37658 .51615 Mtetra
.714 .75 .881 r
.37658 .51615 .37748 .51704 .37899 .51635 .37808 .51544 Mtetra
.543 .694 .938 r
.37808 .51544 .37899 .51635 .38047 .51628 .37956 .51535 Mtetra
.908 .499 .152 r
.37956 .51535 .38047 .51628 .3818 .51962 .38089 .51879 Mtetra
.944 .684 .513 r
.38089 .51879 .3818 .51962 .37511 .7126 .37412 .71215 Mtetra
.926 .579 .355 r
.37412 .71215 .37511 .7126 .37642 .71853 .37545 .7179 Mtetra
0 .452 .841 r
.37545 .7179 .37642 .71853 .37797 .7192 .377 .71849 Mtetra
.706 .802 .924 r
.377 .71849 .37797 .7192 .37956 .7186 .3786 .71779 Mtetra
.784 .787 .855 r
.3786 .71779 .37956 .7186 .38118 .71752 .38022 .7166 Mtetra
.721 .757 .881 r
.38022 .7166 .38118 .71752 .38278 .71678 .38183 .7158 Mtetra
.678 .736 .895 r
.38183 .7158 .38278 .71678 .38438 .71622 .38342 .71523 Mtetra
.665 .73 .898 r
.38342 .71523 .38438 .71622 .38598 .7157 .38502 .71471 Mtetra
.657 .729 .902 r
.38502 .71471 .38598 .7157 .38757 .71523 .38662 .71423 Mtetra
.644 .724 .907 r
.38662 .71423 .38757 .71523 .38917 .7148 .38821 .71381 Mtetra
.626 .719 .914 r
.38821 .71381 .38917 .7148 .39076 .71442 .38981 .71345 Mtetra
.585 .711 .93 r
.38981 .71345 .39076 .71442 .39235 .71412 .3914 .71324 Mtetra
.558 .721 .95 r
.3914 .71324 .39235 .71412 .39395 .71385 .39298 .71307 Mtetra
.552 .746 .967 r
.39298 .71307 .39395 .71385 .39554 .71357 .39457 .71289 Mtetra
.495 .751 .986 r
.39457 .71289 .39554 .71357 .39712 .71354 .39616 .71279 Mtetra
.574 .76 .966 r
.39616 .71279 .39712 .71354 .39872 .71335 .39776 .71254 Mtetra
.686 .776 .919 r
.39776 .71254 .39872 .71335 .40033 .71262 .39937 .71193 Mtetra
.852 .803 .802 r
.39937 .71193 .40033 .71262 .40202 .70958 .40102 .71003 Mtetra
.969 .898 .696 r
.40102 .71003 .40202 .70958 .40402 .69777 .40274 .70644 Mtetra
0 0 .264 r
.40274 .70644 .40402 .69777 .41199 .5093 .4046 .69845 Mtetra
0 0 .34 r
.4046 .69845 .41199 .5093 .41357 .50694 .41226 .51812 Mtetra
.522 .284 .495 r
.41226 .51812 .41357 .50694 .41509 .50636 .4138 .51716 Mtetra
.699 .439 .527 r
.4138 .51716 .41509 .50636 .41659 .50633 .41509 .52371 Mtetra
.916 .652 .525 r
.41509 .52371 .41659 .50633 .4181 .50608 .4113 .68757 Mtetra
.562 .348 .547 r
.4113 .68757 .4181 .50608 .41962 .50564 .41286 .68857 Mtetra
.561 .347 .547 r
.41286 .68857 .41962 .50564 .42114 .50521 .41443 .68914 Mtetra
.567 .352 .548 r
.41443 .68914 .42114 .50521 .42265 .50487 .4159 .69305 Mtetra
.563 .348 .547 r
.4159 .69305 .42265 .50487 .42417 .50452 .41745 .69456 Mtetra
.556 .343 .546 r
.41745 .69456 .42417 .50452 .4257 .50399 .41911 .69214 Mtetra
0 0 .335 r
.41911 .69214 .4257 .50399 .42724 .50292 .42616 .50823 Mtetra
0 0 .151 r
.42616 .50823 .42724 .50292 .42878 .50163 .42784 .50256 Mtetra
.922 .961 .645 r
.42784 .50256 .42878 .50163 .43033 .50046 .42944 .49966 Mtetra
.804 .782 .833 r
.42944 .49966 .43033 .50046 .43186 .49969 .43099 .49832 Mtetra
.668 .659 .832 r
.43099 .49832 .43186 .49969 .43339 .49919 .43251 .49777 Mtetra
.623 .632 .839 r
.43251 .49777 .43339 .49919 .43491 .49878 .43404 .49746 Mtetra
.638 .653 .849 r
.43404 .49746 .43491 .49878 .43644 .49834 .43556 .49708 Mtetra
.659 .671 .85 r
.43556 .49708 .43644 .49834 .43797 .49784 .43709 .49659 Mtetra
.659 .672 .851 r
.43709 .49659 .43797 .49784 .4395 .49734 .43862 .4961 Mtetra
.66 .674 .852 r
.43862 .4961 .4395 .49734 .44103 .49685 .44015 .49561 Mtetra
.66 .675 .853 r
.44015 .49561 .44103 .49685 .44256 .49635 .44169 .49512 Mtetra
.66 .676 .854 r
.44169 .49512 .44256 .49635 .4441 .49585 .44322 .49462 Mtetra
.659 .676 .855 r
.44322 .49462 .4441 .49585 .44563 .49536 .44475 .49414 Mtetra
.659 .677 .856 r
.44475 .49414 .44563 .49536 .44716 .49488 .44629 .49365 Mtetra
.658 .677 .857 r
.44629 .49365 .44716 .49488 .4487 .49439 .44782 .49317 Mtetra
.658 .678 .857 r
.44782 .49317 .4487 .49439 .45023 .49391 .44936 .49269 Mtetra
.657 .677 .857 r
.44936 .49269 .45023 .49391 .45177 .49344 .45089 .49222 Mtetra
.651 .675 .86 r
.45089 .49222 .45177 .49344 .45331 .49298 .45243 .49177 Mtetra
.634 .671 .868 r
.45243 .49177 .45331 .49298 .45484 .49256 .45397 .4914 Mtetra
.618 .674 .881 r
.45397 .4914 .45484 .49256 .45638 .49218 .4555 .49111 Mtetra
.615 .69 .897 r
.4555 .49111 .45638 .49218 .45792 .4918 .45704 .49082 Mtetra
.632 .715 .907 r
.45704 .49082 .45792 .4918 .45946 .49138 .45858 .49046 Mtetra
.654 .736 .91 r
.45858 .49046 .45946 .49138 .461 .49091 .46012 .49001 Mtetra
.663 .743 .909 r
.46012 .49001 .461 .49091 .46254 .49041 .46166 .48952 Mtetra
.663 .744 .91 r
.46166 .48952 .46254 .49041 .46409 .48991 .46321 .48903 Mtetra
.663 .746 .912 r
.46321 .48903 .46409 .48991 .46563 .4894 .46475 .48854 Mtetra
.672 .753 .912 r
.46475 .48854 .46563 .4894 .46718 .48887 .4663 .48801 Mtetra
.692 .759 .903 r
.4663 .48801 .46718 .48887 .46873 .4883 .46785 .4874 Mtetra
.706 .754 .889 r
.46785 .4874 .46873 .4883 .47027 .48769 .4694 .48671 Mtetra
.703 .736 .877 r
.4694 .48671 .47027 .48769 .47182 .48708 .47095 .48602 Mtetra
.687 .717 .872 r
.47095 .48602 .47182 .48708 .47337 .48651 .4725 .48541 Mtetra
.67 .705 .873 r
.4725 .48541 .47337 .48651 .47492 .48597 .47405 .48488 Mtetra
.664 .704 .876 r
.47405 .48488 .47492 .48597 .47648 .48545 .4756 .48437 Mtetra
.664 .707 .879 r
.4756 .48437 .47648 .48545 .47803 .48493 .47716 .48387 Mtetra
.666 .711 .882 r
.47716 .48387 .47803 .48493 .47958 .48441 .47871 .48336 Mtetra
.665 .714 .885 r
.47871 .48336 .47958 .48441 .48113 .48389 .48026 .48286 Mtetra
.686 .722 .877 r
.48026 .48286 .48113 .48389 .48269 .48322 .48182 .48225 Mtetra
.7 .739 .881 r
.48182 .48225 .48269 .48322 .48425 .48247 .48338 .48158 Mtetra
.645 .742 .92 r
.48338 .48158 .48425 .48247 .4858 .4821 .48493 .48116 Mtetra
.321 .585 .938 r
.48493 .48116 .4858 .4821 .48734 .48309 .48648 .48154 Mtetra
0 .05 .616 r
.48648 .48154 .48734 .48309 .48884 .48843 .48801 .48348 Mtetra
0 .01 .526 r
.48801 .48348 .48884 .48843 .48838 .68218 .48952 .48817 Mtetra
0 0 .385 r
.48952 .48817 .48838 .68218 .48999 .68549 .4892 .67159 Mtetra
.525 .35 .586 r
.4892 .67159 .48999 .68549 .49164 .6854 .49083 .67312 Mtetra
.637 .438 .597 r
.49083 .67312 .49164 .6854 .49331 .6846 .49251 .67013 Mtetra
.935 .669 .511 r
.49251 .67013 .49331 .6846 .49497 .68367 .49566 .49894 Mtetra
.575 .362 .554 r
.49566 .49894 .49497 .68367 .49663 .68307 .4973 .49127 Mtetra
.56 .35 .552 r
.4973 .49127 .49663 .68307 .49829 .68262 .49886 .49205 Mtetra
0 0 .388 r
.49886 .49205 .49829 .68262 .49995 .68259 .49909 .67299 Mtetra
.221 .141 .548 r
.49909 .67299 .49995 .68259 .5016 .683 .5007 .67932 Mtetra
.185 .209 .652 r
.5007 .67932 .5016 .683 .50326 .68333 .50235 .68192 Mtetra
.16 .401 .845 r
.50235 .68192 .50326 .68333 .50492 .68338 .50401 .68293 Mtetra
.42 .782 .995 r
.50401 .68293 .50492 .68338 .50659 .68308 .50567 .68281 Mtetra
.536 .878 .988 r
.50567 .68281 .50659 .68308 .50826 .68265 .50734 .68236 Mtetra
.617 .902 .986 r
.50734 .68236 .50826 .68265 .50993 .68215 .50901 .68177 Mtetra
.645 .886 .984 r
.50901 .68177 .50993 .68215 .5116 .68163 .51068 .68116 Mtetra
.674 .87 .973 r
.51068 .68116 .5116 .68163 .51327 .68108 .51235 .68051 Mtetra
.644 .835 .974 r
.51235 .68051 .51327 .68108 .51494 .68069 .51403 .67998 Mtetra
.577 .778 .975 r
.51403 .67998 .51494 .68069 .51661 .68053 .5157 .67969 Mtetra
.656 .771 .933 r
.5157 .67969 .51661 .68053 .51829 .67999 .51737 .67918 Mtetra
.789 .802 .863 r
.51737 .67918 .51829 .67999 .51996 .67823 .51905 .67794 Mtetra
.932 .857 .744 r
.51905 .67794 .51996 .67823 .52164 .67244 .52073 .67502 Mtetra
.75 .78 .284 r
.52073 .67502 .52164 .67244 .5234 .47692 .52241 .66981 Mtetra
.004 0 .396 r
.52241 .66981 .5234 .47692 .52499 .47193 .52413 .48897 Mtetra
.381 .182 .481 r
.52413 .48897 .52499 .47193 .52657 .47096 .52571 .48198 Mtetra
.611 .358 .511 r
.52571 .48198 .52657 .47096 .52815 .47069 .5273 .48411 Mtetra
.935 .661 .494 r
.5273 .48411 .52815 .47069 .52973 .47061 .5291 .65303 Mtetra
.56 .346 .547 r
.5291 .65303 .52973 .47061 .53131 .47012 .53077 .6529 Mtetra
.53077 .6529 .53131 .47012 .5329 .46963 .53244 .65277 Mtetra
.559 .345 .546 r
.53244 .65277 .5329 .46963 .53448 .46914 .53412 .6522 Mtetra
.557 .344 .546 r
.53412 .6522 .53448 .46914 .53607 .46862 .53579 .65058 Mtetra
.556 .343 .546 r
.53579 .65058 .53607 .46862 .53765 .46811 .53746 .64814 Mtetra
.553 .34 .546 r
.53746 .64814 .53765 .46811 .53924 .46758 .53912 .64408 Mtetra
.114 .003 .438 r
.53912 .64408 .53924 .46758 .54083 .46707 .54013 .49902 Mtetra
.434 .236 .511 r
.54013 .49902 .54083 .46707 .54242 .46655 .54169 .489 Mtetra
.515 .296 .519 r
.54169 .489 .54242 .46655 .54401 .46603 .54328 .48633 Mtetra
.529 .305 .519 r
.54328 .48633 .54401 .46603 .5456 .46552 .54487 .4847 Mtetra
.536 .309 .518 r
.54487 .4847 .5456 .46552 .54719 .46501 .54647 .48353 Mtetra
.541 .313 .518 r
.54647 .48353 .54719 .46501 .54878 .4645 .54807 .48265 Mtetra
.545 .315 .518 r
.54807 .48265 .54878 .4645 .55038 .46399 .54967 .48201 Mtetra
.549 .319 .519 r
.54967 .48201 .55038 .46399 .55197 .46349 .55128 .48159 Mtetra
.553 .322 .519 r
.55128 .48159 .55197 .46349 .55357 .46298 .55289 .48139 Mtetra
.558 .327 .521 r
.55289 .48139 .55357 .46298 .55517 .46248 .5545 .48149 Mtetra
.566 .334 .523 r
.5545 .48149 .55517 .46248 .55676 .46199 .55612 .48204 Mtetra
.581 .346 .526 r
.55612 .48204 .55676 .46199 .55836 .46149 .55775 .48355 Mtetra
.644 .4 .535 r
.55775 .48355 .55836 .46149 .55996 .461 .55944 .49056 Mtetra
.903 .627 .51 r
.55944 .49056 .55996 .461 .56156 .4605 .56266 .63757 Mtetra
.566 .35 .547 r
.56266 .63757 .56156 .4605 .56316 .46002 .56439 .64064 Mtetra
.563 .349 .547 r
.56439 .64064 .56316 .46002 .56477 .45953 .56611 .64251 Mtetra
.562 .348 .547 r
.56611 .64251 .56477 .45953 .56637 .45905 .56783 .6436 Mtetra
.561 .347 .547 r
.56783 .6436 .56637 .45905 .56797 .45856 .56954 .64421 Mtetra
.561 .346 .547 r
.56954 .64421 .56797 .45856 .56958 .45807 .57124 .64439 Mtetra
.56 .346 .547 r
.57124 .64439 .56958 .45807 .57118 .45757 .57295 .64437 Mtetra
.57295 .64437 .57118 .45757 .57279 .45707 .57465 .6442 Mtetra
.57465 .6442 .57279 .45707 .5744 .45657 .57636 .64392 Mtetra
.57636 .64392 .5744 .45657 .57601 .45606 .57806 .64352 Mtetra
.559 .345 .547 r
.57806 .64352 .57601 .45606 .57762 .45554 .57977 .64296 Mtetra
.559 .345 .546 r
.57977 .64296 .57762 .45554 .57923 .45501 .58146 .64207 Mtetra
.58146 .64207 .57923 .45501 .58084 .45447 .58316 .64114 Mtetra
.557 .344 .546 r
.58316 .64114 .58084 .45447 .58245 .4539 .58485 .63936 Mtetra
.042 0 .418 r
.58485 .63936 .58245 .4539 .58406 .45287 .58347 .46607 Mtetra
.522 .289 .503 r
.58347 .46607 .58406 .45287 .58567 .45231 .58508 .4648 Mtetra
.944 .663 .477 r
.58508 .4648 .58567 .45231 .5873 .45277 .59005 .64238 Mtetra
.576 .359 .548 r
.59005 .64238 .5873 .45277 .58912 .46272 .59197 .65241 Mtetra
.565 .35 .547 r
.59197 .65241 .58912 .46272 .5946 .65452 .59376 .65559 Mtetra
.703 .281 .241 r
.59376 .65559 .5946 .65452 .5964 .65775 .59552 .65713 Mtetra
.405 .732 .991 r
.59552 .65713 .5964 .65775 .59813 .65787 .59726 .65714 Mtetra
.599 .788 .971 r
.59726 .65714 .59813 .65787 .59986 .65738 .59898 .65678 Mtetra
.659 .839 .969 r
.59898 .65678 .59986 .65738 .60158 .65658 .60071 .65619 Mtetra
.529 .851 .998 r
.60071 .65619 .60158 .65658 .6033 .65611 .60244 .65581 Mtetra
.612 .904 .985 r
.60244 .65581 .6033 .65611 .60503 .65554 .60416 .6552 Mtetra
.754 .923 .946 r
.60416 .6552 .60503 .65554 .60675 .65483 .60588 .65419 Mtetra
.904 .83 .763 r
.60588 .65419 .60675 .65483 .60846 .65367 .60756 .6516 Mtetra
.857 .683 .664 r
.60756 .6516 .60846 .65367 .61017 .65236 .6092 .64733 Mtetra
.867 .63 .578 r
.6092 .64733 .61017 .65236 .61188 .65103 .61063 .63505 Mtetra
.65 .44 .586 r
.61063 .63505 .61188 .65103 .61362 .65096 .61225 .63013 Mtetra
.496 .32 .571 r
.61225 .63013 .61362 .65096 .61536 .65062 .61408 .63401 Mtetra
.619 .416 .585 r
.61408 .63401 .61536 .65062 .61708 .6495 .61574 .63094 Mtetra
.943 .666 .484 r
.61574 .63094 .61708 .6495 .6186 .64139 .61254 .44664 Mtetra
.568 .356 .553 r
.61254 .44664 .6186 .64139 .61495 .44558 .61407 .44239 Mtetra
.744 .581 .674 r
.61407 .44239 .61495 .44558 .61648 .4412 .61565 .43995 Mtetra
.697 .697 .846 r
.61565 .43995 .61648 .4412 .6181 .44016 .61728 .43922 Mtetra
.613 .725 .926 r
.61728 .43922 .6181 .44016 .61973 .43978 .61892 .43889 Mtetra
.556 .717 .948 r
.61892 .43889 .61973 .43978 .62138 .4397 .62056 .43873 Mtetra
.684 .746 .898 r
.62056 .43873 .62138 .4397 .62301 .43918 .62219 .43812 Mtetra
.697 .731 .877 r
.62219 .43812 .62301 .43918 .62465 .43861 .62383 .43743 Mtetra
.693 .709 .86 r
.62383 .43743 .62465 .43861 .62628 .43802 .62546 .43673 Mtetra
.707 .696 .837 r
.62546 .43673 .62628 .43802 .62792 .43738 .62709 .43593 Mtetra
.672 .659 .829 r
.62709 .43593 .62792 .43738 .62956 .43679 .62872 .4353 Mtetra
.609 .625 .842 r
.62872 .4353 .62956 .43679 .6312 .43635 .63037 .43504 Mtetra
.218 .44 .862 r
.63037 .43504 .6312 .43635 .63284 .43601 .63206 .43593 Mtetra
.809 .328 .05 r
.63206 .43593 .63284 .43601 .63451 .43605 .6338 .4383 Mtetra
.896 .574 .43 r
.6338 .4383 .63451 .43605 .6362 .43691 .63584 .44936 Mtetra
.95 .664 .46 r
.63584 .44936 .6362 .43691 .63811 .4441 .64399 .63762 Mtetra
.565 .35 .547 r
.64399 .63762 .63811 .4441 .64664 .63918 .64587 .64085 Mtetra
.668 .278 .298 r
.64587 .64085 .64664 .63918 .64854 .64282 .64769 .64223 Mtetra
.271 .667 .969 r
.64769 .64223 .64854 .64282 .65033 .64349 .64947 .64244 Mtetra
.631 .726 .916 r
.64947 .64244 .65033 .64349 .65209 .64311 .65123 .64203 Mtetra
.737 .753 .865 r
.65123 .64203 .65209 .64311 .65382 .64186 .65297 .64104 Mtetra
.862 .817 .803 r
.65297 .64104 .65382 .64186 .65547 .63828 .65467 .63904 Mtetra
.929 .942 .594 r
.65467 .63904 .65547 .63828 .6567 .62422 .65632 .63556 Mtetra
.157 .001 .404 r
.65632 .63556 .6567 .62422 .65107 .43321 .65774 .62632 Mtetra
.031 0 .423 r
.65774 .62632 .65107 .43321 .65265 .43063 .65201 .43402 Mtetra
0 0 .147 r
.65201 .43402 .65265 .43063 .65427 .42938 .65352 .42981 Mtetra
.873 .983 .697 r
.65352 .42981 .65427 .42938 .65592 .42863 .65511 .42755 Mtetra
.726 .741 .864 r
.65511 .42755 .65592 .42863 .65757 .42809 .65675 .42669 Mtetra
.619 .645 .854 r
.65675 .42669 .65757 .42809 .65923 .42769 .65842 .42637 Mtetra
.565 .632 .876 r
.65842 .42637 .65923 .42769 .6609 .42738 .66009 .42629 Mtetra
.626 .702 .9 r
.66009 .42629 .6609 .42738 .66256 .42691 .66176 .42592 Mtetra
.658 .737 .908 r
.66176 .42592 .66256 .42691 .66422 .42636 .66342 .42541 Mtetra
.674 .753 .91 r
.66342 .42541 .66422 .42636 .66588 .42577 .66508 .42484 Mtetra
.739 .774 .881 r
.66508 .42484 .66588 .42577 .66752 .42482 .66672 .42393 Mtetra
.729 .782 .895 r
.66672 .42393 .66752 .42482 .66917 .42402 .66837 .4231 Mtetra
.654 .751 .921 r
.66837 .4231 .66917 .42402 .67084 .42375 .67004 .42261 Mtetra
.271 .509 .9 r
.67004 .42261 .67084 .42375 .67263 .42582 .67176 .42327 Mtetra
.136 .234 .703 r
.67176 .42327 .67263 .42582 .6751 .44292 .67355 .42546 Mtetra
.352 .219 .556 r
.67355 .42546 .6751 .44292 .68547 .62924 .67565 .43432 Mtetra
.056 0 .442 r
.67565 .43432 .68547 .62924 .68736 .63115 .68629 .62537 Mtetra
.305 .246 .625 r
.68629 .62537 .68736 .63115 .68918 .63149 .68826 .62883 Mtetra
.325 .361 .746 r
.68826 .62883 .68918 .63149 .69098 .63131 .69013 .63031 Mtetra
.375 .619 .947 r
.69013 .63031 .69098 .63131 .69278 .63125 .69196 .63064 Mtetra
.57 .813 .99 r
.69196 .63064 .69278 .63125 .69457 .63095 .69375 .63028 Mtetra
.736 .849 .934 r
.69375 .63028 .69457 .63095 .69634 .63005 .69551 .62938 Mtetra
.862 .854 .832 r
.69551 .62938 .69634 .63005 .698 .627 .69723 .62755 Mtetra
.928 .956 .633 r
.69723 .62755 .698 .627 .69933 .61758 .69888 .6244 Mtetra
.036 0 .324 r
.69888 .6244 .69933 .61758 .69108 .42132 .70034 .61746 Mtetra
.055 0 .436 r
.70034 .61746 .69108 .42132 .69262 .41815 .69211 .42253 Mtetra
0 0 .245 r
.69211 .42253 .69262 .41815 .69426 .41677 .69356 .41755 Mtetra
.767 .915 .537 r
.69356 .41755 .69426 .41677 .69592 .41595 .69513 .41506 Mtetra
.767 .791 .873 r
.69513 .41506 .69592 .41595 .69759 .41537 .69679 .41398 Mtetra
.632 .655 .854 r
.69679 .41398 .69759 .41537 .69928 .41494 .69847 .41359 Mtetra
.578 .635 .872 r
.69847 .41359 .69928 .41494 .70097 .41459 .70018 .41345 Mtetra
.62 .693 .895 r
.70018 .41345 .70097 .41459 .70266 .41412 .70187 .41311 Mtetra
.662 .735 .904 r
.70187 .41311 .70266 .41412 .70434 .41355 .70355 .41258 Mtetra
.676 .749 .906 r
.70355 .41258 .70434 .41355 .70602 .41295 .70524 .41198 Mtetra
.731 .768 .883 r
.70524 .41198 .70602 .41295 .70768 .41204 .7069 .41111 Mtetra
.732 .778 .889 r
.7069 .41111 .70768 .41204 .70935 .41118 .70857 .41024 Mtetra
.666 .754 .916 r
.70857 .41024 .70935 .41118 .71105 .41081 .71026 .40969 Mtetra
.366 .57 .917 r
.71026 .40969 .71105 .41081 .71286 .41236 .712 .41014 Mtetra
.161 .278 .737 r
.712 .41014 .71286 .41236 .71505 .42048 .71383 .41201 Mtetra
.247 .175 .575 r
.71383 .41201 .71505 .42048 .72837 .61628 .71591 .41805 Mtetra
.077 0 .454 r
.71591 .41805 .72837 .61628 .73035 .61882 .72918 .61212 Mtetra
.303 .234 .612 r
.72918 .61212 .73035 .61882 .73221 .61927 .73127 .61625 Mtetra
.326 .341 .724 r
.73127 .61625 .73221 .61927 .73405 .61915 .73321 .61798 Mtetra
.378 .58 .92 r
.73321 .61798 .73405 .61915 .73587 .61886 .73508 .61841 Mtetra
.472 .818 .998 r
.73508 .61841 .73587 .61886 .73769 .61848 .7369 .61815 Mtetra
.57 .891 .988 r
.7369 .61815 .73769 .61848 .7395 .61798 .73871 .6176 Mtetra
.562 .876 .993 r
.73871 .6176 .7395 .61798 .74132 .61766 .74053 .6171 Mtetra
.618 .849 .987 r
.74053 .6171 .74132 .61766 .74315 .61731 .74234 .61658 Mtetra
.721 .834 .935 r
.74234 .61658 .74315 .61731 .74494 .61647 .74413 .61573 Mtetra
.863 .847 .826 r
.74413 .61573 .74494 .61647 .74661 .61372 .74586 .61384 Mtetra
.974 .923 .669 r
.74586 .61384 .74661 .61372 .74789 .60503 .74749 .61035 Mtetra
0 0 .248 r
.74749 .61035 .74789 .60503 .73676 .40713 .74889 .60355 Mtetra
.109 .017 .459 r
.74889 .60355 .73676 .40713 .73829 .40396 .73845 .4171 Mtetra
.483 .26 .499 r
.73845 .4171 .73829 .40396 .73998 .40318 .74001 .41433 Mtetra
.651 .387 .506 r
.74001 .41433 .73998 .40318 .74171 .40302 .74205 .41853 Mtetra
.952 .654 .433 r
.74205 .41853 .74171 .40302 .74344 .40279 .75529 .58872 Mtetra
.562 .348 .547 r
.75529 .58872 .74344 .40279 .74515 .4023 .75724 .59012 Mtetra
.562 .347 .547 r
.75724 .59012 .74515 .4023 .74686 .40182 .75915 .59103 Mtetra
.566 .35 .547 r
.75915 .59103 .74686 .40182 .74858 .40142 .76126 .59474 Mtetra
.563 .348 .547 r
.76126 .59474 .74858 .40142 .7503 .40101 .76325 .59671 Mtetra
.557 .344 .546 r
.76325 .59671 .7503 .40101 .75201 .40043 .76497 .59468 Mtetra
.1 .012 .458 r
.76497 .59468 .75201 .40043 .75369 .39933 .75344 .40556 Mtetra
.05 0 .337 r
.75344 .40556 .75369 .39933 .75534 .3979 .75473 .39902 Mtetra
.705 .82 .367 r
.75473 .39902 .75534 .3979 .757 .3966 .75625 .39584 Mtetra
.858 .837 .824 r
.75625 .39584 .757 .3966 .75867 .39546 .75788 .39408 Mtetra
.703 .69 .834 r
.75788 .39408 .75867 .39546 .76037 .39461 .75958 .39325 Mtetra
.574 .635 .874 r
.75958 .39325 .76037 .39461 .7621 .39433 .76133 .39313 Mtetra
0 .225 .745 r
.76133 .39313 .7621 .39433 .76397 .39585 .76321 .39477 Mtetra
.946 .591 .21 r
.76321 .39477 .76397 .39585 .76662 .40762 .76581 .40599 Mtetra
.976 .676 .372 r
.76581 .40599 .76662 .40762 .78307 .60243 .78227 .60142 Mtetra
0 .001 .535 r
.78227 .60142 .78307 .60243 .78512 .60467 .78432 .60368 Mtetra
.574 .723 .944 r
.78432 .60368 .78512 .60467 .78698 .60443 .78618 .60344 Mtetra
.708 .775 .904 r
.78618 .60344 .78698 .60443 .7888 .60363 .788 .60264 Mtetra
.624 .745 .934 r
.788 .60264 .7888 .60363 .79065 .60315 .78985 .60221 Mtetra
.45 .678 .962 r
.78985 .60221 .79065 .60315 .79253 .60315 .79175 .60232 Mtetra
.624 .782 .957 r
.79175 .60232 .79253 .60315 .79438 .60261 .7936 .60186 Mtetra
.898 .848 .786 r
.7936 .60186 .79438 .60261 .79607 .60017 .7953 .59951 Mtetra
.983 .759 .52 r
.7953 .59951 .79607 .60017 .79713 .58974 .79642 .58975 Mtetra
.978 .683 .381 r
.79642 .58975 .79713 .58974 .78305 .39096 .7823 .39 Mtetra
.926 .793 .694 r
.7823 .39 .78305 .39096 .78455 .38762 .7838 .38657 Mtetra
.722 .756 .879 r
.7838 .38657 .78455 .38762 .78626 .38677 .78551 .38571 Mtetra
.603 .709 .919 r
.78551 .38571 .78626 .38677 .78801 .38646 .78726 .38542 Mtetra
.647 .73 .909 r
.78726 .38542 .78801 .38646 .78975 .38597 .789 .38494 Mtetra
.741 .766 .873 r
.789 .38494 .78975 .38597 .79145 .38501 .7907 .38398 Mtetra
.654 .736 .91 r
.7907 .38398 .79145 .38501 .79319 .38449 .79244 .38347 Mtetra
.097 .422 .868 r
.79244 .38347 .79319 .38449 .79506 .38549 .79431 .38446 Mtetra
.901 .513 .079 r
.79431 .38446 .79506 .38549 .79746 .39271 .79671 .39167 Mtetra
.975 .672 .358 r
.79671 .39167 .79746 .39271 .81624 .59188 .81546 .59091 Mtetra
.595 .132 0 r
.81546 .59091 .81624 .59188 .81839 .59472 .81761 .59375 Mtetra
.605 .744 .943 r
.81761 .59375 .81839 .59472 .82027 .59436 .81948 .59339 Mtetra
.758 .798 .885 r
.81948 .59339 .82027 .59436 .82208 .59326 .8213 .59229 Mtetra
.783 .804 .87 r
.8213 .59229 .82208 .59326 .82388 .59199 .8231 .59102 Mtetra
.713 .785 .909 r
.8231 .59102 .82388 .59199 .82572 .59115 .82494 .59019 Mtetra
.699 .782 .916 r
.82494 .59019 .82572 .59115 .82756 .59038 .82678 .58942 Mtetra
.654 .768 .933 r
.82678 .58942 .82756 .59038 .82942 .58981 .82865 .58887 Mtetra
.576 .737 .952 r
.82865 .58887 .82942 .58981 .83132 .58955 .83054 .5886 Mtetra
.55 .726 .956 r
.83054 .5886 .83132 .58955 .83322 .58936 .83244 .58842 Mtetra
.48 .691 .96 r
.83244 .58842 .83322 .58936 .83514 .5894 .83436 .58845 Mtetra
.405 .651 .958 r
.83436 .58845 .83514 .5894 .83708 .58963 .83631 .58868 Mtetra
.609 .751 .945 r
.83631 .58868 .83708 .58963 .83897 .58924 .8382 .58829 Mtetra
.866 .82 .801 r
.8382 .58829 .83897 .58924 .8407 .58716 .83993 .58621 Mtetra
.982 .745 .504 r
.83993 .58621 .8407 .58716 .84161 .57627 .84085 .5754 Mtetra
.977 .678 .362 r
.84085 .5754 .84161 .57627 .82492 .37776 .82419 .37675 Mtetra
.931 .792 .684 r
.82419 .37675 .82492 .37776 .82639 .37418 .82566 .37316 Mtetra
.723 .765 .886 r
.82566 .37316 .82639 .37418 .82812 .37333 .82739 .3723 Mtetra
.599 .715 .926 r
.82739 .3723 .82812 .37333 .82991 .37304 .82917 .37201 Mtetra
.598 .715 .926 r
.82917 .37201 .82991 .37304 .83169 .37274 .83096 .37172 Mtetra
.738 .77 .879 r
.83096 .37172 .83169 .37274 .83341 .3718 .83268 .37077 Mtetra
.655 .739 .911 r
.83268 .37077 .83341 .3718 .83518 .37128 .83445 .37025 Mtetra
.233 .51 .908 r
.83445 .37025 .83518 .37128 .83707 .37201 .83634 .37098 Mtetra
.881 .489 .032 r
.83634 .37098 .83707 .37201 .83958 .37908 .83885 .37805 Mtetra
.975 .667 .334 r
.83885 .37805 .83958 .37908 .86122 .5795 .86046 .57852 Mtetra
.658 .204 0 r
.86046 .57852 .86122 .5795 .8635 .58293 .86274 .58195 Mtetra
.381 .63 .952 r
.86274 .58195 .8635 .58293 .86548 .58324 .86472 .58227 Mtetra
.694 .781 .918 r
.86472 .58227 .86548 .58324 .86735 .5825 .86659 .58152 Mtetra
.875 .82 .791 r
.86659 .58152 .86735 .5825 .86907 .58029 .86831 .57931 Mtetra
.979 .766 .548 r
.86831 .57931 .86907 .58029 .87024 .57255 .86948 .57159 Mtetra
.977 .675 .347 r
.86948 .57159 .87024 .57255 .8515 .37038 .85078 .36935 Mtetra
.95 .786 .644 r
.85078 .36935 .8515 .37038 .85288 .366 .85216 .36497 Mtetra
.746 .773 .875 r
.85216 .36497 .85288 .366 .85461 .365 .85389 .36397 Mtetra
.62 .724 .921 r
.85389 .36397 .85461 .365 .85641 .36463 .85569 .36359 Mtetra
.589 .709 .927 r
.85569 .36359 .85641 .36463 .85821 .36437 .85749 .36333 Mtetra
.748 .773 .873 r
.85749 .36333 .85821 .36437 .85994 .36336 .85922 .36231 Mtetra
.674 .746 .904 r
.85922 .36231 .85994 .36336 .86171 .36274 .861 .3617 Mtetra
.377 .594 .931 r
.861 .3617 .86171 .36274 .8636 .36315 .86288 .3621 Mtetra
.805 .392 0 r
.86288 .3621 .8636 .36315 .86601 .36854 .86529 .36746 Mtetra
.973 .663 .318 r
.86529 .36746 .86601 .36854 .88954 .5703 .88879 .56929 Mtetra
.709 .27 0 r
.88879 .56929 .88954 .5703 .89195 .57441 .8912 .57341 Mtetra
.504 .693 .953 r
.8912 .57341 .89195 .57441 .89392 .57438 .89317 .57338 Mtetra
.694 .778 .916 r
.89317 .57338 .89392 .57438 .8958 .57363 .89506 .57263 Mtetra
.734 .793 .899 r
.89506 .57263 .8958 .57363 .89767 .57266 .89692 .57166 Mtetra
.497 .69 .954 r
.89692 .57166 .89767 .57266 .89964 .57266 .8989 .57166 Mtetra
.623 .752 .939 r
.8989 .57166 .89964 .57266 .90157 .57221 .90082 .57122 Mtetra
.809 .815 .855 r
.90082 .57122 .90157 .57221 .90338 .57072 .90263 .56973 Mtetra
.979 .774 .556 r
.90263 .56973 .90338 .57072 .90456 .56364 .90382 .56266 Mtetra
.976 .671 .329 r
.90382 .56266 .90456 .56364 .88367 .36076 .88296 .35973 Mtetra
.961 .785 .62 r
.88296 .35973 .88367 .36076 .88498 .35592 .88427 .35488 Mtetra
.743 .773 .877 r
.88427 .35488 .88498 .35592 .88673 .35493 .88602 .35389 Mtetra
.604 .717 .924 r
.88602 .35389 .88673 .35493 .88855 .35461 .88784 .35357 Mtetra
.516 .673 .935 r
.88784 .35357 .88855 .35461 .89041 .35461 .8897 .35356 Mtetra
.653 .738 .912 r
.8897 .35356 .89041 .35461 .89221 .35409 .89151 .35303 Mtetra
.66 .74 .909 r
.89151 .35303 .89221 .35409 .89401 .35354 .89331 .35248 Mtetra
.674 .745 .904 r
.89331 .35248 .89401 .35354 .8958 .35293 .8951 .35186 Mtetra
.764 .777 .864 r
.8951 .35186 .8958 .35293 .89754 .3518 .89683 .35073 Mtetra
.699 .753 .893 r
.89683 .35073 .89754 .3518 .89932 .35105 .89862 .34998 Mtetra
.505 .66 .931 r
.89862 .34998 .89932 .35105 .90119 .3511 .90049 .35002 Mtetra
.735 .319 0 r
.90049 .35002 .90119 .3511 .90364 .35596 .90293 .35482 Mtetra
.971 .656 .294 r
.90293 .35482 .90364 .35596 .92977 .55842 .92903 .55735 Mtetra
.724 .298 0 r
.92903 .55735 .92977 .55842 .93233 .56315 .9316 .56212 Mtetra
.488 .679 .95 r
.9316 .56212 .93233 .56315 .93434 .56319 .93361 .56216 Mtetra
.689 .774 .916 r
.93361 .56216 .93434 .56319 .93625 .56245 .93552 .56143 Mtetra
.762 .8 .884 r
.93552 .56143 .93625 .56245 .93812 .56129 .93739 .56027 Mtetra
.446 .691 .97 r
.3132 .73417 .31419 .73498 .31571 .73504 .31472 .73423 Mtetra
.612 .752 .944 r
.31472 .73423 .31571 .73504 .31726 .73471 .31627 .73391 Mtetra
.771 .781 .861 r
.31627 .73391 .31726 .73471 .31885 .73358 .31786 .73282 Mtetra
.915 .734 .643 r
.31786 .73282 .31885 .73358 .32077 .72693 .31976 .72659 Mtetra
.937 .687 .533 r
.31976 .72659 .32077 .72693 .33333 .53367 .33237 .53334 Mtetra
.929 .768 .661 r
.33237 .53334 .33333 .53367 .33504 .52899 .3341 .52841 Mtetra
.772 .822 .892 r
.3341 .52841 .33504 .52899 .33654 .5281 .3356 .52745 Mtetra
.571 .77 .973 r
.3356 .52745 .33654 .5281 .33799 .52793 .33706 .52721 Mtetra
.382 .675 .974 r
.33706 .52721 .33799 .52793 .33943 .52815 .3385 .52735 Mtetra
.629 .748 .933 r
.3385 .52735 .33943 .52815 .3409 .52783 .33997 .527 Mtetra
.648 .746 .921 r
.33997 .527 .3409 .52783 .34237 .52743 .34145 .52658 Mtetra
.657 .745 .915 r
.34145 .52658 .34237 .52743 .34385 .52699 .34292 .52614 Mtetra
.754 .762 .859 r
.34292 .52614 .34385 .52699 .34535 .52605 .34443 .52519 Mtetra
.705 .753 .89 r
.34443 .52519 .34535 .52605 .34684 .52541 .34592 .52454 Mtetra
.497 .686 .951 r
.34592 .52454 .34684 .52541 .34829 .52544 .34737 .52454 Mtetra
.929 .55 .251 r
.34737 .52454 .34829 .52544 .34952 .52985 .34861 .52864 Mtetra
.94 .684 .52 r
.34861 .52864 .34952 .52985 .34096 .72292 .34001 .72146 Mtetra
.944 .58 .231 r
.34001 .72146 .34096 .72292 .34226 .72766 .3413 .72652 Mtetra
.384 .583 .92 r
.3413 .72652 .34226 .72766 .34379 .72792 .34283 .72687 Mtetra
.686 .722 .877 r
.34283 .72687 .34379 .72792 .34538 .72722 .34441 .72625 Mtetra
.755 .75 .848 r
.34441 .72625 .34538 .72722 .34699 .72608 .34601 .72521 Mtetra
.538 .712 .952 r
.34601 .72521 .34699 .72608 .34854 .72594 .34757 .7251 Mtetra
.6 .742 .944 r
.34757 .7251 .34854 .72594 .35011 .72564 .34913 .72481 Mtetra
.755 .778 .872 r
.34913 .72481 .35011 .72564 .35171 .72464 .35074 .72383 Mtetra
.91 .743 .662 r
.35074 .72383 .35171 .72464 .35353 .71927 .35254 .71873 Mtetra
.941 .688 .526 r
.35254 .71873 .35353 .71927 .3644 .52496 .36345 .52469 Mtetra
.939 .765 .64 r
.36345 .52469 .3644 .52496 .36613 .51945 .3652 .51887 Mtetra
.815 .821 .854 r
.3652 .51887 .36613 .51945 .36765 .51824 .36673 .51758 Mtetra
.6 .779 .966 r
.36673 .51758 .36765 .51824 .36913 .518 .36821 .51727 Mtetra
.41 .687 .975 r
.36821 .51727 .36913 .518 .37059 .51817 .36968 .51737 Mtetra
.608 .742 .94 r
.36968 .51737 .37059 .51817 .37208 .51792 .37116 .51708 Mtetra
.651 .745 .919 r
.37116 .51708 .37208 .51792 .37357 .51751 .37266 .51665 Mtetra
.659 .744 .913 r
.37266 .51665 .37357 .51751 .37506 .51706 .37415 .51619 Mtetra
.748 .76 .862 r
.37415 .51619 .37506 .51706 .37658 .51615 .37567 .51528 Mtetra
.716 .754 .882 r
.37567 .51528 .37658 .51615 .37808 .51544 .37717 .51455 Mtetra
.551 .703 .94 r
.37717 .51455 .37808 .51544 .37956 .51535 .37866 .51443 Mtetra
.896 .476 .116 r
.37866 .51443 .37956 .51535 .38089 .51879 .37999 .51762 Mtetra
.944 .684 .513 r
.37999 .51762 .38089 .51879 .37412 .71215 .3732 .71042 Mtetra
.955 .608 .255 r
.3732 .71042 .37412 .71215 .37545 .7179 .3745 .7167 Mtetra
.226 .483 .891 r
.3745 .7167 .37545 .7179 .377 .71849 .37604 .71737 Mtetra
.685 .713 .87 r
.37604 .71737 .377 .71849 .3786 .71779 .37764 .71675 Mtetra
.76 .742 .836 r
.37764 .71675 .3786 .71779 .38022 .7166 .37926 .71563 Mtetra
.715 .747 .877 r
.37926 .71563 .38022 .7166 .38183 .7158 .38087 .71486 Mtetra
.678 .744 .901 r
.38087 .71486 .38183 .7158 .38342 .71523 .38246 .71429 Mtetra
.669 .742 .905 r
.38246 .71429 .38342 .71523 .38502 .71471 .38406 .71376 Mtetra
.655 .735 .909 r
.38406 .71376 .38502 .71471 .38662 .71423 .38566 .71329 Mtetra
.641 .733 .916 r
.38566 .71329 .38662 .71423 .38821 .71381 .38725 .71287 Mtetra
.627 .731 .922 r
.38725 .71287 .38821 .71381 .38981 .71345 .38885 .71251 Mtetra
.606 .723 .928 r
.38885 .71251 .38981 .71345 .3914 .71324 .39044 .71222 Mtetra
.6 .705 .917 r
.39044 .71222 .3914 .71324 .39298 .71307 .39203 .71196 Mtetra
.605 .687 .901 r
.39203 .71196 .39298 .71307 .39457 .71289 .39363 .7117 Mtetra
.603 .672 .889 r
.39363 .7117 .39457 .71289 .39616 .71279 .39522 .71145 Mtetra
.62 .654 .862 r
.39522 .71145 .39616 .71279 .39776 .71254 .39682 .71114 Mtetra
.647 .656 .844 r
.39682 .71114 .39776 .71254 .39937 .71193 .39842 .71068 Mtetra
.72 .702 .833 r
.39842 .71068 .39937 .71193 .40102 .71003 .40004 .70979 Mtetra
.806 .92 .914 r
.40004 .70979 .40102 .71003 .40274 .70644 .40168 .7086 Mtetra
.208 0 .14 r
.40168 .7086 .40274 .70644 .4046 .69845 .40331 .70732 Mtetra
.517 .269 .478 r
.40331 .70732 .4046 .69845 .41226 .51812 .40493 .7065 Mtetra
.559 .345 .546 r
.40493 .7065 .41226 .51812 .4138 .51716 .40654 .70608 Mtetra
.56 .346 .546 r
.40654 .70608 .4138 .51716 .41509 .52371 .40814 .70579 Mtetra
.559 .345 .546 r
.40814 .70579 .41509 .52371 .4113 .68757 .40974 .70544 Mtetra
.548 .317 .517 r
.40974 .70544 .4113 .68757 .41286 .68857 .41135 .70503 Mtetra
.547 .314 .514 r
.41135 .70503 .41286 .68857 .41443 .68914 .41296 .7046 Mtetra
.555 .319 .513 r
.41296 .7046 .41443 .68914 .4159 .69305 .41456 .70457 Mtetra
.549 .307 .5 r
.41456 .70457 .4159 .69305 .41745 .69456 .41617 .70443 Mtetra
.521 .277 .485 r
.41617 .70443 .41745 .69456 .41911 .69214 .41779 .70358 Mtetra
.384 .167 .456 r
.41779 .70358 .41911 .69214 .42616 .50823 .41953 .69925 Mtetra
0 0 .317 r
.41953 .69925 .42616 .50823 .42784 .50256 .42683 .50557 Mtetra
.855 .823 .345 r
.42683 .50557 .42784 .50256 .42944 .49966 .42853 .49937 Mtetra
.89 .874 .814 r
.42853 .49937 .42944 .49966 .43099 .49832 .43009 .49747 Mtetra
.691 .758 .902 r
.43009 .49747 .43099 .49832 .43251 .49777 .43163 .49686 Mtetra
.588 .715 .931 r
.43163 .49686 .43251 .49777 .43404 .49746 .43315 .49664 Mtetra
.616 .746 .939 r
.43315 .49664 .43404 .49746 .43556 .49708 .43467 .49632 Mtetra
.66 .774 .933 r
.43467 .49632 .43556 .49708 .43709 .49659 .4362 .49583 Mtetra
.659 .775 .935 r
.4362 .49583 .43709 .49659 .43862 .4961 .43773 .49535 Mtetra
.66 .778 .936 r
.43773 .49535 .43862 .4961 .44015 .49561 .43926 .49487 Mtetra
.662 .78 .936 r
.43926 .49487 .44015 .49561 .44169 .49512 .44079 .49438 Mtetra
.661 .78 .937 r
.44079 .49438 .44169 .49512 .44322 .49462 .44233 .49389 Mtetra
.66 .781 .938 r
.44233 .49389 .44322 .49462 .44475 .49414 .44386 .4934 Mtetra
.659 .781 .939 r
.44386 .4934 .44475 .49414 .44629 .49365 .4454 .49292 Mtetra
.657 .781 .94 r
.4454 .49292 .44629 .49365 .44782 .49317 .44693 .49245 Mtetra
.655 .782 .941 r
.44693 .49245 .44782 .49317 .44936 .49269 .44847 .49197 Mtetra
.652 .784 .944 r
.44847 .49197 .44936 .49269 .45089 .49222 .45001 .49151 Mtetra
.646 .786 .949 r
.45001 .49151 .45089 .49222 .45243 .49177 .45154 .49107 Mtetra
.634 .783 .953 r
.45154 .49107 .45243 .49177 .45397 .4914 .45308 .49066 Mtetra
.626 .77 .949 r
.45308 .49066 .45397 .4914 .4555 .49111 .45462 .49029 Mtetra
.63 .751 .935 r
.45462 .49029 .4555 .49111 .45704 .49082 .45616 .48991 Mtetra
.642 .735 .916 r
.45616 .48991 .45704 .49082 .45858 .49046 .4577 .4895 Mtetra
.653 .728 .904 r
.4577 .4895 .45858 .49046 .46012 .49001 .45924 .48906 Mtetra
.658 .73 .903 r
.45924 .48906 .46012 .49001 .46166 .48952 .46078 .48859 Mtetra
.66 .735 .905 r
.46078 .48859 .46166 .48952 .46321 .48903 .46233 .48811 Mtetra
.662 .738 .907 r
.46233 .48811 .46321 .48903 .46475 .48854 .46387 .48762 Mtetra
.667 .741 .905 r
.46387 .48762 .46475 .48854 .4663 .48801 .46542 .48711 Mtetra
.678 .748 .904 r
.46542 .48711 .4663 .48801 .46785 .4874 .46697 .48656 Mtetra
.687 .765 .911 r
.46697 .48656 .46785 .4874 .4694 .48671 .46852 .48597 Mtetra
.687 .788 .927 r
.46852 .48597 .4694 .48671 .47095 .48602 .47007 .48538 Mtetra
.676 .81 .947 r
.47007 .48538 .47095 .48602 .4725 .48541 .47162 .48482 Mtetra
.659 .822 .962 r
.47162 .48482 .4725 .48541 .47405 .48488 .47317 .48431 Mtetra
.652 .826 .967 r
.47317 .48431 .47405 .48488 .4756 .48437 .47473 .48381 Mtetra
.65 .827 .968 r
.47473 .48381 .4756 .48437 .47716 .48387 .47628 .48331 Mtetra
.65 .829 .969 r
.47628 .48331 .47716 .48387 .47871 .48336 .47783 .48281 Mtetra
.649 .832 .971 r
.47783 .48281 .47871 .48336 .48026 .48286 .47939 .48232 Mtetra
.664 .837 .966 r
.47939 .48232 .48026 .48286 .48182 .48225 .48094 .48177 Mtetra
.668 .856 .972 r
.48094 .48177 .48182 .48225 .48338 .48158 .4825 .4812 Mtetra
.616 .87 .99 r
.4825 .4812 .48338 .48158 .48493 .48116 .48406 .48072 Mtetra
.484 .807 1 r
.48406 .48072 .48493 .48116 .48648 .48154 .48561 .48052 Mtetra
.448 .63 .931 r
.48561 .48052 .48648 .48154 .48801 .48348 .48716 .48069 Mtetra
.531 .467 .73 r
.48716 .48069 .48801 .48348 .48952 .48817 .48871 .48099 Mtetra
.566 .404 .622 r
.48871 .48099 .48952 .48817 .4892 .67159 .49027 .48104 Mtetra
.562 .351 .552 r
.49027 .48104 .4892 .67159 .49083 .67312 .49183 .48056 Mtetra
.49183 .48056 .49083 .67312 .49251 .67013 .4934 .47993 Mtetra
.562 .352 .552 r
.4934 .47993 .49251 .67013 .49566 .49894 .49496 .47908 Mtetra
.579 .381 .577 r
.49496 .47908 .49566 .49894 .4973 .49127 .49653 .47816 Mtetra
.574 .387 .59 r
.49653 .47816 .4973 .49127 .49886 .49205 .4981 .47781 Mtetra
.522 .345 .582 r
.4981 .47781 .49886 .49205 .49909 .67299 .49965 .47947 Mtetra
0 0 .373 r
.49965 .47947 .49909 .67299 .5007 .67932 .49984 .67092 Mtetra
0 0 .431 r
.49984 .67092 .5007 .67932 .50235 .68192 .50144 .67987 Mtetra
0 .17 .696 r
.50144 .67987 .50235 .68192 .50401 .68293 .50309 .68187 Mtetra
.551 .683 .926 r
.50309 .68187 .50401 .68293 .50567 .68281 .50475 .68176 Mtetra
.679 .733 .891 r
.50475 .68176 .50567 .68281 .50734 .68236 .50642 .68115 Mtetra
.698 .709 .857 r
.50642 .68115 .50734 .68236 .50901 .68177 .5081 .68041 Mtetra
.664 .675 .85 r
.5081 .68041 .50901 .68177 .51068 .68116 .50977 .67985 Mtetra
.67 .684 .855 r
.50977 .67985 .51068 .68116 .51235 .68051 .51144 .67926 Mtetra
.66 .691 .868 r
.51144 .67926 .51235 .68051 .51403 .67998 .51311 .67874 Mtetra
.637 .682 .876 r
.51311 .67874 .51403 .67998 .5157 .67969 .51479 .67832 Mtetra
.65 .668 .854 r
.51479 .67832 .5157 .67969 .51737 .67918 .51646 .67784 Mtetra
.692 .688 .842 r
.51646 .67784 .51737 .67918 .51905 .67794 .51814 .67711 Mtetra
.78 .796 .866 r
.51814 .67711 .51905 .67794 .52073 .67502 .51982 .67592 Mtetra
0 0 0 r
.51982 .67592 .52073 .67502 .52241 .66981 .52149 .67461 Mtetra
.449 .174 .404 r
.52149 .67461 .52241 .66981 .52413 .48897 .52317 .67346 Mtetra
.559 .345 .546 r
.52317 .67346 .52413 .48897 .52571 .48198 .52485 .67289 Mtetra
.52485 .67289 .52571 .48198 .5273 .48411 .52653 .67251 Mtetra
.56 .345 .546 r
.52653 .67251 .5273 .48411 .5291 .65303 .52821 .67216 Mtetra
.548 .318 .518 r
.52821 .67216 .5291 .65303 .53077 .6529 .5299 .67169 Mtetra
.548 .317 .518 r
.5299 .67169 .53077 .6529 .53244 .65277 .53158 .67121 Mtetra
.547 .317 .517 r
.53158 .67121 .53244 .65277 .53412 .6522 .53326 .67072 Mtetra
.53326 .67072 .53412 .6522 .53579 .65058 .53495 .67022 Mtetra
.548 .318 .519 r
.53495 .67022 .53579 .65058 .53746 .64814 .53663 .66971 Mtetra
.549 .321 .522 r
.53663 .66971 .53746 .64814 .53912 .64408 .53832 .6692 Mtetra
.551 .325 .526 r
.53832 .6692 .53912 .64408 .54013 .49902 .54001 .66869 Mtetra
.559 .345 .546 r
.54001 .66869 .54013 .49902 .54169 .489 .5417 .66819 Mtetra
.5417 .66819 .54169 .489 .54328 .48633 .54339 .6677 Mtetra
.54339 .6677 .54328 .48633 .54487 .4847 .54508 .6672 Mtetra
.54508 .6672 .54487 .4847 .54647 .48353 .54677 .66671 Mtetra
.54677 .66671 .54647 .48353 .54807 .48265 .54846 .66623 Mtetra
.54846 .66623 .54807 .48265 .54967 .48201 .55016 .66575 Mtetra
.55016 .66575 .54967 .48201 .55128 .48159 .55185 .66528 Mtetra
.55185 .66528 .55128 .48159 .55289 .48139 .55355 .66481 Mtetra
.55355 .66481 .55289 .48139 .5545 .48149 .55525 .66434 Mtetra
.55525 .66434 .5545 .48149 .55612 .48204 .55695 .66388 Mtetra
.55695 .66388 .55612 .48204 .55775 .48355 .55865 .66343 Mtetra
.55865 .66343 .55775 .48355 .55944 .49056 .56035 .66298 Mtetra
.56035 .66298 .55944 .49056 .56266 .63757 .56205 .66253 Mtetra
.552 .326 .526 r
.56205 .66253 .56266 .63757 .56439 .64064 .56375 .66209 Mtetra
.55 .322 .522 r
.56375 .66209 .56439 .64064 .56611 .64251 .56546 .66166 Mtetra
.549 .319 .518 r
.56546 .66166 .56611 .64251 .56783 .6436 .56716 .66122 Mtetra
.548 .316 .516 r
.56716 .66122 .56783 .6436 .56954 .64421 .56887 .66078 Mtetra
.547 .314 .514 r
.56887 .66078 .56954 .64421 .57124 .64439 .57058 .66033 Mtetra
.546 .312 .512 r
.57058 .66033 .57124 .64439 .57295 .64437 .57229 .65988 Mtetra
.545 .311 .511 r
.57229 .65988 .57295 .64437 .57465 .6442 .574 .65942 Mtetra
.545 .31 .51 r
.574 .65942 .57465 .6442 .57636 .64392 .57571 .65895 Mtetra
.57571 .65895 .57636 .64392 .57806 .64352 .57742 .65848 Mtetra
.544 .309 .509 r
.57742 .65848 .57806 .64352 .57977 .64296 .57913 .658 Mtetra
.544 .309 .51 r
.57913 .658 .57977 .64296 .58146 .64207 .58084 .65751 Mtetra
.545 .31 .511 r
.58084 .65751 .58146 .64207 .58316 .64114 .58256 .65702 Mtetra
.545 .311 .512 r
.58256 .65702 .58316 .64114 .58485 .63936 .58427 .65651 Mtetra
.543 .312 .514 r
.58427 .65651 .58485 .63936 .58347 .46607 .58599 .65588 Mtetra
.559 .345 .546 r
.58599 .65588 .58347 .46607 .58508 .4648 .5877 .65536 Mtetra
.56 .346 .546 r
.5877 .65536 .58508 .4648 .59005 .64238 .58943 .65509 Mtetra
.563 .32 .506 r
.58943 .65509 .59005 .64238 .59197 .65241 .59116 .65545 Mtetra
.558 .232 .372 r
.59116 .65545 .59197 .65241 .59376 .65559 .5929 .65578 Mtetra
.253 0 0 r
.5929 .65578 .59376 .65559 .59552 .65713 .59464 .65595 Mtetra
.6 .685 .902 r
.59464 .65595 .59552 .65713 .59726 .65714 .59636 .65569 Mtetra
.632 .653 .852 r
.59636 .65569 .59726 .65714 .59898 .65678 .59809 .65529 Mtetra
.647 .654 .843 r
.59809 .65529 .59898 .65678 .60071 .65619 .59982 .65479 Mtetra
.582 .64 .873 r
.59982 .65479 .60071 .65619 .60244 .65581 .60155 .65463 Mtetra
.652 .705 .886 r
.60155 .65463 .60244 .65581 .60416 .6552 .60328 .65413 Mtetra
.76 .758 .851 r
.60328 .65413 .60416 .6552 .60588 .65419 .60499 .653 Mtetra
.91 .747 .668 r
.60499 .653 .60588 .65419 .60756 .6516 .60663 .64856 Mtetra
.964 .687 .462 r
.60663 .64856 .60756 .6516 .6092 .64733 .60369 .45401 Mtetra
.577 .363 .554 r
.60369 .45401 .6092 .64733 .61063 .63505 .60511 .44452 Mtetra
.563 .352 .552 r
.60511 .44452 .61063 .63505 .61225 .63013 .60672 .44333 Mtetra
.562 .351 .552 r
.60672 .44333 .61225 .63013 .61408 .63401 .60835 .44294 Mtetra
.561 .351 .552 r
.60835 .44294 .61408 .63401 .61574 .63094 .60999 .44284 Mtetra
.563 .352 .553 r
.60999 .44284 .61574 .63094 .61254 .44664 .6116 .44155 Mtetra
.642 .479 .648 r
.6116 .44155 .61254 .44664 .61407 .44239 .61322 .44029 Mtetra
.702 .608 .749 r
.61322 .44029 .61407 .44239 .61565 .43995 .61483 .43919 Mtetra
.674 .792 .937 r
.61483 .43919 .61565 .43995 .61728 .43922 .61647 .43861 Mtetra
.618 .819 .978 r
.61647 .43861 .61728 .43922 .61892 .43889 .6181 .43818 Mtetra
.616 .788 .964 r
.6181 .43818 .61892 .43889 .62056 .43873 .61974 .43779 Mtetra
.68 .751 .905 r
.61974 .43779 .62056 .43873 .62219 .43812 .62138 .4372 Mtetra
.689 .758 .905 r
.62138 .4372 .62219 .43812 .62383 .43743 .62301 .43656 Mtetra
.689 .772 .915 r
.62301 .43656 .62383 .43743 .62546 .43673 .62464 .43593 Mtetra
.748 .801 .895 r
.62464 .43593 .62546 .43673 .62709 .43593 .62627 .43501 Mtetra
.694 .762 .904 r
.62627 .43501 .62709 .43593 .62872 .4353 .62791 .43435 Mtetra
.549 .699 .939 r
.62791 .43435 .62872 .4353 .63037 .43504 .62956 .43423 Mtetra
.717 .231 0 r
.62956 .43423 .63037 .43504 .63206 .43593 .6313 .43669 Mtetra
.967 .681 .437 r
.6313 .43669 .63206 .43593 .6338 .4383 .63916 .6237 Mtetra
.585 .365 .548 r
.63916 .6237 .6338 .4383 .63584 .44936 .64146 .63953 Mtetra
.563 .348 .547 r
.64146 .63953 .63584 .44936 .64399 .63762 .64328 .64105 Mtetra
.553 .237 .387 r
.64328 .64105 .64399 .63762 .64587 .64085 .64506 .64132 Mtetra
.155 0 0 r
.64506 .64132 .64587 .64085 .64769 .64223 .64682 .64108 Mtetra
.599 .693 .909 r
.64682 .64108 .64769 .64223 .64947 .64244 .64858 .64081 Mtetra
.639 .634 .829 r
.64858 .64081 .64947 .64244 .65123 .64203 .65034 .64035 Mtetra
.67 .643 .814 r
.65034 .64035 .65123 .64203 .65297 .64104 .6521 .63967 Mtetra
.681 .687 .849 r
.6521 .63967 .65297 .64104 .65467 .63904 .65385 .63898 Mtetra
.706 .975 .921 r
.65385 .63898 .65467 .63904 .65632 .63556 .65559 .63792 Mtetra
.151 0 .167 r
.65559 .63792 .65632 .63556 .65774 .62632 .6573 .63604 Mtetra
.203 .028 .407 r
.6573 .63604 .65774 .62632 .65201 .43402 .6588 .62881 Mtetra
.018 0 .418 r
.6588 .62881 .65201 .43402 .65352 .42981 .65282 .43164 Mtetra
.777 .799 .309 r
.65282 .43164 .65352 .42981 .65511 .42755 .65432 .427 Mtetra
.821 .871 .883 r
.65432 .427 .65511 .42755 .65675 .42669 .65594 .42569 Mtetra
.636 .726 .913 r
.65594 .42569 .65675 .42669 .65842 .42637 .65761 .42528 Mtetra
.539 .665 .918 r
.65761 .42528 .65842 .42637 .66009 .42629 .65928 .42523 Mtetra
.621 .708 .908 r
.65928 .42523 .66009 .42629 .66176 .42592 .66095 .42488 Mtetra
.651 .723 .902 r
.66095 .42488 .66176 .42592 .66342 .42541 .66261 .42441 Mtetra
.66 .734 .904 r
.66261 .42441 .66342 .42541 .66508 .42484 .66428 .42389 Mtetra
.698 .759 .899 r
.66428 .42389 .66508 .42484 .66672 .42393 .66593 .42321 Mtetra
.7 .813 .935 r
.66593 .42321 .66672 .42393 .66837 .4231 .66759 .42252 Mtetra
.657 .841 .971 r
.66759 .42252 .66837 .4231 .67004 .42261 .66925 .42195 Mtetra
.615 .806 .973 r
.66925 .42195 .67004 .42261 .67176 .42327 .67092 .42153 Mtetra
.568 .575 .821 r
.67092 .42153 .67176 .42327 .67355 .42546 .67261 .42149 Mtetra
.507 .413 .683 r
.67261 .42149 .67355 .42546 .67565 .43432 .67434 .4222 Mtetra
.385 .254 .577 r
.67434 .4222 .67565 .43432 .68629 .62537 .67628 .4276 Mtetra
.045 0 .438 r
.67628 .4276 .68629 .62537 .68826 .62883 .68726 .62458 Mtetra
.055 .108 .601 r
.68726 .62458 .68826 .62883 .69013 .63031 .68926 .62876 Mtetra
.356 .497 .862 r
.68926 .62876 .69013 .63031 .69196 .63064 .6911 .62947 Mtetra
.629 .705 .9 r
.6911 .62947 .69196 .63064 .69375 .63028 .69289 .62907 Mtetra
.719 .729 .858 r
.69289 .62907 .69375 .63028 .69551 .62938 .69466 .62816 Mtetra
.703 .724 .866 r
.69466 .62816 .69551 .62938 .69723 .62755 .69643 .62736 Mtetra
.717 .96 .944 r
.69643 .62736 .69723 .62755 .69888 .6244 .69819 .62635 Mtetra
.106 0 .1 r
.69819 .62635 .69888 .6244 .70034 .61746 .69992 .62461 Mtetra
.197 .008 .383 r
.69992 .62461 .70034 .61746 .69211 .42253 .70145 .61909 Mtetra
.042 0 .432 r
.70145 .61909 .69211 .42253 .69356 .41755 .69296 .42034 Mtetra
0 0 0 r
.69296 .42034 .69356 .41755 .69513 .41506 .69438 .41471 Mtetra
.878 .922 .851 r
.69438 .41471 .69513 .41506 .69679 .41398 .696 .41302 Mtetra
.66 .745 .913 r
.696 .41302 .69679 .41398 .69847 .41359 .69768 .4125 Mtetra
.561 .676 .916 r
.69768 .4125 .69847 .41359 .70018 .41345 .69938 .41237 Mtetra
.614 .703 .907 r
.69938 .41237 .70018 .41345 .70187 .41311 .70108 .41205 Mtetra
.657 .724 .898 r
.70108 .41205 .70187 .41311 .70355 .41258 .70276 .41154 Mtetra
.664 .731 .899 r
.70276 .41154 .70355 .41258 .70524 .41198 .70445 .411 Mtetra
.694 .753 .897 r
.70445 .411 .70524 .41198 .7069 .41111 .70613 .41032 Mtetra
.701 .801 .927 r
.70613 .41032 .7069 .41111 .70857 .41024 .70781 .40962 Mtetra
.664 .835 .965 r
.70781 .40962 .70857 .41024 .71026 .40969 .70949 .40903 Mtetra
.621 .81 .973 r
.70949 .40903 .71026 .40969 .712 .41014 .71119 .40859 Mtetra
.578 .606 .844 r
.71119 .40859 .712 .41014 .71383 .41201 .7129 .40847 Mtetra
.515 .432 .7 r
.7129 .40847 .71383 .41201 .71591 .41805 .71466 .40903 Mtetra
.394 .275 .597 r
.71466 .40903 .71591 .41805 .72918 .61212 .71662 .41297 Mtetra
.067 0 .451 r
.71662 .41297 .72918 .61212 .73127 .61625 .73019 .61112 Mtetra
.069 .098 .582 r
.73019 .61112 .73127 .61625 .73321 .61798 .73234 .61622 Mtetra
.29 .428 .828 r
.73234 .61622 .73321 .61798 .73508 .61841 .73424 .61729 Mtetra
.602 .705 .916 r
.73424 .61729 .73508 .61841 .7369 .61815 .73607 .61699 Mtetra
.694 .732 .88 r
.73607 .61699 .7369 .61815 .73871 .6176 .73787 .61624 Mtetra
.675 .693 .859 r
.73787 .61624 .73871 .6176 .74053 .6171 .73967 .61559 Mtetra
.654 .661 .844 r
.73967 .61559 .74053 .6171 .74234 .61658 .74148 .61503 Mtetra
.672 .665 .835 r
.74148 .61503 .74234 .61658 .74413 .61573 .74329 .61435 Mtetra
.725 .71 .836 r
.74329 .61435 .74413 .61573 .74586 .61384 .74507 .61335 Mtetra
.809 .907 .908 r
.74507 .61335 .74586 .61384 .74749 .61035 .74684 .61204 Mtetra
.15 0 .079 r
.74684 .61204 .74749 .61035 .74889 .60355 .7486 .61064 Mtetra
.5 .244 .459 r
.7486 .61064 .74889 .60355 .73845 .4171 .75039 .60961 Mtetra
.559 .345 .546 r
.75039 .60961 .73845 .4171 .74001 .41433 .75221 .60905 Mtetra
.56 .345 .546 r
.75221 .60905 .74001 .41433 .74205 .41853 .75403 .60865 Mtetra
.559 .345 .546 r
.75403 .60865 .74205 .41853 .75529 .58872 .75586 .60824 Mtetra
.549 .319 .519 r
.75586 .60824 .75529 .58872 .75724 .59012 .75769 .60776 Mtetra
.547 .315 .515 r
.75769 .60776 .75724 .59012 .75915 .59103 .75952 .60727 Mtetra
.552 .317 .513 r
.75952 .60727 .75915 .59103 .76126 .59474 .76137 .60712 Mtetra
.55 .308 .501 r
.76137 .60712 .76126 .59474 .76325 .59671 .76322 .60699 Mtetra
.527 .283 .489 r
.76322 .60699 .76325 .59671 .76497 .59468 .76503 .60617 Mtetra
.436 .217 .482 r
.76503 .60617 .76497 .59468 .75344 .40556 .76663 .60241 Mtetra
.074 0 .45 r
.76663 .60241 .75344 .40556 .75473 .39902 .75432 .4031 Mtetra
0 0 .086 r
.75432 .4031 .75473 .39902 .75625 .39584 .75555 .39565 Mtetra
.946 .929 .753 r
.75555 .39565 .75625 .39584 .75788 .39408 .75712 .39312 Mtetra
.745 .779 .881 r
.75712 .39312 .75788 .39408 .75958 .39325 .75881 .39216 Mtetra
.559 .678 .919 r
.75881 .39216 .75958 .39325 .76133 .39313 .76056 .39204 Mtetra
0 .198 .722 r
.76056 .39204 .76133 .39313 .76321 .39477 .76244 .39368 Mtetra
.942 .584 .197 r
.76244 .39368 .76321 .39477 .76581 .40599 .76499 .4042 Mtetra
.976 .676 .371 r
.76499 .4042 .76581 .40599 .78227 .60142 .78146 .6004 Mtetra
0 0 .526 r
.78146 .6004 .78227 .60142 .78432 .60368 .78351 .6027 Mtetra
.568 .725 .948 r
.78351 .6027 .78432 .60368 .78618 .60344 .78538 .60248 Mtetra
.709 .783 .91 r
.78538 .60248 .78618 .60344 .788 .60264 .7872 .60167 Mtetra
.638 .757 .935 r
.7872 .60167 .788 .60264 .78985 .60221 .78905 .60119 Mtetra
.501 .682 .947 r
.78905 .60119 .78985 .60221 .79175 .60232 .79094 .6012 Mtetra
.656 .731 .905 r
.79094 .6012 .79175 .60232 .7936 .60186 .79278 .60065 Mtetra
.865 .773 .758 r
.79278 .60065 .7936 .60186 .7953 .59951 .79448 .59819 Mtetra
.968 .732 .527 r
.79448 .59819 .7953 .59951 .79642 .58975 .79551 .58736 Mtetra
.976 .681 .387 r
.79551 .58736 .79642 .58975 .7823 .39 .78153 .38884 Mtetra
.907 .77 .699 r
.78153 .38884 .7823 .39 .7838 .38657 .78304 .38554 Mtetra
.721 .759 .882 r
.78304 .38554 .7838 .38657 .78551 .38571 .78475 .38469 Mtetra
.602 .715 .924 r
.78475 .38469 .78551 .38571 .78726 .38542 .78651 .38439 Mtetra
.648 .733 .912 r
.78651 .38439 .78726 .38542 .789 .38494 .78825 .38391 Mtetra
.74 .765 .873 r
.78825 .38391 .789 .38494 .7907 .38398 .78995 .38295 Mtetra
.654 .735 .909 r
.78995 .38295 .7907 .38398 .79244 .38347 .79169 .38244 Mtetra
.101 .424 .868 r
.79169 .38244 .79244 .38347 .79431 .38446 .79356 .38343 Mtetra
.9 .511 .075 r
.79356 .38343 .79431 .38446 .79671 .39167 .79595 .39059 Mtetra
.976 .672 .358 r
.79595 .39059 .79671 .39167 .81546 .59091 .81467 .58992 Mtetra
.592 .131 0 r
.81467 .58992 .81546 .59091 .81761 .59375 .81682 .59278 Mtetra
.604 .742 .942 r
.81682 .59278 .81761 .59375 .81948 .59339 .8187 .59242 Mtetra
.758 .797 .885 r
.8187 .59242 .81948 .59339 .8213 .59229 .82051 .59132 Mtetra
.781 .803 .871 r
.82051 .59132 .8213 .59229 .8231 .59102 .82232 .59006 Mtetra
.71 .786 .911 r
.82232 .59006 .8231 .59102 .82494 .59019 .82416 .58924 Mtetra
.696 .784 .919 r
.82416 .58924 .82494 .59019 .82678 .58942 .82601 .58849 Mtetra
.65 .772 .938 r
.82601 .58849 .82678 .58942 .82865 .58887 .82787 .58794 Mtetra
.573 .742 .956 r
.82787 .58794 .82865 .58887 .83054 .5886 .82977 .58768 Mtetra
.549 .731 .96 r
.82977 .58768 .83054 .5886 .83244 .58842 .83167 .58749 Mtetra
.479 .695 .963 r
.83167 .58749 .83244 .58842 .83436 .58845 .83359 .58751 Mtetra
.404 .654 .96 r
.83359 .58751 .83436 .58845 .83631 .58868 .83553 .58774 Mtetra
.61 .754 .947 r
.83553 .58774 .83631 .58868 .8382 .58829 .83742 .58735 Mtetra
.867 .822 .802 r
.83742 .58735 .8382 .58829 .83993 .58621 .83916 .58527 Mtetra
.982 .746 .506 r
.83916 .58527 .83993 .58621 .84085 .5754 .84009 .57459 Mtetra
.978 .678 .361 r
.84009 .57459 .84085 .5754 .82419 .37675 .82345 .37574 Mtetra
.932 .792 .683 r
.82345 .37574 .82419 .37675 .82566 .37316 .82493 .37214 Mtetra
.723 .766 .886 r
.82493 .37214 .82566 .37316 .82739 .3723 .82666 .37128 Mtetra
.599 .716 .926 r
.82666 .37128 .82739 .3723 .82917 .37201 .82844 .37098 Mtetra
.599 .715 .926 r
.82844 .37098 .82917 .37201 .83096 .37172 .83023 .37069 Mtetra
.738 .77 .879 r
.83023 .37069 .83096 .37172 .83268 .37077 .83195 .36974 Mtetra
.655 .739 .911 r
.83195 .36974 .83268 .37077 .83445 .37025 .83372 .36921 Mtetra
.233 .51 .908 r
.83372 .36921 .83445 .37025 .83634 .37098 .83561 .36995 Mtetra
.882 .489 .032 r
.83561 .36995 .83634 .37098 .83885 .37805 .83812 .37702 Mtetra
.975 .667 .334 r
.83812 .37702 .83885 .37805 .86046 .57852 .85969 .57755 Mtetra
.658 .204 0 r
.85969 .57755 .86046 .57852 .86274 .58195 .86197 .58097 Mtetra
.381 .63 .952 r
.86197 .58097 .86274 .58195 .86472 .58227 .86395 .58129 Mtetra
.694 .781 .918 r
.86395 .58129 .86472 .58227 .86659 .58152 .86583 .58054 Mtetra
.874 .82 .791 r
.86583 .58054 .86659 .58152 .86831 .57931 .86755 .57833 Mtetra
.978 .766 .548 r
.86755 .57833 .86831 .57931 .86948 .57159 .86872 .57061 Mtetra
.977 .675 .347 r
.86872 .57061 .86948 .57159 .85078 .36935 .85006 .36831 Mtetra
.95 .786 .644 r
.85006 .36831 .85078 .36935 .85216 .36497 .85144 .36393 Mtetra
.746 .772 .874 r
.85144 .36393 .85216 .36497 .85389 .36397 .85317 .36293 Mtetra
.62 .723 .92 r
.85317 .36293 .85389 .36397 .85569 .36359 .85496 .36254 Mtetra
.589 .709 .926 r
.85496 .36254 .85569 .36359 .85749 .36333 .85677 .36228 Mtetra
.748 .773 .873 r
.85677 .36228 .85749 .36333 .85922 .36231 .8585 .36127 Mtetra
.674 .745 .904 r
.8585 .36127 .85922 .36231 .861 .3617 .86028 .36065 Mtetra
.377 .595 .931 r
.86028 .36065 .861 .3617 .86288 .3621 .86216 .36104 Mtetra
.805 .391 0 r
.86216 .36104 .86288 .3621 .86529 .36746 .86457 .3664 Mtetra
.973 .663 .318 r
.86457 .3664 .86529 .36746 .88879 .56929 .88804 .56828 Mtetra
.712 .272 0 r
.88804 .56828 .88879 .56929 .8912 .57341 .89045 .57241 Mtetra
.503 .693 .954 r
.89045 .57241 .8912 .57341 .89317 .57338 .89242 .57239 Mtetra
.694 .779 .917 r
.89242 .57239 .89317 .57338 .89506 .57263 .89431 .57163 Mtetra
.734 .793 .9 r
.89431 .57163 .89506 .57263 .89692 .57166 .89617 .57067 Mtetra
.496 .69 .954 r
.89617 .57067 .89692 .57166 .8989 .57166 .89815 .57067 Mtetra
.623 .752 .939 r
.89815 .57067 .8989 .57166 .90082 .57122 .90008 .57023 Mtetra
.809 .815 .855 r
.90008 .57023 .90082 .57122 .90263 .56973 .90189 .56874 Mtetra
.979 .774 .556 r
.90189 .56874 .90263 .56973 .90382 .56266 .90308 .56167 Mtetra
.976 .671 .329 r
.90308 .56167 .90382 .56266 .88296 .35973 .88225 .35869 Mtetra
.96 .784 .62 r
.88225 .35869 .88296 .35973 .88427 .35488 .88357 .35383 Mtetra
.743 .773 .877 r
.88357 .35383 .88427 .35488 .88602 .35389 .88531 .35284 Mtetra
.604 .716 .923 r
.88531 .35284 .88602 .35389 .88784 .35357 .88714 .35251 Mtetra
.517 .672 .934 r
.88714 .35251 .88784 .35357 .8897 .35356 .889 .3525 Mtetra
.654 .738 .911 r
.889 .3525 .8897 .35356 .89151 .35303 .8908 .35198 Mtetra
.661 .74 .909 r
.8908 .35198 .89151 .35303 .89331 .35248 .8926 .35142 Mtetra
.674 .745 .904 r
.8926 .35142 .89331 .35248 .8951 .35186 .89439 .35079 Mtetra
.764 .777 .864 r
.89439 .35079 .8951 .35186 .89683 .35073 .89613 .34966 Mtetra
.699 .754 .894 r
.89613 .34966 .89683 .35073 .89862 .34998 .89791 .34891 Mtetra
.505 .662 .932 r
.89791 .34891 .89862 .34998 .90049 .35002 .89979 .34894 Mtetra
.733 .316 0 r
.89979 .34894 .90049 .35002 .90293 .35482 .90222 .35369 Mtetra
.971 .656 .294 r
.90222 .35369 .90293 .35482 .92903 .55735 .92829 .55627 Mtetra
.728 .302 0 r
.92829 .55627 .92903 .55735 .9316 .56212 .93086 .56109 Mtetra
.487 .677 .95 r
.93086 .56109 .9316 .56212 .93361 .56216 .93287 .56114 Mtetra
.687 .774 .917 r
.93287 .56114 .93361 .56216 .93552 .56143 .93479 .5604 Mtetra
.76 .801 .885 r
.93479 .5604 .93552 .56143 .93739 .56027 .93666 .55926 Mtetra
.445 .692 .97 r
.31221 .73336 .3132 .73417 .31472 .73423 .31373 .73342 Mtetra
.61 .751 .945 r
.31373 .73342 .31472 .73423 .31627 .73391 .31528 .7331 Mtetra
.768 .78 .863 r
.31528 .7331 .31627 .73391 .31786 .73282 .31687 .73204 Mtetra
.913 .735 .648 r
.31687 .73204 .31786 .73282 .31976 .72659 .31875 .72611 Mtetra
.937 .687 .533 r
.31875 .72611 .31976 .72659 .33237 .53334 .33142 .53292 Mtetra
.926 .76 .656 r
.33142 .53292 .33237 .53334 .3341 .52841 .33316 .52777 Mtetra
.778 .809 .878 r
.33316 .52777 .3341 .52841 .3356 .52745 .33467 .52675 Mtetra
.601 .768 .959 r
.33467 .52675 .3356 .52745 .33706 .52721 .33613 .52646 Mtetra
.435 .69 .972 r
.33613 .52646 .33706 .52721 .3385 .52735 .33758 .52653 Mtetra
.637 .745 .927 r
.33758 .52653 .3385 .52735 .33997 .527 .33905 .52615 Mtetra
.651 .744 .917 r
.33905 .52615 .33997 .527 .34145 .52658 .34052 .52573 Mtetra
.658 .743 .913 r
.34052 .52573 .34145 .52658 .34292 .52614 .342 .52528 Mtetra
.754 .761 .858 r
.342 .52528 .34292 .52614 .34443 .52519 .34351 .52433 Mtetra
.706 .753 .889 r
.34351 .52433 .34443 .52519 .34592 .52454 .345 .52367 Mtetra
.507 .69 .95 r
.345 .52367 .34592 .52454 .34737 .52454 .34645 .52366 Mtetra
.925 .539 .232 r
.34645 .52366 .34737 .52454 .34861 .52864 .3477 .52753 Mtetra
.94 .683 .521 r
.3477 .52753 .34861 .52864 .34001 .72146 .33906 .72009 Mtetra
.947 .59 .265 r
.33906 .72009 .34001 .72146 .3413 .72652 .34033 .72544 Mtetra
.327 .567 .925 r
.34033 .72544 .3413 .72652 .34283 .72687 .34186 .72586 Mtetra
.673 .727 .89 r
.34186 .72586 .34283 .72687 .34441 .72625 .34343 .72531 Mtetra
.747 .755 .859 r
.34343 .72531 .34441 .72625 .34601 .72521 .34503 .72434 Mtetra
.524 .712 .957 r
.34503 .72434 .34601 .72521 .34757 .7251 .34659 .72426 Mtetra
.596 .743 .946 r
.34659 .72426 .34757 .7251 .34913 .72481 .34816 .72399 Mtetra
.753 .778 .874 r
.34816 .72399 .34913 .72481 .35074 .72383 .34976 .72302 Mtetra
.908 .744 .666 r
.34976 .72302 .35074 .72383 .35254 .71873 .35155 .71812 Mtetra
.941 .688 .526 r
.35155 .71812 .35254 .71873 .36345 .52469 .36251 .52435 Mtetra
.936 .757 .635 r
.36251 .52435 .36345 .52469 .3652 .51887 .36427 .51823 Mtetra
.818 .808 .842 r
.36427 .51823 .3652 .51887 .36673 .51758 .36581 .51687 Mtetra
.626 .775 .952 r
.36581 .51687 .36673 .51758 .36821 .51727 .36729 .51651 Mtetra
.459 .699 .971 r
.36729 .51651 .36821 .51727 .36968 .51737 .36876 .51654 Mtetra
.619 .741 .933 r
.36876 .51654 .36968 .51737 .37116 .51708 .37025 .51621 Mtetra
.654 .743 .915 r
.37025 .51621 .37116 .51708 .37266 .51665 .37174 .51578 Mtetra
.661 .742 .91 r
.37174 .51578 .37266 .51665 .37415 .51619 .37324 .51531 Mtetra
.748 .759 .861 r
.37324 .51531 .37415 .51619 .37567 .51528 .37476 .5144 Mtetra
.718 .753 .88 r
.37476 .5144 .37567 .51528 .37717 .51455 .37626 .51366 Mtetra
.56 .706 .939 r
.37626 .51366 .37717 .51455 .37866 .51443 .37775 .51352 Mtetra
.885 .457 .087 r
.37775 .51352 .37866 .51443 .37999 .51762 .37909 .51653 Mtetra
.944 .684 .513 r
.37909 .51653 .37999 .51762 .3732 .71042 .37227 .70873 Mtetra
.959 .619 .289 r
.37227 .70873 .3732 .71042 .3745 .7167 .37354 .71555 Mtetra
.148 .449 .88 r
.37354 .71555 .3745 .7167 .37604 .71737 .37508 .71631 Mtetra
.673 .718 .883 r
.37508 .71631 .37604 .71737 .37764 .71675 .37668 .71575 Mtetra
.754 .748 .847 r
.37668 .71575 .37764 .71675 .37926 .71563 .3783 .7147 Mtetra
.711 .754 .886 r
.3783 .7147 .37926 .71563 .38087 .71486 .3799 .71396 Mtetra
.678 .752 .907 r
.3799 .71396 .38087 .71486 .38246 .71429 .3815 .71339 Mtetra
.666 .75 .913 r
.3815 .71339 .38246 .71429 .38406 .71376 .3831 .71287 Mtetra
.631 .744 .929 r
.3831 .71287 .38406 .71376 .38566 .71329 .38469 .71248 Mtetra
.603 .755 .951 r
.38469 .71248 .38566 .71329 .38725 .71287 .38629 .71217 Mtetra
.582 .775 .971 r
.38629 .71217 .38725 .71287 .38885 .71251 .38788 .71188 Mtetra
.584 .797 .98 r
.38788 .71188 .38885 .71251 .39044 .71222 .38947 .71156 Mtetra
.597 .793 .974 r
.38947 .71156 .39044 .71222 .39203 .71196 .39107 .71122 Mtetra
.609 .775 .96 r
.39107 .71122 .39203 .71196 .39363 .7117 .39267 .71088 Mtetra
.619 .757 .944 r
.39267 .71088 .39363 .7117 .39522 .71145 .39426 .71052 Mtetra
.626 .733 .924 r
.39426 .71052 .39522 .71145 .39682 .71114 .39586 .71015 Mtetra
.625 .722 .916 r
.39586 .71015 .39682 .71114 .39842 .71068 .39747 .7098 Mtetra
.61 .739 .937 r
.39747 .7098 .39842 .71068 .40004 .70979 .39907 .70948 Mtetra
.487 .844 .993 r
.39907 .70948 .40004 .70979 .40168 .7086 .40067 .70917 Mtetra
.134 0 0 r
.40067 .70917 .40168 .7086 .40331 .70732 .40227 .70885 Mtetra
.385 0 .144 r
.40227 .70885 .40331 .70732 .40493 .7065 .40388 .70849 Mtetra
.421 .053 .231 r
.40388 .70849 .40493 .7065 .40654 .70608 .40548 .70808 Mtetra
.415 .048 .23 r
.40548 .70808 .40654 .70608 .40814 .70579 .40709 .70764 Mtetra
.39 .012 .196 r
.40709 .70764 .40814 .70579 .40974 .70544 .40871 .70716 Mtetra
.367 0 .165 r
.40871 .70716 .40974 .70544 .41135 .70503 .41032 .70665 Mtetra
.351 0 .139 r
.41032 .70665 .41135 .70503 .41296 .7046 .41193 .70613 Mtetra
.426 .022 .167 r
.41193 .70613 .41296 .7046 .41456 .70457 .41354 .70591 Mtetra
.397 0 .115 r
.41354 .70591 .41456 .70457 .41617 .70443 .41515 .70567 Mtetra
.185 0 0 r
.41515 .70567 .41617 .70443 .41779 .70358 .41677 .70494 Mtetra
.762 .904 .515 r
.41677 .70494 .41779 .70358 .41953 .69925 .41846 .70217 Mtetra
.989 .844 .473 r
.41846 .70217 .41953 .69925 .42683 .50557 .42034 .69283 Mtetra
0 0 .312 r
.42034 .69283 .42683 .50557 .42853 .49937 .42755 .50127 Mtetra
0 0 0 r
.42755 .50127 .42853 .49937 .43009 .49747 .42915 .49852 Mtetra
.153 0 0 r
.42915 .49852 .43009 .49747 .43163 .49686 .43068 .49786 Mtetra
.399 0 .045 r
.43068 .49786 .43163 .49686 .43315 .49664 .4322 .49776 Mtetra
.368 0 .059 r
.4322 .49776 .43315 .49664 .43467 .49632 .43372 .49752 Mtetra
.293 0 .034 r
.43372 .49752 .43467 .49632 .4362 .49583 .43525 .49704 Mtetra
.298 0 .038 r
.43525 .49704 .4362 .49583 .43773 .49535 .43679 .49657 Mtetra
.294 0 .039 r
.43679 .49657 .43773 .49535 .43926 .49487 .43832 .49609 Mtetra
.29 0 .037 r
.43832 .49609 .43926 .49487 .44079 .49438 .43985 .4956 Mtetra
.29 0 .036 r
.43985 .4956 .44079 .49438 .44233 .49389 .44139 .4951 Mtetra
.293 0 .036 r
.44139 .4951 .44233 .49389 .44386 .4934 .44292 .49462 Mtetra
.297 0 .04 r
.44292 .49462 .44386 .4934 .4454 .49292 .44446 .49414 Mtetra
.302 0 .044 r
.44446 .49414 .4454 .49292 .44693 .49245 .446 .49368 Mtetra
.338 0 .068 r
.446 .49368 .44693 .49245 .44847 .49197 .44753 .49329 Mtetra
.362 0 .104 r
.44753 .49329 .44847 .49197 .45001 .49151 .44907 .49294 Mtetra
.329 0 .107 r
.44907 .49294 .45001 .49151 .45154 .49107 .45061 .49243 Mtetra
.12 0 0 r
.45061 .49243 .45154 .49107 .45308 .49066 .45216 .49145 Mtetra
0 0 0 r
.45216 .49145 .45308 .49066 .45462 .49029 .45372 .49019 Mtetra
.801 .958 .915 r
.45372 .49019 .45462 .49029 .45616 .48991 .45527 .48904 Mtetra
.73 .764 .88 r
.45527 .48904 .45616 .48991 .4577 .4895 .45682 .48823 Mtetra
.66 .67 .849 r
.45682 .48823 .4577 .4895 .45924 .48906 .45837 .48773 Mtetra
.642 .655 .848 r
.45837 .48773 .45924 .48906 .46078 .48859 .45991 .48732 Mtetra
.646 .667 .856 r
.45991 .48732 .46078 .48859 .46233 .48811 .46145 .48689 Mtetra
.658 .68 .859 r
.46145 .48689 .46233 .48811 .46387 .48762 .463 .48641 Mtetra
.659 .68 .859 r
.463 .48641 .46387 .48762 .46542 .48711 .46455 .48592 Mtetra
.661 .684 .861 r
.46455 .48592 .46542 .48711 .46697 .48656 .4661 .48542 Mtetra
.664 .695 .869 r
.4661 .48542 .46697 .48656 .46852 .48597 .46765 .48491 Mtetra
.665 .711 .882 r
.46765 .48491 .46852 .48597 .47007 .48538 .4692 .4844 Mtetra
.666 .729 .896 r
.4692 .4844 .47007 .48538 .47162 .48482 .47075 .4839 Mtetra
.665 .74 .906 r
.47075 .4839 .47162 .48482 .47317 .48431 .4723 .4834 Mtetra
.661 .742 .91 r
.4723 .4834 .47317 .48431 .47473 .48381 .47385 .48291 Mtetra
.652 .742 .916 r
.47385 .48291 .47473 .48381 .47628 .48331 .4754 .48246 Mtetra
.64 .75 .928 r
.4754 .48246 .47628 .48331 .47783 .48281 .47696 .48205 Mtetra
.637 .771 .944 r
.47696 .48205 .47783 .48281 .47939 .48232 .47851 .48164 Mtetra
.642 .795 .956 r
.47851 .48164 .47939 .48232 .48094 .48177 .48006 .4812 Mtetra
.65 .824 .967 r
.48006 .4812 .48094 .48177 .4825 .4812 .48162 .4807 Mtetra
.652 .848 .975 r
.48162 .4807 .4825 .4812 .48406 .48072 .48318 .48018 Mtetra
.669 .841 .965 r
.48318 .48018 .48406 .48072 .48561 .48052 .48474 .47962 Mtetra
.687 .752 .901 r
.48474 .47962 .48561 .48052 .48716 .48069 .4863 .47902 Mtetra
.664 .622 .797 r
.4863 .47902 .48716 .48069 .48871 .48099 .48786 .47842 Mtetra
.638 .542 .73 r
.48786 .47842 .48871 .48099 .49027 .48104 .48942 .47783 Mtetra
.624 .507 .7 r
.48942 .47783 .49027 .48104 .49183 .48056 .49099 .47729 Mtetra
.621 .503 .698 r
.49099 .47729 .49183 .48056 .4934 .47993 .49255 .47676 Mtetra
.635 .515 .7 r
.49255 .47676 .4934 .47993 .49496 .47908 .49411 .47608 Mtetra
.648 .53 .706 r
.49411 .47608 .49496 .47908 .49653 .47816 .49568 .4753 Mtetra
.615 .515 .718 r
.49568 .4753 .49653 .47816 .4981 .47781 .49725 .4749 Mtetra
.447 .409 .723 r
.49725 .4749 .4981 .47781 .49965 .47947 .4988 .47575 Mtetra
0 0 .383 r
.4988 .47575 .49965 .47947 .49984 .67092 .50033 .4808 Mtetra
0 0 .361 r
.50033 .4808 .49984 .67092 .50144 .67987 .50054 .67511 Mtetra
.149 .149 .602 r
.50054 .67511 .50144 .67987 .50309 .68187 .50218 .67869 Mtetra
.586 .492 .715 r
.50218 .67869 .50309 .68187 .50475 .68176 .50385 .67854 Mtetra
.641 .525 .705 r
.50385 .67854 .50475 .68176 .50642 .68115 .50552 .67778 Mtetra
.618 .505 .703 r
.50552 .67778 .50642 .68115 .5081 .68041 .50719 .67727 Mtetra
.529 .458 .721 r
.50719 .67727 .5081 .68041 .50977 .67985 .50886 .67762 Mtetra
.52 .508 .782 r
.50886 .67762 .50977 .67985 .51144 .67926 .51052 .67789 Mtetra
.547 .622 .879 r
.51052 .67789 .51144 .67926 .51311 .67874 .5122 .67787 Mtetra
.63 .758 .94 r
.5122 .67787 .51311 .67874 .51479 .67832 .51387 .67746 Mtetra
.656 .767 .931 r
.51387 .67746 .51479 .67832 .51646 .67784 .51555 .67695 Mtetra
.652 .759 .928 r
.51555 .67695 .51646 .67784 .51814 .67711 .51722 .67646 Mtetra
.597 .803 .979 r
.51722 .67646 .51814 .67711 .51982 .67592 .5189 .67609 Mtetra
.185 .715 .729 r
.5189 .67609 .51982 .67592 .52149 .67461 .52058 .67572 Mtetra
.305 0 0 r
.52058 .67572 .52149 .67461 .52317 .67346 .52226 .67532 Mtetra
.406 .03 .208 r
.52226 .67532 .52317 .67346 .52485 .67289 .52394 .67488 Mtetra
.413 .046 .228 r
.52394 .67488 .52485 .67289 .52653 .67251 .52562 .67442 Mtetra
.404 .031 .213 r
.52562 .67442 .52653 .67251 .52821 .67216 .52731 .67395 Mtetra
.392 .01 .19 r
.52731 .67395 .52821 .67216 .5299 .67169 .52899 .67348 Mtetra
.388 .006 .188 r
.52899 .67348 .5299 .67169 .53158 .67121 .53068 .67299 Mtetra
.379 0 .182 r
.53068 .67299 .53158 .67121 .53326 .67072 .53236 .67247 Mtetra
.362 0 .168 r
.53236 .67247 .53326 .67072 .53495 .67022 .53405 .6719 Mtetra
.35 0 .151 r
.53405 .6719 .53495 .67022 .53663 .66971 .53574 .67132 Mtetra
.345 0 .136 r
.53574 .67132 .53663 .66971 .53832 .6692 .53742 .67075 Mtetra
.351 0 .129 r
.53742 .67075 .53832 .6692 .54001 .66869 .53911 .67024 Mtetra
.355 0 .13 r
.53911 .67024 .54001 .66869 .5417 .66819 .54081 .66974 Mtetra
.358 0 .133 r
.54081 .66974 .5417 .66819 .54339 .6677 .5425 .66926 Mtetra
.359 0 .135 r
.5425 .66926 .54339 .6677 .54508 .6672 .54419 .66877 Mtetra
.361 0 .136 r
.54419 .66877 .54508 .6672 .54677 .66671 .54588 .66828 Mtetra
.362 0 .137 r
.54588 .66828 .54677 .66671 .54846 .66623 .54758 .6678 Mtetra
.363 0 .138 r
.54758 .6678 .54846 .66623 .55016 .66575 .54928 .66732 Mtetra
.365 0 .139 r
.54928 .66732 .55016 .66575 .55185 .66528 .55097 .66684 Mtetra
.366 0 .139 r
.55097 .66684 .55185 .66528 .55355 .66481 .55267 .66637 Mtetra
.367 0 .14 r
.55267 .66637 .55355 .66481 .55525 .66434 .55437 .6659 Mtetra
.368 0 .14 r
.55437 .6659 .55525 .66434 .55695 .66388 .55607 .66544 Mtetra
.368 0 .139 r
.55607 .66544 .55695 .66388 .55865 .66343 .55777 .66498 Mtetra
.367 0 .138 r
.55777 .66498 .55865 .66343 .56035 .66298 .55948 .66452 Mtetra
.369 0 .137 r
.55948 .66452 .56035 .66298 .56205 .66253 .56118 .66407 Mtetra
.375 0 .139 r
.56118 .66407 .56205 .66253 .56375 .66209 .56289 .66364 Mtetra
.392 0 .151 r
.56289 .66364 .56375 .66209 .56546 .66166 .56459 .66328 Mtetra
.401 .004 .167 r
.56459 .66328 .56546 .66166 .56716 .66122 .5663 .66291 Mtetra
.404 .013 .18 r
.5663 .66291 .56716 .66122 .56887 .66078 .56801 .66253 Mtetra
.396 .01 .185 r
.56801 .66253 .56887 .66078 .57058 .66033 .56972 .66208 Mtetra
.392 .007 .184 r
.56972 .66208 .57058 .66033 .57229 .65988 .57143 .66162 Mtetra
.389 .004 .182 r
.57143 .66162 .57229 .65988 .574 .65942 .57314 .66115 Mtetra
.389 .002 .18 r
.57314 .66115 .574 .65942 .57571 .65895 .57485 .66068 Mtetra
.387 .001 .179 r
.57485 .66068 .57571 .65895 .57742 .65848 .57657 .66021 Mtetra
.386 0 .178 r
.57657 .66021 .57742 .65848 .57913 .658 .57828 .65973 Mtetra
.386 0 .179 r
.57828 .65973 .57913 .658 .58084 .65751 .58 .65925 Mtetra
.386 .001 .18 r
.58 .65925 .58084 .65751 .58256 .65702 .58171 .65877 Mtetra
.386 .002 .182 r
.58171 .65877 .58256 .65702 .58427 .65651 .58343 .65828 Mtetra
.39 .006 .186 r
.58343 .65828 .58427 .65651 .58599 .65588 .58515 .6578 Mtetra
.402 .03 .214 r
.58515 .6578 .58599 .65588 .5877 .65536 .58687 .6573 Mtetra
.401 .031 .216 r
.58687 .6573 .5877 .65536 .58943 .65509 .58859 .65679 Mtetra
.381 0 .171 r
.58859 .65679 .58943 .65509 .59116 .65545 .59031 .6563 Mtetra
.152 0 0 r
.59031 .6563 .59116 .65545 .5929 .65578 .59203 .65573 Mtetra
.557 .926 .933 r
.59203 .65573 .5929 .65578 .59464 .65595 .59375 .65503 Mtetra
.769 .786 .867 r
.59375 .65503 .59464 .65595 .59636 .65569 .59546 .65389 Mtetra
.733 .655 .773 r
.59546 .65389 .59636 .65569 .59809 .65529 .59717 .65261 Mtetra
.694 .579 .722 r
.59717 .65261 .59809 .65529 .59982 .65479 .59888 .65134 Mtetra
.578 .479 .706 r
.59888 .65134 .59982 .65479 .60155 .65463 .60062 .65127 Mtetra
.605 .499 .707 r
.60062 .65127 .60155 .65463 .60328 .65413 .60235 .6509 Mtetra
.673 .545 .701 r
.60235 .6509 .60328 .65413 .60499 .653 .60406 .6497 Mtetra
.877 .655 .598 r
.60406 .6497 .60499 .653 .60663 .64856 .6056 .64095 Mtetra
.958 .681 .469 r
.6056 .64095 .60663 .64856 .60369 .45401 .60269 .44554 Mtetra
.694 .489 .606 r
.60269 .44554 .60369 .45401 .60511 .44452 .60422 .44128 Mtetra
.661 .531 .695 r
.60422 .44128 .60511 .44452 .60672 .44333 .60584 .44024 Mtetra
.615 .509 .709 r
.60584 .44024 .60672 .44333 .60835 .44294 .60747 .43979 Mtetra
.584 .487 .71 r
.60747 .43979 .60835 .44294 .60999 .44284 .60911 .43966 Mtetra
.611 .503 .706 r
.60911 .43966 .60999 .44284 .6116 .44155 .61074 .43925 Mtetra
.623 .553 .755 r
.61074 .43925 .6116 .44155 .61322 .44029 .61238 .43883 Mtetra
.641 .645 .838 r
.61238 .43883 .61322 .44029 .61483 .43919 .61402 .43839 Mtetra
.693 .79 .925 r
.61402 .43839 .61483 .43919 .61647 .43861 .61565 .43775 Mtetra
.687 .77 .915 r
.61565 .43775 .61647 .43861 .6181 .43818 .61728 .43713 Mtetra
.66 .72 .893 r
.61728 .43713 .6181 .43818 .61974 .43779 .61892 .43662 Mtetra
.533 .643 .904 r
.61892 .43662 .61974 .43779 .62138 .4372 .62057 .43662 Mtetra
.294 .674 .974 r
.62057 .43662 .62138 .4372 .62301 .43656 .62223 .4368 Mtetra
.319 0 0 r
.62223 .4368 .62301 .43656 .62464 .43593 .62389 .43703 Mtetra
.113 0 0 r
.62389 .43703 .62464 .43593 .62627 .43501 .62552 .43615 Mtetra
.191 0 0 r
.62552 .43615 .62627 .43501 .62791 .43435 .62715 .4354 Mtetra
.424 0 .071 r
.62715 .4354 .62791 .43435 .62956 .43423 .62881 .43536 Mtetra
.874 .515 .365 r
.62881 .43536 .62956 .43423 .6313 .43669 .63065 .44092 Mtetra
.962 .676 .445 r
.63065 .44092 .6313 .43669 .63916 .6237 .63878 .63715 Mtetra
.637 .382 .515 r
.63878 .63715 .63916 .6237 .64146 .63953 .64068 .64126 Mtetra
.53 .139 .243 r
.64068 .64126 .64146 .63953 .64328 .64105 .64246 .64152 Mtetra
0 0 0 r
.64246 .64152 .64328 .64105 .64506 .64132 .64421 .6409 Mtetra
.752 .909 .945 r
.64421 .6409 .64506 .64132 .64682 .64108 .64595 .6399 Mtetra
.669 .714 .882 r
.64595 .6399 .64682 .64108 .64858 .64081 .6477 .6393 Mtetra
.646 .654 .843 r
.6477 .6393 .64858 .64081 .65034 .64035 .64946 .63881 Mtetra
.64 .647 .841 r
.64946 .63881 .65034 .64035 .6521 .63967 .65122 .63835 Mtetra
.539 .633 .893 r
.65122 .63835 .6521 .63967 .65385 .63898 .653 .63834 Mtetra
.523 .785 .992 r
.653 .63834 .65385 .63898 .65559 .63792 .65477 .63812 Mtetra
.439 .873 .79 r
.65477 .63812 .65559 .63792 .6573 .63604 .65652 .6373 Mtetra
.8 .875 .441 r
.65652 .6373 .6573 .63604 .6588 .62881 .65817 .63374 Mtetra
.953 .757 .301 r
.65817 .63374 .6588 .62881 .65282 .43164 .65922 .61503 Mtetra
.015 0 .417 r
.65922 .61503 .65282 .43164 .65432 .427 .65361 .42851 Mtetra
0 0 0 r
.65361 .42851 .65432 .427 .65594 .42569 .65519 .42601 Mtetra
.595 .935 .748 r
.65519 .42601 .65594 .42569 .65761 .42528 .65682 .42481 Mtetra
.693 .882 .968 r
.65682 .42481 .65761 .42528 .65928 .42523 .65847 .4241 Mtetra
.662 .709 .883 r
.65847 .4241 .65928 .42523 .66095 .42488 .66013 .42357 Mtetra
.633 .666 .864 r
.66013 .42357 .66095 .42488 .66261 .42441 .6618 .42318 Mtetra
.617 .673 .881 r
.6618 .42318 .66261 .42441 .66428 .42389 .66347 .42286 Mtetra
.65 .725 .903 r
.66347 .42286 .66428 .42389 .66593 .42321 .66514 .42239 Mtetra
.667 .781 .935 r
.66514 .42239 .66593 .42321 .66759 .42252 .6668 .42184 Mtetra
.67 .819 .955 r
.6668 .42184 .66759 .42252 .66925 .42195 .66846 .42126 Mtetra
.756 .834 .911 r
.66846 .42126 .66925 .42195 .67092 .42153 .67011 .4203 Mtetra
.709 .709 .849 r
.67011 .4203 .67092 .42153 .67261 .42149 .67177 .4195 Mtetra
.609 .571 .787 r
.67177 .4195 .67261 .42149 .67434 .4222 .67345 .41922 Mtetra
.252 .284 .701 r
.67345 .41922 .67434 .4222 .67628 .4276 .67523 .42125 Mtetra
.775 .532 0 r
.67523 .42125 .67628 .4276 .68726 .62458 .67769 .43737 Mtetra
.041 0 .437 r
.67769 .43737 .68726 .62458 .68926 .62876 .68828 .62497 Mtetra
.353 .325 .688 r
.68828 .62497 .68926 .62876 .6911 .62947 .69018 .62691 Mtetra
.523 .491 .762 r
.69018 .62691 .6911 .62947 .69289 .62907 .69201 .62723 Mtetra
.595 .592 .818 r
.69201 .62723 .69289 .62907 .69466 .62816 .69381 .62703 Mtetra
.541 .673 .923 r
.69381 .62703 .69466 .62816 .69643 .62736 .69562 .62695 Mtetra
.48 .832 .996 r
.69562 .62695 .69643 .62736 .69819 .62635 .69742 .62665 Mtetra
.39 .832 .705 r
.69742 .62665 .69819 .62635 .69992 .62461 .69919 .62575 Mtetra
.712 .85 .422 r
.69919 .62575 .69992 .62461 .70145 .61909 .70085 .62271 Mtetra
.798 .715 .18 r
.70085 .62271 .70145 .61909 .69296 .42034 .70217 .61309 Mtetra
.036 0 .43 r
.70217 .61309 .69296 .42034 .69438 .41471 .69374 .41666 Mtetra
0 0 0 r
.69374 .41666 .69438 .41471 .696 .41302 .69528 .41349 Mtetra
.539 .881 .633 r
.69528 .41349 .696 .41302 .69768 .4125 .69692 .41213 Mtetra
.71 .918 .965 r
.69692 .41213 .69768 .4125 .69938 .41237 .69859 .41131 Mtetra
.686 .733 .887 r
.69859 .41131 .69938 .41237 .70108 .41205 .70027 .41066 Mtetra
.657 .666 .847 r
.70027 .41066 .70108 .41205 .70276 .41154 .70195 .41013 Mtetra
.639 .655 .85 r
.70195 .41013 .70276 .41154 .70445 .411 .70365 .4097 Mtetra
.644 .675 .865 r
.70365 .4097 .70445 .411 .70613 .41032 .70534 .40925 Mtetra
.651 .72 .899 r
.70534 .40925 .70613 .41032 .70781 .40962 .70703 .40877 Mtetra
.652 .77 .936 r
.70703 .40877 .70781 .40962 .70949 .40903 .70872 .40827 Mtetra
.732 .816 .917 r
.70872 .40827 .70949 .40903 .71119 .40859 .71039 .40742 Mtetra
.715 .725 .858 r
.71039 .40742 .71119 .40859 .7129 .40847 .71207 .40658 Mtetra
.622 .589 .796 r
.71207 .40658 .7129 .40847 .71466 .40903 .71377 .40622 Mtetra
.322 .34 .724 r
.71377 .40622 .71466 .40903 .71662 .41297 .71559 .40784 Mtetra
0 0 .332 r
.71559 .40784 .71662 .41297 .73019 .61112 .71786 .41697 Mtetra
.061 0 .449 r
.71786 .41697 .73019 .61112 .73234 .61622 .73132 .61213 Mtetra
.385 .338 .682 r
.73132 .61213 .73234 .61622 .73424 .61729 .73328 .614 Mtetra
.608 .507 .713 r
.73328 .614 .73424 .61729 .73607 .61699 .7351 .6136 Mtetra
.645 .526 .703 r
.7351 .6136 .73607 .61699 .73787 .61624 .73688 .61272 Mtetra
.59 .487 .705 r
.73688 .61272 .73787 .61624 .73967 .61559 .73872 .6125 Mtetra
.535 .471 .731 r
.73872 .6125 .73967 .61559 .74148 .61503 .74058 .61282 Mtetra
.531 .523 .791 r
.74058 .61282 .74148 .61503 .74329 .61435 .74245 .61304 Mtetra
.566 .652 .894 r
.74245 .61304 .74329 .61435 .74507 .61335 .74429 .61292 Mtetra
.528 .85 .998 r
.74429 .61292 .74507 .61335 .74684 .61204 .74612 .61252 Mtetra
.03 0 0 r
.74612 .61252 .74684 .61204 .7486 .61064 .74794 .61203 Mtetra
.344 0 .098 r
.74794 .61203 .7486 .61064 .75039 .60961 .74976 .61153 Mtetra
.409 .037 .218 r
.74976 .61153 .75039 .60961 .75221 .60905 .75158 .61104 Mtetra
.41 .043 .227 r
.75158 .61104 .75221 .60905 .75403 .60865 .75341 .61051 Mtetra
.392 .017 .203 r
.75341 .61051 .75403 .60865 .75586 .60824 .75523 .60996 Mtetra
.371 0 .173 r
.75523 .60996 .75586 .60824 .75769 .60776 .75705 .60938 Mtetra
.356 0 .149 r
.75705 .60938 .75769 .60776 .75952 .60727 .75888 .60879 Mtetra
.404 0 .149 r
.75888 .60879 .75952 .60727 .76137 .60712 .76072 .60846 Mtetra
.399 0 .11 r
.76072 .60846 .76137 .60712 .76322 .60699 .76256 .6082 Mtetra
.24 0 .006 r
.76256 .6082 .76322 .60699 .76503 .60617 .76438 .60748 Mtetra
0 0 0 r
.76438 .60748 .76503 .60617 .76663 .60241 .76608 .60503 Mtetra
.786 .728 .198 r
.76608 .60503 .76663 .60241 .75432 .4031 .7674 .59739 Mtetra
.064 0 .447 r
.7674 .59739 .75432 .4031 .75555 .39565 .75502 .39793 Mtetra
0 0 0 r
.75502 .39793 .75555 .39565 .75712 .39312 .75647 .39361 Mtetra
.67 .924 .619 r
.75647 .39361 .75712 .39312 .75881 .39216 .7581 .39183 Mtetra
.659 .919 .977 r
.7581 .39183 .75881 .39216 .76056 .39204 .7598 .3911 Mtetra
0 .322 .804 r
.7598 .3911 .76056 .39204 .76244 .39368 .76165 .39231 Mtetra
.913 .544 .105 r
.76165 .39231 .76244 .39368 .76499 .4042 .76404 .40071 Mtetra
.977 .677 .366 r
.76404 .40071 .76499 .4042 .78146 .6004 .78065 .59924 Mtetra
0 0 .524 r
.78065 .59924 .78146 .6004 .78351 .6027 .78271 .60175 Mtetra
.561 .726 .952 r
.78271 .60175 .78351 .6027 .78538 .60248 .78458 .60154 Mtetra
.709 .787 .913 r
.78458 .60154 .78538 .60248 .7872 .60167 .7864 .60074 Mtetra
.637 .763 .939 r
.7864 .60074 .7872 .60167 .78905 .60119 .78825 .60025 Mtetra
.489 .696 .96 r
.78825 .60025 .78905 .60119 .79094 .6012 .79014 .60025 Mtetra
.654 .768 .933 r
.79014 .60025 .79094 .6012 .79278 .60065 .79199 .5997 Mtetra
.887 .812 .769 r
.79199 .5997 .79278 .60065 .79448 .59819 .79368 .59723 Mtetra
.977 .743 .516 r
.79368 .59723 .79448 .59819 .79551 .58736 .79472 .58638 Mtetra
.977 .682 .384 r
.79472 .58638 .79551 .58736 .78153 .38884 .78078 .38781 Mtetra
.918 .786 .701 r
.78078 .38781 .78153 .38884 .78304 .38554 .78229 .38451 Mtetra
.722 .761 .884 r
.78229 .38451 .78304 .38554 .78475 .38469 .784 .38366 Mtetra
.603 .714 .923 r
.784 .38366 .78475 .38469 .78651 .38439 .78575 .38336 Mtetra
.648 .733 .911 r
.78575 .38336 .78651 .38439 .78825 .38391 .7875 .38287 Mtetra
.74 .765 .873 r
.7875 .38287 .78825 .38391 .78995 .38295 .7892 .38191 Mtetra
.654 .734 .908 r
.7892 .38191 .78995 .38295 .79169 .38244 .79094 .3814 Mtetra
.108 .426 .87 r
.79094 .3814 .79169 .38244 .79356 .38343 .79281 .38238 Mtetra
.897 .508 .07 r
.79281 .38238 .79356 .38343 .79595 .39059 .79519 .38946 Mtetra
.976 .672 .357 r
.79519 .38946 .79595 .39059 .81467 .58992 .81388 .58892 Mtetra
.59 .131 0 r
.81388 .58892 .81467 .58992 .81682 .59278 .81603 .59179 Mtetra
.604 .741 .941 r
.81603 .59179 .81682 .59278 .8187 .59242 .81791 .59144 Mtetra
.757 .796 .885 r
.81791 .59144 .8187 .59242 .82051 .59132 .81973 .59035 Mtetra
.779 .803 .872 r
.81973 .59035 .82051 .59132 .82232 .59006 .82153 .5891 Mtetra
.705 .785 .913 r
.82153 .5891 .82232 .59006 .82416 .58924 .82338 .5883 Mtetra
.69 .785 .923 r
.82338 .5883 .82416 .58924 .82601 .58849 .82523 .58758 Mtetra
.646 .775 .942 r
.82523 .58758 .82601 .58849 .82787 .58794 .8271 .58705 Mtetra
.571 .748 .96 r
.8271 .58705 .82787 .58794 .82977 .58768 .82899 .58678 Mtetra
.548 .737 .963 r
.82899 .58678 .82977 .58768 .83167 .58749 .8309 .58658 Mtetra
.478 .7 .966 r
.8309 .58658 .83167 .58749 .83359 .58751 .83282 .58659 Mtetra
.402 .657 .962 r
.83282 .58659 .83359 .58751 .83553 .58774 .83476 .58681 Mtetra
.609 .758 .95 r
.83476 .58681 .83553 .58774 .83742 .58735 .83665 .58642 Mtetra
.867 .825 .804 r
.83665 .58642 .83742 .58735 .83916 .58527 .83839 .58435 Mtetra
.982 .748 .507 r
.83839 .58435 .83916 .58527 .84009 .57459 .83934 .57386 Mtetra
.978 .679 .361 r
.83934 .57386 .84009 .57459 .82345 .37574 .82272 .37474 Mtetra
.934 .794 .682 r
.82272 .37474 .82345 .37574 .82493 .37214 .82419 .37112 Mtetra
.724 .767 .887 r
.82419 .37112 .82493 .37214 .82666 .37128 .82592 .37025 Mtetra
.599 .716 .926 r
.82592 .37025 .82666 .37128 .82844 .37098 .82771 .36996 Mtetra
.82771 .36996 .82844 .37098 .83023 .37069 .82949 .36966 Mtetra
.739 .771 .879 r
.82949 .36966 .83023 .37069 .83195 .36974 .83122 .36871 Mtetra
.656 .739 .911 r
.83122 .36871 .83195 .36974 .83372 .36921 .83299 .36818 Mtetra
.233 .51 .908 r
.83299 .36818 .83372 .36921 .83561 .36995 .83488 .36891 Mtetra
.882 .489 .033 r
.83488 .36891 .83561 .36995 .83812 .37702 .83739 .376 Mtetra
.975 .667 .334 r
.83739 .376 .83812 .37702 .85969 .57755 .85893 .57657 Mtetra
.657 .204 0 r
.85893 .57657 .85969 .57755 .86197 .58097 .86121 .57999 Mtetra
.382 .63 .952 r
.86121 .57999 .86197 .58097 .86395 .58129 .86319 .5803 Mtetra
.694 .78 .918 r
.86319 .5803 .86395 .58129 .86583 .58054 .86506 .57956 Mtetra
.874 .82 .791 r
.86506 .57956 .86583 .58054 .86755 .57833 .86679 .57735 Mtetra
.978 .766 .548 r
.86679 .57735 .86755 .57833 .86872 .57061 .86796 .56963 Mtetra
.977 .675 .347 r
.86796 .56963 .86872 .57061 .85006 .36831 .84933 .36727 Mtetra
.949 .785 .644 r
.84933 .36727 .85006 .36831 .85144 .36393 .85072 .36289 Mtetra
.746 .772 .874 r
.85072 .36289 .85144 .36393 .85317 .36293 .85245 .36188 Mtetra
.621 .723 .92 r
.85245 .36188 .85317 .36293 .85496 .36254 .85424 .3615 Mtetra
.59 .709 .926 r
.85424 .3615 .85496 .36254 .85677 .36228 .85605 .36124 Mtetra
.748 .772 .873 r
.85605 .36124 .85677 .36228 .8585 .36127 .85778 .36022 Mtetra
.674 .745 .904 r
.85778 .36022 .8585 .36127 .86028 .36065 .85956 .3596 Mtetra
.378 .595 .931 r
.85956 .3596 .86028 .36065 .86216 .36104 .86144 .35999 Mtetra
.804 .39 0 r
.86144 .35999 .86216 .36104 .86457 .3664 .86385 .36533 Mtetra
.973 .663 .318 r
.86385 .36533 .86457 .3664 .88804 .56828 .88729 .56727 Mtetra
.714 .273 0 r
.88729 .56727 .88804 .56828 .89045 .57241 .8897 .57141 Mtetra
.503 .693 .954 r
.8897 .57141 .89045 .57241 .89242 .57239 .89167 .57139 Mtetra
.693 .779 .917 r
.89167 .57139 .89242 .57239 .89431 .57163 .89356 .57064 Mtetra
.733 .793 .9 r
.89356 .57064 .89431 .57163 .89617 .57067 .89542 .56967 Mtetra
.495 .689 .954 r
.89542 .56967 .89617 .57067 .89815 .57067 .8974 .56967 Mtetra
.623 .751 .939 r
.8974 .56967 .89815 .57067 .90008 .57023 .89933 .56923 Mtetra
.808 .814 .855 r
.89933 .56923 .90008 .57023 .90189 .56874 .90114 .56775 Mtetra
.979 .774 .557 r
.90114 .56775 .90189 .56874 .90308 .56167 .90234 .56068 Mtetra
.976 .671 .329 r
.90234 .56068 .90308 .56167 .88225 .35869 .88154 .35763 Mtetra
.96 .784 .62 r
.88154 .35763 .88225 .35869 .88357 .35383 .88286 .35278 Mtetra
.743 .772 .876 r
.88286 .35278 .88357 .35383 .88531 .35284 .8846 .35178 Mtetra
.605 .716 .923 r
.8846 .35178 .88531 .35284 .88714 .35251 .88643 .35146 Mtetra
.517 .672 .934 r
.88643 .35146 .88714 .35251 .889 .3525 .88829 .35145 Mtetra
.654 .737 .911 r
.88829 .35145 .889 .3525 .8908 .35198 .89009 .35092 Mtetra
.661 .74 .909 r
.89009 .35092 .8908 .35198 .8926 .35142 .89189 .35036 Mtetra
.675 .745 .904 r
.89189 .35036 .8926 .35142 .89439 .35079 .89369 .34973 Mtetra
.765 .778 .864 r
.89369 .34973 .89439 .35079 .89613 .34966 .89543 .34859 Mtetra
.7 .755 .895 r
.89543 .34859 .89613 .34966 .89791 .34891 .89721 .34784 Mtetra
.506 .664 .933 r
.89721 .34784 .89791 .34891 .89979 .34894 .89908 .34787 Mtetra
.733 .314 0 r
.89908 .34787 .89979 .34894 .90222 .35369 .90152 .35259 Mtetra
.971 .656 .295 r
.90152 .35259 .90222 .35369 .92829 .55627 .92755 .55522 Mtetra
.735 .309 0 r
.92755 .55522 .92829 .55627 .93086 .56109 .93013 .56006 Mtetra
.483 .678 .951 r
.93013 .56006 .93086 .56109 .93287 .56114 .93214 .56012 Mtetra
.686 .775 .919 r
.93214 .56012 .93287 .56114 .93479 .5604 .93406 .55939 Mtetra
.76 .802 .887 r
.93406 .55939 .93479 .5604 .93666 .55926 .93593 .55825 Mtetra
.443 .691 .971 r
.31122 .73255 .31221 .73336 .31373 .73342 .31274 .73262 Mtetra
.609 .753 .947 r
.31274 .73262 .31373 .73342 .31528 .7331 .31429 .7323 Mtetra
.768 .781 .864 r
.31429 .7323 .31528 .7331 .31687 .73204 .31588 .73124 Mtetra
.912 .734 .648 r
.31588 .73124 .31687 .73204 .31875 .72611 .31776 .72532 Mtetra
.937 .686 .534 r
.31776 .72532 .31875 .72611 .33142 .53292 .33049 .53206 Mtetra
.904 .731 .656 r
.33049 .53206 .33142 .53292 .33316 .52777 .33224 .52691 Mtetra
.763 .758 .849 r
.33224 .52691 .33316 .52777 .33467 .52675 .33374 .52589 Mtetra
.612 .728 .928 r
.33374 .52589 .33467 .52675 .33613 .52646 .33521 .5256 Mtetra
.459 .672 .956 r
.33521 .5256 .33613 .52646 .33758 .52653 .33665 .52568 Mtetra
.638 .738 .921 r
.33665 .52568 .33758 .52653 .33905 .52615 .33812 .5253 Mtetra
.652 .742 .916 r
.33812 .5253 .33905 .52615 .34052 .52573 .3396 .52487 Mtetra
.659 .743 .912 r
.3396 .52487 .34052 .52573 .342 .52528 .34108 .52442 Mtetra
.755 .76 .857 r
.34108 .52442 .342 .52528 .34351 .52433 .34258 .52346 Mtetra
.707 .752 .887 r
.34258 .52346 .34351 .52433 .345 .52367 .34407 .5228 Mtetra
.509 .69 .949 r
.34407 .5228 .345 .52367 .34645 .52366 .34553 .52278 Mtetra
.924 .539 .234 r
.34553 .52278 .34645 .52366 .3477 .52753 .34678 .52665 Mtetra
.94 .683 .521 r
.34678 .52665 .3477 .52753 .33906 .72009 .33808 .71927 Mtetra
.935 .582 .326 r
.33808 .71927 .33906 .72009 .34033 .72544 .33935 .72463 Mtetra
.213 .573 .941 r
.33935 .72463 .34033 .72544 .34186 .72586 .34088 .72504 Mtetra
.675 .768 .921 r
.34088 .72504 .34186 .72586 .34343 .72531 .34245 .72449 Mtetra
.754 .779 .873 r
.34245 .72449 .34343 .72531 .34503 .72434 .34406 .72352 Mtetra
.518 .718 .963 r
.34406 .72352 .34503 .72434 .34659 .72426 .34561 .72344 Mtetra
.594 .745 .949 r
.34561 .72344 .34659 .72426 .34816 .72399 .34718 .72316 Mtetra
.752 .779 .875 r
.34718 .72316 .34816 .72399 .34976 .72302 .34878 .7222 Mtetra
.908 .743 .666 r
.34878 .7222 .34976 .72302 .35155 .71812 .35058 .71729 Mtetra
.94 .687 .527 r
.35058 .71729 .35155 .71812 .36251 .52435 .36159 .52346 Mtetra
.913 .727 .638 r
.36159 .52346 .36251 .52435 .36427 .51823 .36336 .51735 Mtetra
.798 .76 .819 r
.36336 .51735 .36427 .51823 .36581 .51687 .36489 .51599 Mtetra
.633 .733 .92 r
.36489 .51599 .36581 .51687 .36729 .51651 .36638 .51563 Mtetra
.483 .679 .952 r
.36638 .51563 .36729 .51651 .36876 .51654 .36785 .51567 Mtetra
.621 .732 .925 r
.36785 .51567 .36876 .51654 .37025 .51621 .36934 .51534 Mtetra
.655 .741 .913 r
.36934 .51534 .37025 .51621 .37174 .51578 .37083 .5149 Mtetra
.662 .742 .909 r
.37083 .5149 .37174 .51578 .37324 .51531 .37233 .51443 Mtetra
.748 .758 .86 r
.37233 .51443 .37324 .51531 .37476 .5144 .37384 .51351 Mtetra
.718 .752 .879 r
.37384 .51351 .37476 .5144 .37626 .51366 .37535 .51277 Mtetra
.562 .707 .938 r
.37535 .51277 .37626 .51366 .37775 .51352 .37684 .51262 Mtetra
.884 .454 .086 r
.37684 .51262 .37775 .51352 .37909 .51653 .37818 .5156 Mtetra
.944 .684 .513 r
.37818 .5156 .37909 .51653 .37227 .70873 .37131 .70778 Mtetra
.946 .61 .354 r
.37131 .70778 .37227 .70873 .37354 .71555 .37258 .71469 Mtetra
0 .404 .844 r
.37258 .71469 .37354 .71555 .37508 .71631 .37412 .71545 Mtetra
.675 .762 .916 r
.37412 .71545 .37508 .71631 .37668 .71575 .37571 .71489 Mtetra
.763 .775 .863 r
.37571 .71489 .37668 .71575 .3783 .7147 .37733 .71384 Mtetra
.714 .769 .896 r
.37733 .71384 .3783 .7147 .3799 .71396 .37894 .7131 Mtetra
.675 .761 .916 r
.37894 .7131 .3799 .71396 .3815 .71339 .38054 .71254 Mtetra
.657 .759 .926 r
.38054 .71254 .3815 .71339 .3831 .71287 .38213 .71205 Mtetra
.597 .751 .951 r
.38213 .71205 .3831 .71287 .38469 .71248 .38372 .71176 Mtetra
.547 .759 .975 r
.38372 .71176 .38469 .71248 .38629 .71217 .38531 .71157 Mtetra
.518 .78 .992 r
.38531 .71157 .38629 .71217 .38788 .71188 .3869 .71138 Mtetra
.538 .815 .997 r
.3869 .71138 .38788 .71188 .38947 .71156 .38849 .71111 Mtetra
.555 .832 .997 r
.38849 .71111 .38947 .71156 .39107 .71122 .39009 .71077 Mtetra
.564 .838 .996 r
.39009 .71077 .39107 .71122 .39267 .71088 .39169 .71042 Mtetra
.577 .84 .995 r
.39169 .71042 .39267 .71088 .39426 .71052 .39329 .71004 Mtetra
.581 .837 .993 r
.39329 .71004 .39426 .71052 .39586 .71015 .39489 .70966 Mtetra
.575 .831 .993 r
.39489 .70966 .39586 .71015 .39747 .7098 .39649 .70931 Mtetra
.531 .815 .998 r
.39649 .70931 .39747 .7098 .39907 .70948 .39809 .70904 Mtetra
.494 .815 1 r
.39809 .70904 .39907 .70948 .40067 .70917 .39969 .7088 Mtetra
.481 .828 .997 r
.39969 .7088 .40067 .70917 .40227 .70885 .40129 .70855 Mtetra
.508 .854 .994 r
.40129 .70855 .40227 .70885 .40388 .70849 .4029 .70821 Mtetra
.542 .872 .993 r
.4029 .70821 .40388 .70849 .40548 .70808 .40451 .70779 Mtetra
.576 .882 .992 r
.40451 .70779 .40548 .70808 .40709 .70764 .40612 .70732 Mtetra
.626 .888 .988 r
.40612 .70732 .40709 .70764 .40871 .70716 .40773 .70676 Mtetra
.661 .877 .979 r
.40773 .70676 .40871 .70716 .41032 .70665 .40935 .70615 Mtetra
.675 .855 .968 r
.40935 .70615 .41032 .70665 .41193 .70613 .41097 .70554 Mtetra
.594 .81 .983 r
.41097 .70554 .41193 .70613 .41354 .70591 .41258 .70518 Mtetra
.599 .774 .963 r
.41258 .70518 .41354 .70591 .41515 .70567 .4142 .70485 Mtetra
.686 .776 .92 r
.4142 .70485 .41515 .70567 .41677 .70494 .41582 .70424 Mtetra
.845 .805 .812 r
.41582 .70424 .41677 .70494 .41846 .70217 .41748 .70245 Mtetra
.963 .89 .708 r
.41748 .70245 .41846 .70217 .42034 .69283 .41918 .699 Mtetra
0 0 .112 r
.41918 .699 .42034 .69283 .42755 .50127 .421 .69184 Mtetra
0 0 .347 r
.421 .69184 .42755 .50127 .42915 .49852 .42789 .5103 Mtetra
.495 .263 .491 r
.42789 .5103 .42915 .49852 .43068 .49786 .42946 .5085 Mtetra
.66 .403 .52 r
.42946 .5085 .43068 .49786 .4322 .49776 .43086 .51276 Mtetra
.922 .656 .518 r
.43086 .51276 .4322 .49776 .43372 .49752 .42788 .6752 Mtetra
.561 .346 .546 r
.42788 .6752 .43372 .49752 .43525 .49704 .42947 .67568 Mtetra
.56 .346 .546 r
.42947 .67568 .43525 .49704 .43679 .49657 .43106 .67601 Mtetra
.558 .344 .546 r
.43106 .67601 .43679 .49657 .43832 .49609 .43268 .67525 Mtetra
.557 .343 .546 r
.43268 .67525 .43832 .49609 .43985 .4956 .43433 .67348 Mtetra
.556 .342 .545 r
.43433 .67348 .43985 .4956 .44139 .4951 .43599 .67141 Mtetra
.56 .345 .546 r
.43599 .67141 .44139 .4951 .44292 .49462 .4376 .67137 Mtetra
.562 .347 .546 r
.4376 .67137 .44292 .49462 .44446 .49414 .43917 .67276 Mtetra
.43917 .67276 .44446 .49414 .446 .49368 .44075 .67375 Mtetra
.571 .355 .548 r
.44075 .67375 .446 .49368 .44753 .49329 .44221 .68021 Mtetra
.564 .349 .547 r
.44221 .68021 .44753 .49329 .44907 .49294 .44377 .68273 Mtetra
.556 .342 .546 r
.44377 .68273 .44907 .49294 .45061 .49243 .44544 .68055 Mtetra
0 0 .348 r
.44544 .68055 .45061 .49243 .45216 .49145 .45113 .49733 Mtetra
0 0 .202 r
.45113 .49733 .45216 .49145 .45372 .49019 .45279 .49134 Mtetra
.878 .942 .577 r
.45279 .49134 .45372 .49019 .45527 .48904 .45439 .48833 Mtetra
.826 .805 .831 r
.45439 .48833 .45527 .48904 .45682 .48823 .45595 .48685 Mtetra
.672 .66 .83 r
.45595 .48685 .45682 .48823 .45837 .48773 .4575 .48627 Mtetra
.624 .629 .835 r
.4575 .48627 .45837 .48773 .45991 .48732 .45904 .48594 Mtetra
.631 .644 .845 r
.45904 .48594 .45991 .48732 .46145 .48689 .46058 .48559 Mtetra
.656 .665 .847 r
.46058 .48559 .46145 .48689 .463 .48641 .46213 .48511 Mtetra
.656 .666 .848 r
.46213 .48511 .463 .48641 .46455 .48592 .46368 .48463 Mtetra
.658 .668 .848 r
.46368 .48463 .46455 .48592 .4661 .48542 .46522 .48414 Mtetra
.659 .67 .849 r
.46522 .48414 .4661 .48542 .46765 .48491 .46677 .48364 Mtetra
.659 .671 .85 r
.46677 .48364 .46765 .48491 .4692 .4844 .46832 .48314 Mtetra
.66 .673 .851 r
.46832 .48314 .4692 .4844 .47075 .4839 .46987 .48264 Mtetra
.659 .674 .853 r
.46987 .48264 .47075 .4839 .4723 .4834 .47143 .48214 Mtetra
.654 .673 .855 r
.47143 .48214 .4723 .4834 .47385 .48291 .47298 .48167 Mtetra
.639 .67 .863 r
.47298 .48167 .47385 .48291 .4754 .48246 .47453 .48128 Mtetra
.622 .673 .878 r
.47453 .48128 .4754 .48246 .47696 .48205 .47608 .48096 Mtetra
.619 .69 .894 r
.47608 .48096 .47696 .48205 .47851 .48164 .47764 .48065 Mtetra
.632 .715 .907 r
.47764 .48065 .47851 .48164 .48006 .4812 .47919 .48029 Mtetra
.654 .74 .913 r
.47919 .48029 .48006 .4812 .48162 .4807 .48075 .47983 Mtetra
.669 .752 .913 r
.48075 .47983 .48162 .4807 .48318 .48018 .48231 .47931 Mtetra
.688 .759 .905 r
.48231 .47931 .48318 .48018 .48474 .47962 .48387 .47871 Mtetra
.703 .753 .891 r
.48387 .47871 .48474 .47962 .4863 .47902 .48543 .47803 Mtetra
.701 .736 .878 r
.48543 .47803 .4863 .47902 .48786 .47842 .48699 .47735 Mtetra
.687 .717 .872 r
.48699 .47735 .48786 .47842 .48942 .47783 .48856 .47673 Mtetra
.67 .705 .873 r
.48856 .47673 .48942 .47783 .49099 .47729 .49012 .47619 Mtetra
.665 .705 .877 r
.49012 .47619 .49099 .47729 .49255 .47676 .49168 .47568 Mtetra
.683 .715 .872 r
.49168 .47568 .49255 .47676 .49411 .47608 .49325 .47507 Mtetra
.702 .733 .875 r
.49325 .47507 .49411 .47608 .49568 .4753 .49481 .47438 Mtetra
.651 .738 .913 r
.49481 .47438 .49568 .4753 .49725 .4749 .49638 .47393 Mtetra
.373 .607 .94 r
.49638 .47393 .49725 .4749 .4988 .47575 .49794 .47423 Mtetra
0 .076 .636 r
.49794 .47423 .4988 .47575 .50033 .4808 .49949 .47611 Mtetra
0 .012 .532 r
.49949 .47611 .50033 .4808 .50054 .67511 .50102 .48062 Mtetra
0 0 .392 r
.50102 .48062 .50054 .67511 .50218 .67869 .50136 .66315 Mtetra
.586 .393 .586 r
.50136 .66315 .50218 .67869 .50385 .67854 .50303 .66211 Mtetra
.632 .427 .586 r
.50303 .66211 .50385 .67854 .50552 .67778 .50471 .65831 Mtetra
.337 .199 .541 r
.50471 .65831 .50552 .67778 .50719 .67727 .50632 .66778 Mtetra
.232 .15 .553 r
.50632 .66778 .50719 .67727 .50886 .67762 .50795 .67391 Mtetra
.201 .219 .655 r
.50795 .67391 .50886 .67762 .51052 .67789 .50961 .67646 Mtetra
.197 .42 .852 r
.50961 .67646 .51052 .67789 .5122 .67787 .51128 .67741 Mtetra
.52 .824 1 r
.51128 .67741 .5122 .67787 .51387 .67746 .51295 .67712 Mtetra
.626 .891 .988 r
.51295 .67712 .51387 .67746 .51555 .67695 .51463 .67653 Mtetra
.638 .876 .985 r
.51463 .67653 .51555 .67695 .51722 .67646 .51631 .67596 Mtetra
.536 .821 .998 r
.51631 .67596 .51722 .67646 .5189 .67609 .51799 .67566 Mtetra
.513 .831 1 r
.51799 .67566 .5189 .67609 .52058 .67572 .51967 .67536 Mtetra
.516 .85 .997 r
.51967 .67536 .52058 .67572 .52226 .67532 .52135 .675 Mtetra
.55 .873 .993 r
.52135 .675 .52226 .67532 .52394 .67488 .52303 .67456 Mtetra
.567 .879 .993 r
.52303 .67456 .52394 .67488 .52562 .67442 .52471 .67409 Mtetra
.576 .879 .993 r
.52471 .67409 .52562 .67442 .52731 .67395 .5264 .6736 Mtetra
.573 .874 .994 r
.5264 .6736 .52731 .67395 .52899 .67348 .52808 .67313 Mtetra
.586 .879 .993 r
.52808 .67313 .52899 .67348 .53068 .67299 .52977 .67263 Mtetra
.616 .886 .99 r
.52977 .67263 .53068 .67299 .53236 .67247 .53145 .67207 Mtetra
.663 .889 .98 r
.53145 .67207 .53236 .67247 .53405 .6719 .53314 .67141 Mtetra
.68 .87 .971 r
.53314 .67141 .53405 .6719 .53574 .67132 .53483 .67074 Mtetra
.677 .845 .964 r
.53483 .67074 .53574 .67132 .53742 .67075 .53652 .6701 Mtetra
.651 .819 .964 r
.53652 .6701 .53742 .67075 .53911 .67024 .53821 .66956 Mtetra
.641 .811 .965 r
.53821 .66956 .53911 .67024 .54081 .66974 .5399 .66907 Mtetra
.637 .809 .966 r
.5399 .66907 .54081 .66974 .5425 .66926 .54159 .66858 Mtetra
.64 .811 .965 r
.54159 .66858 .5425 .66926 .54419 .66877 .54329 .66809 Mtetra
.638 .81 .965 r
.54329 .66809 .54419 .66877 .54588 .66828 .54498 .6676 Mtetra
.637 .809 .965 r
.54498 .6676 .54588 .66828 .54758 .6678 .54668 .66711 Mtetra
.636 .808 .966 r
.54668 .66711 .54758 .6678 .54928 .66732 .54838 .66663 Mtetra
.634 .807 .966 r
.54838 .66663 .54928 .66732 .55097 .66684 .55007 .66616 Mtetra
.633 .807 .966 r
.55007 .66616 .55097 .66684 .55267 .66637 .55177 .66569 Mtetra
.631 .807 .967 r
.55177 .66569 .55267 .66637 .55437 .6659 .55347 .66522 Mtetra
.629 .806 .968 r
.55347 .66522 .55437 .6659 .55607 .66544 .55517 .66476 Mtetra
.628 .807 .968 r
.55517 .66476 .55607 .66544 .55777 .66498 .55688 .6643 Mtetra
.63 .808 .968 r
.55688 .6643 .55777 .66498 .55948 .66452 .55858 .66383 Mtetra
.622 .805 .97 r
.55858 .66383 .55948 .66452 .56118 .66407 .56029 .66339 Mtetra
.603 .8 .975 r
.56029 .66339 .56118 .66407 .56289 .66364 .56199 .663 Mtetra
.555 .793 .987 r
.56199 .663 .56289 .66364 .56459 .66328 .5637 .66272 Mtetra
.532 .809 .997 r
.5637 .66272 .56459 .66328 .5663 .66291 .56541 .66245 Mtetra
.524 .83 1 r
.56541 .66245 .5663 .66291 .56801 .66253 .56712 .66213 Mtetra
.557 .861 .997 r
.56712 .66213 .56801 .66253 .56972 .66208 .56883 .66171 Mtetra
.568 .869 .995 r
.56883 .66171 .56972 .66208 .57143 .66162 .57054 .66125 Mtetra
.575 .873 .994 r
.57054 .66125 .57143 .66162 .57314 .66115 .57226 .66078 Mtetra
.572 .87 .995 r
.57226 .66078 .57314 .66115 .57485 .66068 .57397 .66031 Mtetra
.573 .872 .995 r
.57397 .66031 .57485 .66068 .57657 .66021 .57568 .65984 Mtetra
.575 .873 .994 r
.57568 .65984 .57657 .66021 .57828 .65973 .5774 .65936 Mtetra
.5774 .65936 .57828 .65973 .58 .65925 .57912 .65888 Mtetra
.576 .874 .994 r
.57912 .65888 .58 .65925 .58171 .65877 .58083 .6584 Mtetra
.575 .875 .994 r
.58083 .6584 .58171 .65877 .58343 .65828 .58255 .65792 Mtetra
.564 .872 .994 r
.58255 .65792 .58343 .65828 .58515 .6578 .58427 .65746 Mtetra
.568 .878 .993 r
.58427 .65746 .58515 .6578 .58687 .6573 .58599 .65697 Mtetra
.578 .884 .991 r
.58599 .65697 .58687 .6573 .58859 .65679 .58771 .65645 Mtetra
.532 .866 .993 r
.58771 .65645 .58859 .65679 .59031 .6563 .58944 .65603 Mtetra
.608 .909 .982 r
.58944 .65603 .59031 .6563 .59203 .65573 .59116 .65541 Mtetra
.758 .927 .944 r
.59116 .65541 .59203 .65573 .59375 .65503 .59287 .65438 Mtetra
.902 .826 .762 r
.59287 .65438 .59375 .65503 .59546 .65389 .59456 .65178 Mtetra
.855 .68 .664 r
.59456 .65178 .59546 .65389 .59717 .65261 .5962 .64752 Mtetra
.857 .624 .585 r
.5962 .64752 .59717 .65261 .59888 .65134 .5977 .63631 Mtetra
.62 .419 .588 r
.5977 .63631 .59888 .65134 .60062 .65127 .59937 .63353 Mtetra
.522 .342 .578 r
.59937 .63353 .60062 .65127 .60235 .6509 .60115 .63564 Mtetra
.632 .428 .588 r
.60115 .63564 .60235 .6509 .60406 .6497 .60281 .63208 Mtetra
.943 .667 .485 r
.60281 .63208 .60406 .6497 .6056 .64095 .60027 .44678 Mtetra
.568 .356 .553 r
.60027 .44678 .6056 .64095 .60269 .44554 .60181 .44254 Mtetra
.751 .592 .678 r
.60181 .44254 .60269 .44554 .60422 .44128 .60339 .44008 Mtetra
.718 .713 .844 r
.60339 .44008 .60422 .44128 .60584 .44024 .60501 .43922 Mtetra
.653 .726 .902 r
.60501 .43922 .60584 .44024 .60747 .43979 .60664 .43875 Mtetra
.599 .7 .914 r
.60664 .43875 .60747 .43979 .60911 .43966 .60828 .43849 Mtetra
.626 .685 .886 r
.60828 .43849 .60911 .43966 .61074 .43925 .60992 .43814 Mtetra
.624 .696 .896 r
.60992 .43814 .61074 .43925 .61238 .43883 .61155 .43779 Mtetra
.633 .713 .905 r
.61155 .43779 .61238 .43883 .61402 .43839 .61319 .4374 Mtetra
.731 .755 .871 r
.61319 .4374 .61402 .43839 .61565 .43775 .61482 .43653 Mtetra
.701 .705 .85 r
.61482 .43653 .61565 .43775 .61728 .43713 .61645 .43578 Mtetra
.637 .659 .855 r
.61645 .43578 .61728 .43713 .61892 .43662 .61809 .43538 Mtetra
.034 .335 .816 r
.61809 .43538 .61892 .43662 .62057 .43662 .61977 .43657 Mtetra
.842 .385 .117 r
.61977 .43657 .62057 .43662 .62223 .4368 .62151 .43937 Mtetra
.887 .568 .44 r
.62151 .43937 .62223 .4368 .62389 .43703 .6235 .45026 Mtetra
.946 .66 .467 r
.6235 .45026 .62389 .43703 .62552 .43615 .63031 .61821 Mtetra
.073 0 .434 r
.63031 .61821 .62552 .43615 .62715 .4354 .62683 .45025 Mtetra
.565 .327 .513 r
.62683 .45025 .62715 .4354 .62881 .43536 .62851 .45074 Mtetra
.945 .659 .467 r
.62851 .45074 .62881 .43536 .63065 .44092 .63611 .63505 Mtetra
.566 .35 .547 r
.63611 .63505 .63065 .44092 .63878 .63715 .638 .63896 Mtetra
.696 .317 .326 r
.638 .63896 .63878 .63715 .64068 .64126 .63983 .64072 Mtetra
.459 .785 .999 r
.63983 .64072 .64068 .64126 .64246 .64152 .6416 .64057 Mtetra
.699 .77 .906 r
.6416 .64057 .64246 .64152 .64421 .6409 .64334 .63984 Mtetra
.737 .759 .87 r
.64334 .63984 .64421 .6409 .64595 .6399 .64508 .63887 Mtetra
.678 .747 .903 r
.64508 .63887 .64595 .6399 .6477 .6393 .64684 .63824 Mtetra
.651 .731 .908 r
.64684 .63824 .6477 .6393 .64946 .63881 .6486 .63774 Mtetra
.634 .724 .912 r
.6486 .63774 .64946 .63881 .65122 .63835 .65036 .63731 Mtetra
.521 .684 .94 r
.65036 .63731 .65122 .63835 .653 .63834 .65214 .63727 Mtetra
.563 .696 .93 r
.65214 .63727 .653 .63834 .65477 .63812 .65391 .63711 Mtetra
.663 .748 .913 r
.65391 .63711 .65477 .63812 .65652 .6373 .65567 .63655 Mtetra
.861 .832 .817 r
.65567 .63655 .65652 .6373 .65817 .63374 .65738 .63464 Mtetra
.903 .931 .554 r
.65738 .63464 .65817 .63374 .65922 .61503 .65903 .63111 Mtetra
.273 .101 .456 r
.65903 .63111 .65922 .61503 .65361 .42851 .66041 .62092 Mtetra
.031 0 .423 r
.66041 .62092 .65361 .42851 .65519 .42601 .65455 .42935 Mtetra
0 0 .15 r
.65455 .42935 .65519 .42601 .65682 .42481 .65607 .42528 Mtetra
.857 .981 .688 r
.65607 .42528 .65682 .42481 .65847 .4241 .65766 .42305 Mtetra
.728 .747 .867 r
.65766 .42305 .65847 .4241 .66013 .42357 .65931 .42218 Mtetra
.619 .646 .855 r
.65931 .42218 .66013 .42357 .6618 .42318 .66098 .42186 Mtetra
.566 .632 .877 r
.66098 .42186 .6618 .42318 .66347 .42286 .66266 .42177 Mtetra
.624 .702 .901 r
.66266 .42177 .66347 .42286 .66514 .42239 .66433 .42141 Mtetra
.658 .738 .909 r
.66433 .42141 .66514 .42239 .6668 .42184 .666 .4209 Mtetra
.674 .754 .911 r
.666 .4209 .6668 .42184 .66846 .42126 .66766 .42032 Mtetra
.739 .775 .882 r
.66766 .42032 .66846 .42126 .67011 .4203 .66931 .41941 Mtetra
.73 .782 .894 r
.66931 .41941 .67011 .4203 .67177 .4195 .67097 .41857 Mtetra
.655 .75 .92 r
.67097 .41857 .67177 .4195 .67345 .41922 .67264 .41807 Mtetra
.278 .512 .9 r
.67264 .41807 .67345 .41922 .67523 .42125 .67436 .41872 Mtetra
.128 .23 .702 r
.67436 .41872 .67523 .42125 .67769 .43737 .67616 .42093 Mtetra
.329 .204 .554 r
.67616 .42093 .67769 .43737 .68828 .62497 .67829 .42996 Mtetra
.056 0 .442 r
.67829 .42996 .68828 .62497 .69018 .62691 .68911 .6211 Mtetra
.308 .248 .625 r
.68911 .6211 .69018 .62691 .69201 .62723 .69108 .62454 Mtetra
.33 .363 .745 r
.69108 .62454 .69201 .62723 .69381 .62703 .69296 .62601 Mtetra
.376 .615 .944 r
.69296 .62601 .69381 .62703 .69562 .62695 .69479 .62634 Mtetra
.565 .813 .991 r
.69479 .62634 .69562 .62695 .69742 .62665 .69659 .62599 Mtetra
.735 .852 .935 r
.69659 .62599 .69742 .62665 .69919 .62575 .69836 .62509 Mtetra
.864 .856 .832 r
.69836 .62509 .69919 .62575 .70085 .62271 .70008 .62324 Mtetra
.935 .953 .633 r
.70008 .62324 .70085 .62271 .70217 .61309 .70174 .62002 Mtetra
.01 0 .316 r
.70174 .62002 .70217 .61309 .69374 .41666 .70317 .6127 Mtetra
.054 0 .436 r
.70317 .6127 .69374 .41666 .69528 .41349 .69477 .41772 Mtetra
0 0 .237 r
.69477 .41772 .69528 .41349 .69692 .41213 .69623 .41289 Mtetra
.774 .92 .545 r
.69623 .41289 .69692 .41213 .69859 .41131 .69781 .4104 Mtetra
.784 .792 .859 r
.69781 .4104 .69859 .41131 .70027 .41066 .69945 .40919 Mtetra
.662 .657 .834 r
.69945 .40919 .70027 .41066 .70195 .41013 .70114 .40862 Mtetra
.615 .629 .841 r
.70114 .40862 .70195 .41013 .70365 .4097 .70284 .40831 Mtetra
.617 .648 .858 r
.70284 .40831 .70365 .4097 .70534 .40925 .70454 .40799 Mtetra
.626 .674 .876 r
.70454 .40799 .70534 .40925 .70703 .40877 .70624 .40762 Mtetra
.632 .698 .893 r
.70624 .40762 .70703 .40877 .70872 .40827 .70793 .40723 Mtetra
.706 .747 .884 r
.70793 .40723 .70872 .40827 .71039 .40742 .70961 .40648 Mtetra
.725 .773 .891 r
.70961 .40648 .71039 .40742 .71207 .40658 .71129 .40564 Mtetra
.665 .754 .916 r
.71129 .40564 .71207 .40658 .71377 .40622 .71298 .40509 Mtetra
.29 .525 .906 r
.71298 .40509 .71377 .40622 .71559 .40784 .71474 .40572 Mtetra
.002 .182 .696 r
.71474 .40572 .71559 .40784 .71786 .41697 .7166 .40802 Mtetra
.227 .158 .567 r
.7166 .40802 .71786 .41697 .73132 .61213 .71873 .41469 Mtetra
.106 .018 .463 r
.71873 .41469 .73132 .61213 .73328 .614 .7316 .59889 Mtetra
.609 .41 .587 r
.7316 .59889 .73328 .614 .7351 .6136 .73329 .59662 Mtetra
.595 .397 .584 r
.73329 .59662 .7351 .6136 .73688 .61272 .73502 .59488 Mtetra
.324 .201 .554 r
.73502 .59488 .73688 .61272 .73872 .6125 .7375 .60513 Mtetra
.299 .225 .603 r
.7375 .60513 .73872 .6125 .74058 .61282 .73963 .60973 Mtetra
.257 .293 .709 r
.73963 .60973 .74058 .61282 .74245 .61304 .74161 .61188 Mtetra
.312 .546 .916 r
.74161 .61188 .74245 .61304 .74429 .61292 .7435 .61247 Mtetra
.465 .817 .997 r
.7435 .61247 .74429 .61292 .74612 .61252 .74534 .61222 Mtetra
.544 .886 .985 r
.74534 .61222 .74612 .61252 .74794 .61203 .74716 .61169 Mtetra
.561 .886 .989 r
.74716 .61169 .74794 .61203 .74976 .61153 .74898 .61116 Mtetra
.557 .877 .992 r
.74898 .61116 .74976 .61153 .75158 .61104 .75081 .61066 Mtetra
.582 .886 .991 r
.75081 .61066 .75158 .61104 .75341 .61051 .75263 .61011 Mtetra
.62 .892 .988 r
.75263 .61011 .75341 .61051 .75523 .60996 .75445 .60948 Mtetra
.655 .885 .982 r
.75445 .60948 .75523 .60996 .75705 .60938 .75626 .6088 Mtetra
.67 .863 .973 r
.75626 .6088 .75705 .60938 .75888 .60879 .75808 .60811 Mtetra
.612 .817 .979 r
.75808 .60811 .75888 .60879 .76072 .60846 .75991 .60764 Mtetra
.594 .773 .966 r
.75991 .60764 .76072 .60846 .76256 .6082 .76176 .60729 Mtetra
.674 .779 .929 r
.76176 .60729 .76256 .6082 .76438 .60748 .76358 .60665 Mtetra
.823 .832 .855 r
.76358 .60665 .76438 .60748 .76608 .60503 .76534 .60512 Mtetra
.959 .945 .699 r
.76534 .60512 .76608 .60503 .7674 .59739 .767 .60206 Mtetra
0 0 .205 r
.767 .60206 .7674 .59739 .75502 .39793 .7684 .59552 Mtetra
.082 0 .453 r
.7684 .59552 .75502 .39793 .75647 .39361 .75608 .39792 Mtetra
0 0 .249 r
.75608 .39792 .75647 .39361 .7581 .39183 .75746 .39265 Mtetra
.6 .827 .44 r
.75746 .39265 .7581 .39183 .7598 .3911 .75906 .39044 Mtetra
.19 .587 .942 r
.75906 .39044 .7598 .3911 .76165 .39231 .76086 .39088 Mtetra
.872 .491 .012 r
.76086 .39088 .76165 .39231 .76404 .40071 .76312 .39761 Mtetra
.977 .677 .367 r
.76312 .39761 .76404 .40071 .78065 .59924 .77982 .59801 Mtetra
0 0 .478 r
.77982 .59801 .78065 .59924 .78271 .60175 .78191 .60081 Mtetra
.556 .727 .955 r
.78191 .60081 .78271 .60175 .78458 .60154 .78378 .60061 Mtetra
.706 .789 .915 r
.78378 .60061 .78458 .60154 .7864 .60074 .78561 .59982 Mtetra
.621 .761 .946 r
.78561 .59982 .7864 .60074 .78825 .60025 .78746 .59939 Mtetra
.436 .689 .971 r
.78746 .59939 .78825 .60025 .79014 .60025 .78936 .59948 Mtetra
.621 .799 .967 r
.78936 .59948 .79014 .60025 .79199 .5997 .79121 .59901 Mtetra
.904 .86 .788 r
.79121 .59901 .79199 .5997 .79368 .59723 .79292 .59665 Mtetra
.985 .762 .517 r
.79292 .59665 .79368 .59723 .79472 .58638 .79404 .58687 Mtetra
.978 .683 .379 r
.79404 .58687 .79472 .58638 .78078 .38781 .78003 .38693 Mtetra
.932 .802 .694 r
.78003 .38693 .78078 .38781 .78229 .38451 .78154 .38349 Mtetra
.725 .764 .883 r
.78154 .38349 .78229 .38451 .784 .38366 .78325 .38263 Mtetra
.604 .714 .922 r
.78325 .38263 .784 .38366 .78575 .38336 .785 .38232 Mtetra
.648 .732 .91 r
.785 .38232 .78575 .38336 .7875 .38287 .78674 .38183 Mtetra
.741 .765 .872 r
.78674 .38183 .7875 .38287 .7892 .38191 .78845 .38087 Mtetra
.655 .734 .907 r
.78845 .38087 .7892 .38191 .79094 .3814 .79019 .38035 Mtetra
.115 .43 .872 r
.79019 .38035 .79094 .3814 .79281 .38238 .79206 .38133 Mtetra
.895 .504 .063 r
.79206 .38133 .79281 .38238 .79519 .38946 .79443 .38829 Mtetra
.976 .672 .357 r
.79443 .38829 .79519 .38946 .81388 .58892 .81309 .5879 Mtetra
.589 .133 0 r
.81309 .5879 .81388 .58892 .81603 .59179 .81524 .5908 Mtetra
.602 .738 .94 r
.81524 .5908 .81603 .59179 .81791 .59144 .81713 .59045 Mtetra
.755 .795 .885 r
.81713 .59045 .81791 .59144 .81973 .59035 .81894 .58937 Mtetra
.777 .802 .873 r
.81894 .58937 .81973 .59035 .82153 .5891 .82075 .58814 Mtetra
.699 .784 .917 r
.82075 .58814 .82153 .5891 .82338 .5883 .8226 .58737 Mtetra
.683 .786 .928 r
.8226 .58737 .82338 .5883 .82523 .58758 .82445 .58669 Mtetra
.64 .777 .947 r
.82445 .58669 .82523 .58758 .8271 .58705 .82633 .58617 Mtetra
.57 .753 .964 r
.82633 .58617 .8271 .58705 .82899 .58678 .82822 .5859 Mtetra
.548 .742 .966 r
.82822 .5859 .82899 .58678 .8309 .58658 .83012 .58569 Mtetra
.478 .705 .969 r
.83012 .58569 .8309 .58658 .83282 .58659 .83205 .58569 Mtetra
.401 .661 .964 r
.83205 .58569 .83282 .58659 .83476 .58681 .83399 .5859 Mtetra
.609 .761 .952 r
.83399 .5859 .83476 .58681 .83665 .58642 .83588 .5855 Mtetra
.868 .827 .806 r
.83588 .5855 .83665 .58642 .83839 .58435 .83762 .58344 Mtetra
.982 .75 .51 r
.83762 .58344 .83839 .58435 .83934 .57386 .8386 .57319 Mtetra
.978 .679 .361 r
.8386 .57319 .83934 .57386 .82272 .37474 .82199 .37376 Mtetra
.935 .795 .681 r
.82199 .37376 .82272 .37474 .82419 .37112 .82346 .37011 Mtetra
.725 .768 .887 r
.82346 .37011 .82419 .37112 .82592 .37025 .82519 .36923 Mtetra
.599 .717 .927 r
.82519 .36923 .82592 .37025 .82771 .36996 .82697 .36893 Mtetra
.82697 .36893 .82771 .36996 .82949 .36966 .82876 .36863 Mtetra
.739 .771 .879 r
.82876 .36863 .82949 .36966 .83122 .36871 .83049 .36768 Mtetra
.656 .74 .911 r
.83049 .36768 .83122 .36871 .83299 .36818 .83225 .36715 Mtetra
.233 .51 .908 r
.83225 .36715 .83299 .36818 .83488 .36891 .83414 .36788 Mtetra
.882 .489 .033 r
.83414 .36788 .83488 .36891 .83739 .376 .83666 .37496 Mtetra
.975 .667 .334 r
.83666 .37496 .83739 .376 .85893 .57657 .85816 .57558 Mtetra
.657 .204 0 r
.85816 .57558 .85893 .57657 .86121 .57999 .86044 .57901 Mtetra
.382 .63 .952 r
.86044 .57901 .86121 .57999 .86319 .5803 .86242 .57932 Mtetra
.694 .78 .918 r
.86242 .57932 .86319 .5803 .86506 .57956 .8643 .57857 Mtetra
.874 .819 .791 r
.8643 .57857 .86506 .57956 .86679 .57735 .86603 .57636 Mtetra
.978 .766 .548 r
.86603 .57636 .86679 .57735 .86796 .56963 .8672 .56863 Mtetra
.977 .675 .347 r
.8672 .56863 .86796 .56963 .84933 .36727 .8486 .36622 Mtetra
.949 .785 .644 r
.8486 .36622 .84933 .36727 .85072 .36289 .84999 .36184 Mtetra
.746 .771 .874 r
.84999 .36184 .85072 .36289 .85245 .36188 .85172 .36083 Mtetra
.621 .723 .919 r
.85172 .36083 .85245 .36188 .85424 .3615 .85352 .36045 Mtetra
.59 .708 .925 r
.85352 .36045 .85424 .3615 .85605 .36124 .85533 .36019 Mtetra
.748 .772 .873 r
.85533 .36019 .85605 .36124 .85778 .36022 .85706 .35917 Mtetra
.675 .745 .904 r
.85706 .35917 .85778 .36022 .85956 .3596 .85883 .35855 Mtetra
.379 .596 .931 r
.85883 .35855 .85956 .3596 .86144 .35999 .86072 .35894 Mtetra
.803 .39 0 r
.86072 .35894 .86144 .35999 .86385 .36533 .86313 .36427 Mtetra
.973 .663 .318 r
.86313 .36427 .86385 .36533 .88729 .56727 .88653 .56626 Mtetra
.715 .274 0 r
.88653 .56626 .88729 .56727 .8897 .57141 .88894 .57041 Mtetra
.502 .693 .954 r
.88894 .57041 .8897 .57141 .89167 .57139 .89091 .57039 Mtetra
.693 .779 .917 r
.89091 .57039 .89167 .57139 .89356 .57064 .8928 .56964 Mtetra
.733 .793 .9 r
.8928 .56964 .89356 .57064 .89542 .56967 .89467 .56867 Mtetra
.495 .689 .954 r
.89467 .56867 .89542 .56967 .8974 .56967 .89665 .56867 Mtetra
.622 .751 .939 r
.89665 .56867 .8974 .56967 .89933 .56923 .89858 .56823 Mtetra
.808 .814 .855 r
.89858 .56823 .89933 .56923 .90114 .56775 .9004 .56675 Mtetra
.979 .773 .557 r
.9004 .56675 .90114 .56775 .90234 .56068 .90159 .55967 Mtetra
.976 .671 .329 r
.90159 .55967 .90234 .56068 .88154 .35763 .88083 .35658 Mtetra
.96 .784 .621 r
.88083 .35658 .88154 .35763 .88286 .35278 .88214 .35172 Mtetra
.743 .772 .876 r
.88214 .35172 .88286 .35278 .8846 .35178 .88389 .35072 Mtetra
.605 .715 .923 r
.88389 .35072 .8846 .35178 .88643 .35146 .88572 .3504 Mtetra
.518 .672 .933 r
.88572 .3504 .88643 .35146 .88829 .35145 .88758 .35039 Mtetra
.654 .737 .911 r
.88758 .35039 .88829 .35145 .89009 .35092 .88938 .34986 Mtetra
.661 .74 .908 r
.88938 .34986 .89009 .35092 .89189 .35036 .89119 .34929 Mtetra
.675 .746 .904 r
.89119 .34929 .89189 .35036 .89369 .34973 .89298 .34867 Mtetra
.765 .779 .864 r
.89298 .34867 .89369 .34973 .89543 .34859 .89472 .34753 Mtetra
.7 .756 .895 r
.89472 .34753 .89543 .34859 .89721 .34784 .8965 .34677 Mtetra
.505 .664 .933 r
.8965 .34677 .89721 .34784 .89908 .34787 .89838 .34681 Mtetra
.733 .314 0 r
.89838 .34681 .89908 .34787 .90152 .35259 .90081 .35152 Mtetra
.971 .656 .295 r
.90081 .35152 .90152 .35259 .92755 .55522 .92681 .5542 Mtetra
.743 .314 0 r
.92681 .5542 .92755 .55522 .93013 .56006 .9294 .55905 Mtetra
.48 .68 .954 r
.9294 .55905 .93013 .56006 .93214 .56012 .93141 .55911 Mtetra
.686 .778 .921 r
.93141 .55911 .93214 .56012 .93406 .55939 .93333 .55838 Mtetra
.76 .804 .888 r
.93333 .55838 .93406 .55939 .93593 .55825 .9352 .55724 Mtetra
.443 .693 .972 r
.31022 .73175 .31122 .73255 .31274 .73262 .31175 .73181 Mtetra
.609 .753 .947 r
.31175 .73181 .31274 .73262 .31429 .7323 .3133 .73149 Mtetra
.768 .78 .863 r
.3133 .73149 .31429 .7323 .31588 .73124 .31489 .73043 Mtetra
.911 .734 .649 r
.31489 .73043 .31588 .73124 .31776 .72532 .31677 .72451 Mtetra
.937 .686 .534 r
.31677 .72451 .31776 .72532 .33049 .53206 .32956 .53121 Mtetra
.905 .732 .656 r
.32956 .53121 .33049 .53206 .33224 .52691 .33131 .52605 Mtetra
.764 .76 .849 r
.33131 .52605 .33224 .52691 .33374 .52589 .33282 .52503 Mtetra
.613 .729 .928 r
.33282 .52503 .33374 .52589 .33521 .5256 .33428 .52473 Mtetra
.462 .672 .955 r
.33428 .52473 .33521 .5256 .33665 .52568 .33573 .52481 Mtetra
.638 .735 .919 r
.33573 .52481 .33665 .52568 .33812 .5253 .3372 .52443 Mtetra
.652 .739 .913 r
.3372 .52443 .33812 .5253 .3396 .52487 .33868 .524 Mtetra
.659 .741 .911 r
.33868 .524 .3396 .52487 .34108 .52442 .34015 .52355 Mtetra
.754 .759 .856 r
.34015 .52355 .34108 .52442 .34258 .52346 .34166 .5226 Mtetra
.706 .752 .887 r
.34166 .5226 .34258 .52346 .34407 .5228 .34315 .52193 Mtetra
.508 .691 .95 r
.34315 .52193 .34407 .5228 .34553 .52278 .34461 .52191 Mtetra
.924 .538 .235 r
.34461 .52191 .34553 .52278 .34678 .52665 .34586 .52578 Mtetra
.94 .683 .521 r
.34586 .52578 .34678 .52665 .33808 .71927 .3371 .71844 Mtetra
.936 .583 .325 r
.3371 .71844 .33808 .71927 .33935 .72463 .33837 .7238 Mtetra
.217 .573 .941 r
.33837 .7238 .33935 .72463 .34088 .72504 .33989 .72422 Mtetra
.675 .767 .92 r
.33989 .72422 .34088 .72504 .34245 .72449 .34147 .72367 Mtetra
.754 .779 .874 r
.34147 .72367 .34245 .72449 .34406 .72352 .34307 .7227 Mtetra
.516 .72 .965 r
.34307 .7227 .34406 .72352 .34561 .72344 .34463 .72262 Mtetra
.594 .747 .95 r
.34463 .72262 .34561 .72344 .34718 .72316 .3462 .72234 Mtetra
.753 .779 .875 r
.3462 .72234 .34718 .72316 .34878 .7222 .3478 .72138 Mtetra
.908 .743 .666 r
.3478 .72138 .34878 .7222 .35058 .71729 .3496 .71646 Mtetra
.94 .687 .527 r
.3496 .71646 .35058 .71729 .36159 .52346 .36067 .52258 Mtetra
.914 .728 .638 r
.36067 .52258 .36159 .52346 .36336 .51735 .36244 .51647 Mtetra
.799 .762 .819 r
.36244 .51647 .36336 .51735 .36489 .51599 .36398 .51512 Mtetra
.634 .734 .92 r
.36398 .51512 .36489 .51599 .36638 .51563 .36547 .51475 Mtetra
.485 .679 .951 r
.36547 .51475 .36638 .51563 .36785 .51567 .36694 .51478 Mtetra
.622 .729 .923 r
.36694 .51478 .36785 .51567 .36934 .51534 .36842 .51446 Mtetra
.655 .738 .91 r
.36842 .51446 .36934 .51534 .37083 .5149 .36992 .51401 Mtetra
.662 .74 .907 r
.36992 .51401 .37083 .5149 .37233 .51443 .37141 .51354 Mtetra
.748 .757 .86 r
.37141 .51354 .37233 .51443 .37384 .51351 .37293 .51262 Mtetra
.719 .752 .879 r
.37293 .51262 .37384 .51351 .37535 .51277 .37444 .51188 Mtetra
.563 .708 .938 r
.37444 .51188 .37535 .51277 .37684 .51262 .37593 .51173 Mtetra
.883 .453 .085 r
.37593 .51173 .37684 .51262 .37818 .5156 .37727 .51469 Mtetra
.944 .684 .513 r
.37727 .51469 .37818 .5156 .37131 .70778 .37034 .70685 Mtetra
.946 .61 .357 r
.37034 .70685 .37131 .70778 .37258 .71469 .37161 .71384 Mtetra
0 .398 .839 r
.37161 .71384 .37258 .71469 .37412 .71545 .37315 .71461 Mtetra
.674 .764 .918 r
.37315 .71461 .37412 .71545 .37571 .71489 .37474 .71405 Mtetra
.763 .779 .866 r
.37474 .71405 .37571 .71489 .37733 .71384 .37636 .71301 Mtetra
.709 .774 .903 r
.37636 .71301 .37733 .71384 .37894 .7131 .37797 .71229 Mtetra
.668 .773 .928 r
.37797 .71229 .37894 .7131 .38054 .71254 .37957 .71176 Mtetra
.653 .776 .939 r
.37957 .71176 .38054 .71254 .38213 .71205 .38117 .71128 Mtetra
.616 .768 .952 r
.38117 .71128 .38213 .71205 .38372 .71176 .38276 .71092 Mtetra
.599 .745 .946 r
.38276 .71092 .38372 .71176 .38531 .71157 .38435 .71063 Mtetra
.599 .722 .931 r
.38435 .71063 .38531 .71157 .3869 .71138 .38594 .71035 Mtetra
.612 .708 .913 r
.38594 .71035 .3869 .71138 .38849 .71111 .38754 .71005 Mtetra
.619 .705 .906 r
.38754 .71005 .38849 .71111 .39009 .71077 .38914 .70973 Mtetra
.622 .707 .907 r
.38914 .70973 .39009 .71077 .39169 .71042 .39073 .70939 Mtetra
.628 .713 .907 r
.39073 .70939 .39169 .71042 .39329 .71004 .39233 .70903 Mtetra
.631 .717 .909 r
.39233 .70903 .39329 .71004 .39489 .70966 .39394 .70865 Mtetra
.63 .717 .909 r
.39394 .70865 .39489 .70966 .39649 .70931 .39554 .70828 Mtetra
.621 .711 .91 r
.39554 .70828 .39649 .70931 .39809 .70904 .39714 .70794 Mtetra
.619 .697 .9 r
.39714 .70794 .39809 .70904 .39969 .7088 .39874 .70762 Mtetra
.625 .682 .884 r
.39874 .70762 .39969 .7088 .40129 .70855 .40035 .70728 Mtetra
.636 .672 .867 r
.40035 .70728 .40129 .70855 .4029 .70821 .40196 .70688 Mtetra
.645 .667 .857 r
.40196 .70688 .4029 .70821 .40451 .70779 .40357 .70645 Mtetra
.651 .666 .852 r
.40357 .70645 .40451 .70779 .40612 .70732 .40518 .70597 Mtetra
.659 .67 .849 r
.40518 .70597 .40612 .70732 .40773 .70676 .40679 .70545 Mtetra
.665 .677 .852 r
.40679 .70545 .40773 .70676 .40935 .70615 .40841 .7049 Mtetra
.667 .687 .86 r
.40841 .7049 .40935 .70615 .41097 .70554 .41003 .70435 Mtetra
.646 .691 .878 r
.41003 .70435 .41097 .70554 .41258 .70518 .41164 .70392 Mtetra
.639 .676 .869 r
.41164 .70392 .41258 .70518 .4142 .70485 .41326 .70351 Mtetra
.657 .67 .85 r
.41326 .70351 .4142 .70485 .41582 .70424 .41487 .703 Mtetra
.722 .707 .835 r
.41487 .703 .41582 .70424 .41748 .70245 .41651 .70209 Mtetra
.812 .894 .901 r
.41651 .70209 .41748 .70245 .41918 .699 .41815 .70085 Mtetra
.116 0 .048 r
.41815 .70085 .41918 .699 .421 .69184 .4198 .69952 Mtetra
.504 .251 .464 r
.4198 .69952 .421 .69184 .42789 .5103 .42143 .6986 Mtetra
.559 .345 .546 r
.42143 .6986 .42789 .5103 .42946 .5085 .42305 .69812 Mtetra
.42305 .69812 .42946 .5085 .43086 .51276 .42467 .6978 Mtetra
.42467 .6978 .43086 .51276 .42788 .6752 .42629 .69742 Mtetra
.549 .322 .522 r
.42629 .69742 .42788 .6752 .42947 .67568 .42791 .69696 Mtetra
.549 .32 .521 r
.42791 .69696 .42947 .67568 .43106 .67601 .42954 .6965 Mtetra
.548 .319 .52 r
.42954 .6965 .43106 .67601 .43268 .67525 .43116 .69603 Mtetra
.548 .32 .52 r
.43116 .69603 .43268 .67525 .43433 .67348 .43279 .69555 Mtetra
.549 .321 .522 r
.43279 .69555 .43433 .67348 .43599 .67141 .43442 .69507 Mtetra
.55 .323 .524 r
.43442 .69507 .43599 .67141 .4376 .67137 .43605 .69462 Mtetra
.43605 .69462 .4376 .67137 .43917 .67276 .43768 .69418 Mtetra
.549 .321 .521 r
.43768 .69418 .43917 .67276 .44075 .67375 .43931 .69373 Mtetra
.554 .324 .521 r
.43931 .69373 .44075 .67375 .44221 .68021 .44093 .69364 Mtetra
.552 .313 .507 r
.44093 .69364 .44221 .68021 .44377 .68273 .44256 .69355 Mtetra
.527 .285 .491 r
.44256 .69355 .44377 .68273 .44544 .68055 .4442 .69279 Mtetra
.425 .203 .472 r
.4442 .69279 .44544 .68055 .45113 .49733 .44591 .68905 Mtetra
0 0 .331 r
.44591 .68905 .45113 .49733 .45279 .49134 .4518 .49515 Mtetra
.76 .746 .228 r
.4518 .49515 .45279 .49134 .45439 .48833 .45349 .48815 Mtetra
.913 .887 .792 r
.45349 .48815 .45439 .48833 .45595 .48685 .45507 .48598 Mtetra
.701 .759 .897 r
.45507 .48598 .45595 .48685 .4575 .48627 .45662 .48532 Mtetra
.598 .711 .924 r
.45662 .48532 .4575 .48627 .45904 .48594 .45816 .48507 Mtetra
.605 .732 .935 r
.45816 .48507 .45904 .48594 .46058 .48559 .4597 .48479 Mtetra
.659 .765 .928 r
.4597 .48479 .46058 .48559 .46213 .48511 .46124 .48431 Mtetra
.657 .765 .929 r
.46124 .48431 .46213 .48511 .46368 .48463 .46279 .48383 Mtetra
.659 .767 .93 r
.46279 .48383 .46368 .48463 .46522 .48414 .46434 .48335 Mtetra
.661 .77 .931 r
.46434 .48335 .46522 .48414 .46677 .48364 .46589 .48286 Mtetra
.66 .772 .932 r
.46589 .48286 .46677 .48364 .46832 .48314 .46744 .48237 Mtetra
.659 .775 .935 r
.46744 .48237 .46832 .48314 .46987 .48264 .46899 .48189 Mtetra
.656 .778 .938 r
.46899 .48189 .46987 .48264 .47143 .48214 .47055 .48141 Mtetra
.651 .781 .943 r
.47055 .48141 .47143 .48214 .47298 .48167 .4721 .48095 Mtetra
.639 .78 .949 r
.4721 .48095 .47298 .48167 .47453 .48128 .47365 .48052 Mtetra
.629 .769 .947 r
.47365 .48052 .47453 .48128 .47608 .48096 .47521 .48013 Mtetra
.632 .752 .934 r
.47521 .48013 .47608 .48096 .47764 .48065 .47676 .47975 Mtetra
.642 .738 .918 r
.47676 .47975 .47764 .48065 .47919 .48029 .47832 .47934 Mtetra
.654 .731 .906 r
.47832 .47934 .47919 .48029 .48075 .47983 .47987 .47888 Mtetra
.662 .733 .903 r
.47987 .47888 .48075 .47983 .48231 .47931 .48143 .47839 Mtetra
.672 .743 .904 r
.48143 .47839 .48231 .47931 .48387 .47871 .48299 .47785 Mtetra
.683 .762 .911 r
.48299 .47785 .48387 .47871 .48543 .47803 .48455 .47728 Mtetra
.684 .786 .928 r
.48455 .47728 .48543 .47803 .48699 .47735 .48612 .47669 Mtetra
.674 .809 .948 r
.48612 .47669 .48699 .47735 .48856 .47673 .48768 .47613 Mtetra
.657 .823 .963 r
.48768 .47613 .48856 .47673 .49012 .47619 .48924 .47562 Mtetra
.651 .829 .968 r
.48924 .47562 .49012 .47619 .49168 .47568 .49081 .47511 Mtetra
.665 .834 .964 r
.49081 .47511 .49168 .47568 .49325 .47507 .49237 .47457 Mtetra
.675 .851 .967 r
.49237 .47457 .49325 .47507 .49481 .47438 .49394 .47398 Mtetra
.626 .868 .988 r
.49394 .47398 .49481 .47438 .49638 .47393 .49551 .47347 Mtetra
.507 .814 1 r
.49551 .47347 .49638 .47393 .49794 .47423 .49707 .47324 Mtetra
.448 .638 .937 r
.49707 .47324 .49794 .47423 .49949 .47611 .49864 .4734 Mtetra
.529 .471 .735 r
.49864 .4734 .49949 .47611 .50102 .48062 .5002 .4737 Mtetra
.574 .412 .625 r
.5002 .4737 .50102 .48062 .50136 .66315 .50177 .47358 Mtetra
.562 .351 .552 r
.50177 .47358 .50136 .66315 .50303 .66211 .50334 .47269 Mtetra
.561 .35 .552 r
.50334 .47269 .50303 .66211 .50471 .65831 .50492 .47224 Mtetra
.558 .348 .551 r
.50492 .47224 .50471 .65831 .50632 .66778 .50648 .47369 Mtetra
0 0 .376 r
.50648 .47369 .50632 .66778 .50795 .67391 .50707 .6651 Mtetra
0 0 .436 r
.50707 .6651 .50795 .67391 .50961 .67646 .5087 .67436 Mtetra
0 .164 .692 r
.5087 .67436 .50961 .67646 .51128 .67741 .51036 .67641 Mtetra
.562 .703 .935 r
.51036 .67641 .51128 .67741 .51295 .67712 .51204 .67625 Mtetra
.691 .775 .916 r
.51204 .67625 .51295 .67712 .51463 .67653 .51371 .67559 Mtetra
.703 .762 .898 r
.51371 .67559 .51463 .67653 .51631 .67596 .51539 .67487 Mtetra
.631 .71 .903 r
.51539 .67487 .51631 .67596 .51799 .67566 .51707 .67448 Mtetra
.633 .694 .889 r
.51707 .67448 .51799 .67566 .51967 .67536 .51875 .67408 Mtetra
.638 .68 .873 r
.51875 .67408 .51967 .67536 .52135 .675 .52043 .67367 Mtetra
.646 .672 .86 r
.52043 .67367 .52135 .675 .52303 .67456 .52212 .6732 Mtetra
.649 .67 .857 r
.52212 .6732 .52303 .67456 .52471 .67409 .5238 .67272 Mtetra
.651 .67 .855 r
.5238 .67272 .52471 .67409 .5264 .6736 .52548 .67223 Mtetra
.65 .669 .855 r
.52548 .67223 .5264 .6736 .52808 .67313 .52717 .67174 Mtetra
.653 .668 .851 r
.52717 .67174 .52808 .67313 .52977 .67263 .52886 .67123 Mtetra
.659 .669 .848 r
.52886 .67123 .52977 .67263 .53145 .67207 .53054 .67069 Mtetra
.669 .675 .847 r
.53054 .67069 .53145 .67207 .53314 .67141 .53223 .67009 Mtetra
.672 .685 .854 r
.53223 .67009 .53314 .67141 .53483 .67074 .53392 .66948 Mtetra
.67 .695 .865 r
.53392 .66948 .53483 .67074 .53652 .6701 .53561 .66889 Mtetra
.661 .701 .876 r
.53561 .66889 .53652 .6701 .53821 .66956 .5373 .66836 Mtetra
.657 .699 .878 r
.5373 .66836 .53821 .66956 .5399 .66907 .53899 .66785 Mtetra
.654 .696 .877 r
.53899 .66785 .5399 .66907 .54159 .66858 .54069 .66735 Mtetra
.654 .693 .874 r
.54069 .66735 .54159 .66858 .54329 .66809 .54238 .66685 Mtetra
.652 .692 .874 r
.54238 .66685 .54329 .66809 .54498 .6676 .54408 .66635 Mtetra
.651 .691 .874 r
.54408 .66635 .54498 .6676 .54668 .66711 .54577 .66587 Mtetra
.65 .69 .874 r
.54577 .66587 .54668 .66711 .54838 .66663 .54747 .66538 Mtetra
.649 .689 .874 r
.54747 .66538 .54838 .66663 .55007 .66616 .54917 .66491 Mtetra
.647 .689 .875 r
.54917 .66491 .55007 .66616 .55177 .66569 .55087 .66444 Mtetra
.646 .688 .875 r
.55087 .66444 .55177 .66569 .55347 .66522 .55257 .66397 Mtetra
.645 .688 .876 r
.55257 .66397 .55347 .66522 .55517 .66476 .55427 .66352 Mtetra
.644 .689 .877 r
.55427 .66352 .55517 .66476 .55688 .6643 .55597 .66307 Mtetra
.643 .69 .879 r
.55597 .66307 .55688 .6643 .55858 .66383 .55768 .66262 Mtetra
.64 .692 .883 r
.55768 .66262 .55858 .66383 .56029 .66339 .55938 .66218 Mtetra
.634 .691 .886 r
.55938 .66218 .56029 .66339 .56199 .663 .56109 .66178 Mtetra
.621 .683 .887 r
.56109 .66178 .56199 .663 .5637 .66272 .5628 .66143 Mtetra
.621 .672 .878 r
.5628 .66143 .5637 .66272 .56541 .66245 .56451 .66109 Mtetra
.625 .663 .866 r
.56451 .66109 .56541 .66245 .56712 .66213 .56622 .66072 Mtetra
.637 .66 .856 r
.56622 .66072 .56712 .66213 .56883 .66171 .56793 .6603 Mtetra
.641 .661 .854 r
.56793 .6603 .56883 .66171 .57054 .66125 .56964 .65985 Mtetra
.644 .664 .855 r
.56964 .65985 .57054 .66125 .57226 .66078 .57136 .65939 Mtetra
.644 .667 .857 r
.57136 .65939 .57226 .66078 .57397 .66031 .57307 .65893 Mtetra
.645 .668 .857 r
.57307 .65893 .57397 .66031 .57568 .65984 .57479 .65846 Mtetra
.646 .669 .858 r
.57479 .65846 .57568 .65984 .5774 .65936 .5765 .65799 Mtetra
.5765 .65799 .5774 .65936 .57912 .65888 .57822 .65751 Mtetra
.647 .67 .858 r
.57822 .65751 .57912 .65888 .58083 .6584 .57994 .65703 Mtetra
.647 .671 .859 r
.57994 .65703 .58083 .6584 .58255 .65792 .58166 .65655 Mtetra
.644 .67 .86 r
.58166 .65655 .58255 .65792 .58427 .65746 .58338 .65609 Mtetra
.647 .671 .859 r
.58338 .65609 .58427 .65746 .58599 .65697 .5851 .65561 Mtetra
.648 .673 .86 r
.5851 .65561 .58599 .65697 .58771 .65645 .58682 .65513 Mtetra
.59 .654 .881 r
.58682 .65513 .58771 .65645 .58944 .65603 .58855 .65492 Mtetra
.658 .72 .894 r
.58855 .65492 .58944 .65603 .59116 .65541 .59027 .65439 Mtetra
.771 .769 .85 r
.59027 .65439 .59116 .65541 .59287 .65438 .59198 .65319 Mtetra
.91 .746 .666 r
.59198 .65319 .59287 .65438 .59456 .65178 .59363 .64868 Mtetra
.963 .687 .465 r
.59363 .64868 .59456 .65178 .5962 .64752 .59141 .45387 Mtetra
.576 .362 .553 r
.59141 .45387 .5962 .64752 .5977 .63631 .59286 .4448 Mtetra
.562 .351 .552 r
.59286 .4448 .5977 .63631 .59937 .63353 .59447 .44365 Mtetra
.561 .35 .552 r
.59447 .44365 .59937 .63353 .60115 .63564 .5961 .44328 Mtetra
.5961 .44328 .60115 .63564 .60281 .63208 .59774 .44315 Mtetra
.563 .352 .552 r
.59774 .44315 .60281 .63208 .60027 .44678 .59935 .44181 Mtetra
.645 .483 .65 r
.59935 .44181 .60027 .44678 .60181 .44254 .60096 .44051 Mtetra
.708 .617 .753 r
.60096 .44051 .60181 .44254 .60339 .44008 .60257 .43938 Mtetra
.689 .813 .941 r
.60257 .43938 .60339 .44008 .60501 .43922 .6042 .43875 Mtetra
.624 .856 .987 r
.6042 .43875 .60501 .43922 .60664 .43875 .60583 .43825 Mtetra
.596 .841 .991 r
.60583 .43825 .60664 .43875 .60828 .43849 .60746 .43783 Mtetra
.634 .807 .966 r
.60746 .43783 .60828 .43849 .60992 .43814 .6091 .43737 Mtetra
.643 .782 .948 r
.6091 .43737 .60992 .43814 .61155 .43779 .61073 .43691 Mtetra
.653 .757 .926 r
.61073 .43691 .61155 .43779 .61319 .4374 .61237 .43643 Mtetra
.746 .763 .867 r
.61237 .43643 .61319 .4374 .61482 .43653 .61399 .43547 Mtetra
.7 .733 .877 r
.61399 .43547 .61482 .43653 .61645 .43578 .61562 .43477 Mtetra
.566 .692 .926 r
.61562 .43477 .61645 .43578 .61809 .43538 .61727 .43461 Mtetra
.787 .313 0 r
.61727 .43461 .61809 .43538 .61977 .43657 .619 .4374 Mtetra
.966 .681 .441 r
.619 .4374 .61977 .43657 .62151 .43937 .62631 .62982 Mtetra
.576 .358 .547 r
.62631 .62982 .62151 .43937 .6235 .45026 .62837 .64001 Mtetra
.56 .346 .546 r
.62837 .64001 .6235 .45026 .63031 .61821 .63015 .64046 Mtetra
.547 .319 .522 r
.63015 .64046 .63031 .61821 .62683 .45025 .63189 .63981 Mtetra
.558 .344 .546 r
.63189 .63981 .62683 .45025 .62851 .45074 .63363 .63882 Mtetra
.56 .345 .546 r
.63363 .63882 .62851 .45074 .63611 .63505 .6354 .63909 Mtetra
.562 .259 .412 r
.6354 .63909 .63611 .63505 .638 .63896 .63718 .63945 Mtetra
.371 0 0 r
.63718 .63945 .638 .63896 .63983 .64072 .63896 .63962 Mtetra
.636 .717 .906 r
.63896 .63962 .63983 .64072 .6416 .64057 .64072 .63919 Mtetra
.674 .684 .851 r
.64072 .63919 .6416 .64057 .64334 .63984 .64247 .63854 Mtetra
.689 .702 .857 r
.64247 .63854 .64334 .63984 .64508 .63887 .64422 .63781 Mtetra
.665 .738 .904 r
.64422 .63781 .64508 .63887 .64684 .63824 .64597 .63725 Mtetra
.65 .745 .919 r
.64597 .63725 .64684 .63824 .6486 .63774 .64773 .63674 Mtetra
.638 .741 .923 r
.64773 .63674 .6486 .63774 .65036 .63731 .64949 .63629 Mtetra
.591 .717 .931 r
.64949 .63629 .65036 .63731 .65214 .63727 .65126 .63602 Mtetra
.607 .678 .891 r
.65126 .63602 .65214 .63727 .65391 .63711 .65303 .63573 Mtetra
.639 .669 .863 r
.65303 .63573 .65391 .63711 .65567 .63655 .6548 .63528 Mtetra
.672 .7 .867 r
.6548 .63528 .65567 .63655 .65738 .63464 .65656 .63465 Mtetra
.676 .973 .904 r
.65656 .63465 .65738 .63464 .65903 .63111 .65831 .6336 Mtetra
.175 0 .19 r
.65831 .6336 .65903 .63111 .66041 .62092 .66002 .63171 Mtetra
.25 .068 .428 r
.66002 .63171 .66041 .62092 .65455 .42935 .66152 .62451 Mtetra
.019 0 .418 r
.66152 .62451 .65455 .42935 .65607 .42528 .65538 .42717 Mtetra
.753 .782 .286 r
.65538 .42717 .65607 .42528 .65766 .42305 .65688 .42252 Mtetra
.826 .879 .883 r
.65688 .42252 .65766 .42305 .65931 .42218 .6585 .42118 Mtetra
.637 .728 .914 r
.6585 .42118 .65931 .42218 .66098 .42186 .66017 .42077 Mtetra
.54 .666 .919 r
.66017 .42077 .66098 .42186 .66266 .42177 .66186 .42071 Mtetra
.619 .708 .909 r
.66186 .42071 .66266 .42177 .66433 .42141 .66353 .42037 Mtetra
.651 .725 .903 r
.66353 .42037 .66433 .42141 .666 .4209 .6652 .41989 Mtetra
.661 .735 .905 r
.6652 .41989 .666 .4209 .66766 .42032 .66686 .41937 Mtetra
.699 .76 .899 r
.66686 .41937 .66766 .42032 .66931 .41941 .66852 .41868 Mtetra
.702 .813 .934 r
.66852 .41868 .66931 .41941 .67097 .41857 .67019 .41798 Mtetra
.659 .841 .97 r
.67019 .41798 .67097 .41857 .67264 .41807 .67185 .41741 Mtetra
.612 .805 .974 r
.67185 .41741 .67264 .41807 .67436 .41872 .67353 .417 Mtetra
.565 .576 .823 r
.67353 .417 .67436 .41872 .67616 .42093 .67522 .41696 Mtetra
.505 .412 .684 r
.67522 .41696 .67616 .42093 .67829 .42996 .67696 .41768 Mtetra
.391 .257 .577 r
.67696 .41768 .67829 .42996 .68911 .6211 .67891 .42299 Mtetra
.045 0 .438 r
.67891 .42299 .68911 .6211 .69108 .62454 .69007 .62021 Mtetra
.061 .11 .6 r
.69007 .62021 .69108 .62454 .69296 .62601 .69209 .62443 Mtetra
.348 .49 .859 r
.69209 .62443 .69296 .62601 .69479 .62634 .69394 .62518 Mtetra
.628 .706 .902 r
.69394 .62518 .69479 .62634 .69659 .62599 .69573 .62478 Mtetra
.72 .73 .859 r
.69573 .62478 .69659 .62599 .69836 .62509 .6975 .62387 Mtetra
.708 .726 .864 r
.6975 .62387 .69836 .62509 .70008 .62324 .69928 .62303 Mtetra
.731 .96 .943 r
.69928 .62303 .70008 .62324 .70174 .62002 .70105 .62198 Mtetra
.092 0 .095 r
.70105 .62198 .70174 .62002 .70317 .6127 .70277 .62019 Mtetra
.206 .018 .39 r
.70277 .62019 .70317 .6127 .69477 .41772 .7043 .61453 Mtetra
.042 0 .432 r
.7043 .61453 .69477 .41772 .69623 .41289 .69563 .41552 Mtetra
0 0 0 r
.69563 .41552 .69623 .41289 .69781 .4104 .69705 .41002 Mtetra
.884 .913 .842 r
.69705 .41002 .69781 .4104 .69945 .40919 .69867 .40825 Mtetra
.679 .758 .911 r
.69867 .40825 .69945 .40919 .70114 .40862 .70035 .40764 Mtetra
.577 .711 .934 r
.70035 .40764 .70114 .40862 .70284 .40831 .70206 .40743 Mtetra
.599 .744 .946 r
.70206 .40743 .70284 .40831 .70454 .40799 .70376 .40712 Mtetra
.632 .76 .939 r
.70376 .40712 .70454 .40799 .70624 .40762 .70545 .4067 Mtetra
.639 .747 .927 r
.70545 .4067 .70624 .40762 .70793 .40723 .70715 .40625 Mtetra
.678 .751 .906 r
.70715 .40625 .70793 .40723 .70961 .40648 .70884 .40565 Mtetra
.692 .79 .925 r
.70884 .40565 .70961 .40648 .71129 .40564 .71052 .40498 Mtetra
.66 .826 .963 r
.71052 .40498 .71129 .40564 .71298 .40509 .71221 .40441 Mtetra
.516 .764 .986 r
.71221 .40441 .71298 .40509 .71474 .40572 .71393 .40425 Mtetra
.505 .581 .865 r
.71393 .40425 .71474 .40572 .7166 .40802 .71567 .40443 Mtetra
.543 .448 .697 r
.71567 .40443 .7166 .40802 .71873 .41469 .71741 .40472 Mtetra
.581 .402 .604 r
.71741 .40472 .71873 .41469 .7316 .59889 .71912 .40425 Mtetra
.562 .351 .552 r
.71912 .40425 .7316 .59889 .73329 .59662 .7208 .4034 Mtetra
.561 .35 .552 r
.7208 .4034 .73329 .59662 .73502 .59488 .72251 .4031 Mtetra
.555 .346 .552 r
.72251 .4031 .73502 .59488 .7375 .60513 .72444 .40613 Mtetra
.069 0 .452 r
.72444 .40613 .7375 .60513 .73963 .60973 .73853 .6044 Mtetra
.015 .056 .56 r
.73853 .6044 .73963 .60973 .74161 .61188 .74074 .61015 Mtetra
.234 .398 .822 r
.74074 .61015 .74161 .61188 .7435 .61247 .74267 .61138 Mtetra
.593 .708 .924 r
.74267 .61138 .7435 .61247 .74534 .61222 .74451 .6111 Mtetra
.689 .742 .891 r
.74451 .6111 .74534 .61222 .74716 .61169 .74632 .61039 Mtetra
.677 .703 .867 r
.74632 .61039 .74716 .61169 .74898 .61116 .74813 .60972 Mtetra
.65 .671 .857 r
.74813 .60972 .74898 .61116 .75081 .61066 .74996 .60919 Mtetra
.655 .67 .852 r
.74996 .60919 .75081 .61066 .75263 .61011 .75178 .60863 Mtetra
.661 .672 .849 r
.75178 .60863 .75263 .61011 .75445 .60948 .7536 .60804 Mtetra
.666 .678 .852 r
.7536 .60804 .75445 .60948 .75626 .6088 .75542 .60741 Mtetra
.667 .687 .86 r
.75542 .60741 .75626 .6088 .75808 .60811 .75724 .60679 Mtetra
.649 .69 .875 r
.75724 .60679 .75808 .60811 .75991 .60764 .75907 .60628 Mtetra
.637 .677 .872 r
.75907 .60628 .75991 .60764 .76176 .60729 .76091 .60583 Mtetra
.654 .671 .854 r
.76091 .60583 .76176 .60729 .76358 .60665 .76274 .60527 Mtetra
.68 .694 .856 r
.76274 .60527 .76358 .60665 .76534 .60512 .76456 .60457 Mtetra
.748 .892 .944 r
.76456 .60457 .76534 .60512 .767 .60206 .76636 .60358 Mtetra
.01 0 0 r
.76636 .60358 .767 .60206 .7684 .59552 .76811 .6019 Mtetra
.175 0 .372 r
.76811 .6019 .7684 .59552 .75608 .39792 .7696 .59654 Mtetra
.074 0 .45 r
.7696 .59654 .75608 .39792 .75746 .39265 .75697 .39538 Mtetra
0 0 .009 r
.75697 .39538 .75746 .39265 .75906 .39044 .75836 .39033 Mtetra
.324 .803 .899 r
.75836 .39033 .75906 .39044 .76086 .39088 .7601 .39001 Mtetra
.905 .509 .097 r
.7601 .39001 .76086 .39088 .76312 .39761 .76234 .39645 Mtetra
.975 .675 .374 r
.76234 .39645 .76312 .39761 .77982 .59801 .77902 .59701 Mtetra
.615 .153 0 r
.77902 .59701 .77982 .59801 .78191 .60081 .78111 .59987 Mtetra
.551 .728 .957 r
.78111 .59987 .78191 .60081 .78378 .60061 .78298 .59968 Mtetra
.703 .79 .918 r
.78298 .59968 .78378 .60061 .78561 .59982 .78481 .59891 Mtetra
.632 .768 .945 r
.78481 .59891 .78561 .59982 .78746 .59939 .78666 .59844 Mtetra
.493 .695 .959 r
.78666 .59844 .78746 .59939 .78936 .59948 .78855 .59843 Mtetra
.657 .746 .916 r
.78855 .59843 .78936 .59948 .79121 .59901 .7904 .59787 Mtetra
.871 .784 .762 r
.7904 .59787 .79121 .59901 .79292 .59665 .7921 .59542 Mtetra
.97 .736 .529 r
.7921 .59542 .79292 .59665 .79404 .58687 .79317 .58497 Mtetra
.976 .681 .386 r
.79317 .58497 .79404 .58687 .78003 .38693 .77927 .38584 Mtetra
.915 .779 .697 r
.77927 .38584 .78003 .38693 .78154 .38349 .78078 .38249 Mtetra
.726 .767 .885 r
.78078 .38249 .78154 .38349 .78325 .38263 .78249 .38162 Mtetra
.607 .721 .925 r
.78249 .38162 .78325 .38263 .785 .38232 .78425 .38129 Mtetra
.651 .736 .911 r
.78425 .38129 .785 .38232 .78674 .38183 .78599 .38079 Mtetra
.741 .765 .872 r
.78599 .38079 .78674 .38183 .78845 .38087 .78769 .37982 Mtetra
.655 .734 .907 r
.78769 .37982 .78845 .38087 .79019 .38035 .78944 .37931 Mtetra
.119 .433 .873 r
.78944 .37931 .79019 .38035 .79206 .38133 .7913 .38027 Mtetra
.892 .5 .057 r
.7913 .38027 .79206 .38133 .79443 .38829 .79366 .38711 Mtetra
.976 .672 .357 r
.79366 .38711 .79443 .38829 .81309 .5879 .8123 .58686 Mtetra
.59 .136 0 r
.8123 .58686 .81309 .5879 .81524 .5908 .81445 .5898 Mtetra
.6 .735 .939 r
.81445 .5898 .81524 .5908 .81713 .59045 .81634 .58946 Mtetra
.753 .793 .885 r
.81634 .58946 .81713 .59045 .81894 .58937 .81816 .58839 Mtetra
.773 .801 .875 r
.81816 .58839 .81894 .58937 .82075 .58814 .81997 .58718 Mtetra
.691 .782 .921 r
.81997 .58718 .82075 .58814 .8226 .58737 .82182 .58646 Mtetra
.674 .785 .933 r
.82182 .58646 .8226 .58737 .82445 .58669 .82368 .58581 Mtetra
.632 .779 .952 r
.82368 .58581 .82445 .58669 .82633 .58617 .82556 .58532 Mtetra
.568 .758 .968 r
.82556 .58532 .82633 .58617 .82822 .5859 .82745 .58504 Mtetra
.549 .749 .969 r
.82745 .58504 .82822 .5859 .83012 .58569 .82935 .58482 Mtetra
.481 .712 .972 r
.82935 .58482 .83012 .58569 .83205 .58569 .83127 .5848 Mtetra
.404 .667 .967 r
.83127 .5848 .83205 .58569 .83399 .5859 .83322 .58499 Mtetra
.611 .764 .953 r
.83322 .58499 .83399 .5859 .83588 .5855 .83511 .58458 Mtetra
.867 .828 .806 r
.83511 .58458 .83588 .5855 .83762 .58344 .83685 .58253 Mtetra
.982 .751 .513 r
.83685 .58253 .83762 .58344 .8386 .57319 .83785 .57252 Mtetra
.978 .679 .361 r
.83785 .57252 .8386 .57319 .82199 .37376 .82125 .37278 Mtetra
.937 .795 .679 r
.82125 .37278 .82199 .37376 .82346 .37011 .82272 .3691 Mtetra
.727 .77 .887 r
.82272 .3691 .82346 .37011 .82519 .36923 .82445 .36822 Mtetra
.6 .719 .928 r
.82445 .36822 .82519 .36923 .82697 .36893 .82624 .36791 Mtetra
.6 .718 .927 r
.82624 .36791 .82697 .36893 .82876 .36863 .82803 .36761 Mtetra
.74 .772 .879 r
.82803 .36761 .82876 .36863 .83049 .36768 .82975 .36665 Mtetra
.657 .74 .911 r
.82975 .36665 .83049 .36768 .83225 .36715 .83152 .36611 Mtetra
.234 .511 .908 r
.83152 .36611 .83225 .36715 .83414 .36788 .83341 .36684 Mtetra
.882 .489 .033 r
.83341 .36684 .83414 .36788 .83666 .37496 .83592 .37393 Mtetra
.975 .667 .334 r
.83592 .37393 .83666 .37496 .85816 .57558 .85739 .5746 Mtetra
.656 .203 0 r
.85739 .5746 .85816 .57558 .86044 .57901 .85968 .57802 Mtetra
.383 .63 .951 r
.85968 .57802 .86044 .57901 .86242 .57932 .86166 .57833 Mtetra
.694 .78 .917 r
.86166 .57833 .86242 .57932 .8643 .57857 .86353 .57758 Mtetra
.874 .819 .791 r
.86353 .57758 .8643 .57857 .86603 .57636 .86526 .57537 Mtetra
.978 .765 .548 r
.86526 .57537 .86603 .57636 .8672 .56863 .86644 .56762 Mtetra
.977 .675 .347 r
.86644 .56762 .8672 .56863 .8486 .36622 .84787 .36517 Mtetra
.948 .784 .644 r
.84787 .36517 .8486 .36622 .84999 .36184 .84926 .36079 Mtetra
.745 .771 .873 r
.84926 .36079 .84999 .36184 .85172 .36083 .851 .35978 Mtetra
.621 .722 .919 r
.851 .35978 .85172 .36083 .85352 .36045 .85279 .3594 Mtetra
.59 .708 .925 r
.85279 .3594 .85352 .36045 .85533 .36019 .8546 .35914 Mtetra
.748 .772 .872 r
.8546 .35914 .85533 .36019 .85706 .35917 .85634 .35812 Mtetra
.674 .745 .904 r
.85634 .35812 .85706 .35917 .85883 .35855 .85811 .3575 Mtetra
.379 .596 .931 r
.85811 .3575 .85883 .35855 .86072 .35894 .86 .35789 Mtetra
.803 .389 0 r
.86 .35789 .86072 .35894 .86313 .36427 .8624 .36321 Mtetra
.973 .663 .318 r
.8624 .36321 .86313 .36427 .88653 .56626 .88578 .56526 Mtetra
.716 .276 0 r
.88578 .56526 .88653 .56626 .88894 .57041 .88819 .56941 Mtetra
.502 .693 .954 r
.88819 .56941 .88894 .57041 .89091 .57039 .89016 .56939 Mtetra
.693 .78 .917 r
.89016 .56939 .89091 .57039 .8928 .56964 .89205 .56864 Mtetra
.733 .793 .9 r
.89205 .56864 .8928 .56964 .89467 .56867 .89392 .56767 Mtetra
.494 .689 .954 r
.89392 .56767 .89467 .56867 .89665 .56867 .8959 .56767 Mtetra
.622 .751 .939 r
.8959 .56767 .89665 .56867 .89858 .56823 .89783 .56723 Mtetra
.808 .814 .855 r
.89783 .56723 .89858 .56823 .9004 .56675 .89965 .56575 Mtetra
.979 .773 .556 r
.89965 .56575 .9004 .56675 .90159 .55967 .90084 .55866 Mtetra
.976 .671 .329 r
.90084 .55866 .90159 .55967 .88083 .35658 .88012 .35551 Mtetra
.959 .783 .621 r
.88012 .35551 .88083 .35658 .88214 .35172 .88143 .35066 Mtetra
.743 .771 .876 r
.88143 .35066 .88214 .35172 .88389 .35072 .88318 .34966 Mtetra
.605 .715 .922 r
.88318 .34966 .88389 .35072 .88572 .3504 .88501 .34934 Mtetra
.518 .672 .933 r
.88501 .34934 .88572 .3504 .88758 .35039 .88687 .34933 Mtetra
.654 .737 .91 r
.88687 .34933 .88758 .35039 .88938 .34986 .88868 .3488 Mtetra
.661 .74 .908 r
.88868 .3488 .88938 .34986 .89119 .34929 .89048 .34823 Mtetra
.675 .746 .904 r
.89048 .34823 .89119 .34929 .89298 .34867 .89228 .34761 Mtetra
.765 .779 .865 r
.89228 .34761 .89298 .34867 .89472 .34753 .89401 .34647 Mtetra
.7 .756 .896 r
.89401 .34647 .89472 .34753 .8965 .34677 .8958 .34571 Mtetra
.504 .665 .934 r
.8958 .34571 .8965 .34677 .89838 .34681 .89767 .34575 Mtetra
.735 .316 0 r
.89767 .34575 .89838 .34681 .90081 .35152 .90011 .35047 Mtetra
.971 .656 .295 r
.90011 .35047 .90081 .35152 .92681 .5542 .92608 .5532 Mtetra
.748 .317 0 r
.92608 .5532 .92681 .5542 .9294 .55905 .92866 .55805 Mtetra
.479 .682 .955 r
.92866 .55805 .9294 .55905 .93141 .55911 .93068 .5581 Mtetra
.686 .779 .922 r
.93068 .5581 .93141 .55911 .93333 .55838 .9326 .55737 Mtetra
.76 .805 .889 r
.9326 .55737 .93333 .55838 .9352 .55724 .93447 .55624 Mtetra
.441 .692 .972 r
.30923 .73095 .31022 .73175 .31175 .73181 .31075 .73101 Mtetra
.61 .755 .947 r
.31075 .73101 .31175 .73181 .3133 .73149 .3123 .73069 Mtetra
.771 .781 .861 r
.3123 .73069 .3133 .73149 .31489 .73043 .3139 .7296 Mtetra
.912 .731 .644 r
.3139 .7296 .31489 .73043 .31677 .72451 .3158 .72341 Mtetra
.936 .686 .534 r
.3158 .72341 .31677 .72451 .32956 .53121 .32866 .52993 Mtetra
.883 .707 .658 r
.32866 .52993 .32956 .53121 .33131 .52605 .33039 .52497 Mtetra
.742 .718 .829 r
.33039 .52497 .33131 .52605 .33282 .52503 .3319 .52401 Mtetra
.601 .69 .905 r
.3319 .52401 .33282 .52503 .33428 .52473 .33336 .52377 Mtetra
.449 .642 .94 r
.33336 .52377 .33428 .52473 .33573 .52481 .3348 .52391 Mtetra
.633 .728 .916 r
.3348 .52391 .33573 .52481 .3372 .52443 .33627 .52356 Mtetra
.651 .738 .913 r
.33627 .52356 .3372 .52443 .33868 .524 .33775 .52314 Mtetra
.659 .741 .91 r
.33775 .52314 .33868 .524 .34015 .52355 .33923 .52268 Mtetra
.754 .758 .856 r
.33923 .52268 .34015 .52355 .34166 .5226 .34074 .52172 Mtetra
.705 .75 .887 r
.34074 .52172 .34166 .5226 .34315 .52193 .34223 .52106 Mtetra
.5 .687 .951 r
.34223 .52106 .34315 .52193 .34461 .52191 .34368 .52106 Mtetra
.928 .549 .256 r
.34368 .52106 .34461 .52191 .34586 .52578 .34492 .52513 Mtetra
.94 .683 .521 r
.34492 .52513 .34586 .52578 .3371 .71844 .33609 .71814 Mtetra
.914 .563 .359 r
.33609 .71814 .3371 .71844 .33837 .7238 .33737 .72323 Mtetra
.119 .582 .918 r
.33737 .72323 .33837 .7238 .33989 .72422 .3389 .72358 Mtetra
.69 .813 .941 r
.3389 .72358 .33989 .72422 .34147 .72367 .34048 .72295 Mtetra
.771 .803 .879 r
.34048 .72295 .34147 .72367 .34307 .7227 .34209 .7219 Mtetra
.522 .729 .968 r
.34209 .7219 .34307 .7227 .34463 .72262 .34365 .7218 Mtetra
.596 .749 .95 r
.34365 .7218 .34463 .72262 .3462 .72234 .34522 .72152 Mtetra
.755 .78 .874 r
.34522 .72152 .3462 .72234 .3478 .72138 .34682 .72054 Mtetra
.909 .741 .662 r
.34682 .72054 .3478 .72138 .3496 .71646 .34863 .71543 Mtetra
.94 .687 .527 r
.34863 .71543 .3496 .71646 .36067 .52258 .35978 .52119 Mtetra
.89 .702 .642 r
.35978 .52119 .36067 .52258 .36244 .51647 .36154 .51537 Mtetra
.776 .723 .803 r
.36154 .51537 .36244 .51647 .36398 .51512 .36307 .51408 Mtetra
.622 .694 .896 r
.36307 .51408 .36398 .51512 .36547 .51475 .36455 .51377 Mtetra
.474 .649 .935 r
.36455 .51377 .36547 .51475 .36694 .51478 .36602 .51387 Mtetra
.616 .719 .92 r
.36602 .51387 .36694 .51478 .36842 .51446 .36751 .51357 Mtetra
.654 .737 .91 r
.36751 .51357 .36842 .51446 .36992 .51401 .369 .51313 Mtetra
.663 .74 .907 r
.369 .51313 .36992 .51401 .37141 .51354 .3705 .51265 Mtetra
.748 .756 .859 r
.3705 .51265 .37141 .51354 .37293 .51262 .37202 .51173 Mtetra
.718 .752 .879 r
.37202 .51173 .37293 .51262 .37444 .51188 .37353 .51099 Mtetra
.562 .708 .939 r
.37353 .51099 .37444 .51188 .37593 .51173 .37501 .51084 Mtetra
.884 .453 .086 r
.37501 .51084 .37593 .51173 .37727 .51469 .37636 .5138 Mtetra
.944 .684 .513 r
.37636 .5138 .37727 .51469 .37034 .70685 .36937 .70602 Mtetra
.943 .608 .364 r
.36937 .70602 .37034 .70685 .37161 .71384 .37064 .71301 Mtetra
0 .387 .827 r
.37064 .71301 .37161 .71384 .37315 .71461 .37217 .71379 Mtetra
.672 .77 .924 r
.37217 .71379 .37315 .71461 .37474 .71405 .37377 .71324 Mtetra
.763 .786 .871 r
.37377 .71324 .37474 .71405 .37636 .71301 .37539 .7122 Mtetra
.69 .778 .919 r
.37539 .7122 .37636 .71301 .37797 .71229 .37699 .71158 Mtetra
.648 .791 .951 r
.37699 .71158 .37797 .71229 .37957 .71176 .37859 .7111 Mtetra
.672 .811 .949 r
.37859 .7111 .37957 .71176 .38117 .71128 .38019 .71054 Mtetra
.755 .801 .89 r
.38019 .71054 .38117 .71128 .38276 .71092 .38181 .70958 Mtetra
.749 .698 .803 r
.38181 .70958 .38276 .71092 .38435 .71063 .38344 .7084 Mtetra
.706 .604 .739 r
.38344 .7084 .38435 .71063 .38594 .71035 .38507 .70719 Mtetra
.635 .521 .706 r
.38507 .70719 .38594 .71035 .38754 .71005 .38668 .70653 Mtetra
.597 .485 .697 r
.38668 .70653 .38754 .71005 .38914 .70973 .38827 .70624 Mtetra
.586 .479 .699 r
.38827 .70624 .38914 .70973 .39073 .70939 .38986 .70608 Mtetra
.598 .493 .705 r
.38986 .70608 .39073 .70939 .39233 .70903 .39146 .70581 Mtetra
.605 .5 .709 r
.39146 .70581 .39233 .70903 .39394 .70865 .39306 .70547 Mtetra
.607 .503 .71 r
.39306 .70547 .39394 .70865 .39554 .70828 .39466 .70512 Mtetra
.609 .505 .711 r
.39466 .70512 .39554 .70828 .39714 .70794 .39626 .70474 Mtetra
.61 .504 .709 r
.39626 .70474 .39714 .70794 .39874 .70762 .39787 .70435 Mtetra
.611 .502 .706 r
.39787 .70435 .39874 .70762 .40035 .70728 .39948 .70393 Mtetra
.62 .506 .701 r
.39948 .70393 .40035 .70728 .40196 .70688 .40109 .70341 Mtetra
.618 .5 .697 r
.40109 .70341 .40196 .70688 .40357 .70645 .4027 .70289 Mtetra
.604 .489 .695 r
.4027 .70289 .40357 .70645 .40518 .70597 .40431 .70253 Mtetra
.554 .461 .703 r
.40431 .70253 .40518 .70597 .40679 .70545 .4059 .70268 Mtetra
.521 .469 .739 r
.4059 .70268 .40679 .70545 .40841 .7049 .40749 .70302 Mtetra
.513 .534 .815 r
.40749 .70302 .40841 .7049 .41003 .70435 .40908 .70325 Mtetra
.578 .682 .911 r
.40908 .70325 .41003 .70435 .41164 .70392 .41068 .70308 Mtetra
.64 .76 .935 r
.41068 .70308 .41164 .70392 .41326 .70351 .4123 .70264 Mtetra
.66 .76 .923 r
.4123 .70264 .41326 .70351 .41487 .703 .41392 .70213 Mtetra
.638 .754 .932 r
.41392 .70213 .41487 .703 .41651 .70209 .41554 .70171 Mtetra
.542 .849 .998 r
.41554 .70171 .41651 .70209 .41815 .70085 .41715 .70135 Mtetra
.058 0 0 r
.41715 .70135 .41815 .70085 .4198 .69952 .41877 .70099 Mtetra
.365 0 .12 r
.41877 .70099 .4198 .69952 .42143 .6986 .42039 .70059 Mtetra
.415 .046 .228 r
.42039 .70059 .42143 .6986 .42305 .69812 .42201 .70016 Mtetra
.415 .049 .233 r
.42201 .70016 .42305 .69812 .42467 .6978 .42364 .69971 Mtetra
.403 .029 .211 r
.42364 .69971 .42467 .6978 .42629 .69742 .42526 .69926 Mtetra
.395 .016 .197 r
.42526 .69926 .42629 .69742 .42791 .69696 .42689 .6988 Mtetra
.39 .011 .194 r
.42689 .6988 .42791 .69696 .42954 .6965 .42852 .69832 Mtetra
.377 0 .185 r
.42852 .69832 .42954 .6965 .43116 .69603 .43015 .69781 Mtetra
.363 0 .17 r
.43015 .69781 .43116 .69603 .43279 .69555 .43178 .69725 Mtetra
.354 0 .153 r
.43178 .69725 .43279 .69555 .43442 .69507 .43341 .6967 Mtetra
.358 0 .143 r
.43341 .6967 .43442 .69507 .43605 .69462 .43504 .6962 Mtetra
.364 0 .139 r
.43504 .6962 .43605 .69462 .43768 .69418 .43667 .69574 Mtetra
.364 0 .136 r
.43667 .69574 .43768 .69418 .43931 .69373 .4383 .69529 Mtetra
.428 .026 .172 r
.4383 .69529 .43931 .69373 .44093 .69364 .43993 .69508 Mtetra
.419 .005 .145 r
.43993 .69508 .44093 .69364 .44256 .69355 .44156 .69487 Mtetra
.236 0 .008 r
.44156 .69487 .44256 .69355 .4442 .69279 .4432 .6942 Mtetra
.618 .827 .428 r
.4432 .6942 .4442 .69279 .44591 .68905 .44488 .69172 Mtetra
.977 .853 .461 r
.44488 .69172 .44591 .68905 .4518 .49515 .44669 .6836 Mtetra
0 0 .323 r
.44669 .6836 .4518 .49515 .45349 .48815 .45254 .49019 Mtetra
0 0 0 r
.45254 .49019 .45349 .48815 .45507 .48598 .45414 .48696 Mtetra
.084 0 0 r
.45414 .48696 .45507 .48598 .45662 .48532 .45569 .48622 Mtetra
.362 0 0 r
.45569 .48622 .45662 .48532 .45816 .48507 .45723 .48608 Mtetra
.366 0 .025 r
.45723 .48608 .45816 .48507 .4597 .48479 .45877 .48589 Mtetra
.269 0 0 r
.45877 .48589 .4597 .48479 .46124 .48431 .46032 .48542 Mtetra
.274 0 0 r
.46032 .48542 .46124 .48431 .46279 .48383 .46187 .48495 Mtetra
.46187 .48495 .46279 .48383 .46434 .48335 .46342 .48448 Mtetra
.275 0 .002 r
.46342 .48448 .46434 .48335 .46589 .48286 .46497 .484 Mtetra
.279 0 .008 r
.46497 .484 .46589 .48286 .46744 .48237 .46653 .48352 Mtetra
.311 0 .031 r
.46653 .48352 .46744 .48237 .46899 .48189 .46808 .48312 Mtetra
.343 0 .071 r
.46808 .48312 .46899 .48189 .47055 .48141 .46963 .48275 Mtetra
.315 0 .08 r
.46963 .48275 .47055 .48141 .4721 .48095 .47118 .48225 Mtetra
.13 0 0 r
.47118 .48225 .4721 .48095 .47365 .48052 .47275 .48133 Mtetra
0 0 0 r
.47275 .48133 .47365 .48052 .47521 .48013 .47431 .48009 Mtetra
.792 .969 .914 r
.47431 .48009 .47521 .48013 .47676 .47975 .47588 .47893 Mtetra
.738 .78 .887 r
.47588 .47893 .47676 .47975 .47832 .47934 .47744 .47808 Mtetra
.663 .677 .852 r
.47744 .47808 .47832 .47934 .47987 .47888 .479 .47756 Mtetra
.644 .659 .85 r
.479 .47756 .47987 .47888 .48143 .47839 .48056 .47713 Mtetra
.646 .671 .859 r
.48056 .47713 .48143 .47839 .48299 .47785 .48212 .4767 Mtetra
.66 .694 .871 r
.48212 .4767 .48299 .47785 .48455 .47728 .48368 .47621 Mtetra
.659 .71 .885 r
.48368 .47621 .48455 .47728 .48612 .47669 .48524 .47573 Mtetra
.653 .729 .905 r
.48524 .47573 .48612 .47669 .48768 .47613 .48681 .47527 Mtetra
.642 .749 .926 r
.48681 .47527 .48768 .47613 .48924 .47562 .48837 .47485 Mtetra
.639 .772 .944 r
.48837 .47485 .48924 .47562 .49081 .47511 .48993 .47443 Mtetra
.643 .795 .955 r
.48993 .47443 .49081 .47511 .49237 .47457 .4915 .47398 Mtetra
.653 .823 .965 r
.4915 .47398 .49237 .47457 .49394 .47398 .49307 .47348 Mtetra
.655 .849 .974 r
.49307 .47348 .49394 .47398 .49551 .47347 .49463 .47294 Mtetra
.673 .843 .965 r
.49463 .47294 .49551 .47347 .49707 .47324 .4962 .47236 Mtetra
.691 .759 .904 r
.4962 .47236 .49707 .47324 .49864 .4734 .49777 .47174 Mtetra
.666 .626 .799 r
.49777 .47174 .49864 .4734 .5002 .4737 .49934 .47112 Mtetra
.652 .551 .727 r
.49934 .47112 .5002 .4737 .50177 .47358 .50092 .47039 Mtetra
.647 .522 .698 r
.50092 .47039 .50177 .47358 .50334 .47269 .50249 .46957 Mtetra
.614 .504 .706 r
.50249 .46957 .50334 .47269 .50492 .47224 .50406 .46914 Mtetra
.468 .414 .714 r
.50406 .46914 .50492 .47224 .50648 .47369 .50563 .46992 Mtetra
0 0 .412 r
.50563 .46992 .50648 .47369 .50707 .6651 .50718 .47484 Mtetra
0 0 .363 r
.50718 .47484 .50707 .6651 .5087 .67436 .5078 .66958 Mtetra
.112 .123 .591 r
.5078 .66958 .5087 .67436 .51036 .67641 .50945 .6734 Mtetra
.572 .491 .725 r
.50945 .6734 .51036 .67641 .51204 .67625 .51113 .67338 Mtetra
.647 .542 .721 r
.51113 .67338 .51204 .67625 .51371 .67559 .5128 .67263 Mtetra
.658 .544 .714 r
.5128 .67263 .51371 .67559 .51539 .67487 .51448 .67172 Mtetra
.617 .513 .713 r
.51448 .67172 .51539 .67487 .51707 .67448 .51616 .67125 Mtetra
.617 .51 .709 r
.51616 .67125 .51707 .67448 .51875 .67408 .51784 .67076 Mtetra
.617 .506 .706 r
.51784 .67076 .51875 .67408 .52043 .67367 .51952 .67027 Mtetra
.616 .503 .703 r
.51952 .67027 .52043 .67367 .52212 .6732 .5212 .66979 Mtetra
.616 .503 .702 r
.5212 .66979 .52212 .6732 .5238 .67272 .52289 .6693 Mtetra
.619 .505 .701 r
.52289 .6693 .5238 .67272 .52548 .67223 .52457 .66876 Mtetra
.626 .507 .698 r
.52457 .66876 .52548 .67223 .52717 .67174 .52626 .66813 Mtetra
.614 .496 .695 r
.52626 .66813 .52717 .67174 .52886 .67123 .52794 .66762 Mtetra
.586 .478 .698 r
.52794 .66762 .52886 .67123 .53054 .67069 .52963 .66745 Mtetra
.534 .459 .717 r
.52963 .66745 .53054 .67069 .53223 .67009 .53132 .66777 Mtetra
.525 .504 .776 r
.53132 .66777 .53223 .67009 .53392 .66948 .53301 .66803 Mtetra
.545 .61 .869 r
.53301 .66803 .53392 .66948 .53561 .66889 .5347 .66803 Mtetra
.633 .762 .94 r
.5347 .66803 .53561 .66889 .5373 .66836 .53639 .6676 Mtetra
.662 .795 .946 r
.53639 .6676 .5373 .66836 .53899 .66785 .53809 .66705 Mtetra
.672 .788 .936 r
.53809 .66705 .53899 .66785 .54069 .66735 .53978 .66646 Mtetra
.653 .763 .93 r
.53978 .66646 .54069 .66735 .54238 .66685 .54148 .66596 Mtetra
.652 .762 .93 r
.54148 .66596 .54238 .66685 .54408 .66635 .54317 .66546 Mtetra
.65 .761 .93 r
.54317 .66546 .54408 .66635 .54577 .66587 .54487 .66497 Mtetra
.648 .759 .93 r
.54487 .66497 .54577 .66587 .54747 .66538 .54657 .66449 Mtetra
.646 .758 .931 r
.54657 .66449 .54747 .66538 .54917 .66491 .54827 .66401 Mtetra
.644 .758 .932 r
.54827 .66401 .54917 .66491 .55087 .66444 .54997 .66354 Mtetra
.642 .757 .933 r
.54997 .66354 .55087 .66444 .55257 .66397 .55167 .66308 Mtetra
.64 .758 .934 r
.55167 .66308 .55257 .66397 .55427 .66352 .55337 .66263 Mtetra
.634 .757 .936 r
.55337 .66263 .55427 .66352 .55597 .66307 .55507 .66219 Mtetra
.612 .754 .946 r
.55507 .66219 .55597 .66307 .55768 .66262 .55678 .66183 Mtetra
.629 .782 .955 r
.55678 .66183 .55768 .66262 .55938 .66218 .55849 .6614 Mtetra
.682 .796 .935 r
.55849 .6614 .55938 .66218 .56109 .66178 .56019 .66077 Mtetra
.76 .765 .857 r
.56019 .66077 .56109 .66178 .5628 .66143 .56189 .65966 Mtetra
.731 .655 .775 r
.56189 .65966 .5628 .66143 .56451 .66109 .56359 .65841 Mtetra
.687 .575 .723 r
.56359 .65841 .56451 .66109 .56622 .66072 .56529 .65722 Mtetra
.621 .504 .699 r
.56529 .65722 .56622 .66072 .56793 .6603 .567 .65665 Mtetra
.604 .489 .695 r
.567 .65665 .56793 .6603 .56964 .65985 .56871 .65627 Mtetra
.599 .488 .698 r
.56871 .65627 .56964 .65985 .57136 .65939 .57043 .65594 Mtetra
.611 .5 .702 r
.57043 .65594 .57136 .65939 .57307 .65893 .57214 .65549 Mtetra
.612 .501 .703 r
.57214 .65549 .57307 .65893 .57479 .65846 .57386 .65504 Mtetra
.613 .502 .703 r
.57386 .65504 .57479 .65846 .5765 .65799 .57557 .65458 Mtetra
.613 .503 .704 r
.57557 .65458 .5765 .65799 .57822 .65751 .57729 .6541 Mtetra
.614 .503 .704 r
.57729 .6541 .57822 .65751 .57994 .65703 .57901 .65363 Mtetra
.57901 .65363 .57994 .65703 .58166 .65655 .58072 .65315 Mtetra
.613 .503 .704 r
.58072 .65315 .58166 .65655 .58338 .65609 .58244 .65269 Mtetra
.613 .503 .705 r
.58244 .65269 .58338 .65609 .5851 .65561 .58417 .65222 Mtetra
.611 .502 .705 r
.58417 .65222 .5851 .65561 .58682 .65513 .58589 .65178 Mtetra
.565 .475 .712 r
.58589 .65178 .58682 .65513 .58855 .65492 .58762 .65183 Mtetra
.613 .515 .718 r
.58762 .65183 .58855 .65492 .59027 .65439 .58935 .6514 Mtetra
.695 .566 .705 r
.58935 .6514 .59027 .65439 .59198 .65319 .59105 .64996 Mtetra
.88 .658 .597 r
.59105 .64996 .59198 .65319 .59363 .64868 .59261 .64103 Mtetra
.957 .681 .472 r
.59261 .64103 .59363 .64868 .59141 .45387 .59043 .44569 Mtetra
.695 .492 .608 r
.59043 .44569 .59141 .45387 .59286 .4448 .59198 .44151 Mtetra
.658 .528 .693 r
.59198 .44151 .59286 .4448 .59447 .44365 .59359 .44049 Mtetra
.613 .505 .706 r
.59359 .44049 .59447 .44365 .5961 .44328 .59522 .44006 Mtetra
.583 .484 .707 r
.59522 .44006 .5961 .44328 .59774 .44315 .59685 .43993 Mtetra
.611 .501 .704 r
.59685 .43993 .59774 .44315 .59935 .44181 .59848 .43951 Mtetra
.623 .553 .755 r
.59848 .43951 .59935 .44181 .60096 .44051 .60012 .43909 Mtetra
.642 .65 .843 r
.60012 .43909 .60096 .44051 .60257 .43938 .60175 .43866 Mtetra
.671 .8 .944 r
.60175 .43866 .60257 .43938 .6042 .43875 .60338 .43809 Mtetra
.677 .821 .952 r
.60338 .43809 .6042 .43875 .60583 .43825 .60501 .43749 Mtetra
.682 .796 .935 r
.60501 .43749 .60583 .43825 .60746 .43783 .60664 .43689 Mtetra
.691 .754 .9 r
.60664 .43689 .60746 .43783 .6091 .43737 .60827 .43624 Mtetra
.672 .71 .877 r
.60827 .43624 .6091 .43737 .61073 .43691 .6099 .43567 Mtetra
.644 .68 .869 r
.6099 .43567 .61073 .43691 .61237 .43643 .61154 .43523 Mtetra
.632 .683 .88 r
.61154 .43523 .61237 .43643 .61399 .43547 .61318 .43485 Mtetra
.413 .729 .99 r
.61318 .43485 .61399 .43547 .61562 .43477 .61483 .43487 Mtetra
.54 0 0 r
.61483 .43487 .61562 .43477 .61727 .43461 .6165 .43568 Mtetra
.897 .55 .38 r
.6165 .43568 .61727 .43461 .619 .4374 .61836 .44286 Mtetra
.96 .675 .451 r
.61836 .44286 .619 .4374 .62631 .62982 .62571 .63813 Mtetra
.662 .387 .494 r
.62571 .63813 .62631 .62982 .62837 .64001 .62758 .64176 Mtetra
.523 .133 .243 r
.62758 .64176 .62837 .64001 .63015 .64046 .62935 .64197 Mtetra
.334 0 .113 r
.62935 .64197 .63015 .64046 .63189 .63981 .6311 .6414 Mtetra
.241 0 .085 r
.6311 .6414 .63189 .63981 .63363 .63882 .63284 .64047 Mtetra
.35 0 .147 r
.63284 .64047 .63363 .63882 .6354 .63909 .63459 .63987 Mtetra
.132 0 0 r
.63459 .63987 .6354 .63909 .63718 .63945 .63634 .63932 Mtetra
.507 .896 .951 r
.63634 .63932 .63718 .63945 .63896 .63962 .63809 .63876 Mtetra
.661 .778 .936 r
.63809 .63876 .63896 .63962 .64072 .63919 .63985 .6382 Mtetra
.661 .75 .916 r
.63985 .6382 .64072 .63919 .64247 .63854 .6416 .63765 Mtetra
.657 .77 .933 r
.6416 .63765 .64247 .63854 .64422 .63781 .64336 .63711 Mtetra
.64 .811 .965 r
.64336 .63711 .64422 .63781 .64597 .63725 .64512 .63659 Mtetra
.63 .823 .975 r
.64512 .63659 .64597 .63725 .64773 .63674 .64688 .63609 Mtetra
.628 .823 .975 r
.64688 .63609 .64773 .63674 .64949 .63629 .64864 .6356 Mtetra
.641 .815 .967 r
.64864 .6356 .64949 .63629 .65126 .63602 .6504 .63508 Mtetra
.652 .757 .927 r
.6504 .63508 .65126 .63602 .65303 .63573 .65217 .63456 Mtetra
.648 .711 .893 r
.65217 .63456 .65303 .63573 .6548 .63528 .65393 .63407 Mtetra
.528 .651 .913 r
.65393 .63407 .6548 .63528 .65656 .63465 .65571 .63407 Mtetra
.494 .789 .998 r
.65571 .63407 .65656 .63465 .65831 .6336 .65749 .63387 Mtetra
.362 .821 .724 r
.65749 .63387 .65831 .6336 .66002 .63171 .65925 .63309 Mtetra
.742 .841 .393 r
.65925 .63309 .66002 .63171 .66152 .62451 .6609 .62958 Mtetra
.923 .748 .262 r
.6609 .62958 .66152 .62451 .65538 .42717 .66202 .61268 Mtetra
.015 0 .417 r
.66202 .61268 .65538 .42717 .65688 .42252 .65617 .42404 Mtetra
0 0 0 r
.65617 .42404 .65688 .42252 .6585 .42118 .65775 .4215 Mtetra
.592 .935 .75 r
.65775 .4215 .6585 .42118 .66017 .42077 .65939 .42031 Mtetra
.688 .884 .97 r
.65939 .42031 .66017 .42077 .66186 .42071 .66104 .4196 Mtetra
.662 .714 .887 r
.66104 .4196 .66186 .42071 .66353 .42037 .66271 .41907 Mtetra
.634 .669 .866 r
.66271 .41907 .66353 .42037 .6652 .41989 .66438 .41867 Mtetra
.619 .676 .882 r
.66438 .41867 .6652 .41989 .66686 .41937 .66606 .41834 Mtetra
.651 .726 .904 r
.66606 .41834 .66686 .41937 .66852 .41868 .66773 .41786 Mtetra
.667 .782 .935 r
.66773 .41786 .66852 .41868 .67019 .41798 .6694 .41731 Mtetra
.67 .821 .956 r
.6694 .41731 .67019 .41798 .67185 .41741 .67107 .41672 Mtetra
.756 .836 .913 r
.67107 .41672 .67185 .41741 .67353 .417 .67272 .41577 Mtetra
.71 .711 .849 r
.67272 .41577 .67353 .417 .67522 .41696 .67438 .41495 Mtetra
.61 .571 .785 r
.67438 .41495 .67522 .41696 .67696 .41768 .67606 .41466 Mtetra
.267 .292 .702 r
.67606 .41466 .67696 .41768 .67891 .42299 .67785 .41665 Mtetra
.718 .49 0 r
.67785 .41665 .67891 .42299 .69007 .62021 .68026 .43146 Mtetra
.041 0 .437 r
.68026 .43146 .69007 .62021 .69209 .62443 .69111 .62066 Mtetra
.347 .322 .688 r
.69111 .62066 .69209 .62443 .69394 .62518 .69302 .62262 Mtetra
.525 .493 .763 r
.69302 .62262 .69394 .62518 .69573 .62478 .69485 .62293 Mtetra
.598 .593 .817 r
.69485 .62293 .69573 .62478 .6975 .62387 .69665 .6227 Mtetra
.549 .671 .918 r
.69665 .6227 .6975 .62387 .69928 .62303 .69847 .62261 Mtetra
.489 .832 .998 r
.69847 .62261 .69928 .62303 .70105 .62198 .70027 .6223 Mtetra
.384 .827 .696 r
.70027 .6223 .70105 .62198 .70277 .62019 .70205 .62139 Mtetra
.713 .841 .405 r
.70205 .62139 .70277 .62019 .7043 .61453 .7037 .61822 Mtetra
.868 .742 .228 r
.7037 .61822 .7043 .61453 .69563 .41552 .70493 .60688 Mtetra
.036 0 .43 r
.70493 .60688 .69563 .41552 .69705 .41002 .6964 .41174 Mtetra
0 0 0 r
.6964 .41174 .69705 .41002 .69867 .40825 .69799 .40928 Mtetra
.235 0 0 r
.69799 .40928 .69867 .40825 .70035 .40764 .69967 .4087 Mtetra
.392 0 .05 r
.69967 .4087 .70035 .40764 .70206 .40743 .70138 .40855 Mtetra
.148 0 0 r
.70138 .40855 .70206 .40743 .70376 .40712 .70305 .40768 Mtetra
0 0 0 r
.70305 .40768 .70376 .40712 .70545 .4067 .7047 .40641 Mtetra
.788 .948 .926 r
.7047 .40641 .70545 .4067 .70715 .40625 .70636 .40525 Mtetra
.707 .755 .89 r
.70636 .40525 .70715 .40625 .70884 .40565 .70804 .4045 Mtetra
.651 .705 .887 r
.70804 .4045 .70884 .40565 .71052 .40498 .70974 .40402 Mtetra
.633 .737 .923 r
.70974 .40402 .71052 .40498 .71221 .40441 .71144 .4036 Mtetra
.66 .785 .94 r
.71144 .4036 .71221 .40441 .71393 .40425 .71313 .40306 Mtetra
.681 .71 .871 r
.71313 .40306 .71393 .40425 .71567 .40443 .71482 .40242 Mtetra
.656 .597 .776 r
.71482 .40242 .71567 .40443 .71741 .40472 .71652 .40178 Mtetra
.651 .538 .713 r
.71652 .40178 .71741 .40472 .71912 .40425 .7182 .40093 Mtetra
.638 .517 .698 r
.7182 .40093 .71912 .40425 .7208 .4034 .71988 .40016 Mtetra
.6 .496 .707 r
.71988 .40016 .7208 .4034 .72251 .4031 .72159 .39984 Mtetra
.375 .353 .707 r
.72159 .39984 .72251 .4031 .72444 .40613 .72342 .40139 Mtetra
0 0 .352 r
.72342 .40139 .72444 .40613 .73853 .6044 .72568 .40976 Mtetra
.061 0 .449 r
.72568 .40976 .73853 .6044 .74074 .61015 .73973 .60611 Mtetra
.349 .316 .68 r
.73973 .60611 .74074 .61015 .74267 .61138 .74171 .60825 Mtetra
.599 .508 .722 r
.74171 .60825 .74267 .61138 .74451 .6111 .74355 .60795 Mtetra
.654 .54 .712 r
.74355 .60795 .74451 .6111 .74632 .61039 .74534 .60701 Mtetra
.647 .528 .704 r
.74534 .60701 .74632 .61039 .74813 .60972 .74714 .60611 Mtetra
.623 .505 .698 r
.74714 .60611 .74813 .60972 .74996 .60919 .74896 .60546 Mtetra
.611 .494 .695 r
.74896 .60546 .74996 .60919 .75178 .60863 .75078 .60497 Mtetra
.571 .471 .702 r
.75078 .60497 .75178 .60863 .7536 .60804 .75264 .60496 Mtetra
.536 .472 .732 r
.75264 .60496 .7536 .60804 .75542 .60741 .75452 .60527 Mtetra
.53 .529 .798 r
.75452 .60527 .75542 .60741 .75724 .60679 .7564 .60547 Mtetra
.572 .656 .893 r
.7564 .60547 .75724 .60679 .75907 .60628 .75826 .60532 Mtetra
.635 .756 .936 r
.75826 .60532 .75907 .60628 .76091 .60583 .76009 .60485 Mtetra
.658 .761 .926 r
.76009 .60485 .76091 .60583 .76274 .60527 .76192 .60429 Mtetra
.589 .732 .943 r
.76192 .60429 .76274 .60527 .76456 .60457 .76377 .604 Mtetra
.476 .787 .999 r
.76377 .604 .76456 .60457 .76636 .60358 .76563 .60381 Mtetra
.255 .753 .686 r
.76563 .60381 .76636 .60358 .76811 .6019 .76746 .60316 Mtetra
0 0 0 r
.76746 .60316 .76811 .6019 .7696 .59654 .76915 .60049 Mtetra
.707 .643 .084 r
.76915 .60049 .7696 .59654 .75697 .39538 .7703 .59043 Mtetra
.073 0 .45 r
.7703 .59043 .75697 .39538 .75836 .39033 .75785 .39279 Mtetra
.375 .05 .282 r
.75785 .39279 .75836 .39033 .7601 .39001 .75954 .39181 Mtetra
.973 .672 .384 r
.75954 .39181 .7601 .39001 .76234 .39645 .77547 .58427 Mtetra
.579 .359 .546 r
.77547 .58427 .76234 .39645 .77902 .59701 .77829 .59714 Mtetra
.743 .227 0 r
.77829 .59714 .77902 .59701 .78111 .59987 .78033 .59922 Mtetra
.5 .779 .995 r
.78033 .59922 .78111 .59987 .78298 .59968 .7822 .59903 Mtetra
.693 .853 .959 r
.7822 .59903 .78298 .59968 .78481 .59891 .78403 .59827 Mtetra
.716 .865 .952 r
.78403 .59827 .78481 .59891 .78666 .59844 .78586 .59742 Mtetra
.711 .772 .9 r
.78586 .59742 .78666 .59844 .78855 .59843 .78768 .59659 Mtetra
.743 .666 .775 r
.78768 .59659 .78855 .59843 .7904 .59787 .78946 .59517 Mtetra
.817 .646 .67 r
.78946 .59517 .7904 .59787 .7921 .59542 .79108 .59159 Mtetra
.975 .68 .392 r
.79108 .59159 .7921 .59542 .79317 .58497 .77745 .39392 Mtetra
.577 .362 .552 r
.77745 .39392 .79317 .58497 .77927 .38584 .77846 .38418 Mtetra
.842 .709 .716 r
.77846 .38418 .77927 .38584 .78078 .38249 .78003 .38151 Mtetra
.719 .771 .893 r
.78003 .38151 .78078 .38249 .78249 .38162 .78174 .38068 Mtetra
.618 .744 .936 r
.78174 .38068 .78249 .38162 .78425 .38129 .78349 .3803 Mtetra
.673 .752 .911 r
.78349 .3803 .78425 .38129 .78599 .38079 .78523 .37971 Mtetra
.749 .759 .861 r
.78523 .37971 .78599 .38079 .78769 .37982 .78693 .37867 Mtetra
.668 .717 .885 r
.78693 .37867 .78769 .37982 .78944 .37931 .78867 .37809 Mtetra
.227 .465 .879 r
.78867 .37809 .78944 .37931 .7913 .38027 .79053 .37897 Mtetra
.852 .461 0 r
.79053 .37897 .7913 .38027 .79366 .38711 .79284 .38523 Mtetra
.976 .673 .355 r
.79284 .38523 .79366 .38711 .8123 .58686 .81149 .58566 Mtetra
0 0 .421 r
.81149 .58566 .8123 .58686 .81445 .5898 .81366 .58878 Mtetra
.594 .729 .938 r
.81366 .58878 .81445 .5898 .81634 .58946 .81555 .58847 Mtetra
.75 .792 .887 r
.81555 .58847 .81634 .58946 .81816 .58839 .81737 .58741 Mtetra
.769 .8 .878 r
.81737 .58741 .81816 .58839 .81997 .58718 .81918 .58623 Mtetra
.68 .779 .925 r
.81918 .58623 .81997 .58718 .82182 .58646 .82104 .58556 Mtetra
.663 .784 .939 r
.82104 .58556 .82182 .58646 .82368 .58581 .82291 .58495 Mtetra
.624 .781 .956 r
.82291 .58495 .82368 .58581 .82556 .58532 .82478 .58449 Mtetra
.568 .763 .97 r
.82478 .58449 .82556 .58532 .82745 .58504 .82668 .5842 Mtetra
.549 .752 .971 r
.82668 .5842 .82745 .58504 .82935 .58482 .82858 .58397 Mtetra
.467 .711 .975 r
.82858 .58397 .82935 .58482 .83127 .5848 .83051 .58398 Mtetra
.359 .658 .97 r
.83051 .58398 .83127 .5848 .83322 .58499 .83245 .58422 Mtetra
.577 .786 .978 r
.83245 .58422 .83322 .58499 .83511 .58458 .83435 .58388 Mtetra
.877 .871 .828 r
.83435 .58388 .83511 .58458 .83685 .58253 .8361 .58191 Mtetra
.988 .768 .516 r
.8361 .58191 .83685 .58253 .83785 .57252 .8372 .57284 Mtetra
.978 .679 .358 r
.8372 .57284 .83785 .57252 .82125 .37278 .82053 .37194 Mtetra
.95 .809 .67 r
.82053 .37194 .82125 .37278 .82272 .3691 .82199 .36809 Mtetra
.73 .774 .887 r
.82199 .36809 .82272 .3691 .82445 .36822 .82372 .3672 Mtetra
.601 .719 .927 r
.82372 .3672 .82445 .36822 .82624 .36791 .8255 .36689 Mtetra
.6 .718 .927 r
.8255 .36689 .82624 .36791 .82803 .36761 .82729 .36659 Mtetra
.741 .773 .879 r
.82729 .36659 .82803 .36761 .82975 .36665 .82902 .36562 Mtetra
.658 .741 .911 r
.82902 .36562 .82975 .36665 .83152 .36611 .83079 .36508 Mtetra
.235 .512 .909 r
.83079 .36508 .83152 .36611 .83341 .36684 .83268 .3658 Mtetra
.881 .489 .032 r
.83268 .3658 .83341 .36684 .83592 .37393 .83519 .37288 Mtetra
.975 .667 .334 r
.83519 .37288 .83592 .37393 .85739 .5746 .85663 .57361 Mtetra
.655 .203 0 r
.85663 .57361 .85739 .5746 .85968 .57802 .85891 .57704 Mtetra
.383 .63 .951 r
.85891 .57704 .85968 .57802 .86166 .57833 .86089 .57735 Mtetra
.694 .78 .917 r
.86089 .57735 .86166 .57833 .86353 .57758 .86277 .57659 Mtetra
.874 .819 .791 r
.86277 .57659 .86353 .57758 .86526 .57537 .8645 .57438 Mtetra
.978 .765 .547 r
.8645 .57438 .86526 .57537 .86644 .56762 .86567 .5666 Mtetra
.977 .675 .347 r
.86567 .5666 .86644 .56762 .84787 .36517 .84714 .36411 Mtetra
.948 .784 .645 r
.84714 .36411 .84787 .36517 .84926 .36079 .84854 .35973 Mtetra
.745 .77 .873 r
.84854 .35973 .84926 .36079 .851 .35978 .85027 .35873 Mtetra
.621 .722 .918 r
.85027 .35873 .851 .35978 .85279 .3594 .85207 .35834 Mtetra
.59 .708 .925 r
.85207 .35834 .85279 .3594 .8546 .35914 .85388 .35808 Mtetra
.747 .771 .872 r
.85388 .35808 .8546 .35914 .85634 .35812 .85561 .35706 Mtetra
.674 .745 .904 r
.85561 .35706 .85634 .35812 .85811 .3575 .85739 .35644 Mtetra
.379 .596 .931 r
.85739 .35644 .85811 .3575 .86 .35789 .85927 .35683 Mtetra
.802 .388 0 r
.85927 .35683 .86 .35789 .8624 .36321 .86168 .36214 Mtetra
.973 .663 .318 r
.86168 .36214 .8624 .36321 .88578 .56526 .88502 .56425 Mtetra
.717 .276 0 r
.88502 .56425 .88578 .56526 .88819 .56941 .88744 .56841 Mtetra
.502 .693 .954 r
.88744 .56841 .88819 .56941 .89016 .56939 .88941 .56839 Mtetra
.694 .78 .917 r
.88941 .56839 .89016 .56939 .89205 .56864 .8913 .56764 Mtetra
.734 .793 .9 r
.8913 .56764 .89205 .56864 .89392 .56767 .89317 .56667 Mtetra
.494 .689 .954 r
.89317 .56667 .89392 .56767 .8959 .56767 .89515 .56667 Mtetra
.622 .751 .939 r
.89515 .56667 .8959 .56767 .89783 .56723 .89708 .56623 Mtetra
.808 .814 .855 r
.89708 .56623 .89783 .56723 .89965 .56575 .8989 .56474 Mtetra
.979 .773 .556 r
.8989 .56474 .89965 .56575 .90084 .55866 .90009 .55763 Mtetra
.976 .671 .329 r
.90009 .55763 .90084 .55866 .88012 .35551 .8794 .35444 Mtetra
.959 .783 .621 r
.8794 .35444 .88012 .35551 .88143 .35066 .88072 .34959 Mtetra
.743 .77 .875 r
.88072 .34959 .88143 .35066 .88318 .34966 .88247 .3486 Mtetra
.605 .714 .922 r
.88247 .3486 .88318 .34966 .88501 .34934 .8843 .34827 Mtetra
.518 .671 .933 r
.8843 .34827 .88501 .34934 .88687 .34933 .88616 .34826 Mtetra
.654 .736 .91 r
.88616 .34826 .88687 .34933 .88868 .3488 .88797 .34773 Mtetra
.66 .739 .908 r
.88797 .34773 .88868 .3488 .89048 .34823 .88977 .34717 Mtetra
.674 .746 .905 r
.88977 .34717 .89048 .34823 .89228 .34761 .89157 .34654 Mtetra
.765 .779 .865 r
.89157 .34654 .89228 .34761 .89401 .34647 .89331 .34541 Mtetra
.699 .757 .896 r
.89331 .34541 .89401 .34647 .8958 .34571 .89509 .34466 Mtetra
.503 .665 .935 r
.89509 .34466 .8958 .34571 .89767 .34575 .89697 .34469 Mtetra
.739 .319 0 r
.89697 .34469 .89767 .34575 .90011 .35047 .89941 .34944 Mtetra
.971 .656 .295 r
.89941 .34944 .90011 .35047 .92608 .5532 .92535 .55223 Mtetra
.753 .32 0 r
.92535 .55223 .92608 .5532 .92866 .55805 .92793 .55706 Mtetra
.477 .684 .957 r
.92793 .55706 .92866 .55805 .93068 .5581 .92994 .55711 Mtetra
.687 .782 .923 r
.92994 .55711 .93068 .5581 .9326 .55737 .93187 .55638 Mtetra
.761 .807 .889 r
.93187 .55638 .9326 .55737 .93447 .55624 .93374 .55523 Mtetra
.439 .693 .972 r
.30823 .73015 .30923 .73095 .31075 .73101 .30976 .73021 Mtetra
.613 .756 .947 r
.30976 .73021 .31075 .73101 .3123 .73069 .31131 .72988 Mtetra
.774 .78 .858 r
.31131 .72988 .3123 .73069 .3139 .7296 .31291 .72876 Mtetra
.914 .729 .638 r
.31291 .72876 .3139 .7296 .3158 .72341 .31483 .72216 Mtetra
.936 .686 .534 r
.31483 .72216 .3158 .72341 .32866 .52993 .32776 .52854 Mtetra
.875 .7 .662 r
.32776 .52854 .32866 .52993 .33039 .52497 .32948 .52381 Mtetra
.728 .704 .827 r
.32948 .52381 .33039 .52497 .3319 .52401 .33098 .52293 Mtetra
.58 .671 .901 r
.33098 .52293 .3319 .52401 .33336 .52377 .33244 .52277 Mtetra
.413 .616 .934 r
.33244 .52277 .33336 .52377 .3348 .52391 .33388 .523 Mtetra
.625 .721 .916 r
.33388 .523 .3348 .52391 .33627 .52356 .33535 .52267 Mtetra
.648 .735 .912 r
.33535 .52267 .33627 .52356 .33775 .52314 .33682 .52226 Mtetra
.659 .74 .909 r
.33682 .52226 .33775 .52314 .33923 .52268 .3383 .5218 Mtetra
.754 .757 .855 r
.3383 .5218 .33923 .52268 .34074 .52172 .33981 .52085 Mtetra
.704 .75 .887 r
.33981 .52085 .34074 .52172 .34223 .52106 .3413 .52019 Mtetra
.488 .682 .952 r
.3413 .52019 .34223 .52106 .34368 .52106 .34276 .52021 Mtetra
.932 .562 .281 r
.34276 .52021 .34368 .52106 .34492 .52513 .34398 .5246 Mtetra
.939 .683 .521 r
.34398 .5246 .34492 .52513 .33609 .71814 .33507 .71797 Mtetra
.906 .551 .357 r
.33507 .71797 .33609 .71814 .33737 .72323 .33637 .72274 Mtetra
.148 .621 .925 r
.33637 .72274 .33737 .72323 .3389 .72358 .3379 .72299 Mtetra
.712 .831 .939 r
.3379 .72299 .3389 .72358 .34048 .72295 .33949 .72228 Mtetra
.787 .811 .872 r
.33949 .72228 .34048 .72295 .34209 .7219 .34111 .72113 Mtetra
.533 .737 .969 r
.34111 .72113 .34209 .7219 .34365 .7218 .34267 .72099 Mtetra
.599 .751 .95 r
.34267 .72099 .34365 .7218 .34522 .72152 .34424 .7207 Mtetra
.757 .78 .872 r
.34424 .7207 .34522 .72152 .34682 .72054 .34584 .7197 Mtetra
.911 .739 .656 r
.34584 .7197 .34682 .72054 .34863 .71543 .34767 .7143 Mtetra
.94 .687 .527 r
.34767 .7143 .34863 .71543 .35978 .52119 .35889 .51968 Mtetra
.882 .696 .647 r
.35889 .51968 .35978 .52119 .36154 .51537 .36063 .51419 Mtetra
.763 .71 .803 r
.36063 .51419 .36154 .51537 .36307 .51408 .36216 .51298 Mtetra
.602 .676 .893 r
.36216 .51298 .36307 .51408 .36455 .51377 .36364 .51275 Mtetra
.442 .625 .93 r
.36364 .51275 .36455 .51377 .36602 .51387 .36511 .51293 Mtetra
.606 .712 .919 r
.36511 .51293 .36602 .51387 .36751 .51357 .36659 .51267 Mtetra
.652 .734 .91 r
.36659 .51267 .36751 .51357 .369 .51313 .36809 .51223 Mtetra
.664 .739 .906 r
.36809 .51223 .369 .51313 .3705 .51265 .36959 .51175 Mtetra
.747 .755 .859 r
.36959 .51175 .3705 .51265 .37202 .51173 .3711 .51084 Mtetra
.717 .752 .879 r
.3711 .51084 .37202 .51173 .37353 .51099 .37262 .5101 Mtetra
.56 .708 .94 r
.37262 .5101 .37353 .51099 .37501 .51084 .3741 .50996 Mtetra
.885 .455 .091 r
.3741 .50996 .37501 .51084 .37636 .5138 .37545 .51294 Mtetra
.944 .684 .513 r
.37545 .51294 .37636 .5138 .36937 .70602 .3684 .70527 Mtetra
.94 .606 .368 r
.3684 .70527 .36937 .70602 .37064 .71301 .36966 .71221 Mtetra
0 .376 .814 r
.36966 .71221 .37064 .71301 .37217 .71379 .3712 .71299 Mtetra
.669 .776 .93 r
.3712 .71299 .37217 .71379 .37377 .71324 .3728 .71246 Mtetra
.763 .791 .876 r
.3728 .71246 .37377 .71324 .37539 .7122 .37442 .71143 Mtetra
.652 .776 .939 r
.37442 .71143 .37539 .7122 .37699 .71158 .37602 .71095 Mtetra
.616 .804 .972 r
.37602 .71095 .37699 .71158 .37859 .7111 .37761 .71055 Mtetra
.714 .843 .944 r
.37761 .71055 .37859 .7111 .38019 .71054 .37922 .70982 Mtetra
.864 .791 .778 r
.37922 .70982 .38019 .71054 .38181 .70958 .38089 .70762 Mtetra
.847 .675 .669 r
.38089 .70762 .38181 .70958 .38344 .7084 .38264 .70335 Mtetra
.938 .682 .524 r
.38264 .70335 .38344 .7084 .38507 .70719 .39124 .5274 Mtetra
.587 .372 .555 r
.39124 .5274 .38507 .70719 .38668 .70653 .39329 .51351 Mtetra
.56 .349 .551 r
.39329 .51351 .38668 .70653 .38827 .70624 .39479 .51344 Mtetra
.555 .345 .55 r
.39479 .51344 .38827 .70624 .38986 .70608 .39619 .51614 Mtetra
.554 .344 .55 r
.39619 .51614 .38986 .70608 .39146 .70581 .39757 .51927 Mtetra
.553 .344 .55 r
.39757 .51927 .39146 .70581 .39306 .70547 .39894 .5228 Mtetra
0 0 .379 r
.39894 .5228 .39306 .70547 .39466 .70512 .39458 .68064 Mtetra
.496 .312 .561 r
.39458 .68064 .39466 .70512 .39626 .70474 .39601 .68476 Mtetra
.54 .351 .573 r
.39601 .68476 .39626 .70474 .39787 .70435 .39754 .68601 Mtetra
.552 .362 .577 r
.39754 .68601 .39787 .70435 .39948 .70393 .39911 .68658 Mtetra
.92 .663 .532 r
.39911 .68658 .39948 .70393 .40109 .70341 .4066 .51975 Mtetra
.571 .359 .553 r
.4066 .51975 .40109 .70341 .4027 .70289 .40831 .51395 Mtetra
0 0 .378 r
.40831 .51395 .4027 .70289 .40431 .70253 .40413 .67904 Mtetra
.126 .03 .465 r
.40413 .67904 .40431 .70253 .4059 .70268 .40513 .69614 Mtetra
.203 .15 .571 r
.40513 .69614 .4059 .70268 .40749 .70302 .40659 .70035 Mtetra
.114 .214 .691 r
.40659 .70035 .40749 .70302 .40908 .70325 .40812 .70234 Mtetra
.294 .593 .947 r
.40812 .70234 .40908 .70325 .41068 .70308 .40971 .70272 Mtetra
.555 .859 .997 r
.40971 .70272 .41068 .70308 .4123 .70264 .41133 .70232 Mtetra
.65 .895 .983 r
.41133 .70232 .4123 .70264 .41392 .70213 .41295 .7017 Mtetra
.594 .853 .993 r
.41295 .7017 .41392 .70213 .41554 .70171 .41457 .70127 Mtetra
.521 .826 1 r
.41457 .70127 .41554 .70171 .41715 .70135 .41618 .70098 Mtetra
.501 .837 .998 r
.41618 .70098 .41715 .70135 .41877 .70099 .4178 .70069 Mtetra
.522 .861 .994 r
.4178 .70069 .41877 .70099 .42039 .70059 .41942 .70031 Mtetra
.551 .877 .992 r
.41942 .70031 .42039 .70059 .42201 .70016 .42104 .69987 Mtetra
.568 .882 .992 r
.42104 .69987 .42201 .70016 .42364 .69971 .42267 .69941 Mtetra
.569 .878 .993 r
.42267 .69941 .42364 .69971 .42526 .69926 .4243 .69895 Mtetra
.572 .877 .993 r
.4243 .69895 .42526 .69926 .42689 .6988 .42592 .69849 Mtetra
.588 .882 .992 r
.42592 .69849 .42689 .6988 .42852 .69832 .42755 .69799 Mtetra
.632 .89 .987 r
.42755 .69799 .42852 .69832 .43015 .69781 .42918 .69742 Mtetra
.668 .884 .978 r
.42918 .69742 .43015 .69781 .43178 .69725 .43082 .69677 Mtetra
.68 .862 .969 r
.43082 .69677 .43178 .69725 .43341 .6967 .43245 .69613 Mtetra
.661 .834 .966 r
.43245 .69613 .43341 .6967 .43504 .6962 .43409 .69557 Mtetra
.639 .814 .967 r
.43409 .69557 .43504 .6962 .43667 .69574 .43572 .69509 Mtetra
.631 .807 .967 r
.43572 .69509 .43667 .69574 .4383 .69529 .43735 .69464 Mtetra
.575 .79 .981 r
.43735 .69464 .4383 .69529 .43993 .69508 .43898 .69434 Mtetra
.584 .771 .969 r
.43898 .69434 .43993 .69508 .44156 .69487 .44061 .69405 Mtetra
.678 .777 .925 r
.44061 .69405 .44156 .69487 .4432 .6942 .44225 .69346 Mtetra
.833 .806 .825 r
.44225 .69346 .4432 .6942 .44488 .69172 .44392 .69182 Mtetra
.956 .877 .716 r
.44392 .69182 .44488 .69172 .44669 .6836 .44562 .68845 Mtetra
0 0 0 r
.44562 .68845 .44669 .6836 .45254 .49019 .4474 .68158 Mtetra
0 0 .354 r
.4474 .68158 .45254 .49019 .45414 .48696 .45301 .49766 Mtetra
.482 .248 .482 r
.45301 .49766 .45414 .48696 .45569 .48622 .45459 .49571 Mtetra
.62 .363 .506 r
.45459 .49571 .45569 .48622 .45723 .48608 .45608 .49792 Mtetra
.655 .4 .521 r
.45608 .49792 .45723 .48608 .45877 .48589 .45754 .50237 Mtetra
.553 .32 .516 r
.45754 .50237 .45877 .48589 .46032 .48542 .45909 .50227 Mtetra
.56 .326 .518 r
.45909 .50227 .46032 .48542 .46187 .48495 .46063 .5025 Mtetra
.57 .335 .521 r
.46063 .5025 .46187 .48495 .46342 .48448 .46217 .50326 Mtetra
.585 .349 .525 r
.46217 .50326 .46342 .48448 .46497 .484 .46369 .50497 Mtetra
.616 .377 .532 r
.46369 .50497 .46497 .484 .46653 .48352 .46517 .50913 Mtetra
.906 .638 .521 r
.46517 .50913 .46653 .48352 .46808 .48312 .46394 .66868 Mtetra
.566 .35 .546 r
.46394 .66868 .46808 .48312 .46963 .48275 .46551 .67239 Mtetra
.556 .342 .545 r
.46551 .67239 .46963 .48275 .47118 .48225 .46718 .67044 Mtetra
0 0 .359 r
.46718 .67044 .47118 .48225 .47275 .48133 .47175 .48777 Mtetra
0 0 .239 r
.47175 .48777 .47275 .48133 .47431 .48009 .4734 .48143 Mtetra
.822 .908 .503 r
.4734 .48143 .47431 .48009 .47588 .47893 .475 .47832 Mtetra
.845 .826 .829 r
.475 .47832 .47588 .47893 .47744 .47808 .47657 .47671 Mtetra
.677 .665 .831 r
.47657 .47671 .47744 .47808 .479 .47756 .47814 .47609 Mtetra
.627 .632 .836 r
.47814 .47609 .479 .47756 .48056 .47713 .47969 .47575 Mtetra
.627 .643 .846 r
.47969 .47575 .48056 .47713 .48212 .4767 .48125 .47541 Mtetra
.657 .668 .849 r
.48125 .47541 .48212 .4767 .48368 .47621 .48281 .47492 Mtetra
.652 .667 .852 r
.48281 .47492 .48368 .47621 .48524 .47573 .48437 .47445 Mtetra
.639 .665 .859 r
.48437 .47445 .48524 .47573 .48681 .47527 .48594 .47406 Mtetra
.622 .668 .873 r
.48594 .47406 .48681 .47527 .48837 .47485 .4875 .47374 Mtetra
.62 .686 .89 r
.4875 .47374 .48837 .47485 .48993 .47443 .48906 .47342 Mtetra
.632 .712 .904 r
.48906 .47342 .48993 .47443 .4915 .47398 .49063 .47305 Mtetra
.655 .738 .911 r
.49063 .47305 .4915 .47398 .49307 .47348 .49219 .47259 Mtetra
.67 .751 .911 r
.49219 .47259 .49307 .47348 .49463 .47294 .49376 .47206 Mtetra
.69 .758 .904 r
.49376 .47206 .49463 .47294 .4962 .47236 .49533 .47144 Mtetra
.707 .754 .889 r
.49533 .47144 .4962 .47236 .49777 .47174 .4969 .47074 Mtetra
.704 .737 .877 r
.4969 .47074 .49777 .47174 .49934 .47112 .49848 .47004 Mtetra
.705 .722 .863 r
.49848 .47004 .49934 .47112 .50092 .47039 .50005 .46931 Mtetra
.705 .723 .864 r
.50005 .46931 .50092 .47039 .50249 .46957 .50162 .46859 Mtetra
.652 .726 .903 r
.50162 .46859 .50249 .46957 .50406 .46914 .5032 .46813 Mtetra
.396 .61 .935 r
.5032 .46813 .50406 .46914 .50563 .46992 .50477 .46841 Mtetra
0 .071 .632 r
.50477 .46841 .50563 .46992 .50718 .47484 .50633 .4703 Mtetra
0 0 .517 r
.50633 .4703 .50718 .47484 .5078 .66958 .50788 .47493 Mtetra
0 0 .388 r
.50788 .47493 .5078 .66958 .50945 .6734 .50859 .66078 Mtetra
.519 .348 .589 r
.50859 .66078 .50945 .6734 .51113 .67338 .51025 .66236 Mtetra
.618 .427 .601 r
.51025 .66236 .51113 .67338 .5128 .67263 .51193 .66048 Mtetra
.647 .445 .597 r
.51193 .66048 .5128 .67263 .51448 .67172 .51361 .657 Mtetra
.577 .387 .588 r
.51361 .657 .51448 .67172 .51616 .67125 .51528 .65643 Mtetra
.579 .388 .587 r
.51528 .65643 .51616 .67125 .51784 .67076 .51696 .65578 Mtetra
.58 .389 .587 r
.51696 .65578 .51784 .67076 .51952 .67027 .51863 .65503 Mtetra
.583 .391 .587 r
.51863 .65503 .51952 .67027 .5212 .66979 .52031 .65416 Mtetra
.583 .39 .586 r
.52031 .65416 .5212 .66979 .52289 .6693 .52199 .65325 Mtetra
.632 .427 .587 r
.52199 .65325 .52289 .6693 .52457 .66876 .52366 .64955 Mtetra
.931 .663 .507 r
.52366 .64955 .52457 .66876 .52626 .66813 .52532 .47749 Mtetra
.56 .349 .551 r
.52532 .47749 .52626 .66813 .52794 .66762 .52691 .47741 Mtetra
0 0 .4 r
.52691 .47741 .52794 .66762 .52963 .66745 .52871 .65672 Mtetra
.231 .144 .545 r
.52871 .65672 .52963 .66745 .53132 .66777 .5304 .66372 Mtetra
.216 .218 .646 r
.5304 .66372 .53132 .66777 .53301 .66803 .5321 .66645 Mtetra
.177 .384 .828 r
.5321 .66645 .53301 .66803 .5347 .66803 .53379 .66756 Mtetra
.504 .819 1 r
.53379 .66756 .5347 .66803 .53639 .6676 .53549 .6673 Mtetra
.62 .901 .986 r
.53549 .6673 .53639 .6676 .53809 .66705 .53718 .66669 Mtetra
.671 .902 .977 r
.53718 .66669 .53809 .66705 .53978 .66646 .53887 .66598 Mtetra
.616 .856 .989 r
.53887 .66598 .53978 .66646 .54148 .66596 .54057 .66548 Mtetra
.615 .857 .989 r
.54057 .66548 .54148 .66596 .54317 .66546 .54227 .66498 Mtetra
.613 .856 .989 r
.54227 .66498 .54317 .66546 .54487 .66497 .54397 .66449 Mtetra
.609 .854 .99 r
.54397 .66449 .54487 .66497 .54657 .66449 .54566 .664 Mtetra
.606 .852 .991 r
.54566 .664 .54657 .66449 .54827 .66401 .54736 .66352 Mtetra
.602 .851 .991 r
.54736 .66352 .54827 .66401 .54997 .66354 .54907 .66306 Mtetra
.597 .85 .992 r
.54907 .66306 .54997 .66354 .55167 .66308 .55077 .6626 Mtetra
.595 .85 .993 r
.55077 .6626 .55167 .66308 .55337 .66263 .55247 .66215 Mtetra
.576 .844 .995 r
.55247 .66215 .55337 .66263 .55507 .66219 .55418 .66174 Mtetra
.477 .811 .999 r
.55418 .66174 .55507 .66219 .55678 .66183 .55588 .66151 Mtetra
.55 .874 .993 r
.55588 .66151 .55678 .66183 .55849 .6614 .55759 .66106 Mtetra
.756 .92 .945 r
.55759 .66106 .55849 .6614 .56019 .66077 .55929 .66005 Mtetra
.898 .811 .753 r
.55929 .66005 .56019 .66077 .56189 .65966 .56098 .65736 Mtetra
.851 .669 .657 r
.56098 .65736 .56189 .65966 .56359 .65841 .56264 .65279 Mtetra
.864 .626 .576 r
.56264 .65279 .56359 .65841 .56529 .65722 .5642 .63901 Mtetra
.937 .665 .497 r
.5642 .63901 .56529 .65722 .567 .65665 .56385 .465 Mtetra
.553 .344 .551 r
.56385 .465 .567 .65665 .56871 .65627 .56551 .46872 Mtetra
.04 0 .422 r
.56551 .46872 .56871 .65627 .57043 .65594 .56934 .64027 Mtetra
.565 .376 .585 r
.56934 .64027 .57043 .65594 .57214 .65549 .57106 .64024 Mtetra
.565 .377 .586 r
.57106 .64024 .57214 .65549 .57386 .65504 .57277 .6402 Mtetra
.567 .379 .587 r
.57277 .6402 .57386 .65504 .57557 .65458 .57448 .64009 Mtetra
.571 .384 .588 r
.57448 .64009 .57557 .65458 .57729 .6541 .5762 .63978 Mtetra
.573 .385 .589 r
.5762 .63978 .57729 .6541 .57901 .65363 .57791 .63941 Mtetra
.57791 .63941 .57901 .65363 .58072 .65315 .57963 .63905 Mtetra
.57 .384 .589 r
.57963 .63905 .58072 .65315 .58244 .65269 .58134 .63879 Mtetra
.572 .385 .59 r
.58134 .63879 .58244 .65269 .58417 .65222 .58306 .63848 Mtetra
.568 .382 .59 r
.58306 .63848 .58417 .65222 .58589 .65178 .58478 .63835 Mtetra
.5 .333 .586 r
.58478 .63835 .58589 .65178 .58762 .65183 .58655 .64071 Mtetra
.571 .392 .6 r
.58655 .64071 .58762 .65183 .58935 .6514 .58828 .64053 Mtetra
.702 .489 .596 r
.58828 .64053 .58935 .6514 .59105 .64996 .58989 .6345 Mtetra
.946 .67 .485 r
.58989 .6345 .59105 .64996 .59261 .64103 .588 .44711 Mtetra
.568 .355 .552 r
.588 .44711 .59261 .64103 .59043 .44569 .58955 .44277 Mtetra
.755 .596 .68 r
.58955 .44277 .59043 .44569 .59198 .44151 .59114 .44032 Mtetra
.717 .713 .846 r
.59114 .44032 .59198 .44151 .59359 .44049 .59276 .43947 Mtetra
.651 .724 .902 r
.59276 .43947 .59359 .44049 .59522 .44006 .59439 .43901 Mtetra
.597 .697 .913 r
.59439 .43901 .59522 .44006 .59685 .43993 .59602 .43876 Mtetra
.624 .683 .885 r
.59602 .43876 .59685 .43993 .59848 .43951 .59765 .43841 Mtetra
.621 .697 .899 r
.59765 .43841 .59848 .43951 .60012 .43909 .59928 .43807 Mtetra
.632 .718 .909 r
.59928 .43807 .60012 .43909 .60175 .43866 .60092 .43768 Mtetra
.693 .749 .894 r
.60092 .43768 .60175 .43866 .60338 .43809 .60254 .43703 Mtetra
.701 .733 .875 r
.60254 .43703 .60338 .43809 .60501 .43749 .60417 .43632 Mtetra
.696 .71 .859 r
.60417 .43632 .60501 .43749 .60664 .43689 .6058 .43561 Mtetra
.706 .697 .839 r
.6058 .43561 .60664 .43689 .60827 .43624 .60743 .43481 Mtetra
.669 .66 .832 r
.60743 .43481 .60827 .43624 .6099 .43567 .60906 .43421 Mtetra
.604 .627 .848 r
.60906 .43421 .6099 .43567 .61154 .43523 .6107 .43397 Mtetra
.179 .426 .861 r
.6107 .43397 .61154 .43523 .61318 .43485 .61238 .43489 Mtetra
.811 .338 .091 r
.61238 .43489 .61318 .43485 .61483 .43487 .61409 .43724 Mtetra
.889 .569 .436 r
.61409 .43724 .61483 .43487 .6165 .43568 .61605 .4479 Mtetra
.949 .665 .464 r
.61605 .4479 .6165 .43568 .61836 .44286 .62306 .63659 Mtetra
.564 .349 .546 r
.62306 .63659 .61836 .44286 .62571 .63813 .62492 .63985 Mtetra
.666 .28 .305 r
.62492 .63985 .62571 .63813 .62758 .64176 .62672 .64123 Mtetra
.416 .765 .995 r
.62672 .64123 .62758 .64176 .62935 .64197 .62848 .64115 Mtetra
.659 .786 .942 r
.62848 .64115 .62935 .64197 .6311 .6414 .63023 .64059 Mtetra
.712 .805 .922 r
.63023 .64059 .6311 .6414 .63284 .64047 .63198 .63981 Mtetra
.651 .827 .967 r
.63198 .63981 .63284 .64047 .63459 .63987 .63373 .63925 Mtetra
.641 .831 .974 r
.63373 .63925 .63459 .63987 .63634 .63932 .63548 .63871 Mtetra
.639 .836 .976 r
.63548 .63871 .63634 .63932 .63809 .63876 .63724 .63816 Mtetra
.635 .84 .979 r
.63724 .63816 .63809 .63876 .63985 .6382 .63899 .63763 Mtetra
.63 .845 .982 r
.63899 .63763 .63985 .6382 .6416 .63765 .64075 .6371 Mtetra
.626 .848 .984 r
.64075 .6371 .6416 .63765 .64336 .63711 .64251 .63657 Mtetra
.613 .848 .988 r
.64251 .63657 .64336 .63711 .64512 .63659 .64427 .63607 Mtetra
.612 .851 .989 r
.64427 .63607 .64512 .63659 .64688 .63609 .64603 .63557 Mtetra
.62 .853 .987 r
.64603 .63557 .64688 .63609 .64864 .6356 .64779 .63504 Mtetra
.662 .858 .975 r
.64779 .63504 .64864 .6356 .6504 .63508 .64955 .63441 Mtetra
.675 .832 .959 r
.64955 .63441 .6504 .63508 .65217 .63456 .65131 .63376 Mtetra
.666 .796 .944 r
.65131 .63376 .65217 .63456 .65393 .63407 .65307 .63317 Mtetra
.519 .715 .961 r
.65307 .63317 .65393 .63407 .65571 .63407 .65485 .63308 Mtetra
.552 .709 .944 r
.65485 .63308 .65571 .63407 .65749 .63387 .65663 .63293 Mtetra
.656 .759 .926 r
.65663 .63293 .65749 .63387 .65925 .63309 .6584 .63239 Mtetra
.864 .845 .823 r
.6584 .63239 .65925 .63309 .6609 .62958 .66012 .6305 Mtetra
.895 .929 .547 r
.66012 .6305 .6609 .62958 .66202 .61268 .66177 .62698 Mtetra
.237 .07 .441 r
.66177 .62698 .66202 .61268 .65617 .42404 .66316 .61711 Mtetra
.032 0 .423 r
.66316 .61711 .65617 .42404 .65775 .4215 .65712 .42493 Mtetra
0 0 .163 r
.65712 .42493 .65775 .4215 .65939 .42031 .65864 .42081 Mtetra
.843 .975 .67 r
.65864 .42081 .65939 .42031 .66104 .4196 .66024 .41857 Mtetra
.733 .754 .869 r
.66024 .41857 .66104 .4196 .66271 .41907 .66189 .41768 Mtetra
.621 .648 .855 r
.66189 .41768 .66271 .41907 .66438 .41867 .66356 .41734 Mtetra
.568 .634 .876 r
.66356 .41734 .66438 .41867 .66606 .41834 .66525 .41724 Mtetra
.624 .701 .9 r
.66525 .41724 .66606 .41834 .66773 .41786 .66693 .41688 Mtetra
.659 .739 .909 r
.66693 .41688 .66773 .41786 .6694 .41731 .6686 .41636 Mtetra
.675 .754 .911 r
.6686 .41636 .6694 .41731 .67107 .41672 .67026 .41578 Mtetra
.739 .775 .882 r
.67026 .41578 .67107 .41672 .67272 .41577 .67192 .41487 Mtetra
.731 .781 .893 r
.67192 .41487 .67272 .41577 .67438 .41495 .67358 .41401 Mtetra
.658 .749 .918 r
.67358 .41401 .67438 .41495 .67606 .41466 .67525 .4135 Mtetra
.288 .516 .901 r
.67525 .4135 .67606 .41466 .67785 .41665 .67698 .41414 Mtetra
.123 .229 .703 r
.67698 .41414 .67785 .41665 .68026 .43146 .67879 .41634 Mtetra
.303 .188 .552 r
.67879 .41634 .68026 .43146 .69111 .62066 .68093 .42533 Mtetra
.056 0 .442 r
.68093 .42533 .69111 .62066 .69302 .62262 .69193 .61676 Mtetra
.311 .249 .625 r
.69193 .61676 .69302 .62262 .69485 .62293 .69392 .62019 Mtetra
.336 .364 .743 r
.69392 .62019 .69485 .62293 .69665 .6227 .6958 .62166 Mtetra
.381 .612 .941 r
.6958 .62166 .69665 .6227 .69847 .62261 .69764 .62199 Mtetra
.565 .813 .991 r
.69764 .62199 .69847 .62261 .70027 .6223 .69944 .62164 Mtetra
.735 .853 .936 r
.69944 .62164 .70027 .6223 .70205 .62139 .70122 .62073 Mtetra
.884 .854 .808 r
.70122 .62073 .70205 .62139 .7037 .61822 .70293 .61863 Mtetra
.971 .928 .63 r
.70293 .61863 .7037 .61822 .70493 .60688 .70456 .61488 Mtetra
.03 0 .338 r
.70456 .61488 .70493 .60688 .6964 .41174 .70595 .60666 Mtetra
.099 .006 .451 r
.70595 .60666 .6964 .41174 .69799 .40928 .69808 .4249 Mtetra
.759 .484 .516 r
.69808 .4249 .69799 .40928 .69967 .4087 .70068 .44105 Mtetra
.913 .622 .48 r
.70068 .44105 .69967 .4087 .70138 .40855 .71068 .59298 Mtetra
.068 0 .441 r
.71068 .59298 .70138 .40855 .70305 .40768 .70258 .4124 Mtetra
0 0 .266 r
.70258 .4124 .70305 .40768 .7047 .40641 .70401 .40719 Mtetra
.826 .924 .537 r
.70401 .40719 .7047 .40641 .70636 .40525 .70558 .40435 Mtetra
.788 .797 .86 r
.70558 .40435 .70636 .40525 .70804 .4045 .70723 .40312 Mtetra
.639 .661 .855 r
.70723 .40312 .70804 .4045 .70974 .40402 .70893 .40269 Mtetra
.593 .647 .874 r
.70893 .40269 .70974 .40402 .71144 .4036 .71065 .40248 Mtetra
.648 .709 .892 r
.71065 .40248 .71144 .4036 .71313 .40306 .71235 .402 Mtetra
.697 .741 .885 r
.71235 .402 .71313 .40306 .71482 .40242 .71403 .4013 Mtetra
.697 .728 .874 r
.71403 .4013 .71482 .40242 .71652 .40178 .71572 .40058 Mtetra
.705 .718 .859 r
.71572 .40058 .71652 .40178 .7182 .40093 .7174 .39979 Mtetra
.692 .724 .874 r
.7174 .39979 .7182 .40093 .71988 .40016 .71909 .39909 Mtetra
.628 .715 .909 r
.71909 .39909 .71988 .40016 .72159 .39984 .7208 .39871 Mtetra
.271 .511 .901 r
.7208 .39871 .72159 .39984 .72342 .40139 .72258 .39938 Mtetra
0 .162 .689 r
.72258 .39938 .72342 .40139 .72568 .40976 .72446 .40172 Mtetra
.166 .122 .56 r
.72446 .40172 .72568 .40976 .73973 .60611 .72663 .40853 Mtetra
.098 .013 .461 r
.72663 .40853 .73973 .60611 .74171 .60825 .74019 .59615 Mtetra
.558 .38 .597 r
.74019 .59615 .74171 .60825 .74355 .60795 .74206 .59644 Mtetra
.636 .437 .597 r
.74206 .59644 .74355 .60795 .74534 .60701 .74372 .59357 Mtetra
.726 .497 .58 r
.74372 .59357 .74534 .60701 .74714 .60611 .74497 .58419 Mtetra
.949 .658 .454 r
.74497 .58419 .74714 .60611 .74896 .60546 .73556 .41149 Mtetra
.543 .337 .55 r
.73556 .41149 .74896 .60546 .75078 .60497 .73795 .42104 Mtetra
.098 .014 .463 r
.73795 .42104 .75078 .60497 .75264 .60496 .75137 .59719 Mtetra
.3 .222 .599 r
.75137 .59719 .75264 .60496 .75452 .60527 .75356 .60206 Mtetra
.263 .292 .704 r
.75356 .60206 .75452 .60527 .7564 .60547 .75557 .60427 Mtetra
.334 .55 .912 r
.75557 .60427 .7564 .60547 .75826 .60532 .75748 .60483 Mtetra
.546 .844 .998 r
.75748 .60483 .75826 .60532 .76009 .60485 .75932 .60443 Mtetra
.634 .895 .986 r
.75932 .60443 .76009 .60485 .76192 .60429 .76114 .60377 Mtetra
.559 .842 .997 r
.76114 .60377 .76192 .60429 .76377 .604 .76298 .60336 Mtetra
.496 .782 .996 r
.76298 .60336 .76377 .604 .76563 .60381 .76484 .60317 Mtetra
.611 .829 .983 r
.76484 .60317 .76563 .60381 .76746 .60316 .76668 .60269 Mtetra
.853 .915 .874 r
.76668 .60269 .76746 .60316 .76915 .60049 .76845 .60106 Mtetra
.922 .94 .585 r
.76845 .60106 .76915 .60049 .7703 .59043 .77008 .59763 Mtetra
.214 .025 .395 r
.77008 .59763 .7703 .59043 .75785 .39279 .77155 .59206 Mtetra
.557 .343 .545 r
.77155 .59206 .75785 .39279 .75954 .39181 .77332 .59055 Mtetra
.566 .35 .546 r
.77332 .59055 .75954 .39181 .77547 .58427 .77553 .59515 Mtetra
.617 .355 .498 r
.77553 .59515 .77547 .58427 .77829 .59714 .7776 .59772 Mtetra
.593 .074 0 r
.7776 .59772 .77829 .59714 .78033 .59922 .77956 .59866 Mtetra
.477 .794 .999 r
.77956 .59866 .78033 .59922 .7822 .59903 .78143 .59846 Mtetra
.681 .872 .971 r
.78143 .59846 .7822 .59903 .78403 .59827 .78326 .59772 Mtetra
.837 .9 .883 r
.78326 .59772 .78403 .59827 .78586 .59742 .78503 .5962 Mtetra
.879 .773 .74 r
.78503 .5962 .78586 .59742 .78768 .59659 .78671 .59345 Mtetra
.843 .644 .632 r
.78671 .59345 .78768 .59659 .78946 .59517 .7882 .58826 Mtetra
.972 .677 .401 r
.7882 .58826 .78946 .59517 .79108 .59159 .77486 .39237 Mtetra
.572 .358 .552 r
.77486 .39237 .79108 .59159 .77745 .39392 .77608 .38515 Mtetra
.659 .461 .606 r
.77608 .38515 .77745 .39392 .77846 .38418 .77762 .38215 Mtetra
.749 .643 .743 r
.77762 .38215 .77846 .38418 .78003 .38151 .77928 .38055 Mtetra
.701 .77 .905 r
.77928 .38055 .78003 .38151 .78174 .38068 .781 .37982 Mtetra
.641 .77 .942 r
.781 .37982 .78174 .38068 .78349 .3803 .78274 .37935 Mtetra
.704 .771 .904 r
.78274 .37935 .78349 .3803 .78523 .37971 .78447 .3786 Mtetra
.76 .758 .851 r
.78447 .3786 .78523 .37971 .78693 .37867 .78616 .37748 Mtetra
.683 .716 .874 r
.78616 .37748 .78693 .37867 .78867 .37809 .78789 .37682 Mtetra
.283 .49 .882 r
.78789 .37682 .78867 .37809 .79053 .37897 .78975 .3776 Mtetra
.815 .422 0 r
.78975 .3776 .79053 .37897 .79284 .38523 .79201 .38325 Mtetra
.976 .673 .354 r
.79201 .38325 .79284 .38523 .81149 .58566 .81067 .58437 Mtetra
0 0 .4 r
.81067 .58437 .81149 .58566 .81366 .58878 .81287 .58774 Mtetra
.585 .721 .937 r
.81287 .58774 .81366 .58878 .81555 .58847 .81476 .58747 Mtetra
.746 .79 .888 r
.81476 .58747 .81555 .58847 .81737 .58741 .81658 .58643 Mtetra
.764 .799 .881 r
.81658 .58643 .81737 .58741 .81918 .58623 .8184 .58529 Mtetra
.668 .776 .93 r
.8184 .58529 .81918 .58623 .82104 .58556 .82026 .58466 Mtetra
.65 .782 .944 r
.82026 .58466 .82104 .58556 .82291 .58495 .82213 .58411 Mtetra
.615 .781 .961 r
.82213 .58411 .82291 .58495 .82478 .58449 .82401 .58367 Mtetra
.568 .768 .973 r
.82401 .58367 .82478 .58449 .82668 .5842 .82591 .58337 Mtetra
.547 .756 .974 r
.82591 .58337 .82668 .5842 .82858 .58397 .82781 .58314 Mtetra
.449 .707 .977 r
.82781 .58314 .82858 .58397 .83051 .58398 .82974 .58318 Mtetra
.312 .639 .966 r
.82974 .58318 .83051 .58398 .83245 .58422 .8317 .5835 Mtetra
.543 .784 .987 r
.8317 .5835 .83245 .58422 .83435 .58388 .8336 .58323 Mtetra
.871 .885 .842 r
.8336 .58323 .83435 .58388 .8361 .58191 .83536 .58137 Mtetra
.99 .78 .527 r
.83536 .58137 .8361 .58191 .8372 .57284 .83654 .57318 Mtetra
.978 .679 .358 r
.83654 .57318 .8372 .57284 .82053 .37194 .81981 .37115 Mtetra
.958 .813 .658 r
.81981 .37115 .82053 .37194 .82199 .36809 .82125 .3671 Mtetra
.735 .777 .887 r
.82125 .3671 .82199 .36809 .82372 .3672 .82298 .36618 Mtetra
.602 .72 .928 r
.82298 .36618 .82372 .3672 .8255 .36689 .82477 .36587 Mtetra
.6 .718 .927 r
.82477 .36587 .8255 .36689 .82729 .36659 .82656 .36556 Mtetra
.743 .774 .878 r
.82656 .36556 .82729 .36659 .82902 .36562 .82828 .36459 Mtetra
.659 .742 .911 r
.82828 .36459 .82902 .36562 .83079 .36508 .83005 .36404 Mtetra
.237 .513 .909 r
.83005 .36404 .83079 .36508 .83268 .3658 .83194 .36476 Mtetra
.881 .488 .032 r
.83194 .36476 .83268 .3658 .83519 .37288 .83445 .37183 Mtetra
.975 .667 .334 r
.83445 .37183 .83519 .37288 .85663 .57361 .85586 .57261 Mtetra
.655 .202 0 r
.85586 .57261 .85663 .57361 .85891 .57704 .85814 .57604 Mtetra
.384 .63 .951 r
.85814 .57604 .85891 .57704 .86089 .57735 .86012 .57635 Mtetra
.694 .779 .917 r
.86012 .57635 .86089 .57735 .86277 .57659 .862 .5756 Mtetra
.874 .818 .79 r
.862 .5756 .86277 .57659 .8645 .57438 .86373 .57338 Mtetra
.978 .765 .547 r
.86373 .57338 .8645 .57438 .86567 .5666 .8649 .56556 Mtetra
.977 .675 .347 r
.8649 .56556 .86567 .5666 .84714 .36411 .84641 .36304 Mtetra
.947 .783 .646 r
.84641 .36304 .84714 .36411 .84854 .35973 .84781 .35867 Mtetra
.745 .769 .873 r
.84781 .35867 .84854 .35973 .85027 .35873 .84954 .35767 Mtetra
.621 .721 .918 r
.84954 .35767 .85027 .35873 .85207 .35834 .85134 .35729 Mtetra
.59 .707 .924 r
.85134 .35729 .85207 .35834 .85388 .35808 .85315 .35702 Mtetra
.747 .77 .872 r
.85315 .35702 .85388 .35808 .85561 .35706 .85489 .356 Mtetra
.674 .744 .903 r
.85489 .356 .85561 .35706 .85739 .35644 .85667 .35538 Mtetra
.38 .596 .931 r
.85667 .35538 .85739 .35644 .85927 .35683 .85855 .35577 Mtetra
.801 .387 0 r
.85855 .35577 .85927 .35683 .86168 .36214 .86096 .36107 Mtetra
.973 .663 .318 r
.86096 .36107 .86168 .36214 .88502 .56425 .88426 .56324 Mtetra
.717 .277 0 r
.88426 .56324 .88502 .56425 .88744 .56841 .88668 .56741 Mtetra
.502 .693 .954 r
.88668 .56741 .88744 .56841 .88941 .56839 .88865 .56739 Mtetra
.694 .78 .917 r
.88865 .56739 .88941 .56839 .8913 .56764 .89055 .56664 Mtetra
.734 .793 .9 r
.89055 .56664 .8913 .56764 .89317 .56667 .89242 .56566 Mtetra
.495 .689 .954 r
.89242 .56566 .89317 .56667 .89515 .56667 .8944 .56567 Mtetra
.623 .751 .938 r
.8944 .56567 .89515 .56667 .89708 .56623 .89633 .56523 Mtetra
.809 .813 .854 r
.89633 .56523 .89708 .56623 .8989 .56474 .89815 .56373 Mtetra
.979 .773 .555 r
.89815 .56373 .8989 .56474 .90009 .55763 .89934 .5566 Mtetra
.976 .671 .329 r
.89934 .5566 .90009 .55763 .8794 .35444 .87868 .35336 Mtetra
.958 .782 .622 r
.87868 .35336 .8794 .35444 .88072 .34959 .88001 .34852 Mtetra
.742 .77 .875 r
.88001 .34852 .88072 .34959 .88247 .3486 .88176 .34753 Mtetra
.605 .714 .921 r
.88176 .34753 .88247 .3486 .8843 .34827 .88358 .3472 Mtetra
.519 .671 .932 r
.88358 .3472 .8843 .34827 .88616 .34826 .88545 .34719 Mtetra
.653 .735 .91 r
.88545 .34719 .88616 .34826 .88797 .34773 .88726 .34666 Mtetra
.66 .739 .908 r
.88726 .34666 .88797 .34773 .88977 .34717 .88906 .34611 Mtetra
.673 .745 .905 r
.88906 .34611 .88977 .34717 .89157 .34654 .89086 .34548 Mtetra
.764 .78 .866 r
.89086 .34548 .89157 .34654 .89331 .34541 .8926 .34435 Mtetra
.699 .757 .897 r
.8926 .34435 .89331 .34541 .89509 .34466 .89439 .3436 Mtetra
.5 .665 .936 r
.89439 .3436 .89509 .34466 .89697 .34469 .89627 .34364 Mtetra
.744 .324 0 r
.89627 .34364 .89697 .34469 .89941 .34944 .89871 .34843 Mtetra
.971 .656 .295 r
.89871 .34843 .89941 .34944 .92535 .55223 .92462 .55129 Mtetra
.755 .32 0 r
.92462 .55129 .92535 .55223 .92793 .55706 .9272 .55608 Mtetra
.477 .687 .959 r
.9272 .55608 .92793 .55706 .92994 .55711 .92921 .55613 Mtetra
.688 .785 .924 r
.92921 .55613 .92994 .55711 .93187 .55638 .93113 .55539 Mtetra
.763 .809 .89 r
.93113 .55539 .93187 .55638 .93374 .55523 .93301 .55423 Mtetra
.45 .7 .973 r
.30724 .72936 .30823 .73015 .30976 .73021 .30876 .7294 Mtetra
.619 .754 .942 r
.30876 .7294 .30976 .73021 .31131 .72988 .31032 .72905 Mtetra
.773 .776 .855 r
.31032 .72905 .31131 .72988 .31291 .72876 .31192 .72793 Mtetra
.913 .73 .642 r
.31192 .72793 .31291 .72876 .31483 .72216 .31383 .72157 Mtetra
.937 .687 .533 r
.31383 .72157 .31483 .72216 .32776 .52854 .32681 .52799 Mtetra
.918 .754 .663 r
.32681 .52799 .32776 .52854 .32948 .52381 .32854 .52313 Mtetra
.764 .798 .88 r
.32854 .52313 .32948 .52381 .33098 .52293 .33005 .52218 Mtetra
.58 .747 .956 r
.33005 .52218 .33098 .52293 .33244 .52277 .33151 .52195 Mtetra
.408 .66 .962 r
.33151 .52195 .33244 .52277 .33388 .523 .33295 .5221 Mtetra
.628 .725 .916 r
.33295 .5221 .33388 .523 .33535 .52267 .33442 .52176 Mtetra
.646 .727 .908 r
.33442 .52176 .33535 .52267 .33682 .52226 .3359 .52135 Mtetra
.654 .731 .906 r
.3359 .52135 .33682 .52226 .3383 .5218 .33738 .52092 Mtetra
.75 .755 .857 r
.33738 .52092 .3383 .5218 .33981 .52085 .33888 .51998 Mtetra
.702 .753 .892 r
.33888 .51998 .33981 .52085 .3413 .52019 .34038 .51934 Mtetra
.483 .686 .957 r
.34038 .51934 .3413 .52019 .34276 .52021 .34183 .51937 Mtetra
.93 .555 .269 r
.34183 .51937 .34276 .52021 .34398 .5246 .34306 .52359 Mtetra
.94 .683 .521 r
.34306 .52359 .34398 .5246 .33507 .71797 .33411 .71678 Mtetra
.941 .575 .26 r
.33411 .71678 .33507 .71797 .33637 .72274 .33539 .72172 Mtetra
.365 .6 .938 r
.33539 .72172 .33637 .72274 .3379 .72299 .33693 .72203 Mtetra
.692 .742 .889 r
.33693 .72203 .3379 .72299 .33949 .72228 .33851 .72139 Mtetra
.764 .768 .856 r
.33851 .72139 .33949 .72228 .34111 .72113 .34012 .72032 Mtetra
.537 .732 .965 r
.34012 .72032 .34111 .72113 .34267 .72099 .34168 .72019 Mtetra
.604 .755 .95 r
.34168 .72019 .34267 .72099 .34424 .7207 .34325 .71987 Mtetra
.759 .78 .871 r
.34325 .71987 .34424 .7207 .34584 .7197 .34486 .71886 Mtetra
.91 .74 .659 r
.34486 .71886 .34584 .7197 .34767 .7143 .34668 .71362 Mtetra
.941 .688 .527 r
.34668 .71362 .34767 .7143 .35889 .51968 .35795 .51918 Mtetra
.928 .752 .644 r
.35795 .51918 .35889 .51968 .36063 .51419 .3597 .5135 Mtetra
.805 .799 .846 r
.3597 .5135 .36063 .51419 .36216 .51298 .36124 .51222 Mtetra
.607 .756 .95 r
.36124 .51222 .36216 .51298 .36364 .51275 .36272 .51192 Mtetra
.436 .673 .963 r
.36272 .51192 .36364 .51275 .36511 .51293 .36419 .51202 Mtetra
.612 .721 .923 r
.36419 .51202 .36511 .51293 .36659 .51267 .36568 .51173 Mtetra
.65 .727 .905 r
.36568 .51173 .36659 .51267 .36809 .51223 .36717 .51131 Mtetra
.659 .731 .903 r
.36717 .51131 .36809 .51223 .36959 .51175 .36867 .51085 Mtetra
.744 .753 .86 r
.36867 .51085 .36959 .51175 .3711 .51084 .37019 .50994 Mtetra
.715 .751 .88 r
.37019 .50994 .3711 .51084 .37262 .5101 .3717 .50922 Mtetra
.556 .707 .941 r
.3717 .50922 .37262 .5101 .3741 .50996 .37319 .50908 Mtetra
.886 .458 .097 r
.37319 .50908 .3741 .50996 .37545 .51294 .37453 .51208 Mtetra
.944 .684 .513 r
.37453 .51208 .37545 .51294 .3684 .70527 .36742 .70454 Mtetra
.94 .605 .367 r
.36742 .70454 .3684 .70527 .36966 .71221 .36869 .71142 Mtetra
0 .371 .81 r
.36869 .71142 .36966 .71221 .3712 .71299 .37023 .71221 Mtetra
.665 .776 .932 r
.37023 .71221 .3712 .71299 .3728 .71246 .37182 .71168 Mtetra
.762 .793 .879 r
.37182 .71168 .3728 .71246 .37442 .71143 .37344 .71067 Mtetra
.608 .768 .957 r
.37344 .71067 .37442 .71143 .37602 .71095 .37504 .71033 Mtetra
.586 .799 .98 r
.37504 .71033 .37602 .71095 .37761 .71055 .37663 .71 Mtetra
.749 .846 .923 r
.37663 .71 .37761 .71055 .37922 .70982 .37825 .70911 Mtetra
.905 .769 .701 r
.37825 .70911 .37922 .70982 .38089 .70762 .37998 .70539 Mtetra
.942 .686 .521 r
.37998 .70539 .38089 .70762 .38264 .70335 .38927 .51553 Mtetra
.579 .364 .554 r
.38927 .51553 .38264 .70335 .39124 .5274 .39117 .50564 Mtetra
.591 .388 .575 r
.39117 .50564 .39124 .5274 .39329 .51351 .39273 .50379 Mtetra
.582 .402 .603 r
.39273 .50379 .39329 .51351 .39479 .51344 .39425 .50332 Mtetra
.565 .387 .6 r
.39425 .50332 .39479 .51344 .39619 .51614 .39574 .50333 Mtetra
.57 .384 .59 r
.39574 .50333 .39619 .51614 .39757 .51927 .39725 .5031 Mtetra
.572 .379 .581 r
.39725 .5031 .39757 .51927 .39894 .5228 .39876 .50271 Mtetra
.57 .373 .575 r
.39876 .50271 .39894 .5228 .39458 .68064 .40027 .50231 Mtetra
.561 .35 .551 r
.40027 .50231 .39458 .68064 .39601 .68476 .40179 .50188 Mtetra
.40179 .50188 .39601 .68476 .39754 .68601 .40331 .50143 Mtetra
.40331 .50143 .39754 .68601 .39911 .68658 .40482 .50097 Mtetra
.562 .35 .551 r
.40482 .50097 .39911 .68658 .4066 .51975 .40636 .50011 Mtetra
.576 .378 .576 r
.40636 .50011 .4066 .51975 .40831 .51395 .40789 .49937 Mtetra
.565 .376 .584 r
.40789 .49937 .40831 .51395 .40413 .67904 .40939 .49931 Mtetra
.552 .343 .55 r
.40939 .49931 .40413 .67904 .40513 .69614 .41077 .50299 Mtetra
0 0 .323 r
.41077 .50299 .40513 .69614 .40659 .70035 .40575 .6959 Mtetra
0 0 .431 r
.40575 .6959 .40659 .70035 .40812 .70234 .40718 .70089 Mtetra
.17 .401 .844 r
.40718 .70089 .40812 .70234 .40971 .70272 .40875 .70184 Mtetra
.617 .746 .938 r
.40875 .70184 .40971 .70272 .41133 .70232 .41037 .70149 Mtetra
.712 .78 .905 r
.41037 .70149 .41133 .70232 .41295 .7017 .412 .70075 Mtetra
.672 .745 .906 r
.412 .70075 .41295 .7017 .41457 .70127 .41362 .7002 Mtetra
.63 .708 .902 r
.41362 .7002 .41457 .70127 .41618 .70098 .41524 .69982 Mtetra
.633 .692 .887 r
.41524 .69982 .41618 .70098 .4178 .70069 .41686 .69944 Mtetra
.641 .679 .871 r
.41686 .69944 .4178 .70069 .41942 .70031 .41848 .69902 Mtetra
.647 .674 .862 r
.41848 .69902 .41942 .70031 .42104 .69987 .4201 .69856 Mtetra
.65 .673 .859 r
.4201 .69856 .42104 .69987 .42267 .69941 .42173 .69809 Mtetra
.65 .673 .858 r
.42173 .69809 .42267 .69941 .4243 .69895 .42336 .69762 Mtetra
.651 .671 .856 r
.42336 .69762 .4243 .69895 .42592 .69849 .42498 .69714 Mtetra
.654 .67 .853 r
.42498 .69714 .42592 .69849 .42755 .69799 .42661 .69665 Mtetra
.663 .673 .849 r
.42661 .69665 .42755 .69799 .42918 .69742 .42824 .6961 Mtetra
.67 .68 .85 r
.42824 .6961 .42918 .69742 .43082 .69677 .42988 .69552 Mtetra
.672 .69 .858 r
.42988 .69552 .43082 .69677 .43245 .69613 .43151 .69493 Mtetra
.664 .697 .871 r
.43151 .69493 .43245 .69613 .43409 .69557 .43314 .6944 Mtetra
.655 .699 .879 r
.43314 .6944 .43409 .69557 .43572 .69509 .43478 .69391 Mtetra
.65 .696 .879 r
.43478 .69391 .43572 .69509 .43735 .69464 .43641 .69345 Mtetra
.636 .688 .882 r
.43641 .69345 .43735 .69464 .43898 .69434 .43804 .69305 Mtetra
.633 .67 .868 r
.43804 .69305 .43898 .69434 .44061 .69405 .43968 .69266 Mtetra
.653 .664 .848 r
.43968 .69266 .44061 .69405 .44225 .69346 .44132 .69217 Mtetra
.714 .698 .834 r
.44132 .69217 .44225 .69346 .44392 .69182 .44296 .6913 Mtetra
.809 .86 .887 r
.44296 .6913 .44392 .69182 .44562 .68845 .44462 .69004 Mtetra
.01 0 0 r
.44462 .69004 .44562 .68845 .4474 .68158 .44628 .68865 Mtetra
.492 .236 .453 r
.44628 .68865 .4474 .68158 .45301 .49766 .44793 .68762 Mtetra
.558 .344 .545 r
.44793 .68762 .45301 .49766 .45459 .49571 .44957 .68712 Mtetra
.559 .344 .545 r
.44957 .68712 .45459 .49571 .45608 .49792 .45121 .68679 Mtetra
.558 .344 .545 r
.45121 .68679 .45608 .49792 .45754 .50237 .45285 .68642 Mtetra
.45285 .68642 .45754 .50237 .45909 .50227 .4545 .68596 Mtetra
.4545 .68596 .45909 .50227 .46063 .5025 .45614 .6855 Mtetra
.45614 .6855 .46063 .5025 .46217 .50326 .45778 .68505 Mtetra
.45778 .68505 .46217 .50326 .46369 .50497 .45943 .68461 Mtetra
.45943 .68461 .46369 .50497 .46517 .50913 .46108 .68416 Mtetra
.559 .344 .545 r
.46108 .68416 .46517 .50913 .46394 .66868 .46272 .68402 Mtetra
.553 .317 .511 r
.46272 .68402 .46394 .66868 .46551 .67239 .46436 .68397 Mtetra
.531 .29 .495 r
.46436 .68397 .46551 .67239 .46718 .67044 .46602 .68327 Mtetra
.45 .225 .481 r
.46602 .68327 .46718 .67044 .47175 .48777 .46772 .67998 Mtetra
0 0 .342 r
.46772 .67998 .47175 .48777 .4734 .48143 .47243 .48617 Mtetra
0 0 0 r
.47243 .48617 .4734 .48143 .475 .47832 .47411 .47825 Mtetra
.932 .899 .772 r
.47411 .47825 .475 .47832 .47657 .47671 .4757 .47584 Mtetra
.709 .763 .895 r
.4757 .47584 .47657 .47671 .47814 .47609 .47726 .47513 Mtetra
.604 .712 .921 r
.47726 .47513 .47814 .47609 .47969 .47575 .47882 .47486 Mtetra
.593 .725 .936 r
.47882 .47486 .47969 .47575 .48125 .47541 .48037 .47461 Mtetra
.654 .768 .933 r
.48037 .47461 .48125 .47541 .48281 .47492 .48194 .47414 Mtetra
.647 .771 .939 r
.48194 .47414 .48281 .47492 .48437 .47445 .4835 .47369 Mtetra
.637 .772 .945 r
.4835 .47369 .48437 .47445 .48594 .47406 .48506 .47327 Mtetra
.628 .764 .945 r
.48506 .47327 .48594 .47406 .4875 .47374 .48662 .47289 Mtetra
.631 .749 .933 r
.48662 .47289 .4875 .47374 .48906 .47342 .48819 .4725 Mtetra
.642 .736 .917 r
.48819 .4725 .48906 .47342 .49063 .47305 .48976 .47209 Mtetra
.655 .73 .905 r
.48976 .47209 .49063 .47305 .49219 .47259 .49132 .47162 Mtetra
.663 .733 .902 r
.49132 .47162 .49219 .47259 .49376 .47206 .49289 .47112 Mtetra
.674 .743 .902 r
.49289 .47112 .49376 .47206 .49533 .47144 .49446 .47057 Mtetra
.686 .762 .909 r
.49446 .47057 .49533 .47144 .4969 .47074 .49603 .46998 Mtetra
.688 .786 .925 r
.49603 .46998 .4969 .47074 .49848 .47004 .49761 .46937 Mtetra
.689 .811 .94 r
.49761 .46937 .49848 .47004 .50005 .46931 .49918 .46876 Mtetra
.681 .84 .959 r
.49918 .46876 .50005 .46931 .50162 .46859 .50075 .46815 Mtetra
.629 .861 .986 r
.50075 .46815 .50162 .46859 .5032 .46813 .50233 .46765 Mtetra
.508 .808 .999 r
.50233 .46765 .5032 .46813 .50477 .46841 .5039 .46743 Mtetra
.426 .631 .94 r
.5039 .46743 .50477 .46841 .50633 .4703 .50547 .46763 Mtetra
.519 .467 .739 r
.50547 .46763 .50633 .4703 .50788 .47493 .50704 .46798 Mtetra
.559 .401 .624 r
.50704 .46798 .50788 .47493 .50859 .66078 .50862 .46815 Mtetra
.561 .35 .551 r
.50862 .46815 .50859 .66078 .51025 .66236 .5102 .46773 Mtetra
.5102 .46773 .51025 .66236 .51193 .66048 .51178 .46711 Mtetra
.51178 .46711 .51193 .66048 .51361 .657 .51336 .46647 Mtetra
.51336 .46647 .51361 .657 .51528 .65643 .51494 .46595 Mtetra
.51494 .46595 .51528 .65643 .51696 .65578 .51653 .46543 Mtetra
.51653 .46543 .51696 .65578 .51863 .65503 .51811 .46491 Mtetra
.51811 .46491 .51863 .65503 .52031 .65416 .5197 .46437 Mtetra
.5197 .46437 .52031 .65416 .52199 .65325 .52128 .46384 Mtetra
.52128 .46384 .52199 .65325 .52366 .64955 .52287 .46315 Mtetra
.562 .351 .551 r
.52287 .46315 .52366 .64955 .52532 .47749 .52446 .46217 Mtetra
.573 .382 .584 r
.52446 .46217 .52532 .47749 .52691 .47741 .52605 .46172 Mtetra
.538 .354 .58 r
.52605 .46172 .52691 .47741 .52871 .65672 .52764 .46287 Mtetra
0 0 .389 r
.52764 .46287 .52871 .65672 .5304 .66372 .52948 .65158 Mtetra
0 0 .427 r
.52948 .65158 .5304 .66372 .5321 .66645 .53118 .66416 Mtetra
0 .114 .655 r
.53118 .66416 .5321 .66645 .53379 .66756 .53288 .66655 Mtetra
.546 .696 .938 r
.53288 .66655 .53379 .66756 .53549 .6673 .53458 .66644 Mtetra
.689 .779 .92 r
.53458 .66644 .53549 .6673 .53718 .66669 .53627 .66578 Mtetra
.721 .776 .896 r
.53627 .66578 .53718 .66669 .53887 .66598 .53797 .66496 Mtetra
.654 .733 .907 r
.53797 .66496 .53887 .66598 .54057 .66548 .53966 .66446 Mtetra
.655 .734 .907 r
.53966 .66446 .54057 .66548 .54227 .66498 .54136 .66395 Mtetra
.654 .733 .907 r
.54136 .66395 .54227 .66498 .54397 .66449 .54306 .66345 Mtetra
.651 .73 .908 r
.54306 .66345 .54397 .66449 .54566 .664 .54476 .66297 Mtetra
.649 .73 .908 r
.54476 .66297 .54566 .664 .54736 .66352 .54646 .66249 Mtetra
.646 .729 .909 r
.54646 .66249 .54736 .66352 .54907 .66306 .54816 .66202 Mtetra
.643 .728 .91 r
.54816 .66202 .54907 .66306 .55077 .6626 .54986 .66157 Mtetra
.643 .729 .911 r
.54986 .66157 .55077 .6626 .55247 .66215 .55157 .66112 Mtetra
.626 .724 .917 r
.55157 .66112 .55247 .66215 .55418 .66174 .55327 .66073 Mtetra
.541 .696 .94 r
.55327 .66073 .55418 .66174 .55588 .66151 .55498 .66063 Mtetra
.642 .762 .936 r
.55498 .66063 .55588 .66151 .55759 .66106 .55669 .66016 Mtetra
.798 .793 .848 r
.55669 .66016 .55759 .66106 .55929 .66005 .55839 .6588 Mtetra
.91 .737 .655 r
.55839 .6588 .55929 .66005 .56098 .65736 .56005 .65384 Mtetra
.959 .687 .475 r
.56005 .65384 .56098 .65736 .56264 .65279 .55969 .45786 Mtetra
.572 .359 .552 r
.55969 .45786 .56264 .65279 .5642 .63901 .56123 .45102 Mtetra
.562 .351 .551 r
.56123 .45102 .5642 .63901 .56385 .465 .56283 .44989 Mtetra
.571 .381 .584 r
.56283 .44989 .56385 .465 .56551 .46872 .56445 .44956 Mtetra
.563 .369 .576 r
.56445 .44956 .56551 .46872 .56934 .64027 .56606 .44957 Mtetra
.561 .35 .551 r
.56606 .44957 .56934 .64027 .57106 .64024 .56768 .44908 Mtetra
.56768 .44908 .57106 .64024 .57277 .6402 .56929 .4486 Mtetra
.56929 .4486 .57277 .6402 .57448 .64009 .57091 .44812 Mtetra
.57091 .44812 .57448 .64009 .5762 .63978 .57252 .44761 Mtetra
.57252 .44761 .5762 .63978 .57791 .63941 .57414 .44711 Mtetra
.57414 .44711 .57791 .63941 .57963 .63905 .57576 .4466 Mtetra
.57576 .4466 .57963 .63905 .58134 .63879 .57738 .4461 Mtetra
.57738 .4461 .58134 .63879 .58306 .63848 .579 .4456 Mtetra
.579 .4456 .58306 .63848 .58478 .63835 .58062 .44511 Mtetra
.56 .35 .551 r
.58062 .44511 .58478 .63835 .58655 .64071 .58224 .44476 Mtetra
.561 .35 .551 r
.58224 .44476 .58655 .64071 .58828 .64053 .58386 .44429 Mtetra
.58386 .44429 .58828 .64053 .58989 .6345 .58548 .44356 Mtetra
.562 .351 .551 r
.58548 .44356 .58989 .6345 .588 .44711 .58709 .44215 Mtetra
.648 .485 .649 r
.58709 .44215 .588 .44711 .58955 .44277 .5887 .44079 Mtetra
.713 .623 .755 r
.5887 .44079 .58955 .44277 .59114 .44032 .59031 .43964 Mtetra
.689 .816 .943 r
.59031 .43964 .59114 .44032 .59276 .43947 .59194 .439 Mtetra
.623 .856 .987 r
.59194 .439 .59276 .43947 .59439 .43901 .59356 .4385 Mtetra
.594 .839 .991 r
.59356 .4385 .59439 .43901 .59602 .43876 .59519 .43809 Mtetra
.628 .804 .967 r
.59519 .43809 .59602 .43876 .59765 .43841 .59682 .43765 Mtetra
.637 .782 .951 r
.59682 .43765 .59765 .43841 .59928 .43807 .59845 .43721 Mtetra
.652 .76 .929 r
.59845 .43721 .59928 .43807 .60092 .43768 .60009 .43673 Mtetra
.686 .75 .9 r
.60009 .43673 .60092 .43768 .60254 .43703 .60172 .43611 Mtetra
.692 .76 .904 r
.60172 .43611 .60254 .43703 .60417 .43632 .60335 .43546 Mtetra
.691 .774 .915 r
.60335 .43546 .60417 .43632 .6058 .43561 .60498 .43482 Mtetra
.749 .803 .896 r
.60498 .43482 .6058 .43561 .60743 .43481 .6066 .4339 Mtetra
.688 .761 .907 r
.6066 .4339 .60743 .43481 .60906 .43421 .60823 .43327 Mtetra
.531 .695 .944 r
.60823 .43327 .60906 .43421 .6107 .43397 .60988 .43319 Mtetra
.766 .286 0 r
.60988 .43319 .6107 .43397 .61238 .43489 .6116 .43582 Mtetra
.965 .681 .444 r
.6116 .43582 .61238 .43489 .61409 .43724 .61841 .62602 Mtetra
.579 .36 .547 r
.61841 .62602 .61409 .43724 .61605 .4479 .62052 .63866 Mtetra
.561 .346 .546 r
.62052 .63866 .61605 .4479 .62306 .63659 .62232 .64007 Mtetra
.553 .238 .387 r
.62232 .64007 .62306 .63659 .62492 .63985 .62409 .64035 Mtetra
.174 0 0 r
.62409 .64035 .62492 .63985 .62672 .64123 .62584 .64013 Mtetra
.623 .713 .91 r
.62584 .64013 .62672 .64123 .62848 .64115 .6276 .63975 Mtetra
.656 .673 .855 r
.6276 .63975 .62848 .64115 .63023 .64059 .62935 .63921 Mtetra
.671 .681 .851 r
.62935 .63921 .63023 .64059 .63198 .63981 .6311 .63858 Mtetra
.656 .701 .879 r
.6311 .63858 .63198 .63981 .63373 .63925 .63285 .63805 Mtetra
.654 .706 .885 r
.63285 .63805 .63373 .63925 .63548 .63871 .63461 .63753 Mtetra
.654 .71 .889 r
.63461 .63753 .63548 .63871 .63724 .63816 .63636 .63701 Mtetra
.653 .715 .893 r
.63636 .63701 .63724 .63816 .63899 .63763 .63812 .6365 Mtetra
.653 .719 .897 r
.63812 .6365 .63899 .63763 .64075 .6371 .63988 .63599 Mtetra
.653 .723 .9 r
.63988 .63599 .64075 .6371 .64251 .63657 .64164 .63547 Mtetra
.652 .726 .903 r
.64164 .63547 .64251 .63657 .64427 .63607 .6434 .63497 Mtetra
.653 .724 .901 r
.6434 .63497 .64427 .63607 .64603 .63557 .64516 .63445 Mtetra
.655 .723 .899 r
.64516 .63445 .64603 .63557 .64779 .63504 .64692 .63393 Mtetra
.666 .727 .895 r
.64692 .63393 .64779 .63504 .64955 .63441 .64868 .63336 Mtetra
.666 .739 .905 r
.64868 .63336 .64955 .63441 .65131 .63376 .65044 .63278 Mtetra
.658 .752 .919 r
.65044 .63278 .65131 .63376 .65307 .63317 .65221 .63224 Mtetra
.594 .74 .946 r
.65221 .63224 .65307 .63317 .65485 .63308 .65398 .63193 Mtetra
.606 .698 .908 r
.65398 .63193 .65485 .63308 .65663 .63293 .65576 .63162 Mtetra
.64 .684 .875 r
.65576 .63162 .65663 .63293 .6584 .63239 .65753 .63117 Mtetra
.678 .712 .874 r
.65753 .63117 .6584 .63239 .66012 .6305 .6593 .63052 Mtetra
.681 .975 .901 r
.6593 .63052 .66012 .6305 .66177 .62698 .66105 .62944 Mtetra
.165 0 .181 r
.66105 .62944 .66177 .62698 .66316 .61711 .66276 .62754 Mtetra
.251 .067 .426 r
.66276 .62754 .66316 .61711 .65712 .42493 .66428 .62061 Mtetra
.02 0 .419 r
.66428 .62061 .65712 .42493 .65864 .42081 .65796 .42284 Mtetra
.726 .76 .255 r
.65796 .42284 .65864 .42081 .66024 .41857 .65945 .41807 Mtetra
.834 .885 .879 r
.65945 .41807 .66024 .41857 .66189 .41768 .66108 .41668 Mtetra
.64 .73 .914 r
.66108 .41668 .66189 .41768 .66356 .41734 .66275 .41625 Mtetra
.543 .668 .918 r
.66275 .41625 .66356 .41734 .66525 .41724 .66444 .41618 Mtetra
.618 .708 .91 r
.66444 .41618 .66525 .41724 .66693 .41688 .66612 .41584 Mtetra
.652 .726 .903 r
.66612 .41584 .66693 .41688 .6686 .41636 .66779 .41535 Mtetra
.662 .736 .905 r
.66779 .41535 .6686 .41636 .67026 .41578 .66946 .41483 Mtetra
.7 .761 .899 r
.66946 .41483 .67026 .41578 .67192 .41487 .67113 .41412 Mtetra
.704 .812 .932 r
.67113 .41412 .67192 .41487 .67358 .41401 .67279 .41341 Mtetra
.662 .839 .968 r
.67279 .41341 .67358 .41401 .67525 .4135 .67447 .41283 Mtetra
.61 .803 .973 r
.67447 .41283 .67525 .4135 .67698 .41414 .67615 .41242 Mtetra
.563 .577 .825 r
.67615 .41242 .67698 .41414 .67879 .41634 .67785 .41239 Mtetra
.504 .412 .684 r
.67785 .41239 .67879 .41634 .68093 .42533 .67959 .41311 Mtetra
.395 .261 .578 r
.67959 .41311 .68093 .42533 .69193 .61676 .68154 .41827 Mtetra
.046 0 .438 r
.68154 .41827 .69193 .61676 .69392 .62019 .6929 .61576 Mtetra
.066 .11 .599 r
.6929 .61576 .69392 .62019 .6958 .62166 .69493 .62005 Mtetra
.344 .483 .856 r
.69493 .62005 .6958 .62166 .69764 .62199 .69679 .62083 Mtetra
.628 .706 .902 r
.69679 .62083 .69764 .62199 .69944 .62164 .69859 .62042 Mtetra
.721 .731 .859 r
.69859 .62042 .69944 .62164 .70122 .62073 .70036 .6195 Mtetra
.755 .741 .839 r
.70036 .6195 .70122 .62073 .70293 .61863 .70213 .61833 Mtetra
.816 .947 .908 r
.70213 .61833 .70293 .61863 .70456 .61488 .70388 .61696 Mtetra
.205 0 .157 r
.70388 .61696 .70456 .61488 .70595 .60666 .70563 .61548 Mtetra
.53 .278 .478 r
.70563 .61548 .70595 .60666 .69808 .4249 .70743 .61496 Mtetra
.559 .344 .545 r
.70743 .61496 .69808 .4249 .70068 .44105 .70925 .61476 Mtetra
.558 .343 .545 r
.70925 .61476 .70068 .44105 .71068 .59298 .71103 .61394 Mtetra
.476 .263 .51 r
.71103 .61394 .71068 .59298 .70258 .4124 .71261 .60917 Mtetra
.044 0 .433 r
.71261 .60917 .70258 .4124 .70401 .40719 .70343 .40998 Mtetra
0 0 0 r
.70343 .40998 .70401 .40719 .70558 .40435 .70482 .40398 Mtetra
.891 .915 .834 r
.70482 .40398 .70558 .40435 .70723 .40312 .70645 .40214 Mtetra
.666 .746 .91 r
.70645 .40214 .70723 .40312 .70893 .40269 .70814 .40159 Mtetra
.572 .682 .915 r
.70814 .40159 .70893 .40269 .71065 .40248 .70986 .40142 Mtetra
.625 .714 .91 r
.70986 .40142 .71065 .40248 .71235 .402 .71156 .40104 Mtetra
.677 .755 .91 r
.71156 .40104 .71235 .402 .71403 .4013 .71326 .40044 Mtetra
.678 .78 .927 r
.71326 .40044 .71403 .4013 .71572 .40058 .71495 .39983 Mtetra
.683 .809 .943 r
.71495 .39983 .71572 .40058 .7174 .39979 .71664 .39919 Mtetra
.665 .845 .969 r
.71664 .39919 .7174 .39979 .71909 .39909 .71834 .39858 Mtetra
.611 .853 .989 r
.71834 .39858 .71909 .39909 .7208 .39871 .72005 .3981 Mtetra
.473 .765 .994 r
.72005 .3981 .7208 .39871 .72258 .39938 .72178 .39798 Mtetra
.486 .582 .876 r
.72178 .39798 .72258 .39938 .72446 .40172 .72353 .39821 Mtetra
.537 .447 .701 r
.72353 .39821 .72446 .40172 .72663 .40853 .72529 .39855 Mtetra
.568 .392 .604 r
.72529 .39855 .72663 .40853 .74019 .59615 .72702 .39848 Mtetra
.561 .35 .551 r
.72702 .39848 .74019 .59615 .74206 .59644 .72873 .39793 Mtetra
.72873 .39793 .74206 .59644 .74372 .59357 .73043 .39723 Mtetra
.562 .35 .551 r
.73043 .39723 .74372 .59357 .74497 .58419 .73211 .39624 Mtetra
.561 .35 .551 r
.73211 .39624 .74497 .58419 .73556 .41149 .7338 .39533 Mtetra
.568 .378 .583 r
.7338 .39533 .73556 .41149 .73795 .42104 .73553 .39508 Mtetra
.527 .338 .568 r
.73553 .39508 .73795 .42104 .75137 .59719 .73746 .39781 Mtetra
.075 0 .455 r
.73746 .39781 .75137 .59719 .75356 .60206 .75242 .59624 Mtetra
.026 .056 .555 r
.75242 .59624 .75356 .60206 .75557 .60427 .7547 .60247 Mtetra
.218 .379 .811 r
.7547 .60247 .75557 .60427 .75748 .60483 .75665 .60381 Mtetra
.6 .728 .934 r
.75665 .60381 .75748 .60483 .75932 .60443 .7585 .60349 Mtetra
.701 .782 .914 r
.7585 .60349 .75932 .60443 .76114 .60377 .76032 .60272 Mtetra
.671 .75 .91 r
.76032 .60272 .76114 .60377 .76298 .60336 .76215 .6021 Mtetra
.618 .688 .893 r
.76215 .6021 .76298 .60336 .76484 .60317 .764 .60174 Mtetra
.641 .67 .862 r
.764 .60174 .76484 .60317 .76668 .60269 .76584 .60126 Mtetra
.708 .699 .839 r
.76584 .60126 .76668 .60269 .76845 .60106 .76765 .60035 Mtetra
.81 .86 .886 r
.76765 .60035 .76845 .60106 .77008 .59763 .76943 .59899 Mtetra
.052 0 0 r
.76943 .59899 .77008 .59763 .77155 .59206 .77121 .59759 Mtetra
.504 .231 .434 r
.77121 .59759 .77155 .59206 .77332 .59055 .77304 .59695 Mtetra
.555 .281 .456 r
.77304 .59695 .77332 .59055 .77553 .59515 .77494 .59717 Mtetra
.533 .155 .27 r
.77494 .59717 .77553 .59515 .7776 .59772 .77685 .59744 Mtetra
.137 .657 .887 r
.77685 .59744 .7776 .59772 .77956 .59866 .77874 .59755 Mtetra
.571 .699 .928 r
.77874 .59755 .77956 .59866 .78143 .59846 .78061 .59735 Mtetra
.691 .748 .895 r
.78061 .59735 .78143 .59846 .78326 .59772 .78245 .59662 Mtetra
.861 .79 .78 r
.78245 .59662 .78326 .59772 .78503 .5962 .78417 .5944 Mtetra
.925 .721 .608 r
.78417 .5944 .78503 .5962 .78671 .59345 .78557 .58799 Mtetra
.974 .679 .398 r
.78557 .58799 .78671 .59345 .7882 .58826 .77203 .38758 Mtetra
.568 .355 .551 r
.77203 .38758 .7882 .58826 .77486 .39237 .77344 .38282 Mtetra
.614 .427 .605 r
.77344 .38282 .77486 .39237 .77608 .38515 .77509 .38124 Mtetra
.64 .501 .678 r
.77509 .38124 .77608 .38515 .77762 .38215 .7768 .38028 Mtetra
.667 .618 .79 r
.7768 .38028 .77762 .38215 .77928 .38055 .77852 .37958 Mtetra
.683 .76 .91 r
.77852 .37958 .77928 .38055 .781 .37982 .78025 .37893 Mtetra
.664 .774 .931 r
.78025 .37893 .781 .37982 .78274 .37935 .78199 .37837 Mtetra
.716 .771 .896 r
.78199 .37837 .78274 .37935 .78447 .3786 .78371 .37756 Mtetra
.754 .771 .867 r
.78371 .37756 .78447 .3786 .78616 .37748 .78541 .37651 Mtetra
.674 .759 .915 r
.78541 .37651 .78616 .37748 .78789 .37682 .78715 .37591 Mtetra
.116 .467 .892 r
.78715 .37591 .78789 .37682 .78975 .3776 .78901 .37673 Mtetra
.88 .471 .034 r
.78901 .37673 .78975 .3776 .79201 .38325 .79128 .38252 Mtetra
.975 .672 .359 r
.79128 .38252 .79201 .38325 .81067 .58437 .80988 .58338 Mtetra
.672 .216 0 r
.80988 .58338 .81067 .58437 .81287 .58774 .81207 .58669 Mtetra
.58 .717 .936 r
.81207 .58669 .81287 .58774 .81476 .58747 .81396 .58644 Mtetra
.739 .782 .887 r
.81396 .58644 .81476 .58747 .81658 .58643 .81579 .58544 Mtetra
.755 .794 .885 r
.81579 .58544 .81658 .58643 .8184 .58529 .81762 .58435 Mtetra
.655 .774 .937 r
.81762 .58435 .8184 .58529 .82026 .58466 .81948 .58378 Mtetra
.636 .781 .951 r
.81948 .58378 .82026 .58466 .82213 .58411 .82136 .58328 Mtetra
.604 .781 .965 r
.82136 .58328 .82213 .58411 .82401 .58367 .82325 .58287 Mtetra
.563 .772 .977 r
.82325 .58287 .82401 .58367 .82591 .58337 .82514 .58259 Mtetra
.548 .767 .979 r
.82514 .58259 .82591 .58337 .82781 .58314 .82704 .58234 Mtetra
.472 .725 .98 r
.82704 .58234 .82781 .58314 .82974 .58318 .82897 .5823 Mtetra
.394 .663 .967 r
.82897 .5823 .82974 .58318 .8317 .5835 .83091 .5825 Mtetra
.607 .74 .94 r
.83091 .5825 .8317 .5835 .8336 .58323 .83281 .58214 Mtetra
.843 .795 .805 r
.83281 .58214 .8336 .58323 .83536 .58137 .83457 .5802 Mtetra
.971 .75 .547 r
.83457 .5802 .83536 .58137 .83654 .57318 .83572 .57176 Mtetra
.977 .678 .363 r
.83572 .57176 .83654 .57318 .81981 .37115 .81907 .37011 Mtetra
.938 .785 .665 r
.81907 .37011 .81981 .37115 .82125 .3671 .82052 .36612 Mtetra
.736 .779 .888 r
.82052 .36612 .82125 .3671 .82298 .36618 .82225 .36519 Mtetra
.604 .728 .932 r
.82225 .36519 .82298 .36618 .82477 .36587 .82403 .36486 Mtetra
.603 .724 .93 r
.82403 .36486 .82477 .36587 .82656 .36556 .82582 .36454 Mtetra
.744 .775 .878 r
.82582 .36454 .82656 .36556 .82828 .36459 .82755 .36355 Mtetra
.66 .742 .911 r
.82755 .36355 .82828 .36459 .83005 .36404 .82932 .363 Mtetra
.24 .514 .909 r
.82932 .363 .83005 .36404 .83194 .36476 .83121 .36372 Mtetra
.88 .487 .03 r
.83121 .36372 .83194 .36476 .83445 .37183 .83372 .37076 Mtetra
.975 .667 .334 r
.83372 .37076 .83445 .37183 .85586 .57261 .85509 .57161 Mtetra
.653 .202 0 r
.85509 .57161 .85586 .57261 .85814 .57604 .85737 .57505 Mtetra
.385 .63 .951 r
.85737 .57505 .85814 .57604 .86012 .57635 .85935 .57536 Mtetra
.695 .779 .916 r
.85935 .57536 .86012 .57635 .862 .5756 .86123 .5746 Mtetra
.874 .817 .789 r
.86123 .5746 .862 .5756 .86373 .57338 .86296 .57237 Mtetra
.978 .764 .546 r
.86296 .57237 .86373 .57338 .8649 .56556 .86413 .5645 Mtetra
.977 .675 .348 r
.86413 .5645 .8649 .56556 .84641 .36304 .84568 .36196 Mtetra
.946 .782 .646 r
.84568 .36196 .84641 .36304 .84781 .35867 .84708 .35761 Mtetra
.744 .768 .872 r
.84708 .35761 .84781 .35867 .84954 .35767 .84881 .35661 Mtetra
.621 .72 .917 r
.84881 .35661 .84954 .35767 .85134 .35729 .85061 .35622 Mtetra
.59 .706 .924 r
.85061 .35622 .85134 .35729 .85315 .35702 .85243 .35596 Mtetra
.746 .77 .872 r
.85243 .35596 .85315 .35702 .85489 .356 .85416 .35494 Mtetra
.674 .744 .903 r
.85416 .35494 .85489 .356 .85667 .35538 .85594 .35432 Mtetra
.38 .595 .93 r
.85594 .35432 .85667 .35538 .85855 .35577 .85783 .35471 Mtetra
.8 .386 0 r
.85783 .35471 .85855 .35577 .86096 .36107 .86023 .36 Mtetra
.973 .663 .318 r
.86023 .36 .86096 .36107 .88426 .56324 .88351 .56224 Mtetra
.718 .278 0 r
.88351 .56224 .88426 .56324 .88668 .56741 .88592 .56641 Mtetra
.502 .693 .954 r
.88592 .56641 .88668 .56741 .88865 .56739 .8879 .56639 Mtetra
.694 .78 .917 r
.8879 .56639 .88865 .56739 .89055 .56664 .88979 .56563 Mtetra
.734 .794 .9 r
.88979 .56563 .89055 .56664 .89242 .56566 .89166 .56466 Mtetra
.495 .689 .954 r
.89166 .56466 .89242 .56566 .8944 .56567 .89365 .56466 Mtetra
.623 .751 .938 r
.89365 .56466 .8944 .56567 .89633 .56523 .89558 .56422 Mtetra
.809 .813 .854 r
.89558 .56422 .89633 .56523 .89815 .56373 .8974 .56272 Mtetra
.979 .772 .555 r
.8974 .56272 .89815 .56373 .89934 .5566 .89859 .55555 Mtetra
.976 .671 .329 r
.89859 .55555 .89934 .5566 .87868 .35336 .87796 .35227 Mtetra
.957 .782 .623 r
.87796 .35227 .87868 .35336 .88001 .34852 .87929 .34745 Mtetra
.742 .768 .874 r
.87929 .34745 .88001 .34852 .88176 .34753 .88104 .34646 Mtetra
.605 .713 .92 r
.88104 .34646 .88176 .34753 .88358 .3472 .88287 .34613 Mtetra
.519 .67 .931 r
.88287 .34613 .88358 .3472 .88545 .34719 .88474 .34612 Mtetra
.652 .734 .909 r
.88474 .34612 .88545 .34719 .88726 .34666 .88654 .34559 Mtetra
.658 .738 .908 r
.88654 .34559 .88726 .34666 .88906 .34611 .88835 .34504 Mtetra
.672 .744 .905 r
.88835 .34504 .88906 .34611 .89086 .34548 .89015 .34442 Mtetra
.763 .779 .866 r
.89015 .34442 .89086 .34548 .8926 .34435 .89189 .34329 Mtetra
.698 .757 .898 r
.89189 .34329 .8926 .34435 .89439 .3436 .89368 .34255 Mtetra
.497 .664 .937 r
.89368 .34255 .89439 .3436 .89627 .34364 .89556 .3426 Mtetra
.749 .329 0 r
.89556 .3426 .89627 .34364 .89871 .34843 .89801 .34744 Mtetra
.971 .656 .295 r
.89801 .34744 .89871 .34843 .92462 .55129 .9239 .55035 Mtetra
.753 .317 0 r
.9239 .55035 .92462 .55129 .9272 .55608 .92647 .5551 Mtetra
.479 .688 .959 r
.92647 .5551 .9272 .55608 .92921 .55613 .92848 .55514 Mtetra
.688 .785 .924 r
.92848 .55514 .92921 .55613 .93113 .55539 .9304 .5544 Mtetra
.764 .81 .89 r
.9304 .5544 .93113 .55539 .93301 .55423 .93227 .55324 Mtetra
.502 .727 .973 r
.30624 .72859 .30724 .72936 .30876 .7294 .30777 .72852 Mtetra
.629 .742 .929 r
.30777 .72852 .30876 .7294 .31032 .72905 .30933 .72815 Mtetra
.754 .761 .858 r
.30933 .72815 .31032 .72905 .31192 .72793 .31092 .72714 Mtetra
.902 .745 .677 r
.31092 .72714 .31192 .72793 .31383 .72157 .31273 .72262 Mtetra
.939 .689 .532 r
.31273 .72262 .31383 .72157 .32681 .52799 .3256 .53169 Mtetra
.916 .846 .397 r
.3256 .53169 .32681 .52799 .32854 .52313 .32749 .52423 Mtetra
.532 .828 .497 r
.32749 .52423 .32854 .52313 .33005 .52218 .32904 .52257 Mtetra
.504 .901 .773 r
.32904 .52257 .33005 .52218 .33151 .52195 .33054 .52171 Mtetra
.592 .891 .99 r
.33054 .52171 .33151 .52195 .33295 .5221 .33202 .52124 Mtetra
.666 .746 .91 r
.33202 .52124 .33295 .5221 .33442 .52176 .3335 .52076 Mtetra
.643 .709 .895 r
.3335 .52076 .33442 .52176 .3359 .52135 .33498 .52037 Mtetra
.632 .708 .902 r
.33498 .52037 .3359 .52135 .33738 .52092 .33645 .52002 Mtetra
.736 .751 .864 r
.33645 .52002 .33738 .52092 .33888 .51998 .33795 .51918 Mtetra
.697 .764 .903 r
.33795 .51918 .33888 .51998 .34038 .51934 .33944 .51856 Mtetra
.512 .716 .964 r
.33944 .51856 .34038 .51934 .34183 .51937 .34091 .5185 Mtetra
.884 .452 .095 r
.34091 .5185 .34183 .51937 .34306 .52359 .34221 .52133 Mtetra
.942 .685 .519 r
.34221 .52133 .34306 .52359 .33411 .71678 .33344 .71005 Mtetra
0 0 .222 r
.33344 .71005 .33411 .71678 .33539 .72172 .33453 .71862 Mtetra
.394 .37 .714 r
.33453 .71862 .33539 .72172 .33693 .72203 .33602 .71974 Mtetra
.556 .519 .769 r
.33602 .71974 .33693 .72203 .33851 .72139 .33757 .71981 Mtetra
.632 .624 .824 r
.33757 .71981 .33851 .72139 .34012 .72032 .33914 .71942 Mtetra
.504 .696 .955 r
.33914 .71942 .34012 .72032 .34168 .72019 .3407 .7194 Mtetra
.615 .762 .95 r
.3407 .7194 .34168 .72019 .34325 .71987 .34227 .71905 Mtetra
.757 .781 .872 r
.34227 .71905 .34325 .71987 .34486 .71886 .34388 .71805 Mtetra
.898 .754 .694 r
.34388 .71805 .34486 .71886 .34668 .71362 .34563 .71415 Mtetra
.942 .689 .526 r
.34563 .71415 .34668 .71362 .35795 .51918 .3567 .52483 Mtetra
.836 .771 .263 r
.3567 .52483 .35795 .51918 .3597 .5135 .35868 .51471 Mtetra
.629 .864 .502 r
.35868 .51471 .3597 .5135 .36124 .51222 .36025 .51269 Mtetra
.495 .889 .73 r
.36025 .51269 .36124 .51222 .36272 .51192 .36177 .51175 Mtetra
.593 .907 .982 r
.36177 .51175 .36272 .51192 .36419 .51202 .36327 .51123 Mtetra
.668 .762 .921 r
.36327 .51123 .36419 .51202 .36568 .51173 .36477 .51073 Mtetra
.651 .712 .892 r
.36477 .51073 .36568 .51173 .36717 .51131 .36626 .5103 Mtetra
.639 .708 .897 r
.36626 .5103 .36717 .51131 .36867 .51085 .36776 .50992 Mtetra
.74 .749 .86 r
.36776 .50992 .36867 .51085 .37019 .50994 .36927 .50904 Mtetra
.713 .749 .88 r
.36927 .50904 .37019 .50994 .3717 .50922 .37079 .50833 Mtetra
.548 .702 .942 r
.37079 .50833 .3717 .50922 .37319 .50908 .37227 .50821 Mtetra
.896 .475 .126 r
.37227 .50821 .37319 .50908 .37453 .51208 .37361 .51137 Mtetra
.943 .683 .513 r
.37361 .51137 .37453 .51208 .36742 .70454 .36641 .70448 Mtetra
.915 .581 .395 r
.36641 .70448 .36742 .70454 .36869 .71142 .3677 .71088 Mtetra
0 .32 .703 r
.3677 .71088 .36869 .71142 .37023 .71221 .36924 .7116 Mtetra
.675 .823 .954 r
.36924 .7116 .37023 .71221 .37182 .71168 .37084 .71101 Mtetra
.776 .818 .885 r
.37084 .71101 .37182 .71168 .37344 .71067 .37247 .70994 Mtetra
.585 .77 .967 r
.37247 .70994 .37344 .71067 .37504 .71033 .37406 .70965 Mtetra
.578 .781 .976 r
.37406 .70965 .37504 .71033 .37663 .71 .37565 .70937 Mtetra
.761 .826 .903 r
.37565 .70937 .37663 .71 .37825 .70911 .37727 .7084 Mtetra
.916 .757 .669 r
.37727 .7084 .37825 .70911 .37998 .70539 .37905 .70363 Mtetra
.943 .687 .52 r
.37905 .70363 .37998 .70539 .38927 .51553 .38861 .50863 Mtetra
.75 .541 .613 r
.38861 .50863 .38927 .51553 .39117 .50564 .39034 .50259 Mtetra
.706 .561 .688 r
.39034 .50259 .39117 .50564 .39273 .50379 .3919 .50095 Mtetra
.624 .52 .716 r
.3919 .50095 .39273 .50379 .39425 .50332 .39342 .50047 Mtetra
.58 .493 .72 r
.39342 .50047 .39425 .50332 .39574 .50333 .39491 .50038 Mtetra
.602 .502 .713 r
.39491 .50038 .39574 .50333 .39725 .5031 .39642 .50009 Mtetra
.615 .508 .708 r
.39642 .50009 .39725 .5031 .39876 .50271 .39793 .49967 Mtetra
.615 .507 .707 r
.39793 .49967 .39876 .50271 .40027 .50231 .39945 .49925 Mtetra
.617 .507 .706 r
.39945 .49925 .40027 .50231 .40179 .50188 .40096 .4988 Mtetra
.619 .507 .705 r
.40096 .4988 .40179 .50188 .40331 .50143 .40248 .49833 Mtetra
.619 .507 .704 r
.40248 .49833 .40331 .50143 .40482 .50097 .404 .49786 Mtetra
.642 .521 .7 r
.404 .49786 .40482 .50097 .40636 .50011 .40553 .49712 Mtetra
.638 .523 .706 r
.40553 .49712 .40636 .50011 .40789 .49937 .40706 .49646 Mtetra
.593 .498 .716 r
.40706 .49646 .40789 .49937 .40939 .49931 .40857 .49625 Mtetra
.232 .258 .682 r
.40857 .49625 .40939 .49931 .41077 .50299 .41001 .4981 Mtetra
.922 .651 .165 r
.41001 .4981 .41077 .50299 .40575 .6959 .41113 .50948 Mtetra
0 0 .319 r
.41113 .50948 .40575 .6959 .40718 .70089 .40631 .69737 Mtetra
.326 .308 .685 r
.40631 .69737 .40718 .70089 .40875 .70184 .40786 .69906 Mtetra
.606 .52 .731 r
.40786 .69906 .40875 .70184 .41037 .70149 .40947 .69875 Mtetra
.663 .555 .722 r
.40947 .69875 .41037 .70149 .412 .70075 .4111 .69786 Mtetra
.643 .537 .719 r
.4111 .69786 .412 .70075 .41362 .7002 .41273 .69716 Mtetra
.619 .517 .716 r
.41273 .69716 .41362 .7002 .41524 .69982 .41435 .69669 Mtetra
.619 .513 .712 r
.41435 .69669 .41524 .69982 .41686 .69944 .41597 .69622 Mtetra
.617 .509 .708 r
.41597 .69622 .41686 .69944 .41848 .69902 .4176 .69574 Mtetra
.616 .506 .705 r
.4176 .69574 .41848 .69902 .4201 .69856 .41922 .69526 Mtetra
.616 .505 .704 r
.41922 .69526 .4201 .69856 .42173 .69809 .42085 .69478 Mtetra
.624 .51 .703 r
.42085 .69478 .42173 .69809 .42336 .69762 .42248 .69422 Mtetra
.623 .506 .699 r
.42248 .69422 .42336 .69762 .42498 .69714 .4241 .69364 Mtetra
.609 .494 .697 r
.4241 .69364 .42498 .69714 .42661 .69665 .42573 .69322 Mtetra
.566 .469 .704 r
.42573 .69322 .42661 .69665 .42824 .6961 .42735 .69326 Mtetra
.53 .472 .736 r
.42735 .69326 .42824 .6961 .42988 .69552 .42895 .69355 Mtetra
.523 .532 .806 r
.42895 .69355 .42988 .69552 .43151 .69493 .43057 .69375 Mtetra
.577 .667 .9 r
.43057 .69375 .43151 .69493 .43314 .6944 .43219 .69359 Mtetra
.641 .77 .941 r
.43219 .69359 .43314 .6944 .43478 .69391 .43383 .69314 Mtetra
.664 .785 .939 r
.43383 .69314 .43478 .69391 .43641 .69345 .43546 .6926 Mtetra
.659 .767 .93 r
.43546 .6926 .43641 .69345 .43804 .69305 .4371 .69209 Mtetra
.647 .739 .916 r
.4371 .69209 .43804 .69305 .43968 .69266 .43873 .69164 Mtetra
.643 .723 .906 r
.43873 .69164 .43968 .69266 .44132 .69217 .44037 .6912 Mtetra
.631 .731 .92 r
.44037 .6912 .44132 .69217 .44296 .6913 .44201 .69081 Mtetra
.568 .832 .995 r
.44201 .69081 .44296 .6913 .44462 .69004 .44364 .69045 Mtetra
.002 0 0 r
.44364 .69045 .44462 .69004 .44628 .68865 .44528 .69009 Mtetra
.361 0 .108 r
.44528 .69009 .44628 .68865 .44793 .68762 .44692 .6897 Mtetra
.421 .057 .238 r
.44692 .6897 .44793 .68762 .44957 .68712 .44856 .68926 Mtetra
.421 .061 .246 r
.44856 .68926 .44957 .68712 .45121 .68679 .45021 .6888 Mtetra
.4 .033 .221 r
.45021 .6888 .45121 .68679 .45285 .68642 .45185 .6883 Mtetra
.378 .001 .191 r
.45185 .6883 .45285 .68642 .4545 .68596 .4535 .68776 Mtetra
.368 0 .174 r
.4535 .68776 .4545 .68596 .45614 .6855 .45515 .68721 Mtetra
.368 0 .161 r
.45515 .68721 .45614 .6855 .45778 .68505 .4568 .6867 Mtetra
.373 0 .155 r
.4568 .6867 .45778 .68505 .45943 .68461 .45844 .68624 Mtetra
.372 0 .151 r
.45844 .68624 .45943 .68461 .46108 .68416 .46009 .68579 Mtetra
.425 .027 .179 r
.46009 .68579 .46108 .68416 .46272 .68402 .46174 .68554 Mtetra
.432 .025 .165 r
.46174 .68554 .46272 .68402 .46436 .68397 .46339 .68535 Mtetra
.271 0 .044 r
.46339 .68535 .46436 .68397 .46602 .68327 .46504 .68472 Mtetra
0 0 0 r
.46504 .68472 .46602 .68327 .46772 .67998 .46672 .68249 Mtetra
.961 .858 .448 r
.46672 .68249 .46772 .67998 .47243 .48617 .46849 .67517 Mtetra
0 0 .331 r
.46849 .67517 .47243 .48617 .47411 .47825 .47318 .48045 Mtetra
0 0 0 r
.47318 .48045 .47411 .47825 .4757 .47584 .47479 .47677 Mtetra
.025 0 0 r
.47479 .47677 .4757 .47584 .47726 .47513 .47635 .47597 Mtetra
.332 0 0 r
.47635 .47597 .47726 .47513 .47882 .47486 .47791 .4758 Mtetra
.395 0 .022 r
.47791 .4758 .47882 .47486 .48037 .47461 .47947 .47573 Mtetra
.325 0 .028 r
.47947 .47573 .48037 .47461 .48194 .47414 .48103 .47537 Mtetra
.306 0 .048 r
.48103 .47537 .48194 .47414 .4835 .47369 .48259 .47491 Mtetra
.135 0 0 r
.48259 .47491 .4835 .47369 .48506 .47327 .48416 .47406 Mtetra
0 0 0 r
.48416 .47406 .48506 .47327 .48662 .47289 .48574 .47285 Mtetra
.785 .973 .915 r
.48574 .47285 .48662 .47289 .48819 .4725 .48731 .4717 Mtetra
.742 .788 .89 r
.48731 .4717 .48819 .4725 .48976 .47209 .48889 .47084 Mtetra
.665 .68 .854 r
.48889 .47084 .48976 .47209 .49132 .47162 .49045 .4703 Mtetra
.646 .661 .851 r
.49045 .4703 .49132 .47162 .49289 .47112 .49202 .46987 Mtetra
.647 .672 .86 r
.49202 .46987 .49289 .47112 .49446 .47057 .49359 .46943 Mtetra
.662 .696 .871 r
.49359 .46943 .49446 .47057 .49603 .46998 .49516 .46892 Mtetra
.663 .714 .886 r
.49516 .46892 .49603 .46998 .49761 .46937 .49673 .46842 Mtetra
.657 .734 .906 r
.49673 .46842 .49761 .46937 .49918 .46876 .49831 .46794 Mtetra
.645 .762 .934 r
.49831 .46794 .49918 .46876 .50075 .46815 .49988 .4675 Mtetra
.639 .803 .962 r
.49988 .4675 .50075 .46815 .50233 .46765 .50146 .46705 Mtetra
.653 .82 .964 r
.50146 .46705 .50233 .46765 .5039 .46743 .50303 .46654 Mtetra
.682 .757 .908 r
.50303 .46654 .5039 .46743 .50547 .46763 .50461 .46596 Mtetra
.663 .624 .8 r
.50461 .46596 .50547 .46763 .50704 .46798 .50619 .46536 Mtetra
.636 .54 .728 r
.50619 .46536 .50704 .46798 .50862 .46815 .50776 .46478 Mtetra
.62 .5 .695 r
.50776 .46478 .50862 .46815 .5102 .46773 .50934 .46424 Mtetra
.617 .495 .691 r
.50934 .46424 .5102 .46773 .51178 .46711 .51092 .46371 Mtetra
.618 .498 .694 r
.51092 .46371 .51178 .46711 .51336 .46647 .5125 .4632 Mtetra
.619 .503 .699 r
.5125 .4632 .51336 .46647 .51494 .46595 .51409 .46268 Mtetra
.51409 .46268 .51494 .46595 .51653 .46543 .51567 .46217 Mtetra
.51567 .46217 .51653 .46543 .51811 .46491 .51725 .46165 Mtetra
.62 .504 .7 r
.51725 .46165 .51811 .46491 .5197 .46437 .51884 .46113 Mtetra
.62 .505 .7 r
.51884 .46113 .5197 .46437 .52128 .46384 .52042 .46061 Mtetra
.629 .511 .7 r
.52042 .46061 .52128 .46384 .52287 .46315 .52201 .45999 Mtetra
.647 .524 .7 r
.52201 .45999 .52287 .46315 .52446 .46217 .5236 .45916 Mtetra
.618 .512 .711 r
.5236 .45916 .52446 .46217 .52605 .46172 .52518 .4587 Mtetra
.498 .437 .719 r
.52518 .4587 .52605 .46172 .52764 .46287 .52677 .45926 Mtetra
0 0 .484 r
.52677 .45926 .52764 .46287 .52948 .65158 .52837 .4636 Mtetra
0 0 .366 r
.52837 .4636 .52948 .65158 .53118 .66416 .53027 .65897 Mtetra
.05 .072 .561 r
.53027 .65897 .53118 .66416 .53288 .66655 .53197 .66354 Mtetra
.563 .487 .727 r
.53197 .66354 .53288 .66655 .53458 .66644 .53366 .6636 Mtetra
.646 .544 .724 r
.53366 .6636 .53458 .66644 .53627 .66578 .53535 .66286 Mtetra
.665 .551 .716 r
.53535 .66286 .53627 .66578 .53797 .66496 .53705 .66187 Mtetra
.621 .519 .716 r
.53705 .66187 .53797 .66496 .53966 .66446 .53874 .66136 Mtetra
.622 .519 .716 r
.53874 .66136 .53966 .66446 .54136 .66395 .54044 .66084 Mtetra
.621 .518 .715 r
.54044 .66084 .54136 .66395 .54306 .66345 .54214 .66033 Mtetra
.619 .516 .715 r
.54214 .66033 .54306 .66345 .54476 .66297 .54384 .65984 Mtetra
.617 .515 .715 r
.54384 .65984 .54476 .66297 .54646 .66249 .54554 .65936 Mtetra
.616 .514 .716 r
.54554 .65936 .54646 .66249 .54816 .66202 .54724 .6589 Mtetra
.614 .513 .716 r
.54724 .6589 .54816 .66202 .54986 .66157 .54894 .65846 Mtetra
.614 .514 .717 r
.54894 .65846 .54986 .66157 .55157 .66112 .55065 .65802 Mtetra
.605 .509 .719 r
.55065 .65802 .55157 .66112 .55327 .66073 .55235 .65768 Mtetra
.561 .484 .726 r
.55235 .65768 .55327 .66073 .55498 .66063 .55406 .65775 Mtetra
.619 .527 .728 r
.55406 .65775 .55498 .66063 .55669 .66016 .55577 .65729 Mtetra
.722 .585 .702 r
.55577 .65729 .55669 .66016 .55839 .6588 .55747 .65549 Mtetra
.898 .665 .578 r
.55747 .65549 .55839 .6588 .56005 .65384 .55906 .64346 Mtetra
.95 .678 .485 r
.55906 .64346 .56005 .65384 .55969 .45786 .55878 .45145 Mtetra
.707 .511 .621 r
.55878 .45145 .55969 .45786 .56123 .45102 .56036 .4478 Mtetra
.653 .526 .697 r
.56036 .4478 .56123 .45102 .56283 .44989 .56196 .44687 Mtetra
.611 .508 .713 r
.56196 .44687 .56283 .44989 .56445 .44956 .56357 .44648 Mtetra
.588 .492 .713 r
.56357 .44648 .56445 .44956 .56606 .44957 .56519 .44631 Mtetra
.618 .504 .701 r
.56519 .44631 .56606 .44957 .56768 .44908 .5668 .4458 Mtetra
.617 .503 .7 r
.5668 .4458 .56768 .44908 .56929 .4486 .56842 .4453 Mtetra
.617 .502 .7 r
.56842 .4453 .56929 .4486 .57091 .44812 .57003 .4448 Mtetra
.618 .502 .699 r
.57003 .4448 .57091 .44812 .57252 .44761 .57165 .44429 Mtetra
.618 .502 .698 r
.57165 .44429 .57252 .44761 .57414 .44711 .57326 .44378 Mtetra
.618 .501 .698 r
.57326 .44378 .57414 .44711 .57576 .4466 .57488 .44327 Mtetra
.57488 .44327 .57576 .4466 .57738 .4461 .5765 .44275 Mtetra
.617 .5 .698 r
.5765 .44275 .57738 .4461 .579 .4456 .57812 .44224 Mtetra
.617 .5 .697 r
.57812 .44224 .579 .4456 .58062 .44511 .57974 .44174 Mtetra
.617 .499 .697 r
.57974 .44174 .58062 .44511 .58224 .44476 .58136 .44123 Mtetra
.614 .493 .691 r
.58136 .44123 .58224 .44476 .58386 .44429 .58298 .44073 Mtetra
.612 .491 .69 r
.58298 .44073 .58386 .44429 .58548 .44356 .5846 .44025 Mtetra
.611 .498 .7 r
.5846 .44025 .58548 .44356 .58709 .44215 .58623 .43982 Mtetra
.625 .552 .753 r
.58623 .43982 .58709 .44215 .5887 .44079 .58785 .43938 Mtetra
.646 .654 .843 r
.58785 .43938 .5887 .44079 .59031 .43964 .58948 .43892 Mtetra
.671 .804 .946 r
.58948 .43892 .59031 .43964 .59194 .439 .59111 .43835 Mtetra
.675 .824 .955 r
.59111 .43835 .59194 .439 .59356 .4385 .59273 .43776 Mtetra
.68 .798 .938 r
.59273 .43776 .59356 .4385 .59519 .43809 .59436 .43716 Mtetra
.687 .756 .904 r
.59436 .43716 .59519 .43809 .59682 .43765 .59599 .43654 Mtetra
.669 .712 .88 r
.59599 .43654 .59682 .43765 .59845 .43721 .59762 .43598 Mtetra
.642 .682 .872 r
.59762 .43598 .59845 .43721 .60009 .43673 .59925 .43555 Mtetra
.531 .642 .904 r
.59925 .43555 .60009 .43673 .60172 .43611 .60089 .43556 Mtetra
.302 .689 .976 r
.60089 .43556 .60172 .43611 .60335 .43546 .60254 .4357 Mtetra
.284 0 0 r
.60254 .4357 .60335 .43546 .60498 .43482 .6042 .43586 Mtetra
.06 0 0 r
.6042 .43586 .60498 .43482 .6066 .4339 .60582 .43494 Mtetra
.173 0 0 r
.60582 .43494 .6066 .4339 .60823 .43327 .60745 .43425 Mtetra
.437 0 .054 r
.60745 .43425 .60823 .43327 .60988 .43319 .60911 .43428 Mtetra
.886 .534 .375 r
.60911 .43428 .60988 .43319 .6116 .43582 .61093 .44063 Mtetra
.96 .676 .451 r
.61093 .44063 .6116 .43582 .61841 .62602 .61785 .63661 Mtetra
.649 .385 .505 r
.61785 .63661 .61841 .62602 .62052 .63866 .61972 .64049 Mtetra
.524 .139 .252 r
.61972 .64049 .62052 .63866 .62232 .64007 .62148 .6407 Mtetra
.051 0 0 r
.62148 .6407 .62232 .64007 .62409 .64035 .62323 .64015 Mtetra
.696 .949 .957 r
.62323 .64015 .62409 .64035 .62584 .64013 .62497 .63924 Mtetra
.639 .765 .939 r
.62497 .63924 .62584 .64013 .6276 .63975 .62672 .63877 Mtetra
.649 .748 .922 r
.62672 .63877 .6276 .63975 .62935 .63921 .62848 .63827 Mtetra
.679 .767 .917 r
.62848 .63827 .62935 .63921 .6311 .63858 .63023 .63763 Mtetra
.764 .787 .872 r
.63023 .63763 .6311 .63858 .63285 .63805 .63196 .63652 Mtetra
.752 .694 .796 r
.63196 .63652 .63285 .63805 .63461 .63753 .63369 .6352 Mtetra
.715 .61 .739 r
.63369 .6352 .63461 .63753 .63636 .63701 .63542 .63383 Mtetra
.642 .529 .711 r
.63542 .63383 .63636 .63701 .63812 .6365 .63717 .63305 Mtetra
.615 .503 .703 r
.63717 .63305 .63812 .6365 .63988 .63599 .63893 .63254 Mtetra
.604 .497 .705 r
.63893 .63254 .63988 .63599 .64164 .63547 .64069 .63216 Mtetra
.627 .516 .708 r
.64069 .63216 .64164 .63547 .6434 .63497 .64245 .63154 Mtetra
.621 .508 .704 r
.64245 .63154 .6434 .63497 .64516 .63445 .6442 .63097 Mtetra
.602 .495 .704 r
.6442 .63097 .64516 .63445 .64692 .63393 .64597 .63061 Mtetra
.539 .462 .716 r
.64597 .63061 .64692 .63393 .64868 .63336 .64776 .6309 Mtetra
.512 .491 .77 r
.64776 .6309 .64868 .63336 .65044 .63278 .64956 .63126 Mtetra
.494 .58 .87 r
.64956 .63126 .65044 .63278 .65221 .63224 .65135 .63147 Mtetra
.556 .767 .976 r
.65135 .63147 .65221 .63224 .65398 .63193 .65313 .63122 Mtetra
.617 .805 .972 r
.65313 .63122 .65398 .63193 .65576 .63162 .6549 .63078 Mtetra
.651 .781 .943 r
.6549 .63078 .65576 .63162 .65753 .63117 .65667 .63025 Mtetra
.53 .716 .957 r
.65667 .63025 .65753 .63117 .6593 .63052 .65846 .63013 Mtetra
.474 .833 .995 r
.65846 .63013 .6593 .63052 .66105 .62944 .66024 .62983 Mtetra
.32 .779 .64 r
.66024 .62983 .66105 .62944 .66276 .62754 .662 .62896 Mtetra
.71 .822 .369 r
.662 .62896 .66276 .62754 .66428 .62061 .66365 .6255 Mtetra
.888 .738 .23 r
.66365 .6255 .66428 .62061 .65796 .42284 .66485 .61077 Mtetra
.015 0 .417 r
.66485 .61077 .65796 .42284 .65945 .41807 .65875 .4196 Mtetra
0 0 0 r
.65875 .4196 .65945 .41807 .66108 .41668 .66033 .41699 Mtetra
.599 .938 .754 r
.66033 .41699 .66108 .41668 .66275 .41625 .66197 .41579 Mtetra
.687 .885 .971 r
.66197 .41579 .66275 .41625 .66444 .41618 .66363 .41508 Mtetra
.664 .718 .889 r
.66363 .41508 .66444 .41618 .66612 .41584 .6653 .41454 Mtetra
.637 .672 .867 r
.6653 .41454 .66612 .41584 .66779 .41535 .66698 .41413 Mtetra
.622 .678 .882 r
.66698 .41413 .66779 .41535 .66946 .41483 .66866 .41378 Mtetra
.652 .726 .903 r
.66866 .41378 .66946 .41483 .67113 .41412 .67033 .4133 Mtetra
.669 .783 .934 r
.67033 .4133 .67113 .41412 .67279 .41341 .67201 .41273 Mtetra
.672 .822 .956 r
.67201 .41273 .67279 .41341 .67447 .41283 .67368 .41214 Mtetra
.755 .837 .914 r
.67368 .41214 .67447 .41283 .67615 .41242 .67534 .41119 Mtetra
.711 .712 .849 r
.67534 .41119 .67615 .41242 .67785 .41239 .677 .41036 Mtetra
.611 .57 .783 r
.677 .41036 .67785 .41239 .67959 .41311 .67869 .41005 Mtetra
.283 .301 .703 r
.67869 .41005 .67959 .41311 .68154 .41827 .68049 .41198 Mtetra
0 0 .176 r
.68049 .41198 .68154 .41827 .6929 .61576 .68283 .42509 Mtetra
.04 0 .437 r
.68283 .42509 .6929 .61576 .69493 .62005 .69394 .61626 Mtetra
.341 .318 .687 r
.69394 .61626 .69493 .62005 .69679 .62083 .69586 .61827 Mtetra
.528 .495 .763 r
.69586 .61827 .69679 .62083 .69859 .62042 .6977 .61855 Mtetra
.601 .593 .815 r
.6977 .61855 .69859 .62042 .70036 .6195 .69951 .61831 Mtetra
.625 .7 .899 r
.69951 .61831 .70036 .6195 .70213 .61833 .70131 .61791 Mtetra
.571 .871 .995 r
.70131 .61791 .70213 .61833 .70388 .61696 .70312 .61742 Mtetra
0 0 0 r
.70312 .61742 .70388 .61696 .70563 .61548 .70491 .61684 Mtetra
.402 0 .112 r
.70491 .61684 .70563 .61548 .70743 .61496 .70673 .6166 Mtetra
.423 .025 .177 r
.70673 .6166 .70743 .61496 .70925 .61476 .70854 .61632 Mtetra
.285 0 .102 r
.70854 .61632 .70925 .61476 .71103 .61394 .71033 .61552 Mtetra
0 0 0 r
.71033 .61552 .71103 .61394 .71261 .60917 .71201 .61259 Mtetra
.823 .729 .201 r
.71201 .61259 .71261 .60917 .70343 .40998 .71331 .60291 Mtetra
.037 0 .431 r
.71331 .60291 .70343 .40998 .70482 .40398 .70419 .40578 Mtetra
0 0 0 r
.70419 .40578 .70482 .40398 .70645 .40214 .70574 .40254 Mtetra
.573 .91 .68 r
.70574 .40254 .70645 .40214 .70814 .40159 .70739 .40121 Mtetra
.702 .914 .968 r
.70739 .40121 .70814 .40159 .70986 .40142 .70907 .4004 Mtetra
.684 .745 .898 r
.70907 .4004 .70986 .40142 .71156 .40104 .71076 .39977 Mtetra
.661 .687 .864 r
.71076 .39977 .71156 .40104 .71326 .40044 .71246 .39922 Mtetra
.642 .69 .88 r
.71246 .39922 .71326 .40044 .71495 .39983 .71416 .39878 Mtetra
.64 .722 .907 r
.71416 .39878 .71495 .39983 .71664 .39919 .71587 .39834 Mtetra
.64 .768 .94 r
.71587 .39834 .71664 .39919 .71834 .39858 .71758 .39787 Mtetra
.636 .805 .964 r
.71758 .39787 .71834 .39858 .72005 .3981 .71928 .39739 Mtetra
.66 .815 .958 r
.71928 .39739 .72005 .3981 .72178 .39798 .72098 .39683 Mtetra
.679 .718 .878 r
.72098 .39683 .72178 .39798 .72353 .39821 .72268 .3962 Mtetra
.656 .597 .778 r
.72268 .3962 .72353 .39821 .72529 .39855 .72438 .39556 Mtetra
.631 .525 .715 r
.72438 .39556 .72529 .39855 .72702 .39848 .72608 .39494 Mtetra
.62 .498 .693 r
.72608 .39494 .72702 .39848 .72873 .39793 .72779 .39435 Mtetra
.618 .496 .691 r
.72779 .39435 .72873 .39793 .73043 .39723 .7295 .39377 Mtetra
.636 .511 .694 r
.7295 .39377 .73043 .39723 .73211 .39624 .73119 .39298 Mtetra
.64 .52 .701 r
.73119 .39298 .73211 .39624 .7338 .39533 .73288 .3922 Mtetra
.603 .503 .713 r
.73288 .3922 .7338 .39533 .73553 .39508 .73461 .39186 Mtetra
.397 .37 .711 r
.73461 .39186 .73553 .39508 .73746 .39781 .73645 .39324 Mtetra
0 0 .413 r
.73645 .39324 .73746 .39781 .75242 .59624 .73869 .40067 Mtetra
.065 0 .452 r
.73869 .40067 .75242 .59624 .7547 .60247 .75367 .59836 Mtetra
.318 .294 .674 r
.75367 .59836 .7547 .60247 .75665 .60381 .7557 .60078 Mtetra
.594 .51 .729 r
.7557 .60078 .75665 .60381 .7585 .60349 .75755 .60054 Mtetra
.655 .549 .723 r
.75755 .60054 .7585 .60349 .76032 .60272 .75936 .59965 Mtetra
.647 .539 .718 r
.75936 .59965 .76032 .60272 .76215 .6021 .76118 .59883 Mtetra
.616 .513 .714 r
.76118 .59883 .76215 .6021 .764 .60174 .76301 .59832 Mtetra
.614 .507 .708 r
.76301 .59832 .764 .60174 .76584 .60126 .76485 .59782 Mtetra
.609 .503 .708 r
.76485 .59782 .76584 .60126 .76765 .60035 .7667 .59737 Mtetra
.61 .522 .73 r
.7667 .59737 .76765 .60035 .76943 .59899 .76855 .59697 Mtetra
.625 .593 .798 r
.76855 .59697 .76943 .59899 .77121 .59759 .7704 .59655 Mtetra
.648 .743 .919 r
.7704 .59655 .77121 .59759 .77304 .59695 .77224 .59603 Mtetra
.669 .78 .932 r
.77224 .59603 .77304 .59695 .77494 .59717 .77408 .59541 Mtetra
.661 .637 .815 r
.77408 .59541 .77494 .59717 .77685 .59744 .77591 .59476 Mtetra
.605 .535 .749 r
.77591 .59476 .77685 .59744 .77874 .59755 .77777 .59444 Mtetra
.584 .5 .727 r
.77777 .59444 .77874 .59755 .78061 .59735 .77965 .5943 Mtetra
.641 .537 .721 r
.77965 .5943 .78061 .59735 .78245 .59662 .78148 .59354 Mtetra
.785 .616 .671 r
.78148 .59354 .78245 .59662 .78417 .5944 .78313 .59032 Mtetra
.975 .68 .395 r
.78313 .59032 .78417 .5944 .78557 .58799 .7699 .39196 Mtetra
.575 .36 .552 r
.7699 .39196 .78557 .58799 .77203 .38758 .77095 .38246 Mtetra
.698 .516 .638 r
.77095 .38246 .77203 .38758 .77344 .38282 .77253 .37986 Mtetra
.64 .532 .716 r
.77253 .37986 .77344 .38282 .77509 .38124 .77425 .37913 Mtetra
.605 .564 .782 r
.77425 .37913 .77509 .38124 .7768 .38028 .77601 .37886 Mtetra
.622 .65 .857 r
.77601 .37886 .7768 .38028 .77852 .37958 .77776 .3785 Mtetra
.697 .744 .887 r
.77776 .3785 .77852 .37958 .78025 .37893 .77949 .37778 Mtetra
.683 .723 .88 r
.77949 .37778 .78025 .37893 .78199 .37837 .78122 .37712 Mtetra
.663 .698 .872 r
.78122 .37712 .78199 .37837 .78371 .37756 .78296 .37655 Mtetra
.623 .729 .923 r
.78296 .37655 .78371 .37756 .78541 .37651 .78471 .37616 Mtetra
.226 .699 .94 r
.78471 .37616 .78541 .37651 .78715 .37591 .78651 .37624 Mtetra
.701 .182 0 r
.78651 .37624 .78715 .37591 .78901 .37673 .78843 .37783 Mtetra
.937 .588 .336 r
.78843 .37783 .78901 .37673 .79128 .38252 .79129 .39073 Mtetra
.968 .663 .388 r
.79129 .39073 .79128 .38252 .80988 .58338 .80916 .5833 Mtetra
.745 .224 0 r
.80916 .5833 .80988 .58338 .81207 .58669 .81127 .58563 Mtetra
.595 .722 .933 r
.81127 .58563 .81207 .58669 .81396 .58644 .81316 .58533 Mtetra
.724 .761 .882 r
.81316 .58533 .81396 .58644 .81579 .58544 .815 .5844 Mtetra
.735 .779 .889 r
.815 .5844 .81579 .58544 .81762 .58435 .81683 .58343 Mtetra
.641 .772 .943 r
.81683 .58343 .81762 .58435 .81948 .58378 .81871 .58291 Mtetra
.619 .776 .956 r
.81871 .58291 .81948 .58378 .82136 .58328 .82059 .58247 Mtetra
.568 .769 .973 r
.82059 .58247 .82136 .58328 .82325 .58287 .82248 .58217 Mtetra
.484 .759 .991 r
.82248 .58217 .82325 .58287 .82514 .58259 .8244 .58204 Mtetra
.48 .802 1 r
.8244 .58204 .82514 .58259 .82704 .58234 .8263 .58181 Mtetra
.545 .838 .999 r
.8263 .58181 .82704 .58234 .82897 .5823 .82819 .58141 Mtetra
.67 .793 .94 r
.82819 .58141 .82897 .5823 .83091 .5825 .83006 .58077 Mtetra
.731 .675 .795 r
.83006 .58077 .83091 .5825 .83281 .58214 .83188 .57954 Mtetra
.8 .644 .689 r
.83188 .57954 .83281 .58214 .83457 .5802 .83354 .57657 Mtetra
.976 .677 .372 r
.83354 .57657 .83457 .5802 .83572 .57176 .81784 .38361 Mtetra
.585 .368 .552 r
.81784 .38361 .83572 .57176 .81907 .37011 .81826 .36827 Mtetra
.853 .701 .694 r
.81826 .36827 .81907 .37011 .82052 .36612 .81978 .36515 Mtetra
.726 .779 .895 r
.81978 .36515 .82052 .36612 .82225 .36519 .82152 .36428 Mtetra
.61 .749 .944 r
.82152 .36428 .82225 .36519 .82403 .36486 .8233 .36391 Mtetra
.619 .743 .935 r
.8233 .36391 .82403 .36486 .82582 .36454 .82509 .36352 Mtetra
.746 .775 .877 r
.82509 .36352 .82582 .36454 .82755 .36355 .82681 .36252 Mtetra
.662 .743 .91 r
.82681 .36252 .82755 .36355 .82932 .363 .82858 .36196 Mtetra
.244 .517 .91 r
.82858 .36196 .82932 .363 .83121 .36372 .83047 .36267 Mtetra
.879 .485 .027 r
.83047 .36267 .83121 .36372 .83372 .37076 .83297 .36967 Mtetra
.975 .667 .334 r
.83297 .36967 .83372 .37076 .85509 .57161 .85431 .5706 Mtetra
.652 .202 0 r
.85431 .5706 .85509 .57161 .85737 .57505 .8566 .57405 Mtetra
.386 .629 .95 r
.8566 .57405 .85737 .57505 .85935 .57536 .85858 .57435 Mtetra
.695 .778 .915 r
.85858 .57435 .85935 .57536 .86123 .5746 .86046 .57359 Mtetra
.875 .817 .789 r
.86046 .57359 .86123 .5746 .86296 .57237 .86219 .57135 Mtetra
.978 .763 .544 r
.86219 .57135 .86296 .57237 .86413 .5645 .86335 .5634 Mtetra
.977 .675 .348 r
.86335 .5634 .86413 .5645 .84568 .36196 .84494 .36085 Mtetra
.944 .781 .648 r
.84494 .36085 .84568 .36196 .84708 .35761 .84635 .35653 Mtetra
.743 .765 .871 r
.84635 .35653 .84708 .35761 .84881 .35661 .84808 .35553 Mtetra
.62 .718 .916 r
.84808 .35553 .84881 .35661 .85061 .35622 .84988 .35515 Mtetra
.59 .705 .923 r
.84988 .35515 .85061 .35622 .85243 .35596 .8517 .35489 Mtetra
.746 .769 .872 r
.8517 .35489 .85243 .35596 .85416 .35494 .85344 .35388 Mtetra
.673 .743 .903 r
.85344 .35388 .85416 .35494 .85594 .35432 .85522 .35326 Mtetra
.38 .595 .93 r
.85522 .35326 .85594 .35432 .85783 .35471 .8571 .35365 Mtetra
.8 .386 0 r
.8571 .35365 .85783 .35471 .86023 .36 .8595 .35893 Mtetra
.973 .663 .318 r
.8595 .35893 .86023 .36 .88351 .56224 .88275 .56123 Mtetra
.719 .279 0 r
.88275 .56123 .88351 .56224 .88592 .56641 .88517 .56541 Mtetra
.502 .693 .954 r
.88517 .56541 .88592 .56641 .8879 .56639 .88714 .56539 Mtetra
.694 .78 .917 r
.88714 .56539 .8879 .56639 .88979 .56563 .88904 .56463 Mtetra
.734 .794 .9 r
.88904 .56463 .88979 .56563 .89166 .56466 .89091 .56365 Mtetra
.496 .689 .954 r
.89091 .56365 .89166 .56466 .89365 .56466 .89289 .56365 Mtetra
.624 .751 .938 r
.89289 .56365 .89365 .56466 .89558 .56422 .89482 .5632 Mtetra
.809 .813 .853 r
.89482 .5632 .89558 .56422 .8974 .56272 .89664 .5617 Mtetra
.979 .771 .554 r
.89664 .5617 .8974 .56272 .89859 .55555 .89783 .55447 Mtetra
.976 .671 .329 r
.89783 .55447 .89859 .55555 .87796 .35227 .87724 .35116 Mtetra
.956 .78 .625 r
.87724 .35116 .87796 .35227 .87929 .34745 .87857 .34636 Mtetra
.741 .766 .873 r
.87857 .34636 .87929 .34745 .88104 .34646 .88033 .34537 Mtetra
.605 .711 .919 r
.88033 .34537 .88104 .34646 .88287 .34613 .88215 .34505 Mtetra
.519 .668 .93 r
.88215 .34505 .88287 .34613 .88474 .34612 .88402 .34503 Mtetra
.651 .732 .909 r
.88402 .34503 .88474 .34612 .88654 .34559 .88583 .34452 Mtetra
.657 .736 .908 r
.88583 .34452 .88654 .34559 .88835 .34504 .88764 .34397 Mtetra
.67 .743 .905 r
.88764 .34397 .88835 .34504 .89015 .34442 .88944 .34336 Mtetra
.763 .78 .867 r
.88944 .34336 .89015 .34442 .89189 .34329 .89119 .34223 Mtetra
.696 .756 .898 r
.89119 .34223 .89189 .34329 .89368 .34255 .89297 .3415 Mtetra
.488 .659 .937 r
.89297 .3415 .89368 .34255 .89556 .3426 .89486 .34157 Mtetra
.776 .358 0 r
.89486 .34157 .89556 .3426 .89801 .34744 .89735 .34676 Mtetra
.971 .656 .296 r
.89735 .34676 .89801 .34744 .9239 .55035 .92322 .54987 Mtetra
.812 .352 0 r
.92322 .54987 .9239 .55035 .92647 .5551 .92576 .55437 Mtetra
.45 .738 .989 r
.92576 .55437 .92647 .5551 .92848 .55514 .92777 .55433 Mtetra
.702 .831 .944 r
.92777 .55433 .92848 .55514 .9304 .5544 .92968 .55351 Mtetra
.78 .837 .895 r
.92968 .55351 .9304 .5544 .93227 .55324 .93155 .55227 Mtetra
.582 .759 .963 r
.30523 .72784 .30624 .72859 .30777 .72852 .30678 .72758 Mtetra
.64 .732 .915 r
.30678 .72758 .30777 .72852 .30933 .72815 .30834 .72717 Mtetra
.716 .742 .872 r
.30834 .72717 .30933 .72815 .31092 .72714 .30992 .7264 Mtetra
.859 .779 .772 r
.30992 .7264 .31092 .72714 .31273 .72262 .31159 .72418 Mtetra
.948 .934 .593 r
.31159 .72418 .31273 .72262 .3256 .53169 .31336 .72016 Mtetra
0 0 .28 r
.31336 .72016 .3256 .53169 .32749 .52423 .32574 .53729 Mtetra
0 0 .266 r
.32574 .53729 .32749 .52423 .32904 .52257 .32788 .52561 Mtetra
0 0 0 r
.32788 .52561 .32904 .52257 .33054 .52171 .32952 .52234 Mtetra
.862 .995 .761 r
.32952 .52234 .33054 .52171 .33202 .52124 .33109 .52044 Mtetra
.723 .768 .888 r
.33109 .52044 .33202 .52124 .3335 .52076 .33258 .51969 Mtetra
.639 .694 .885 r
.33258 .51969 .3335 .52076 .33498 .52037 .33406 .51932 Mtetra
.593 .681 .902 r
.33406 .51932 .33498 .52037 .33645 .52002 .33552 .51911 Mtetra
.71 .744 .879 r
.33552 .51911 .33645 .52002 .33795 .51918 .33702 .51842 Mtetra
.689 .775 .917 r
.33702 .51842 .33795 .51918 .33944 .51856 .33851 .51784 Mtetra
.58 .757 .962 r
.33851 .51784 .33944 .51856 .34091 .5185 .33998 .5176 Mtetra
0 .247 .732 r
.33998 .5176 .34091 .5185 .34221 .52133 .34139 .51858 Mtetra
0 .031 .582 r
.34139 .51858 .34221 .52133 .33344 .71005 .34271 .52113 Mtetra
0 0 .323 r
.34271 .52113 .33344 .71005 .33453 .71862 .33475 .69543 Mtetra
.005 0 .411 r
.33475 .69543 .33453 .71862 .33602 .71974 .33528 .71429 Mtetra
.278 .218 .608 r
.33528 .71429 .33602 .71974 .33757 .71981 .33668 .71717 Mtetra
.315 .347 .736 r
.33668 .71717 .33757 .71981 .33914 .71942 .33816 .71842 Mtetra
.417 .634 .945 r
.33816 .71842 .33914 .71942 .3407 .7194 .33971 .71862 Mtetra
.629 .769 .947 r
.33971 .71862 .3407 .7194 .34227 .71905 .34128 .71823 Mtetra
.751 .78 .877 r
.34128 .71823 .34227 .71905 .34388 .71805 .34289 .71727 Mtetra
.85 .781 .783 r
.34289 .71727 .34388 .71805 .34563 .71415 .34455 .71522 Mtetra
.966 .937 .652 r
.34455 .71522 .34563 .71415 .3567 .52483 .3463 .71152 Mtetra
.53 .32 .54 r
.3463 .71152 .3567 .52483 .35868 .51471 .3486 .69661 Mtetra
0 0 .286 r
.3486 .69661 .35868 .51471 .36025 .51269 .35912 .51616 Mtetra
0 0 .047 r
.35912 .51616 .36025 .51269 .36177 .51175 .36077 .51258 Mtetra
.82 .978 .686 r
.36077 .51258 .36177 .51175 .36327 .51123 .36234 .51054 Mtetra
.753 .803 .893 r
.36234 .51054 .36327 .51123 .36477 .51073 .36386 .50966 Mtetra
.652 .7 .881 r
.36386 .50966 .36477 .51073 .36626 .5103 .36535 .50922 Mtetra
.604 .681 .896 r
.36535 .50922 .36626 .5103 .36776 .50992 .36684 .50898 Mtetra
.734 .745 .861 r
.36684 .50898 .36776 .50992 .36927 .50904 .36836 .50813 Mtetra
.711 .748 .881 r
.36836 .50813 .36927 .50904 .37079 .50833 .36987 .50743 Mtetra
.535 .697 .944 r
.36987 .50743 .37079 .50833 .37227 .50821 .37135 .50735 Mtetra
.907 .497 .162 r
.37135 .50735 .37227 .50821 .37361 .51137 .37268 .51074 Mtetra
.943 .683 .514 r
.37268 .51074 .37361 .51137 .36641 .70448 .3654 .70456 Mtetra
.906 .568 .391 r
.3654 .70456 .36641 .70448 .3677 .71088 .36671 .71043 Mtetra
0 .353 .703 r
.36671 .71043 .3677 .71088 .36924 .7116 .36825 .71105 Mtetra
.695 .842 .953 r
.36825 .71105 .36924 .7116 .37084 .71101 .36986 .71038 Mtetra
.79 .825 .88 r
.36986 .71038 .37084 .71101 .37247 .70994 .37149 .70922 Mtetra
.593 .775 .967 r
.37149 .70922 .37247 .70994 .37406 .70965 .37308 .70891 Mtetra
.582 .766 .966 r
.37308 .70891 .37406 .70965 .37565 .70937 .37467 .70863 Mtetra
.754 .804 .892 r
.37467 .70863 .37565 .70937 .37727 .7084 .37629 .70768 Mtetra
.916 .756 .668 r
.37629 .70768 .37727 .7084 .37905 .70363 .37807 .70287 Mtetra
.944 .688 .519 r
.37807 .70287 .37905 .70363 .38861 .50863 .3877 .5075 Mtetra
.906 .719 .638 r
.3877 .5075 .38861 .50863 .39034 .50259 .38944 .50152 Mtetra
.807 .736 .786 r
.38944 .50152 .39034 .50259 .3919 .50095 .391 .4999 Mtetra
.661 .707 .881 r
.391 .4999 .3919 .50095 .39342 .50047 .39251 .49942 Mtetra
.551 .669 .915 r
.39251 .49942 .39342 .50047 .39491 .50038 .39401 .49934 Mtetra
.612 .694 .902 r
.39401 .49934 .39491 .50038 .39642 .50009 .39552 .49906 Mtetra
.646 .707 .892 r
.39552 .49906 .39642 .50009 .39793 .49967 .39703 .49865 Mtetra
.647 .709 .893 r
.39703 .49865 .39793 .49967 .39945 .49925 .39855 .49823 Mtetra
.653 .713 .891 r
.39855 .49823 .39945 .49925 .40096 .4988 .40006 .49779 Mtetra
.658 .715 .891 r
.40006 .49779 .40096 .4988 .40248 .49833 .40158 .49733 Mtetra
.66 .717 .891 r
.40158 .49733 .40248 .49833 .404 .49786 .4031 .49685 Mtetra
.697 .727 .873 r
.4031 .49685 .404 .49786 .40553 .49712 .40462 .4962 Mtetra
.692 .743 .89 r
.40462 .4962 .40553 .49712 .40706 .49646 .40615 .49558 Mtetra
.616 .733 .93 r
.40615 .49558 .40706 .49646 .40857 .49625 .40767 .49527 Mtetra
0 .372 .837 r
.40767 .49527 .40857 .49625 .41001 .4981 .40914 .49613 Mtetra
0 0 .467 r
.40914 .49613 .41001 .4981 .41113 .50948 .41056 .49873 Mtetra
0 0 .447 r
.41056 .49873 .41113 .50948 .40631 .69737 .41175 .50812 Mtetra
0 0 .344 r
.41175 .50812 .40631 .69737 .40786 .69906 .40722 .68865 Mtetra
.568 .391 .601 r
.40722 .68865 .40786 .69906 .40947 .69875 .40882 .68857 Mtetra
.638 .444 .605 r
.40882 .68857 .40947 .69875 .4111 .69786 .4105 .6861 Mtetra
.617 .424 .598 r
.4105 .6861 .4111 .69786 .41273 .69716 .41216 .68412 Mtetra
.581 .393 .592 r
.41216 .68412 .41273 .69716 .41435 .69669 .41379 .68346 Mtetra
.582 .394 .591 r
.41379 .68346 .41435 .69669 .41597 .69622 .41541 .68275 Mtetra
.583 .394 .591 r
.41541 .68275 .41597 .69622 .4176 .69574 .41704 .68197 Mtetra
.584 .394 .59 r
.41704 .68197 .4176 .69574 .41922 .69526 .41867 .68114 Mtetra
.583 .392 .589 r
.41867 .68114 .41922 .69526 .42085 .69478 .4203 .68033 Mtetra
.682 .469 .591 r
.4203 .68033 .42085 .69478 .42248 .69422 .42209 .67386 Mtetra
.919 .659 .529 r
.42209 .67386 .42248 .69422 .4241 .69364 .42856 .50588 Mtetra
0 0 .385 r
.42856 .50588 .4241 .69364 .42573 .69322 .42541 .67027 Mtetra
.165 .06 .481 r
.42541 .67027 .42573 .69322 .42735 .69326 .42657 .68615 Mtetra
.219 .156 .569 r
.42657 .68615 .42735 .69326 .42895 .69355 .42806 .69062 Mtetra
.147 .22 .683 r
.42806 .69062 .42895 .69355 .43057 .69375 .42962 .69271 Mtetra
.263 .547 .925 r
.42962 .69271 .43057 .69375 .43219 .69359 .43123 .69322 Mtetra
.541 .855 .997 r
.43123 .69322 .43219 .69359 .43383 .69314 .43286 .69285 Mtetra
.649 .904 .982 r
.43286 .69285 .43383 .69314 .43546 .6926 .4345 .69221 Mtetra
.651 .879 .982 r
.4345 .69221 .43546 .6926 .4371 .69209 .43614 .69161 Mtetra
.617 .848 .987 r
.43614 .69161 .4371 .69209 .43873 .69164 .43778 .69114 Mtetra
.607 .841 .988 r
.43778 .69114 .43873 .69164 .44037 .6912 .43941 .69069 Mtetra
.568 .828 .994 r
.43941 .69069 .44037 .6912 .44201 .69081 .44105 .69034 Mtetra
.52 .822 1 r
.44105 .69034 .44201 .69081 .44364 .69045 .44269 .69006 Mtetra
.496 .833 .998 r
.44269 .69006 .44364 .69045 .44528 .69009 .44432 .68978 Mtetra
.507 .855 .993 r
.44432 .68978 .44528 .69009 .44692 .6897 .44596 .68942 Mtetra
.539 .876 .99 r
.44596 .68942 .44692 .6897 .44856 .68926 .44761 .68899 Mtetra
.569 .886 .99 r
.44761 .68899 .44856 .68926 .45021 .6888 .44925 .6885 Mtetra
.617 .895 .988 r
.44925 .6885 .45021 .6888 .45185 .6883 .4509 .68793 Mtetra
.659 .889 .981 r
.4509 .68793 .45185 .6883 .4535 .68776 .45255 .68729 Mtetra
.675 .868 .972 r
.45255 .68729 .4535 .68776 .45515 .68721 .4542 .68665 Mtetra
.661 .839 .968 r
.4542 .68665 .45515 .68721 .4568 .6867 .45585 .68607 Mtetra
.638 .817 .969 r
.45585 .68607 .4568 .6867 .45844 .68624 .4575 .68559 Mtetra
.63 .809 .969 r
.4575 .68559 .45844 .68624 .46009 .68579 .45915 .68514 Mtetra
.582 .794 .98 r
.45915 .68514 .46009 .68579 .46174 .68554 .4608 .68481 Mtetra
.575 .774 .973 r
.4608 .68481 .46174 .68554 .46339 .68535 .46244 .68453 Mtetra
.671 .778 .93 r
.46244 .68453 .46339 .68535 .46504 .68472 .4641 .68397 Mtetra
.822 .808 .838 r
.4641 .68397 .46504 .68472 .46672 .68249 .46577 .68245 Mtetra
.95 .868 .722 r
.46577 .68245 .46672 .68249 .46849 .67517 .46747 .67916 Mtetra
0 0 0 r
.46747 .67916 .46849 .67517 .47318 .48045 .46922 .67258 Mtetra
0 0 .361 r
.46922 .67258 .47318 .48045 .47479 .47677 .47374 .487 Mtetra
.471 .237 .477 r
.47374 .487 .47479 .47677 .47635 .47597 .47533 .4849 Mtetra
.606 .347 .499 r
.47533 .4849 .47635 .47597 .47791 .4758 .47686 .48655 Mtetra
.935 .665 .501 r
.47686 .48655 .47791 .4758 .47947 .47573 .47608 .65339 Mtetra
.577 .359 .547 r
.47608 .65339 .47947 .47573 .48103 .47537 .47758 .66397 Mtetra
.556 .342 .545 r
.47758 .66397 .48103 .47537 .48259 .47491 .47925 .66232 Mtetra
0 0 .364 r
.47925 .66232 .48259 .47491 .48416 .47406 .48319 .48075 Mtetra
0 0 .256 r
.48319 .48075 .48416 .47406 .48574 .47285 .48483 .47431 Mtetra
.78 .88 .456 r
.48483 .47431 .48574 .47285 .48731 .4717 .48643 .47115 Mtetra
.857 .839 .827 r
.48643 .47115 .48731 .4717 .48889 .47084 .48802 .46947 Mtetra
.68 .668 .831 r
.48802 .46947 .48889 .47084 .49045 .4703 .48959 .46883 Mtetra
.63 .632 .834 r
.48959 .46883 .49045 .4703 .49202 .46987 .49115 .46846 Mtetra
.627 .641 .845 r
.49115 .46846 .49202 .46987 .49359 .46943 .49272 .46812 Mtetra
.658 .669 .849 r
.49272 .46812 .49359 .46943 .49516 .46892 .49429 .46762 Mtetra
.654 .668 .851 r
.49429 .46762 .49516 .46892 .49673 .46842 .49587 .46713 Mtetra
.642 .666 .858 r
.49587 .46713 .49673 .46842 .49831 .46794 .49744 .46672 Mtetra
.623 .67 .874 r
.49744 .46672 .49831 .46794 .49988 .4675 .49901 .46639 Mtetra
.626 .692 .892 r
.49901 .46639 .49988 .4675 .50146 .46705 .50059 .46605 Mtetra
.654 .724 .9 r
.50059 .46605 .50146 .46705 .50303 .46654 .50216 .46558 Mtetra
.696 .745 .889 r
.50216 .46558 .50303 .46654 .50461 .46596 .50374 .46493 Mtetra
.7 .732 .875 r
.50374 .46493 .50461 .46596 .50619 .46536 .50532 .46424 Mtetra
.688 .712 .866 r
.50532 .46424 .50619 .46536 .50776 .46478 .5069 .4636 Mtetra
.667 .694 .866 r
.5069 .4636 .50776 .46478 .50934 .46424 .50848 .46306 Mtetra
.662 .693 .868 r
.50848 .46306 .50934 .46424 .51092 .46371 .51006 .46255 Mtetra
.66 .695 .872 r
.51006 .46255 .51092 .46371 .5125 .4632 .51164 .46205 Mtetra
.662 .699 .874 r
.51164 .46205 .5125 .4632 .51409 .46268 .51322 .46154 Mtetra
.662 .7 .875 r
.51322 .46154 .51409 .46268 .51567 .46217 .51481 .46104 Mtetra
.662 .701 .876 r
.51481 .46104 .51567 .46217 .51725 .46165 .51639 .46053 Mtetra
.663 .703 .877 r
.51639 .46053 .51725 .46165 .51884 .46113 .51797 .46002 Mtetra
.663 .705 .879 r
.51797 .46002 .51884 .46113 .52042 .46061 .51956 .4595 Mtetra
.677 .712 .874 r
.51956 .4595 .52042 .46061 .52201 .45999 .52115 .45892 Mtetra
.704 .728 .869 r
.52115 .45892 .52201 .45999 .5236 .45916 .52274 .45821 Mtetra
.659 .736 .906 r
.52274 .45821 .5236 .45916 .52518 .4587 .52432 .45772 Mtetra
.453 .646 .941 r
.52432 .45772 .52518 .4587 .52677 .45926 .52591 .45786 Mtetra
0 .097 .651 r
.52591 .45786 .52677 .45926 .52837 .4636 .52751 .45964 Mtetra
0 0 .523 r
.52751 .45964 .52837 .4636 .53027 .65897 .52911 .4639 Mtetra
0 0 .394 r
.52911 .4639 .53027 .65897 .53197 .66354 .53103 .65069 Mtetra
.508 .34 .587 r
.53103 .65069 .53197 .66354 .53366 .6636 .53273 .65263 Mtetra
.615 .425 .601 r
.53273 .65263 .53366 .6636 .53535 .66286 .53441 .65084 Mtetra
.659 .455 .596 r
.53441 .65084 .53535 .66286 .53705 .66187 .53609 .64673 Mtetra
.585 .392 .587 r
.53609 .64673 .53705 .66187 .53874 .66136 .53778 .64572 Mtetra
.586 .392 .586 r
.53778 .64572 .53874 .66136 .54044 .66084 .53947 .64465 Mtetra
.583 .389 .584 r
.53947 .64465 .54044 .66084 .54214 .66033 .54116 .64365 Mtetra
.576 .383 .583 r
.54116 .64365 .54214 .66033 .54384 .65984 .54285 .64299 Mtetra
.572 .38 .582 r
.54285 .64299 .54384 .65984 .54554 .65936 .54454 .64256 Mtetra
.567 .376 .582 r
.54454 .64256 .54554 .65936 .54724 .6589 .54624 .64238 Mtetra
.561 .372 .582 r
.54624 .64238 .54724 .6589 .54894 .65846 .54794 .64249 Mtetra
.561 .373 .583 r
.54794 .64249 .54894 .65846 .55065 .65802 .54964 .6426 Mtetra
.542 .36 .583 r
.54964 .6426 .55065 .65802 .55235 .65768 .55135 .64354 Mtetra
.487 .321 .581 r
.55135 .64354 .55235 .65768 .55406 .65775 .55307 .64638 Mtetra
.572 .391 .598 r
.55307 .64638 .55406 .65775 .55577 .65729 .55478 .64614 Mtetra
.816 .574 .573 r
.55478 .64614 .55577 .65729 .55747 .65549 .55633 .6287 Mtetra
.924 .653 .507 r
.55633 .6287 .55747 .65549 .55906 .64346 .55634 .45293 Mtetra
.567 .354 .552 r
.55634 .45293 .55906 .64346 .55878 .45145 .55792 .44891 Mtetra
.76 .613 .696 r
.55792 .44891 .55878 .45145 .56036 .4478 .55951 .44667 Mtetra
.709 .72 .859 r
.55951 .44667 .56036 .4478 .56196 .44687 .56112 .44591 Mtetra
.642 .73 .913 r
.56112 .44591 .56196 .44687 .56357 .44648 .56273 .44548 Mtetra
.607 .71 .918 r
.56273 .44548 .56357 .44648 .56519 .44631 .56434 .44519 Mtetra
.661 .706 .88 r
.56434 .44519 .56519 .44631 .5668 .4458 .56596 .44467 Mtetra
.661 .705 .879 r
.56596 .44467 .5668 .4458 .56842 .4453 .56757 .44416 Mtetra
.661 .703 .878 r
.56757 .44416 .56842 .4453 .57003 .4448 .56918 .44365 Mtetra
.662 .701 .875 r
.56918 .44365 .57003 .4448 .57165 .44429 .5708 .44313 Mtetra
.662 .7 .874 r
.5708 .44313 .57165 .44429 .57326 .44378 .57242 .44262 Mtetra
.662 .699 .874 r
.57242 .44262 .57326 .44378 .57488 .44327 .57403 .4421 Mtetra
.661 .698 .873 r
.57403 .4421 .57488 .44327 .5765 .44275 .57565 .44158 Mtetra
.661 .697 .873 r
.57565 .44158 .5765 .44275 .57812 .44224 .57727 .44106 Mtetra
.661 .696 .872 r
.57727 .44106 .57812 .44224 .57974 .44174 .57889 .44055 Mtetra
.663 .696 .87 r
.57889 .44055 .57974 .44174 .58136 .44123 .58051 .44002 Mtetra
.659 .691 .869 r
.58051 .44002 .58136 .44123 .58298 .44073 .58214 .43952 Mtetra
.652 .686 .87 r
.58214 .43952 .58298 .44073 .5846 .44025 .58376 .43904 Mtetra
.625 .677 .88 r
.58376 .43904 .5846 .44025 .58623 .43982 .58539 .4387 Mtetra
.624 .693 .894 r
.58539 .4387 .58623 .43982 .58785 .43938 .58702 .43835 Mtetra
.637 .716 .905 r
.58702 .43835 .58785 .43938 .58948 .43892 .58864 .43794 Mtetra
.693 .747 .892 r
.58864 .43794 .58948 .43892 .59111 .43835 .59027 .43728 Mtetra
.7 .73 .874 r
.59027 .43728 .59111 .43835 .59273 .43776 .59189 .43657 Mtetra
.695 .708 .858 r
.59189 .43657 .59273 .43776 .59436 .43716 .59352 .43587 Mtetra
.703 .694 .838 r
.59352 .43587 .59436 .43716 .59599 .43654 .59514 .43509 Mtetra
.665 .656 .831 r
.59514 .43509 .59599 .43654 .59762 .43598 .59677 .43451 Mtetra
.598 .623 .847 r
.59677 .43451 .59762 .43598 .59925 .43555 .59841 .43429 Mtetra
0 .293 .791 r
.59841 .43429 .59925 .43555 .60089 .43556 .60009 .43559 Mtetra
.844 .396 .149 r
.60009 .43559 .60089 .43556 .60254 .4357 .6018 .43843 Mtetra
.882 .565 .446 r
.6018 .43843 .60254 .4357 .6042 .43586 .60371 .44929 Mtetra
.654 .397 .518 r
.60371 .44929 .6042 .43586 .60582 .43494 .60549 .45437 Mtetra
.425 .221 .498 r
.60549 .45437 .60582 .43494 .60745 .43425 .60699 .44791 Mtetra
.613 .363 .515 r
.60699 .44791 .60745 .43425 .60911 .43428 .60872 .4507 Mtetra
.941 .658 .473 r
.60872 .4507 .60911 .43428 .61093 .44063 .61519 .63449 Mtetra
.565 .349 .546 r
.61519 .63449 .61093 .44063 .61785 .63661 .61704 .63825 Mtetra
.7 .312 .31 r
.61704 .63825 .61785 .63661 .61972 .64049 .61885 .63999 Mtetra
.388 .76 .992 r
.61885 .63999 .61972 .64049 .62148 .6407 .62061 .63993 Mtetra
.649 .798 .954 r
.62061 .63993 .62148 .6407 .62323 .64015 .62236 .6394 Mtetra
.706 .818 .935 r
.62236 .6394 .62323 .64015 .62497 .63924 .62411 .63865 Mtetra
.544 .807 .994 r
.62411 .63865 .62497 .63924 .62672 .63877 .62586 .63835 Mtetra
.563 .861 .997 r
.62586 .63835 .62672 .63877 .62848 .63827 .62762 .6379 Mtetra
.696 .914 .97 r
.62762 .6379 .62848 .63827 .63023 .63763 .62936 .63709 Mtetra
.906 .856 .781 r
.62936 .63709 .63023 .63763 .63196 .63652 .63106 .63467 Mtetra
.87 .7 .669 r
.63106 .63467 .63196 .63652 .63369 .6352 .6327 .63049 Mtetra
.873 .636 .576 r
.6327 .63049 .63369 .6352 .63542 .63383 .6341 .61862 Mtetra
.95 .67 .472 r
.6341 .61862 .63542 .63383 .63717 .63305 .63002 .43749 Mtetra
.561 .349 .551 r
.63002 .43749 .63717 .63305 .63893 .63254 .63168 .43691 Mtetra
.551 .342 .55 r
.63168 .43691 .63893 .63254 .64069 .63216 .63351 .44161 Mtetra
.569 .356 .552 r
.63351 .44161 .64069 .63216 .64245 .63154 .63501 .43628 Mtetra
.562 .351 .551 r
.63501 .43628 .64245 .63154 .6442 .63097 .63663 .43461 Mtetra
.55 .341 .55 r
.63663 .43461 .6442 .63097 .64597 .63061 .63851 .44016 Mtetra
.038 0 .43 r
.63851 .44016 .64597 .63061 .64776 .6309 .64672 .62485 Mtetra
.253 .204 .608 r
.64672 .62485 .64776 .6309 .64956 .63126 .64864 .62887 Mtetra
.172 .284 .738 r
.64864 .62887 .64956 .63126 .65135 .63147 .6505 .63074 Mtetra
.385 .694 .981 r
.6505 .63074 .65135 .63147 .65313 .63122 .65229 .63085 Mtetra
.55 .87 .994 r
.65229 .63085 .65313 .63122 .6549 .63078 .65406 .6304 Mtetra
.651 .901 .982 r
.65406 .6304 .6549 .63078 .65667 .63025 .65582 .62971 Mtetra
.523 .815 .999 r
.65582 .62971 .65667 .63025 .65846 .63013 .65761 .62942 Mtetra
.59 .794 .977 r
.65761 .62942 .65846 .63013 .66024 .62983 .65938 .62905 Mtetra
.699 .811 .935 r
.65938 .62905 .66024 .62983 .662 .62896 .66115 .62831 Mtetra
.872 .854 .821 r
.66115 .62831 .662 .62896 .66365 .6255 .66287 .62637 Mtetra
.906 .933 .561 r
.66287 .62637 .66365 .6255 .66485 .61077 .66452 .62284 Mtetra
.177 .018 .413 r
.66452 .62284 .66485 .61077 .65875 .4196 .66593 .61338 Mtetra
.032 0 .423 r
.66593 .61338 .65875 .4196 .66033 .41699 .65971 .42052 Mtetra
0 0 .172 r
.65971 .42052 .66033 .41699 .66197 .41579 .66122 .41633 Mtetra
.833 .97 .656 r
.66122 .41633 .66197 .41579 .66363 .41508 .66282 .41407 Mtetra
.738 .759 .87 r
.66282 .41407 .66363 .41508 .6653 .41454 .66448 .41314 Mtetra
.624 .649 .854 r
.66448 .41314 .6653 .41454 .66698 .41413 .66616 .41279 Mtetra
.572 .634 .875 r
.66616 .41279 .66698 .41413 .66866 .41378 .66785 .41267 Mtetra
.625 .7 .899 r
.66785 .41267 .66866 .41378 .67033 .4133 .66953 .41231 Mtetra
.661 .739 .908 r
.66953 .41231 .67033 .4133 .67201 .41273 .6712 .41178 Mtetra
.676 .754 .91 r
.6712 .41178 .67201 .41273 .67368 .41214 .67288 .41119 Mtetra
.739 .774 .881 r
.67288 .41119 .67368 .41214 .67534 .41119 .67454 .41027 Mtetra
.733 .78 .891 r
.67454 .41027 .67534 .41119 .677 .41036 .6762 .4094 Mtetra
.66 .748 .915 r
.6762 .4094 .677 .41036 .67869 .41005 .67788 .40888 Mtetra
.301 .522 .901 r
.67788 .40888 .67869 .41005 .68049 .41198 .67961 .4095 Mtetra
.122 .231 .705 r
.67961 .4095 .68049 .41198 .68283 .42509 .68143 .41168 Mtetra
.275 .171 .551 r
.68143 .41168 .68283 .42509 .69394 .61626 .68356 .42031 Mtetra
.056 0 .442 r
.68356 .42031 .69394 .61626 .69586 .61827 .69477 .6123 Mtetra
.313 .249 .624 r
.69477 .6123 .69586 .61827 .6977 .61855 .69676 .61577 Mtetra
.338 .363 .74 r
.69676 .61577 .6977 .61855 .69951 .61831 .69866 .61724 Mtetra
.447 .645 .942 r
.69866 .61724 .69951 .61831 .70131 .61791 .7005 .61742 Mtetra
.581 .853 .995 r
.7005 .61742 .70131 .61791 .70312 .61742 .7023 .61696 Mtetra
.668 .889 .978 r
.7023 .61696 .70312 .61742 .70491 .61684 .70409 .61624 Mtetra
.583 .826 .991 r
.70409 .61624 .70491 .61684 .70673 .6166 .7059 .61583 Mtetra
.593 .784 .972 r
.7059 .61583 .70673 .6166 .70854 .61632 .70771 .61546 Mtetra
.689 .797 .931 r
.70771 .61546 .70854 .61632 .71033 .61552 .70951 .61477 Mtetra
.851 .843 .837 r
.70951 .61477 .71033 .61552 .71201 .61259 .71125 .61301 Mtetra
.951 .949 .646 r
.71125 .61301 .71201 .61259 .71331 .60291 .7129 .6097 Mtetra
0 0 .291 r
.7129 .6097 .71331 .60291 .70419 .40578 .7143 .60187 Mtetra
.056 0 .437 r
.7143 .60187 .70419 .40578 .70574 .40254 .70523 .40666 Mtetra
0 0 .238 r
.70523 .40666 .70574 .40254 .70739 .40121 .7067 .402 Mtetra
.735 .899 .516 r
.7067 .402 .70739 .40121 .70907 .4004 .70829 .39954 Mtetra
.793 .808 .864 r
.70829 .39954 .70907 .4004 .71076 .39977 .70995 .3983 Mtetra
.666 .661 .836 r
.70995 .3983 .71076 .39977 .71246 .39922 .71164 .3977 Mtetra
.619 .631 .841 r
.71164 .3977 .71246 .39922 .71416 .39878 .71335 .39737 Mtetra
.614 .646 .858 r
.71335 .39737 .71416 .39878 .71587 .39834 .71507 .39706 Mtetra
.621 .671 .877 r
.71507 .39706 .71587 .39834 .71758 .39787 .71678 .39671 Mtetra
.626 .695 .894 r
.71678 .39671 .71758 .39787 .71928 .39739 .71849 .39634 Mtetra
.666 .732 .899 r
.71849 .39634 .71928 .39739 .72098 .39683 .7202 .39578 Mtetra
.696 .744 .888 r
.7202 .39578 .72098 .39683 .72268 .3962 .72189 .39507 Mtetra
.698 .729 .874 r
.72189 .39507 .72268 .3962 .72438 .39556 .72359 .39434 Mtetra
.682 .707 .867 r
.72359 .39434 .72438 .39556 .72608 .39494 .72529 .39368 Mtetra
.668 .695 .867 r
.72529 .39368 .72608 .39494 .72779 .39435 .72699 .3931 Mtetra
.663 .695 .87 r
.72699 .3931 .72779 .39435 .7295 .39377 .7287 .39255 Mtetra
.689 .709 .864 r
.7287 .39255 .7295 .39377 .73119 .39298 .7304 .39185 Mtetra
.693 .728 .877 r
.7304 .39185 .73119 .39298 .73288 .3922 .7321 .39115 Mtetra
.633 .722 .911 r
.7321 .39115 .73288 .3922 .73461 .39186 .73382 .39073 Mtetra
.304 .534 .909 r
.73382 .39073 .73461 .39186 .73645 .39324 .73561 .39133 Mtetra
0 .165 .694 r
.73561 .39133 .73645 .39324 .73869 .40067 .73751 .39362 Mtetra
.116 .097 .558 r
.73751 .39362 .73869 .40067 .75367 .59836 .73971 .40019 Mtetra
.1 .016 .463 r
.73971 .40019 .75367 .59836 .7557 .60078 .75416 .58914 Mtetra
.55 .376 .598 r
.75416 .58914 .7557 .60078 .75755 .60054 .75606 .58965 Mtetra
.624 .431 .6 r
.75606 .58965 .75755 .60054 .75936 .59965 .75778 .58743 Mtetra
.622 .426 .595 r
.75778 .58743 .75936 .59965 .76118 .59883 .75947 .58499 Mtetra
.578 .39 .591 r
.75947 .58499 .76118 .59883 .76301 .59832 .7613 .58439 Mtetra
.569 .384 .59 r
.7613 .58439 .76301 .59832 .76485 .59782 .76315 .58417 Mtetra
.542 .365 .591 r
.76315 .58417 .76485 .59782 .7667 .59737 .76509 .58511 Mtetra
.53 .36 .595 r
.76509 .58511 .7667 .59737 .76855 .59697 .76705 .5864 Mtetra
.545 .377 .604 r
.76705 .5864 .76855 .59697 .7704 .59655 .76897 .58704 Mtetra
.582 .407 .61 r
.76897 .58704 .7704 .59655 .77224 .59603 .77082 .58655 Mtetra
.618 .432 .608 r
.77082 .58655 .77224 .59603 .77408 .59541 .77257 .58487 Mtetra
.63 .436 .602 r
.77257 .58487 .77408 .59541 .77591 .59476 .77428 .58249 Mtetra
.576 .393 .596 r
.77428 .58249 .77591 .59476 .77777 .59444 .77612 .58204 Mtetra
.535 .363 .595 r
.77612 .58204 .77777 .59444 .77965 .5943 .77809 .58315 Mtetra
.602 .415 .6 r
.77809 .58315 .77965 .5943 .78148 .59354 .77987 .58177 Mtetra
.967 .672 .416 r
.77987 .58177 .78148 .59354 .78313 .59032 .76743 .39191 Mtetra
.573 .358 .551 r
.76743 .39191 .78313 .59032 .7699 .39196 .76859 .38382 Mtetra
.677 .477 .607 r
.76859 .38382 .7699 .39196 .77095 .38246 .77011 .38038 Mtetra
.753 .641 .737 r
.77011 .38038 .77095 .38246 .77253 .37986 .77175 .37869 Mtetra
.663 .711 .884 r
.77175 .37869 .77253 .37986 .77425 .37913 .77349 .37813 Mtetra
.593 .717 .93 r
.77349 .37813 .77425 .37913 .77601 .37886 .77525 .37785 Mtetra
.653 .741 .914 r
.77525 .37785 .77601 .37886 .77776 .3785 .77699 .37734 Mtetra
.728 .738 .86 r
.77699 .37734 .77776 .3785 .77949 .37778 .7787 .37642 Mtetra
.684 .688 .848 r
.7787 .37642 .77949 .37778 .78122 .37712 .78043 .37572 Mtetra
.554 .62 .872 r
.78043 .37572 .78122 .37712 .78296 .37655 .78221 .37568 Mtetra
0 .344 .815 r
.78221 .37568 .78296 .37655 .78471 .37616 .78409 .37681 Mtetra
.804 .354 .175 r
.78409 .37681 .78471 .37616 .78651 .37624 .78611 .37957 Mtetra
.972 .668 .374 r
.78611 .37957 .78651 .37624 .78843 .37783 .80312 .56483 Mtetra
.583 .362 .546 r
.80312 .56483 .78843 .37783 .79129 .39073 .80635 .58102 Mtetra
.563 .347 .545 r
.80635 .58102 .79129 .39073 .80916 .5833 .80849 .58379 Mtetra
.544 .003 0 r
.80849 .58379 .80916 .5833 .81127 .58563 .81047 .58457 Mtetra
.628 .736 .925 r
.81047 .58457 .81127 .58563 .81316 .58533 .81235 .58413 Mtetra
.702 .739 .88 r
.81235 .58413 .81316 .58533 .815 .5844 .8142 .58332 Mtetra
.703 .761 .897 r
.8142 .58332 .815 .5844 .81683 .58343 .81605 .58252 Mtetra
.628 .771 .949 r
.81605 .58252 .81683 .58343 .81871 .58291 .81793 .58205 Mtetra
.601 .772 .962 r
.81793 .58205 .81871 .58291 .82059 .58247 .81982 .58166 Mtetra
.515 .748 .98 r
.81982 .58166 .82059 .58247 .82248 .58217 .82172 .58151 Mtetra
.365 .709 .986 r
.82172 .58151 .82248 .58217 .8244 .58204 .82366 .58161 Mtetra
.43 .807 .992 r
.82366 .58161 .8244 .58204 .8263 .58181 .82556 .58139 Mtetra
.73 .928 .956 r
.82556 .58139 .8263 .58181 .82819 .58141 .8274 .58039 Mtetra
.889 .808 .763 r
.8274 .58039 .82819 .58141 .83006 .58077 .82911 .57784 Mtetra
.845 .652 .641 r
.82911 .57784 .83006 .58077 .83188 .57954 .83061 .57307 Mtetra
.974 .674 .381 r
.83061 .57307 .83188 .57954 .83354 .57657 .81483 .37767 Mtetra
.573 .359 .551 r
.81483 .37767 .83354 .57657 .81784 .38361 .81587 .36914 Mtetra
.626 .421 .585 r
.81587 .36914 .81784 .38361 .81826 .36827 .8174 .36594 Mtetra
.746 .624 .724 r
.8174 .36594 .81826 .36827 .81978 .36515 .81905 .36418 Mtetra
.702 .773 .907 r
.81905 .36418 .81978 .36515 .82152 .36428 .8208 .36344 Mtetra
.623 .775 .953 r
.8208 .36344 .82152 .36428 .8233 .36391 .82258 .36301 Mtetra
.648 .768 .936 r
.82258 .36301 .8233 .36391 .82509 .36352 .82435 .3625 Mtetra
.747 .776 .876 r
.82435 .3625 .82509 .36352 .82681 .36252 .82608 .36149 Mtetra
.665 .744 .91 r
.82608 .36149 .82681 .36252 .82858 .36196 .82784 .36092 Mtetra
.25 .52 .911 r
.82784 .36092 .82858 .36196 .83047 .36267 .82973 .36161 Mtetra
.877 .483 .023 r
.82973 .36161 .83047 .36267 .83297 .36967 .83223 .36856 Mtetra
.975 .667 .334 r
.83223 .36856 .83297 .36967 .85431 .5706 .85354 .56957 Mtetra
.651 .202 0 r
.85354 .56957 .85431 .5706 .8566 .57405 .85582 .57304 Mtetra
.387 .629 .95 r
.85582 .57304 .8566 .57405 .85858 .57435 .85781 .57335 Mtetra
.696 .777 .914 r
.85781 .57335 .85858 .57435 .86046 .57359 .85969 .57258 Mtetra
.875 .816 .787 r
.85969 .57258 .86046 .57359 .86219 .57135 .86142 .57033 Mtetra
.978 .762 .542 r
.86142 .57033 .86219 .57135 .86335 .5634 .86257 .56226 Mtetra
.977 .675 .348 r
.86257 .56226 .86335 .5634 .84494 .36085 .84421 .35973 Mtetra
.943 .779 .65 r
.84421 .35973 .84494 .36085 .84635 .35653 .84561 .35544 Mtetra
.741 .763 .87 r
.84561 .35544 .84635 .35653 .84808 .35553 .84735 .35445 Mtetra
.619 .716 .915 r
.84735 .35445 .84808 .35553 .84988 .35515 .84915 .35408 Mtetra
.589 .703 .922 r
.84915 .35408 .84988 .35515 .8517 .35489 .85097 .35382 Mtetra
.744 .767 .872 r
.85097 .35382 .8517 .35489 .85344 .35388 .85271 .35281 Mtetra
.672 .742 .903 r
.85271 .35281 .85344 .35388 .85522 .35326 .85449 .3522 Mtetra
.38 .595 .93 r
.85449 .3522 .85522 .35326 .8571 .35365 .85638 .35259 Mtetra
.799 .385 0 r
.85638 .35259 .8571 .35365 .8595 .35893 .85878 .35786 Mtetra
.973 .663 .318 r
.85878 .35786 .8595 .35893 .88275 .56123 .88199 .56022 Mtetra
.72 .28 0 r
.88199 .56022 .88275 .56123 .88517 .56541 .88441 .56441 Mtetra
.502 .694 .954 r
.88441 .56441 .88517 .56541 .88714 .56539 .88638 .56439 Mtetra
.694 .78 .917 r
.88638 .56439 .88714 .56539 .88904 .56463 .88828 .56362 Mtetra
.735 .794 .899 r
.88828 .56362 .88904 .56463 .89091 .56365 .89015 .56264 Mtetra
.497 .69 .954 r
.89015 .56264 .89091 .56365 .89289 .56365 .89214 .56264 Mtetra
.625 .751 .937 r
.89214 .56264 .89289 .56365 .89482 .5632 .89407 .56218 Mtetra
.81 .812 .852 r
.89407 .56218 .89482 .5632 .89664 .5617 .89589 .56067 Mtetra
.979 .77 .552 r
.89589 .56067 .89664 .5617 .89783 .55447 .89707 .55336 Mtetra
.976 .671 .329 r
.89707 .55336 .89783 .55447 .87724 .35116 .87652 .35003 Mtetra
.954 .779 .626 r
.87652 .35003 .87724 .35116 .87857 .34636 .87785 .34527 Mtetra
.74 .764 .872 r
.87785 .34527 .87857 .34636 .88033 .34537 .87961 .34428 Mtetra
.605 .709 .918 r
.87961 .34428 .88033 .34537 .88215 .34505 .88144 .34395 Mtetra
.519 .667 .929 r
.88144 .34395 .88215 .34505 .88402 .34503 .88331 .34395 Mtetra
.649 .73 .908 r
.88331 .34395 .88402 .34503 .88583 .34452 .88512 .34343 Mtetra
.655 .734 .908 r
.88512 .34343 .88583 .34452 .88764 .34397 .88693 .3429 Mtetra
.667 .742 .906 r
.88693 .3429 .88764 .34397 .88944 .34336 .88873 .3423 Mtetra
.763 .78 .867 r
.88873 .3423 .88944 .34336 .89119 .34223 .89048 .34117 Mtetra
.694 .755 .899 r
.89048 .34117 .89119 .34223 .89297 .3415 .89227 .34045 Mtetra
.475 .653 .938 r
.89227 .34045 .89297 .3415 .89486 .34157 .89416 .34056 Mtetra
.806 .394 0 r
.89416 .34056 .89486 .34157 .89735 .34676 .89671 .34628 Mtetra
.971 .656 .297 r
.89671 .34628 .89735 .34676 .92322 .54987 .92256 .54951 Mtetra
.813 .343 0 r
.92256 .54951 .92322 .54987 .92576 .55437 .92507 .55372 Mtetra
.466 .771 .997 r
.92507 .55372 .92576 .55437 .92777 .55433 .92706 .55358 Mtetra
.722 .855 .944 r
.92706 .55358 .92777 .55433 .92968 .55351 .92896 .55266 Mtetra
.798 .85 .89 r
.92896 .55266 .92968 .55351 .93155 .55227 .93082 .55132 Mtetra
.635 .771 .945 r
.30423 .72707 .30523 .72784 .30678 .72758 .30579 .72666 Mtetra
.649 .74 .915 r
.30579 .72666 .30678 .72758 .30834 .72717 .30735 .72622 Mtetra
.676 .739 .898 r
.30735 .72622 .30834 .72717 .30992 .7264 .30892 .72566 Mtetra
.688 .789 .927 r
.30892 .72566 .30992 .7264 .31159 .72418 .31049 .72506 Mtetra
0 0 0 r
.31049 .72506 .31159 .72418 .31336 .72016 .31209 .72403 Mtetra
.28 0 .294 r
.31209 .72403 .31336 .72016 .32574 .53729 .31374 .72214 Mtetra
.542 .33 .542 r
.31374 .72214 .32574 .53729 .32788 .52561 .3158 .71332 Mtetra
0 0 .255 r
.3158 .71332 .32788 .52561 .32952 .52234 .32846 .52365 Mtetra
.972 .925 .618 r
.32846 .52365 .32952 .52234 .33109 .52044 .33015 .51963 Mtetra
.765 .774 .86 r
.33015 .51963 .33109 .52044 .33258 .51969 .33166 .51863 Mtetra
.637 .694 .887 r
.33166 .51863 .33258 .51969 .33406 .51932 .33314 .51826 Mtetra
.549 .664 .913 r
.33314 .51826 .33406 .51932 .33552 .51911 .3346 .51819 Mtetra
.678 .736 .894 r
.3346 .51819 .33552 .51911 .33702 .51842 .33608 .51766 Mtetra
.678 .772 .921 r
.33608 .51766 .33702 .51842 .33851 .51784 .33757 .51712 Mtetra
.645 .775 .943 r
.33757 .51712 .33851 .51784 .33998 .5176 .33905 .5167 Mtetra
.635 .729 .916 r
.33905 .5167 .33998 .5176 .34139 .51858 .34053 .51633 Mtetra
.568 .519 .761 r
.34053 .51633 .34139 .51858 .34271 .52113 .34199 .51632 Mtetra
.507 .387 .651 r
.34199 .51632 .34271 .52113 .33475 .69543 .34342 .51706 Mtetra
.546 .338 .548 r
.34342 .51706 .33475 .69543 .33528 .71429 .34455 .52313 Mtetra
0 0 .284 r
.34455 .52313 .33528 .71429 .33668 .71717 .33584 .7136 Mtetra
0 0 .461 r
.33584 .7136 .33668 .71717 .33816 .71842 .33719 .71741 Mtetra
.287 .564 .932 r
.33719 .71741 .33816 .71842 .33971 .71862 .33872 .71785 Mtetra
.643 .772 .942 r
.33872 .71785 .33971 .71862 .34128 .71823 .3403 .71741 Mtetra
.744 .78 .882 r
.3403 .71741 .34128 .71823 .34289 .71727 .3419 .7165 Mtetra
.7 .784 .916 r
.3419 .7165 .34289 .71727 .34455 .71522 .34349 .71583 Mtetra
.402 .821 .638 r
.34349 .71583 .34455 .71522 .3463 .71152 .3451 .71484 Mtetra
.248 0 .254 r
.3451 .71484 .3463 .71152 .3486 .69661 .34675 .71307 Mtetra
.346 .144 .457 r
.34675 .71307 .3486 .69661 .35912 .51616 .34866 .70608 Mtetra
0 0 .276 r
.34866 .70608 .35912 .51616 .36077 .51258 .35971 .51438 Mtetra
.945 .912 .535 r
.35971 .51438 .36077 .51258 .36234 .51054 .36141 .50988 Mtetra
.808 .805 .848 r
.36141 .50988 .36234 .51054 .36386 .50966 .36295 .5086 Mtetra
.655 .702 .882 r
.36295 .5086 .36386 .50966 .36535 .50922 .36444 .50815 Mtetra
.565 .668 .908 r
.36444 .50815 .36535 .50922 .36684 .50898 .36592 .50804 Mtetra
.725 .743 .866 r
.36592 .50804 .36684 .50898 .36836 .50813 .36744 .50724 Mtetra
.707 .75 .886 r
.36744 .50724 .36836 .50813 .36987 .50743 .36895 .50656 Mtetra
.527 .7 .949 r
.36895 .50656 .36987 .50743 .37135 .50735 .37043 .50649 Mtetra
.903 .489 .15 r
.37043 .50649 .37135 .50735 .37268 .51074 .37176 .50979 Mtetra
.944 .684 .513 r
.37176 .50979 .37268 .51074 .3654 .70456 .36444 .70334 Mtetra
.949 .6 .301 r
.36444 .70334 .3654 .70456 .36671 .71043 .36574 .70941 Mtetra
.128 .47 .893 r
.36574 .70941 .36671 .71043 .36825 .71105 .36728 .7101 Mtetra
.68 .744 .9 r
.36728 .7101 .36825 .71105 .36986 .71038 .36889 .70951 Mtetra
.763 .775 .862 r
.36889 .70951 .36986 .71038 .37149 .70922 .37051 .70845 Mtetra
.587 .76 .961 r
.37051 .70845 .37149 .70922 .37308 .70891 .3721 .70817 Mtetra
.581 .766 .967 r
.3721 .70817 .37308 .70891 .37467 .70863 .37369 .7079 Mtetra
.751 .802 .894 r
.37369 .7079 .37467 .70863 .37629 .70768 .37531 .70696 Mtetra
.914 .758 .675 r
.37531 .70696 .37629 .70768 .37807 .70287 .37709 .70243 Mtetra
.945 .689 .519 r
.37709 .70243 .37807 .70287 .3877 .5075 .38676 .50742 Mtetra
.952 .772 .624 r
.38676 .50742 .3877 .5075 .38944 .50152 .38852 .50096 Mtetra
.85 .823 .821 r
.38852 .50096 .38944 .50152 .391 .4999 .39008 .4993 Mtetra
.647 .813 .963 r
.39008 .4993 .391 .4999 .39251 .49942 .39159 .49884 Mtetra
.446 .748 .993 r
.39159 .49884 .39251 .49942 .39401 .49934 .39309 .49879 Mtetra
.553 .799 .99 r
.39309 .49879 .39401 .49934 .39552 .49906 .3946 .49854 Mtetra
.612 .824 .981 r
.3946 .49854 .39552 .49906 .39703 .49865 .39611 .49814 Mtetra
.612 .829 .983 r
.39611 .49814 .39703 .49865 .39855 .49823 .39762 .49774 Mtetra
.621 .836 .982 r
.39762 .49774 .39855 .49823 .40006 .49779 .39914 .49731 Mtetra
.629 .842 .982 r
.39914 .49731 .40006 .49779 .40158 .49733 .40066 .49686 Mtetra
.634 .846 .981 r
.40066 .49686 .40158 .49733 .4031 .49685 .40218 .49639 Mtetra
.668 .854 .971 r
.40218 .49639 .4031 .49685 .40462 .4962 .4037 .49582 Mtetra
.655 .877 .981 r
.4037 .49582 .40462 .4962 .40615 .49558 .40522 .49526 Mtetra
.59 .875 .993 r
.40522 .49526 .40615 .49558 .40767 .49527 .40675 .49482 Mtetra
.368 .75 .989 r
.40675 .49482 .40767 .49527 .40914 .49613 .40825 .49479 Mtetra
.441 .562 .881 r
.40825 .49479 .40914 .49613 .41056 .49873 .40975 .49511 Mtetra
.524 .428 .689 r
.40975 .49511 .41056 .49873 .41175 .50812 .41124 .49553 Mtetra
.565 .38 .59 r
.41124 .49553 .41175 .50812 .40722 .68865 .41276 .49549 Mtetra
.56 .349 .551 r
.41276 .49549 .40722 .68865 .40882 .68857 .41429 .49497 Mtetra
.561 .349 .551 r
.41429 .49497 .40882 .68857 .4105 .6861 .41582 .49429 Mtetra
.56 .349 .551 r
.41582 .49429 .4105 .6861 .41216 .68412 .41736 .49369 Mtetra
.41736 .49369 .41216 .68412 .41379 .68346 .41889 .49317 Mtetra
.41889 .49317 .41379 .68346 .41541 .68275 .42042 .49265 Mtetra
.42042 .49265 .41541 .68275 .41704 .68197 .42195 .49212 Mtetra
.42195 .49212 .41704 .68197 .41867 .68114 .42349 .49159 Mtetra
.42349 .49159 .41867 .68114 .4203 .68033 .42502 .49107 Mtetra
.561 .35 .551 r
.42502 .49107 .4203 .68033 .42209 .67386 .42657 .4902 Mtetra
.42657 .4902 .42209 .67386 .42856 .50588 .42811 .48937 Mtetra
.566 .374 .58 r
.42811 .48937 .42856 .50588 .42541 .67027 .42964 .48921 Mtetra
.553 .343 .55 r
.42964 .48921 .42541 .67027 .42657 .68615 .43108 .4922 Mtetra
0 0 .334 r
.43108 .4922 .42657 .68615 .42806 .69062 .42723 .68543 Mtetra
0 0 .433 r
.42723 .68543 .42806 .69062 .42962 .69271 .42869 .69112 Mtetra
.1 .332 .804 r
.42869 .69112 .42962 .69271 .43123 .69322 .43028 .69233 Mtetra
.604 .739 .94 r
.43028 .69233 .43123 .69322 .43286 .69285 .43191 .69202 Mtetra
.711 .782 .907 r
.43191 .69202 .43286 .69285 .4345 .69221 .43355 .69128 Mtetra
.694 .757 .9 r
.43355 .69128 .4345 .69221 .43614 .69161 .43519 .69061 Mtetra
.652 .731 .908 r
.43519 .69061 .43614 .69161 .43778 .69114 .43683 .69013 Mtetra
.649 .73 .908 r
.43683 .69013 .43778 .69114 .43941 .69069 .43847 .68967 Mtetra
.637 .722 .91 r
.43847 .68967 .43941 .69069 .44105 .69034 .44011 .68926 Mtetra
.627 .707 .903 r
.44011 .68926 .44105 .69034 .44269 .69006 .44174 .68889 Mtetra
.629 .691 .889 r
.44174 .68889 .44269 .69006 .44432 .68978 .44338 .68852 Mtetra
.638 .679 .873 r
.44338 .68852 .44432 .68978 .44596 .68942 .44503 .68811 Mtetra
.647 .673 .861 r
.44503 .68811 .44596 .68942 .44761 .68899 .44667 .68765 Mtetra
.653 .672 .856 r
.44667 .68765 .44761 .68899 .44925 .6885 .44831 .68715 Mtetra
.662 .675 .852 r
.44831 .68715 .44925 .6885 .4509 .68793 .44996 .68661 Mtetra
.669 .682 .853 r
.44996 .68661 .4509 .68793 .45255 .68729 .45161 .68603 Mtetra
.671 .691 .86 r
.45161 .68603 .45255 .68729 .4542 .68665 .45326 .68544 Mtetra
.665 .698 .871 r
.45326 .68544 .4542 .68665 .45585 .68607 .45491 .6849 Mtetra
.655 .7 .88 r
.45491 .6849 .45585 .68607 .4575 .68559 .45656 .68441 Mtetra
.65 .697 .88 r
.45656 .68441 .4575 .68559 .45915 .68514 .45821 .68394 Mtetra
.637 .689 .882 r
.45821 .68394 .45915 .68514 .4608 .68481 .45986 .68352 Mtetra
.632 .673 .871 r
.45986 .68352 .4608 .68481 .46244 .68453 .46151 .68314 Mtetra
.651 .664 .849 r
.46151 .68314 .46244 .68453 .4641 .68397 .46317 .68265 Mtetra
.709 .695 .835 r
.46317 .68265 .4641 .68397 .46577 .68245 .46483 .6818 Mtetra
.805 .835 .874 r
.46483 .6818 .46577 .68245 .46747 .67916 .4665 .68052 Mtetra
0 0 0 r
.4665 .68052 .46747 .67916 .46922 .67258 .46817 .67909 Mtetra
.479 .219 .442 r
.46817 .67909 .46922 .67258 .47374 .487 .46984 .67797 Mtetra
.558 .343 .545 r
.46984 .67797 .47374 .487 .47533 .4849 .47149 .67745 Mtetra
.47149 .67745 .47533 .4849 .47686 .48655 .47315 .67713 Mtetra
.558 .344 .545 r
.47315 .67713 .47686 .48655 .47608 .65339 .4748 .67708 Mtetra
.556 .327 .524 r
.4748 .67708 .47608 .65339 .47758 .66397 .47646 .67707 Mtetra
.535 .297 .501 r
.47646 .67707 .47758 .66397 .47925 .66232 .47812 .67642 Mtetra
.469 .244 .489 r
.47812 .67642 .47925 .66232 .48319 .48075 .47982 .67338 Mtetra
0 0 .348 r
.47982 .67338 .48319 .48075 .48483 .47431 .48388 .47975 Mtetra
0 0 0 r
.48388 .47975 .48483 .47431 .48643 .47115 .48555 .47116 Mtetra
.942 .906 .758 r
.48555 .47116 .48643 .47115 .48802 .46947 .48714 .46859 Mtetra
.715 .765 .892 r
.48714 .46859 .48802 .46947 .48959 .46883 .48871 .46785 Mtetra
.611 .713 .917 r
.48871 .46785 .48959 .46883 .49115 .46846 .49028 .46755 Mtetra
.591 .721 .934 r
.49028 .46755 .49115 .46846 .49272 .46812 .49185 .4673 Mtetra
.657 .766 .93 r
.49185 .4673 .49272 .46812 .49429 .46762 .49342 .46682 Mtetra
.651 .77 .936 r
.49342 .46682 .49429 .46762 .49587 .46713 .49499 .46636 Mtetra
.64 .771 .943 r
.49499 .46636 .49587 .46713 .49744 .46672 .49657 .46593 Mtetra
.629 .764 .944 r
.49657 .46593 .49744 .46672 .49901 .46639 .49814 .46554 Mtetra
.635 .75 .931 r
.49814 .46554 .49901 .46639 .50059 .46605 .49972 .46514 Mtetra
.654 .743 .915 r
.49972 .46514 .50059 .46605 .50216 .46558 .50129 .46467 Mtetra
.678 .75 .905 r
.50129 .46467 .50216 .46558 .50374 .46493 .50287 .4641 Mtetra
.683 .771 .918 r
.50287 .4641 .50374 .46493 .50532 .46424 .50445 .46351 Mtetra
.677 .794 .937 r
.50445 .46351 .50532 .46424 .5069 .4636 .50603 .46294 Mtetra
.659 .809 .955 r
.50603 .46294 .5069 .4636 .50848 .46306 .50761 .46243 Mtetra
.653 .813 .96 r
.50761 .46243 .50848 .46306 .51006 .46255 .50919 .46193 Mtetra
.651 .815 .962 r
.50919 .46193 .51006 .46255 .51164 .46205 .51077 .46143 Mtetra
.652 .816 .962 r
.51077 .46143 .51164 .46205 .51322 .46154 .51236 .46093 Mtetra
.651 .818 .964 r
.51236 .46093 .51322 .46154 .51481 .46104 .51394 .46043 Mtetra
.65 .82 .965 r
.51394 .46043 .51481 .46104 .51639 .46053 .51552 .45992 Mtetra
.65 .822 .966 r
.51552 .45992 .51639 .46053 .51797 .46002 .51711 .45942 Mtetra
.65 .825 .967 r
.51711 .45942 .51797 .46002 .51956 .4595 .5187 .45892 Mtetra
.66 .83 .965 r
.5187 .45892 .51956 .4595 .52115 .45892 .52028 .45838 Mtetra
.677 .845 .963 r
.52028 .45838 .52115 .45892 .52274 .45821 .52187 .45777 Mtetra
.632 .866 .986 r
.52187 .45777 .52274 .45821 .52432 .45772 .52346 .45726 Mtetra
.526 .823 .999 r
.52346 .45726 .52432 .45772 .52591 .45786 .52505 .45698 Mtetra
.4 .647 .957 r
.52505 .45698 .52591 .45786 .52751 .45964 .52664 .45717 Mtetra
.512 .477 .755 r
.52664 .45717 .52751 .45964 .52911 .4639 .52824 .45753 Mtetra
.554 .403 .631 r
.52824 .45753 .52911 .4639 .53103 .65069 .52983 .45777 Mtetra
.56 .349 .551 r
.52983 .45777 .53103 .65069 .53273 .65263 .53143 .45735 Mtetra
.53143 .45735 .53273 .65263 .53441 .65084 .53302 .45672 Mtetra
.561 .349 .551 r
.53302 .45672 .53441 .65084 .53609 .64673 .53462 .45604 Mtetra
.56 .349 .551 r
.53462 .45604 .53609 .64673 .53778 .64572 .53622 .45549 Mtetra
.53622 .45549 .53778 .64572 .53947 .64465 .53782 .45495 Mtetra
.53782 .45495 .53947 .64465 .54116 .64365 .53942 .45442 Mtetra
.53942 .45442 .54116 .64365 .54285 .64299 .54102 .4539 Mtetra
.54102 .4539 .54285 .64299 .54454 .64256 .54262 .45339 Mtetra
.54262 .45339 .54454 .64256 .54624 .64238 .54422 .45289 Mtetra
.54422 .45289 .54624 .64238 .54794 .64249 .54583 .4524 Mtetra
.54583 .4524 .54794 .64249 .54964 .6426 .54743 .45192 Mtetra
.54743 .45192 .54964 .6426 .55135 .64354 .54904 .45147 Mtetra
.54904 .45147 .55135 .64354 .55307 .64638 .55064 .45115 Mtetra
.55064 .45115 .55307 .64638 .55478 .64614 .55225 .4507 Mtetra
.561 .349 .551 r
.55225 .4507 .55478 .64614 .55633 .6287 .55386 .44991 Mtetra
.562 .351 .551 r
.55386 .44991 .55633 .6287 .55634 .45293 .55546 .4485 Mtetra
.655 .498 .659 r
.55546 .4485 .55634 .45293 .55792 .44891 .55706 .44716 Mtetra
.719 .643 .773 r
.55706 .44716 .55792 .44891 .55951 .44667 .55866 .44606 Mtetra
.676 .83 .958 r
.55866 .44606 .55951 .44667 .56112 .44591 .56027 .44547 Mtetra
.606 .859 .991 r
.56027 .44547 .56112 .44591 .56273 .44548 .56189 .445 Mtetra
.593 .845 .992 r
.56189 .445 .56273 .44548 .56434 .44519 .5635 .44459 Mtetra
.65 .827 .968 r
.5635 .44459 .56434 .44519 .56596 .44467 .56511 .44407 Mtetra
.652 .826 .967 r
.56511 .44407 .56596 .44467 .56757 .44416 .56673 .44355 Mtetra
.653 .824 .965 r
.56673 .44355 .56757 .44416 .56918 .44365 .56834 .44302 Mtetra
.654 .821 .964 r
.56834 .44302 .56918 .44365 .5708 .44313 .56996 .4425 Mtetra
.655 .82 .962 r
.56996 .4425 .5708 .44313 .57242 .44262 .57158 .44197 Mtetra
.655 .818 .962 r
.57158 .44197 .57242 .44262 .57403 .4421 .5732 .44145 Mtetra
.655 .816 .961 r
.5732 .44145 .57403 .4421 .57565 .44158 .57481 .44093 Mtetra
.655 .815 .96 r
.57481 .44093 .57565 .44158 .57727 .44106 .57644 .44041 Mtetra
.655 .814 .96 r
.57644 .44041 .57727 .44106 .57889 .44055 .57806 .43989 Mtetra
.657 .813 .958 r
.57806 .43989 .57889 .44055 .58051 .44002 .57968 .43936 Mtetra
.654 .812 .959 r
.57968 .43936 .58051 .44002 .58214 .43952 .5813 .43884 Mtetra
.65 .808 .959 r
.5813 .43884 .58214 .43952 .58376 .43904 .58293 .43834 Mtetra
.632 .795 .961 r
.58293 .43834 .58376 .43904 .58539 .4387 .58455 .4379 Mtetra
.64 .773 .944 r
.58455 .4379 .58539 .4387 .58702 .43835 .58618 .43746 Mtetra
.653 .754 .924 r
.58618 .43746 .58702 .43835 .58864 .43794 .58781 .43698 Mtetra
.686 .748 .898 r
.58781 .43698 .58864 .43794 .59027 .43728 .58943 .43635 Mtetra
.691 .758 .902 r
.58943 .43635 .59027 .43728 .59189 .43657 .59106 .43571 Mtetra
.691 .772 .913 r
.59106 .43571 .59189 .43657 .59352 .43587 .59269 .43507 Mtetra
.747 .799 .895 r
.59269 .43507 .59352 .43587 .59514 .43509 .59431 .43415 Mtetra
.682 .754 .906 r
.59431 .43415 .59514 .43509 .59677 .43451 .59594 .43355 Mtetra
.518 .685 .943 r
.59594 .43355 .59677 .43451 .59841 .43429 .59758 .43352 Mtetra
.817 .355 0 r
.59758 .43352 .59841 .43429 .60009 .43559 .5993 .43652 Mtetra
.964 .681 .447 r
.5993 .43652 .60009 .43559 .6018 .43843 .60546 .63 Mtetra
.573 .355 .546 r
.60546 .63 .6018 .43843 .60371 .44929 .60742 .63912 Mtetra
.559 .344 .545 r
.60742 .63912 .60371 .44929 .60549 .45437 .60919 .63942 Mtetra
.557 .343 .545 r
.60919 .63942 .60549 .45437 .60699 .44791 .61093 .63879 Mtetra
.61093 .63879 .60699 .44791 .60872 .4507 .61266 .63786 Mtetra
.559 .344 .545 r
.61266 .63786 .60872 .4507 .61519 .63449 .61443 .63827 Mtetra
.565 .255 .402 r
.61443 .63827 .61519 .63449 .61704 .63825 .6162 .63869 Mtetra
.38 0 0 r
.6162 .63869 .61704 .63825 .61885 .63999 .61797 .63892 Mtetra
.607 .713 .92 r
.61797 .63892 .61885 .63999 .62061 .63993 .61972 .6386 Mtetra
.649 .681 .867 r
.61972 .6386 .62061 .63993 .62236 .6394 .62147 .6381 Mtetra
.666 .693 .866 r
.62147 .6381 .62236 .6394 .62411 .63865 .62322 .63751 Mtetra
.559 .68 .92 r
.62322 .63751 .62411 .63865 .62586 .63835 .62499 .63738 Mtetra
.621 .741 .932 r
.62499 .63738 .62586 .63835 .62762 .6379 .62675 .63699 Mtetra
.746 .789 .887 r
.62675 .63699 .62762 .6379 .62936 .63709 .62849 .63599 Mtetra
.913 .762 .681 r
.62849 .63599 .62936 .63709 .63106 .63467 .63013 .63195 Mtetra
.967 .687 .451 r
.63013 .63195 .63106 .63467 .6327 .63049 .62593 .4389 Mtetra
.581 .365 .552 r
.62593 .4389 .6327 .63049 .6341 .61862 .62721 .42668 Mtetra
.562 .351 .551 r
.62721 .42668 .6341 .61862 .63002 .43749 .62883 .425 Mtetra
.578 .391 .592 r
.62883 .425 .63002 .43749 .63168 .43691 .63048 .42447 Mtetra
.565 .382 .592 r
.63048 .42447 .63168 .43691 .63351 .44161 .63215 .42441 Mtetra
.58 .384 .58 r
.63215 .42441 .63351 .44161 .63501 .43628 .63379 .42348 Mtetra
.581 .393 .591 r
.63379 .42348 .63501 .43628 .63663 .43461 .63544 .4228 Mtetra
.562 .381 .594 r
.63544 .4228 .63663 .43461 .63851 .44016 .63712 .42288 Mtetra
.446 .285 .569 r
.63712 .42288 .63851 .44016 .64672 .62485 .63898 .42811 Mtetra
.015 0 .422 r
.63898 .42811 .64672 .62485 .64864 .62887 .64768 .62518 Mtetra
0 .016 .561 r
.64768 .62518 .64864 .62887 .6505 .63074 .64962 .62945 Mtetra
.376 .559 .905 r
.64962 .62945 .6505 .63074 .65229 .63085 .65142 .62993 Mtetra
.639 .759 .935 r
.65142 .62993 .65229 .63085 .65406 .6304 .6532 .62946 Mtetra
.72 .781 .901 r
.6532 .62946 .65406 .6304 .65582 .62971 .65496 .62862 Mtetra
.643 .725 .908 r
.65496 .62862 .65582 .62971 .65761 .62942 .65673 .62814 Mtetra
.638 .689 .881 r
.65673 .62814 .65761 .62942 .65938 .62905 .65851 .6277 Mtetra
.665 .687 .861 r
.65851 .6277 .65938 .62905 .66115 .62831 .66028 .6271 Mtetra
.691 .72 .871 r
.66028 .6271 .66115 .62831 .66287 .62637 .66205 .62637 Mtetra
.699 .979 .901 r
.66205 .62637 .66287 .62637 .66452 .62284 .6638 .62525 Mtetra
.151 0 .17 r
.6638 .62525 .66452 .62284 .66593 .61338 .66552 .62334 Mtetra
.245 .06 .42 r
.66552 .62334 .66593 .61338 .65971 .42052 .66704 .61663 Mtetra
.02 0 .419 r
.66704 .61663 .65971 .42052 .66122 .41633 .66055 .41845 Mtetra
.706 .742 .232 r
.66055 .41845 .66122 .41633 .66282 .41407 .66203 .41357 Mtetra
.841 .89 .875 r
.66203 .41357 .66282 .41407 .66448 .41314 .66367 .41214 Mtetra
.644 .731 .912 r
.66367 .41214 .66448 .41314 .66616 .41279 .66534 .41169 Mtetra
.547 .668 .917 r
.66534 .41169 .66616 .41279 .66785 .41267 .66704 .4116 Mtetra
.619 .708 .909 r
.66704 .4116 .66785 .41267 .66953 .41231 .66872 .41126 Mtetra
.655 .726 .902 r
.66872 .41126 .66953 .41231 .6712 .41178 .6704 .41076 Mtetra
.664 .735 .903 r
.6704 .41076 .6712 .41178 .67288 .41119 .67207 .41022 Mtetra
.701 .759 .897 r
.67207 .41022 .67288 .41119 .67454 .41027 .67374 .40951 Mtetra
.706 .809 .929 r
.67374 .40951 .67454 .41027 .6762 .4094 .67541 .40879 Mtetra
.665 .836 .965 r
.67541 .40879 .6762 .4094 .67788 .40888 .67709 .40819 Mtetra
.61 .799 .972 r
.67709 .40819 .67788 .40888 .67961 .4095 .67878 .40779 Mtetra
.561 .578 .828 r
.67878 .40779 .67961 .4095 .68143 .41168 .68048 .40777 Mtetra
.503 .413 .686 r
.68048 .40777 .68143 .41168 .68356 .42031 .68223 .40849 Mtetra
.397 .263 .58 r
.68223 .40849 .68356 .42031 .69477 .6123 .68418 .41342 Mtetra
.046 0 .438 r
.68418 .41342 .69477 .6123 .69676 .61577 .69574 .61121 Mtetra
.066 .108 .595 r
.69574 .61121 .69676 .61577 .69866 .61724 .69778 .61562 Mtetra
.354 .487 .855 r
.69778 .61562 .69866 .61724 .7005 .61742 .69965 .61637 Mtetra
.634 .734 .92 r
.69965 .61637 .7005 .61742 .7023 .61696 .70145 .61592 Mtetra
.717 .765 .891 r
.70145 .61592 .7023 .61696 .70409 .61624 .70324 .61507 Mtetra
.666 .722 .891 r
.70324 .61507 .70409 .61624 .7059 .61583 .70504 .61448 Mtetra
.638 .679 .873 r
.70504 .61448 .7059 .61583 .70771 .61546 .70684 .61403 Mtetra
.661 .675 .853 r
.70684 .61403 .70771 .61546 .70951 .61477 .70865 .61344 Mtetra
.687 .703 .859 r
.70865 .61344 .70951 .61477 .71125 .61301 .71044 .61271 Mtetra
.751 .946 .944 r
.71044 .61271 .71125 .61301 .7129 .6097 .71222 .61163 Mtetra
.075 0 .081 r
.71222 .61163 .7129 .6097 .7143 .60187 .71396 .6098 Mtetra
.237 .044 .404 r
.71396 .6098 .7143 .60187 .70523 .40666 .71548 .60421 Mtetra
.046 0 .434 r
.71548 .60421 .70523 .40666 .7067 .402 .70612 .40474 Mtetra
0 0 0 r
.70612 .40474 .7067 .402 .70829 .39954 .70754 .39921 Mtetra
.894 .923 .832 r
.70754 .39921 .70829 .39954 .70995 .3983 .70916 .39735 Mtetra
.684 .759 .909 r
.70916 .39735 .70995 .3983 .71164 .3977 .71085 .39671 Mtetra
.584 .712 .931 r
.71085 .39671 .71164 .3977 .71335 .39737 .71257 .39647 Mtetra
.593 .738 .945 r
.71257 .39647 .71335 .39737 .71507 .39706 .71429 .39618 Mtetra
.628 .757 .94 r
.71429 .39618 .71507 .39706 .71678 .39671 .716 .39576 Mtetra
.634 .743 .927 r
.716 .39576 .71678 .39671 .71849 .39634 .71771 .39534 Mtetra
.659 .741 .911 r
.71771 .39534 .71849 .39634 .7202 .39578 .71942 .39481 Mtetra
.678 .756 .91 r
.71942 .39481 .7202 .39578 .72189 .39507 .72112 .3942 Mtetra
.682 .779 .924 r
.72112 .3942 .72189 .39507 .72359 .39434 .72282 .39357 Mtetra
.672 .801 .944 r
.72282 .39357 .72359 .39434 .72529 .39368 .72452 .39297 Mtetra
.658 .813 .958 r
.72452 .39297 .72529 .39368 .72699 .3931 .72623 .39241 Mtetra
.654 .818 .962 r
.72623 .39241 .72699 .3931 .7287 .39255 .72794 .39186 Mtetra
.67 .825 .958 r
.72794 .39186 .7287 .39255 .7304 .39185 .72965 .39125 Mtetra
.666 .848 .969 r
.72965 .39125 .7304 .39185 .7321 .39115 .73136 .39064 Mtetra
.615 .856 .989 r
.73136 .39064 .7321 .39115 .73382 .39073 .73307 .39013 Mtetra
.477 .772 .996 r
.73307 .39013 .73382 .39073 .73561 .39133 .73481 .39 Mtetra
.472 .588 .889 r
.73481 .39 .73561 .39133 .73751 .39362 .73658 .39024 Mtetra
.53 .449 .708 r
.73658 .39024 .73751 .39362 .73971 .40019 .73836 .39062 Mtetra
.564 .392 .606 r
.73836 .39062 .73971 .40019 .75416 .58914 .74012 .39065 Mtetra
.56 .349 .551 r
.74012 .39065 .75416 .58914 .75606 .58965 .74184 .39014 Mtetra
.74184 .39014 .75606 .58965 .75778 .58743 .74355 .38946 Mtetra
.74355 .38946 .75778 .58743 .75947 .58499 .74526 .38881 Mtetra
.74526 .38881 .75947 .58499 .7613 .58439 .74699 .38825 Mtetra
.74699 .38825 .7613 .58439 .76315 .58417 .74871 .38771 Mtetra
.74871 .38771 .76315 .58417 .76509 .58511 .75044 .38725 Mtetra
.75044 .38725 .76509 .58511 .76705 .5864 .75218 .38686 Mtetra
.75218 .38686 .76705 .5864 .76897 .58704 .75392 .38644 Mtetra
.75392 .38644 .76897 .58704 .77082 .58655 .75564 .3859 Mtetra
.75564 .3859 .77082 .58655 .77257 .58487 .75736 .3852 Mtetra
.561 .349 .551 r
.75736 .3852 .77257 .58487 .77428 .58249 .75908 .38449 Mtetra
.56 .349 .551 r
.75908 .38449 .77428 .58249 .77612 .58204 .76081 .38392 Mtetra
.76081 .38392 .77612 .58204 .77809 .58315 .76255 .38347 Mtetra
.76255 .38347 .77809 .58315 .77987 .58177 .76428 .38288 Mtetra
.561 .35 .551 r
.76428 .38288 .77987 .58177 .76743 .39191 .76597 .38178 Mtetra
.609 .42 .602 r
.76597 .38178 .76743 .39191 .76859 .38382 .76764 .38028 Mtetra
.674 .532 .684 r
.76764 .38028 .76859 .38382 .77011 .38038 .76931 .37892 Mtetra
.718 .689 .821 r
.76931 .37892 .77011 .38038 .77175 .37869 .77102 .37796 Mtetra
.654 .812 .959 r
.77102 .37796 .77175 .37869 .77349 .37813 .77275 .3774 Mtetra
.625 .801 .967 r
.77275 .3774 .77349 .37813 .77525 .37785 .7745 .37695 Mtetra
.696 .78 .916 r
.7745 .37695 .77525 .37785 .77699 .37734 .77623 .37624 Mtetra
.737 .753 .866 r
.77623 .37624 .77699 .37734 .7787 .37642 .77793 .37528 Mtetra
.67 .722 .888 r
.77793 .37528 .7787 .37642 .78043 .37572 .77967 .37469 Mtetra
.275 .54 .92 r
.77967 .37469 .78043 .37572 .78221 .37568 .78151 .37529 Mtetra
.843 .383 0 r
.78151 .37529 .78221 .37568 .78409 .37681 .7836 .37906 Mtetra
.973 .67 .371 r
.7836 .37906 .78409 .37681 .78611 .37957 .80156 .57772 Mtetra
.567 .35 .545 r
.80156 .57772 .78611 .37957 .80312 .56483 .80392 .58331 Mtetra
.566 .329 .516 r
.80392 .58331 .80312 .56483 .80635 .58102 .80589 .58406 Mtetra
.512 .184 .347 r
.80589 .58406 .80635 .58102 .80849 .58379 .8078 .58397 Mtetra
0 0 0 r
.8078 .58397 .80849 .58379 .81047 .58457 .80967 .58352 Mtetra
.658 .749 .917 r
.80967 .58352 .81047 .58457 .81235 .58413 .81154 .58294 Mtetra
.68 .731 .888 r
.81154 .58294 .81235 .58413 .8142 .58332 .8134 .58225 Mtetra
.667 .75 .912 r
.8134 .58225 .8142 .58332 .81605 .58252 .81527 .58164 Mtetra
.61 .77 .957 r
.81527 .58164 .81605 .58252 .81793 .58205 .81715 .58123 Mtetra
.587 .775 .969 r
.81715 .58123 .81793 .58205 .81982 .58166 .81904 .58087 Mtetra
.505 .746 .982 r
.81904 .58087 .81982 .58166 .82172 .58151 .82095 .58074 Mtetra
.404 .7 .981 r
.82095 .58074 .82172 .58151 .82366 .58161 .82289 .58084 Mtetra
.589 .791 .976 r
.82289 .58084 .82366 .58161 .82556 .58139 .82478 .58046 Mtetra
.837 .824 .836 r
.82478 .58046 .82556 .58139 .8274 .58039 .82656 .57874 Mtetra
.932 .735 .614 r
.82656 .57874 .8274 .58039 .82911 .57784 .82796 .57286 Mtetra
.975 .676 .377 r
.82796 .57286 .82911 .57784 .83061 .57307 .81184 .37193 Mtetra
.568 .355 .551 r
.81184 .37193 .83061 .57307 .81483 .37767 .81317 .36647 Mtetra
.607 .416 .597 r
.81317 .36647 .81483 .37767 .81587 .36914 .81483 .36484 Mtetra
.634 .489 .668 r
.81483 .36484 .81587 .36914 .8174 .36594 .81656 .36388 Mtetra
.655 .596 .777 r
.81656 .36388 .8174 .36594 .81905 .36418 .81832 .36322 Mtetra
.672 .762 .918 r
.81832 .36322 .81905 .36418 .8208 .36344 .82008 .36261 Mtetra
.643 .784 .949 r
.82008 .36261 .8208 .36344 .82258 .36301 .82185 .36211 Mtetra
.68 .78 .926 r
.82185 .36211 .82258 .36301 .82435 .3625 .82361 .36147 Mtetra
.748 .775 .874 r
.82361 .36147 .82435 .3625 .82608 .36149 .82534 .36045 Mtetra
.667 .744 .908 r
.82534 .36045 .82608 .36149 .82784 .36092 .82711 .35987 Mtetra
.258 .523 .912 r
.82711 .35987 .82784 .36092 .82973 .36161 .82899 .36054 Mtetra
.874 .479 .017 r
.82899 .36054 .82973 .36161 .83223 .36856 .83148 .3674 Mtetra
.975 .667 .334 r
.83148 .3674 .83223 .36856 .85354 .56957 .85276 .56853 Mtetra
.649 .202 0 r
.85276 .56853 .85354 .56957 .85582 .57304 .85505 .57202 Mtetra
.389 .628 .949 r
.85505 .57202 .85582 .57304 .85781 .57335 .85703 .57233 Mtetra
.696 .776 .913 r
.85703 .57233 .85781 .57335 .85969 .57258 .85891 .57156 Mtetra
.875 .814 .786 r
.85891 .57156 .85969 .57258 .86142 .57033 .86065 .56929 Mtetra
.978 .76 .54 r
.86065 .56929 .86142 .57033 .86257 .56226 .86179 .5611 Mtetra
.977 .675 .348 r
.86179 .5611 .86257 .56226 .84421 .35973 .84347 .35861 Mtetra
.942 .78 .651 r
.84347 .35861 .84421 .35973 .84561 .35544 .84488 .35436 Mtetra
.741 .764 .871 r
.84488 .35436 .84561 .35544 .84735 .35445 .84662 .35337 Mtetra
.619 .716 .915 r
.84662 .35337 .84735 .35445 .84915 .35408 .84842 .35299 Mtetra
.588 .702 .922 r
.84842 .35299 .84915 .35408 .85097 .35382 .85024 .35274 Mtetra
.743 .766 .872 r
.85024 .35274 .85097 .35382 .85271 .35281 .85198 .35174 Mtetra
.671 .741 .903 r
.85198 .35174 .85271 .35281 .85449 .3522 .85376 .35113 Mtetra
.379 .594 .929 r
.85376 .35113 .85449 .3522 .85638 .35259 .85565 .35152 Mtetra
.798 .384 0 r
.85565 .35152 .85638 .35259 .85878 .35786 .85805 .35678 Mtetra
.973 .663 .318 r
.85805 .35678 .85878 .35786 .88199 .56022 .88123 .55921 Mtetra
.721 .281 0 r
.88123 .55921 .88199 .56022 .88441 .56441 .88365 .56341 Mtetra
.501 .694 .955 r
.88365 .56341 .88441 .56441 .88638 .56439 .88563 .56339 Mtetra
.695 .781 .917 r
.88563 .56339 .88638 .56439 .88828 .56362 .88752 .56262 Mtetra
.736 .795 .899 r
.88752 .56262 .88828 .56362 .89015 .56264 .8894 .56163 Mtetra
.498 .691 .954 r
.8894 .56163 .89015 .56264 .89214 .56264 .89138 .56162 Mtetra
.627 .751 .936 r
.89138 .56162 .89214 .56264 .89407 .56218 .89331 .56116 Mtetra
.811 .811 .851 r
.89331 .56116 .89407 .56218 .89589 .56067 .89513 .55963 Mtetra
.979 .769 .55 r
.89513 .55963 .89589 .56067 .89707 .55336 .89631 .55224 Mtetra
.976 .671 .329 r
.89631 .55224 .89707 .55336 .87652 .35003 .87579 .3489 Mtetra
.954 .779 .628 r
.87579 .3489 .87652 .35003 .87785 .34527 .87713 .34417 Mtetra
.74 .764 .873 r
.87713 .34417 .87785 .34527 .87961 .34428 .87889 .34318 Mtetra
.606 .709 .917 r
.87889 .34318 .87961 .34428 .88144 .34395 .88072 .34286 Mtetra
.52 .666 .928 r
.88072 .34286 .88144 .34395 .88331 .34395 .88259 .34284 Mtetra
.647 .727 .907 r
.88259 .34284 .88331 .34395 .88512 .34343 .8844 .34234 Mtetra
.652 .731 .907 r
.8844 .34234 .88512 .34343 .88693 .3429 .88621 .34182 Mtetra
.664 .739 .906 r
.88621 .34182 .88693 .3429 .88873 .3423 .88802 .34123 Mtetra
.759 .778 .869 r
.88802 .34123 .88873 .3423 .89048 .34117 .88977 .34013 Mtetra
.691 .759 .904 r
.88977 .34013 .89048 .34117 .89227 .34045 .89156 .33942 Mtetra
.47 .656 .942 r
.89156 .33942 .89227 .34045 .89416 .34056 .89345 .33954 Mtetra
.795 .382 0 r
.89345 .33954 .89416 .34056 .89671 .34628 .89598 .34507 Mtetra
.971 .656 .294 r
.89598 .34507 .89671 .34628 .92256 .54951 .92179 .54823 Mtetra
.623 .214 0 r
.92179 .54823 .92256 .54951 .92507 .55372 .92431 .55253 Mtetra
.54 .673 .924 r
.92431 .55253 .92507 .55372 .92706 .55358 .92631 .55245 Mtetra
.705 .762 .896 r
.92631 .55245 .92706 .55358 .92896 .55266 .92822 .55161 Mtetra
.774 .801 .874 r
.92822 .55161 .92896 .55266 .93082 .55132 .93009 .55036 Mtetra
.629 .82 .973 r
.30322 .72651 .30423 .72707 .30579 .72666 .30478 .72607 Mtetra
.67 .82 .955 r
.30478 .72607 .30579 .72666 .30735 .72622 .30634 .72551 Mtetra
.683 .794 .934 r
.30634 .72551 .30735 .72622 .30892 .72566 .30791 .72492 Mtetra
.369 .678 .977 r
.30791 .72492 .30892 .72566 .31049 .72506 .30944 .72507 Mtetra
.209 .734 .826 r
.30944 .72507 .31049 .72506 .31209 .72403 .31099 .72485 Mtetra
0 0 0 r
.31099 .72485 .31209 .72403 .31374 .72214 .31259 .72392 Mtetra
.984 .9 .58 r
.31259 .72392 .31374 .72214 .3158 .71332 .31444 .71853 Mtetra
.945 .695 .528 r
.31444 .71853 .3158 .71332 .32846 .52365 .32744 .52428 Mtetra
.974 .822 .631 r
.32744 .52428 .32846 .52365 .33015 .51963 .32923 .51857 Mtetra
.758 .725 .821 r
.32923 .51857 .33015 .51963 .33166 .51863 .33075 .51748 Mtetra
.621 .672 .877 r
.33075 .51748 .33166 .51863 .33314 .51826 .33222 .51718 Mtetra
.497 .636 .916 r
.33222 .51718 .33314 .51826 .3346 .51819 .33367 .51725 Mtetra
.648 .723 .903 r
.33367 .51725 .3346 .51819 .33608 .51766 .33515 .51684 Mtetra
.668 .756 .917 r
.33515 .51684 .33608 .51766 .33757 .51712 .33664 .51635 Mtetra
.677 .768 .92 r
.33664 .51635 .33757 .51712 .33905 .5167 .33812 .51582 Mtetra
.763 .758 .848 r
.33812 .51582 .33905 .5167 .34053 .51633 .33964 .51478 Mtetra
.69 .642 .797 r
.33964 .51478 .34053 .51633 .34199 .51632 .34114 .51404 Mtetra
.583 .525 .756 r
.34114 .51404 .34199 .51632 .34342 .51706 .34261 .51394 Mtetra
0 0 .438 r
.34261 .51394 .34342 .51706 .34455 .52313 .34388 .51744 Mtetra
.947 .691 .515 r
.34388 .51744 .34455 .52313 .33584 .7136 .33496 .71072 Mtetra
.896 .575 .08 r
.33496 .71072 .33584 .7136 .33719 .71741 .33619 .71673 Mtetra
.055 .512 .892 r
.33619 .71673 .33719 .71741 .33872 .71785 .33772 .71723 Mtetra
.666 .817 .956 r
.33772 .71723 .33872 .71785 .3403 .71741 .3393 .71668 Mtetra
.757 .802 .889 r
.3393 .71668 .3403 .71741 .3419 .7165 .34091 .71572 Mtetra
.467 .713 .976 r
.34091 .71572 .3419 .7165 .34349 .71583 .34247 .71571 Mtetra
.261 .76 .895 r
.34247 .71571 .34349 .71583 .3451 .71484 .34404 .71555 Mtetra
0 0 0 r
.34404 .71555 .3451 .71484 .34675 .71307 .34564 .7147 Mtetra
.963 .92 .577 r
.34564 .7147 .34675 .71307 .34866 .70608 .34744 .71013 Mtetra
.947 .694 .521 r
.34744 .71013 .34866 .70608 .35971 .51438 .35868 .51568 Mtetra
.992 .839 .587 r
.35868 .51568 .35971 .51438 .36141 .50988 .36049 .50889 Mtetra
.798 .744 .803 r
.36049 .50889 .36141 .50988 .36295 .5086 .36204 .50744 Mtetra
.64 .68 .872 r
.36204 .50744 .36295 .5086 .36444 .50815 .36353 .50706 Mtetra
.517 .644 .913 r
.36353 .50706 .36444 .50815 .36592 .50804 .36501 .50709 Mtetra
.705 .738 .877 r
.36501 .50709 .36592 .50804 .36744 .50724 .36652 .50641 Mtetra
.701 .762 .9 r
.36652 .50641 .36744 .50724 .36895 .50656 .36803 .50577 Mtetra
.544 .727 .959 r
.36803 .50577 .36895 .50656 .37043 .50649 .36951 .50563 Mtetra
.819 .35 0 r
.36951 .50563 .37043 .50649 .37176 .50979 .37089 .50795 Mtetra
.945 .685 .512 r
.37089 .50795 .37176 .50979 .36444 .70334 .3639 .69298 Mtetra
0 0 .203 r
.3639 .69298 .36444 .70334 .36574 .70941 .36487 .70623 Mtetra
.318 .317 .701 r
.36487 .70623 .36574 .70941 .36728 .7101 .36637 .70775 Mtetra
.547 .511 .768 r
.36637 .70775 .36728 .7101 .36889 .70951 .36794 .70788 Mtetra
.628 .618 .821 r
.36794 .70788 .36889 .70951 .37051 .70845 .36954 .70751 Mtetra
.506 .688 .95 r
.36954 .70751 .37051 .70845 .3721 .70817 .37112 .70749 Mtetra
.567 .778 .978 r
.37112 .70749 .3721 .70817 .37369 .7079 .37271 .70723 Mtetra
.763 .819 .897 r
.37271 .70723 .37369 .7079 .37531 .70696 .37433 .70624 Mtetra
.913 .759 .677 r
.37433 .70624 .37531 .70696 .37709 .70243 .37611 .70178 Mtetra
.944 .688 .519 r
.37611 .70178 .37709 .70243 .38676 .50742 .38583 .50686 Mtetra
.933 .745 .625 r
.38583 .50686 .38676 .50742 .38852 .50096 .3876 .50018 Mtetra
.83 .783 .807 r
.3876 .50018 .38852 .50096 .39008 .4993 .38916 .49855 Mtetra
.635 .768 .944 r
.38916 .49855 .39008 .4993 .39159 .49884 .39067 .49816 Mtetra
.422 .709 .983 r
.39067 .49816 .39159 .49884 .39309 .49879 .39217 .4982 Mtetra
.532 .781 .989 r
.39217 .4982 .39309 .49879 .3946 .49854 .39367 .498 Mtetra
.601 .82 .984 r
.39367 .498 .3946 .49854 .39611 .49814 .39518 .49764 Mtetra
.605 .828 .985 r
.39518 .49764 .39611 .49814 .39762 .49774 .3967 .49725 Mtetra
.613 .835 .985 r
.3967 .49725 .39762 .49774 .39914 .49731 .39821 .49684 Mtetra
.622 .842 .984 r
.39821 .49684 .39914 .49731 .40066 .49686 .39973 .4964 Mtetra
.63 .848 .983 r
.39973 .4964 .40066 .49686 .40218 .49639 .40125 .49593 Mtetra
.64 .852 .981 r
.40125 .49593 .40218 .49639 .4037 .49582 .40277 .49544 Mtetra
.639 .871 .985 r
.40277 .49544 .4037 .49582 .40522 .49526 .4043 .49492 Mtetra
.643 .883 .985 r
.4043 .49492 .40522 .49526 .40675 .49482 .40582 .49437 Mtetra
.675 .862 .971 r
.40582 .49437 .40675 .49482 .40825 .49479 .40735 .49378 Mtetra
.689 .726 .878 r
.40735 .49378 .40825 .49479 .40975 .49511 .40888 .49317 Mtetra
.658 .593 .771 r
.40888 .49317 .40975 .49511 .41124 .49553 .41041 .49256 Mtetra
.63 .519 .708 r
.41041 .49256 .41124 .49553 .41276 .49549 .41194 .49198 Mtetra
.619 .494 .688 r
.41194 .49198 .41276 .49549 .41429 .49497 .41347 .49143 Mtetra
.618 .492 .687 r
.41347 .49143 .41429 .49497 .41582 .49429 .415 .4909 Mtetra
.619 .497 .692 r
.415 .4909 .41582 .49429 .41736 .49369 .41653 .49038 Mtetra
.619 .5 .695 r
.41653 .49038 .41736 .49369 .41889 .49317 .41806 .48986 Mtetra
.619 .5 .696 r
.41806 .48986 .41889 .49317 .42042 .49265 .41959 .48935 Mtetra
.619 .501 .696 r
.41959 .48935 .42042 .49265 .42195 .49212 .42113 .48883 Mtetra
.62 .501 .697 r
.42113 .48883 .42195 .49212 .42349 .49159 .42266 .48832 Mtetra
.619 .502 .697 r
.42266 .48832 .42349 .49159 .42502 .49107 .42419 .48781 Mtetra
.639 .514 .695 r
.42419 .48781 .42502 .49107 .42657 .4902 .42574 .48707 Mtetra
.639 .519 .701 r
.42574 .48707 .42657 .4902 .42811 .48937 .42728 .48636 Mtetra
.599 .499 .711 r
.42728 .48636 .42811 .48937 .42964 .48921 .42881 .48609 Mtetra
.321 .315 .696 r
.42881 .48609 .42964 .48921 .43108 .4922 .43029 .48761 Mtetra
.751 .512 0 r
.43029 .48761 .43108 .4922 .42723 .68543 .43159 .49569 Mtetra
0 0 .328 r
.43159 .49569 .42723 .68543 .42869 .69112 .42781 .68736 Mtetra
.262 .256 .664 r
.42781 .68736 .42869 .69112 .43028 .69233 .42937 .68952 Mtetra
.598 .515 .732 r
.42937 .68952 .43028 .69233 .43191 .69202 .431 .68928 Mtetra
.661 .555 .724 r
.431 .68928 .43191 .69202 .43355 .69128 .43265 .68841 Mtetra
.648 .542 .72 r
.43265 .68841 .43355 .69128 .43519 .69061 .43429 .68764 Mtetra
.621 .521 .72 r
.43429 .68764 .43519 .69061 .43683 .69013 .43593 .68716 Mtetra
.43593 .68716 .43683 .69013 .43847 .68967 .43757 .68668 Mtetra
.62 .52 .719 r
.43757 .68668 .43847 .68967 .44011 .68926 .43921 .6862 Mtetra
.618 .516 .716 r
.43921 .6862 .44011 .68926 .44174 .68889 .44085 .68574 Mtetra
.616 .511 .712 r
.44085 .68574 .44174 .68889 .44338 .68852 .44249 .68528 Mtetra
.622 .511 .707 r
.44249 .68528 .44338 .68852 .44503 .68811 .44414 .68474 Mtetra
.623 .507 .701 r
.44414 .68474 .44503 .68811 .44667 .68765 .44578 .68417 Mtetra
.61 .496 .699 r
.44578 .68417 .44667 .68765 .44831 .68715 .44742 .68374 Mtetra
.571 .474 .705 r
.44742 .68374 .44831 .68715 .44996 .68661 .44906 .68371 Mtetra
.533 .472 .733 r
.44906 .68371 .44996 .68661 .45161 .68603 .45069 .68399 Mtetra
.527 .528 .8 r
.45069 .68399 .45161 .68603 .45326 .68544 .45232 .68418 Mtetra
.571 .652 .891 r
.45232 .68418 .45326 .68544 .45491 .6849 .45397 .68405 Mtetra
.639 .763 .937 r
.45397 .68405 .45491 .6849 .45656 .68441 .45562 .6836 Mtetra
.663 .781 .936 r
.45562 .6836 .45656 .68441 .45821 .68394 .45727 .68307 Mtetra
.661 .765 .927 r
.45727 .68307 .45821 .68394 .45986 .68352 .45892 .68255 Mtetra
.648 .737 .914 r
.45892 .68255 .45986 .68352 .46151 .68314 .46057 .68208 Mtetra
.645 .719 .902 r
.46057 .68208 .46151 .68314 .46317 .68265 .46223 .68163 Mtetra
.634 .725 .913 r
.46223 .68163 .46317 .68265 .46483 .6818 .46388 .68123 Mtetra
.587 .817 .987 r
.46388 .68123 .46483 .6818 .4665 .68052 .46554 .68086 Mtetra
0 0 0 r
.46554 .68086 .4665 .68052 .46817 .67909 .46719 .68048 Mtetra
.342 0 .086 r
.46719 .68048 .46817 .67909 .46984 .67797 .46885 .68005 Mtetra
.408 .044 .232 r
.46885 .68005 .46984 .67797 .47149 .67745 .47051 .67955 Mtetra
.405 .042 .232 r
.47051 .67955 .47149 .67745 .47315 .67713 .47217 .67903 Mtetra
.432 .055 .221 r
.47217 .67903 .47315 .67713 .4748 .67708 .47383 .67871 Mtetra
.444 .047 .19 r
.47383 .67871 .4748 .67708 .47646 .67707 .47549 .67855 Mtetra
.301 0 .079 r
.47549 .67855 .47646 .67707 .47812 .67642 .47715 .67795 Mtetra
0 0 0 r
.47715 .67795 .47812 .67642 .47982 .67338 .47884 .67585 Mtetra
.946 .859 .435 r
.47884 .67585 .47982 .67338 .48388 .47975 .48059 .66894 Mtetra
0 0 .335 r
.48059 .66894 .48388 .47975 .48555 .47116 .48463 .47346 Mtetra
0 0 0 r
.48463 .47346 .48555 .47116 .48714 .46859 .48624 .46947 Mtetra
.48624 .46947 .48714 .46859 .48871 .46785 .48782 .46862 Mtetra
.296 0 0 r
.48782 .46862 .48871 .46785 .49028 .46755 .48939 .46842 Mtetra
.38 0 0 r
.48939 .46842 .49028 .46755 .49185 .4673 .49095 .46834 Mtetra
.299 0 0 r
.49095 .46834 .49185 .4673 .49342 .46682 .49253 .46798 Mtetra
.285 0 .014 r
.49253 .46798 .49342 .46682 .49499 .46636 .4941 .4675 Mtetra
.128 0 0 r
.4941 .4675 .49499 .46636 .49657 .46593 .49568 .4667 Mtetra
0 0 0 r
.49568 .4667 .49657 .46593 .49814 .46554 .49726 .4655 Mtetra
.778 .975 .915 r
.49726 .4655 .49814 .46554 .49972 .46514 .49884 .46437 Mtetra
.747 .798 .894 r
.49884 .46437 .49972 .46514 .50129 .46467 .50042 .46348 Mtetra
.67 .693 .863 r
.50042 .46348 .50129 .46467 .50287 .4641 .502 .46293 Mtetra
.651 .689 .873 r
.502 .46293 .50287 .4641 .50445 .46351 .50358 .46247 Mtetra
.648 .714 .896 r
.50358 .46247 .50445 .46351 .50603 .46294 .50516 .46203 Mtetra
.661 .745 .912 r
.50516 .46203 .50603 .46294 .50761 .46243 .50674 .46153 Mtetra
.66 .749 .916 r
.50674 .46153 .50761 .46243 .50919 .46193 .50832 .46104 Mtetra
.66 .751 .917 r
.50832 .46104 .50919 .46193 .51077 .46143 .5099 .46054 Mtetra
.661 .752 .918 r
.5099 .46054 .51077 .46143 .51236 .46093 .51149 .46004 Mtetra
.658 .752 .919 r
.51149 .46004 .51236 .46093 .51394 .46043 .51307 .45955 Mtetra
.652 .753 .924 r
.51307 .45955 .51394 .46043 .51552 .45992 .51466 .45909 Mtetra
.64 .758 .934 r
.51466 .45909 .51552 .45992 .51711 .45942 .51624 .45866 Mtetra
.636 .777 .948 r
.51624 .45866 .51711 .45942 .5187 .45892 .51783 .45824 Mtetra
.639 .798 .959 r
.51783 .45824 .5187 .45892 .52028 .45838 .51942 .45779 Mtetra
.649 .825 .968 r
.51942 .45779 .52028 .45838 .52187 .45777 .52101 .45728 Mtetra
.649 .853 .978 r
.52101 .45728 .52187 .45777 .52346 .45726 .5226 .45674 Mtetra
.662 .851 .972 r
.5226 .45674 .52346 .45726 .52505 .45698 .52419 .45617 Mtetra
.686 .78 .922 r
.52419 .45617 .52505 .45698 .52664 .45717 .52578 .45557 Mtetra
.667 .635 .808 r
.52578 .45557 .52664 .45717 .52824 .45753 .52738 .45496 Mtetra
.638 .544 .732 r
.52738 .45496 .52824 .45753 .52983 .45777 .52897 .45436 Mtetra
.621 .5 .694 r
.52897 .45436 .52983 .45777 .53143 .45735 .53056 .4538 Mtetra
.618 .494 .689 r
.53056 .4538 .53143 .45735 .53302 .45672 .53216 .45326 Mtetra
.618 .497 .692 r
.53216 .45326 .53302 .45672 .53462 .45604 .53376 .45272 Mtetra
.62 .502 .698 r
.53376 .45272 .53462 .45604 .53622 .45549 .53535 .45219 Mtetra
.619 .503 .699 r
.53535 .45219 .53622 .45549 .53782 .45495 .53695 .45167 Mtetra
.53695 .45167 .53782 .45495 .53942 .45442 .53855 .45115 Mtetra
.619 .503 .7 r
.53855 .45115 .53942 .45442 .54102 .4539 .54015 .45063 Mtetra
.618 .503 .7 r
.54015 .45063 .54102 .4539 .54262 .45339 .54175 .45012 Mtetra
.54175 .45012 .54262 .45339 .54422 .45289 .54335 .44961 Mtetra
.617 .502 .7 r
.54335 .44961 .54422 .45289 .54583 .4524 .54496 .44911 Mtetra
.617 .501 .699 r
.54496 .44911 .54583 .4524 .54743 .45192 .54656 .44861 Mtetra
.616 .5 .699 r
.54656 .44861 .54743 .45192 .54904 .45147 .54817 .44812 Mtetra
.615 .498 .697 r
.54817 .44812 .54904 .45147 .55064 .45115 .54977 .44763 Mtetra
.612 .491 .691 r
.54977 .44763 .55064 .45115 .55225 .4507 .55138 .44715 Mtetra
.61 .49 .69 r
.55138 .44715 .55225 .4507 .55386 .44991 .55299 .4467 Mtetra
.611 .5 .704 r
.55299 .4467 .55386 .44991 .55546 .4485 .5546 .44628 Mtetra
.624 .559 .761 r
.5546 .44628 .55546 .4485 .55706 .44716 .55621 .44587 Mtetra
.642 .668 .86 r
.55621 .44587 .55706 .44716 .55866 .44606 .55782 .44544 Mtetra
.637 .816 .969 r
.55782 .44544 .55866 .44606 .56027 .44547 .55943 .44497 Mtetra
.632 .85 .983 r
.55943 .44497 .56027 .44547 .56189 .445 .56104 .44447 Mtetra
.649 .845 .975 r
.56104 .44447 .56189 .445 .5635 .44459 .56266 .44393 Mtetra
.676 .82 .952 r
.56266 .44393 .5635 .44459 .56511 .44407 .56427 .44334 Mtetra
.682 .802 .939 r
.56427 .44334 .56511 .44407 .56673 .44355 .56588 .44274 Mtetra
.681 .781 .926 r
.56588 .44274 .56673 .44355 .56834 .44302 .5675 .44215 Mtetra
.67 .761 .919 r
.5675 .44215 .56834 .44302 .56996 .4425 .56912 .4416 Mtetra
.667 .756 .917 r
.56912 .4416 .56996 .4425 .57158 .44197 .57073 .44107 Mtetra
.665 .753 .916 r
.57073 .44107 .57158 .44197 .5732 .44145 .57235 .44054 Mtetra
.665 .754 .916 r
.57235 .44054 .5732 .44145 .57481 .44093 .57397 .44001 Mtetra
.665 .752 .915 r
.57397 .44001 .57481 .44093 .57644 .44041 .57559 .43949 Mtetra
.665 .751 .914 r
.57559 .43949 .57644 .44041 .57806 .43989 .57722 .43896 Mtetra
.665 .75 .914 r
.57722 .43896 .57806 .43989 .57968 .43936 .57884 .43844 Mtetra
.57884 .43844 .57968 .43936 .5813 .43884 .58046 .43791 Mtetra
.666 .748 .912 r
.58046 .43791 .5813 .43884 .58293 .43834 .58209 .43738 Mtetra
.682 .747 .9 r
.58209 .43738 .58293 .43834 .58455 .4379 .58371 .43677 Mtetra
.667 .709 .879 r
.58371 .43677 .58455 .4379 .58618 .43746 .58534 .43623 Mtetra
.641 .681 .872 r
.58534 .43623 .58618 .43746 .58781 .43698 .58697 .43581 Mtetra
.531 .644 .906 r
.58697 .43581 .58781 .43698 .58943 .43635 .5886 .4358 Mtetra
.307 .693 .977 r
.5886 .4358 .58943 .43635 .59106 .43571 .59025 .43593 Mtetra
.262 0 0 r
.59025 .43593 .59106 .43571 .59269 .43507 .59189 .43607 Mtetra
.027 0 0 r
.59189 .43607 .59269 .43507 .59431 .43415 .59351 .43513 Mtetra
.16 0 0 r
.59351 .43513 .59431 .43415 .59594 .43355 .59514 .43447 Mtetra
.448 0 .043 r
.59514 .43447 .59594 .43355 .59758 .43352 .59679 .43458 Mtetra
.896 .55 .384 r
.59679 .43458 .59758 .43352 .5993 .43652 .5986 .44171 Mtetra
.959 .675 .456 r
.5986 .44171 .5993 .43652 .60546 .63 .60477 .63723 Mtetra
.674 .393 .487 r
.60477 .63723 .60546 .63 .60742 .63912 .60661 .64093 Mtetra
.522 .135 .248 r
.60661 .64093 .60742 .63912 .60919 .63942 .60837 .64113 Mtetra
.38 0 .168 r
.60837 .64113 .60919 .63942 .61093 .63879 .61011 .64064 Mtetra
.313 0 .16 r
.61011 .64064 .61093 .63879 .61266 .63786 .61185 .6398 Mtetra
.401 .028 .212 r
.61185 .6398 .61266 .63786 .61443 .63827 .6136 .63931 Mtetra
.218 0 0 r
.6136 .63931 .61443 .63827 .6162 .63869 .61535 .63873 Mtetra
.486 .901 .883 r
.61535 .63873 .6162 .63869 .61797 .63892 .61709 .63804 Mtetra
.763 .799 .883 r
.61709 .63804 .61797 .63892 .61972 .6386 .61883 .63695 Mtetra
.736 .675 .791 r
.61883 .63695 .61972 .6386 .62147 .6381 .62056 .63572 Mtetra
.704 .602 .74 r
.62056 .63572 .62147 .6381 .62322 .63751 .62229 .63446 Mtetra
.584 .5 .726 r
.62229 .63446 .62322 .63751 .62499 .63738 .62405 .63432 Mtetra
.602 .511 .723 r
.62405 .63432 .62499 .63738 .62675 .63699 .62581 .634 Mtetra
.671 .554 .714 r
.62581 .634 .62675 .63699 .62849 .63599 .62755 .6329 Mtetra
.87 .656 .61 r
.62755 .6329 .62849 .63599 .63013 .63195 .6291 .62563 Mtetra
.963 .683 .457 r
.6291 .62563 .63013 .63195 .62593 .4389 .62479 .42795 Mtetra
.677 .468 .595 r
.62479 .42795 .62593 .4389 .62721 .42668 .62632 .42328 Mtetra
.674 .534 .687 r
.62632 .42328 .62721 .42668 .62883 .425 .62794 .42198 Mtetra
.623 .517 .713 r
.62794 .42198 .62883 .425 .63048 .42447 .6296 .42145 Mtetra
.591 .498 .718 r
.6296 .42145 .63048 .42447 .63215 .42441 .63126 .42125 Mtetra
.644 .524 .703 r
.63126 .42125 .63215 .42441 .63379 .42348 .6329 .42045 Mtetra
.632 .522 .711 r
.6329 .42045 .63379 .42348 .63544 .4228 .63456 .41981 Mtetra
.582 .493 .72 r
.63456 .41981 .63544 .4228 .63712 .42288 .63623 .41969 Mtetra
.17 .218 .67 r
.63623 .41969 .63712 .42288 .63898 .42811 .63799 .42219 Mtetra
.975 .689 .415 r
.63799 .42219 .63898 .42811 .64768 .62518 .64641 .61289 Mtetra
0 0 .458 r
.64641 .61289 .64768 .62518 .64962 .62945 .64867 .62609 Mtetra
.472 .418 .716 r
.64867 .62609 .64962 .62945 .65142 .62993 .65048 .62694 Mtetra
.622 .526 .724 r
.65048 .62694 .65142 .62993 .6532 .62946 .65225 .62641 Mtetra
.655 .543 .715 r
.65225 .62641 .6532 .62946 .65496 .62862 .65401 .6255 Mtetra
.561 .484 .726 r
.65401 .6255 .65496 .62862 .65673 .62814 .65581 .62558 Mtetra
.528 .494 .762 r
.65581 .62558 .65673 .62814 .65851 .6277 .65761 .62586 Mtetra
.53 .558 .828 r
.65761 .62586 .65851 .6277 .66028 .6271 .65941 .62599 Mtetra
.496 .658 .933 r
.65941 .62599 .66028 .6271 .66205 .62637 .66121 .62605 Mtetra
.452 .838 .985 r
.66121 .62605 .66205 .62637 .6638 .62525 .663 .62573 Mtetra
0 0 0 r
.663 .62573 .6638 .62525 .66552 .62334 .66476 .62479 Mtetra
.686 .808 .353 r
.66476 .62479 .66552 .62334 .66704 .61663 .66642 .62137 Mtetra
.865 .73 .211 r
.66642 .62137 .66704 .61663 .66055 .41845 .66766 .6078 Mtetra
.014 0 .417 r
.66766 .6078 .66055 .41845 .66203 .41357 .66133 .41509 Mtetra
0 0 0 r
.66133 .41509 .66203 .41357 .66367 .41214 .66291 .41242 Mtetra
.615 .947 .769 r
.66291 .41242 .66367 .41214 .66534 .41169 .66456 .41121 Mtetra
.687 .883 .971 r
.66456 .41121 .66534 .41169 .66704 .4116 .66623 .41051 Mtetra
.665 .72 .89 r
.66623 .41051 .66704 .4116 .66872 .41126 .6679 .40996 Mtetra
.639 .673 .866 r
.6679 .40996 .66872 .41126 .6704 .41076 .66958 .40953 Mtetra
.625 .679 .881 r
.66958 .40953 .6704 .41076 .67207 .41022 .67127 .40917 Mtetra
.654 .725 .901 r
.67127 .40917 .67207 .41022 .67374 .40951 .67295 .40867 Mtetra
.671 .78 .931 r
.67295 .40867 .67374 .40951 .67541 .40879 .67463 .4081 Mtetra
.674 .819 .953 r
.67463 .4081 .67541 .40879 .67709 .40819 .6763 .40749 Mtetra
.753 .835 .914 r
.6763 .40749 .67709 .40819 .67878 .40779 .67796 .40655 Mtetra
.711 .711 .848 r
.67796 .40655 .67878 .40779 .68048 .40777 .67963 .40572 Mtetra
.612 .569 .782 r
.67963 .40572 .68048 .40777 .68223 .40849 .68133 .4054 Mtetra
.298 .31 .704 r
.68133 .4054 .68223 .40849 .68418 .41342 .68313 .40726 Mtetra
0 0 .243 r
.68313 .40726 .68418 .41342 .69574 .61121 .68542 .41895 Mtetra
.04 0 .437 r
.68542 .41895 .69574 .61121 .69778 .61562 .6968 .61183 Mtetra
.332 .312 .686 r
.6968 .61183 .69778 .61562 .69965 .61637 .69873 .6139 Mtetra
.527 .5 .77 r
.69873 .6139 .69965 .61637 .70145 .61592 .70057 .61417 Mtetra
.604 .608 .828 r
.70057 .61417 .70145 .61592 .70324 .61507 .70238 .6139 Mtetra
.627 .706 .903 r
.70238 .6139 .70324 .61507 .70504 .61448 .70419 .6135 Mtetra
.644 .751 .927 r
.70419 .6135 .70504 .61448 .70684 .61403 .706 .613 Mtetra
.665 .75 .914 r
.706 .613 .70684 .61403 .70865 .61344 .7078 .61241 Mtetra
.581 .718 .937 r
.7078 .61241 .70865 .61344 .71044 .61271 .70962 .61216 Mtetra
.514 .813 .999 r
.70962 .61216 .71044 .61271 .71222 .61163 .71145 .61188 Mtetra
.364 .823 .727 r
.71145 .61188 .71222 .61163 .71396 .6098 .71324 .61107 Mtetra
.632 .794 .353 r
.71324 .61107 .71396 .6098 .71548 .60421 .71491 .60804 Mtetra
.833 .721 .192 r
.71491 .60804 .71548 .60421 .70612 .40474 .71613 .59694 Mtetra
.039 0 .431 r
.71613 .59694 .70612 .40474 .70754 .39921 .7069 .40088 Mtetra
0 0 0 r
.7069 .40088 .70754 .39921 .70916 .39735 .70848 .39825 Mtetra
.169 0 0 r
.70848 .39825 .70916 .39735 .71085 .39671 .71018 .39762 Mtetra
.353 0 0 r
.71018 .39762 .71085 .39671 .71257 .39647 .7119 .39745 Mtetra
.138 0 0 r
.7119 .39745 .71257 .39647 .71429 .39618 .71359 .39668 Mtetra
.423 .811 .576 r
.71359 .39668 .71429 .39618 .716 .39576 .71525 .39547 Mtetra
.78 .948 .93 r
.71525 .39547 .716 .39576 .71771 .39534 .71692 .39434 Mtetra
.716 .762 .888 r
.71692 .39434 .71771 .39534 .71942 .39481 .71861 .39353 Mtetra
.663 .69 .865 r
.71861 .39353 .71942 .39481 .72112 .3942 .72032 .39298 Mtetra
.648 .693 .878 r
.72032 .39298 .72112 .3942 .72282 .39357 .72203 .3925 Mtetra
.654 .725 .902 r
.72203 .3925 .72282 .39357 .72452 .39297 .72374 .392 Mtetra
.662 .748 .914 r
.72374 .392 .72452 .39297 .72623 .39241 .72545 .39145 Mtetra
.66 .752 .918 r
.72545 .39145 .72623 .39241 .72794 .39186 .72717 .39092 Mtetra
.651 .753 .924 r
.72717 .39092 .72794 .39186 .72965 .39125 .72888 .39042 Mtetra
.642 .776 .945 r
.72888 .39042 .72965 .39125 .73136 .39064 .7306 .38994 Mtetra
.637 .811 .967 r
.7306 .38994 .73136 .39064 .73307 .39013 .73231 .38945 Mtetra
.657 .821 .962 r
.73231 .38945 .73307 .39013 .73481 .39 .73403 .38888 Mtetra
.678 .727 .887 r
.73403 .38888 .73481 .39 .73658 .39024 .73574 .38826 Mtetra
.655 .6 .781 r
.73574 .38826 .73658 .39024 .73836 .39062 .73745 .38762 Mtetra
.629 .524 .715 r
.73745 .38762 .73836 .39062 .74012 .39065 .73916 .38701 Mtetra
.617 .494 .69 r
.73916 .38701 .74012 .39065 .74184 .39014 .74088 .38644 Mtetra
.615 .491 .688 r
.74088 .38644 .74184 .39014 .74355 .38946 .7426 .38587 Mtetra
.616 .495 .692 r
.7426 .38587 .74355 .38946 .74526 .38881 .74432 .38531 Mtetra
.617 .499 .696 r
.74432 .38531 .74526 .38881 .74699 .38825 .74604 .38476 Mtetra
.74604 .38476 .74699 .38825 .74871 .38771 .74776 .38421 Mtetra
.617 .498 .695 r
.74776 .38421 .74871 .38771 .75044 .38725 .74949 .38366 Mtetra
.615 .495 .692 r
.74949 .38366 .75044 .38725 .75218 .38686 .75121 .38311 Mtetra
.614 .489 .687 r
.75121 .38311 .75218 .38686 .75392 .38644 .75294 .38256 Mtetra
.613 .485 .683 r
.75294 .38256 .75392 .38644 .75564 .3859 .75467 .38201 Mtetra
.613 .485 .682 r
.75467 .38201 .75564 .3859 .75736 .3852 .7564 .38145 Mtetra
.614 .489 .687 r
.7564 .38145 .75736 .3852 .75908 .38449 .75812 .38089 Mtetra
.616 .495 .692 r
.75812 .38089 .75908 .38449 .76081 .38392 .75985 .38033 Mtetra
.75985 .38033 .76081 .38392 .76255 .38347 .76159 .37977 Mtetra
.614 .491 .689 r
.76159 .37977 .76255 .38347 .76428 .38288 .76332 .37923 Mtetra
.612 .491 .691 r
.76332 .37923 .76428 .38288 .76597 .38178 .76505 .37872 Mtetra
.617 .515 .715 r
.76505 .37872 .76597 .38178 .76764 .38028 .76679 .37823 Mtetra
.636 .586 .781 r
.76679 .37823 .76764 .38028 .76931 .37892 .76853 .37773 Mtetra
.672 .711 .877 r
.76853 .37773 .76931 .37892 .77102 .37796 .77027 .37712 Mtetra
.698 .798 .926 r
.77027 .37712 .77102 .37796 .77275 .3774 .77199 .37641 Mtetra
.683 .756 .906 r
.77199 .37641 .77275 .3774 .7745 .37695 .77372 .37576 Mtetra
.663 .71 .883 r
.77372 .37576 .7745 .37695 .77623 .37624 .77546 .3752 Mtetra
.621 .721 .918 r
.77546 .3752 .77623 .37624 .77793 .37528 .77722 .37483 Mtetra
.263 .696 .964 r
.77722 .37483 .77793 .37528 .77967 .37469 .77901 .37494 Mtetra
.73 .216 0 r
.77901 .37494 .77967 .37469 .78151 .37529 .78095 .37678 Mtetra
.974 .67 .37 r
.78095 .37678 .78151 .37529 .7836 .37906 .79824 .56907 Mtetra
.579 .358 .545 r
.79824 .56907 .7836 .37906 .80156 .57772 .80125 .58284 Mtetra
.641 .337 .441 r
.80125 .58284 .80156 .57772 .80392 .58331 .80333 .58488 Mtetra
.395 0 .149 r
.80333 .58488 .80392 .58331 .80589 .58406 .80521 .58449 Mtetra
0 0 0 r
.80521 .58449 .80589 .58406 .8078 .58397 .80704 .58351 Mtetra
.748 .92 .948 r
.80704 .58351 .8078 .58397 .80967 .58352 .80887 .58246 Mtetra
.672 .755 .913 r
.80887 .58246 .80967 .58352 .81154 .58294 .81074 .58182 Mtetra
.658 .737 .908 r
.81074 .58182 .81154 .58294 .8134 .58225 .81261 .58125 Mtetra
.616 .744 .937 r
.81261 .58125 .8134 .58225 .81527 .58164 .81449 .58084 Mtetra
.534 .761 .98 r
.81449 .58084 .81527 .58164 .81715 .58123 .81639 .58063 Mtetra
.521 .81 .998 r
.81639 .58063 .81715 .58123 .81904 .58087 .81829 .58034 Mtetra
.563 .845 .997 r
.81829 .58034 .81904 .58087 .82095 .58074 .82018 .5799 Mtetra
.676 .807 .945 r
.82018 .5799 .82095 .58074 .82289 .58084 .82205 .57923 Mtetra
.744 .694 .804 r
.82205 .57923 .82289 .58084 .82478 .58046 .82386 .57794 Mtetra
.817 .655 .683 r
.82386 .57794 .82478 .58046 .82656 .57874 .8255 .57468 Mtetra
.976 .677 .375 r
.8255 .57468 .82656 .57874 .82796 .57286 .80975 .37615 Mtetra
.575 .36 .551 r
.80975 .37615 .82796 .57286 .81184 .37193 .81068 .36621 Mtetra
.695 .506 .629 r
.81068 .36621 .81184 .37193 .81317 .36647 .81223 .36335 Mtetra
.637 .525 .71 r
.81223 .36335 .81317 .36647 .81483 .36484 .81398 .36262 Mtetra
.598 .552 .774 r
.81398 .36262 .81483 .36484 .81656 .36388 .81577 .36238 Mtetra
.579 .62 .858 r
.81577 .36238 .81656 .36388 .81832 .36322 .81758 .36224 Mtetra
.655 .753 .922 r
.81758 .36224 .81832 .36322 .82008 .36261 .81935 .36171 Mtetra
.661 .773 .933 r
.81935 .36171 .82008 .36261 .82185 .36211 .82112 .36114 Mtetra
.699 .773 .909 r
.82112 .36114 .82185 .36211 .82361 .36147 .82287 .36041 Mtetra
.749 .771 .871 r
.82287 .36041 .82361 .36147 .82534 .36045 .8246 .35939 Mtetra
.669 .74 .904 r
.8246 .35939 .82534 .36045 .82711 .35987 .82636 .35879 Mtetra
.27 .527 .912 r
.82636 .35879 .82711 .35987 .82899 .36054 .82825 .35946 Mtetra
.869 .473 .006 r
.82825 .35946 .82899 .36054 .83148 .3674 .83073 .36618 Mtetra
.975 .667 .334 r
.83073 .36618 .83148 .3674 .85276 .56853 .85198 .56747 Mtetra
.647 .203 0 r
.85198 .56747 .85276 .56853 .85505 .57202 .85427 .57099 Mtetra
.388 .626 .947 r
.85427 .57099 .85505 .57202 .85703 .57233 .85626 .57131 Mtetra
.698 .776 .912 r
.85626 .57131 .85703 .57233 .85891 .57156 .85814 .57053 Mtetra
.878 .814 .782 r
.85814 .57053 .85891 .57156 .86065 .56929 .85987 .56822 Mtetra
.979 .754 .53 r
.85987 .56822 .86065 .56929 .86179 .5611 .86095 .55937 Mtetra
.977 .675 .35 r
.86095 .55937 .86179 .5611 .84347 .35861 .8427 .35716 Mtetra
.915 .748 .66 r
.8427 .35716 .84347 .35861 .84488 .35436 .84413 .35308 Mtetra
.72 .721 .85 r
.84413 .35308 .84488 .35436 .84662 .35337 .84587 .35216 Mtetra
.607 .684 .896 r
.84587 .35216 .84662 .35337 .84842 .35299 .84768 .35185 Mtetra
.576 .682 .913 r
.84768 .35185 .84842 .35299 .85024 .35274 .84951 .35165 Mtetra
.74 .764 .872 r
.84951 .35165 .85024 .35274 .85198 .35174 .85125 .35067 Mtetra
.67 .741 .904 r
.85125 .35067 .85198 .35174 .85376 .35113 .85303 .35006 Mtetra
.378 .594 .93 r
.85303 .35006 .85376 .35113 .85565 .35152 .85492 .35046 Mtetra
.799 .385 0 r
.85492 .35046 .85565 .35152 .85805 .35678 .85732 .35572 Mtetra
.973 .663 .318 r
.85732 .35572 .85805 .35678 .88123 .55921 .88047 .55822 Mtetra
.725 .283 0 r
.88047 .55822 .88123 .55921 .88365 .56341 .88289 .56242 Mtetra
.501 .696 .956 r
.88289 .56242 .88365 .56341 .88563 .56339 .88487 .56239 Mtetra
.696 .783 .918 r
.88487 .56239 .88563 .56339 .88752 .56262 .88677 .56162 Mtetra
.737 .796 .899 r
.88677 .56162 .88752 .56262 .8894 .56163 .88864 .56062 Mtetra
.499 .691 .954 r
.88864 .56062 .8894 .56163 .89138 .56162 .89062 .56061 Mtetra
.629 .753 .937 r
.89062 .56061 .89138 .56162 .89331 .56116 .89256 .56014 Mtetra
.816 .813 .847 r
.89256 .56014 .89331 .56116 .89513 .55963 .89437 .55857 Mtetra
.98 .764 .54 r
.89437 .55857 .89513 .55963 .89631 .55224 .8955 .5507 Mtetra
.976 .671 .331 r
.8955 .5507 .89631 .55224 .87579 .3489 .87503 .34742 Mtetra
.928 .749 .64 r
.87503 .34742 .87579 .3489 .87713 .34417 .87639 .34287 Mtetra
.72 .72 .849 r
.87639 .34287 .87713 .34417 .87889 .34318 .87815 .34194 Mtetra
.597 .676 .895 r
.87815 .34194 .87889 .34318 .88072 .34286 .87999 .34167 Mtetra
.512 .643 .915 r
.87999 .34167 .88072 .34286 .88259 .34284 .88187 .34172 Mtetra
.641 .72 .905 r
.88187 .34172 .88259 .34284 .8844 .34234 .88368 .34124 Mtetra
.648 .729 .908 r
.88368 .34124 .8844 .34234 .88621 .34182 .8855 .34074 Mtetra
.661 .738 .907 r
.8855 .34074 .88621 .34182 .88802 .34123 .88731 .34017 Mtetra
.745 .773 .876 r
.88731 .34017 .88802 .34123 .88977 .34013 .88907 .33915 Mtetra
.688 .771 .915 r
.88907 .33915 .88977 .34013 .89156 .33942 .89086 .33846 Mtetra
.5 .689 .952 r
.89086 .33846 .89156 .33942 .89345 .33954 .89274 .33845 Mtetra
.605 .179 0 r
.89274 .33845 .89345 .33954 .89598 .34507 .89504 .34203 Mtetra
.97 .657 .285 r
.89504 .34203 .89598 .34507 .92179 .54823 .92052 .54273 Mtetra
.035 .078 .576 r
.92052 .54273 .92179 .54823 .92431 .55253 .92331 .54935 Mtetra
.483 .44 .734 r
.92331 .54935 .92431 .55253 .92631 .55245 .92542 .55014 Mtetra
.571 .545 .787 r
.92542 .55014 .92631 .55245 .92822 .55161 .92742 .55009 Mtetra
.638 .666 .861 r
.92742 .55009 .92822 .55161 .93009 .55036 .92938 .5496 Mtetra
.564 .82 .994 r
.3022 .726 .30322 .72651 .30478 .72607 .30375 .72569 Mtetra
.694 .88 .967 r
.30375 .72569 .30478 .72607 .30634 .72551 .30532 .725 Mtetra
.741 .85 .931 r
.30532 .725 .30634 .72551 .30791 .72492 .30691 .72416 Mtetra
.329 .653 .97 r
.30691 .72416 .30791 .72492 .30944 .72507 .30843 .72438 Mtetra
.516 .754 .982 r
.30843 .72438 .30944 .72507 .31099 .72485 .30998 .72424 Mtetra
.747 .824 .912 r
.30998 .72424 .31099 .72485 .31259 .72392 .31157 .72336 Mtetra
.921 .753 .656 r
.31157 .72336 .31259 .72392 .31444 .71853 .31344 .71788 Mtetra
.937 .687 .532 r
.31344 .71788 .31444 .71853 .32744 .52428 .32653 .52296 Mtetra
.889 .704 .647 r
.32653 .52296 .32744 .52428 .32923 .51857 .32832 .51735 Mtetra
.741 .699 .811 r
.32832 .51735 .32923 .51857 .33075 .51748 .32983 .51633 Mtetra
.599 .665 .885 r
.32983 .51633 .33075 .51748 .33222 .51718 .3313 .51612 Mtetra
.446 .618 .924 r
.3313 .51612 .33222 .51718 .33367 .51725 .33274 .5163 Mtetra
.632 .716 .907 r
.33274 .5163 .33367 .51725 .33515 .51684 .33422 .51595 Mtetra
.66 .737 .907 r
.33422 .51595 .33515 .51684 .33664 .51635 .3357 .51548 Mtetra
.677 .748 .905 r
.3357 .51548 .33664 .51635 .33812 .51582 .33719 .51495 Mtetra
.775 .763 .842 r
.33719 .51495 .33812 .51582 .33964 .51478 .33872 .51383 Mtetra
.73 .74 .86 r
.33872 .51383 .33964 .51478 .34114 .51404 .34022 .51301 Mtetra
.579 .681 .91 r
.34022 .51301 .34114 .51404 .34261 .51394 .34169 .51284 Mtetra
.915 .514 .153 r
.34169 .51284 .34261 .51394 .34388 .51744 .34296 .51641 Mtetra
.941 .683 .52 r
.34296 .51641 .34388 .51744 .33496 .71072 .33394 .7104 Mtetra
.92 .581 .379 r
.33394 .7104 .33496 .71072 .33619 .71673 .33518 .71627 Mtetra
0 .511 .837 r
.33518 .71627 .33619 .71673 .33772 .71723 .33672 .71667 Mtetra
.696 .838 .951 r
.33672 .71667 .33772 .71723 .3393 .71668 .33831 .71601 Mtetra
.777 .814 .882 r
.33831 .71601 .3393 .71668 .34091 .71572 .33992 .71493 Mtetra
.442 .698 .975 r
.33992 .71493 .34091 .71572 .34247 .71571 .34148 .71498 Mtetra
.499 .736 .979 r
.34148 .71498 .34247 .71571 .34404 .71555 .34304 .71489 Mtetra
.725 .817 .922 r
.34304 .71489 .34404 .71555 .34564 .7147 .34465 .71412 Mtetra
.919 .765 .674 r
.34465 .71412 .34564 .7147 .34744 .71013 .34644 .70949 Mtetra
.941 .688 .525 r
.34644 .70949 .34744 .71013 .35868 .51568 .35778 .5143 Mtetra
.898 .703 .631 r
.35778 .5143 .35868 .51568 .36049 .50889 .35959 .50767 Mtetra
.775 .708 .789 r
.35959 .50767 .36049 .50889 .36204 .50744 .36113 .50629 Mtetra
.618 .674 .881 r
.36113 .50629 .36204 .50744 .36353 .50706 .36262 .506 Mtetra
.466 .63 .925 r
.36262 .506 .36353 .50706 .36501 .50709 .36409 .50614 Mtetra
.67 .731 .895 r
.36409 .50614 .36501 .50709 .36652 .50641 .36559 .50563 Mtetra
.687 .773 .917 r
.36559 .50563 .36652 .50641 .36803 .50577 .3671 .50505 Mtetra
.594 .765 .961 r
.3671 .50505 .36803 .50577 .36951 .50563 .36859 .50477 Mtetra
0 .352 .812 r
.36859 .50477 .36951 .50563 .37089 .50795 .37004 .50559 Mtetra
0 .037 .598 r
.37004 .50559 .37089 .50795 .3639 .69298 .37141 .50791 Mtetra
.537 .33 .547 r
.37141 .50791 .3639 .69298 .36487 .70623 .37243 .51822 Mtetra
0 0 .311 r
.37243 .51822 .36487 .70623 .36637 .70775 .36562 .70186 Mtetra
.276 .21 .6 r
.36562 .70186 .36637 .70775 .36794 .70788 .36706 .70502 Mtetra
.32 .337 .722 r
.36706 .70502 .36794 .70788 .36954 .70751 .36857 .70638 Mtetra
.298 .544 .917 r
.36857 .70638 .36954 .70751 .37112 .70749 .37013 .70687 Mtetra
.547 .787 .988 r
.37013 .70687 .37112 .70749 .37271 .70723 .37172 .70663 Mtetra
.785 .835 .89 r
.37172 .70663 .37271 .70723 .37433 .70624 .37335 .70551 Mtetra
.914 .757 .672 r
.37335 .70551 .37433 .70624 .37611 .70178 .37513 .70087 Mtetra
.944 .688 .519 r
.37513 .70087 .37611 .70178 .38583 .50686 .38494 .50544 Mtetra
.898 .704 .632 r
.38494 .50544 .38583 .50686 .3876 .50018 .3867 .49904 Mtetra
.796 .724 .785 r
.3867 .49904 .3876 .50018 .38916 .49855 .38826 .49748 Mtetra
.62 .692 .895 r
.38826 .49748 .38916 .49855 .39067 .49816 .38976 .49717 Mtetra
.446 .64 .939 r
.38976 .49717 .39067 .49816 .39217 .4982 .39125 .49732 Mtetra
.553 .71 .945 r
.39125 .49732 .39217 .4982 .39367 .498 .39276 .49719 Mtetra
.621 .749 .938 r
.39276 .49719 .39367 .498 .39518 .49764 .39427 .49685 Mtetra
.63 .758 .939 r
.39427 .49685 .39518 .49764 .3967 .49725 .39578 .49647 Mtetra
.637 .763 .939 r
.39578 .49647 .3967 .49725 .39821 .49684 .3973 .49607 Mtetra
.644 .768 .938 r
.3973 .49607 .39821 .49684 .39973 .4964 .39882 .49565 Mtetra
.653 .774 .938 r
.39882 .49565 .39973 .4964 .40125 .49593 .40034 .49519 Mtetra
.658 .778 .937 r
.40034 .49519 .40125 .49593 .40277 .49544 .40186 .49471 Mtetra
.668 .784 .935 r
.40186 .49471 .40277 .49544 .4043 .49492 .40339 .4942 Mtetra
.682 .788 .93 r
.40339 .4942 .4043 .49492 .40582 .49437 .40491 .49363 Mtetra
.71 .789 .913 r
.40491 .49363 .40582 .49437 .40735 .49378 .40644 .49295 Mtetra
.719 .769 .892 r
.40644 .49295 .40735 .49378 .40888 .49317 .40798 .49221 Mtetra
.711 .741 .874 r
.40798 .49221 .40888 .49317 .41041 .49256 .40951 .49148 Mtetra
.689 .713 .867 r
.40951 .49148 .41041 .49256 .41194 .49198 .41105 .49085 Mtetra
.674 .7 .866 r
.41105 .49085 .41194 .49198 .41347 .49143 .41258 .4903 Mtetra
.668 .697 .868 r
.41258 .4903 .41347 .49143 .415 .4909 .41411 .48978 Mtetra
.667 .699 .871 r
.41411 .48978 .415 .4909 .41653 .49038 .41564 .48926 Mtetra
.667 .7 .872 r
.41564 .48926 .41653 .49038 .41806 .48986 .41717 .48875 Mtetra
.665 .7 .873 r
.41717 .48875 .41806 .48986 .41959 .48935 .4187 .48824 Mtetra
.665 .701 .873 r
.4187 .48824 .41959 .48935 .42113 .48883 .42023 .48773 Mtetra
.665 .702 .874 r
.42023 .48773 .42113 .48883 .42266 .48832 .42177 .48723 Mtetra
.664 .704 .876 r
.42177 .48723 .42266 .48832 .42419 .48781 .4233 .48672 Mtetra
.694 .714 .864 r
.4233 .48672 .42419 .48781 .42574 .48707 .42484 .48607 Mtetra
.695 .73 .877 r
.42484 .48607 .42574 .48707 .42728 .48636 .42638 .48542 Mtetra
.63 .725 .916 r
.42638 .48542 .42728 .48636 .42881 .48609 .42791 .48506 Mtetra
.145 .463 .889 r
.42791 .48506 .42881 .48609 .43029 .48761 .42942 .48575 Mtetra
0 0 .526 r
.42942 .48575 .43029 .48761 .43159 .49569 .43087 .48812 Mtetra
0 0 .458 r
.43087 .48812 .43159 .49569 .42781 .68736 .4322 .49518 Mtetra
0 0 .353 r
.4322 .49518 .42781 .68736 .42937 .68952 .4287 .67849 Mtetra
.555 .379 .597 r
.4287 .67849 .42937 .68952 .431 .68928 .43031 .67878 Mtetra
.633 .44 .603 r
.43031 .67878 .431 .68928 .43265 .68841 .43199 .67639 Mtetra
.626 .43 .597 r
.43199 .67639 .43265 .68841 .43429 .68764 .43368 .67394 Mtetra
.581 .392 .59 r
.43368 .67394 .43429 .68764 .43593 .68716 .43531 .67323 Mtetra
.581 .391 .589 r
.43531 .67323 .43593 .68716 .43757 .68668 .43695 .67249 Mtetra
.579 .389 .588 r
.43695 .67249 .43757 .68668 .43921 .6862 .43859 .67181 Mtetra
.577 .387 .588 r
.43859 .67181 .43921 .6862 .44085 .68574 .44023 .67123 Mtetra
.575 .386 .587 r
.44023 .67123 .44085 .68574 .44249 .68528 .44187 .67072 Mtetra
.653 .446 .59 r
.44187 .67072 .44249 .68528 .44414 .68474 .4436 .66614 Mtetra
.924 .662 .523 r
.4436 .66614 .44414 .68474 .44578 .68417 .44909 .49698 Mtetra
.001 0 .392 r
.44909 .49698 .44578 .68417 .44742 .68374 .44697 .66088 Mtetra
.193 .083 .491 r
.44697 .66088 .44742 .68374 .44906 .68371 .44826 .67607 Mtetra
.229 .159 .566 r
.44826 .67607 .44906 .68371 .45069 .68399 .44979 .68083 Mtetra
.17 .223 .675 r
.44979 .68083 .45069 .68399 .45232 .68418 .45138 .68303 Mtetra
.237 .505 .904 r
.45138 .68303 .45232 .68418 .45397 .68405 .45301 .68367 Mtetra
.529 .848 .998 r
.45301 .68367 .45397 .68405 .45562 .6836 .45466 .68331 Mtetra
.639 .904 .983 r
.45466 .68331 .45562 .6836 .45727 .68307 .45632 .68268 Mtetra
.655 .885 .982 r
.45632 .68268 .45727 .68307 .45892 .68255 .45797 .68206 Mtetra
.618 .85 .987 r
.45797 .68206 .45892 .68255 .46057 .68208 .45963 .68157 Mtetra
.611 .843 .988 r
.45963 .68157 .46057 .68208 .46223 .68163 .46128 .68112 Mtetra
.573 .829 .994 r
.46128 .68112 .46223 .68163 .46388 .68123 .46293 .68075 Mtetra
.521 .821 1 r
.46293 .68075 .46388 .68123 .46554 .68086 .46459 .68047 Mtetra
.505 .837 .998 r
.46459 .68047 .46554 .68086 .46719 .68048 .46624 .68016 Mtetra
.553 .872 .994 r
.46624 .68016 .46719 .68048 .46885 .68005 .4679 .67972 Mtetra
.631 .895 .986 r
.4679 .67972 .46885 .68005 .47051 .67955 .46956 .67913 Mtetra
.663 .878 .978 r
.46956 .67913 .47051 .67955 .47217 .67903 .47123 .67849 Mtetra
.617 .837 .984 r
.47123 .67849 .47217 .67903 .47383 .67871 .47289 .67803 Mtetra
.571 .784 .979 r
.47289 .67803 .47383 .67871 .47549 .67855 .47455 .67774 Mtetra
.664 .781 .936 r
.47455 .67774 .47549 .67855 .47715 .67795 .47622 .67719 Mtetra
.815 .812 .848 r
.47622 .67719 .47715 .67795 .47884 .67585 .47789 .67575 Mtetra
.947 .865 .725 r
.47789 .67575 .47884 .67585 .48059 .66894 .4796 .6725 Mtetra
.708 .726 .206 r
.4796 .6725 .48059 .66894 .48463 .47346 .48134 .66607 Mtetra
0 0 .363 r
.48134 .66607 .48463 .47346 .48624 .46947 .48524 .47935 Mtetra
.461 .227 .472 r
.48524 .47935 .48624 .46947 .48782 .46862 .48683 .47711 Mtetra
.592 .333 .492 r
.48683 .47711 .48782 .46862 .48939 .46842 .48839 .47829 Mtetra
.712 .443 .517 r
.48839 .47829 .48939 .46842 .49095 .46834 .48989 .4852 Mtetra
.927 .655 .505 r
.48989 .4852 .49095 .46834 .49253 .46798 .48975 .65528 Mtetra
.555 .341 .544 r
.48975 .65528 .49253 .46798 .4941 .4675 .49143 .65353 Mtetra
0 0 .368 r
.49143 .65353 .4941 .4675 .49568 .4667 .49473 .47353 Mtetra
0 0 .27 r
.49473 .47353 .49568 .4667 .49726 .4655 .49637 .46707 Mtetra
.733 .847 .407 r
.49637 .46707 .49726 .4655 .49884 .46437 .49797 .46388 Mtetra
.868 .854 .825 r
.49797 .46388 .49884 .46437 .50042 .46348 .49955 .46212 Mtetra
.685 .673 .832 r
.49955 .46212 .50042 .46348 .502 .46293 .50113 .46145 Mtetra
.634 .635 .834 r
.50113 .46145 .502 .46293 .50358 .46247 .50271 .46106 Mtetra
.625 .641 .846 r
.50271 .46106 .50358 .46247 .50516 .46203 .50429 .46072 Mtetra
.656 .669 .851 r
.50429 .46072 .50516 .46203 .50674 .46153 .50587 .46023 Mtetra
.654 .669 .852 r
.50587 .46023 .50674 .46153 .50832 .46104 .50745 .45974 Mtetra
.655 .671 .853 r
.50745 .45974 .50832 .46104 .5099 .46054 .50904 .45925 Mtetra
.657 .673 .853 r
.50904 .45925 .5099 .46054 .51149 .46004 .51062 .45875 Mtetra
.653 .671 .855 r
.51062 .45875 .51149 .46004 .51307 .45955 .51221 .45828 Mtetra
.642 .669 .86 r
.51221 .45828 .51307 .45955 .51466 .45909 .51379 .45786 Mtetra
.623 .668 .873 r
.51379 .45786 .51466 .45909 .51624 .45866 .51538 .45753 Mtetra
.619 .685 .89 r
.51538 .45753 .51624 .45866 .51783 .45824 .51697 .45721 Mtetra
.628 .71 .905 r
.51697 .45721 .51783 .45824 .51942 .45779 .51855 .45684 Mtetra
.652 .738 .912 r
.51855 .45684 .51942 .45779 .52101 .45728 .52014 .45638 Mtetra
.668 .752 .913 r
.52014 .45638 .52101 .45728 .5226 .45674 .52174 .45585 Mtetra
.686 .759 .907 r
.52174 .45585 .5226 .45674 .52419 .45617 .52333 .45525 Mtetra
.704 .756 .892 r
.52333 .45525 .52419 .45617 .52578 .45557 .52492 .45455 Mtetra
.703 .737 .878 r
.52492 .45455 .52578 .45557 .52738 .45496 .52651 .45384 Mtetra
.691 .716 .868 r
.52651 .45384 .52738 .45496 .52897 .45436 .52811 .45318 Mtetra
.671 .697 .866 r
.52811 .45318 .52897 .45436 .53056 .4538 .5297 .45262 Mtetra
.665 .695 .868 r
.5297 .45262 .53056 .4538 .53216 .45326 .5313 .45209 Mtetra
.663 .696 .871 r
.5313 .45209 .53216 .45326 .53376 .45272 .5329 .45157 Mtetra
.665 .7 .873 r
.5329 .45157 .53376 .45272 .53535 .45219 .53449 .45104 Mtetra
.664 .701 .874 r
.53449 .45104 .53535 .45219 .53695 .45167 .53609 .45052 Mtetra
.663 .701 .875 r
.53609 .45052 .53695 .45167 .53855 .45115 .53769 .45 Mtetra
.662 .701 .876 r
.53769 .45 .53855 .45115 .54015 .45063 .53929 .44949 Mtetra
.53929 .44949 .54015 .45063 .54175 .45012 .54089 .44897 Mtetra
.661 .701 .876 r
.54089 .44897 .54175 .45012 .54335 .44961 .5425 .44846 Mtetra
.66 .7 .876 r
.5425 .44846 .54335 .44961 .54496 .44911 .5441 .44796 Mtetra
.659 .7 .876 r
.5441 .44796 .54496 .44911 .54656 .44861 .5457 .44746 Mtetra
.659 .699 .876 r
.5457 .44746 .54656 .44861 .54817 .44812 .54731 .44696 Mtetra
.66 .698 .874 r
.54731 .44696 .54817 .44812 .54977 .44763 .54892 .44645 Mtetra
.655 .693 .873 r
.54892 .44645 .54977 .44763 .55138 .44715 .55052 .44596 Mtetra
.645 .687 .875 r
.55052 .44596 .55138 .44715 .55299 .4467 .55213 .44552 Mtetra
.622 .681 .885 r
.55213 .44552 .55299 .4467 .5546 .44628 .55374 .44519 Mtetra
.617 .695 .9 r
.55374 .44519 .5546 .44628 .55621 .44587 .55536 .44487 Mtetra
.622 .718 .915 r
.55536 .44487 .55621 .44587 .55782 .44544 .55697 .44452 Mtetra
.649 .745 .92 r
.55697 .44452 .55782 .44544 .55943 .44497 .55858 .44406 Mtetra
.664 .753 .916 r
.55858 .44406 .55943 .44497 .56104 .44447 .56019 .44354 Mtetra
.681 .753 .906 r
.56019 .44354 .56104 .44447 .56266 .44393 .56181 .44295 Mtetra
.701 .746 .887 r
.56181 .44295 .56266 .44393 .56427 .44334 .56342 .44225 Mtetra
.7 .726 .87 r
.56342 .44225 .56427 .44334 .56588 .44274 .56503 .44154 Mtetra
.691 .704 .857 r
.56503 .44154 .56588 .44274 .5675 .44215 .56665 .44086 Mtetra
.669 .682 .853 r
.56665 .44086 .5675 .44215 .56912 .4416 .56827 .44029 Mtetra
.663 .675 .852 r
.56827 .44029 .56912 .4416 .57073 .44107 .56988 .43975 Mtetra
.659 .673 .852 r
.56988 .43975 .57073 .44107 .57235 .44054 .5715 .43923 Mtetra
.661 .674 .852 r
.5715 .43923 .57235 .44054 .57397 .44001 .57312 .4387 Mtetra
.661 .673 .851 r
.57312 .4387 .57397 .44001 .57559 .43949 .57474 .43817 Mtetra
.66 .673 .851 r
.57474 .43817 .57559 .43949 .57722 .43896 .57637 .43764 Mtetra
.661 .672 .85 r
.57637 .43764 .57722 .43896 .57884 .43844 .57799 .4371 Mtetra
.66 .671 .849 r
.57799 .4371 .57884 .43844 .58046 .43791 .57961 .43657 Mtetra
.661 .67 .848 r
.57961 .43657 .58046 .43791 .58209 .43738 .58124 .43603 Mtetra
.693 .682 .835 r
.58124 .43603 .58209 .43738 .58371 .43677 .58286 .4353 Mtetra
.66 .65 .829 r
.58286 .4353 .58371 .43677 .58534 .43623 .58449 .43474 Mtetra
.593 .619 .847 r
.58449 .43474 .58534 .43623 .58697 .43581 .58612 .43455 Mtetra
0 .277 .781 r
.58612 .43455 .58697 .43581 .5886 .4358 .58779 .43587 Mtetra
.845 .401 .164 r
.58779 .43587 .5886 .4358 .59025 .43593 .58948 .43873 Mtetra
.878 .562 .449 r
.58948 .43873 .59025 .43593 .59189 .43607 .59134 .44932 Mtetra
.598 .35 .512 r
.59134 .44932 .59189 .43607 .59351 .43513 .59303 .4513 Mtetra
.461 .245 .498 r
.59303 .4513 .59351 .43513 .59514 .43447 .5946 .44733 Mtetra
.633 .378 .514 r
.5946 .44733 .59514 .43447 .59679 .43458 .59634 .45104 Mtetra
.94 .658 .476 r
.59634 .45104 .59679 .43458 .5986 .44171 .6021 .63494 Mtetra
.564 .348 .545 r
.6021 .63494 .5986 .44171 .60477 .63723 .60394 .63863 Mtetra
.708 .308 .287 r
.60394 .63863 .60477 .63723 .60661 .64093 .60573 .64038 Mtetra
.335 .718 .983 r
.60573 .64038 .60661 .64093 .60837 .64113 .60749 .64044 Mtetra
.588 .799 .98 r
.60749 .64044 .60837 .64113 .61011 .64064 .60924 .64008 Mtetra
.658 .854 .975 r
.60924 .64008 .61011 .64064 .61185 .6398 .61098 .63947 Mtetra
.517 .861 .993 r
.61098 .63947 .61185 .6398 .6136 .63931 .61273 .63906 Mtetra
.587 .909 .979 r
.61273 .63906 .6136 .63931 .61535 .63873 .61448 .63845 Mtetra
.736 .937 .952 r
.61448 .63845 .61535 .63873 .61709 .63804 .61622 .63746 Mtetra
.904 .85 .78 r
.61622 .63746 .61709 .63804 .61883 .63695 .61792 .63503 Mtetra
.86 .694 .675 r
.61792 .63503 .61883 .63695 .62056 .63572 .61958 .63108 Mtetra
.845 .62 .597 r
.61958 .63108 .62056 .63572 .62229 .63446 .6211 .62227 Mtetra
.643 .441 .595 r
.6211 .62227 .62229 .63446 .62405 .63432 .62276 .61888 Mtetra
.532 .353 .583 r
.62276 .61888 .62405 .63432 .62581 .634 .62456 .62025 Mtetra
.603 .408 .591 r
.62456 .62025 .62581 .634 .62755 .6329 .62628 .61851 Mtetra
.951 .672 .471 r
.62628 .61851 .62755 .6329 .6291 .62563 .62237 .42941 Mtetra
.567 .354 .551 r
.62237 .42941 .6291 .62563 .62479 .42795 .6239 .42465 Mtetra
.749 .582 .668 r
.6239 .42465 .62479 .42795 .62632 .42328 .62548 .422 Mtetra
.734 .71 .828 r
.62548 .422 .62632 .42328 .62794 .42198 .62712 .42099 Mtetra
.661 .739 .907 r
.62712 .42099 .62794 .42198 .6296 .42145 .62877 .42047 Mtetra
.608 .721 .925 r
.62877 .42047 .6296 .42145 .63126 .42125 .63043 .42016 Mtetra
.698 .73 .876 r
.63043 .42016 .63126 .42125 .6329 .42045 .63208 .41945 Mtetra
.681 .743 .898 r
.63208 .41945 .6329 .42045 .63456 .41981 .63374 .41884 Mtetra
.596 .719 .93 r
.63374 .41884 .63456 .41981 .63623 .41969 .6354 .41857 Mtetra
0 .334 .817 r
.6354 .41857 .63623 .41969 .63799 .42219 .63712 .41973 Mtetra
0 .064 .615 r
.63712 .41973 .63799 .42219 .64641 .61289 .6389 .42264 Mtetra
.53 .325 .548 r
.6389 .42264 .64641 .61289 .64867 .62609 .64114 .43827 Mtetra
.065 0 .44 r
.64114 .43827 .64867 .62609 .65048 .62694 .64916 .61321 Mtetra
.611 .414 .591 r
.64916 .61321 .65048 .62694 .65225 .62641 .65086 .61106 Mtetra
.568 .38 .586 r
.65086 .61106 .65225 .62641 .65401 .6255 .65264 .61082 Mtetra
.283 .174 .548 r
.65264 .61082 .65401 .6255 .65581 .62558 .65476 .61983 Mtetra
.28 .228 .62 r
.65476 .61983 .65581 .62558 .65761 .62586 .65669 .6234 Mtetra
.22 .311 .745 r
.65669 .6234 .65761 .62586 .65941 .62599 .65855 .62514 Mtetra
.314 .626 .96 r
.65855 .62514 .65941 .62599 .66121 .62605 .66036 .62548 Mtetra
.564 .823 .994 r
.66036 .62548 .66121 .62605 .663 .62573 .66215 .62511 Mtetra
.741 .861 .936 r
.66215 .62511 .663 .62573 .66476 .62479 .66391 .62418 Mtetra
.879 .862 .819 r
.66391 .62418 .66476 .62479 .66642 .62137 .66563 .62218 Mtetra
.916 .937 .573 r
.66563 .62218 .66642 .62137 .66766 .6078 .66729 .61865 Mtetra
.12 0 .387 r
.66729 .61865 .66766 .6078 .66133 .41509 .6687 .60923 Mtetra
.031 0 .423 r
.6687 .60923 .66133 .41509 .66291 .41242 .6623 .41597 Mtetra
0 0 .173 r
.6623 .41597 .66291 .41242 .66456 .41121 .66382 .41177 Mtetra
.828 .968 .65 r
.66382 .41177 .66456 .41121 .66623 .41051 .66542 .4095 Mtetra
.742 .762 .869 r
.66542 .4095 .66623 .41051 .6679 .40996 .66708 .40855 Mtetra
.627 .649 .852 r
.66708 .40855 .6679 .40996 .66958 .40953 .66876 .40817 Mtetra
.576 .635 .872 r
.66876 .40817 .66958 .40953 .67127 .40917 .67046 .40804 Mtetra
.628 .699 .896 r
.67046 .40804 .67127 .40917 .67295 .40867 .67214 .40766 Mtetra
.664 .737 .904 r
.67214 .40766 .67295 .40867 .67463 .4081 .67382 .40712 Mtetra
.678 .75 .905 r
.67382 .40712 .67463 .4081 .6763 .40749 .6755 .40651 Mtetra
.736 .768 .879 r
.6755 .40651 .6763 .40749 .67796 .40655 .67716 .4056 Mtetra
.73 .774 .888 r
.67716 .4056 .67796 .40655 .67963 .40572 .67883 .40474 Mtetra
.659 .744 .912 r
.67883 .40474 .67963 .40572 .68133 .4054 .68052 .40422 Mtetra
.311 .526 .902 r
.68052 .40422 .68133 .4054 .68313 .40726 .68226 .40482 Mtetra
.115 .23 .707 r
.68226 .40482 .68313 .40726 .68542 .41895 .68408 .40699 Mtetra
.239 .15 .548 r
.68408 .40699 .68542 .41895 .6968 .61183 .68621 .4154 Mtetra
.056 0 .442 r
.68621 .4154 .6968 .61183 .69873 .6139 .69763 .60789 Mtetra
.313 .249 .623 r
.69763 .60789 .69873 .6139 .70057 .61417 .69963 .61138 Mtetra
.338 .363 .74 r
.69963 .61138 .70057 .61417 .70238 .6139 .70153 .61286 Mtetra
.438 .645 .945 r
.70153 .61286 .70238 .6139 .70419 .6135 .70338 .61304 Mtetra
.568 .86 .996 r
.70338 .61304 .70419 .6135 .706 .613 .70519 .61258 Mtetra
.659 .9 .98 r
.70519 .61258 .706 .613 .7078 .61241 .70698 .61186 Mtetra
.577 .838 .994 r
.70698 .61186 .7078 .61241 .70962 .61216 .7088 .61144 Mtetra
.587 .795 .979 r
.7088 .61144 .70962 .61216 .71145 .61188 .71061 .61107 Mtetra
.688 .808 .939 r
.71061 .61107 .71145 .61188 .71324 .61107 .71242 .61037 Mtetra
.871 .852 .821 r
.71242 .61037 .71324 .61107 .71491 .60804 .71415 .60841 Mtetra
.973 .926 .631 r
.71415 .60841 .71491 .60804 .71613 .59694 .71578 .60462 Mtetra
0 0 .313 r
.71578 .60462 .71613 .59694 .7069 .40088 .71714 .59604 Mtetra
.087 0 .447 r
.71714 .59604 .7069 .40088 .70848 .39825 .70842 .41019 Mtetra
.579 .33 .503 r
.70842 .41019 .70848 .39825 .71018 .39762 .71023 .41127 Mtetra
.578 .333 .508 r
.71023 .41127 .71018 .39762 .7119 .39745 .71204 .41242 Mtetra
.223 .066 .446 r
.71204 .41242 .7119 .39745 .71359 .39668 .71314 .40139 Mtetra
.002 0 .274 r
.71314 .40139 .71359 .39668 .71525 .39547 .71458 .39631 Mtetra
.797 .906 .505 r
.71458 .39631 .71525 .39547 .71692 .39434 .71615 .39345 Mtetra
.81 .806 .847 r
.71615 .39345 .71692 .39434 .71861 .39353 .7178 .39205 Mtetra
.668 .66 .833 r
.7178 .39205 .71861 .39353 .72032 .39298 .7195 .39143 Mtetra
.626 .632 .837 r
.7195 .39143 .72032 .39298 .72203 .3925 .72122 .39105 Mtetra
.638 .652 .847 r
.72122 .39105 .72203 .3925 .72374 .392 .72294 .39061 Mtetra
.656 .67 .851 r
.72294 .39061 .72374 .392 .72545 .39145 .72465 .39008 Mtetra
.651 .669 .854 r
.72465 .39008 .72545 .39145 .72717 .39092 .72636 .38957 Mtetra
.636 .666 .862 r
.72636 .38957 .72717 .39092 .72888 .39042 .72808 .38914 Mtetra
.623 .674 .877 r
.72808 .38914 .72888 .39042 .7306 .38994 .72981 .38878 Mtetra
.629 .697 .894 r
.72981 .38878 .7306 .38994 .73231 .38945 .73153 .38839 Mtetra
.665 .733 .9 r
.73153 .38839 .73231 .38945 .73403 .38888 .73325 .38783 Mtetra
.696 .746 .89 r
.73325 .38783 .73403 .38888 .73574 .38826 .73495 .38712 Mtetra
.698 .73 .875 r
.73495 .38712 .73574 .38826 .73745 .38762 .73666 .38639 Mtetra
.681 .706 .866 r
.73666 .38639 .73745 .38762 .73916 .38701 .73837 .38573 Mtetra
.665 .691 .865 r
.73837 .38573 .73916 .38701 .74088 .38644 .74009 .38516 Mtetra
.66 .69 .867 r
.74009 .38516 .74088 .38644 .7426 .38587 .74181 .38461 Mtetra
.66 .693 .869 r
.74181 .38461 .7426 .38587 .74432 .38531 .74353 .38406 Mtetra
.662 .695 .871 r
.74353 .38406 .74432 .38531 .74604 .38476 .74525 .38351 Mtetra
.661 .695 .871 r
.74525 .38351 .74604 .38476 .74776 .38421 .74697 .38296 Mtetra
.66 .695 .871 r
.74697 .38296 .74776 .38421 .74949 .38366 .7487 .38241 Mtetra
.7487 .38241 .74949 .38366 .75121 .38311 .75043 .38186 Mtetra
.75043 .38186 .75121 .38311 .75294 .38256 .75215 .38131 Mtetra
.662 .695 .871 r
.75215 .38131 .75294 .38256 .75467 .38201 .75388 .38075 Mtetra
.663 .696 .87 r
.75388 .38075 .75467 .38201 .7564 .38145 .75561 .38019 Mtetra
.75561 .38019 .7564 .38145 .75812 .38089 .75734 .37962 Mtetra
.664 .695 .869 r
.75734 .37962 .75812 .38089 .75985 .38033 .75907 .37905 Mtetra
.664 .693 .867 r
.75907 .37905 .75985 .38033 .76159 .37977 .7608 .37848 Mtetra
.659 .688 .866 r
.7608 .37848 .76159 .37977 .76332 .37923 .76253 .37793 Mtetra
.645 .681 .869 r
.76253 .37793 .76332 .37923 .76505 .37872 .76427 .37746 Mtetra
.631 .681 .879 r
.76427 .37746 .76505 .37872 .76679 .37823 .76602 .37705 Mtetra
.635 .699 .892 r
.76602 .37705 .76679 .37823 .76853 .37773 .76776 .37663 Mtetra
.688 .735 .887 r
.76776 .37663 .76853 .37773 .77027 .37712 .76949 .37595 Mtetra
.725 .735 .859 r
.76949 .37595 .77027 .37712 .77199 .37641 .7712 .37503 Mtetra
.681 .685 .847 r
.7712 .37503 .77199 .37641 .77372 .37576 .77293 .37434 Mtetra
.548 .615 .872 r
.77293 .37434 .77372 .37576 .77546 .3752 .77471 .37433 Mtetra
0 .329 .804 r
.77471 .37433 .77546 .3752 .77722 .37483 .77659 .3755 Mtetra
.813 .37 .189 r
.77659 .3755 .77722 .37483 .77901 .37494 .77861 .37843 Mtetra
.972 .669 .377 r
.77861 .37843 .77901 .37494 .78095 .37678 .79574 .57063 Mtetra
.573 .354 .545 r
.79574 .57063 .78095 .37678 .79824 .56907 .79847 .58086 Mtetra
.612 .352 .5 r
.79847 .58086 .79824 .56907 .80125 .58284 .80058 .58343 Mtetra
.525 0 0 r
.80058 .58343 .80125 .58284 .80333 .58488 .80255 .58409 Mtetra
.663 .813 .955 r
.80255 .58409 .80333 .58488 .80521 .58449 .80441 .58346 Mtetra
.744 .783 .884 r
.80441 .58346 .80521 .58449 .80704 .58351 .80624 .58243 Mtetra
.738 .772 .88 r
.80624 .58243 .80704 .58351 .80887 .58246 .80807 .58142 Mtetra
.663 .754 .918 r
.80807 .58142 .80887 .58246 .81074 .58182 .80994 .58082 Mtetra
.636 .752 .932 r
.80994 .58082 .81074 .58182 .81261 .58125 .81182 .58033 Mtetra
.554 .737 .961 r
.81182 .58033 .81261 .58125 .81449 .58084 .81372 .58012 Mtetra
.411 .716 .986 r
.81372 .58012 .81449 .58084 .81639 .58063 .81565 .58017 Mtetra
.461 .815 .997 r
.81565 .58017 .81639 .58063 .81829 .58034 .81755 .57991 Mtetra
.742 .929 .951 r
.81755 .57991 .81829 .58034 .82018 .5799 .81938 .57887 Mtetra
.891 .806 .758 r
.81938 .57887 .82018 .5799 .82205 .57923 .82108 .57626 Mtetra
.851 .653 .635 r
.82108 .57626 .82205 .57923 .82386 .57794 .82257 .5712 Mtetra
.974 .674 .384 r
.82257 .5712 .82386 .57794 .8255 .57468 .80711 .37424 Mtetra
.571 .357 .551 r
.80711 .37424 .8255 .57468 .80975 .37615 .80827 .36687 Mtetra
.655 .456 .602 r
.80827 .36687 .80975 .37615 .81068 .36621 .80981 .36379 Mtetra
.733 .612 .723 r
.80981 .36379 .81068 .36621 .81223 .36335 .81147 .36215 Mtetra
.656 .706 .885 r
.81147 .36215 .81223 .36335 .81398 .36262 .81324 .36162 Mtetra
.567 .71 .938 r
.81324 .36162 .81398 .36262 .81577 .36238 .81504 .36142 Mtetra
.557 .715 .946 r
.81504 .36142 .81577 .36238 .81758 .36224 .81684 .36125 Mtetra
.658 .751 .918 r
.81684 .36125 .81758 .36224 .81935 .36171 .81861 .3607 Mtetra
.67 .753 .913 r
.81861 .3607 .81935 .36171 .82112 .36114 .82037 .36011 Mtetra
.704 .759 .894 r
.82037 .36011 .82112 .36114 .82287 .36041 .82213 .35934 Mtetra
.749 .767 .868 r
.82213 .35934 .82287 .36041 .8246 .35939 .82385 .3583 Mtetra
.67 .737 .9 r
.82385 .3583 .8246 .35939 .82636 .35879 .82562 .35771 Mtetra
.282 .53 .912 r
.82562 .35771 .82636 .35879 .82825 .35946 .82751 .35835 Mtetra
.863 .466 0 r
.82751 .35835 .82825 .35946 .83073 .36618 .82996 .36491 Mtetra
.975 .667 .333 r
.82996 .36491 .83073 .36618 .85198 .56747 .8512 .56638 Mtetra
.646 .205 0 r
.8512 .56638 .85198 .56747 .85427 .57099 .8535 .56996 Mtetra
.387 .622 .946 r
.8535 .56996 .85427 .57099 .85626 .57131 .85548 .57028 Mtetra
.699 .775 .91 r
.85548 .57028 .85626 .57131 .85814 .57053 .85736 .5695 Mtetra
.881 .812 .776 r
.85736 .5695 .85814 .57053 .85987 .56822 .85909 .56711 Mtetra
.98 .747 .513 r
.85909 .56711 .85987 .56822 .86095 .55937 .86006 .55715 Mtetra
.977 .674 .351 r
.86006 .55715 .86095 .55937 .8427 .35716 .84191 .35559 Mtetra
.901 .736 .668 r
.84191 .35559 .8427 .35716 .84413 .35308 .84336 .35171 Mtetra
.702 .7 .845 r
.84336 .35171 .84413 .35308 .84587 .35216 .84512 .35088 Mtetra
.588 .664 .891 r
.84512 .35088 .84587 .35216 .84768 .35185 .84694 .35066 Mtetra
.555 .665 .91 r
.84694 .35066 .84768 .35185 .84951 .35165 .84877 .35056 Mtetra
.735 .761 .873 r
.84877 .35056 .84951 .35165 .85125 .35067 .85052 .3496 Mtetra
.669 .741 .904 r
.85052 .3496 .85125 .35067 .85303 .35006 .8523 .349 Mtetra
.379 .595 .93 r
.8523 .349 .85303 .35006 .85492 .35046 .85419 .34939 Mtetra
.8 .386 0 r
.85419 .34939 .85492 .35046 .85732 .35572 .85659 .35468 Mtetra
.973 .663 .318 r
.85659 .35468 .85732 .35572 .88047 .55822 .87972 .55725 Mtetra
.728 .285 0 r
.87972 .55725 .88047 .55822 .88289 .56242 .88213 .56143 Mtetra
.501 .698 .958 r
.88213 .56143 .88289 .56242 .88487 .56239 .88411 .5614 Mtetra
.698 .785 .919 r
.88411 .5614 .88487 .56239 .88677 .56162 .88601 .56062 Mtetra
.739 .798 .899 r
.88601 .56062 .88677 .56162 .88864 .56062 .88788 .55961 Mtetra
.499 .692 .954 r
.88788 .55961 .88864 .56062 .89062 .56061 .88987 .5596 Mtetra
.633 .755 .936 r
.88987 .5596 .89062 .56061 .89256 .56014 .8918 .55911 Mtetra
.822 .813 .842 r
.8918 .55911 .89256 .56014 .89437 .55857 .89361 .55749 Mtetra
.981 .757 .525 r
.89361 .55749 .89437 .55857 .8955 .5507 .89465 .54883 Mtetra
.976 .671 .332 r
.89465 .54883 .8955 .5507 .87503 .34742 .87425 .3458 Mtetra
.914 .737 .649 r
.87425 .3458 .87503 .34742 .87639 .34287 .87564 .34148 Mtetra
.704 .7 .843 r
.87564 .34148 .87639 .34287 .87815 .34194 .87741 .34063 Mtetra
.581 .656 .888 r
.87741 .34063 .87815 .34194 .87999 .34167 .87926 .34044 Mtetra
.492 .624 .908 r
.87926 .34044 .87999 .34167 .88187 .34172 .88114 .34058 Mtetra
.633 .713 .904 r
.88114 .34058 .88187 .34172 .88368 .34124 .88296 .34014 Mtetra
.644 .725 .907 r
.88296 .34014 .88368 .34124 .8855 .34074 .88478 .33965 Mtetra
.658 .735 .906 r
.88478 .33965 .8855 .34074 .88731 .34017 .88659 .33909 Mtetra
.718 .762 .888 r
.88659 .33909 .88731 .34017 .88907 .33915 .88837 .33823 Mtetra
.683 .785 .927 r
.88837 .33823 .88907 .33915 .89086 .33846 .89017 .33756 Mtetra
.572 .742 .957 r
.89017 .33756 .89086 .33846 .89274 .33845 .89202 .3373 Mtetra
.111 .403 .855 r
.89202 .3373 .89274 .33845 .89504 .34203 .89404 .33847 Mtetra
.2 .232 .67 r
.89404 .33847 .89504 .34203 .92052 .54273 .89629 .34161 Mtetra
.156 .067 .496 r
.89629 .34161 .92052 .54273 .92331 .54935 .92121 .5368 Mtetra
.302 .206 .577 r
.92121 .5368 .92331 .54935 .92542 .55014 .92422 .54531 Mtetra
.373 .318 .667 r
.92422 .54531 .92542 .55014 .92742 .55009 .92654 .54785 Mtetra
.386 .44 .795 r
.92654 .54785 .92742 .55009 .92938 .5496 .92868 .54891 Mtetra
.525 .676 .933 r
.30121 .72498 .3022 .726 .30375 .72569 .30274 .72495 Mtetra
.694 .789 .924 r
.30274 .72495 .30375 .72569 .30532 .725 .30432 .72431 Mtetra
.755 .807 .894 r
.30432 .72431 .30532 .725 .30691 .72416 .30591 .72338 Mtetra
.408 .684 .974 r
.30591 .72338 .30691 .72416 .30843 .72438 .30744 .72348 Mtetra
.589 .728 .94 r
.30744 .72348 .30843 .72438 .30998 .72424 .30899 .72324 Mtetra
.745 .743 .85 r
.30899 .72324 .30998 .72424 .31157 .72336 .31059 .72226 Mtetra
.898 .72 .653 r
.31059 .72226 .31157 .72336 .31344 .71788 .31247 .71664 Mtetra
.937 .686 .533 r
.31247 .71664 .31344 .71788 .32653 .52296 .3256 .52206 Mtetra
.906 .728 .65 r
.3256 .52206 .32653 .52296 .32832 .51735 .32738 .5166 Mtetra
.775 .784 .86 r
.32738 .5166 .32832 .51735 .32983 .51633 .32889 .51554 Mtetra
.6 .744 .945 r
.32889 .51554 .32983 .51633 .3313 .51612 .33036 .51526 Mtetra
.437 .666 .959 r
.33036 .51526 .3313 .51612 .33274 .5163 .33181 .51537 Mtetra
.635 .723 .911 r
.33181 .51537 .33274 .5163 .33422 .51595 .33329 .51501 Mtetra
.655 .726 .902 r
.33329 .51501 .33422 .51595 .3357 .51548 .33478 .51457 Mtetra
.665 .734 .901 r
.33478 .51457 .3357 .51548 .33719 .51495 .33626 .51408 Mtetra
.763 .761 .851 r
.33626 .51408 .33719 .51495 .33872 .51383 .33778 .51306 Mtetra
.723 .779 .897 r
.33778 .51306 .33872 .51383 .34022 .51301 .33928 .51232 Mtetra
.502 .741 .98 r
.33928 .51232 .34022 .51301 .34169 .51284 .34075 .51223 Mtetra
.913 .525 .259 r
.34075 .51223 .34169 .51284 .34296 .51641 .34201 .51591 Mtetra
.94 .683 .52 r
.34201 .51591 .34296 .51641 .33394 .7104 .33295 .70964 Mtetra
.935 .587 .341 r
.33295 .70964 .33394 .7104 .33518 .71627 .3342 .7153 Mtetra
.274 .568 .936 r
.3342 .7153 .33518 .71627 .33672 .71667 .33573 .71573 Mtetra
.684 .746 .898 r
.33573 .71573 .33672 .71667 .33831 .71601 .33732 .71513 Mtetra
.758 .769 .862 r
.33732 .71513 .33831 .71601 .33992 .71493 .33893 .71409 Mtetra
.495 .711 .967 r
.33893 .71409 .33992 .71493 .34148 .71498 .3405 .71406 Mtetra
.569 .718 .942 r
.3405 .71406 .34148 .71498 .34304 .71489 .34207 .71387 Mtetra
.729 .74 .861 r
.34207 .71387 .34304 .71489 .34465 .71412 .34367 .713 Mtetra
.892 .726 .669 r
.34367 .713 .34465 .71412 .34644 .70949 .34548 .70826 Mtetra
.94 .687 .526 r
.34548 .70826 .34644 .70949 .35778 .5143 .35686 .51333 Mtetra
.912 .723 .633 r
.35686 .51333 .35778 .5143 .35959 .50767 .35866 .50691 Mtetra
.812 .786 .828 r
.35866 .50691 .35959 .50767 .36113 .50629 .3602 .50551 Mtetra
.621 .756 .943 r
.3602 .50551 .36113 .50629 .36262 .506 .3617 .50517 Mtetra
.452 .681 .963 r
.3617 .50517 .36262 .506 .36409 .50614 .36317 .50524 Mtetra
.643 .733 .914 r
.36317 .50524 .36409 .50614 .36559 .50563 .36467 .50484 Mtetra
.671 .766 .921 r
.36467 .50484 .36559 .50563 .3671 .50505 .36617 .50432 Mtetra
.643 .775 .944 r
.36617 .50432 .3671 .50505 .36859 .50477 .36767 .5039 Mtetra
.627 .736 .926 r
.36767 .5039 .36859 .50477 .37004 .50559 .36917 .50355 Mtetra
.57 .538 .78 r
.36917 .50355 .37004 .50559 .37141 .50791 .37066 .50352 Mtetra
.509 .397 .662 r
.37066 .50352 .37141 .50791 .37243 .51822 .37211 .50417 Mtetra
.402 .25 .558 r
.37211 .50417 .37243 .51822 .36562 .70186 .37338 .50904 Mtetra
0 0 .301 r
.37338 .50904 .36562 .70186 .36706 .70502 .36623 .70091 Mtetra
0 0 .464 r
.36623 .70091 .36706 .70502 .36857 .70638 .36761 .70521 Mtetra
0 .338 .819 r
.36761 .70521 .36857 .70638 .37013 .70687 .36915 .70622 Mtetra
.548 .778 .984 r
.36915 .70622 .37013 .70687 .37172 .70663 .37074 .70599 Mtetra
.796 .824 .873 r
.37074 .70599 .37172 .70663 .37335 .70551 .37237 .70477 Mtetra
.912 .757 .676 r
.37237 .70477 .37335 .70551 .37513 .70087 .37415 .70027 Mtetra
.944 .689 .519 r
.37415 .70027 .37513 .70087 .38494 .50544 .38399 .5052 Mtetra
.946 .761 .62 r
.38399 .5052 .38494 .50544 .3867 .49904 .38577 .49839 Mtetra
.841 .808 .818 r
.38577 .49839 .3867 .49904 .38826 .49748 .38734 .49677 Mtetra
.622 .774 .954 r
.38734 .49677 .38826 .49748 .38976 .49717 .38885 .4964 Mtetra
.422 .683 .972 r
.38885 .4964 .38976 .49717 .39125 .49732 .39034 .4965 Mtetra
.553 .723 .953 r
.39034 .4965 .39125 .49732 .39276 .49719 .39184 .49635 Mtetra
.618 .741 .934 r
.39184 .49635 .39276 .49719 .39427 .49685 .39336 .49602 Mtetra
.623 .746 .935 r
.39336 .49602 .39427 .49685 .39578 .49647 .39487 .49567 Mtetra
.631 .756 .937 r
.39487 .49567 .39578 .49647 .3973 .49607 .39639 .49529 Mtetra
.64 .763 .937 r
.39639 .49529 .3973 .49607 .39882 .49565 .3979 .49488 Mtetra
.65 .769 .936 r
.3979 .49488 .39882 .49565 .40034 .49519 .39942 .49443 Mtetra
.66 .775 .934 r
.39942 .49443 .40034 .49519 .40186 .49471 .40095 .49395 Mtetra
.671 .776 .929 r
.40095 .49395 .40186 .49471 .40339 .4942 .40247 .49343 Mtetra
.682 .777 .923 r
.40247 .49343 .40339 .4942 .40491 .49363 .404 .49286 Mtetra
.699 .781 .915 r
.404 .49286 .40491 .49363 .40644 .49295 .40553 .49223 Mtetra
.708 .794 .918 r
.40553 .49223 .40644 .49295 .40798 .49221 .40706 .49155 Mtetra
.706 .811 .93 r
.40706 .49155 .40798 .49221 .40951 .49148 .4086 .49089 Mtetra
.688 .824 .948 r
.4086 .49089 .40951 .49148 .41105 .49085 .41013 .49028 Mtetra
.672 .828 .958 r
.41013 .49028 .41105 .49085 .41258 .4903 .41166 .48973 Mtetra
.665 .826 .961 r
.41166 .48973 .41258 .4903 .41411 .48978 .41319 .4892 Mtetra
.662 .823 .961 r
.41319 .4892 .41411 .48978 .41564 .48926 .41472 .48868 Mtetra
.66 .821 .961 r
.41472 .48868 .41564 .48926 .41717 .48875 .41625 .48816 Mtetra
.658 .821 .962 r
.41625 .48816 .41717 .48875 .4187 .48824 .41779 .48766 Mtetra
.656 .821 .963 r
.41779 .48766 .4187 .48824 .42023 .48773 .41932 .48715 Mtetra
.655 .822 .964 r
.41932 .48715 .42023 .48773 .42177 .48723 .42085 .48665 Mtetra
.654 .824 .965 r
.42085 .48665 .42177 .48723 .4233 .48672 .42239 .48615 Mtetra
.676 .829 .957 r
.42239 .48615 .4233 .48672 .42484 .48607 .42393 .48558 Mtetra
.671 .852 .969 r
.42393 .48558 .42484 .48607 .42638 .48542 .42547 .48501 Mtetra
.615 .859 .989 r
.42547 .48501 .42638 .48542 .42791 .48506 .427 .48455 Mtetra
.43 .764 .996 r
.427 .48455 .42791 .48506 .42942 .48575 .42853 .48448 Mtetra
.438 .572 .891 r
.42853 .48448 .42942 .48575 .43087 .48812 .43005 .48477 Mtetra
.519 .435 .701 r
.43005 .48477 .43087 .48812 .4322 .49518 .43156 .4852 Mtetra
.563 .387 .6 r
.43156 .4852 .4322 .49518 .4287 .67849 .43309 .48523 Mtetra
.56 .348 .55 r
.43309 .48523 .4287 .67849 .43031 .67878 .43463 .48476 Mtetra
.56 .349 .55 r
.43463 .48476 .43031 .67878 .43199 .67639 .43618 .4841 Mtetra
.56 .348 .55 r
.43618 .4841 .43199 .67639 .43368 .67394 .43772 .4835 Mtetra
.43772 .4835 .43368 .67394 .43531 .67323 .43927 .48298 Mtetra
.43927 .48298 .43531 .67323 .43695 .67249 .44082 .48247 Mtetra
.44082 .48247 .43695 .67249 .43859 .67181 .44237 .48195 Mtetra
.44237 .48195 .43859 .67181 .44023 .67123 .44391 .48144 Mtetra
.44391 .48144 .44023 .67123 .44187 .67072 .44546 .48093 Mtetra
.56 .349 .55 r
.44546 .48093 .44187 .67072 .4436 .66614 .44702 .48012 Mtetra
.561 .349 .55 r
.44702 .48012 .4436 .66614 .44909 .49698 .44858 .47926 Mtetra
.567 .373 .578 r
.44858 .47926 .44909 .49698 .44697 .66088 .45012 .47903 Mtetra
.554 .344 .55 r
.45012 .47903 .44697 .66088 .44826 .67607 .45161 .48151 Mtetra
0 0 .345 r
.45161 .48151 .44826 .67607 .44979 .68083 .44896 .67487 Mtetra
0 0 .435 r
.44896 .67487 .44979 .68083 .45138 .68303 .45046 .6813 Mtetra
.037 .269 .766 r
.45046 .6813 .45138 .68303 .45301 .68367 .45207 .68276 Mtetra
.589 .733 .943 r
.45207 .68276 .45301 .68367 .45466 .68331 .45371 .68249 Mtetra
.706 .785 .913 r
.45371 .68249 .45466 .68331 .45632 .68268 .45537 .68177 Mtetra
.702 .765 .901 r
.45537 .68177 .45632 .68268 .45797 .68206 .45703 .68106 Mtetra
.654 .734 .909 r
.45703 .68106 .45797 .68206 .45963 .68157 .45868 .68057 Mtetra
.652 .733 .909 r
.45868 .68057 .45963 .68157 .46128 .68112 .46034 .68009 Mtetra
.64 .725 .91 r
.46034 .68009 .46128 .68112 .46293 .68075 .462 .67966 Mtetra
.629 .709 .904 r
.462 .67966 .46293 .68075 .46459 .68047 .46365 .67928 Mtetra
.633 .691 .887 r
.46365 .67928 .46459 .68047 .46624 .68016 .46531 .67889 Mtetra
.648 .682 .868 r
.46531 .67889 .46624 .68016 .4679 .67972 .46697 .67842 Mtetra
.665 .684 .858 r
.46697 .67842 .4679 .67972 .46956 .67913 .46863 .67786 Mtetra
.669 .691 .862 r
.46863 .67786 .46956 .67913 .47123 .67849 .47029 .67728 Mtetra
.654 .695 .876 r
.47029 .67728 .47123 .67849 .47289 .67803 .47196 .67678 Mtetra
.635 .682 .878 r
.47196 .67678 .47289 .67803 .47455 .67774 .47362 .67638 Mtetra
.652 .671 .855 r
.47362 .67638 .47455 .67774 .47622 .67719 .47528 .67588 Mtetra
.707 .698 .839 r
.47528 .67588 .47622 .67719 .47789 .67575 .47695 .67505 Mtetra
.804 .825 .867 r
.47695 .67505 .47789 .67575 .4796 .6725 .47863 .67374 Mtetra
0 0 0 r
.47863 .67374 .4796 .6725 .48134 .66607 .48031 .67227 Mtetra
.469 .207 .433 r
.48031 .67227 .48134 .66607 .48524 .47935 .48199 .67106 Mtetra
.557 .342 .544 r
.48199 .67106 .48524 .47935 .48683 .47711 .48366 .67052 Mtetra
.558 .343 .544 r
.48366 .67052 .48683 .47711 .48839 .47829 .48533 .67019 Mtetra
.48533 .67019 .48839 .47829 .48989 .4852 .48699 .6701 Mtetra
.48699 .6701 .48989 .4852 .48975 .65528 .48866 .67012 Mtetra
.538 .303 .506 r
.48866 .67012 .48975 .65528 .49143 .65353 .49033 .6695 Mtetra
.486 .261 .498 r
.49033 .6695 .49143 .65353 .49473 .47353 .49203 .66668 Mtetra
0 0 .354 r
.49203 .66668 .49473 .47353 .49637 .46707 .49543 .47325 Mtetra
0 0 .008 r
.49543 .47325 .49637 .46707 .49797 .46388 .49708 .46397 Mtetra
.951 .912 .743 r
.49708 .46397 .49797 .46388 .49955 .46212 .49868 .46125 Mtetra
.722 .77 .89 r
.49868 .46125 .49955 .46212 .50113 .46145 .50026 .46047 Mtetra
.618 .716 .916 r
.50026 .46047 .50113 .46145 .50271 .46106 .50184 .46014 Mtetra
.59 .72 .934 r
.50184 .46014 .50271 .46106 .50429 .46072 .50342 .4599 Mtetra
.658 .766 .93 r
.50342 .4599 .50429 .46072 .50587 .46023 .505 .45941 Mtetra
.654 .766 .931 r
.505 .45941 .50587 .46023 .50745 .45974 .50658 .45893 Mtetra
.654 .768 .933 r
.50658 .45893 .50745 .45974 .50904 .45925 .50817 .45845 Mtetra
.655 .771 .935 r
.50817 .45845 .50904 .45925 .51062 .45875 .50975 .45797 Mtetra
.651 .774 .939 r
.50975 .45797 .51062 .45875 .51221 .45828 .51134 .4575 Mtetra
.641 .773 .944 r
.51134 .4575 .51221 .45828 .51379 .45786 .51292 .45706 Mtetra
.627 .765 .945 r
.51292 .45706 .51379 .45786 .51538 .45753 .51451 .45667 Mtetra
.629 .75 .935 r
.51451 .45667 .51538 .45753 .51697 .45721 .5161 .45629 Mtetra
.638 .738 .921 r
.5161 .45629 .51697 .45721 .51855 .45684 .51769 .45587 Mtetra
.653 .732 .907 r
.51769 .45587 .51855 .45684 .52014 .45638 .51928 .45541 Mtetra
.662 .734 .903 r
.51928 .45541 .52014 .45638 .52174 .45585 .52087 .4549 Mtetra
.673 .743 .903 r
.52087 .4549 .52174 .45585 .52333 .45525 .52246 .45435 Mtetra
.686 .759 .907 r
.52246 .45435 .52333 .45525 .52492 .45455 .52406 .45374 Mtetra
.689 .781 .921 r
.52406 .45374 .52492 .45455 .52651 .45384 .52565 .45313 Mtetra
.682 .801 .938 r
.52565 .45313 .52651 .45384 .52811 .45318 .52725 .45253 Mtetra
.665 .814 .955 r
.52725 .45253 .52811 .45318 .5297 .45262 .52884 .45199 Mtetra
.658 .817 .96 r
.52884 .45199 .5297 .45262 .5313 .45209 .53044 .45146 Mtetra
.656 .818 .961 r
.53044 .45146 .5313 .45209 .5329 .45157 .53204 .45094 Mtetra
.657 .818 .961 r
.53204 .45094 .5329 .45157 .53449 .45104 .53363 .45041 Mtetra
.656 .819 .962 r
.53363 .45041 .53449 .45104 .53609 .45052 .53523 .44989 Mtetra
.654 .819 .962 r
.53523 .44989 .53609 .45052 .53769 .45 .53683 .44937 Mtetra
.654 .819 .963 r
.53683 .44937 .53769 .45 .53929 .44949 .53844 .44886 Mtetra
.653 .819 .963 r
.53844 .44886 .53929 .44949 .54089 .44897 .54004 .44835 Mtetra
.652 .819 .964 r
.54004 .44835 .54089 .44897 .5425 .44846 .54164 .44783 Mtetra
.651 .818 .964 r
.54164 .44783 .5425 .44846 .5441 .44796 .54325 .44733 Mtetra
.65 .818 .964 r
.54325 .44733 .5441 .44796 .5457 .44746 .54485 .44682 Mtetra
.649 .817 .964 r
.54485 .44682 .5457 .44746 .54731 .44696 .54646 .44632 Mtetra
.651 .816 .963 r
.54646 .44632 .54731 .44696 .54892 .44645 .54806 .44581 Mtetra
.647 .815 .964 r
.54806 .44581 .54892 .44645 .55052 .44596 .54967 .44532 Mtetra
.639 .811 .965 r
.54967 .44532 .55052 .44596 .55213 .44552 .55128 .44485 Mtetra
.623 .797 .966 r
.55128 .44485 .55213 .44552 .55374 .44519 .55289 .44443 Mtetra
.628 .778 .953 r
.55289 .44443 .55374 .44519 .55536 .44487 .5545 .44402 Mtetra
.64 .758 .934 r
.5545 .44402 .55536 .44487 .55697 .44452 .55612 .44359 Mtetra
.659 .745 .913 r
.55612 .44359 .55697 .44452 .55858 .44406 .55773 .44309 Mtetra
.668 .739 .903 r
.55773 .44309 .55858 .44406 .56019 .44354 .55934 .44255 Mtetra
.677 .738 .897 r
.55934 .44255 .56019 .44354 .56181 .44295 .56096 .44197 Mtetra
.689 .745 .894 r
.56096 .44197 .56181 .44295 .56342 .44225 .56257 .44134 Mtetra
.692 .759 .903 r
.56257 .44134 .56342 .44225 .56503 .44154 .56419 .44069 Mtetra
.689 .774 .916 r
.56419 .44069 .56503 .44154 .56665 .44086 .5658 .44006 Mtetra
.675 .782 .93 r
.5658 .44006 .56665 .44086 .56827 .44029 .56742 .43949 Mtetra
.67 .781 .933 r
.56742 .43949 .56827 .44029 .56988 .43975 .56904 .43894 Mtetra
.667 .777 .932 r
.56904 .43894 .56988 .43975 .5715 .43923 .57066 .4384 Mtetra
.667 .773 .929 r
.57066 .4384 .5715 .43923 .57312 .4387 .57228 .43786 Mtetra
.666 .772 .929 r
.57228 .43786 .57312 .4387 .57474 .43817 .5739 .43733 Mtetra
.666 .771 .928 r
.5739 .43733 .57474 .43817 .57637 .43764 .57552 .4368 Mtetra
.668 .771 .927 r
.57552 .4368 .57637 .43764 .57799 .4371 .57715 .43625 Mtetra
.666 .769 .926 r
.57715 .43625 .57799 .4371 .57961 .43657 .57877 .43572 Mtetra
.668 .768 .925 r
.57877 .43572 .57961 .43657 .58124 .43603 .5804 .43517 Mtetra
.735 .784 .892 r
.5804 .43517 .58124 .43603 .58286 .4353 .58202 .43431 Mtetra
.673 .741 .901 r
.58202 .43431 .58286 .4353 .58449 .43474 .58365 .43375 Mtetra
.499 .668 .939 r
.58365 .43375 .58449 .43474 .58612 .43455 .58528 .43378 Mtetra
.83 .372 0 r
.58528 .43378 .58612 .43455 .58779 .43587 .58698 .43686 Mtetra
.964 .682 .451 r
.58698 .43686 .58779 .43587 .58948 .43873 .59242 .63072 Mtetra
.572 .354 .546 r
.59242 .63072 .58948 .43873 .59134 .44932 .59433 .63938 Mtetra
.558 .343 .544 r
.59433 .63938 .59134 .44932 .59303 .4513 .59608 .63959 Mtetra
.557 .342 .544 r
.59608 .63959 .59303 .4513 .5946 .44733 .59782 .63895 Mtetra
.59782 .63895 .5946 .44733 .59634 .45104 .59955 .63805 Mtetra
.559 .343 .544 r
.59955 .63805 .59634 .45104 .6021 .63494 .60132 .63854 Mtetra
.567 .252 .395 r
.60132 .63854 .6021 .63494 .60394 .63863 .60308 .63899 Mtetra
.369 0 0 r
.60308 .63899 .60394 .63863 .60573 .64038 .60484 .63925 Mtetra
.586 .693 .916 r
.60484 .63925 .60573 .64038 .60749 .64044 .60659 .63902 Mtetra
.629 .659 .86 r
.60659 .63902 .60749 .64044 .60924 .64008 .60834 .63862 Mtetra
.649 .663 .85 r
.60834 .63862 .60924 .64008 .61098 .63947 .61009 .63811 Mtetra
.586 .651 .881 r
.61009 .63811 .61098 .63947 .61273 .63906 .61185 .63792 Mtetra
.649 .715 .896 r
.61185 .63792 .61273 .63906 .61448 .63845 .6136 .63742 Mtetra
.755 .77 .865 r
.6136 .63742 .61448 .63845 .61622 .63746 .61533 .63634 Mtetra
.91 .758 .681 r
.61533 .63634 .61622 .63746 .61792 .63503 .61699 .63227 Mtetra
.966 .688 .455 r
.61699 .63227 .61792 .63503 .61958 .63108 .61356 .44095 Mtetra
.583 .366 .552 r
.61356 .44095 .61958 .63108 .6211 .62227 .61484 .42717 Mtetra
.561 .35 .55 r
.61484 .42717 .6211 .62227 .62276 .61888 .61647 .42572 Mtetra
.56 .348 .55 r
.61647 .42572 .62276 .61888 .62456 .62025 .61812 .42531 Mtetra
.559 .348 .55 r
.61812 .42531 .62456 .62025 .62628 .61851 .61978 .42519 Mtetra
.561 .349 .55 r
.61978 .42519 .62628 .61851 .62237 .42941 .62141 .42386 Mtetra
.641 .473 .64 r
.62141 .42386 .62237 .42941 .6239 .42465 .62303 .42245 Mtetra
.709 .607 .741 r
.62303 .42245 .6239 .42465 .62548 .422 .62467 .42124 Mtetra
.702 .804 .928 r
.62467 .42124 .62548 .422 .62712 .42099 .62631 .42054 Mtetra
.619 .865 .989 r
.62631 .42054 .62712 .42099 .62877 .42047 .62797 .42003 Mtetra
.583 .856 .995 r
.62797 .42003 .62877 .42047 .63043 .42016 .62963 .41959 Mtetra
.67 .849 .968 r
.62963 .41959 .63043 .42016 .63208 .41945 .63128 .41898 Mtetra
.646 .87 .983 r
.63128 .41898 .63208 .41945 .63374 .41884 .63293 .41841 Mtetra
.586 .86 .995 r
.63293 .41841 .63374 .41884 .6354 .41857 .63459 .41796 Mtetra
.388 .721 .989 r
.63459 .41796 .6354 .41857 .63712 .41973 .63627 .418 Mtetra
.49 .536 .831 r
.63627 .418 .63712 .41973 .6389 .42264 .63796 .4183 Mtetra
.537 .423 .672 r
.63796 .4183 .6389 .42264 .64114 .43827 .63966 .4187 Mtetra
.574 .377 .576 r
.63966 .4187 .64114 .43827 .64916 .61321 .64131 .41795 Mtetra
.56 .349 .55 r
.64131 .41795 .64916 .61321 .65086 .61106 .64297 .41718 Mtetra
.559 .348 .55 r
.64297 .41718 .65086 .61106 .65264 .61082 .64465 .4171 Mtetra
.549 .34 .549 r
.64465 .4171 .65264 .61082 .65476 .61983 .64654 .42256 Mtetra
.02 0 .424 r
.64654 .42256 .65476 .61983 .65669 .6234 .65572 .61962 Mtetra
0 .05 .58 r
.65572 .61962 .65669 .6234 .65855 .62514 .65767 .62376 Mtetra
.353 .526 .888 r
.65767 .62376 .65855 .62514 .66036 .62548 .65949 .62436 Mtetra
.633 .716 .907 r
.65949 .62436 .66036 .62548 .66215 .62511 .66128 .62393 Mtetra
.724 .737 .861 r
.66128 .62393 .66215 .62511 .66391 .62418 .66304 .623 Mtetra
.712 .734 .868 r
.66304 .623 .66391 .62418 .66563 .62218 .66481 .62215 Mtetra
.721 .981 .908 r
.66481 .62215 .66563 .62218 .66729 .61865 .66657 .621 Mtetra
.127 0 .152 r
.66657 .621 .66729 .61865 .6687 .60923 .66829 .61904 Mtetra
.241 .056 .418 r
.66829 .61904 .6687 .60923 .6623 .41597 .66982 .61238 Mtetra
.02 0 .419 r
.66982 .61238 .6623 .41597 .66382 .41177 .66314 .41391 Mtetra
.7 .737 .225 r
.66314 .41391 .66382 .41177 .66542 .4095 .66463 .409 Mtetra
.846 .89 .87 r
.66463 .409 .66542 .4095 .66708 .40855 .66627 .40752 Mtetra
.648 .729 .908 r
.66627 .40752 .66708 .40855 .66876 .40817 .66795 .40705 Mtetra
.554 .668 .913 r
.66795 .40705 .66876 .40817 .67046 .40804 .66965 .40695 Mtetra
.621 .706 .906 r
.66965 .40695 .67046 .40804 .67214 .40766 .67133 .40659 Mtetra
.658 .725 .898 r
.67133 .40659 .67214 .40766 .67382 .40712 .67301 .40608 Mtetra
.666 .733 .9 r
.67301 .40608 .67382 .40712 .6755 .40651 .6747 .40552 Mtetra
.7 .755 .895 r
.6747 .40552 .6755 .40651 .67716 .4056 .67637 .40481 Mtetra
.704 .803 .926 r
.67637 .40481 .67716 .4056 .67883 .40474 .67805 .4041 Mtetra
.663 .83 .964 r
.67805 .4041 .67883 .40474 .68052 .40422 .67973 .40351 Mtetra
.604 .794 .972 r
.67973 .40351 .68052 .40422 .68226 .40482 .68142 .40313 Mtetra
.556 .578 .832 r
.68142 .40313 .68226 .40482 .68408 .40699 .68313 .40313 Mtetra
.499 .412 .688 r
.68313 .40313 .68408 .40699 .68621 .4154 .68489 .40387 Mtetra
.394 .262 .581 r
.68489 .40387 .68621 .4154 .69763 .60789 .68685 .40872 Mtetra
.046 0 .438 r
.68685 .40872 .69763 .60789 .69963 .61138 .6986 .6068 Mtetra
.063 .105 .594 r
.6986 .6068 .69963 .61138 .70153 .61286 .70066 .61125 Mtetra
.335 .48 .856 r
.70066 .61125 .70153 .61286 .70338 .61304 .70253 .61205 Mtetra
.628 .744 .931 r
.70253 .61205 .70338 .61304 .70519 .61258 .70434 .61162 Mtetra
.717 .78 .902 r
.70434 .61162 .70519 .61258 .70698 .61186 .70613 .61078 Mtetra
.67 .74 .903 r
.70613 .61078 .70698 .61186 .7088 .61144 .70794 .61016 Mtetra
.641 .694 .884 r
.70794 .61016 .7088 .61144 .71061 .61107 .70975 .60969 Mtetra
.664 .687 .861 r
.70975 .60969 .71061 .61107 .71242 .61037 .71156 .60909 Mtetra
.734 .728 .846 r
.71156 .60909 .71242 .61037 .71415 .60841 .71334 .60805 Mtetra
.822 .938 .904 r
.71334 .60805 .71415 .60841 .71578 .60462 .71511 .60665 Mtetra
.182 0 .138 r
.71511 .60665 .71578 .60462 .71714 .59604 .71687 .60512 Mtetra
.526 .275 .478 r
.71687 .60512 .71714 .59604 .70842 .41019 .71867 .60449 Mtetra
.558 .343 .544 r
.71867 .60449 .70842 .41019 .71023 .41127 .72051 .6043 Mtetra
.557 .342 .544 r
.72051 .6043 .71023 .41127 .71204 .41242 .72231 .6035 Mtetra
.551 .337 .544 r
.72231 .6035 .71204 .41242 .71314 .40139 .72389 .59894 Mtetra
.048 0 .435 r
.72389 .59894 .71314 .40139 .71458 .39631 .71402 .39921 Mtetra
0 0 0 r
.71402 .39921 .71458 .39631 .71615 .39345 .7154 .39307 Mtetra
.905 .911 .815 r
.7154 .39307 .71615 .39345 .7178 .39205 .71701 .39106 Mtetra
.691 .755 .901 r
.71701 .39106 .7178 .39205 .7195 .39143 .71871 .39038 Mtetra
.599 .707 .92 r
.71871 .39038 .7195 .39143 .72122 .39105 .72044 .3901 Mtetra
.616 .736 .932 r
.72044 .3901 .72122 .39105 .72294 .39061 .72216 .38973 Mtetra
.654 .769 .933 r
.72216 .38973 .72294 .39061 .72465 .39008 .72387 .38921 Mtetra
.648 .771 .938 r
.72387 .38921 .72465 .39008 .72636 .38957 .72559 .38871 Mtetra
.636 .769 .943 r
.72559 .38871 .72636 .38957 .72808 .38914 .72731 .38826 Mtetra
.629 .759 .94 r
.72731 .38826 .72808 .38914 .72981 .38878 .72903 .38783 Mtetra
.637 .746 .928 r
.72903 .38783 .72981 .38878 .73153 .38839 .73075 .38739 Mtetra
.66 .743 .912 r
.73075 .38739 .73153 .38839 .73325 .38783 .73247 .38685 Mtetra
.679 .756 .909 r
.73247 .38685 .73325 .38783 .73495 .38712 .73418 .38623 Mtetra
.683 .778 .923 r
.73418 .38623 .73495 .38712 .73666 .38639 .73589 .3856 Mtetra
.672 .798 .942 r
.73589 .3856 .73666 .38639 .73837 .38573 .73761 .385 Mtetra
.658 .809 .956 r
.73761 .385 .73837 .38573 .74009 .38516 .73933 .38444 Mtetra
.654 .811 .959 r
.73933 .38444 .74009 .38516 .74181 .38461 .74105 .38389 Mtetra
.653 .812 .96 r
.74105 .38389 .74181 .38461 .74353 .38406 .74277 .38334 Mtetra
.654 .813 .959 r
.74277 .38334 .74353 .38406 .74525 .38351 .7445 .38279 Mtetra
.654 .813 .96 r
.7445 .38279 .74525 .38351 .74697 .38296 .74622 .38224 Mtetra
.74622 .38224 .74697 .38296 .7487 .38241 .74795 .38169 Mtetra
.74795 .38169 .7487 .38241 .75043 .38186 .74967 .38114 Mtetra
.655 .812 .959 r
.74967 .38114 .75043 .38186 .75215 .38131 .7514 .38058 Mtetra
.656 .812 .958 r
.7514 .38058 .75215 .38131 .75388 .38075 .75313 .38002 Mtetra
.658 .812 .957 r
.75313 .38002 .75388 .38075 .75561 .38019 .75486 .37946 Mtetra
.659 .812 .957 r
.75486 .37946 .75561 .38019 .75734 .37962 .75659 .37889 Mtetra
.66 .812 .956 r
.75659 .37889 .75734 .37962 .75907 .37905 .75832 .37832 Mtetra
.661 .812 .956 r
.75832 .37832 .75907 .37905 .7608 .37848 .76005 .37774 Mtetra
.659 .81 .956 r
.76005 .37774 .7608 .37848 .76253 .37793 .76178 .37718 Mtetra
.651 .803 .956 r
.76178 .37718 .76253 .37793 .76427 .37746 .76352 .37664 Mtetra
.646 .785 .948 r
.76352 .37664 .76427 .37746 .76602 .37705 .76526 .37613 Mtetra
.654 .763 .929 r
.76526 .37613 .76602 .37705 .76776 .37663 .767 .37561 Mtetra
.708 .761 .893 r
.767 .37561 .76776 .37663 .76949 .37595 .76872 .37484 Mtetra
.735 .751 .865 r
.76872 .37484 .76949 .37595 .7712 .37503 .77043 .37388 Mtetra
.667 .718 .887 r
.77043 .37388 .7712 .37503 .77293 .37434 .77217 .3733 Mtetra
.252 .524 .913 r
.77217 .3733 .77293 .37434 .77471 .37433 .774 .37396 Mtetra
.853 .399 .019 r
.774 .37396 .77471 .37433 .77659 .3755 .7761 .37789 Mtetra
.973 .67 .375 r
.7761 .37789 .77659 .3755 .77861 .37843 .79363 .57697 Mtetra
.566 .349 .545 r
.79363 .57697 .77861 .37843 .79574 .57063 .79595 .58226 Mtetra
.573 .321 .497 r
.79595 .58226 .79574 .57063 .79847 .58086 .79793 .58312 Mtetra
.504 .141 .282 r
.79793 .58312 .79847 .58086 .80058 .58343 .79984 .58313 Mtetra
.479 .863 .978 r
.79984 .58313 .80058 .58343 .80255 .58409 .80172 .5827 Mtetra
.676 .696 .861 r
.80172 .5827 .80255 .58409 .80441 .58346 .80357 .58201 Mtetra
.697 .696 .845 r
.80357 .58201 .80441 .58346 .80624 .58243 .80542 .58117 Mtetra
.692 .724 .875 r
.80542 .58117 .80624 .58243 .80807 .58142 .80727 .58041 Mtetra
.642 .753 .93 r
.80727 .58041 .80807 .58142 .80994 .58082 .80915 .5799 Mtetra
.617 .765 .95 r
.80915 .5799 .80994 .58082 .81182 .58033 .81103 .57947 Mtetra
.53 .741 .972 r
.81103 .57947 .81182 .58033 .81372 .58012 .81294 .5793 Mtetra
.426 .7 .979 r
.81294 .5793 .81372 .58012 .81565 .58017 .81487 .57938 Mtetra
.598 .79 .972 r
.81487 .57938 .81565 .58017 .81755 .57991 .81676 .57897 Mtetra
.843 .823 .829 r
.81676 .57897 .81755 .57991 .81938 .57887 .81853 .57718 Mtetra
.933 .732 .608 r
.81853 .57718 .81938 .57887 .82108 .57626 .81992 .571 Mtetra
.975 .676 .38 r
.81992 .571 .82108 .57626 .82257 .5712 .80426 .37003 Mtetra
.567 .354 .55 r
.80426 .37003 .82257 .5712 .80711 .37424 .80562 .36485 Mtetra
.618 .429 .605 r
.80562 .36485 .80711 .37424 .80827 .36687 .80728 .36314 Mtetra
.647 .511 .683 r
.80728 .36314 .80827 .36687 .80981 .36379 .809 .36211 Mtetra
.667 .64 .813 r
.809 .36211 .80981 .36379 .81147 .36215 .81076 .36144 Mtetra
.625 .809 .97 r
.81076 .36144 .81147 .36215 .81324 .36162 .81253 .36096 Mtetra
.574 .804 .986 r
.81253 .36096 .81324 .36162 .81504 .36142 .81431 .36061 Mtetra
.605 .774 .961 r
.81431 .36061 .81504 .36142 .81684 .36125 .8161 .36023 Mtetra
.665 .749 .913 r
.8161 .36023 .81684 .36125 .81861 .3607 .81786 .35966 Mtetra
.675 .746 .904 r
.81786 .35966 .81861 .3607 .82037 .36011 .81963 .35904 Mtetra
.705 .753 .889 r
.81963 .35904 .82037 .36011 .82213 .35934 .82138 .35826 Mtetra
.749 .766 .866 r
.82138 .35826 .82213 .35934 .82385 .3583 .82311 .35722 Mtetra
.671 .736 .899 r
.82311 .35722 .82385 .3583 .82562 .35771 .82488 .35661 Mtetra
.288 .534 .913 r
.82488 .35661 .82562 .35771 .82751 .35835 .82676 .35725 Mtetra
.856 .457 0 r
.82676 .35725 .82751 .35835 .82996 .36491 .8292 .36361 Mtetra
.975 .667 .333 r
.8292 .36361 .82996 .36491 .8512 .56638 .85041 .56526 Mtetra
.647 .209 0 r
.85041 .56526 .8512 .56638 .8535 .56996 .85271 .5689 Mtetra
.393 .621 .943 r
.85271 .5689 .8535 .56996 .85548 .57028 .8547 .56922 Mtetra
.7 .768 .905 r
.8547 .56922 .85548 .57028 .85736 .5695 .85658 .56843 Mtetra
.878 .807 .775 r
.85658 .56843 .85736 .5695 .85909 .56711 .85831 .56604 Mtetra
.981 .75 .516 r
.85831 .56604 .85909 .56711 .86006 .55715 .85931 .55636 Mtetra
.977 .675 .347 r
.85931 .55636 .86006 .55715 .84191 .35559 .84119 .35472 Mtetra
.953 .81 .664 r
.84119 .35472 .84191 .35559 .84336 .35171 .84264 .35079 Mtetra
.729 .795 .904 r
.84264 .35079 .84336 .35171 .84512 .35088 .84439 .3499 Mtetra
.588 .726 .939 r
.84439 .3499 .84512 .35088 .84694 .35066 .84621 .34962 Mtetra
.56 .698 .933 r
.84621 .34962 .84694 .35066 .84877 .35056 .84804 .34946 Mtetra
.735 .76 .873 r
.84804 .34946 .84877 .35056 .85052 .3496 .84978 .3485 Mtetra
.666 .734 .901 r
.84978 .3485 .85052 .3496 .8523 .349 .85157 .34791 Mtetra
.377 .59 .927 r
.85157 .34791 .8523 .349 .85419 .34939 .85346 .34832 Mtetra
.8 .387 0 r
.85346 .34832 .85419 .34939 .85659 .35468 .85587 .35362 Mtetra
.973 .663 .318 r
.85587 .35362 .85659 .35468 .87972 .55725 .87896 .55626 Mtetra
.725 .282 0 r
.87896 .55626 .87972 .55725 .88213 .56143 .88137 .56044 Mtetra
.502 .698 .957 r
.88137 .56044 .88213 .56143 .88411 .5614 .88335 .56041 Mtetra
.698 .785 .918 r
.88335 .56041 .88411 .5614 .88601 .56062 .88525 .55963 Mtetra
.741 .799 .899 r
.88525 .55963 .88601 .56062 .88788 .55961 .88712 .55861 Mtetra
.506 .697 .955 r
.88712 .55861 .88788 .55961 .88987 .5596 .8891 .55857 Mtetra
.637 .753 .932 r
.8891 .55857 .88987 .5596 .8918 .55911 .89104 .55807 Mtetra
.82 .809 .84 r
.89104 .55807 .8918 .55911 .89361 .55749 .89285 .55644 Mtetra
.982 .761 .528 r
.89285 .55644 .89361 .55749 .89465 .54883 .89392 .54804 Mtetra
.976 .671 .328 r
.89392 .54804 .89465 .54883 .87425 .3458 .87355 .34495 Mtetra
.966 .809 .636 r
.87355 .34495 .87425 .3458 .87564 .34148 .87493 .34055 Mtetra
.734 .799 .904 r
.87493 .34055 .87564 .34148 .87741 .34063 .8767 .33964 Mtetra
.581 .722 .94 r
.8767 .33964 .87741 .34063 .87926 .34044 .87854 .33938 Mtetra
.492 .66 .936 r
.87854 .33938 .87926 .34044 .88114 .34058 .88042 .33944 Mtetra
.634 .714 .905 r
.88042 .33944 .88114 .34058 .88296 .34014 .88224 .339 Mtetra
.641 .717 .903 r
.88224 .339 .88296 .34014 .88478 .33965 .88406 .33852 Mtetra
.651 .725 .903 r
.88406 .33852 .88478 .33965 .88659 .33909 .88588 .338 Mtetra
.686 .747 .898 r
.88588 .338 .88659 .33909 .88837 .33823 .88768 .33731 Mtetra
.676 .781 .929 r
.88768 .33731 .88837 .33823 .89017 .33756 .88948 .33667 Mtetra
.645 .775 .943 r
.88948 .33667 .89017 .33756 .89202 .3373 .8913 .33615 Mtetra
.629 .709 .904 r
.8913 .33615 .89202 .3373 .89404 .33847 .89314 .33573 Mtetra
.564 .501 .744 r
.89314 .33573 .89404 .33847 .89629 .34161 .89502 .33576 Mtetra
.512 .386 .646 r
.89502 .33576 .89629 .34161 .92121 .5368 .89703 .33675 Mtetra
.538 .333 .55 r
.89703 .33675 .92121 .5368 .92422 .54531 .90042 .3495 Mtetra
.144 .059 .493 r
.90042 .3495 .92422 .54531 .92654 .54785 .92553 .54454 Mtetra
.169 .231 .685 r
.92553 .54454 .92654 .54785 .92868 .54891 .92792 .54767 Mtetra
.411 .392 .728 r
.30033 .7221 .30121 .72498 .30274 .72495 .30181 .72304 Mtetra
.543 .545 .806 r
.30181 .72304 .30274 .72495 .30432 .72431 .30334 .72312 Mtetra
.63 .681 .879 r
.30334 .72312 .30432 .72431 .30591 .72338 .30489 .72276 Mtetra
.424 .739 .992 r
.30489 .72276 .30591 .72338 .30744 .72348 .30643 .72275 Mtetra
.642 .781 .948 r
.30643 .72275 .30744 .72348 .30899 .72324 .308 .72231 Mtetra
.767 .758 .845 r
.308 .72231 .30899 .72324 .31059 .72226 .3096 .72118 Mtetra
.887 .727 .678 r
.3096 .72118 .31059 .72226 .31247 .71664 .31141 .71679 Mtetra
.939 .688 .532 r
.31141 .71679 .31247 .71664 .3256 .52206 .32439 .52566 Mtetra
.955 .856 .438 r
.32439 .52566 .3256 .52206 .32738 .5166 .32633 .51757 Mtetra
.684 .925 .611 r
.32633 .51757 .32738 .5166 .32889 .51554 .32789 .51578 Mtetra
.65 .969 .875 r
.32789 .51578 .32889 .51554 .33036 .51526 .3294 .51485 Mtetra
.657 .861 .977 r
.3294 .51485 .33036 .51526 .33181 .51537 .33089 .51432 Mtetra
.66 .704 .88 r
.33089 .51432 .33181 .51537 .33329 .51501 .33238 .51385 Mtetra
.635 .677 .873 r
.33238 .51385 .33329 .51501 .33478 .51457 .33385 .51349 Mtetra
.623 .689 .891 r
.33385 .51349 .33478 .51457 .33626 .51408 .33533 .51318 Mtetra
.734 .752 .866 r
.33533 .51318 .33626 .51408 .33778 .51306 .33684 .51235 Mtetra
.701 .788 .918 r
.33684 .51235 .33778 .51306 .33928 .51232 .33834 .51172 Mtetra
.482 .754 .99 r
.33834 .51172 .33928 .51232 .34075 .51223 .3398 .51163 Mtetra
.88 .448 .146 r
.3398 .51163 .34075 .51223 .34201 .51591 .34112 .51435 Mtetra
.941 .684 .519 r
.34112 .51435 .34201 .51591 .33295 .70964 .33228 .70299 Mtetra
0 0 .133 r
.33228 .70299 .33295 .70964 .3342 .7153 .33332 .71232 Mtetra
.37 .361 .719 r
.33332 .71232 .3342 .7153 .33573 .71573 .33482 .7135 Mtetra
.554 .523 .775 r
.33482 .7135 .33573 .71573 .33732 .71513 .33637 .71356 Mtetra
.633 .628 .827 r
.33637 .71356 .33732 .71513 .33893 .71409 .33795 .71317 Mtetra
.5 .689 .952 r
.33795 .71317 .33893 .71409 .3405 .71406 .33951 .71316 Mtetra
.609 .735 .935 r
.33951 .71316 .3405 .71406 .34207 .71387 .34109 .71285 Mtetra
.74 .742 .852 r
.34109 .71285 .34207 .71387 .34367 .713 .3427 .71189 Mtetra
.879 .731 .693 r
.3427 .71189 .34367 .713 .34548 .70826 .34446 .70808 Mtetra
.942 .688 .525 r
.34446 .70808 .34548 .70826 .35686 .51333 .35559 .51912 Mtetra
.882 .791 .3 r
.35559 .51912 .35686 .51333 .35866 .50691 .35763 .508 Mtetra
.716 .92 .575 r
.35763 .508 .35866 .50691 .3602 .50551 .35921 .50593 Mtetra
.532 .913 .767 r
.35921 .50593 .3602 .50551 .3617 .50517 .36074 .50499 Mtetra
.594 .906 .982 r
.36074 .50499 .3617 .50517 .36317 .50524 .36224 .50446 Mtetra
.674 .771 .923 r
.36224 .50446 .36317 .50524 .36467 .50484 .36375 .50394 Mtetra
.662 .739 .907 r
.36375 .50394 .36467 .50484 .36617 .50432 .36525 .50346 Mtetra
.653 .745 .918 r
.36525 .50346 .36617 .50432 .36767 .5039 .36675 .50302 Mtetra
.751 .761 .86 r
.36675 .50302 .36767 .5039 .36917 .50355 .36828 .50207 Mtetra
.697 .654 .804 r
.36828 .50207 .36917 .50355 .37066 .50352 .3698 .50129 Mtetra
.595 .537 .759 r
.3698 .50129 .37066 .50352 .37211 .50417 .37129 .5011 Mtetra
0 .021 .567 r
.37129 .5011 .37211 .50417 .37338 .50904 .37265 .50396 Mtetra
.95 .69 .507 r
.37265 .50396 .37338 .50904 .36623 .70091 .36538 .6971 Mtetra
.853 .569 .034 r
.36538 .6971 .36623 .70091 .36761 .70521 .36663 .70443 Mtetra
0 .115 .577 r
.36663 .70443 .36761 .70521 .36915 .70622 .36816 .70561 Mtetra
.578 .801 .984 r
.36816 .70561 .36915 .70622 .37074 .70599 .36975 .70529 Mtetra
.8 .812 .86 r
.36975 .70529 .37074 .70599 .37237 .70477 .37139 .70401 Mtetra
.899 .767 .707 r
.37139 .70401 .37237 .70477 .37415 .70027 .37313 .70046 Mtetra
.946 .69 .519 r
.37313 .70046 .37415 .70027 .38399 .5052 .38224 .52381 Mtetra
0 0 .082 r
.38224 .52381 .38399 .5052 .38577 .49839 .38477 .49967 Mtetra
.716 .894 .513 r
.38477 .49967 .38577 .49839 .38734 .49677 .38636 .49729 Mtetra
.45 .855 .677 r
.38636 .49729 .38734 .49677 .38885 .4964 .3879 .49632 Mtetra
.52 .9 .956 r
.3879 .49632 .38885 .4964 .39034 .4965 .38942 .49583 Mtetra
.633 .791 .958 r
.38942 .49583 .39034 .4965 .39184 .49635 .39093 .49542 Mtetra
.625 .725 .918 r
.39093 .49542 .39184 .49635 .39336 .49602 .39244 .49508 Mtetra
.605 .715 .922 r
.39244 .49508 .39336 .49602 .39487 .49567 .39396 .4948 Mtetra
.622 .738 .93 r
.39396 .4948 .39487 .49567 .39639 .49529 .39547 .49446 Mtetra
.639 .752 .931 r
.39547 .49446 .39639 .49529 .3979 .49488 .39699 .49406 Mtetra
.649 .758 .929 r
.39699 .49406 .3979 .49488 .39942 .49443 .39851 .49362 Mtetra
.662 .764 .925 r
.39851 .49362 .39942 .49443 .40095 .49395 .40003 .49314 Mtetra
.674 .766 .92 r
.40003 .49314 .40095 .49395 .40247 .49343 .40156 .49261 Mtetra
.684 .766 .914 r
.40156 .49261 .40247 .49343 .404 .49286 .40309 .49204 Mtetra
.697 .767 .906 r
.40309 .49204 .404 .49286 .40553 .49223 .40462 .4914 Mtetra
.704 .769 .903 r
.40462 .4914 .40553 .49223 .40706 .49155 .40615 .49074 Mtetra
.703 .771 .905 r
.40615 .49074 .40706 .49155 .4086 .49089 .40769 .49008 Mtetra
.691 .771 .913 r
.40769 .49008 .4086 .49089 .41013 .49028 .40922 .48948 Mtetra
.68 .769 .918 r
.40922 .48948 .41013 .49028 .41166 .48973 .41075 .48892 Mtetra
.675 .766 .92 r
.41075 .48892 .41166 .48973 .41319 .4892 .41228 .48838 Mtetra
.672 .764 .919 r
.41228 .48838 .41319 .4892 .41472 .48868 .41382 .48785 Mtetra
.67 .762 .919 r
.41382 .48785 .41472 .48868 .41625 .48816 .41535 .48733 Mtetra
.664 .76 .921 r
.41535 .48733 .41625 .48816 .41779 .48766 .41688 .48684 Mtetra
.653 .759 .928 r
.41688 .48684 .41779 .48766 .41932 .48715 .41841 .48638 Mtetra
.644 .769 .939 r
.41841 .48638 .41932 .48715 .42085 .48665 .41995 .48595 Mtetra
.64 .787 .952 r
.41995 .48595 .42085 .48665 .42239 .48615 .42148 .48552 Mtetra
.648 .807 .96 r
.42148 .48552 .42239 .48615 .42393 .48558 .42301 .48505 Mtetra
.652 .836 .971 r
.42301 .48505 .42393 .48558 .42547 .48501 .42455 .48454 Mtetra
.654 .855 .977 r
.42455 .48454 .42547 .48501 .427 .48455 .42609 .48401 Mtetra
.673 .838 .963 r
.42609 .48401 .427 .48455 .42853 .48448 .42763 .48344 Mtetra
.682 .722 .879 r
.42763 .48344 .42853 .48448 .43005 .48477 .42918 .48286 Mtetra
.655 .594 .775 r
.42918 .48286 .43005 .48477 .43156 .4852 .43072 .48227 Mtetra
.629 .52 .712 r
.43072 .48227 .43156 .4852 .43309 .48523 .43226 .48171 Mtetra
.617 .493 .688 r
.43226 .48171 .43309 .48523 .43463 .48476 .4338 .48118 Mtetra
.616 .49 .686 r
.4338 .48118 .43463 .48476 .43618 .4841 .43535 .48066 Mtetra
.617 .495 .691 r
.43535 .48066 .43618 .4841 .43772 .4835 .43689 .48015 Mtetra
.617 .498 .695 r
.43689 .48015 .43772 .4835 .43927 .48298 .43844 .47964 Mtetra
.43844 .47964 .43927 .48298 .44082 .48247 .43998 .47914 Mtetra
.618 .499 .696 r
.43998 .47914 .44082 .48247 .44237 .48195 .44153 .47863 Mtetra
.618 .5 .696 r
.44153 .47863 .44237 .48195 .44391 .48144 .44308 .47812 Mtetra
.44308 .47812 .44391 .48144 .44546 .48093 .44463 .47762 Mtetra
.635 .511 .694 r
.44463 .47762 .44546 .48093 .44702 .48012 .44618 .47692 Mtetra
.639 .517 .698 r
.44618 .47692 .44702 .48012 .44858 .47926 .44774 .47618 Mtetra
.603 .499 .708 r
.44774 .47618 .44858 .47926 .45012 .47903 .44928 .47586 Mtetra
.379 .352 .703 r
.44928 .47586 .45012 .47903 .45161 .48151 .4508 .47714 Mtetra
0 0 .201 r
.4508 .47714 .45161 .48151 .44896 .67487 .45219 .48395 Mtetra
0 0 .336 r
.45219 .48395 .44896 .67487 .45046 .6813 .44957 .67738 Mtetra
.196 .206 .643 r
.44957 .67738 .45046 .6813 .45207 .68276 .45116 .67998 Mtetra
.59 .513 .736 r
.45116 .67998 .45207 .68276 .45371 .68249 .4528 .6798 Mtetra
.659 .557 .728 r
.4528 .6798 .45371 .68249 .45537 .68177 .45446 .67896 Mtetra
.655 .549 .723 r
.45446 .67896 .45537 .68177 .45703 .68106 .45612 .67814 Mtetra
.623 .525 .723 r
.45612 .67814 .45703 .68106 .45868 .68057 .45778 .67764 Mtetra
.623 .525 .722 r
.45778 .67764 .45868 .68057 .46034 .68009 .45943 .67713 Mtetra
.627 .526 .72 r
.45943 .67713 .46034 .68009 .462 .67966 .46109 .67658 Mtetra
.627 .521 .714 r
.46109 .67658 .462 .67966 .46365 .67928 .46275 .676 Mtetra
.612 .505 .707 r
.46275 .676 .46365 .67928 .46531 .67889 .46441 .67556 Mtetra
.576 .48 .709 r
.46441 .67556 .46531 .67889 .46697 .67842 .46606 .6755 Mtetra
.535 .473 .733 r
.46606 .6755 .46697 .67842 .46863 .67786 .46771 .67575 Mtetra
.528 .524 .795 r
.46771 .67575 .46863 .67786 .47029 .67728 .46936 .67594 Mtetra
.565 .639 .883 r
.46936 .67594 .47029 .67728 .47196 .67678 .47102 .67584 Mtetra
.636 .743 .926 r
.47102 .67584 .47196 .67678 .47362 .67638 .47268 .67542 Mtetra
.658 .745 .914 r
.47268 .67542 .47362 .67638 .47528 .67588 .47435 .67491 Mtetra
.65 .739 .915 r
.47435 .67491 .47528 .67588 .47695 .67505 .47601 .67443 Mtetra
.599 .81 .981 r
.47601 .67443 .47695 .67505 .47863 .67374 .47768 .67404 Mtetra
0 0 0 r
.47768 .67404 .47863 .67374 .48031 .67227 .47935 .67365 Mtetra
.336 0 .078 r
.47935 .67365 .48031 .67227 .48199 .67106 .48102 .67321 Mtetra
.411 .05 .238 r
.48102 .67321 .48199 .67106 .48366 .67052 .48269 .6727 Mtetra
.41 .052 .243 r
.48269 .6727 .48366 .67052 .48533 .67019 .48436 .67218 Mtetra
.432 .061 .232 r
.48436 .67218 .48533 .67019 .48699 .6701 .48603 .67183 Mtetra
.452 .061 .206 r
.48603 .67183 .48699 .6701 .48866 .67012 .4877 .67167 Mtetra
.323 0 .106 r
.4877 .67167 .48866 .67012 .49033 .6695 .48938 .67109 Mtetra
0 0 0 r
.48938 .67109 .49033 .6695 .49203 .66668 .49107 .66913 Mtetra
.929 .856 .419 r
.49107 .66913 .49203 .66668 .49543 .47325 .4928 .66252 Mtetra
0 0 .339 r
.4928 .66252 .49543 .47325 .49708 .46397 .49618 .46637 Mtetra
0 0 0 r
.49618 .46637 .49708 .46397 .49868 .46125 .49779 .46209 Mtetra
.49779 .46209 .49868 .46125 .50026 .46047 .49938 .46119 Mtetra
.255 0 0 r
.49938 .46119 .50026 .46047 .50184 .46014 .50096 .46094 Mtetra
.346 0 0 r
.50096 .46094 .50184 .46014 .50342 .4599 .50254 .46083 Mtetra
.213 0 0 r
.50254 .46083 .50342 .4599 .505 .45941 .50412 .46035 Mtetra
.224 0 0 r
.50412 .46035 .505 .45941 .50658 .45893 .5057 .45988 Mtetra
.248 0 0 r
.5057 .45988 .50658 .45893 .50817 .45845 .50729 .45946 Mtetra
.289 0 0 r
.50729 .45946 .50817 .45845 .50975 .45797 .50887 .45909 Mtetra
.274 0 0 r
.50887 .45909 .50975 .45797 .51134 .4575 .51046 .45861 Mtetra
.138 0 0 r
.51046 .45861 .51134 .4575 .51292 .45706 .51205 .45784 Mtetra
0 0 0 r
.51205 .45784 .51292 .45706 .51451 .45667 .51364 .45668 Mtetra
.761 .982 .911 r
.51364 .45668 .51451 .45667 .5161 .45629 .51523 .45556 Mtetra
.75 .81 .9 r
.51523 .45556 .5161 .45629 .51769 .45587 .51682 .45465 Mtetra
.668 .688 .86 r
.51682 .45465 .51769 .45587 .51928 .45541 .51841 .4541 Mtetra
.649 .667 .854 r
.51841 .4541 .51928 .45541 .52087 .4549 .52001 .45364 Mtetra
.646 .673 .862 r
.52001 .45364 .52087 .4549 .52246 .45435 .5216 .45319 Mtetra
.662 .698 .873 r
.5216 .45319 .52246 .45435 .52406 .45374 .52319 .45268 Mtetra
.664 .717 .888 r
.52319 .45268 .52406 .45374 .52565 .45313 .52479 .45216 Mtetra
.666 .738 .904 r
.52479 .45216 .52565 .45313 .52725 .45253 .52638 .45164 Mtetra
.666 .755 .917 r
.52638 .45164 .52725 .45253 .52884 .45199 .52798 .45111 Mtetra
.666 .759 .92 r
.52798 .45111 .52884 .45199 .53044 .45146 .52958 .45059 Mtetra
.665 .76 .921 r
.52958 .45059 .53044 .45146 .53204 .45094 .53118 .45007 Mtetra
.53118 .45007 .53204 .45094 .53363 .45041 .53277 .44955 Mtetra
.664 .76 .922 r
.53277 .44955 .53363 .45041 .53523 .44989 .53437 .44903 Mtetra
.664 .761 .922 r
.53437 .44903 .53523 .44989 .53683 .44937 .53598 .44851 Mtetra
.663 .761 .923 r
.53598 .44851 .53683 .44937 .53844 .44886 .53758 .448 Mtetra
.53758 .448 .53844 .44886 .54004 .44835 .53918 .44748 Mtetra
.662 .761 .923 r
.53918 .44748 .54004 .44835 .54164 .44783 .54078 .44697 Mtetra
.662 .76 .923 r
.54078 .44697 .54164 .44783 .54325 .44733 .54239 .44646 Mtetra
.661 .76 .923 r
.54239 .44646 .54325 .44733 .54485 .44682 .544 .44595 Mtetra
.661 .759 .923 r
.544 .44595 .54485 .44682 .54646 .44632 .5456 .44544 Mtetra
.66 .758 .923 r
.5456 .44544 .54646 .44632 .54806 .44581 .54721 .44494 Mtetra
.66 .759 .923 r
.54721 .44494 .54806 .44581 .54967 .44532 .54882 .44443 Mtetra
.66 .757 .921 r
.54882 .44443 .54967 .44532 .55128 .44485 .55043 .44393 Mtetra
.661 .749 .915 r
.55043 .44393 .55128 .44485 .55289 .44443 .55204 .44342 Mtetra
.662 .729 .899 r
.55204 .44342 .55289 .44443 .5545 .44402 .55365 .44291 Mtetra
.665 .71 .882 r
.55365 .44291 .5545 .44402 .55612 .44359 .55526 .44238 Mtetra
.677 .697 .862 r
.55526 .44238 .55612 .44359 .55773 .44309 .55688 .44178 Mtetra
.663 .675 .851 r
.55688 .44178 .55773 .44309 .55934 .44255 .55849 .44124 Mtetra
.635 .663 .86 r
.55849 .44124 .55934 .44255 .56096 .44197 .56011 .44084 Mtetra
.523 .647 .913 r
.56011 .44084 .56096 .44197 .56257 .44134 .56173 .44085 Mtetra
.271 .69 .968 r
.56173 .44085 .56257 .44134 .56419 .44069 .56335 .44098 Mtetra
.256 0 0 r
.56335 .44098 .56419 .44069 .5658 .44006 .56498 .44106 Mtetra
.26 0 0 r
.56498 .44106 .5658 .44006 .56742 .43949 .5666 .44062 Mtetra
.231 0 0 r
.5666 .44062 .56742 .43949 .56904 .43894 .56822 .44002 Mtetra
.188 0 0 r
.56822 .44002 .56904 .43894 .57066 .4384 .56984 .43936 Mtetra
.197 0 0 r
.56984 .43936 .57066 .4384 .57228 .43786 .57146 .43881 Mtetra
.195 0 0 r
.57146 .43881 .57228 .43786 .5739 .43733 .57309 .43826 Mtetra
.193 0 0 r
.57309 .43826 .5739 .43733 .57552 .4368 .57471 .43772 Mtetra
.186 0 0 r
.57471 .43772 .57552 .4368 .57715 .43625 .57633 .43717 Mtetra
.189 0 0 r
.57633 .43717 .57715 .43625 .57877 .43572 .57796 .43663 Mtetra
.182 0 0 r
.57796 .43663 .57877 .43572 .5804 .43517 .57959 .43608 Mtetra
0 0 0 r
.57959 .43608 .5804 .43517 .58202 .43431 .58121 .43506 Mtetra
.087 0 0 r
.58121 .43506 .58202 .43431 .58365 .43375 .58283 .43447 Mtetra
.481 0 0 r
.58283 .43447 .58365 .43375 .58528 .43378 .58448 .43477 Mtetra
.9 .557 .387 r
.58448 .43477 .58528 .43378 .58698 .43686 .58626 .44217 Mtetra
.958 .675 .459 r
.58626 .44217 .58698 .43686 .59242 .63072 .59168 .63759 Mtetra
.676 .392 .484 r
.59168 .63759 .59242 .63072 .59433 .63938 .5935 .64122 Mtetra
.513 .128 .248 r
.5935 .64122 .59433 .63938 .59608 .63959 .59525 .64136 Mtetra
.383 0 .178 r
.59525 .64136 .59608 .63959 .59782 .63895 .59699 .64086 Mtetra
.318 0 .169 r
.59699 .64086 .59782 .63895 .59955 .63805 .59873 .64002 Mtetra
.407 .035 .217 r
.59873 .64002 .59955 .63805 .60132 .63854 .60047 .63955 Mtetra
.21 0 0 r
.60047 .63955 .60132 .63854 .60308 .63899 .60221 .63898 Mtetra
.51 .91 .909 r
.60221 .63898 .60308 .63899 .60484 .63925 .60395 .6383 Mtetra
.755 .783 .876 r
.60395 .6383 .60484 .63925 .60659 .63902 .60569 .63725 Mtetra
.724 .657 .782 r
.60569 .63725 .60659 .63902 .60834 .63862 .60742 .63607 Mtetra
.692 .585 .732 r
.60742 .63607 .60834 .63862 .61009 .63811 .60915 .63488 Mtetra
.58 .49 .717 r
.60915 .63488 .61009 .63811 .61185 .63792 .61091 .63477 Mtetra
.603 .507 .718 r
.61091 .63477 .61185 .63792 .6136 .63742 .61266 .63442 Mtetra
.672 .554 .713 r
.61266 .63442 .6136 .63742 .61533 .63634 .6144 .6333 Mtetra
.871 .658 .611 r
.6144 .6333 .61533 .63634 .61699 .63227 .61597 .62606 Mtetra
.962 .683 .46 r
.61597 .62606 .61699 .63227 .61356 .44095 .61241 .42828 Mtetra
.664 .454 .59 r
.61241 .42828 .61356 .44095 .61484 .42717 .61394 .42359 Mtetra
.664 .523 .682 r
.61394 .42359 .61484 .42717 .61647 .42572 .61557 .42238 Mtetra
.613 .499 .7 r
.61557 .42238 .61647 .42572 .61812 .42531 .61722 .4219 Mtetra
.581 .477 .701 r
.61722 .4219 .61812 .42531 .61978 .42519 .61888 .42177 Mtetra
.606 .492 .698 r
.61888 .42177 .61978 .42519 .62141 .42386 .62054 .42137 Mtetra
.62 .542 .745 r
.62054 .42137 .62141 .42386 .62303 .42245 .62219 .42095 Mtetra
.637 .64 .836 r
.62219 .42095 .62303 .42245 .62467 .42124 .62385 .42053 Mtetra
.641 .801 .96 r
.62385 .42053 .62467 .42124 .62631 .42054 .6255 .42005 Mtetra
.623 .857 .987 r
.6255 .42005 .62631 .42054 .62797 .42003 .62716 .41954 Mtetra
.63 .86 .986 r
.62716 .41954 .62797 .42003 .62963 .41959 .62882 .41902 Mtetra
.646 .839 .975 r
.62882 .41902 .62963 .41959 .63128 .41898 .63047 .41848 Mtetra
.642 .859 .982 r
.63047 .41848 .63128 .41898 .63293 .41841 .63213 .41793 Mtetra
.646 .868 .982 r
.63213 .41793 .63293 .41841 .63459 .41796 .63379 .41736 Mtetra
.678 .842 .962 r
.63379 .41736 .63459 .41796 .63627 .418 .63544 .41673 Mtetra
.68 .692 .854 r
.63544 .41673 .63627 .418 .63796 .4183 .6371 .41608 Mtetra
.649 .575 .758 r
.6371 .41608 .63796 .4183 .63966 .4187 .63876 .41545 Mtetra
.651 .526 .698 r
.63876 .41545 .63966 .4187 .64131 .41795 .64041 .41453 Mtetra
.631 .508 .694 r
.64041 .41453 .64131 .41795 .64297 .41718 .64206 .41382 Mtetra
.585 .481 .703 r
.64206 .41382 .64297 .41718 .64465 .4171 .64374 .41366 Mtetra
.239 .254 .674 r
.64374 .41366 .64465 .4171 .64654 .42256 .64551 .41601 Mtetra
.977 .689 .409 r
.64551 .41601 .64654 .42256 .65572 .61962 .65436 .60554 Mtetra
0 0 .459 r
.65436 .60554 .65572 .61962 .65767 .62376 .65671 .62037 Mtetra
.364 .348 .708 r
.65671 .62037 .65767 .62376 .65949 .62436 .65857 .62197 Mtetra
.535 .511 .776 r
.65857 .62197 .65949 .62436 .66128 .62393 .66038 .62217 Mtetra
.61 .61 .826 r
.66038 .62217 .66128 .62393 .66304 .623 .66217 .62187 Mtetra
.537 .674 .926 r
.66217 .62187 .66304 .623 .66481 .62215 .66397 .6218 Mtetra
.472 .842 .99 r
.66397 .6218 .66481 .62215 .66657 .621 .66577 .62147 Mtetra
0 0 0 r
.66577 .62147 .66657 .621 .66829 .61904 .66753 .62051 Mtetra
.67 .798 .341 r
.66753 .62051 .66829 .61904 .66982 .61238 .6692 .6171 Mtetra
.866 .73 .211 r
.6692 .6171 .66982 .61238 .66314 .41391 .67043 .60348 Mtetra
.014 0 .416 r
.67043 .60348 .66314 .41391 .66463 .409 .66393 .41045 Mtetra
0 0 0 r
.66393 .41045 .66463 .409 .66627 .40752 .66551 .40776 Mtetra
.639 .96 .795 r
.66551 .40776 .66627 .40752 .66795 .40705 .66716 .40656 Mtetra
.691 .879 .968 r
.66716 .40656 .66795 .40705 .66965 .40695 .66883 .40584 Mtetra
.678 .724 .884 r
.66883 .40584 .66965 .40695 .67133 .40659 .67051 .40523 Mtetra
.655 .671 .853 r
.67051 .40523 .67133 .40659 .67301 .40608 .67219 .40471 Mtetra
.64 .663 .856 r
.67219 .40471 .67301 .40608 .6747 .40552 .67388 .40427 Mtetra
.648 .685 .871 r
.67388 .40427 .6747 .40552 .67637 .40481 .67557 .40379 Mtetra
.655 .733 .907 r
.67557 .40379 .67637 .40481 .67805 .4041 .67725 .40329 Mtetra
.654 .784 .944 r
.67725 .40329 .67805 .4041 .67973 .40351 .67894 .40277 Mtetra
.74 .825 .917 r
.67894 .40277 .67973 .40351 .68142 .40313 .68061 .40189 Mtetra
.708 .711 .851 r
.68061 .40189 .68142 .40313 .68313 .40313 .68228 .40108 Mtetra
.612 .57 .783 r
.68228 .40108 .68313 .40313 .68489 .40387 .68398 .40076 Mtetra
.289 .303 .702 r
.68398 .40076 .68489 .40387 .68685 .40872 .68579 .40268 Mtetra
0 0 .123 r
.68579 .40268 .68685 .40872 .6986 .6068 .68821 .41653 Mtetra
.04 0 .436 r
.68821 .41653 .6986 .6068 .70066 .61125 .69967 .60758 Mtetra
.403 .364 .7 r
.69967 .60758 .70066 .61125 .70253 .61205 .70158 .60907 Mtetra
.616 .524 .728 r
.70158 .60907 .70253 .61205 .70434 .61162 .70339 .60861 Mtetra
.656 .547 .719 r
.70339 .60861 .70434 .61162 .70613 .61078 .70518 .6077 Mtetra
.591 .505 .726 r
.70518 .6077 .70613 .61078 .70794 .61016 .707 .60748 Mtetra
.539 .495 .755 r
.707 .60748 .70794 .61016 .70975 .60969 .70885 .6077 Mtetra
.537 .547 .813 r
.70885 .6077 .70975 .60969 .71156 .60909 .7107 .60783 Mtetra
.574 .667 .902 r
.7107 .60783 .71156 .60909 .71334 .60805 .71253 .60765 Mtetra
.517 .854 .996 r
.71253 .60765 .71334 .60805 .71511 .60665 .71435 .60726 Mtetra
.085 0 0 r
.71435 .60726 .71511 .60665 .71687 .60512 .71617 .60676 Mtetra
.421 .021 .172 r
.71617 .60676 .71687 .60512 .71867 .60449 .718 .60648 Mtetra
.437 .063 .23 r
.718 .60648 .71867 .60449 .72051 .6043 .71983 .60614 Mtetra
.315 0 .161 r
.71983 .60614 .72051 .6043 .72231 .6035 .72163 .60527 Mtetra
0 0 0 r
.72163 .60527 .72231 .6035 .72389 .59894 .72331 .60232 Mtetra
.851 .738 .219 r
.72331 .60232 .72389 .59894 .71402 .39921 .72456 .59193 Mtetra
.039 0 .432 r
.72456 .59193 .71402 .39921 .7154 .39307 .71476 .39468 Mtetra
0 0 0 r
.71476 .39468 .7154 .39307 .71701 .39106 .71633 .3918 Mtetra
.041 0 0 r
.71633 .3918 .71701 .39106 .71871 .39038 .71803 .39107 Mtetra
.295 0 0 r
.71803 .39107 .71871 .39038 .72044 .3901 .71976 .3909 Mtetra
.316 0 0 r
.71976 .3909 .72044 .3901 .72216 .38973 .7215 .3907 Mtetra
.275 0 0 r
.7215 .3907 .72216 .38973 .72387 .38921 .72322 .39028 Mtetra
.257 0 0 r
.72322 .39028 .72387 .38921 .72559 .38871 .72493 .38973 Mtetra
.068 0 0 r
.72493 .38973 .72559 .38871 .72731 .38826 .72662 .38877 Mtetra
0 0 0 r
.72662 .38877 .72731 .38826 .72903 .38783 .72829 .38755 Mtetra
.778 .954 .929 r
.72829 .38755 .72903 .38783 .73075 .38739 .72997 .38642 Mtetra
.722 .77 .891 r
.72997 .38642 .73075 .38739 .73247 .38685 .73167 .38558 Mtetra
.664 .693 .866 r
.73167 .38558 .73247 .38685 .73418 .38623 .73339 .38501 Mtetra
.649 .695 .879 r
.73339 .38501 .73418 .38623 .73589 .3856 .73511 .38452 Mtetra
.653 .726 .903 r
.73511 .38452 .73589 .3856 .73761 .385 .73683 .38402 Mtetra
.661 .75 .916 r
.73683 .38402 .73761 .385 .73933 .38444 .73855 .38348 Mtetra
.661 .754 .919 r
.73855 .38348 .73933 .38444 .74105 .38389 .74028 .38293 Mtetra
.662 .755 .919 r
.74028 .38293 .74105 .38389 .74277 .38334 .742 .38238 Mtetra
.742 .38238 .74277 .38334 .7445 .38279 .74373 .38183 Mtetra
.663 .756 .919 r
.74373 .38183 .7445 .38279 .74622 .38224 .74545 .38128 Mtetra
.74545 .38128 .74622 .38224 .74795 .38169 .74718 .38073 Mtetra
.74718 .38073 .74795 .38169 .74967 .38114 .7489 .38017 Mtetra
.664 .755 .918 r
.7489 .38017 .74967 .38114 .7514 .38058 .75063 .37962 Mtetra
.664 .755 .917 r
.75063 .37962 .7514 .38058 .75313 .38002 .75236 .37906 Mtetra
.665 .755 .917 r
.75236 .37906 .75313 .38002 .75486 .37946 .75409 .37849 Mtetra
.666 .755 .917 r
.75409 .37849 .75486 .37946 .75659 .37889 .75582 .37792 Mtetra
.667 .755 .916 r
.75582 .37792 .75659 .37889 .75832 .37832 .75755 .37735 Mtetra
.668 .756 .916 r
.75755 .37735 .75832 .37832 .76005 .37774 .75928 .37677 Mtetra
.669 .755 .915 r
.75928 .37677 .76005 .37774 .76178 .37718 .76102 .37619 Mtetra
.679 .756 .909 r
.76102 .37619 .76178 .37718 .76352 .37664 .76275 .37556 Mtetra
.684 .738 .891 r
.76275 .37556 .76352 .37664 .76526 .37613 .76448 .3749 Mtetra
.666 .702 .873 r
.76448 .3749 .76526 .37613 .767 .37561 .76621 .37432 Mtetra
.654 .686 .868 r
.76621 .37432 .767 .37561 .76872 .37484 .76795 .3738 Mtetra
.62 .721 .919 r
.76795 .3738 .76872 .37484 .77043 .37388 .76971 .37342 Mtetra
.266 .696 .965 r
.76971 .37342 .77043 .37388 .77217 .3733 .7715 .37354 Mtetra
.739 .228 0 r
.7715 .37354 .77217 .3733 .774 .37396 .77344 .37546 Mtetra
.974 .671 .372 r
.77344 .37546 .774 .37396 .7761 .37789 .79043 .5697 Mtetra
.576 .356 .545 r
.79043 .5697 .7761 .37789 .79363 .57697 .79328 .58174 Mtetra
.641 .332 .433 r
.79328 .58174 .79363 .57697 .79595 .58226 .79534 .58369 Mtetra
.376 0 .112 r
.79534 .58369 .79595 .58226 .79793 .58312 .79722 .5833 Mtetra
.473 .887 .771 r
.79722 .5833 .79793 .58312 .79984 .58313 .79905 .58233 Mtetra
.754 .836 .914 r
.79905 .58233 .79984 .58313 .80172 .5827 .80088 .58128 Mtetra
.673 .69 .858 r
.80088 .58128 .80172 .5827 .80357 .58201 .80274 .58061 Mtetra
.666 .69 .863 r
.80274 .58061 .80357 .58201 .80542 .58117 .8046 .57998 Mtetra
.645 .717 .9 r
.8046 .57998 .80542 .58117 .80727 .58041 .80648 .57947 Mtetra
.6 .752 .95 r
.80648 .57947 .80727 .58041 .80915 .5799 .80837 .5791 Mtetra
.604 .79 .97 r
.80837 .5791 .80915 .5799 .81103 .57947 .81025 .57868 Mtetra
.621 .799 .968 r
.81025 .57868 .81103 .57947 .81294 .5793 .81214 .5782 Mtetra
.666 .744 .909 r
.81214 .5782 .81294 .5793 .81487 .57938 .81401 .57759 Mtetra
.728 .668 .791 r
.81401 .57759 .81487 .57938 .81676 .57897 .81583 .57636 Mtetra
.815 .65 .679 r
.81583 .57636 .81676 .57897 .81853 .57718 .81747 .57303 Mtetra
.976 .677 .378 r
.81747 .57303 .81853 .57718 .81992 .571 .80209 .37357 Mtetra
.573 .358 .55 r
.80209 .37357 .81992 .571 .80426 .37003 .80312 .36458 Mtetra
.697 .511 .633 r
.80312 .36458 .80426 .37003 .80562 .36485 .80469 .36182 Mtetra
.638 .53 .714 r
.80469 .36182 .80562 .36485 .80728 .36314 .80644 .36109 Mtetra
.598 .567 .79 r
.80644 .36109 .80728 .36314 .809 .36211 .80823 .36086 Mtetra
.566 .656 .897 r
.80823 .36086 .809 .36211 .81076 .36144 .81004 .36073 Mtetra
.624 .809 .971 r
.81004 .36073 .81076 .36144 .81253 .36096 .81181 .36025 Mtetra
.636 .815 .969 r
.81181 .36025 .81253 .36096 .81431 .36061 .81358 .35974 Mtetra
.664 .783 .937 r
.81358 .35974 .81431 .36061 .8161 .36023 .81535 .35916 Mtetra
.686 .745 .896 r
.81535 .35916 .8161 .36023 .81786 .35966 .81711 .35848 Mtetra
.688 .726 .879 r
.81711 .35848 .81786 .35966 .81963 .35904 .81887 .35778 Mtetra
.707 .718 .858 r
.81887 .35778 .81963 .35904 .82138 .35826 .82061 .35695 Mtetra
.736 .722 .838 r
.82061 .35695 .82138 .35826 .82311 .35722 .82234 .35591 Mtetra
.667 .694 .866 r
.82234 .35591 .82311 .35722 .82488 .35661 .82411 .35531 Mtetra
.357 .531 .89 r
.82411 .35531 .82488 .35661 .82676 .35725 .82599 .35591 Mtetra
.804 .409 0 r
.82599 .35591 .82676 .35725 .8292 .36361 .82838 .36174 Mtetra
.975 .667 .331 r
.82838 .36174 .8292 .36361 .85041 .56526 .84961 .56397 Mtetra
.618 .202 0 r
.84961 .56397 .85041 .56526 .85271 .5689 .85193 .5678 Mtetra
.416 .624 .939 r
.85193 .5678 .85271 .5689 .8547 .56922 .85391 .56808 Mtetra
.697 .752 .894 r
.85391 .56808 .8547 .56922 .85658 .56843 .8558 .56729 Mtetra
.857 .795 .79 r
.8558 .56729 .85658 .56843 .85831 .56604 .85755 .56515 Mtetra
.977 .785 .581 r
.85755 .56515 .85831 .56604 .85931 .55636 .85888 .55884 Mtetra
.978 .677 .336 r
.85888 .55884 .85931 .55636 .84119 .35472 .84076 .35668 Mtetra
0 0 0 r
.84076 .35668 .84119 .35472 .84264 .35079 .84208 .35142 Mtetra
.84208 .35142 .84264 .35079 .84439 .3499 .84377 .3499 Mtetra
.552 .932 .871 r
.84377 .3499 .84439 .3499 .84621 .34962 .84552 .34902 Mtetra
.67 .861 .972 r
.84552 .34902 .84621 .34962 .84804 .34946 .8473 .34835 Mtetra
.745 .762 .866 r
.8473 .34835 .84804 .34946 .84978 .3485 .84904 .34732 Mtetra
.658 .715 .89 r
.84904 .34732 .84978 .3485 .85157 .34791 .85083 .34677 Mtetra
.358 .565 .916 r
.85083 .34677 .85157 .34791 .85346 .34832 .85273 .34727 Mtetra
.818 .407 0 r
.85273 .34727 .85346 .34832 .85587 .35362 .85517 .35286 Mtetra
.973 .663 .32 r
.85517 .35286 .85587 .35362 .87896 .55626 .87824 .55567 Mtetra
.788 .321 0 r
.87824 .55567 .87896 .55626 .88137 .56044 .88064 .55967 Mtetra
.483 .746 .987 r
.88064 .55967 .88137 .56044 .88335 .56041 .88261 .55957 Mtetra
.713 .826 .935 r
.88261 .55957 .88335 .56041 .88525 .55963 .8845 .55872 Mtetra
.758 .823 .903 r
.8845 .55872 .88525 .55963 .88712 .55861 .88637 .55761 Mtetra
.537 .715 .954 r
.88637 .55761 .88712 .55861 .8891 .55857 .88834 .55747 Mtetra
.643 .74 .92 r
.88834 .55747 .8891 .55857 .89104 .55807 .89027 .55695 Mtetra
.794 .791 .849 r
.89027 .55695 .89104 .55807 .89285 .55644 .8921 .55551 Mtetra
.975 .793 .595 r
.8921 .55551 .89285 .55644 .89392 .54804 .89346 .54977 Mtetra
.976 .672 .319 r
.89346 .54977 .89392 .54804 .87355 .34495 .87321 .34731 Mtetra
0 0 0 r
.87321 .34731 .87355 .34495 .87493 .34055 .87441 .34126 Mtetra
.87441 .34126 .87493 .34055 .8767 .33964 .8761 .33962 Mtetra
.577 .943 .872 r
.8761 .33962 .8767 .33964 .87854 .33938 .87786 .33868 Mtetra
.644 .828 .971 r
.87786 .33868 .87854 .33938 .88042 .33944 .87967 .33812 Mtetra
.646 .686 .873 r
.87967 .33812 .88042 .33944 .88224 .339 .88149 .33762 Mtetra
.624 .666 .87 r
.88149 .33762 .88224 .339 .88406 .33852 .88332 .33724 Mtetra
.618 .678 .885 r
.88332 .33724 .88406 .33852 .88588 .338 .88516 .33687 Mtetra
.658 .728 .901 r
.88516 .33687 .88588 .338 .88768 .33731 .88697 .33632 Mtetra
.669 .762 .92 r
.88697 .33632 .88768 .33731 .88948 .33667 .88878 .33571 Mtetra
.682 .775 .921 r
.88878 .33571 .88948 .33667 .8913 .33615 .89059 .33504 Mtetra
.758 .77 .863 r
.89059 .33504 .8913 .33615 .89314 .33573 .89234 .33393 Mtetra
.677 .636 .801 r
.89234 .33393 .89314 .33573 .89502 .33576 .89413 .33315 Mtetra
.583 .52 .75 r
.89413 .33315 .89502 .33576 .89703 .33675 .896 .33302 Mtetra
.215 .236 .667 r
.896 .33302 .89703 .33675 .90042 .3495 .89827 .3362 Mtetra
.957 .652 .229 r
.89827 .3362 .90042 .3495 .92553 .54454 .92394 .53638 Mtetra
.149 .124 .572 r
.92394 .53638 .92553 .54454 .92792 .54767 .92692 .54445 Mtetra
.074 .003 .463 r
.3001 .70916 .30033 .7221 .30181 .72304 .30103 .71859 Mtetra
.229 .205 .623 r
.30103 .71859 .30181 .72304 .30334 .72312 .30241 .72114 Mtetra
.24 .362 .787 r
.30241 .72114 .30334 .72312 .30489 .72276 .30387 .72223 Mtetra
.401 .749 .993 r
.30387 .72223 .30489 .72276 .30643 .72275 .30541 .7222 Mtetra
.679 .835 .959 r
.30541 .7222 .30643 .72275 .308 .72231 .30699 .7216 Mtetra
.787 .804 .866 r
.30699 .7216 .308 .72231 .3096 .72118 .3086 .72043 Mtetra
.861 .779 .77 r
.3086 .72043 .3096 .72118 .31141 .71679 .31028 .71817 Mtetra
.968 .93 .622 r
.31028 .71817 .31141 .71679 .32439 .52566 .31206 .71407 Mtetra
0 0 .271 r
.31206 .71407 .32439 .52566 .32633 .51757 .32463 .52944 Mtetra
0 0 .237 r
.32463 .52944 .32633 .51757 .32789 .51578 .32675 .5184 Mtetra
0 0 0 r
.32675 .5184 .32789 .51578 .3294 .51485 .3284 .51513 Mtetra
.904 .965 .814 r
.3284 .51513 .3294 .51485 .33089 .51432 .32997 .51323 Mtetra
.697 .709 .857 r
.32997 .51323 .33089 .51432 .33238 .51385 .33146 .51257 Mtetra
.611 .647 .862 r
.33146 .51257 .33238 .51385 .33385 .51349 .33294 .51232 Mtetra
.557 .644 .892 r
.33294 .51232 .33385 .51349 .33533 .51318 .3344 .51225 Mtetra
.701 .739 .881 r
.3344 .51225 .33533 .51318 .33684 .51235 .3359 .51159 Mtetra
.69 .777 .918 r
.3359 .51159 .33684 .51235 .33834 .51172 .33739 .51101 Mtetra
.586 .764 .964 r
.33739 .51101 .33834 .51172 .3398 .51163 .33887 .51075 Mtetra
0 .237 .72 r
.33887 .51075 .3398 .51163 .34112 .51435 .34028 .51173 Mtetra
0 0 .556 r
.34028 .51173 .34112 .51435 .33228 .70299 .3416 .51433 Mtetra
0 0 .311 r
.3416 .51433 .33228 .70299 .33332 .71232 .33341 .69161 Mtetra
.021 0 .421 r
.33341 .69161 .33332 .71232 .33482 .7135 .33407 .70808 Mtetra
.28 .22 .609 r
.33407 .70808 .33482 .7135 .33637 .71356 .33548 .7109 Mtetra
.32 .35 .736 r
.33548 .7109 .33637 .71356 .33795 .71317 .33697 .71213 Mtetra
.408 .623 .94 r
.33697 .71213 .33795 .71317 .33951 .71316 .33852 .71237 Mtetra
.619 .764 .949 r
.33852 .71237 .33951 .71316 .34109 .71285 .3401 .712 Mtetra
.745 .777 .879 r
.3401 .712 .34109 .71285 .3427 .71189 .34171 .71108 Mtetra
.849 .778 .783 r
.34171 .71108 .3427 .71189 .34446 .70808 .34338 .70903 Mtetra
.972 .928 .665 r
.34338 .70903 .34446 .70808 .35559 .51912 .34513 .70529 Mtetra
.528 .318 .538 r
.34513 .70529 .35559 .51912 .35763 .508 .34747 .69006 Mtetra
0 0 .283 r
.34747 .69006 .35763 .508 .35921 .50593 .35807 .50942 Mtetra
0 0 .051 r
.35807 .50942 .35921 .50593 .36074 .50499 .35973 .50586 Mtetra
.803 .971 .67 r
.35973 .50586 .36074 .50499 .36224 .50446 .36131 .50383 Mtetra
.76 .816 .897 r
.36131 .50383 .36224 .50446 .36375 .50394 .36283 .50291 Mtetra
.661 .713 .886 r
.36283 .50291 .36375 .50394 .36525 .50346 .36433 .50244 Mtetra
.622 .701 .901 r
.36433 .50244 .36525 .50346 .36675 .50302 .36583 .50212 Mtetra
.758 .758 .853 r
.36583 .50212 .36675 .50302 .36828 .50207 .36736 .50112 Mtetra
.736 .745 .858 r
.36736 .50112 .36828 .50207 .3698 .50129 .36889 .50024 Mtetra
.604 .69 .904 r
.36889 .50024 .3698 .50129 .37129 .5011 .37038 .49999 Mtetra
.859 .425 .001 r
.37038 .49999 .37129 .5011 .37265 .50396 .37173 .5029 Mtetra
.944 .684 .512 r
.37173 .5029 .37265 .50396 .36538 .6971 .36438 .69686 Mtetra
.925 .596 .397 r
.36438 .69686 .36538 .6971 .36663 .70443 .36563 .70398 Mtetra
.487 0 0 r
.36563 .70398 .36663 .70443 .36816 .70561 .36717 .70496 Mtetra
.641 .808 .963 r
.36717 .70496 .36816 .70561 .36975 .70529 .36877 .70449 Mtetra
.791 .79 .851 r
.36877 .70449 .36975 .70529 .37139 .70401 .37041 .70323 Mtetra
.854 .785 .784 r
.37041 .70323 .37139 .70401 .37313 .70046 .37209 .70115 Mtetra
.97 .923 .689 r
.37209 .70115 .37313 .70046 .38224 .52381 .37382 .69763 Mtetra
.537 .325 .54 r
.37382 .69763 .38224 .52381 .38477 .49967 .37584 .68747 Mtetra
0 0 .3 r
.37584 .68747 .38477 .49967 .38636 .49729 .38524 .50133 Mtetra
0 0 .132 r
.38524 .50133 .38636 .49729 .3879 .49632 .3869 .49747 Mtetra
.68 .893 .532 r
.3869 .49747 .3879 .49632 .38942 .49583 .38848 .49536 Mtetra
.771 .861 .917 r
.38848 .49536 .38942 .49583 .39093 .49542 .39002 .49441 Mtetra
.639 .71 .899 r
.39002 .49441 .39093 .49542 .39244 .49508 .39154 .49402 Mtetra
.574 .678 .91 r
.39154 .49402 .39244 .49508 .39396 .4948 .39305 .49387 Mtetra
.608 .717 .922 r
.39305 .49387 .39396 .4948 .39547 .49446 .39456 .49358 Mtetra
.639 .74 .922 r
.39456 .49358 .39547 .49446 .39699 .49406 .39608 .49319 Mtetra
.648 .744 .919 r
.39608 .49319 .39699 .49406 .39851 .49362 .3976 .49276 Mtetra
.661 .749 .915 r
.3976 .49276 .39851 .49362 .40003 .49314 .39912 .49228 Mtetra
.675 .754 .91 r
.39912 .49228 .40003 .49314 .40156 .49261 .40065 .49174 Mtetra
.69 .756 .902 r
.40065 .49174 .40156 .49261 .40309 .49204 .40218 .49114 Mtetra
.713 .754 .885 r
.40218 .49114 .40309 .49204 .40462 .4914 .40371 .49041 Mtetra
.719 .738 .867 r
.40371 .49041 .40462 .4914 .40615 .49074 .40525 .48964 Mtetra
.711 .716 .853 r
.40525 .48964 .40615 .49074 .40769 .49008 .40679 .48888 Mtetra
.689 .693 .848 r
.40679 .48888 .40769 .49008 .40922 .48948 .40832 .48823 Mtetra
.674 .68 .848 r
.40832 .48823 .40922 .48948 .41075 .48892 .40986 .48766 Mtetra
.667 .676 .849 r
.40986 .48766 .41075 .48892 .41228 .48838 .41139 .48712 Mtetra
.666 .676 .85 r
.41139 .48712 .41228 .48838 .41382 .48785 .41292 .48659 Mtetra
.664 .675 .85 r
.41292 .48659 .41382 .48785 .41535 .48733 .41445 .48607 Mtetra
.657 .672 .853 r
.41445 .48607 .41535 .48733 .41688 .48684 .41599 .48559 Mtetra
.639 .667 .861 r
.41599 .48559 .41688 .48684 .41841 .48638 .41752 .48519 Mtetra
.625 .673 .876 r
.41752 .48519 .41841 .48638 .41995 .48595 .41905 .48486 Mtetra
.623 .692 .893 r
.41905 .48486 .41995 .48595 .42148 .48552 .42058 .48454 Mtetra
.64 .719 .905 r
.42058 .48454 .42148 .48552 .42301 .48505 .42211 .48414 Mtetra
.66 .74 .91 r
.42211 .48414 .42301 .48505 .42455 .48454 .42365 .48366 Mtetra
.674 .751 .908 r
.42365 .48366 .42455 .48454 .42609 .48401 .42519 .48312 Mtetra
.694 .755 .898 r
.42519 .48312 .42609 .48401 .42763 .48344 .42673 .48249 Mtetra
.704 .744 .883 r
.42673 .48249 .42763 .48344 .42918 .48286 .42828 .48181 Mtetra
.699 .724 .869 r
.42828 .48181 .42918 .48286 .43072 .48227 .42983 .48113 Mtetra
.681 .702 .863 r
.42983 .48113 .43072 .48227 .43226 .48171 .43137 .48053 Mtetra
.667 .69 .863 r
.43137 .48053 .43226 .48171 .4338 .48118 .43291 .48 Mtetra
.661 .689 .866 r
.43291 .48 .4338 .48118 .43535 .48066 .43446 .4795 Mtetra
.661 .693 .869 r
.43446 .4795 .43535 .48066 .43689 .48015 .436 .47901 Mtetra
.662 .695 .87 r
.436 .47901 .43689 .48015 .43844 .47964 .43755 .47851 Mtetra
.661 .696 .872 r
.43755 .47851 .43844 .47964 .43998 .47914 .43909 .47801 Mtetra
.662 .697 .873 r
.43909 .47801 .43998 .47914 .44153 .47863 .44064 .47751 Mtetra
.662 .699 .874 r
.44064 .47751 .44153 .47863 .44308 .47812 .44219 .47701 Mtetra
.661 .701 .876 r
.44219 .47701 .44308 .47812 .44463 .47762 .44374 .47651 Mtetra
.688 .711 .866 r
.44374 .47651 .44463 .47762 .44618 .47692 .44529 .47588 Mtetra
.696 .727 .874 r
.44529 .47588 .44618 .47692 .44774 .47618 .44685 .47522 Mtetra
.636 .725 .912 r
.44685 .47522 .44774 .47618 .44928 .47586 .44839 .47483 Mtetra
.232 .517 .912 r
.44839 .47483 .44928 .47586 .4508 .47714 .44992 .4754 Mtetra
0 0 .539 r
.44992 .4754 .4508 .47714 .45219 .48395 .45141 .47767 Mtetra
0 0 .443 r
.45141 .47767 .45219 .48395 .44957 .67738 .45282 .48415 Mtetra
0 0 .36 r
.45282 .48415 .44957 .67738 .45116 .67998 .45042 .66924 Mtetra
.547 .374 .598 r
.45042 .66924 .45116 .67998 .4528 .6798 .45205 .66973 Mtetra
.627 .436 .605 r
.45205 .66973 .4528 .6798 .45446 .67896 .45373 .66767 Mtetra
.632 .436 .599 r
.45373 .66767 .45446 .67896 .45612 .67814 .45542 .66513 Mtetra
.586 .397 .592 r
.45542 .66513 .45612 .67814 .45778 .67764 .45708 .66423 Mtetra
.586 .396 .591 r
.45708 .66423 .45778 .67764 .45943 .67713 .45874 .66332 Mtetra
.638 .435 .591 r
.45874 .66332 .45943 .67713 .46109 .67658 .46044 .65981 Mtetra
.929 .665 .517 r
.46044 .65981 .46109 .67658 .46275 .676 .46512 .4913 Mtetra
0 0 .393 r
.46512 .4913 .46275 .676 .46441 .67556 .46381 .6548 Mtetra
.239 .121 .509 r
.46381 .6548 .46441 .67556 .46606 .6755 .46524 .66748 Mtetra
.237 .162 .565 r
.46524 .66748 .46606 .6755 .46771 .67575 .46681 .67242 Mtetra
.186 .226 .67 r
.46681 .67242 .46771 .67575 .46936 .67594 .46843 .67469 Mtetra
.224 .476 .887 r
.46843 .67469 .46936 .67594 .47102 .67584 .47007 .67543 Mtetra
.527 .84 .999 r
.47007 .67543 .47102 .67584 .47268 .67542 .47173 .67509 Mtetra
.63 .896 .986 r
.47173 .67509 .47268 .67542 .47435 .67491 .4734 .67449 Mtetra
.621 .872 .989 r
.4734 .67449 .47435 .67491 .47601 .67443 .47507 .67396 Mtetra
.523 .825 1 r
.47507 .67396 .47601 .67443 .47768 .67404 .47673 .67366 Mtetra
.507 .842 .998 r
.47673 .67366 .47768 .67404 .47935 .67365 .4784 .67334 Mtetra
.547 .874 .992 r
.4784 .67334 .47935 .67365 .48102 .67321 .48007 .6729 Mtetra
.626 .899 .986 r
.48007 .6729 .48102 .67321 .48269 .6727 .48174 .67229 Mtetra
.661 .884 .98 r
.48174 .67229 .48269 .6727 .48436 .67218 .48342 .67165 Mtetra
.623 .844 .984 r
.48342 .67165 .48436 .67218 .48603 .67183 .48509 .67116 Mtetra
.565 .788 .983 r
.48509 .67116 .48603 .67183 .4877 .67167 .48676 .67088 Mtetra
.659 .785 .941 r
.48676 .67088 .4877 .67167 .48938 .67109 .48844 .67034 Mtetra
.808 .815 .857 r
.48844 .67034 .48938 .67109 .49107 .66913 .49013 .66897 Mtetra
.945 .862 .727 r
.49013 .66897 .49107 .66913 .4928 .66252 .49183 .66576 Mtetra
.762 .764 .255 r
.49183 .66576 .4928 .66252 .49618 .46637 .49356 .65942 Mtetra
0 0 .366 r
.49356 .65942 .49618 .46637 .49779 .46209 .49683 .47153 Mtetra
.451 .217 .466 r
.49683 .47153 .49779 .46209 .49938 .46119 .49843 .4692 Mtetra
.579 .318 .485 r
.49843 .4692 .49938 .46119 .50096 .46094 .50001 .47 Mtetra
.622 .36 .5 r
.50001 .47 .50096 .46094 .50254 .46083 .50157 .47227 Mtetra
.548 .305 .498 r
.50157 .47227 .50254 .46083 .50412 .46035 .50316 .47217 Mtetra
.552 .309 .501 r
.50316 .47217 .50412 .46035 .5057 .45988 .50475 .47218 Mtetra
.619 .367 .513 r
.50475 .47218 .5057 .45988 .50729 .45946 .50632 .47498 Mtetra
.931 .657 .498 r
.50632 .47498 .50729 .45946 .50887 .45909 .50703 .64635 Mtetra
.556 .341 .544 r
.50703 .64635 .50887 .45909 .51046 .45861 .50872 .64514 Mtetra
0 0 .376 r
.50872 .64514 .51046 .45861 .51205 .45784 .51114 .46535 Mtetra
.003 0 .295 r
.51114 .46535 .51205 .45784 .51364 .45668 .51276 .45845 Mtetra
.655 .785 .325 r
.51276 .45845 .51364 .45668 .51523 .45556 .51436 .45515 Mtetra
.883 .871 .821 r
.51436 .45515 .51523 .45556 .51682 .45465 .51596 .45329 Mtetra
.687 .674 .832 r
.51596 .45329 .51682 .45465 .51841 .4541 .51755 .45259 Mtetra
.635 .634 .832 r
.51755 .45259 .51841 .4541 .52001 .45364 .51914 .45219 Mtetra
.622 .636 .843 r
.51914 .45219 .52001 .45364 .5216 .45319 .52073 .45186 Mtetra
.658 .667 .848 r
.52073 .45186 .5216 .45319 .52319 .45268 .52233 .45135 Mtetra
.658 .668 .848 r
.52233 .45135 .52319 .45268 .52479 .45216 .52392 .45084 Mtetra
.658 .669 .849 r
.52392 .45084 .52479 .45216 .52638 .45164 .52552 .45033 Mtetra
.659 .671 .851 r
.52552 .45033 .52638 .45164 .52798 .45111 .52712 .44981 Mtetra
.659 .673 .852 r
.52712 .44981 .52798 .45111 .52958 .45059 .52871 .44929 Mtetra
.66 .674 .852 r
.52871 .44929 .52958 .45059 .53118 .45007 .53031 .44877 Mtetra
.66 .675 .853 r
.53031 .44877 .53118 .45007 .53277 .44955 .53191 .44825 Mtetra
.659 .675 .854 r
.53191 .44825 .53277 .44955 .53437 .44903 .53351 .44774 Mtetra
.53351 .44774 .53437 .44903 .53598 .44851 .53511 .44722 Mtetra
.659 .676 .855 r
.53511 .44722 .53598 .44851 .53758 .448 .53672 .44671 Mtetra
.53672 .44671 .53758 .448 .53918 .44748 .53832 .44619 Mtetra
.659 .675 .855 r
.53832 .44619 .53918 .44748 .54078 .44697 .53992 .44568 Mtetra
.658 .675 .855 r
.53992 .44568 .54078 .44697 .54239 .44646 .54153 .44516 Mtetra
.54153 .44516 .54239 .44646 .544 .44595 .54314 .44465 Mtetra
.658 .674 .854 r
.54314 .44465 .544 .44595 .5456 .44544 .54474 .44414 Mtetra
.54474 .44414 .5456 .44544 .54721 .44494 .54635 .44363 Mtetra
.658 .673 .853 r
.54635 .44363 .54721 .44494 .54882 .44443 .54796 .44312 Mtetra
.658 .672 .852 r
.54796 .44312 .54882 .44443 .55043 .44393 .54957 .4426 Mtetra
.659 .671 .85 r
.54957 .4426 .55043 .44393 .55204 .44342 .55118 .44208 Mtetra
.658 .669 .849 r
.55118 .44208 .55204 .44342 .55365 .44291 .55279 .44156 Mtetra
.664 .67 .846 r
.55279 .44156 .55365 .44291 .55526 .44238 .55441 .44101 Mtetra
.692 .678 .831 r
.55441 .44101 .55526 .44238 .55688 .44178 .55602 .44028 Mtetra
.658 .646 .827 r
.55602 .44028 .55688 .44178 .55849 .44124 .55763 .43974 Mtetra
.571 .607 .85 r
.55763 .43974 .55849 .44124 .56011 .44084 .55925 .43965 Mtetra
0 .213 .735 r
.55925 .43965 .56011 .44084 .56173 .44085 .56089 .44106 Mtetra
.851 .427 .22 r
.56089 .44106 .56173 .44085 .56335 .44098 .56255 .44411 Mtetra
.875 .567 .461 r
.56255 .44411 .56335 .44098 .56498 .44106 .56432 .45563 Mtetra
.939 .659 .482 r
.56432 .45563 .56498 .44106 .5666 .44062 .56813 .62958 Mtetra
.551 .337 .543 r
.56813 .62958 .5666 .44062 .56822 .44002 .5698 .62547 Mtetra
.025 0 .408 r
.5698 .62547 .56822 .44002 .56984 .43936 .56918 .45199 Mtetra
.527 .29 .499 r
.56918 .45199 .56984 .43936 .57146 .43881 .5708 .45107 Mtetra
.526 .288 .497 r
.5708 .45107 .57146 .43881 .57309 .43826 .57243 .45016 Mtetra
.527 .288 .496 r
.57243 .45016 .57309 .43826 .57471 .43772 .57405 .44932 Mtetra
.53 .29 .495 r
.57405 .44932 .57471 .43772 .57633 .43717 .57568 .44861 Mtetra
.533 .292 .495 r
.57568 .44861 .57633 .43717 .57796 .43663 .57731 .448 Mtetra
.53 .289 .494 r
.57731 .448 .57796 .43663 .57959 .43608 .57894 .44729 Mtetra
.422 .201 .472 r
.57894 .44729 .57959 .43608 .58121 .43506 .58053 .44366 Mtetra
.514 .266 .476 r
.58053 .44366 .58121 .43506 .58283 .43447 .58216 .44283 Mtetra
.703 .426 .501 r
.58216 .44283 .58283 .43447 .58448 .43477 .5839 .44837 Mtetra
.944 .662 .474 r
.5839 .44837 .58448 .43477 .58626 .44217 .58901 .63514 Mtetra
.564 .347 .544 r
.58901 .63514 .58626 .44217 .59168 .63759 .59083 .6389 Mtetra
.712 .307 .277 r
.59083 .6389 .59168 .63759 .5935 .64122 .59261 .64065 Mtetra
.358 .727 .987 r
.59261 .64065 .5935 .64122 .59525 .64136 .59436 .64069 Mtetra
.588 .803 .981 r
.59436 .64069 .59525 .64136 .59699 .64086 .59611 .64032 Mtetra
.658 .858 .976 r
.59611 .64032 .59699 .64086 .59873 .64002 .59785 .6397 Mtetra
.506 .86 .99 r
.59785 .6397 .59873 .64002 .60047 .63955 .5996 .63931 Mtetra
.589 .91 .978 r
.5996 .63931 .60047 .63955 .60221 .63898 .60134 .63869 Mtetra
.739 .935 .952 r
.60134 .63869 .60221 .63898 .60395 .6383 .60307 .6377 Mtetra
.901 .844 .778 r
.60307 .6377 .60395 .6383 .60569 .63725 .60478 .63526 Mtetra
.854 .688 .676 r
.60478 .63526 .60569 .63725 .60742 .63607 .60644 .6314 Mtetra
.835 .614 .603 r
.60644 .6314 .60742 .63607 .60915 .63488 .60801 .62334 Mtetra
.616 .423 .598 r
.60801 .62334 .60915 .63488 .61091 .63477 .60972 .62133 Mtetra
.544 .365 .589 r
.60972 .62133 .61091 .63477 .61266 .63442 .61149 .62209 Mtetra
.605 .413 .595 r
.61149 .62209 .61266 .63442 .6144 .6333 .61321 .62044 Mtetra
.953 .674 .472 r
.61321 .62044 .6144 .6333 .61597 .62606 .60998 .42979 Mtetra
.567 .354 .55 r
.60998 .42979 .61597 .62606 .61241 .42828 .61151 .42493 Mtetra
.748 .58 .667 r
.61151 .42493 .61241 .42828 .61394 .42359 .6131 .42228 Mtetra
.726 .703 .828 r
.6131 .42228 .61394 .42359 .61557 .42238 .61474 .42133 Mtetra
.652 .722 .899 r
.61474 .42133 .61557 .42238 .61722 .4219 .61639 .42084 Mtetra
.591 .696 .916 r
.61639 .42084 .61722 .4219 .61888 .42177 .61805 .4206 Mtetra
.619 .686 .891 r
.61805 .4206 .61888 .42177 .62054 .42137 .61971 .42027 Mtetra
.615 .697 .903 r
.61971 .42027 .62054 .42137 .62219 .42095 .62137 .41995 Mtetra
.614 .718 .92 r
.62137 .41995 .62219 .42095 .62385 .42053 .62302 .41962 Mtetra
.643 .75 .927 r
.62302 .41962 .62385 .42053 .6255 .42005 .62468 .41916 Mtetra
.657 .761 .926 r
.62468 .41916 .6255 .42005 .62716 .41954 .62634 .41865 Mtetra
.666 .763 .923 r
.62634 .41865 .62716 .41954 .62882 .41902 .62799 .41811 Mtetra
.66 .757 .922 r
.62799 .41811 .62882 .41902 .63047 .41848 .62965 .41759 Mtetra
.665 .762 .922 r
.62965 .41759 .63047 .41848 .63213 .41793 .63131 .41705 Mtetra
.676 .768 .92 r
.63131 .41705 .63213 .41793 .63379 .41736 .63297 .41646 Mtetra
.703 .774 .907 r
.63297 .41646 .63379 .41736 .63544 .41673 .63462 .41575 Mtetra
.707 .757 .891 r
.63462 .41575 .63544 .41673 .6371 .41608 .63627 .415 Mtetra
.701 .735 .878 r
.63627 .415 .6371 .41608 .63876 .41545 .63793 .41428 Mtetra
.716 .723 .856 r
.63793 .41428 .63876 .41545 .64041 .41453 .63958 .41344 Mtetra
.69 .73 .881 r
.63958 .41344 .64041 .41453 .64206 .41382 .64124 .41277 Mtetra
.607 .706 .915 r
.64124 .41277 .64206 .41382 .64374 .41366 .64291 .41247 Mtetra
.172 .44 .872 r
.64291 .41247 .64374 .41366 .64551 .41601 .64463 .41336 Mtetra
.048 .168 .669 r
.64463 .41336 .64551 .41601 .65436 .60554 .64642 .4159 Mtetra
.52 .318 .546 r
.64642 .4159 .65436 .60554 .65671 .62037 .64887 .43609 Mtetra
.033 0 .429 r
.64887 .43609 .65671 .62037 .65857 .62197 .65754 .61666 Mtetra
.314 .259 .635 r
.65754 .61666 .65857 .62197 .66038 .62217 .65946 .61966 Mtetra
.336 .381 .76 r
.65946 .61966 .66038 .62217 .66217 .62187 .66131 .62096 Mtetra
.37 .642 .961 r
.66131 .62096 .66217 .62187 .66397 .6218 .66313 .62122 Mtetra
.568 .823 .993 r
.66313 .62122 .66397 .6218 .66577 .62147 .66492 .62084 Mtetra
.743 .862 .935 r
.66492 .62084 .66577 .62147 .66753 .62051 .66669 .61989 Mtetra
.88 .862 .818 r
.66669 .61989 .66753 .62051 .6692 .6171 .66841 .61788 Mtetra
.927 .937 .58 r
.66841 .61788 .6692 .6171 .67043 .60348 .67007 .61428 Mtetra
.078 0 .372 r
.67007 .61428 .67043 .60348 .66393 .41045 .67145 .60426 Mtetra
.031 0 .423 r
.67145 .60426 .66393 .41045 .66551 .40776 .6649 .41122 Mtetra
0 0 .166 r
.6649 .41122 .66551 .40776 .66716 .40656 .66642 .40709 Mtetra
.834 .97 .655 r
.66642 .40709 .66716 .40656 .66883 .40584 .66802 .40482 Mtetra
.762 .765 .855 r
.66802 .40482 .66883 .40584 .67051 .40523 .66968 .40372 Mtetra
.657 .65 .831 r
.66968 .40372 .67051 .40523 .67219 .40471 .67136 .40317 Mtetra
.614 .626 .839 r
.67136 .40317 .67219 .40471 .67388 .40427 .67305 .40286 Mtetra
.62 .647 .856 r
.67305 .40286 .67388 .40427 .67557 .40379 .67475 .40252 Mtetra
.627 .673 .875 r
.67475 .40252 .67557 .40379 .67725 .40329 .67644 .40214 Mtetra
.634 .7 .893 r
.67644 .40214 .67725 .40329 .67894 .40277 .67813 .40174 Mtetra
.715 .751 .88 r
.67813 .40174 .67894 .40277 .68061 .40189 .67981 .40094 Mtetra
.725 .771 .89 r
.67981 .40094 .68061 .40189 .68228 .40108 .68148 .4001 Mtetra
.659 .745 .913 r
.68148 .4001 .68228 .40108 .68398 .40076 .68317 .39957 Mtetra
.223 .473 .885 r
.68317 .39957 .68398 .40076 .68579 .40268 .68493 .40037 Mtetra
0 .128 .659 r
.68493 .40037 .68579 .40268 .68821 .41653 .68678 .40298 Mtetra
.231 .139 .54 r
.68678 .40298 .68821 .41653 .69967 .60758 .68899 .41267 Mtetra
.08 0 .45 r
.68899 .41267 .69967 .60758 .70158 .60907 .70014 .59648 Mtetra
.602 .41 .594 r
.70014 .59648 .70158 .60907 .70339 .60861 .70188 .59487 Mtetra
.591 .399 .59 r
.70188 .59487 .70339 .60861 .70518 .6077 .70365 .59366 Mtetra
.348 .224 .566 r
.70365 .59366 .70518 .6077 .707 .60748 .70586 .60085 Mtetra
.303 .234 .611 r
.70586 .60085 .707 .60748 .70885 .6077 .70791 .60482 Mtetra
.253 .303 .722 r
.70791 .60482 .70885 .6077 .7107 .60783 .70985 .60677 Mtetra
.316 .577 .934 r
.70985 .60677 .7107 .60783 .71253 .60765 .71172 .60725 Mtetra
.446 .82 .992 r
.71172 .60725 .71253 .60765 .71435 .60726 .71355 .60699 Mtetra
.534 .891 .977 r
.71355 .60699 .71435 .60726 .71617 .60676 .71537 .60645 Mtetra
.515 .875 .984 r
.71537 .60645 .71617 .60676 .718 .60648 .71719 .60598 Mtetra
.601 .863 .993 r
.71719 .60598 .718 .60648 .71983 .60614 .71901 .60546 Mtetra
.723 .852 .943 r
.71901 .60546 .71983 .60614 .72163 .60527 .72081 .60459 Mtetra
.878 .857 .817 r
.72081 .60459 .72163 .60527 .72331 .60232 .72255 .60256 Mtetra
.979 .917 .641 r
.72255 .60256 .72331 .60232 .72456 .59193 .72417 .59873 Mtetra
0 0 .255 r
.72417 .59873 .72456 .59193 .71476 .39468 .72551 .58993 Mtetra
.078 0 .445 r
.72551 .58993 .71476 .39468 .71633 .3918 .71613 .40072 Mtetra
.497 .254 .476 r
.71613 .40072 .71633 .3918 .71803 .39107 .7178 .39937 Mtetra
.6 .333 .484 r
.7178 .39937 .71803 .39107 .71976 .3909 .71964 .40088 Mtetra
.706 .426 .499 r
.71964 .40088 .71976 .3909 .7215 .3907 .7218 .4076 Mtetra
.95 .652 .438 r
.7218 .4076 .7215 .3907 .72322 .39028 .73418 .58023 Mtetra
.212 .088 .485 r
.73418 .58023 .72322 .39028 .72493 .38973 .72693 .43358 Mtetra
.122 .014 .448 r
.72693 .43358 .72493 .38973 .72662 .38877 .72621 .39374 Mtetra
.025 0 .292 r
.72621 .39374 .72662 .38877 .72829 .38755 .72763 .3885 Mtetra
.756 .875 .455 r
.72763 .3885 .72829 .38755 .72997 .38642 .7292 .38557 Mtetra
.823 .819 .845 r
.7292 .38557 .72997 .38642 .73167 .38558 .73086 .38409 Mtetra
.671 .662 .832 r
.73086 .38409 .73167 .38558 .73339 .38501 .73257 .38344 Mtetra
.628 .632 .835 r
.73257 .38344 .73339 .38501 .73511 .38452 .7343 .38305 Mtetra
.635 .648 .846 r
.7343 .38305 .73511 .38452 .73683 .38402 .73603 .38262 Mtetra
.656 .668 .85 r
.73603 .38262 .73683 .38402 .73855 .38348 .73775 .38208 Mtetra
.656 .669 .851 r
.73775 .38208 .73855 .38348 .74028 .38293 .73947 .38154 Mtetra
.657 .67 .852 r
.73947 .38154 .74028 .38293 .742 .38238 .7412 .381 Mtetra
.658 .672 .852 r
.7412 .381 .742 .38238 .74373 .38183 .74292 .38045 Mtetra
.74292 .38045 .74373 .38183 .74545 .38128 .74465 .37989 Mtetra
.658 .673 .852 r
.74465 .37989 .74545 .38128 .74718 .38073 .74638 .37934 Mtetra
.659 .673 .852 r
.74638 .37934 .74718 .38073 .7489 .38017 .7481 .37879 Mtetra
.7481 .37879 .7489 .38017 .75063 .37962 .74983 .37823 Mtetra
.66 .673 .852 r
.74983 .37823 .75063 .37962 .75236 .37906 .75156 .37766 Mtetra
.66 .673 .851 r
.75156 .37766 .75236 .37906 .75409 .37849 .75329 .3771 Mtetra
.661 .673 .851 r
.75329 .3771 .75409 .37849 .75582 .37792 .75502 .37653 Mtetra
.662 .674 .85 r
.75502 .37653 .75582 .37792 .75755 .37735 .75675 .37595 Mtetra
.663 .673 .849 r
.75675 .37595 .75755 .37735 .75928 .37677 .75849 .37536 Mtetra
.664 .673 .848 r
.75849 .37536 .75928 .37677 .76102 .37619 .76022 .37477 Mtetra
.681 .68 .842 r
.76022 .37477 .76102 .37619 .76275 .37556 .76194 .37408 Mtetra
.687 .673 .831 r
.76194 .37408 .76275 .37556 .76448 .3749 .76367 .37333 Mtetra
.648 .643 .831 r
.76367 .37333 .76448 .3749 .76621 .37432 .76541 .37281 Mtetra
.522 .588 .862 r
.76541 .37281 .76621 .37432 .76795 .3738 .7672 .37292 Mtetra
0 .314 .793 r
.7672 .37292 .76795 .3738 .76971 .37342 .76907 .37412 Mtetra
.813 .373 .196 r
.76907 .37412 .76971 .37342 .7715 .37354 .77109 .37707 Mtetra
.972 .669 .38 r
.77109 .37707 .7715 .37354 .77344 .37546 .78781 .5698 Mtetra
.572 .353 .544 r
.78781 .5698 .77344 .37546 .79043 .5697 .79048 .57968 Mtetra
.619 .352 .491 r
.79048 .57968 .79043 .5697 .79328 .58174 .79259 .58223 Mtetra
.505 0 0 r
.79259 .58223 .79328 .58174 .79534 .58369 .79455 .58286 Mtetra
.665 .805 .95 r
.79455 .58286 .79534 .58369 .79722 .5833 .79641 .58223 Mtetra
.743 .776 .879 r
.79641 .58223 .79722 .5833 .79905 .58233 .79824 .58119 Mtetra
.737 .762 .873 r
.79824 .58119 .79905 .58233 .80088 .58128 .80007 .58018 Mtetra
.672 .744 .905 r
.80007 .58018 .80088 .58128 .80274 .58061 .80193 .57954 Mtetra
.656 .745 .915 r
.80193 .57954 .80274 .58061 .8046 .57998 .8038 .57897 Mtetra
.607 .74 .939 r
.8038 .57897 .8046 .57998 .80648 .57947 .80569 .5786 Mtetra
.537 .743 .97 r
.80569 .5786 .80648 .57947 .80837 .5791 .8076 .57841 Mtetra
.603 .818 .982 r
.8076 .57841 .80837 .5791 .81025 .57868 .80948 .57795 Mtetra
.781 .86 .909 r
.80948 .57795 .81025 .57868 .81214 .5782 .8113 .57676 Mtetra
.86 .749 .739 r
.8113 .57676 .81214 .5782 .81401 .57759 .813 .5741 Mtetra
.835 .631 .627 r
.813 .5741 .81401 .57759 .81583 .57636 .81447 .5688 Mtetra
.973 .674 .388 r
.81447 .5688 .81583 .57636 .81747 .57303 .79949 .37205 Mtetra
.569 .355 .55 r
.79949 .37205 .81747 .57303 .80209 .37357 .80071 .36526 Mtetra
.663 .466 .607 r
.80071 .36526 .80209 .37357 .80312 .36458 .80226 .36224 Mtetra
.735 .618 .728 r
.80226 .36224 .80312 .36458 .80469 .36182 .80393 .36062 Mtetra
.655 .708 .886 r
.80393 .36062 .80469 .36182 .80644 .36109 .8057 .3601 Mtetra
.565 .71 .939 r
.8057 .3601 .80644 .36109 .80823 .36086 .80749 .3599 Mtetra
.551 .713 .947 r
.80749 .3599 .80823 .36086 .81004 .36073 .80929 .35974 Mtetra
.642 .746 .925 r
.80929 .35974 .81004 .36073 .81181 .36025 .81107 .35926 Mtetra
.661 .753 .918 r
.81107 .35926 .81181 .36025 .81358 .35974 .81284 .3587 Mtetra
.685 .752 .902 r
.81284 .3587 .81358 .35974 .81535 .35916 .8146 .35803 Mtetra
.707 .743 .879 r
.8146 .35803 .81535 .35916 .81711 .35848 .81634 .35724 Mtetra
.705 .72 .861 r
.81634 .35724 .81711 .35848 .81887 .35778 .81809 .35642 Mtetra
.713 .705 .841 r
.81809 .35642 .81887 .35778 .82061 .35695 .81983 .35553 Mtetra
.729 .702 .825 r
.81983 .35553 .82061 .35695 .82234 .35591 .82156 .35449 Mtetra
.663 .675 .851 r
.82156 .35449 .82234 .35591 .82411 .35531 .82333 .3539 Mtetra
.39 .531 .877 r
.82333 .3539 .82411 .35531 .82599 .35591 .82521 .35446 Mtetra
.743 .353 0 r
.82521 .35446 .82599 .35591 .82838 .36174 .82754 .3597 Mtetra
.975 .667 .33 r
.82754 .3597 .82838 .36174 .84961 .56397 .84879 .56254 Mtetra
0 0 .352 r
.84879 .56254 .84961 .56397 .85193 .5678 .85114 .56665 Mtetra
.452 .635 .934 r
.85114 .56665 .85193 .5678 .85391 .56808 .85311 .56685 Mtetra
.692 .733 .882 r
.85311 .56685 .85391 .56808 .8558 .56729 .855 .56608 Mtetra
.809 .774 .821 r
.855 .56608 .8558 .56729 .85755 .56515 .8568 .56444 Mtetra
.932 .86 .746 r
.8568 .56444 .85755 .56515 .85888 .55884 .85848 .56156 Mtetra
0 0 .004 r
.85848 .56156 .85888 .55884 .84076 .35668 .85986 .5557 Mtetra
.12 .032 .473 r
.85986 .5557 .84076 .35668 .84208 .35142 .84209 .35787 Mtetra
.154 0 .382 r
.84209 .35787 .84208 .35142 .84377 .3499 .84334 .35189 Mtetra
0 0 .075 r
.84334 .35189 .84377 .3499 .84552 .34902 .8449 .34904 Mtetra
.842 .999 .796 r
.8449 .34904 .84552 .34902 .8473 .34835 .84656 .34724 Mtetra
.766 .768 .855 r
.84656 .34724 .8473 .34835 .84904 .34732 .84829 .34607 Mtetra
.646 .696 .882 r
.84829 .34607 .84904 .34732 .85083 .34677 .85009 .34557 Mtetra
.315 .527 .901 r
.85009 .34557 .85083 .34677 .85273 .34727 .85201 .34622 Mtetra
.841 .435 0 r
.85201 .34622 .85273 .34727 .85517 .35286 .85449 .35233 Mtetra
.973 .663 .321 r
.85449 .35233 .85517 .35286 .87824 .55567 .87753 .55525 Mtetra
.797 .32 0 r
.87753 .55525 .87824 .55567 .88064 .55967 .87991 .55902 Mtetra
.493 .783 .996 r
.87991 .55902 .88064 .55967 .88261 .55957 .88187 .55881 Mtetra
.733 .852 .937 r
.88187 .55881 .88261 .55957 .8845 .55872 .88375 .55786 Mtetra
.78 .84 .897 r
.88375 .55786 .8845 .55872 .88637 .55761 .88561 .55663 Mtetra
.591 .743 .949 r
.88561 .55663 .88637 .55761 .88834 .55747 .88756 .5563 Mtetra
.647 .727 .908 r
.88756 .5563 .88834 .55747 .89027 .55695 .88949 .55576 Mtetra
.738 .761 .871 r
.88949 .55576 .89027 .55695 .8921 .55551 .89137 .55471 Mtetra
.92 .855 .761 r
.89137 .55471 .8921 .55551 .89346 .54977 .89306 .55201 Mtetra
0 0 0 r
.89306 .55201 .89346 .54977 .87321 .34731 .89448 .54678 Mtetra
.135 .045 .481 r
.89448 .54678 .87321 .34731 .87441 .34126 .87465 .34886 Mtetra
.155 0 .403 r
.87465 .34886 .87441 .34126 .8761 .33962 .87572 .34165 Mtetra
0 0 .083 r
.87572 .34165 .8761 .33962 .87786 .33868 .87725 .33856 Mtetra
.87 .991 .817 r
.87725 .33856 .87786 .33868 .87967 .33812 .87892 .33672 Mtetra
.667 .682 .855 r
.87892 .33672 .87967 .33812 .88149 .33762 .88072 .3361 Mtetra
.602 .632 .854 r
.88072 .3361 .88149 .33762 .88332 .33724 .88257 .33583 Mtetra
.567 .632 .876 r
.88257 .33583 .88332 .33724 .88516 .33687 .88443 .33572 Mtetra
.644 .715 .9 r
.88443 .33572 .88516 .33687 .88697 .33632 .88626 .33523 Mtetra
.661 .737 .906 r
.88626 .33523 .88697 .33632 .88878 .33571 .88807 .33466 Mtetra
.681 .754 .906 r
.88807 .33466 .88878 .33571 .89059 .33504 .88988 .33399 Mtetra
.755 .781 .874 r
.88988 .33399 .89059 .33504 .89234 .33393 .89163 .33291 Mtetra
.721 .778 .897 r
.89163 .33291 .89234 .33393 .89413 .33315 .89342 .33205 Mtetra
.631 .722 .913 r
.89342 .33205 .89413 .33315 .896 .33302 .89525 .33161 Mtetra
.228 .431 .852 r
.89525 .33161 .896 .33302 .89827 .3362 .89727 .33271 Mtetra
.218 .247 .677 r
.89727 .33271 .89827 .3362 .92394 .53638 .89951 .33567 Mtetra
.155 .067 .496 r
.89951 .33567 .92394 .53638 .92692 .54445 .92464 .53056 Mtetra
.535 .327 .545 r
.31109 .52076 .3001 .70916 .30103 .71859 .31184 .53174 Mtetra
0 0 .26 r
.31184 .53174 .30103 .71859 .30241 .72114 .30154 .71809 Mtetra
0 0 .508 r
.30154 .71809 .30241 .72114 .30387 .72223 .30288 .72118 Mtetra
.467 .645 .935 r
.30288 .72118 .30387 .72223 .30541 .7222 .30441 .72129 Mtetra
.681 .75 .903 r
.30441 .72129 .30541 .7222 .30699 .7216 .30599 .72071 Mtetra
.759 .765 .857 r
.30599 .72071 .30699 .7216 .3086 .72043 .30759 .71966 Mtetra
.712 .787 .91 r
.30759 .71966 .3086 .72043 .31028 .71817 .30918 .71895 Mtetra
0 0 0 r
.30918 .71895 .31028 .71817 .31206 .71407 .31079 .71781 Mtetra
.234 0 .265 r
.31079 .71781 .31206 .71407 .32463 .52944 .31245 .71578 Mtetra
.538 .326 .54 r
.31245 .71578 .32463 .52944 .32675 .5184 .3146 .70564 Mtetra
0 0 .252 r
.3146 .70564 .32675 .5184 .3284 .51513 .32733 .51646 Mtetra
.963 .932 .615 r
.32733 .51646 .3284 .51513 .32997 .51323 .32902 .51262 Mtetra
.77 .817 .889 r
.32902 .51262 .32997 .51323 .33146 .51257 .33053 .51165 Mtetra
.619 .719 .917 r
.33053 .51165 .33146 .51257 .33294 .51232 .33201 .51133 Mtetra
.517 .669 .932 r
.33201 .51133 .33294 .51232 .3344 .51225 .33347 .51132 Mtetra
.67 .735 .898 r
.33347 .51132 .3344 .51225 .3359 .51159 .33496 .51082 Mtetra
.676 .769 .921 r
.33496 .51082 .3359 .51159 .33739 .51101 .33645 .51029 Mtetra
.643 .776 .944 r
.33645 .51029 .33739 .51101 .33887 .51075 .33794 .50987 Mtetra
.62 .731 .926 r
.33794 .50987 .33887 .51075 .34028 .51173 .33942 .50955 Mtetra
.558 .519 .768 r
.33942 .50955 .34028 .51173 .3416 .51433 .34089 .50959 Mtetra
.499 .383 .652 r
.34089 .50959 .3416 .51433 .33341 .69161 .34231 .51038 Mtetra
.545 .336 .547 r
.34231 .51038 .33341 .69161 .33407 .70808 .34345 .51645 Mtetra
0 0 .281 r
.34345 .51645 .33407 .70808 .33548 .7109 .33463 .70727 Mtetra
0 0 .466 r
.33463 .70727 .33548 .7109 .33697 .71213 .33599 .71109 Mtetra
.267 .546 .925 r
.33599 .71109 .33697 .71213 .33852 .71237 .33752 .71157 Mtetra
.635 .767 .943 r
.33752 .71157 .33852 .71237 .3401 .712 .33911 .71116 Mtetra
.739 .776 .882 r
.33911 .71116 .3401 .712 .34171 .71108 .34072 .71027 Mtetra
.707 .779 .908 r
.34072 .71027 .34171 .71108 .34338 .70903 .34232 .70956 Mtetra
.482 .878 .707 r
.34232 .70956 .34338 .70903 .34513 .70529 .34394 .70854 Mtetra
.227 0 .237 r
.34394 .70854 .34513 .70529 .34747 .69006 .34559 .70673 Mtetra
.355 .151 .459 r
.34559 .70673 .34747 .69006 .35807 .50942 .3475 .69994 Mtetra
0 0 .274 r
.3475 .69994 .35807 .50942 .35973 .50586 .35866 .5078 Mtetra
.933 .906 .514 r
.35866 .5078 .35973 .50586 .36131 .50383 .36037 .50321 Mtetra
.817 .815 .848 r
.36037 .50321 .36131 .50383 .36283 .50291 .36191 .50187 Mtetra
.662 .709 .883 r
.36191 .50187 .36283 .50291 .36433 .50244 .36342 .50138 Mtetra
.58 .68 .909 r
.36342 .50138 .36433 .50244 .36583 .50212 .36491 .50122 Mtetra
.741 .756 .864 r
.36491 .50122 .36583 .50212 .36736 .50112 .36643 .50033 Mtetra
.731 .779 .892 r
.36643 .50033 .36736 .50112 .36889 .50024 .36795 .49954 Mtetra
.544 .754 .974 r
.36795 .49954 .36889 .50024 .37038 .49999 .36945 .49937 Mtetra
.89 .466 .162 r
.36945 .49937 .37038 .49999 .37173 .5029 .37079 .50237 Mtetra
.944 .683 .513 r
.37079 .50237 .37173 .5029 .36438 .69686 .36339 .69622 Mtetra
.936 .6 .369 r
.36339 .69622 .36438 .69686 .36563 .70398 .36465 .70302 Mtetra
0 .356 .819 r
.36465 .70302 .36563 .70398 .36717 .70496 .3662 .70391 Mtetra
.654 .718 .895 r
.3662 .70391 .36717 .70496 .36877 .70449 .3678 .70343 Mtetra
.751 .741 .843 r
.3678 .70343 .36877 .70449 .37041 .70323 .36943 .70237 Mtetra
.729 .776 .89 r
.36943 .70237 .37041 .70323 .37209 .70115 .37105 .70154 Mtetra
.547 .923 .788 r
.37105 .70154 .37209 .70115 .37382 .69763 .37268 .70055 Mtetra
.216 0 .211 r
.37268 .70055 .37382 .69763 .37584 .68747 .37434 .69886 Mtetra
.303 .096 .424 r
.37434 .69886 .37584 .68747 .38524 .50133 .37616 .69331 Mtetra
0 0 .292 r
.37616 .69331 .38524 .50133 .3869 .49747 .38583 .50018 Mtetra
.842 .841 .374 r
.38583 .50018 .3869 .49747 .38848 .49536 .38755 .49492 Mtetra
.85 .852 .844 r
.38755 .49492 .38848 .49536 .39002 .49441 .38911 .49338 Mtetra
.65 .71 .891 r
.38911 .49338 .39002 .49441 .39154 .49402 .39063 .49294 Mtetra
.537 .659 .914 r
.39063 .49294 .39154 .49402 .39305 .49387 .39213 .49291 Mtetra
.594 .706 .922 r
.39213 .49291 .39305 .49387 .39456 .49358 .39365 .49267 Mtetra
.639 .732 .916 r
.39365 .49267 .39456 .49358 .39608 .49319 .39516 .49228 Mtetra
.648 .736 .913 r
.39516 .49228 .39608 .49319 .3976 .49276 .39669 .49185 Mtetra
.665 .741 .907 r
.39669 .49185 .3976 .49276 .39912 .49228 .39821 .49135 Mtetra
.679 .742 .898 r
.39821 .49135 .39912 .49228 .40065 .49174 .39974 .4908 Mtetra
.689 .74 .89 r
.39974 .4908 .40065 .49174 .40218 .49114 .40127 .49019 Mtetra
.702 .743 .883 r
.40127 .49019 .40218 .49114 .40371 .49041 .4028 .48952 Mtetra
.709 .755 .888 r
.4028 .48952 .40371 .49041 .40525 .48964 .40434 .48882 Mtetra
.71 .771 .901 r
.40434 .48882 .40525 .48964 .40679 .48888 .40588 .48813 Mtetra
.697 .785 .918 r
.40588 .48813 .40679 .48888 .40832 .48823 .40741 .48749 Mtetra
.685 .787 .928 r
.40741 .48749 .40832 .48823 .40986 .48766 .40894 .48691 Mtetra
.678 .783 .929 r
.40894 .48691 .40986 .48766 .41139 .48712 .41048 .48636 Mtetra
.674 .778 .928 r
.41048 .48636 .41139 .48712 .41292 .48659 .41201 .48582 Mtetra
.668 .776 .93 r
.41201 .48582 .41292 .48659 .41445 .48607 .41354 .4853 Mtetra
.66 .775 .934 r
.41354 .4853 .41445 .48607 .41599 .48559 .41508 .48482 Mtetra
.644 .77 .94 r
.41508 .48482 .41599 .48559 .41752 .48519 .41661 .48439 Mtetra
.634 .757 .937 r
.41661 .48439 .41752 .48519 .41905 .48486 .41814 .48399 Mtetra
.635 .742 .926 r
.41814 .48399 .41905 .48486 .42058 .48454 .41968 .4836 Mtetra
.647 .732 .911 r
.41968 .4836 .42058 .48454 .42211 .48414 .42121 .48317 Mtetra
.659 .729 .901 r
.42121 .48317 .42211 .48414 .42365 .48366 .42275 .4827 Mtetra
.667 .732 .898 r
.42275 .4827 .42365 .48366 .42519 .48312 .42429 .48219 Mtetra
.679 .742 .898 r
.42429 .48219 .42519 .48312 .42673 .48249 .42583 .48163 Mtetra
.687 .759 .906 r
.42583 .48163 .42673 .48249 .42828 .48181 .42737 .48103 Mtetra
.688 .779 .921 r
.42737 .48103 .42828 .48181 .42983 .48113 .42892 .48043 Mtetra
.676 .797 .94 r
.42892 .48043 .42983 .48113 .43137 .48053 .43046 .47988 Mtetra
.662 .806 .952 r
.43046 .47988 .43137 .48053 .43291 .48 .43201 .47937 Mtetra
.656 .809 .957 r
.43201 .47937 .43291 .48 .43446 .4795 .43355 .47887 Mtetra
.654 .81 .958 r
.43355 .47887 .43446 .4795 .436 .47901 .4351 .47838 Mtetra
.654 .811 .959 r
.4351 .47838 .436 .47901 .43755 .47851 .43664 .47789 Mtetra
.652 .813 .96 r
.43664 .47789 .43755 .47851 .43909 .47801 .43819 .4774 Mtetra
.651 .815 .962 r
.43819 .4774 .43909 .47801 .44064 .47751 .43974 .47691 Mtetra
.65 .817 .964 r
.43974 .47691 .44064 .47751 .44219 .47701 .44129 .47642 Mtetra
.65 .82 .965 r
.44129 .47642 .44219 .47701 .44374 .47651 .44283 .47593 Mtetra
.67 .826 .959 r
.44283 .47593 .44374 .47651 .44529 .47588 .44439 .47537 Mtetra
.671 .848 .967 r
.44439 .47537 .44529 .47588 .44685 .47522 .44594 .4748 Mtetra
.617 .859 .989 r
.44594 .4748 .44685 .47522 .44839 .47483 .44749 .47433 Mtetra
.445 .774 .998 r
.44749 .47433 .44839 .47483 .44992 .4754 .44903 .47423 Mtetra
.413 .582 .909 r
.44903 .47423 .44992 .4754 .45141 .47767 .45057 .47454 Mtetra
.51 .439 .712 r
.45057 .47454 .45141 .47767 .45282 .48415 .45211 .475 Mtetra
.559 .387 .605 r
.45211 .475 .45282 .48415 .45042 .66924 .45365 .47513 Mtetra
.559 .347 .55 r
.45365 .47513 .45042 .66924 .45205 .66973 .45521 .47467 Mtetra
.56 .348 .55 r
.45521 .47467 .45205 .66973 .45373 .66767 .45677 .47401 Mtetra
.45677 .47401 .45373 .66767 .45542 .66513 .45833 .47336 Mtetra
.559 .348 .55 r
.45833 .47336 .45542 .66513 .45708 .66423 .45989 .47281 Mtetra
.45989 .47281 .45708 .66423 .45874 .66332 .46145 .47227 Mtetra
.56 .348 .55 r
.46145 .47227 .45874 .66332 .46044 .65981 .46302 .47147 Mtetra
.46302 .47147 .46044 .65981 .46512 .4913 .46459 .47057 Mtetra
.566 .369 .573 r
.46459 .47057 .46512 .4913 .46381 .6548 .46615 .47028 Mtetra
.554 .344 .549 r
.46615 .47028 .46381 .6548 .46524 .66748 .46767 .47242 Mtetra
0 0 .353 r
.46767 .47242 .46524 .66748 .46681 .67242 .46596 .66577 Mtetra
0 0 .437 r
.46596 .66577 .46681 .67242 .46843 .67469 .4675 .67285 Mtetra
0 .226 .738 r
.4675 .67285 .46843 .67469 .47007 .67543 .46913 .6745 Mtetra
.578 .727 .944 r
.46913 .6745 .47007 .67543 .47173 .67509 .47079 .67427 Mtetra
.699 .786 .918 r
.47079 .67427 .47173 .67509 .4734 .67449 .47246 .67357 Mtetra
.695 .765 .905 r
.47246 .67357 .4734 .67449 .47507 .67396 .47413 .67289 Mtetra
.63 .715 .908 r
.47413 .67289 .47507 .67396 .47673 .67366 .4758 .6725 Mtetra
.636 .698 .891 r
.4758 .6725 .47673 .67366 .4784 .67334 .47747 .67209 Mtetra
.65 .688 .872 r
.47747 .67209 .4784 .67334 .48007 .6729 .47914 .6716 Mtetra
.667 .687 .86 r
.47914 .6716 .48007 .6729 .48174 .67229 .48081 .67103 Mtetra
.67 .694 .863 r
.48081 .67103 .48174 .67229 .48342 .67165 .48249 .67044 Mtetra
.657 .698 .876 r
.48249 .67044 .48342 .67165 .48509 .67116 .48416 .66993 Mtetra
.634 .685 .881 r
.48416 .66993 .48509 .67116 .48676 .67088 .48583 .66952 Mtetra
.651 .672 .858 r
.48583 .66952 .48676 .67088 .48844 .67034 .48751 .66903 Mtetra
.704 .698 .841 r
.48751 .66903 .48844 .67034 .49013 .66897 .48919 .66822 Mtetra
.802 .815 .861 r
.48919 .66822 .49013 .66897 .49183 .66576 .49088 .66689 Mtetra
0 0 0 r
.49088 .66689 .49183 .66576 .49356 .65942 .49256 .66538 Mtetra
.458 .194 .426 r
.49256 .66538 .49356 .65942 .49683 .47153 .49425 .66409 Mtetra
.557 .341 .544 r
.49425 .66409 .49683 .47153 .49843 .4692 .49593 .66351 Mtetra
.557 .342 .544 r
.49593 .66351 .49843 .4692 .50001 .47 .49761 .66316 Mtetra
.49761 .66316 .50001 .47 .50157 .47227 .49929 .66285 Mtetra
.49929 .66285 .50157 .47227 .50316 .47217 .50097 .6624 Mtetra
.50097 .6624 .50316 .47217 .50475 .47218 .50266 .66196 Mtetra
.50266 .66196 .50475 .47218 .50632 .47498 .50434 .6617 Mtetra
.558 .342 .544 r
.50434 .6617 .50632 .47498 .50703 .64635 .50602 .66174 Mtetra
.54 .304 .507 r
.50602 .66174 .50703 .64635 .50872 .64514 .50771 .66116 Mtetra
.495 .268 .499 r
.50771 .66116 .50872 .64514 .51114 .46535 .50941 .65868 Mtetra
0 0 .364 r
.50941 .65868 .51114 .46535 .51276 .45845 .51185 .4667 Mtetra
0 0 .11 r
.51185 .4667 .51276 .45845 .51436 .45515 .51349 .45537 Mtetra
.962 .92 .718 r
.51349 .45537 .51436 .45515 .51596 .45329 .51509 .45241 Mtetra
.729 .772 .887 r
.51509 .45241 .51596 .45329 .51755 .45259 .51668 .45158 Mtetra
.624 .714 .911 r
.51668 .45158 .51755 .45259 .51914 .45219 .51827 .45123 Mtetra
.586 .711 .93 r
.51827 .45123 .51914 .45219 .52073 .45186 .51987 .451 Mtetra
.661 .762 .925 r
.51987 .451 .52073 .45186 .52233 .45135 .52146 .4505 Mtetra
.659 .763 .926 r
.52146 .4505 .52233 .45135 .52392 .45084 .52306 .45 Mtetra
.659 .766 .928 r
.52306 .45 .52392 .45084 .52552 .45033 .52465 .4495 Mtetra
.662 .769 .929 r
.52465 .4495 .52552 .45033 .52712 .44981 .52625 .44899 Mtetra
.662 .77 .93 r
.52625 .44899 .52712 .44981 .52871 .44929 .52785 .44847 Mtetra
.662 .772 .931 r
.52785 .44847 .52871 .44929 .53031 .44877 .52945 .44796 Mtetra
.52945 .44796 .53031 .44877 .53191 .44825 .53105 .44744 Mtetra
.662 .773 .932 r
.53105 .44744 .53191 .44825 .53351 .44774 .53265 .44693 Mtetra
.53265 .44693 .53351 .44774 .53511 .44722 .53425 .44641 Mtetra
.53425 .44641 .53511 .44722 .53672 .44671 .53586 .44589 Mtetra
.662 .774 .932 r
.53586 .44589 .53672 .44671 .53832 .44619 .53746 .44538 Mtetra
.662 .773 .932 r
.53746 .44538 .53832 .44619 .53992 .44568 .53907 .44486 Mtetra
.661 .773 .932 r
.53907 .44486 .53992 .44568 .54153 .44516 .54067 .44435 Mtetra
.54067 .44435 .54153 .44516 .54314 .44465 .54228 .44383 Mtetra
.54228 .44383 .54314 .44465 .54474 .44414 .54389 .44332 Mtetra
.661 .772 .931 r
.54389 .44332 .54474 .44414 .54635 .44363 .5455 .4428 Mtetra
.662 .771 .931 r
.5455 .4428 .54635 .44363 .54796 .44312 .54711 .44229 Mtetra
.663 .771 .929 r
.54711 .44229 .54796 .44312 .54957 .4426 .54872 .44176 Mtetra
.666 .77 .927 r
.54872 .44176 .54957 .4426 .55118 .44208 .55033 .44123 Mtetra
.666 .766 .925 r
.55033 .44123 .55118 .44208 .55279 .44156 .55194 .4407 Mtetra
.677 .767 .919 r
.55194 .4407 .55279 .44156 .55441 .44101 .55355 .44013 Mtetra
.733 .776 .887 r
.55355 .44013 .55441 .44101 .55602 .44028 .55516 .43928 Mtetra
.668 .733 .899 r
.55516 .43928 .55602 .44028 .55763 .43974 .55678 .43874 Mtetra
.429 .632 .94 r
.55678 .43874 .55763 .43974 .55925 .43965 .5584 .43894 Mtetra
.868 .426 .045 r
.5584 .43894 .55925 .43965 .56089 .44106 .56006 .44232 Mtetra
.961 .682 .46 r
.56006 .44232 .56089 .44106 .56255 .44411 .56388 .63713 Mtetra
.569 .351 .545 r
.56388 .63713 .56255 .44411 .56432 .45563 .56569 .64409 Mtetra
.558 .342 .544 r
.56569 .64409 .56432 .45563 .56813 .62958 .56742 .64433 Mtetra
.537 .3 .504 r
.56742 .64433 .56813 .62958 .5698 .62547 .56915 .64366 Mtetra
.533 .302 .511 r
.56915 .64366 .5698 .62547 .56918 .45199 .57087 .64257 Mtetra
.557 .341 .544 r
.57087 .64257 .56918 .45199 .5708 .45107 .57259 .64206 Mtetra
.57259 .64206 .5708 .45107 .57243 .45016 .57432 .64155 Mtetra
.57432 .64155 .57243 .45016 .57405 .44932 .57605 .64103 Mtetra
.557 .342 .544 r
.57605 .64103 .57405 .44932 .57568 .44861 .57778 .64054 Mtetra
.57778 .64054 .57568 .44861 .57731 .448 .57951 .64005 Mtetra
.57951 .64005 .57731 .448 .57894 .44729 .58124 .63955 Mtetra
.556 .341 .544 r
.58124 .63955 .57894 .44729 .58053 .44366 .58297 .63889 Mtetra
.557 .342 .544 r
.58297 .63889 .58053 .44366 .58216 .44283 .58471 .63836 Mtetra
.58471 .63836 .58216 .44283 .5839 .44837 .58645 .63813 Mtetra
.558 .343 .544 r
.58645 .63813 .5839 .44837 .58901 .63514 .5882 .63869 Mtetra
.571 .255 .394 r
.5882 .63869 .58901 .63514 .59083 .6389 .58996 .6392 Mtetra
.368 0 0 r
.58996 .6392 .59083 .6389 .59261 .64065 .59172 .6395 Mtetra
.586 .689 .912 r
.59172 .6395 .59261 .64065 .59436 .64069 .59346 .63927 Mtetra
.629 .66 .861 r
.59346 .63927 .59436 .64069 .59611 .64032 .59521 .63888 Mtetra
.65 .665 .852 r
.59521 .63888 .59611 .64032 .59785 .6397 .59695 .63837 Mtetra
.583 .654 .885 r
.59695 .63837 .59785 .6397 .5996 .63931 .5987 .63818 Mtetra
.652 .719 .898 r
.5987 .63818 .5996 .63931 .60134 .63869 .60045 .63767 Mtetra
.758 .771 .864 r
.60045 .63767 .60134 .63869 .60307 .6377 .60218 .63657 Mtetra
.91 .756 .678 r
.60218 .63657 .60307 .6377 .60478 .63526 .60385 .63241 Mtetra
.965 .688 .458 r
.60385 .63241 .60478 .63526 .60644 .6314 .60112 .44051 Mtetra
.581 .365 .552 r
.60112 .44051 .60644 .6314 .60801 .62334 .60247 .42743 Mtetra
.561 .349 .55 r
.60247 .42743 .60801 .62334 .60972 .62133 .6041 .42609 Mtetra
.559 .347 .55 r
.6041 .42609 .60972 .62133 .61149 .62209 .60574 .42569 Mtetra
.60574 .42569 .61149 .62209 .61321 .62044 .6074 .42557 Mtetra
.561 .349 .55 r
.6074 .42557 .61321 .62044 .60998 .42979 .60903 .42415 Mtetra
.641 .472 .639 r
.60903 .42415 .60998 .42979 .61151 .42493 .61065 .42273 Mtetra
.708 .606 .74 r
.61065 .42273 .61151 .42493 .6131 .42228 .61228 .42151 Mtetra
.697 .799 .928 r
.61228 .42151 .6131 .42228 .61474 .42133 .61392 .42083 Mtetra
.616 .852 .988 r
.61392 .42083 .61474 .42133 .61639 .42084 .61558 .42035 Mtetra
.574 .837 .995 r
.61558 .42035 .61639 .42084 .61805 .4206 .61723 .41996 Mtetra
.612 .81 .976 r
.61723 .41996 .61805 .4206 .61971 .42027 .61889 .41955 Mtetra
.62 .79 .963 r
.61889 .41955 .61971 .42027 .62137 .41995 .62054 .41914 Mtetra
.63 .771 .948 r
.62054 .41914 .62137 .41995 .62302 .41962 .6222 .41872 Mtetra
.652 .756 .926 r
.6222 .41872 .62302 .41962 .62468 .41916 .62386 .41823 Mtetra
.66 .751 .918 r
.62386 .41823 .62468 .41916 .62634 .41865 .62551 .41771 Mtetra
.664 .751 .915 r
.62551 .41771 .62634 .41865 .62799 .41811 .62717 .41717 Mtetra
.661 .752 .917 r
.62717 .41717 .62799 .41811 .62965 .41759 .62883 .41665 Mtetra
.664 .752 .915 r
.62883 .41665 .62965 .41759 .63131 .41705 .63049 .41611 Mtetra
.67 .755 .914 r
.63049 .41611 .63131 .41705 .63297 .41646 .63215 .41555 Mtetra
.685 .765 .912 r
.63215 .41555 .63297 .41646 .63462 .41575 .6338 .41492 Mtetra
.691 .786 .924 r
.6338 .41492 .63462 .41575 .63627 .415 .63546 .41427 Mtetra
.689 .809 .939 r
.63546 .41427 .63627 .415 .63793 .41428 .63712 .41361 Mtetra
.7 .831 .945 r
.63712 .41361 .63793 .41428 .63958 .41344 .63878 .41292 Mtetra
.669 .862 .973 r
.63878 .41292 .63958 .41344 .64124 .41277 .64044 .41229 Mtetra
.604 .853 .991 r
.64044 .41229 .64124 .41277 .64291 .41247 .64211 .41182 Mtetra
.566 .792 .984 r
.64211 .41182 .64291 .41247 .64463 .41336 .64378 .41153 Mtetra
.538 .551 .816 r
.64378 .41153 .64463 .41336 .64642 .4159 .64548 .41163 Mtetra
.487 .392 .674 r
.64548 .41163 .64642 .4159 .64887 .43609 .6472 .41255 Mtetra
.451 .282 .56 r
.6472 .41255 .64887 .43609 .65754 .61666 .64915 .41928 Mtetra
.022 0 .425 r
.64915 .41928 .65754 .61666 .65946 .61966 .65848 .61575 Mtetra
.047 .114 .611 r
.65848 .61575 .65946 .61966 .66131 .62096 .66043 .61952 Mtetra
.372 .528 .882 r
.66043 .61952 .66131 .62096 .66313 .62122 .66226 .62009 Mtetra
.634 .717 .907 r
.66226 .62009 .66313 .62122 .66492 .62084 .66404 .61965 Mtetra
.726 .738 .861 r
.66404 .61965 .66492 .62084 .66669 .61989 .66581 .61871 Mtetra
.718 .735 .865 r
.66581 .61871 .66669 .61989 .66841 .61788 .66759 .61782 Mtetra
.742 .982 .91 r
.66759 .61782 .66841 .61788 .67007 .61428 .66935 .61662 Mtetra
.108 0 .143 r
.66935 .61662 .67007 .61428 .67145 .60426 .67107 .6146 Mtetra
.251 .066 .424 r
.67107 .6146 .67145 .60426 .6649 .41122 .67259 .60776 Mtetra
.02 0 .419 r
.67259 .60776 .6649 .41122 .66642 .40709 .66574 .40913 Mtetra
.723 .755 .249 r
.66574 .40913 .66642 .40709 .66802 .40482 .66724 .40429 Mtetra
.855 .882 .858 r
.66724 .40429 .66802 .40482 .66968 .40372 .66887 .40272 Mtetra
.671 .743 .905 r
.66887 .40272 .66968 .40372 .67136 .40317 .67055 .40214 Mtetra
.576 .701 .927 r
.67055 .40214 .67136 .40317 .67305 .40286 .67225 .40194 Mtetra
.607 .738 .938 r
.67225 .40194 .67305 .40286 .67475 .40252 .67394 .40161 Mtetra
.631 .75 .933 r
.67394 .40161 .67475 .40252 .67644 .40214 .67564 .40119 Mtetra
.638 .741 .923 r
.67564 .40119 .67644 .40214 .67813 .40174 .67733 .40075 Mtetra
.684 .751 .902 r
.67733 .40075 .67813 .40174 .67981 .40094 .67901 .40011 Mtetra
.696 .793 .925 r
.67901 .40011 .67981 .40094 .68148 .4001 .68069 .39943 Mtetra
.66 .823 .962 r
.68069 .39943 .68148 .4001 .68317 .39957 .68238 .39886 Mtetra
.485 .741 .984 r
.68238 .39886 .68317 .39957 .68493 .40037 .68409 .39877 Mtetra
.485 .553 .85 r
.68409 .39877 .68493 .40037 .68678 .40298 .68583 .39906 Mtetra
.531 .431 .686 r
.68583 .39906 .68678 .40298 .68899 .41267 .68757 .39948 Mtetra
.575 .387 .589 r
.68757 .39948 .68899 .41267 .70014 .59648 .68927 .39897 Mtetra
.56 .348 .55 r
.68927 .39897 .70014 .59648 .70188 .59487 .69095 .39812 Mtetra
.559 .347 .55 r
.69095 .39812 .70188 .59487 .70365 .59366 .69266 .39786 Mtetra
.552 .342 .549 r
.69266 .39786 .70365 .59366 .70586 .60085 .69458 .40157 Mtetra
.047 0 .44 r
.69458 .40157 .70586 .60085 .70791 .60482 .70687 .60011 Mtetra
0 .054 .567 r
.70687 .60011 .70791 .60482 .70985 .60677 .70898 .60518 Mtetra
.258 .435 .846 r
.70898 .60518 .70985 .60677 .71172 .60725 .71088 .6062 Mtetra
.597 .719 .93 r
.71088 .6062 .71172 .60725 .71355 .60699 .7127 .60589 Mtetra
.692 .746 .893 r
.7127 .60589 .71355 .60699 .71537 .60645 .71451 .60516 Mtetra
.671 .705 .872 r
.71451 .60516 .71537 .60645 .71719 .60598 .71632 .60453 Mtetra
.656 .672 .854 r
.71632 .60453 .71719 .60598 .71901 .60546 .71814 .60396 Mtetra
.678 .676 .841 r
.71814 .60396 .71901 .60546 .72081 .60459 .71995 .60325 Mtetra
.74 .722 .835 r
.71995 .60325 .72081 .60459 .72255 .60256 .72174 .60214 Mtetra
.833 .923 .894 r
.72174 .60214 .72255 .60256 .72417 .59873 .72351 .60067 Mtetra
.144 0 .11 r
.72351 .60067 .72417 .59873 .72551 .58993 .72527 .59907 Mtetra
.507 .26 .475 r
.72527 .59907 .72551 .58993 .71613 .40072 .72706 .59795 Mtetra
.557 .342 .544 r
.72706 .59795 .71613 .40072 .7178 .39937 .72888 .59739 Mtetra
.72888 .59739 .7178 .39937 .71964 .40088 .73072 .59703 Mtetra
.558 .342 .544 r
.73072 .59703 .71964 .40088 .7218 .4076 .73258 .59701 Mtetra
.557 .342 .544 r
.73258 .59701 .7218 .4076 .73418 .58023 .73443 .59689 Mtetra
.536 .303 .509 r
.73443 .59689 .73418 .58023 .72693 .43358 .73624 .59602 Mtetra
.549 .336 .542 r
.73624 .59602 .72693 .43358 .72621 .39374 .73784 .59174 Mtetra
.054 0 .439 r
.73784 .59174 .72621 .39374 .72763 .3885 .72712 .39175 Mtetra
0 0 0 r
.72712 .39175 .72763 .3885 .7292 .38557 .72846 .38524 Mtetra
.918 .918 .8 r
.72846 .38524 .7292 .38557 .73086 .38409 .73008 .38308 Mtetra
.697 .756 .898 r
.73008 .38308 .73086 .38409 .73257 .38344 .73178 .38237 Mtetra
.605 .707 .916 r
.73178 .38237 .73257 .38344 .7343 .38305 .73352 .38206 Mtetra
.614 .73 .929 r
.73352 .38206 .7343 .38305 .73603 .38262 .73525 .38171 Mtetra
.658 .765 .928 r
.73525 .38171 .73603 .38262 .73775 .38208 .73698 .38117 Mtetra
.657 .765 .929 r
.73698 .38117 .73775 .38208 .73947 .38154 .7387 .38064 Mtetra
.658 .767 .93 r
.7387 .38064 .73947 .38154 .7412 .381 .74043 .3801 Mtetra
.66 .769 .93 r
.74043 .3801 .7412 .381 .74292 .38045 .74215 .37955 Mtetra
.661 .77 .93 r
.74215 .37955 .74292 .38045 .74465 .37989 .74388 .379 Mtetra
.662 .77 .93 r
.74388 .379 .74465 .37989 .74638 .37934 .74561 .37844 Mtetra
.662 .771 .93 r
.74561 .37844 .74638 .37934 .7481 .37879 .74734 .37789 Mtetra
.663 .771 .93 r
.74734 .37789 .7481 .37879 .74983 .37823 .74907 .37733 Mtetra
.664 .771 .929 r
.74907 .37733 .74983 .37823 .75156 .37766 .7508 .37676 Mtetra
.665 .771 .929 r
.7508 .37676 .75156 .37766 .75329 .3771 .75253 .3762 Mtetra
.666 .771 .928 r
.75253 .3762 .75329 .3771 .75502 .37653 .75426 .37562 Mtetra
.669 .772 .927 r
.75426 .37562 .75502 .37653 .75675 .37595 .75599 .37504 Mtetra
.671 .771 .925 r
.75599 .37504 .75675 .37595 .75849 .37536 .75772 .37444 Mtetra
.671 .77 .924 r
.75772 .37444 .75849 .37536 .76022 .37477 .75946 .37385 Mtetra
.708 .781 .909 r
.75946 .37385 .76022 .37477 .76194 .37408 .76118 .37309 Mtetra
.721 .771 .892 r
.76118 .37309 .76194 .37408 .76367 .37333 .7629 .37225 Mtetra
.643 .723 .907 r
.7629 .37225 .76367 .37333 .76541 .37281 .76464 .37178 Mtetra
.195 .492 .902 r
.76464 .37178 .76541 .37281 .7672 .37292 .76648 .37254 Mtetra
.858 .407 .029 r
.76648 .37254 .7672 .37292 .76907 .37412 .76857 .37656 Mtetra
.973 .671 .377 r
.76857 .37656 .76907 .37412 .77109 .37707 .78565 .5758 Mtetra
.565 .348 .544 r
.78565 .5758 .77109 .37707 .78781 .5698 .78795 .58096 Mtetra
.573 .32 .494 r
.78795 .58096 .78781 .5698 .79048 .57968 .78992 .58184 Mtetra
.503 .133 .271 r
.78992 .58184 .79048 .57968 .79259 .58223 .79183 .58187 Mtetra
.5 .861 .988 r
.79183 .58187 .79259 .58223 .79455 .58286 .79371 .58145 Mtetra
.677 .693 .858 r
.79371 .58145 .79455 .58286 .79641 .58223 .79557 .58075 Mtetra
.699 .692 .839 r
.79557 .58075 .79641 .58223 .79824 .58119 .79741 .57988 Mtetra
.696 .717 .865 r
.79741 .57988 .79824 .58119 .80007 .58018 .79926 .57908 Mtetra
.656 .741 .912 r
.79926 .57908 .80007 .58018 .80193 .57954 .80113 .57852 Mtetra
.64 .751 .929 r
.80113 .57852 .80193 .57954 .8038 .57897 .80301 .57801 Mtetra
.57 .736 .954 r
.80301 .57801 .8038 .57897 .80569 .5786 .8049 .57776 Mtetra
.477 .721 .977 r
.8049 .57776 .80569 .5786 .8076 .57841 .80682 .57772 Mtetra
.619 .825 .979 r
.80682 .57772 .8076 .57841 .80948 .57795 .8087 .57721 Mtetra
.873 .862 .826 r
.8087 .57721 .80948 .57795 .8113 .57676 .81046 .57524 Mtetra
.948 .74 .589 r
.81046 .57524 .8113 .57676 .813 .5741 .8118 .56833 Mtetra
.974 .676 .384 r
.8118 .56833 .813 .5741 .81447 .5688 .79665 .36793 Mtetra
.566 .352 .55 r
.79665 .36793 .81447 .5688 .79949 .37205 .79807 .36327 Mtetra
.62 .434 .608 r
.79807 .36327 .79949 .37205 .80071 .36526 .79973 .3616 Mtetra
.648 .514 .686 r
.79973 .3616 .80071 .36526 .80226 .36224 .80145 .36058 Mtetra
.668 .643 .816 r
.80145 .36058 .80226 .36224 .80393 .36062 .80321 .3599 Mtetra
.624 .807 .97 r
.80321 .3599 .80393 .36062 .8057 .3601 .80498 .35943 Mtetra
.571 .802 .986 r
.80498 .35943 .8057 .3601 .80749 .3599 .80676 .35909 Mtetra
.598 .772 .963 r
.80676 .35909 .80749 .3599 .80929 .35974 .80855 .35873 Mtetra
.654 .746 .917 r
.80855 .35873 .80929 .35974 .81107 .35926 .81032 .3582 Mtetra
.668 .741 .905 r
.81032 .3582 .81107 .35926 .81284 .3587 .81208 .35761 Mtetra
.683 .74 .895 r
.81208 .35761 .81284 .3587 .8146 .35803 .81385 .35695 Mtetra
.699 .748 .89 r
.81385 .35695 .8146 .35803 .81634 .35724 .8156 .3562 Mtetra
.702 .76 .897 r
.8156 .3562 .81634 .35724 .81809 .35642 .81735 .35545 Mtetra
.723 .779 .898 r
.81735 .35545 .81809 .35642 .81983 .35553 .8191 .35459 Mtetra
.756 .798 .887 r
.8191 .35459 .81983 .35553 .82156 .35449 .82083 .35356 Mtetra
.67 .77 .925 r
.82083 .35356 .82156 .35449 .82333 .3539 .8226 .35296 Mtetra
.268 .56 .932 r
.8226 .35296 .82333 .3539 .82521 .35446 .82448 .35351 Mtetra
.83 .411 0 r
.82448 .35351 .82521 .35446 .82754 .3597 .82681 .35872 Mtetra
.975 .667 .335 r
.82681 .35872 .82754 .3597 .84879 .56254 .848 .56141 Mtetra
.701 .268 0 r
.848 .56141 .84879 .56254 .85114 .56665 .85034 .56549 Mtetra
.49 .653 .932 r
.85034 .56549 .85114 .56665 .85311 .56685 .85231 .56558 Mtetra
.686 .723 .878 r
.85231 .56558 .85311 .56685 .855 .56608 .8542 .56483 Mtetra
.746 .75 .856 r
.8542 .56483 .855 .56608 .8568 .56444 .85605 .56371 Mtetra
.715 .852 .947 r
.85605 .56371 .8568 .56444 .85848 .56156 .85793 .56284 Mtetra
.03 0 0 r
.85793 .56284 .85848 .56156 .85986 .5557 .85975 .56139 Mtetra
.338 .104 .405 r
.85975 .56139 .85986 .5557 .84209 .35787 .86141 .55828 Mtetra
.124 .035 .474 r
.86141 .55828 .84209 .35787 .84334 .35189 .84355 .3603 Mtetra
0 0 .343 r
.84355 .3603 .84334 .35189 .8449 .34904 .84431 .34938 Mtetra
.931 .94 .591 r
.84431 .34938 .8449 .34904 .84656 .34724 .84582 .34613 Mtetra
.783 .775 .846 r
.84582 .34613 .84656 .34724 .84829 .34607 .84754 .34484 Mtetra
.636 .696 .889 r
.84754 .34484 .84829 .34607 .85009 .34557 .84934 .34439 Mtetra
.272 .505 .897 r
.84934 .34439 .85009 .34557 .85201 .34622 .85127 .34514 Mtetra
.824 .417 0 r
.85127 .34514 .85201 .34622 .85449 .35233 .85373 .35095 Mtetra
.973 .663 .317 r
.85373 .35095 .85449 .35233 .87753 .55525 .87674 .55392 Mtetra
0 0 .377 r
.87674 .55392 .87753 .55525 .87991 .55902 .87913 .55783 Mtetra
.554 .68 .923 r
.87913 .55783 .87991 .55902 .88187 .55881 .88109 .55769 Mtetra
.713 .764 .892 r
.88109 .55769 .88187 .55881 .88375 .55786 .88299 .55681 Mtetra
.763 .796 .879 r
.88299 .55681 .88375 .55786 .88561 .55663 .88485 .55564 Mtetra
.632 .76 .94 r
.88485 .55564 .88561 .55663 .88756 .5563 .88678 .55515 Mtetra
.65 .734 .911 r
.88678 .55515 .88756 .5563 .88949 .55576 .88871 .55459 Mtetra
.677 .742 .9 r
.88871 .55459 .88949 .55576 .89137 .55471 .89063 .5539 Mtetra
.703 .834 .945 r
.89063 .5539 .89137 .55471 .89306 .55201 .89253 .55309 Mtetra
0 0 0 r
.89253 .55309 .89306 .55201 .89448 .54678 .89438 .55174 Mtetra
.345 .099 .391 r
.89438 .55174 .89448 .54678 .87465 .34886 .89608 .54908 Mtetra
.152 .057 .485 r
.89608 .54908 .87465 .34886 .87572 .34165 .87676 .35646 Mtetra
.044 0 .414 r
.87676 .35646 .87572 .34165 .87725 .33856 .87673 .33929 Mtetra
.824 .874 .436 r
.87673 .33929 .87725 .33856 .87892 .33672 .87822 .3358 Mtetra
.725 .798 .91 r
.87822 .3358 .87892 .33672 .88072 .3361 .87999 .33493 Mtetra
.605 .695 .907 r
.87999 .33493 .88072 .3361 .88257 .33583 .88183 .33461 Mtetra
.54 .653 .908 r
.88183 .33461 .88257 .33583 .88443 .33572 .88371 .33456 Mtetra
.643 .716 .901 r
.88371 .33456 .88443 .33572 .88626 .33523 .88553 .33408 Mtetra
.653 .721 .899 r
.88553 .33408 .88626 .33523 .88807 .33466 .88735 .33354 Mtetra
.667 .735 .901 r
.88735 .33354 .88807 .33466 .88988 .33399 .88916 .33294 Mtetra
.713 .767 .895 r
.88916 .33294 .88988 .33399 .89163 .33291 .89095 .33211 Mtetra
.702 .823 .94 r
.89095 .33211 .89163 .33291 .89342 .33205 .89275 .33135 Mtetra
.653 .832 .969 r
.89275 .33135 .89342 .33205 .89525 .33161 .89457 .33075 Mtetra
.594 .763 .96 r
.89457 .33075 .89525 .33161 .89727 .33271 .89641 .3304 Mtetra
.546 .519 .777 r
.89641 .3304 .89727 .33271 .89951 .33567 .89832 .33053 Mtetra
.498 .388 .659 r
.89832 .33053 .89951 .33567 .92464 .53056 .90034 .3316 Mtetra
0 0 .533 r
.31031 .51739 .31109 .52076 .31184 .53174 .31156 .52046 Mtetra
.953 .699 .515 r
.31156 .52046 .31184 .53174 .30154 .71809 .30098 .71027 Mtetra
0 0 .348 r
.30098 .71027 .30154 .71809 .30288 .72118 .30201 .71828 Mtetra
.417 .396 .728 r
.30201 .71828 .30288 .72118 .30441 .72129 .30349 .71919 Mtetra
.557 .535 .786 r
.30349 .71919 .30441 .72129 .30599 .72071 .30503 .71922 Mtetra
.634 .637 .836 r
.30503 .71922 .30599 .72071 .30759 .71966 .30659 .71883 Mtetra
.417 .677 .97 r
.30659 .71883 .30759 .71966 .30918 .71895 .30812 .71894 Mtetra
.293 .788 .869 r
.30812 .71894 .30918 .71895 .31079 .71781 .30968 .71866 Mtetra
0 0 0 r
.30968 .71866 .31079 .71781 .31245 .71578 .31129 .71769 Mtetra
.899 .919 .527 r
.31129 .71769 .31245 .71578 .3146 .70564 .31308 .71361 Mtetra
.949 .699 .524 r
.31308 .71361 .3146 .70564 .32733 .51646 .32593 .52347 Mtetra
0 0 0 r
.32593 .52347 .32733 .51646 .32902 .51262 .32796 .51371 Mtetra
.631 .885 .55 r
.32796 .51371 .32902 .51262 .33053 .51165 .32953 .51188 Mtetra
.637 .965 .877 r
.32953 .51188 .33053 .51165 .33201 .51133 .33104 .51097 Mtetra
.637 .872 .986 r
.33104 .51097 .33201 .51133 .33347 .51132 .33253 .51047 Mtetra
.681 .752 .905 r
.33253 .51047 .33347 .51132 .33496 .51082 .33403 .50992 Mtetra
.664 .738 .905 r
.33403 .50992 .33496 .51082 .33645 .51029 .33552 .50944 Mtetra
.655 .747 .917 r
.33552 .50944 .33645 .51029 .33794 .50987 .33701 .50899 Mtetra
.758 .76 .854 r
.33701 .50899 .33794 .50987 .33942 .50955 .33853 .508 Mtetra
.687 .641 .798 r
.33853 .508 .33942 .50955 .34089 .50959 .34003 .50727 Mtetra
.582 .523 .754 r
.34003 .50727 .34089 .50959 .34231 .51038 .3415 .50717 Mtetra
0 0 .473 r
.3415 .50717 .34231 .51038 .34345 .51645 .34279 .51056 Mtetra
.948 .691 .513 r
.34279 .51056 .34345 .51645 .33463 .70727 .33377 .70413 Mtetra
.88 .57 .058 r
.33377 .70413 .33463 .70727 .33599 .71109 .33499 .71036 Mtetra
.024 .48 .878 r
.33499 .71036 .33599 .71109 .33752 .71157 .33652 .71092 Mtetra
.658 .81 .956 r
.33652 .71092 .33752 .71157 .33911 .71116 .33811 .71041 Mtetra
.752 .798 .89 r
.33811 .71041 .33911 .71116 .34072 .71027 .33972 .70946 Mtetra
.484 .714 .972 r
.33972 .70946 .34072 .71027 .34232 .70956 .34129 .70944 Mtetra
.266 .761 .901 r
.34129 .70944 .34232 .70956 .34394 .70854 .34287 .70927 Mtetra
0 0 0 r
.34287 .70927 .34394 .70854 .34559 .70673 .34448 .70845 Mtetra
.935 .925 .556 r
.34448 .70845 .34559 .70673 .3475 .69994 .34626 .70419 Mtetra
.948 .695 .52 r
.34626 .70419 .3475 .69994 .35866 .5078 .35757 .51013 Mtetra
.996 .858 .525 r
.35757 .51013 .35866 .5078 .36037 .50321 .35943 .50247 Mtetra
.83 .788 .812 r
.35943 .50247 .36037 .50321 .36191 .50187 .36099 .50086 Mtetra
.662 .718 .89 r
.36099 .50086 .36191 .50187 .36342 .50138 .3625 .50038 Mtetra
.54 .676 .926 r
.3625 .50038 .36342 .50138 .36491 .50122 .36398 .50032 Mtetra
.714 .752 .882 r
.36398 .50032 .36491 .50122 .36643 .50033 .3655 .4996 Mtetra
.709 .789 .914 r
.3655 .4996 .36643 .50033 .36795 .49954 .36702 .49893 Mtetra
.515 .766 .988 r
.36702 .49893 .36795 .49954 .36945 .49937 .36851 .49877 Mtetra
.842 .375 .041 r
.36851 .49877 .36945 .49937 .37079 .50237 .36989 .50107 Mtetra
.945 .684 .511 r
.36989 .50107 .37079 .50237 .36339 .69622 .36279 .68713 Mtetra
0 0 .123 r
.36279 .68713 .36339 .69622 .36465 .70302 .36377 .70003 Mtetra
.288 .308 .708 r
.36377 .70003 .36465 .70302 .3662 .70391 .36528 .70157 Mtetra
.544 .511 .769 r
.36528 .70157 .3662 .70391 .3678 .70343 .36686 .70169 Mtetra
.621 .605 .813 r
.36686 .70169 .3678 .70343 .36943 .70237 .36846 .70136 Mtetra
.484 .664 .941 r
.36846 .70136 .36943 .70237 .37105 .70154 .37004 .70142 Mtetra
.233 .741 .885 r
.37004 .70142 .37105 .70154 .37268 .70055 .37163 .70128 Mtetra
0 0 0 r
.37163 .70128 .37268 .70055 .37434 .69886 .37326 .70048 Mtetra
.878 .924 .534 r
.37326 .70048 .37434 .69886 .37616 .69331 .375 .69683 Mtetra
.95 .694 .514 r
.375 .69683 .37616 .69331 .38583 .50018 .38468 .50491 Mtetra
.934 .818 .363 r
.38468 .50491 .38583 .50018 .38755 .49492 .38662 .49429 Mtetra
.861 .806 .794 r
.38662 .49429 .38755 .49492 .38911 .49338 .3882 .49237 Mtetra
.656 .716 .893 r
.3882 .49237 .38911 .49338 .39063 .49294 .38972 .49191 Mtetra
.506 .655 .926 r
.38972 .49191 .39063 .49294 .39213 .49291 .39122 .49194 Mtetra
.585 .702 .924 r
.39122 .49194 .39213 .49291 .39365 .49267 .39273 .49173 Mtetra
.64 .727 .911 r
.39273 .49173 .39365 .49267 .39516 .49228 .39425 .49134 Mtetra
.648 .729 .908 r
.39425 .49134 .39516 .49228 .39669 .49185 .39577 .49091 Mtetra
.68 .738 .895 r
.39577 .49091 .39669 .49185 .39821 .49135 .3973 .49035 Mtetra
.687 .726 .88 r
.3973 .49035 .39821 .49135 .39974 .4908 .39883 .48974 Mtetra
.672 .713 .879 r
.39883 .48974 .39974 .4908 .40127 .49019 .40036 .4892 Mtetra
.592 .701 .919 r
.40036 .4892 .40127 .49019 .4028 .48952 .40188 .48898 Mtetra
.399 .741 .992 r
.40188 .48898 .4028 .48952 .40434 .48882 .40339 .48897 Mtetra
.136 0 0 r
.40339 .48897 .40434 .48882 .40588 .48813 .4049 .48899 Mtetra
.26 0 0 r
.4049 .48899 .40588 .48813 .40741 .48749 .40643 .48867 Mtetra
.221 0 0 r
.40643 .48867 .40741 .48749 .40894 .48691 .40796 .48807 Mtetra
.178 0 0 r
.40796 .48807 .40894 .48691 .41048 .48636 .4095 .4874 Mtetra
.211 0 0 r
.4095 .4874 .41048 .48636 .41201 .48582 .41104 .48687 Mtetra
.244 0 0 r
.41104 .48687 .41201 .48582 .41354 .4853 .41257 .4864 Mtetra
.204 0 0 r
.41257 .4864 .41354 .4853 .41508 .48482 .41411 .48582 Mtetra
0 0 0 r
.41411 .48582 .41508 .48482 .41661 .48439 .41566 .48486 Mtetra
.592 .934 .746 r
.41566 .48486 .41661 .48439 .41814 .48399 .41722 .48372 Mtetra
.789 .914 .924 r
.41722 .48372 .41814 .48399 .41968 .4836 .41877 .48266 Mtetra
.715 .748 .878 r
.41877 .48266 .41968 .4836 .42121 .48317 .42032 .48192 Mtetra
.662 .676 .853 r
.42032 .48192 .42121 .48317 .42275 .4827 .42186 .48141 Mtetra
.646 .665 .854 r
.42186 .48141 .42275 .4827 .42429 .48219 .42339 .48098 Mtetra
.653 .68 .863 r
.42339 .48098 .42429 .48219 .42583 .48163 .42493 .48052 Mtetra
.663 .701 .875 r
.42493 .48052 .42583 .48163 .42737 .48103 .42648 .48002 Mtetra
.664 .721 .891 r
.42648 .48002 .42737 .48103 .42892 .48043 .42802 .47952 Mtetra
.664 .741 .907 r
.42802 .47952 .42892 .48043 .43046 .47988 .42956 .47902 Mtetra
.663 .753 .917 r
.42956 .47902 .43046 .47988 .43201 .47937 .43111 .47852 Mtetra
.662 .757 .92 r
.43111 .47852 .43201 .47937 .43355 .47887 .43265 .47802 Mtetra
.662 .757 .921 r
.43265 .47802 .43355 .47887 .4351 .47838 .4342 .47753 Mtetra
.66 .757 .922 r
.4342 .47753 .4351 .47838 .43664 .47789 .43574 .47704 Mtetra
.657 .758 .924 r
.43574 .47704 .43664 .47789 .43819 .4774 .43729 .47657 Mtetra
.647 .759 .93 r
.43729 .47657 .43819 .4774 .43974 .47691 .43884 .47613 Mtetra
.638 .767 .942 r
.43884 .47613 .43974 .47691 .44129 .47642 .44038 .47571 Mtetra
.634 .786 .954 r
.44038 .47571 .44129 .47642 .44283 .47593 .44193 .47529 Mtetra
.641 .807 .963 r
.44193 .47529 .44283 .47593 .44439 .47537 .44348 .47484 Mtetra
.646 .836 .973 r
.44348 .47484 .44439 .47537 .44594 .4748 .44503 .47434 Mtetra
.646 .857 .98 r
.44503 .47434 .44594 .4748 .44749 .47433 .44659 .47382 Mtetra
.665 .846 .969 r
.44659 .47382 .44749 .47433 .44903 .47423 .44814 .47326 Mtetra
.682 .737 .893 r
.44814 .47326 .44903 .47423 .45057 .47454 .4497 .47268 Mtetra
.656 .601 .782 r
.4497 .47268 .45057 .47454 .45211 .475 .45126 .47209 Mtetra
.629 .522 .713 r
.45126 .47209 .45211 .475 .45365 .47513 .45281 .47153 Mtetra
.616 .49 .686 r
.45281 .47153 .45365 .47513 .45521 .47467 .45437 .47099 Mtetra
.615 .487 .684 r
.45437 .47099 .45521 .47467 .45677 .47401 .45593 .47046 Mtetra
.616 .492 .688 r
.45593 .47046 .45677 .47401 .45833 .47336 .45749 .46993 Mtetra
.618 .497 .692 r
.45749 .46993 .45833 .47336 .45989 .47281 .45905 .4694 Mtetra
.617 .497 .693 r
.45905 .4694 .45989 .47281 .46145 .47227 .46061 .46888 Mtetra
.632 .507 .692 r
.46061 .46888 .46145 .47227 .46302 .47147 .46218 .46819 Mtetra
.64 .515 .695 r
.46218 .46819 .46302 .47147 .46459 .47057 .46374 .46742 Mtetra
.606 .499 .705 r
.46374 .46742 .46459 .47057 .46615 .47028 .46531 .46706 Mtetra
.417 .375 .704 r
.46531 .46706 .46615 .47028 .46767 .47242 .46684 .46815 Mtetra
0 0 .289 r
.46684 .46815 .46767 .47242 .46596 .66577 .46829 .47428 Mtetra
0 0 .343 r
.46829 .47428 .46596 .66577 .4675 .67285 .46661 .66879 Mtetra
.143 .165 .624 r
.46661 .66879 .4675 .67285 .46913 .6745 .46822 .67176 Mtetra
.584 .512 .74 r
.46822 .67176 .46913 .6745 .47079 .67427 .46988 .67163 Mtetra
.658 .559 .732 r
.46988 .67163 .47079 .67427 .47246 .67357 .47155 .67082 Mtetra
.664 .557 .724 r
.47155 .67082 .47246 .67357 .47413 .67289 .47322 .66991 Mtetra
.63 .527 .719 r
.47322 .66991 .47413 .67289 .4758 .6725 .47489 .66932 Mtetra
.617 .512 .712 r
.47489 .66932 .4758 .6725 .47747 .67209 .47656 .66883 Mtetra
.584 .489 .712 r
.47656 .66883 .47747 .67209 .47914 .6716 .47823 .66869 Mtetra
.541 .477 .733 r
.47823 .66869 .47914 .6716 .48081 .67103 .47989 .6689 Mtetra
.534 .526 .792 r
.47989 .6689 .48081 .67103 .48249 .67044 .48155 .66906 Mtetra
.565 .632 .877 r
.48155 .66906 .48249 .67044 .48416 .66993 .48322 .66896 Mtetra
.636 .739 .923 r
.48322 .66896 .48416 .66993 .48583 .66952 .4849 .66854 Mtetra
.657 .741 .912 r
.4849 .66854 .48583 .66952 .48751 .66903 .48658 .66803 Mtetra
.652 .736 .912 r
.48658 .66803 .48751 .66903 .48919 .66822 .48825 .66754 Mtetra
.607 .8 .973 r
.48825 .66754 .48919 .66822 .49088 .66689 .48993 .66714 Mtetra
0 0 0 r
.48993 .66714 .49088 .66689 .49256 .66538 .49161 .66675 Mtetra
.343 0 .079 r
.49161 .66675 .49256 .66538 .49425 .66409 .49329 .66634 Mtetra
.429 .073 .257 r
.49329 .66634 .49425 .66409 .49593 .66351 .49497 .66589 Mtetra
.434 .085 .272 r
.49497 .66589 .49593 .66351 .49761 .66316 .49665 .66543 Mtetra
.422 .067 .255 r
.49665 .66543 .49761 .66316 .49929 .66285 .49834 .66493 Mtetra
.402 .037 .227 r
.49834 .66493 .49929 .66285 .50097 .6624 .50002 .66441 Mtetra
.392 .022 .212 r
.50002 .66441 .50097 .6624 .50266 .66196 .50171 .66387 Mtetra
.417 .04 .213 r
.50171 .66387 .50266 .66196 .50434 .6617 .50339 .66349 Mtetra
.457 .069 .215 r
.50339 .66349 .50434 .6617 .50602 .66174 .50508 .66334 Mtetra
.34 0 .124 r
.50508 .66334 .50602 .66174 .50771 .66116 .50677 .66279 Mtetra
0 0 0 r
.50677 .66279 .50771 .66116 .50941 .65868 .50847 .66102 Mtetra
.904 .853 .404 r
.50847 .66102 .50941 .65868 .51185 .4667 .51018 .65493 Mtetra
0 0 .342 r
.51018 .65493 .51185 .4667 .51349 .45537 .5126 .45805 Mtetra
0 0 0 r
.5126 .45805 .51349 .45537 .51509 .45241 .51421 .45322 Mtetra
.51421 .45322 .51509 .45241 .51668 .45158 .51581 .45226 Mtetra
.217 0 0 r
.51581 .45226 .51668 .45158 .51827 .45123 .5174 .45197 Mtetra
.34 0 0 r
.5174 .45197 .51827 .45123 .51987 .451 .519 .45189 Mtetra
.188 0 0 r
.519 .45189 .51987 .451 .52146 .4505 .52059 .45139 Mtetra
.197 0 0 r
.52059 .45139 .52146 .4505 .52306 .45 .52219 .45091 Mtetra
.201 0 0 r
.52219 .45091 .52306 .45 .52465 .4495 .52379 .45042 Mtetra
.198 0 0 r
.52379 .45042 .52465 .4495 .52625 .44899 .52539 .44991 Mtetra
.52539 .44991 .52625 .44899 .52785 .44847 .52699 .4494 Mtetra
.52699 .4494 .52785 .44847 .52945 .44796 .52859 .44889 Mtetra
.199 0 0 r
.52859 .44889 .52945 .44796 .53105 .44744 .53019 .44838 Mtetra
.53019 .44838 .53105 .44744 .53265 .44693 .53179 .44786 Mtetra
.53179 .44786 .53265 .44693 .53425 .44641 .5334 .44734 Mtetra
.2 0 0 r
.5334 .44734 .53425 .44641 .53586 .44589 .535 .44683 Mtetra
.535 .44683 .53586 .44589 .53746 .44538 .53661 .44631 Mtetra
.201 0 0 r
.53661 .44631 .53746 .44538 .53907 .44486 .53821 .4458 Mtetra
.53821 .4458 .53907 .44486 .54067 .44435 .53982 .44528 Mtetra
.2 0 0 r
.53982 .44528 .54067 .44435 .54228 .44383 .54143 .44477 Mtetra
.54143 .44477 .54228 .44383 .54389 .44332 .54304 .44425 Mtetra
.199 0 0 r
.54304 .44425 .54389 .44332 .5455 .4428 .54465 .44373 Mtetra
.196 0 0 r
.54465 .44373 .5455 .4428 .54711 .44229 .54626 .44321 Mtetra
.191 0 0 r
.54626 .44321 .54711 .44229 .54872 .44176 .54787 .44268 Mtetra
.179 0 0 r
.54787 .44268 .54872 .44176 .55033 .44123 .54949 .44213 Mtetra
.174 0 0 r
.54949 .44213 .55033 .44123 .55194 .4407 .5511 .44159 Mtetra
.133 0 0 r
.5511 .44159 .55194 .4407 .55355 .44013 .55271 .44098 Mtetra
0 0 0 r
.55271 .44098 .55355 .44013 .55516 .43928 .55433 .43997 Mtetra
.074 0 0 r
.55433 .43997 .55516 .43928 .55678 .43874 .55594 .43942 Mtetra
.554 .062 .041 r
.55594 .43942 .55678 .43874 .5584 .43894 .55757 .43998 Mtetra
.911 .582 .409 r
.55757 .43998 .5584 .43894 .56006 .44232 .55929 .44928 Mtetra
.953 .673 .47 r
.55929 .44928 .56006 .44232 .56388 .63713 .56305 .64273 Mtetra
.681 .388 .471 r
.56305 .64273 .56388 .63713 .56569 .64409 .56482 .64591 Mtetra
.488 .101 .233 r
.56482 .64591 .56569 .64409 .56742 .64433 .56655 .64591 Mtetra
.325 0 .115 r
.56655 .64591 .56742 .64433 .56915 .64366 .56828 .64531 Mtetra
.254 0 .091 r
.56828 .64531 .56915 .64366 .57087 .64257 .57 .64442 Mtetra
.387 .006 .189 r
.57 .64442 .57087 .64257 .57259 .64206 .57173 .64392 Mtetra
.388 .008 .191 r
.57173 .64392 .57259 .64206 .57432 .64155 .57346 .64342 Mtetra
.394 .015 .196 r
.57346 .64342 .57432 .64155 .57605 .64103 .57519 .64293 Mtetra
.411 .033 .208 r
.57519 .64293 .57605 .64103 .57778 .64054 .57692 .64251 Mtetra
.419 .046 .221 r
.57692 .64251 .57778 .64054 .57951 .64005 .57866 .6421 Mtetra
.422 .054 .232 r
.57866 .6421 .57951 .64005 .58124 .63955 .58039 .64168 Mtetra
.419 .055 .239 r
.58039 .64168 .58124 .63955 .58297 .63889 .58213 .64121 Mtetra
.428 .076 .264 r
.58213 .64121 .58297 .63889 .58471 .63836 .58387 .64072 Mtetra
.427 .077 .266 r
.58387 .64072 .58471 .63836 .58645 .63813 .5856 .6402 Mtetra
.412 .046 .23 r
.5856 .6402 .58645 .63813 .5882 .63869 .58734 .63972 Mtetra
.218 0 0 r
.58734 .63972 .5882 .63869 .58996 .6392 .58908 .63917 Mtetra
.515 .91 .921 r
.58908 .63917 .58996 .6392 .59172 .6395 .59082 .63851 Mtetra
.75 .774 .872 r
.59082 .63851 .59172 .6395 .59346 .63927 .59255 .63747 Mtetra
.72 .653 .782 r
.59255 .63747 .59346 .63927 .59521 .63888 .59428 .63633 Mtetra
.689 .584 .733 r
.59428 .63633 .59521 .63888 .59695 .63837 .59601 .63517 Mtetra
.576 .489 .719 r
.59601 .63517 .59695 .63837 .5987 .63818 .59776 .6351 Mtetra
.606 .512 .722 r
.59776 .6351 .5987 .63818 .60045 .63767 .59951 .63474 Mtetra
.677 .56 .715 r
.59951 .63474 .60045 .63767 .60218 .63657 .60125 .63358 Mtetra
.876 .661 .608 r
.60125 .63358 .60218 .63657 .60385 .63241 .60283 .62603 Mtetra
.961 .683 .464 r
.60283 .62603 .60385 .63241 .60112 .44051 .60002 .42837 Mtetra
.666 .457 .591 r
.60002 .42837 .60112 .44051 .60247 .42743 .60157 .42377 Mtetra
.658 .517 .681 r
.60157 .42377 .60247 .42743 .6041 .42609 .6032 .42262 Mtetra
.611 .493 .695 r
.6032 .42262 .6041 .42609 .60574 .42569 .60485 .42216 Mtetra
.58 .472 .695 r
.60485 .42216 .60574 .42569 .6074 .42557 .6065 .42203 Mtetra
.606 .488 .693 r
.6065 .42203 .6074 .42557 .60903 .42415 .60815 .42161 Mtetra
.619 .538 .741 r
.60815 .42161 .60903 .42415 .61065 .42273 .6098 .42119 Mtetra
.636 .635 .832 r
.6098 .42119 .61065 .42273 .61228 .42151 .61145 .42077 Mtetra
.638 .793 .957 r
.61145 .42077 .61228 .42151 .61392 .42083 .61311 .42031 Mtetra
.624 .847 .985 r
.61311 .42031 .61392 .42083 .61558 .42035 .61476 .41982 Mtetra
.634 .848 .982 r
.61476 .41982 .61558 .42035 .61723 .41996 .61641 .4193 Mtetra
.664 .82 .958 r
.61641 .4193 .61723 .41996 .61889 .41955 .61806 .41873 Mtetra
.674 .783 .931 r
.61806 .41873 .61889 .41955 .62054 .41914 .61971 .41815 Mtetra
.675 .744 .903 r
.61971 .41815 .62054 .41914 .6222 .41872 .62137 .41757 Mtetra
.664 .708 .88 r
.62137 .41757 .6222 .41872 .62386 .41823 .62302 .41702 Mtetra
.661 .696 .872 r
.62302 .41702 .62386 .41823 .62551 .41771 .62468 .41649 Mtetra
.659 .694 .871 r
.62468 .41649 .62551 .41771 .62717 .41717 .62634 .41597 Mtetra
.662 .697 .873 r
.62634 .41597 .62717 .41717 .62883 .41665 .628 .41543 Mtetra
.661 .695 .871 r
.628 .41543 .62883 .41665 .63049 .41611 .62965 .4149 Mtetra
.659 .696 .873 r
.62965 .4149 .63049 .41611 .63215 .41555 .63132 .41438 Mtetra
.652 .7 .882 r
.63132 .41438 .63215 .41555 .6338 .41492 .63298 .41389 Mtetra
.651 .728 .906 r
.63298 .41389 .6338 .41492 .63546 .41427 .63464 .41341 Mtetra
.651 .769 .935 r
.63464 .41341 .63546 .41427 .63712 .41361 .63631 .41292 Mtetra
.659 .813 .957 r
.63631 .41292 .63712 .41361 .63878 .41292 .63797 .41237 Mtetra
.655 .853 .976 r
.63797 .41237 .63878 .41292 .64044 .41229 .63964 .41179 Mtetra
.655 .866 .979 r
.63964 .41179 .64044 .41229 .64211 .41182 .6413 .4112 Mtetra
.76 .854 .92 r
.6413 .4112 .64211 .41182 .64378 .41153 .64295 .41023 Mtetra
.7 .698 .844 r
.64295 .41023 .64378 .41153 .64548 .41163 .64461 .40946 Mtetra
.598 .551 .773 r
.64461 .40946 .64548 .41163 .6472 .41255 .64629 .40923 Mtetra
.225 .249 .677 r
.64629 .40923 .6472 .41255 .64915 .41928 .64807 .41157 Mtetra
.978 .69 .403 r
.64807 .41157 .64915 .41928 .65848 .61575 .65715 .60285 Mtetra
0 0 .47 r
.65715 .60285 .65848 .61575 .66043 .61952 .65947 .61615 Mtetra
.366 .35 .709 r
.65947 .61615 .66043 .61952 .66226 .62009 .66133 .61772 Mtetra
.54 .516 .777 r
.66133 .61772 .66226 .62009 .66404 .61965 .66315 .61788 Mtetra
.616 .611 .823 r
.66315 .61788 .66404 .61965 .66581 .61871 .66494 .61754 Mtetra
.548 .672 .919 r
.66494 .61754 .66581 .61871 .66759 .61782 .66675 .61744 Mtetra
.487 .844 .993 r
.66675 .61744 .66759 .61782 .66935 .61662 .66854 .6171 Mtetra
0 0 0 r
.66854 .6171 .66935 .61662 .67107 .6146 .67032 .61613 Mtetra
.675 .793 .33 r
.67032 .61613 .67107 .6146 .67259 .60776 .67198 .61258 Mtetra
.954 .754 .299 r
.67198 .61258 .67259 .60776 .66574 .40913 .67296 .5933 Mtetra
.013 0 .416 r
.67296 .5933 .66574 .40913 .66724 .40429 .66653 .40558 Mtetra
0 0 0 r
.66653 .40558 .66724 .40429 .66887 .40272 .66814 .40348 Mtetra
.133 0 0 r
.66814 .40348 .66887 .40272 .67055 .40214 .66982 .40293 Mtetra
.33 0 0 r
.66982 .40293 .67055 .40214 .67225 .40194 .67153 .40279 Mtetra
.016 0 0 r
.67153 .40279 .67225 .40194 .67394 .40161 .6732 .40193 Mtetra
.555 .916 .733 r
.6732 .40193 .67394 .40161 .67564 .40119 .67486 .40077 Mtetra
.775 .915 .933 r
.67486 .40077 .67564 .40119 .67733 .40075 .67652 .39971 Mtetra
.695 .745 .89 r
.67652 .39971 .67733 .40075 .67901 .40011 .6782 .39901 Mtetra
.652 .717 .896 r
.6782 .39901 .67901 .40011 .68069 .39943 .67989 .39852 Mtetra
.635 .754 .934 r
.67989 .39852 .68069 .39943 .68238 .39886 .68159 .39809 Mtetra
.663 .797 .946 r
.68159 .39809 .68238 .39886 .68409 .39877 .68328 .39752 Mtetra
.678 .699 .863 r
.68328 .39752 .68409 .39877 .68583 .39906 .68497 .39689 Mtetra
.65 .582 .765 r
.68497 .39689 .68583 .39906 .68757 .39948 .68666 .39625 Mtetra
.647 .525 .701 r
.68666 .39625 .68757 .39948 .68927 .39897 .68833 .39538 Mtetra
.632 .504 .689 r
.68833 .39538 .68927 .39897 .69095 .39812 .69002 .39462 Mtetra
.593 .483 .697 r
.69002 .39462 .69095 .39812 .69266 .39786 .69173 .39434 Mtetra
.346 .323 .691 r
.69173 .39434 .69266 .39786 .69458 .40157 .69355 .39616 Mtetra
0 0 .195 r
.69355 .39616 .69458 .40157 .70687 .60011 .69588 .40757 Mtetra
.04 0 .437 r
.69588 .40757 .70687 .60011 .70898 .60518 .70799 .60153 Mtetra
.376 .347 .699 r
.70799 .60153 .70898 .60518 .71088 .6062 .70992 .60321 Mtetra
.61 .521 .729 r
.70992 .60321 .71088 .6062 .7127 .60589 .71175 .60281 Mtetra
.652 .541 .716 r
.71175 .60281 .7127 .60589 .71451 .60516 .71354 .60191 Mtetra
.596 .501 .718 r
.71354 .60191 .71451 .60516 .71632 .60453 .71537 .60163 Mtetra
.548 .489 .742 r
.71537 .60163 .71632 .60453 .71814 .60396 .71723 .6018 Mtetra
.548 .538 .796 r
.71723 .6018 .71814 .60396 .71995 .60325 .71909 .60188 Mtetra
.584 .655 .886 r
.71909 .60188 .71995 .60325 .72174 .60214 .72093 .60168 Mtetra
.547 .854 .998 r
.72093 .60168 .72174 .60214 .72351 .60067 .72276 .60126 Mtetra
.067 0 0 r
.72276 .60126 .72351 .60067 .72527 .59907 .72459 .60074 Mtetra
.364 0 .152 r
.72459 .60074 .72527 .59907 .72706 .59795 .72641 .60019 Mtetra
.415 .06 .252 r
.72641 .60019 .72706 .59795 .72888 .59739 .72824 .59962 Mtetra
.412 .057 .249 r
.72824 .59962 .72888 .59739 .73072 .59703 .73006 .59904 Mtetra
.446 .073 .235 r
.73006 .59904 .73072 .59703 .73258 .59701 .73191 .59875 Mtetra
.432 .039 .191 r
.73191 .59875 .73258 .59701 .73443 .59689 .73375 .59848 Mtetra
.301 0 .113 r
.73375 .59848 .73443 .59689 .73624 .59602 .73557 .59772 Mtetra
0 0 0 r
.73557 .59772 .73624 .59602 .73784 .59174 .73727 .59497 Mtetra
.82 .727 .198 r
.73727 .59497 .73784 .59174 .72712 .39175 .73854 .58545 Mtetra
.044 0 .435 r
.73854 .58545 .72712 .39175 .72846 .38524 .72784 .38689 Mtetra
0 0 0 r
.72784 .38689 .72846 .38524 .73008 .38308 .7294 .38377 Mtetra
.7294 .38377 .73008 .38308 .73178 .38237 .73111 .383 Mtetra
.258 0 0 r
.73111 .383 .73178 .38237 .73352 .38206 .73285 .3828 Mtetra
.271 0 0 r
.73285 .3828 .73352 .38206 .73525 .38171 .73459 .38255 Mtetra
.19 0 0 r
.73459 .38255 .73525 .38171 .73698 .38117 .73632 .38202 Mtetra
.197 0 0 r
.73632 .38202 .73698 .38117 .7387 .38064 .73805 .3815 Mtetra
.198 0 0 r
.73805 .3815 .7387 .38064 .74043 .3801 .73978 .38097 Mtetra
.196 0 0 r
.73978 .38097 .74043 .3801 .74215 .37955 .7415 .38042 Mtetra
.195 0 0 r
.7415 .38042 .74215 .37955 .74388 .379 .74323 .37988 Mtetra
.194 0 0 r
.74323 .37988 .74388 .379 .74561 .37844 .74496 .37932 Mtetra
.193 0 0 r
.74496 .37932 .74561 .37844 .74734 .37789 .74669 .37876 Mtetra
.191 0 0 r
.74669 .37876 .74734 .37789 .74907 .37733 .74842 .3782 Mtetra
.188 0 0 r
.74842 .3782 .74907 .37733 .7508 .37676 .75016 .37763 Mtetra
.184 0 0 r
.75016 .37763 .7508 .37676 .75253 .3762 .75189 .37706 Mtetra
.178 0 0 r
.75189 .37706 .75253 .3762 .75426 .37562 .75362 .37648 Mtetra
.168 0 0 r
.75362 .37648 .75426 .37562 .75599 .37504 .75535 .37588 Mtetra
.157 0 0 r
.75535 .37588 .75599 .37504 .75772 .37444 .75709 .37527 Mtetra
.15 0 0 r
.75709 .37527 .75772 .37444 .75946 .37385 .75882 .37466 Mtetra
.023 0 0 r
.75882 .37466 .75946 .37385 .76118 .37309 .76054 .3738 Mtetra
0 0 0 r
.76054 .3738 .76118 .37309 .7629 .37225 .76225 .37283 Mtetra
.124 0 0 r
.76225 .37283 .7629 .37225 .76464 .37178 .764 .3724 Mtetra
.704 .217 .088 r
.764 .3724 .76464 .37178 .76648 .37254 .7659 .37396 Mtetra
.974 .671 .375 r
.7659 .37396 .76648 .37254 .76857 .37656 .78238 .56749 Mtetra
.577 .356 .544 r
.78238 .56749 .76857 .37656 .78565 .5758 .78527 .58044 Mtetra
.643 .333 .43 r
.78527 .58044 .78565 .5758 .78795 .58096 .78733 .58242 Mtetra
.378 0 .118 r
.78733 .58242 .78795 .58096 .78992 .58184 .78921 .58203 Mtetra
.472 .886 .77 r
.78921 .58203 .78992 .58184 .79183 .58187 .79104 .58105 Mtetra
.753 .832 .912 r
.79104 .58105 .79183 .58187 .79371 .58145 .79287 .58001 Mtetra
.677 .689 .854 r
.79287 .58001 .79371 .58145 .79557 .58075 .79473 .57931 Mtetra
.672 .686 .855 r
.79473 .57931 .79557 .58075 .79741 .57988 .79659 .57863 Mtetra
.662 .714 .886 r
.79659 .57863 .79741 .57988 .79926 .57908 .79845 .57803 Mtetra
.64 .744 .925 r
.79845 .57803 .79926 .57908 .80113 .57852 .80033 .57754 Mtetra
.623 .753 .94 r
.80033 .57754 .80113 .57852 .80301 .57801 .80221 .5771 Mtetra
.527 .726 .965 r
.80221 .5771 .80301 .57801 .8049 .57776 .80412 .57696 Mtetra
.398 .691 .979 r
.80412 .57696 .8049 .57776 .80682 .57772 .80605 .57708 Mtetra
.599 .831 .988 r
.80605 .57708 .80682 .57772 .8087 .57721 .80794 .57661 Mtetra
.912 .883 .792 r
.80794 .57661 .8087 .57721 .81046 .57524 .80966 .57424 Mtetra
.981 .731 .48 r
.80966 .57424 .81046 .57524 .8118 .56833 .8104 .56014 Mtetra
.972 .674 .391 r
.8104 .56014 .8118 .56833 .79665 .36793 .79561 .36351 Mtetra
.74 .553 .64 r
.79561 .36351 .79665 .36793 .79807 .36327 .79714 .36024 Mtetra
.641 .531 .714 r
.79714 .36024 .79807 .36327 .79973 .3616 .79888 .35948 Mtetra
.592 .557 .784 r
.79888 .35948 .79973 .3616 .80145 .36058 .80068 .35928 Mtetra
.558 .643 .891 r
.80068 .35928 .80145 .36058 .80321 .3599 .80248 .35919 Mtetra
.622 .809 .972 r
.80248 .35919 .80321 .3599 .80498 .35943 .80426 .35872 Mtetra
.633 .813 .969 r
.80426 .35872 .80498 .35943 .80676 .35909 .80603 .35822 Mtetra
.665 .783 .937 r
.80603 .35822 .80676 .35909 .80855 .35873 .80779 .35763 Mtetra
.69 .742 .891 r
.80779 .35763 .80855 .35873 .81032 .3582 .80955 .35693 Mtetra
.677 .705 .868 r
.80955 .35693 .81032 .3582 .81208 .35761 .81131 .35628 Mtetra
.64 .677 .869 r
.81131 .35628 .81208 .35761 .81385 .35695 .81309 .35581 Mtetra
.549 .672 .919 r
.81309 .35581 .81385 .35695 .8156 .3562 .8149 .35571 Mtetra
.361 .747 .988 r
.8149 .35571 .8156 .3562 .81735 .35545 .81673 .35569 Mtetra
0 0 0 r
.81673 .35569 .81735 .35545 .8191 .35459 .81852 .35538 Mtetra
.81852 .35538 .8191 .35459 .82083 .35356 .82026 .35434 Mtetra
.121 0 0 r
.82026 .35434 .82083 .35356 .8226 .35296 .82202 .35367 Mtetra
.545 .038 0 r
.82202 .35367 .8226 .35296 .82448 .35351 .82391 .35433 Mtetra
.917 .536 .278 r
.82391 .35433 .82448 .35351 .82681 .35872 .82652 .36249 Mtetra
.973 .663 .352 r
.82652 .36249 .82681 .35872 .848 .56141 .8473 .56126 Mtetra
.791 .294 0 r
.8473 .56126 .848 .56141 .85034 .56549 .84955 .56435 Mtetra
.536 .68 .931 r
.84955 .56435 .85034 .56549 .85231 .56558 .8515 .56427 Mtetra
.678 .714 .876 r
.8515 .56427 .85231 .56558 .8542 .56483 .8534 .56356 Mtetra
.685 .724 .879 r
.8534 .56356 .8542 .56483 .85605 .56371 .85529 .56282 Mtetra
.447 .696 .972 r
.85529 .56282 .85605 .56371 .85793 .56284 .85726 .56289 Mtetra
.248 .761 .785 r
.85726 .56289 .85793 .56284 .85975 .56139 .85918 .56243 Mtetra
0 0 0 r
.85918 .56243 .85975 .56139 .86141 .55828 .86097 .56063 Mtetra
.824 .724 .195 r
.86097 .56063 .86141 .55828 .84355 .3603 .86206 .55189 Mtetra
.082 .006 .462 r
.86206 .55189 .84355 .3603 .84431 .34938 .84365 .3491 Mtetra
.989 .866 .621 r
.84365 .3491 .84431 .34938 .84582 .34613 .84507 .34487 Mtetra
.766 .742 .831 r
.84507 .34487 .84582 .34613 .84754 .34484 .84679 .34362 Mtetra
.617 .689 .894 r
.84679 .34362 .84754 .34484 .84934 .34439 .84861 .34326 Mtetra
.279 .52 .905 r
.84861 .34326 .84934 .34439 .85127 .34514 .85053 .34395 Mtetra
.628 .211 0 r
.85053 .34395 .85127 .34514 .85373 .35095 .85277 .34769 Mtetra
.973 .664 .309 r
.85277 .34769 .85373 .35095 .87674 .55392 .87552 .5486 Mtetra
.035 .079 .577 r
.87552 .5486 .87674 .55392 .87913 .55783 .87814 .55475 Mtetra
.484 .445 .739 r
.87814 .55475 .87913 .55783 .88109 .55769 .8802 .55548 Mtetra
.577 .556 .794 r
.8802 .55548 .88109 .55769 .88299 .55681 .88218 .55537 Mtetra
.642 .679 .87 r
.88218 .55537 .88299 .55681 .88485 .55564 .88411 .55486 Mtetra
.633 .814 .97 r
.88411 .55486 .88485 .55564 .88678 .55515 .88604 .55431 Mtetra
.667 .813 .953 r
.88604 .55431 .88678 .55515 .88871 .55459 .88796 .55365 Mtetra
.66 .783 .939 r
.88796 .55365 .88871 .55459 .89063 .5539 .88989 .55303 Mtetra
.474 .714 .974 r
.88989 .55303 .89063 .5539 .89253 .55309 .89188 .55301 Mtetra
.298 .792 .862 r
.89188 .55301 .89253 .55309 .89438 .55174 .89383 .55262 Mtetra
0 0 0 r
.89383 .55262 .89438 .55174 .89608 .54908 .89569 .55136 Mtetra
.89569 .55136 .89608 .54908 .87676 .35646 .89711 .54616 Mtetra
.092 .016 .469 r
.89711 .54616 .87676 .35646 .87673 .33929 .87661 .34362 Mtetra
0 0 .221 r
.87661 .34362 .87673 .33929 .87822 .3358 .8777 .33653 Mtetra
0 0 0 r
.8777 .33653 .87822 .3358 .87999 .33493 .87938 .3348 Mtetra
.648 .964 .915 r
.87938 .3348 .87999 .33493 .88183 .33461 .88115 .33382 Mtetra
.657 .809 .956 r
.88115 .33382 .88183 .33461 .88371 .33456 .88296 .33324 Mtetra
.654 .689 .871 r
.88296 .33324 .88371 .33456 .88553 .33408 .88478 .33269 Mtetra
.632 .669 .868 r
.88478 .33269 .88553 .33408 .88735 .33354 .88661 .33226 Mtetra
.627 .684 .885 r
.88661 .33226 .88735 .33354 .88916 .33294 .88845 .33185 Mtetra
.665 .74 .906 r
.88845 .33185 .88916 .33294 .89095 .33211 .89027 .33126 Mtetra
.673 .798 .942 r
.89027 .33126 .89095 .33211 .89275 .33135 .89208 .33062 Mtetra
.677 .834 .959 r
.89208 .33062 .89275 .33135 .89457 .33075 .89389 .32994 Mtetra
.772 .843 .905 r
.89389 .32994 .89457 .33075 .89641 .3304 .89565 .32883 Mtetra
.685 .669 .828 r
.89565 .32883 .89641 .3304 .89832 .33053 .89745 .32806 Mtetra
.585 .531 .76 r
.89745 .32806 .89832 .33053 .90034 .3316 .89932 .3279 Mtetra
0 .219 .736 r
.30939 .51622 .31031 .51739 .31156 .52046 .31076 .51737 Mtetra
0 0 .538 r
.31076 .51737 .31156 .52046 .30098 .71027 .31202 .52026 Mtetra
0 0 .275 r
.31202 .52026 .30098 .71027 .30201 .71828 .30182 .7046 Mtetra
.098 .018 .468 r
.30182 .7046 .30201 .71828 .30349 .71919 .30274 .71425 Mtetra
.277 .227 .62 r
.30274 .71425 .30349 .71919 .30503 .71922 .30412 .71679 Mtetra
.309 .36 .753 r
.30412 .71679 .30503 .71922 .30659 .71883 .30559 .71793 Mtetra
.307 .605 .951 r
.30559 .71793 .30659 .71883 .30812 .71894 .30711 .71826 Mtetra
.56 .771 .977 r
.30711 .71826 .30812 .71894 .30968 .71866 .30867 .71802 Mtetra
.732 .821 .92 r
.30867 .71802 .30968 .71866 .31129 .71769 .31026 .71721 Mtetra
.877 .822 .79 r
.31026 .71721 .31129 .71769 .31308 .71361 .31194 .71505 Mtetra
.955 .937 .611 r
.31194 .71505 .31308 .71361 .32593 .52347 .31372 .7111 Mtetra
0 0 .282 r
.31372 .7111 .32593 .52347 .32796 .51371 .32596 .53074 Mtetra
0 0 .258 r
.32596 .53074 .32796 .51371 .32953 .51188 .32836 .51493 Mtetra
0 0 0 r
.32836 .51493 .32953 .51188 .33104 .51097 .33002 .51161 Mtetra
.86 .995 .758 r
.33002 .51161 .33104 .51097 .33253 .51047 .33159 .50969 Mtetra
.737 .779 .886 r
.33159 .50969 .33253 .51047 .33403 .50992 .3331 .50887 Mtetra
.657 .706 .884 r
.3331 .50887 .33403 .50992 .33552 .50944 .33459 .50842 Mtetra
.621 .7 .901 r
.33459 .50842 .33552 .50944 .33701 .50899 .33607 .5081 Mtetra
.768 .76 .845 r
.33607 .5081 .33701 .50899 .33853 .508 .3376 .50703 Mtetra
.728 .739 .86 r
.3376 .50703 .33853 .508 .34003 .50727 .33911 .50621 Mtetra
.579 .678 .908 r
.33911 .50621 .34003 .50727 .3415 .50717 .34059 .50605 Mtetra
.908 .502 .128 r
.34059 .50605 .3415 .50717 .34279 .51056 .34186 .50949 Mtetra
.941 .684 .519 r
.34186 .50949 .34279 .51056 .33377 .70413 .33275 .70381 Mtetra
.922 .584 .382 r
.33275 .70381 .33377 .70413 .33499 .71036 .33398 .70991 Mtetra
0 .46 .794 r
.33398 .70991 .33499 .71036 .33652 .71092 .33551 .71037 Mtetra
.689 .838 .955 r
.33551 .71037 .33652 .71092 .33811 .71041 .33711 .70973 Mtetra
.774 .814 .885 r
.33711 .70973 .33811 .71041 .33972 .70946 .33873 .70866 Mtetra
.456 .704 .974 r
.33873 .70866 .33972 .70946 .34129 .70944 .34029 .70869 Mtetra
.492 .732 .979 r
.34029 .70869 .34129 .70944 .34287 .70927 .34186 .70862 Mtetra
.712 .817 .931 r
.34186 .70862 .34287 .70927 .34448 .70845 .34347 .70789 Mtetra
.916 .775 .69 r
.34347 .70789 .34448 .70845 .34626 .70419 .34525 .70377 Mtetra
.942 .688 .524 r
.34525 .70377 .34626 .70419 .35757 .51013 .35661 .50976 Mtetra
.94 .742 .608 r
.35661 .50976 .35757 .51013 .35943 .50247 .35851 .50155 Mtetra
.817 .757 .796 r
.35851 .50155 .35943 .50247 .36099 .50086 .36007 .49993 Mtetra
.658 .731 .903 r
.36007 .49993 .36099 .50086 .3625 .50038 .36157 .49947 Mtetra
.517 .687 .944 r
.36157 .49947 .3625 .50038 .36398 .50032 .36306 .49943 Mtetra
.688 .749 .898 r
.36306 .49943 .36398 .50032 .3655 .4996 .36457 .49884 Mtetra
.696 .781 .917 r
.36457 .49884 .3655 .4996 .36702 .49893 .36609 .49822 Mtetra
.593 .77 .964 r
.36609 .49822 .36702 .49893 .36851 .49877 .36759 .49793 Mtetra
0 .331 .792 r
.36759 .49793 .36851 .49877 .36989 .50107 .36903 .49877 Mtetra
0 0 .556 r
.36903 .49877 .36989 .50107 .36279 .68713 .37041 .50123 Mtetra
.526 .32 .544 r
.37041 .50123 .36279 .68713 .36377 .70003 .37121 .51618 Mtetra
0 0 .308 r
.37121 .51618 .36377 .70003 .36528 .70157 .36452 .69582 Mtetra
.287 .22 .605 r
.36452 .69582 .36528 .70157 .36686 .70169 .36597 .6988 Mtetra
.324 .338 .721 r
.36597 .6988 .36686 .70169 .36846 .70136 .36749 .70015 Mtetra
.236 .492 .896 r
.36749 .70015 .36846 .70136 .37004 .70142 .36905 .7008 Mtetra
.425 .74 .992 r
.36905 .7008 .37004 .70142 .37163 .70128 .37064 .70077 Mtetra
.73 .859 .942 r
.37064 .70077 .37163 .70128 .37326 .70048 .37226 .69996 Mtetra
.915 .792 .71 r
.37226 .69996 .37326 .70048 .375 .69683 .374 .69639 Mtetra
.945 .689 .518 r
.374 .69639 .375 .69683 .38468 .50491 .38369 .50554 Mtetra
.967 .754 .564 r
.38369 .50554 .38468 .50491 .38662 .49429 .38571 .49337 Mtetra
.84 .759 .773 r
.38571 .49337 .38662 .49429 .3882 .49237 .38729 .4914 Mtetra
.656 .725 .9 r
.38729 .4914 .3882 .49237 .38972 .49191 .38881 .49094 Mtetra
.492 .665 .939 r
.38881 .49094 .38972 .49191 .39122 .49194 .39031 .49098 Mtetra
.584 .704 .925 r
.39031 .49098 .39122 .49194 .39273 .49173 .39182 .49078 Mtetra
.643 .724 .907 r
.39182 .49078 .39273 .49173 .39425 .49134 .39334 .49037 Mtetra
.649 .724 .903 r
.39334 .49037 .39425 .49134 .39577 .49091 .39486 .48994 Mtetra
.702 .737 .878 r
.39486 .48994 .39577 .49091 .3973 .49035 .3964 .48926 Mtetra
.698 .714 .862 r
.3964 .48926 .3973 .49035 .39883 .48974 .39793 .48858 Mtetra
.64 .683 .875 r
.39793 .48858 .39883 .48974 .40036 .4892 .39945 .48819 Mtetra
.078 .425 .87 r
.39945 .48819 .40036 .4892 .40188 .48898 .40094 .48895 Mtetra
.838 .4 .191 r
.40094 .48895 .40188 .48898 .40339 .48897 .40236 .49131 Mtetra
.842 .535 .468 r
.40236 .49131 .40339 .48897 .4049 .48899 .40362 .49816 Mtetra
.932 .668 .514 r
.40362 .49816 .4049 .48899 .40643 .48867 .39869 .67715 Mtetra
.556 .341 .543 r
.39869 .67715 .40643 .48867 .40796 .48807 .40031 .67645 Mtetra
.539 .327 .54 r
.40031 .67645 .40796 .48807 .4095 .4874 .40227 .6664 Mtetra
.56 .344 .544 r
.40227 .6664 .4095 .4874 .41104 .48687 .40381 .66805 Mtetra
.565 .348 .544 r
.40381 .66805 .41104 .48687 .41257 .4864 .40527 .67233 Mtetra
0 0 .356 r
.40527 .67233 .41257 .4864 .41411 .48582 .41258 .50326 Mtetra
.05 0 .357 r
.41258 .50326 .41411 .48582 .41566 .48486 .41458 .48921 Mtetra
0 0 .095 r
.41458 .48921 .41566 .48486 .41722 .48372 .41626 .48449 Mtetra
.925 .969 .685 r
.41626 .48449 .41722 .48372 .41877 .48266 .41787 .48179 Mtetra
.796 .773 .832 r
.41787 .48179 .41877 .48266 .42032 .48192 .41943 .48049 Mtetra
.667 .652 .826 r
.41943 .48049 .42032 .48192 .42186 .48141 .42097 .47992 Mtetra
.625 .627 .832 r
.42097 .47992 .42186 .48141 .42339 .48098 .42251 .47958 Mtetra
.638 .646 .842 r
.42251 .47958 .42339 .48098 .42493 .48052 .42404 .47919 Mtetra
.657 .663 .844 r
.42404 .47919 .42493 .48052 .42648 .48002 .42559 .47869 Mtetra
.657 .664 .845 r
.42559 .47869 .42648 .48002 .42802 .47952 .42713 .4782 Mtetra
.657 .665 .846 r
.42713 .4782 .42802 .47952 .42956 .47902 .42867 .47771 Mtetra
.656 .666 .848 r
.42867 .47771 .42956 .47902 .43111 .47852 .43022 .47722 Mtetra
.656 .667 .849 r
.43022 .47722 .43111 .47852 .43265 .47802 .43176 .47673 Mtetra
.657 .669 .85 r
.43176 .47673 .43265 .47802 .4342 .47753 .43331 .47624 Mtetra
.656 .669 .851 r
.43331 .47624 .4342 .47753 .43574 .47704 .43485 .47575 Mtetra
.651 .667 .853 r
.43485 .47575 .43574 .47704 .43729 .47657 .4364 .4753 Mtetra
.635 .664 .861 r
.4364 .4753 .43729 .47657 .43884 .47613 .43795 .47492 Mtetra
.62 .669 .876 r
.43795 .47492 .43884 .47613 .44038 .47571 .43949 .47461 Mtetra
.618 .688 .893 r
.43949 .47461 .44038 .47571 .44193 .47529 .44104 .4743 Mtetra
.633 .716 .907 r
.44104 .4743 .44193 .47529 .44348 .47484 .44258 .47392 Mtetra
.654 .74 .913 r
.44258 .47392 .44348 .47484 .44503 .47434 .44414 .47346 Mtetra
.67 .752 .912 r
.44414 .47346 .44503 .47434 .44659 .47382 .44569 .47293 Mtetra
.69 .757 .903 r
.44569 .47293 .44659 .47382 .44814 .47326 .44725 .47232 Mtetra
.702 .748 .887 r
.44725 .47232 .44814 .47326 .4497 .47268 .44881 .47164 Mtetra
.699 .727 .872 r
.44881 .47164 .4497 .47268 .45126 .47209 .45037 .47095 Mtetra
.683 .705 .864 r
.45037 .47095 .45126 .47209 .45281 .47153 .45193 .47034 Mtetra
.667 .691 .863 r
.45193 .47034 .45281 .47153 .45437 .47099 .45349 .46981 Mtetra
.662 .69 .866 r
.45349 .46981 .45437 .47099 .45593 .47046 .45504 .4693 Mtetra
.662 .694 .869 r
.45504 .4693 .45593 .47046 .45749 .46993 .4566 .46879 Mtetra
.664 .698 .872 r
.4566 .46879 .45749 .46993 .45905 .4694 .45816 .46827 Mtetra
.663 .7 .874 r
.45816 .46827 .45905 .4694 .46061 .46888 .45973 .46776 Mtetra
.686 .71 .866 r
.45973 .46776 .46061 .46888 .46218 .46819 .46129 .46713 Mtetra
.699 .726 .871 r
.46129 .46713 .46218 .46819 .46374 .46742 .46286 .46645 Mtetra
.643 .726 .909 r
.46286 .46645 .46374 .46742 .46531 .46706 .46442 .46603 Mtetra
.297 .554 .924 r
.46442 .46603 .46531 .46706 .46684 .46815 .46597 .46649 Mtetra
0 0 .551 r
.46597 .46649 .46684 .46815 .46829 .47428 .46749 .46868 Mtetra
0 0 .434 r
.46749 .46868 .46829 .47428 .46661 .66879 .46894 .47482 Mtetra
0 0 .365 r
.46894 .47482 .46661 .66879 .46822 .67176 .46743 .66123 Mtetra
.544 .372 .599 r
.46743 .66123 .46822 .67176 .46988 .67163 .46908 .66182 Mtetra
.623 .434 .606 r
.46908 .66182 .46988 .67163 .47155 .67082 .47076 .65994 Mtetra
.665 .462 .6 r
.47076 .65994 .47155 .67082 .47322 .66991 .47248 .65596 Mtetra
.681 .467 .59 r
.47248 .65596 .47322 .66991 .47489 .66932 .47422 .64973 Mtetra
.523 .337 .571 r
.47422 .64973 .47489 .66932 .47656 .66883 .47585 .65176 Mtetra
.309 .179 .536 r
.47585 .65176 .47656 .66883 .47823 .66869 .47739 .66054 Mtetra
.25 .17 .567 r
.47739 .66054 .47823 .66869 .47989 .6689 .47898 .66545 Mtetra
.204 .233 .669 r
.47898 .66545 .47989 .6689 .48155 .66906 .48062 .66773 Mtetra
.218 .458 .875 r
.48062 .66773 .48155 .66906 .48322 .66896 .48228 .66853 Mtetra
.52 .835 .999 r
.48228 .66853 .48322 .66896 .4849 .66854 .48395 .66821 Mtetra
.622 .896 .987 r
.48395 .66821 .4849 .66854 .48658 .66803 .48563 .66762 Mtetra
.625 .877 .989 r
.48563 .66762 .48658 .66803 .48825 .66754 .48731 .66707 Mtetra
.525 .827 1 r
.48731 .66707 .48825 .66754 .48993 .66714 .48899 .66676 Mtetra
.495 .838 .997 r
.48899 .66676 .48993 .66714 .49161 .66675 .49067 .66646 Mtetra
.488 .854 .988 r
.49067 .66646 .49161 .66675 .49329 .66634 .49235 .6661 Mtetra
.513 .876 .982 r
.49235 .6661 .49329 .66634 .49497 .66589 .49403 .66566 Mtetra
.541 .888 .983 r
.49403 .66566 .49497 .66589 .49665 .66543 .49571 .66517 Mtetra
.584 .899 .985 r
.49571 .66517 .49665 .66543 .49834 .66493 .4974 .66461 Mtetra
.635 .9 .985 r
.4974 .66461 .49834 .66493 .50002 .66441 .49909 .66398 Mtetra
.661 .881 .98 r
.49909 .66398 .50002 .66441 .50171 .66387 .50077 .66334 Mtetra
.629 .846 .983 r
.50077 .66334 .50171 .66387 .50339 .66349 .50246 .66283 Mtetra
.559 .79 .985 r
.50246 .66283 .50339 .66349 .50508 .66334 .50415 .66254 Mtetra
.652 .786 .945 r
.50415 .66254 .50508 .66334 .50677 .66279 .50584 .66203 Mtetra
.795 .817 .869 r
.50584 .66203 .50677 .66279 .50847 .66102 .50753 .66077 Mtetra
.939 .858 .734 r
.50753 .66077 .50847 .66102 .51018 .65493 .50924 .65765 Mtetra
.82 .809 .321 r
.50924 .65765 .51018 .65493 .5126 .45805 .51095 .65169 Mtetra
0 0 .372 r
.51095 .65169 .5126 .45805 .51421 .45322 .5133 .46298 Mtetra
.438 .207 .465 r
.5133 .46298 .51421 .45322 .51581 .45226 .51491 .46029 Mtetra
.574 .313 .483 r
.51491 .46029 .51581 .45226 .5174 .45197 .51651 .46096 Mtetra
.629 .365 .499 r
.51651 .46096 .5174 .45197 .519 .45189 .5181 .46348 Mtetra
.545 .302 .498 r
.5181 .46348 .519 .45189 .52059 .45139 .5197 .46329 Mtetra
.548 .305 .499 r
.5197 .46329 .52059 .45139 .52219 .45091 .52131 .46319 Mtetra
.547 .306 .501 r
.52131 .46319 .52219 .45091 .52379 .45042 .52291 .46307 Mtetra
.542 .302 .501 r
.52291 .46307 .52379 .45042 .52539 .44991 .52452 .46273 Mtetra
.54 .301 .501 r
.52452 .46273 .52539 .44991 .52699 .4494 .52613 .46232 Mtetra
.539 .3 .501 r
.52613 .46232 .52699 .4494 .52859 .44889 .52773 .46187 Mtetra
.52773 .46187 .52859 .44889 .53019 .44838 .52934 .4614 Mtetra
.538 .3 .502 r
.52934 .4614 .53019 .44838 .53179 .44786 .53095 .46091 Mtetra
.53095 .46091 .53179 .44786 .5334 .44734 .53257 .46041 Mtetra
.53257 .46041 .5334 .44734 .535 .44683 .53418 .45991 Mtetra
.53418 .45991 .535 .44683 .53661 .44631 .53579 .45941 Mtetra
.53579 .45941 .53661 .44631 .53821 .4458 .53741 .45891 Mtetra
.53741 .45891 .53821 .4458 .53982 .44528 .53902 .45842 Mtetra
.53902 .45842 .53982 .44528 .54143 .44477 .54064 .45791 Mtetra
.537 .299 .502 r
.54064 .45791 .54143 .44477 .54304 .44425 .54225 .45737 Mtetra
.537 .299 .501 r
.54225 .45737 .54304 .44425 .54465 .44373 .54387 .45681 Mtetra
.535 .297 .501 r
.54387 .45681 .54465 .44373 .54626 .44321 .54549 .45619 Mtetra
.531 .294 .5 r
.54549 .45619 .54626 .44321 .54787 .44268 .54711 .45544 Mtetra
.525 .288 .498 r
.54711 .45544 .54787 .44268 .54949 .44213 .54873 .45449 Mtetra
.525 .287 .497 r
.54873 .45449 .54949 .44213 .5511 .44159 .55034 .45356 Mtetra
.505 .27 .492 r
.55034 .45356 .5511 .44159 .55271 .44098 .55196 .45205 Mtetra
.418 .196 .468 r
.55196 .45205 .55271 .44098 .55433 .43997 .55355 .44844 Mtetra
.516 .266 .474 r
.55355 .44844 .55433 .43997 .55594 .43942 .55517 .4477 Mtetra
.787 .503 .506 r
.55517 .4477 .55594 .43942 .55757 .43998 .55691 .45904 Mtetra
.932 .653 .489 r
.55691 .45904 .55757 .43998 .55929 .44928 .5604 .64023 Mtetra
.563 .346 .544 r
.5604 .64023 .55929 .44928 .56305 .64273 .56217 .64376 Mtetra
.703 .275 .229 r
.56217 .64376 .56305 .64273 .56482 .64591 .56392 .64529 Mtetra
.502 .78 .995 r
.56392 .64529 .56482 .64591 .56655 .64591 .56565 .6451 Mtetra
.665 .79 .941 r
.56565 .6451 .56655 .64591 .56828 .64531 .56737 .64453 Mtetra
.705 .808 .929 r
.56737 .64453 .56828 .64531 .57 .64442 .5691 .64378 Mtetra
.635 .824 .973 r
.5691 .64378 .57 .64442 .57173 .64392 .57083 .64327 Mtetra
.629 .821 .974 r
.57083 .64327 .57173 .64392 .57346 .64342 .57256 .64278 Mtetra
.613 .818 .979 r
.57256 .64278 .57346 .64342 .57519 .64293 .57429 .64233 Mtetra
.557 .808 .992 r
.57429 .64233 .57519 .64293 .57692 .64251 .57603 .64201 Mtetra
.525 .823 .999 r
.57603 .64201 .57692 .64251 .57866 .6421 .57777 .6417 Mtetra
.502 .841 .997 r
.57777 .6417 .57866 .6421 .58039 .64168 .5795 .64137 Mtetra
.517 .868 .989 r
.5795 .64137 .58039 .64168 .58213 .64121 .58124 .64095 Mtetra
.528 .882 .983 r
.58124 .64095 .58213 .64121 .58387 .64072 .58298 .64047 Mtetra
.55 .894 .981 r
.58298 .64047 .58387 .64072 .5856 .6402 .58472 .63994 Mtetra
.499 .869 .982 r
.58472 .63994 .5856 .6402 .58734 .63972 .58646 .63951 Mtetra
.58 .912 .974 r
.58646 .63951 .58734 .63972 .58908 .63917 .5882 .63889 Mtetra
.736 .937 .953 r
.5882 .63889 .58908 .63917 .59082 .63851 .58993 .63791 Mtetra
.901 .841 .776 r
.58993 .63791 .59082 .63851 .59255 .63747 .59164 .63545 Mtetra
.85 .684 .676 r
.59164 .63545 .59255 .63747 .59428 .63633 .59331 .6316 Mtetra
.83 .61 .605 r
.59331 .6316 .59428 .63633 .59601 .63517 .59491 .62377 Mtetra
.599 .411 .598 r
.59491 .62377 .59601 .63517 .59776 .6351 .59663 .62249 Mtetra
.548 .37 .592 r
.59663 .62249 .59776 .6351 .59951 .63474 .59839 .62303 Mtetra
.61 .418 .597 r
.59839 .62303 .59951 .63474 .60125 .63358 .60011 .62126 Mtetra
.953 .675 .474 r
.60011 .62126 .60125 .63358 .60283 .62603 .59758 .42993 Mtetra
.567 .353 .55 r
.59758 .42993 .60283 .62603 .60002 .42837 .59913 .4251 Mtetra
.75 .583 .669 r
.59913 .4251 .60002 .42837 .60157 .42377 .60073 .42246 Mtetra
.722 .701 .83 r
.60073 .42246 .60157 .42377 .6032 .42262 .60236 .42153 Mtetra
.653 .714 .893 r
.60236 .42153 .6032 .42262 .60485 .42216 .60401 .42105 Mtetra
.595 .688 .906 r
.60401 .42105 .60485 .42216 .6065 .42203 .60566 .4208 Mtetra
.622 .676 .88 r
.60566 .4208 .6065 .42203 .60815 .42161 .60731 .42046 Mtetra
.616 .687 .894 r
.60731 .42046 .60815 .42161 .6098 .42119 .60897 .42013 Mtetra
.616 .707 .91 r
.60897 .42013 .6098 .42119 .61145 .42077 .61062 .4198 Mtetra
.642 .736 .917 r
.61062 .4198 .61145 .42077 .61311 .42031 .61227 .41936 Mtetra
.658 .747 .915 r
.61227 .41936 .61311 .42031 .61476 .41982 .61393 .41885 Mtetra
.672 .748 .907 r
.61393 .41885 .61476 .41982 .61641 .4193 .61558 .41828 Mtetra
.693 .743 .89 r
.61558 .41828 .61641 .4193 .61806 .41873 .61723 .4176 Mtetra
.695 .723 .871 r
.61723 .4176 .61806 .41873 .61971 .41815 .61888 .4169 Mtetra
.688 .7 .856 r
.61888 .4169 .61971 .41815 .62137 .41757 .62053 .41622 Mtetra
.667 .676 .849 r
.62053 .41622 .62137 .41757 .62302 .41702 .62218 .41564 Mtetra
.659 .667 .847 r
.62218 .41564 .62302 .41702 .62468 .41649 .62384 .4151 Mtetra
.655 .664 .847 r
.62384 .4151 .62468 .41649 .62634 .41597 .6255 .41458 Mtetra
.659 .667 .847 r
.6255 .41458 .62634 .41597 .628 .41543 .62716 .41404 Mtetra
.656 .665 .847 r
.62716 .41404 .628 .41543 .62965 .4149 .62882 .41352 Mtetra
.651 .664 .85 r
.62882 .41352 .62965 .4149 .63132 .41438 .63048 .41302 Mtetra
.632 .66 .859 r
.63048 .41302 .63132 .41438 .63298 .41389 .63215 .41263 Mtetra
.625 .673 .875 r
.63215 .41263 .63298 .41389 .63464 .41341 .63381 .41227 Mtetra
.627 .695 .894 r
.63381 .41227 .63464 .41341 .63631 .41292 .63548 .41189 Mtetra
.649 .728 .907 r
.63548 .41189 .63631 .41292 .63797 .41237 .63715 .41142 Mtetra
.665 .75 .914 r
.63715 .41142 .63797 .41237 .63964 .41179 .63882 .41088 Mtetra
.679 .764 .915 r
.63882 .41088 .63964 .41179 .6413 .4112 .64048 .41028 Mtetra
.746 .78 .881 r
.64048 .41028 .6413 .4112 .64295 .41023 .64214 .40933 Mtetra
.728 .78 .894 r
.64214 .40933 .64295 .41023 .64461 .40946 .64379 .40848 Mtetra
.648 .74 .916 r
.64379 .40848 .64461 .40946 .64629 .40923 .64547 .40801 Mtetra
.214 .461 .878 r
.64547 .40801 .64629 .40923 .64807 .41157 .64719 .40883 Mtetra
.063 .173 .668 r
.64719 .40883 .64807 .41157 .65715 .60285 .64898 .4114 Mtetra
.056 0 .437 r
.64898 .4114 .65715 .60285 .65947 .61615 .65772 .59261 Mtetra
.134 .052 .49 r
.65772 .59261 .65947 .61615 .66133 .61772 .6603 .6124 Mtetra
.321 .264 .637 r
.6603 .6124 .66133 .61772 .66315 .61788 .66222 .61533 Mtetra
.346 .384 .759 r
.66222 .61533 .66315 .61788 .66494 .61754 .66408 .6166 Mtetra
.381 .642 .958 r
.66408 .6166 .66494 .61754 .66675 .61744 .6659 .61685 Mtetra
.571 .824 .993 r
.6659 .61685 .66675 .61744 .66854 .6171 .6677 .61647 Mtetra
.744 .862 .935 r
.6677 .61647 .66854 .6171 .67032 .61613 .66947 .61552 Mtetra
.898 .858 .793 r
.66947 .61552 .67032 .61613 .67198 .61258 .67119 .61322 Mtetra
.971 .919 .59 r
.67119 .61322 .67198 .61258 .67296 .5933 .67282 .60905 Mtetra
.18 .03 .427 r
.67282 .60905 .67296 .5933 .66653 .40558 .6741 .59681 Mtetra
.06 0 .433 r
.6741 .59681 .66653 .40558 .66814 .40348 .66782 .41361 Mtetra
.572 .318 .493 r
.66782 .41361 .66814 .40348 .66982 .40293 .66957 .41435 Mtetra
.556 .31 .497 r
.66957 .41435 .66982 .40293 .67153 .40279 .6713 .41457 Mtetra
.2 .036 .422 r
.6713 .41457 .67153 .40279 .6732 .40193 .67261 .40575 Mtetra
0 0 .197 r
.67261 .40575 .6732 .40193 .67486 .40077 .67412 .40132 Mtetra
.882 .966 .64 r
.67412 .40132 .67486 .40077 .67652 .39971 .67571 .3987 Mtetra
.762 .77 .859 r
.67571 .3987 .67652 .39971 .6782 .39901 .67738 .39761 Mtetra
.635 .656 .854 r
.67738 .39761 .6782 .39901 .67989 .39852 .67907 .39719 Mtetra
.593 .649 .874 r
.67907 .39719 .67989 .39852 .68159 .39809 .68078 .39697 Mtetra
.658 .716 .892 r
.68078 .39697 .68159 .39809 .68328 .39752 .68247 .39645 Mtetra
.698 .739 .883 r
.68247 .39645 .68328 .39752 .68497 .39689 .68416 .39573 Mtetra
.697 .723 .87 r
.68416 .39573 .68497 .39689 .68666 .39625 .68584 .395 Mtetra
.706 .711 .852 r
.68584 .395 .68666 .39625 .68833 .39538 .68752 .3942 Mtetra
.69 .716 .869 r
.68752 .3942 .68833 .39538 .69002 .39462 .68921 .39351 Mtetra
.622 .703 .904 r
.68921 .39351 .69002 .39462 .69173 .39434 .69092 .39314 Mtetra
.214 .465 .881 r
.69092 .39314 .69173 .39434 .69355 .39616 .69269 .39397 Mtetra
0 .113 .654 r
.69269 .39397 .69355 .39616 .69588 .40757 .69455 .39659 Mtetra
.133 .079 .526 r
.69455 .39659 .69588 .40757 .70799 .60153 .69679 .40615 Mtetra
.079 0 .45 r
.69679 .40615 .70799 .60153 .70992 .60321 .70849 .59127 Mtetra
.593 .405 .596 r
.70849 .59127 .70992 .60321 .71175 .60281 .71027 .5901 Mtetra
.589 .4 .593 r
.71027 .5901 .71175 .60281 .71354 .60191 .71205 .58903 Mtetra
.373 .245 .575 r
.71205 .58903 .71354 .60191 .71537 .60163 .71422 .595 Mtetra
.313 .241 .614 r
.71422 .595 .71537 .60163 .71723 .6018 .71628 .59885 Mtetra
.268 .31 .721 r
.71628 .59885 .71723 .6018 .71909 .60188 .71824 .60078 Mtetra
.325 .571 .928 r
.71824 .60078 .71909 .60188 .72093 .60168 .72012 .60128 Mtetra
.452 .822 .993 r
.72012 .60128 .72093 .60168 .72276 .60126 .72196 .60101 Mtetra
.529 .892 .974 r
.72196 .60101 .72276 .60126 .72459 .60074 .72379 .60046 Mtetra
.585 .909 .979 r
.72379 .60046 .72459 .60074 .72641 .60019 .72561 .59982 Mtetra
.627 .904 .984 r
.72561 .59982 .72641 .60019 .72824 .59962 .72743 .59914 Mtetra
.661 .888 .98 r
.72743 .59914 .72824 .59962 .73006 .59904 .72925 .59844 Mtetra
.594 .833 .99 r
.72925 .59844 .73006 .59904 .73191 .59875 .73108 .59798 Mtetra
.587 .787 .975 r
.73108 .59798 .73191 .59875 .73375 .59848 .73293 .59761 Mtetra
.678 .795 .937 r
.73293 .59761 .73375 .59848 .73557 .59772 .73475 .59695 Mtetra
.857 .846 .831 r
.73475 .59695 .73557 .59772 .73727 .59497 .7365 .59511 Mtetra
.979 .915 .653 r
.7365 .59511 .73727 .59497 .73854 .58545 .73814 .59136 Mtetra
0 0 .204 r
.73814 .59136 .73854 .58545 .72784 .38689 .73947 .58284 Mtetra
.081 0 .447 r
.73947 .58284 .72784 .38689 .7294 .38377 .72923 .39243 Mtetra
.491 .247 .472 r
.72923 .39243 .7294 .38377 .73111 .383 .7309 .39099 Mtetra
.593 .325 .48 r
.7309 .39099 .73111 .383 .73285 .3828 .73275 .39227 Mtetra
.597 .335 .491 r
.73275 .39227 .73285 .3828 .73459 .38255 .73462 .39386 Mtetra
.544 .3 .495 r
.73462 .39386 .73459 .38255 .73632 .38202 .73637 .39366 Mtetra
.547 .302 .497 r
.73637 .39366 .73632 .38202 .73805 .3815 .73813 .39353 Mtetra
.545 .302 .498 r
.73813 .39353 .73805 .3815 .73978 .38097 .73989 .39331 Mtetra
.541 .3 .499 r
.73989 .39331 .73978 .38097 .7415 .38042 .74164 .39294 Mtetra
.539 .299 .499 r
.74164 .39294 .7415 .38042 .74323 .37988 .74338 .39248 Mtetra
.538 .298 .499 r
.74338 .39248 .74323 .37988 .74496 .37932 .74512 .39197 Mtetra
.536 .297 .499 r
.74512 .39197 .74496 .37932 .74669 .37876 .74686 .3914 Mtetra
.534 .295 .499 r
.74686 .3914 .74669 .37876 .74842 .3782 .74859 .39074 Mtetra
.532 .293 .499 r
.74859 .39074 .74842 .3782 .75016 .37763 .75032 .39001 Mtetra
.53 .291 .498 r
.75032 .39001 .75016 .37763 .75189 .37706 .75204 .3892 Mtetra
.526 .288 .496 r
.75204 .3892 .75189 .37706 .75362 .37648 .75376 .3883 Mtetra
.521 .283 .495 r
.75376 .3883 .75362 .37648 .75535 .37588 .75547 .38724 Mtetra
.517 .278 .492 r
.75547 .38724 .75535 .37588 .75709 .37527 .75717 .3861 Mtetra
.515 .276 .489 r
.75717 .3861 .75709 .37527 .75882 .37466 .75887 .38496 Mtetra
.467 .236 .48 r
.75887 .38496 .75882 .37466 .76054 .3738 .76048 .38251 Mtetra
.45 .216 .467 r
.76048 .38251 .76054 .3738 .76225 .37283 .76209 .3801 Mtetra
.533 .272 .466 r
.76209 .3801 .76225 .37283 .764 .3724 .76386 .37983 Mtetra
.968 .665 .394 r
.76386 .37983 .764 .3724 .7659 .37396 .77973 .56721 Mtetra
.573 .353 .544 r
.77973 .56721 .7659 .37396 .78238 .56749 .78243 .57784 Mtetra
.627 .359 .493 r
.78243 .57784 .78238 .56749 .78527 .58044 .78457 .58083 Mtetra
.532 0 0 r
.78457 .58083 .78527 .58044 .78733 .58242 .78653 .58163 Mtetra
.665 .815 .955 r
.78653 .58163 .78733 .58242 .78921 .58203 .78839 .58099 Mtetra
.746 .783 .883 r
.78839 .58099 .78921 .58203 .79104 .58105 .79022 .57995 Mtetra
.741 .769 .875 r
.79022 .57995 .79104 .58105 .79287 .58001 .79205 .57891 Mtetra
.683 .751 .903 r
.79205 .57891 .79287 .58001 .79473 .57931 .79391 .57821 Mtetra
.668 .746 .909 r
.79391 .57821 .79473 .57931 .79659 .57863 .79578 .57759 Mtetra
.649 .75 .923 r
.79578 .57759 .79659 .57863 .79845 .57803 .79765 .57705 Mtetra
.626 .754 .939 r
.79765 .57705 .79845 .57803 .80033 .57754 .79953 .5766 Mtetra
.605 .755 .95 r
.79953 .5766 .80033 .57754 .80221 .5771 .80142 .57622 Mtetra
.486 .715 .972 r
.80142 .57622 .80221 .5771 .80412 .57696 .80334 .57618 Mtetra
.336 .659 .972 r
.80334 .57618 .80412 .57696 .80605 .57708 .80528 .57642 Mtetra
.567 .812 .991 r
.80528 .57642 .80605 .57708 .80794 .57661 .80717 .57605 Mtetra
.908 .894 .803 r
.80717 .57605 .80794 .57661 .80966 .57424 .80891 .57378 Mtetra
.99 .75 .475 r
.80891 .57378 .80966 .57424 .8104 .56014 .80978 .56121 Mtetra
.978 .682 .364 r
.80978 .56121 .8104 .56014 .79561 .36351 .79484 .36233 Mtetra
.91 .774 .698 r
.79484 .36233 .79561 .36351 .79714 .36024 .79637 .359 Mtetra
.685 .713 .87 r
.79637 .359 .79714 .36024 .79888 .35948 .79812 .35831 Mtetra
.553 .667 .912 r
.79812 .35831 .79888 .35948 .80068 .35928 .79992 .3582 Mtetra
.517 .668 .931 r
.79992 .3582 .80068 .35928 .80248 .35919 .80173 .35819 Mtetra
.642 .744 .923 r
.80173 .35819 .80248 .35919 .80426 .35872 .80351 .35771 Mtetra
.658 .749 .917 r
.80351 .35771 .80426 .35872 .80603 .35822 .80528 .35717 Mtetra
.694 .753 .897 r
.80528 .35717 .80603 .35822 .80779 .35763 .80703 .35645 Mtetra
.729 .74 .861 r
.80703 .35645 .80779 .35763 .80955 .35693 .80877 .35551 Mtetra
.684 .683 .843 r
.80877 .35551 .80955 .35693 .81131 .35628 .81052 .35478 Mtetra
.562 .614 .862 r
.81052 .35478 .81131 .35628 .81309 .35581 .81234 .35471 Mtetra
0 .292 .79 r
.81234 .35471 .81309 .35581 .8149 .35571 .81429 .35615 Mtetra
.823 .363 .128 r
.81429 .35615 .8149 .35571 .81673 .35569 .8164 .35926 Mtetra
.81 .468 .409 r
.8164 .35926 .81673 .35569 .81852 .35538 .81882 .36559 Mtetra
.501 .263 .485 r
.81882 .36559 .81852 .35538 .82026 .35434 .82051 .36408 Mtetra
.477 .243 .479 r
.82051 .36408 .82026 .35434 .82202 .35367 .82215 .36199 Mtetra
.667 .384 .481 r
.82215 .36199 .82202 .35367 .82391 .35433 .82437 .36602 Mtetra
.966 .656 .38 r
.82437 .36602 .82391 .35433 .82652 .36249 .84435 .55801 Mtetra
.563 .346 .543 r
.84435 .55801 .82652 .36249 .8473 .56126 .84667 .56183 Mtetra
.658 .143 .005 r
.84667 .56183 .8473 .56126 .84955 .56435 .84876 .56323 Mtetra
.588 .711 .928 r
.84876 .56323 .84955 .56435 .8515 .56427 .85069 .56295 Mtetra
.669 .709 .877 r
.85069 .56295 .8515 .56427 .8534 .56356 .85259 .56229 Mtetra
.651 .71 .89 r
.85259 .56229 .8534 .56356 .85529 .56282 .8545 .56174 Mtetra
.435 .641 .943 r
.8545 .56174 .85529 .56282 .85726 .56289 .85649 .56195 Mtetra
.587 .753 .957 r
.85649 .56195 .85726 .56289 .85918 .56243 .85842 .56162 Mtetra
.847 .857 .85 r
.85842 .56162 .85918 .56243 .86097 .56063 .86022 .5599 Mtetra
.988 .767 .513 r
.86022 .5599 .86097 .56063 .86206 .55189 .8613 .55094 Mtetra
.977 .675 .344 r
.8613 .55094 .86206 .55189 .84365 .3491 .84288 .34767 Mtetra
.919 .751 .657 r
.84288 .34767 .84365 .3491 .84507 .34487 .84431 .34351 Mtetra
.734 .716 .834 r
.84431 .34351 .84507 .34487 .84679 .34362 .84605 .34246 Mtetra
.591 .69 .911 r
.84605 .34246 .84679 .34362 .84861 .34326 .84787 .3422 Mtetra
.354 .584 .93 r
.84787 .3422 .84861 .34326 .85053 .34395 .84977 .34264 Mtetra
.111 .373 .834 r
.84977 .34264 .85053 .34395 .85277 .34769 .85176 .34394 Mtetra
.19 .217 .659 r
.85176 .34394 .85277 .34769 .87552 .5486 .85396 .34721 Mtetra
.136 .05 .485 r
.85396 .34721 .87552 .5486 .87814 .55475 .87623 .5427 Mtetra
.291 .198 .574 r
.87623 .5427 .87814 .55475 .8802 .55548 .87906 .55087 Mtetra
.363 .315 .67 r
.87906 .55087 .8802 .55548 .88218 .55537 .8813 .55331 Mtetra
.393 .462 .812 r
.8813 .55331 .88218 .55537 .88411 .55486 .88339 .55421 Mtetra
.586 .829 .991 r
.88339 .55421 .88411 .55486 .88604 .55431 .88533 .55375 Mtetra
.689 .892 .971 r
.88533 .55375 .88604 .55431 .88796 .55365 .88723 .55292 Mtetra
.714 .857 .95 r
.88723 .55292 .88796 .55365 .88989 .55303 .88913 .55205 Mtetra
.512 .707 .959 r
.88913 .55205 .88989 .55303 .89188 .55301 .89112 .55197 Mtetra
.583 .729 .943 r
.89112 .55197 .89188 .55301 .89383 .55262 .89308 .55168 Mtetra
.708 .804 .925 r
.89308 .55168 .89383 .55262 .89569 .55136 .89499 .55084 Mtetra
.934 .91 .772 r
.89499 .55084 .89569 .55136 .89711 .54616 .8967 .54825 Mtetra
0 0 0 r
.8967 .54825 .89711 .54616 .87661 .34362 .89816 .54338 Mtetra
.135 .045 .481 r
.89816 .54338 .87661 .34362 .8777 .33653 .87807 .34523 Mtetra
.151 .004 .412 r
.87807 .34523 .8777 .33653 .87938 .3348 .87902 .3369 Mtetra
0 0 .094 r
.87902 .3369 .87938 .3348 .88115 .33382 .88054 .33371 Mtetra
.875 .991 .81 r
.88054 .33371 .88115 .33382 .88296 .33324 .8822 .33182 Mtetra
.673 .684 .852 r
.8822 .33182 .88296 .33324 .88478 .33269 .88401 .33116 Mtetra
.608 .635 .852 r
.88401 .33116 .88478 .33269 .88661 .33226 .88586 .33085 Mtetra
.573 .637 .876 r
.88586 .33085 .88661 .33226 .88845 .33185 .88773 .33071 Mtetra
.651 .723 .901 r
.88773 .33071 .88845 .33185 .89027 .33126 .88955 .33018 Mtetra
.667 .744 .908 r
.88955 .33018 .89027 .33126 .89208 .33062 .89137 .32958 Mtetra
.684 .76 .909 r
.89137 .32958 .89208 .33062 .89389 .32994 .89318 .3289 Mtetra
.756 .785 .877 r
.89318 .3289 .89389 .32994 .89565 .32883 .89494 .32783 Mtetra
.72 .78 .9 r
.89494 .32783 .89565 .32883 .89745 .32806 .89673 .32696 Mtetra
.633 .725 .914 r
.89673 .32696 .89745 .32806 .89932 .3279 .89857 .32651 Mtetra
.568 .771 .974 r
.30843 .51557 .30939 .51622 .31076 .51737 .30989 .51533 Mtetra
.521 .51 .785 r
.30989 .51533 .31076 .51737 .31202 .52026 .31133 .51554 Mtetra
.468 .361 .649 r
.31133 .51554 .31202 .52026 .30182 .7046 .31271 .5166 Mtetra
.54 .331 .546 r
.31271 .5166 .30182 .7046 .30274 .71425 .31363 .52499 Mtetra
0 0 .26 r
.31363 .52499 .30274 .71425 .30412 .71679 .30326 .71367 Mtetra
0 0 .466 r
.30326 .71367 .30412 .71679 .30559 .71793 .30459 .71701 Mtetra
.292 .593 .947 r
.30459 .71701 .30559 .71793 .30711 .71826 .30611 .71737 Mtetra
.625 .741 .931 r
.30611 .71737 .30711 .71826 .30867 .71802 .30768 .717 Mtetra
.722 .738 .864 r
.30768 .717 .30867 .71802 .31026 .71721 .30927 .71617 Mtetra
.708 .732 .869 r
.30927 .71617 .31026 .71721 .31194 .71505 .31086 .71543 Mtetra
.699 .983 .842 r
.31086 .71543 .31194 .71505 .31372 .7111 .31248 .71423 Mtetra
.128 0 .176 r
.31248 .71423 .31372 .7111 .32596 .53074 .31415 .71215 Mtetra
.54 .328 .54 r
.31415 .71215 .32596 .53074 .32836 .51493 .3162 .70371 Mtetra
0 0 .252 r
.3162 .70371 .32836 .51493 .33002 .51161 .32894 .51305 Mtetra
.967 .925 .601 r
.32894 .51305 .33002 .51161 .33159 .50969 .33065 .50893 Mtetra
.782 .784 .855 r
.33065 .50893 .33159 .50969 .3331 .50887 .33218 .50781 Mtetra
.653 .702 .882 r
.33218 .50781 .3331 .50887 .33459 .50842 .33366 .50737 Mtetra
.575 .678 .91 r
.33366 .50737 .33459 .50842 .33607 .5081 .33514 .50722 Mtetra
.754 .758 .856 r
.33514 .50722 .33607 .5081 .3376 .50703 .33666 .50625 Mtetra
.722 .777 .896 r
.33666 .50625 .3376 .50703 .33911 .50621 .33816 .50551 Mtetra
.504 .739 .978 r
.33816 .50551 .33911 .50621 .34059 .50605 .33964 .50542 Mtetra
.911 .517 .243 r
.33964 .50542 .34059 .50605 .34186 .50949 .34091 .50898 Mtetra
.94 .683 .519 r
.34091 .50898 .34186 .50949 .33275 .70381 .33175 .70309 Mtetra
.934 .589 .349 r
.33175 .70309 .33275 .70381 .33398 .70991 .33299 .70895 Mtetra
.226 .546 .929 r
.33299 .70895 .33398 .70991 .33551 .71037 .33452 .70943 Mtetra
.681 .748 .902 r
.33452 .70943 .33551 .71037 .33711 .70973 .33612 .70884 Mtetra
.756 .77 .865 r
.33612 .70884 .33711 .70973 .33873 .70866 .33774 .70782 Mtetra
.499 .712 .966 r
.33774 .70782 .33873 .70866 .34029 .70869 .3393 .70778 Mtetra
.557 .717 .948 r
.3393 .70778 .34029 .70869 .34186 .70862 .34088 .70762 Mtetra
.721 .744 .87 r
.34088 .70762 .34186 .70862 .34347 .70789 .34249 .7068 Mtetra
.889 .73 .68 r
.34249 .7068 .34347 .70789 .34525 .70377 .34428 .7025 Mtetra
.941 .687 .525 r
.34428 .7025 .34525 .70377 .35661 .50976 .35572 .50809 Mtetra
.894 .692 .621 r
.35572 .50809 .35661 .50976 .35851 .50155 .35758 .50058 Mtetra
.81 .75 .797 r
.35758 .50058 .35851 .50155 .36007 .49993 .35914 .49902 Mtetra
.653 .735 .909 r
.35914 .49902 .36007 .49993 .36157 .49947 .36065 .49857 Mtetra
.511 .69 .949 r
.36065 .49857 .36157 .49947 .36306 .49943 .36213 .49854 Mtetra
.656 .741 .912 r
.36213 .49854 .36306 .49943 .36457 .49884 .36364 .49809 Mtetra
.68 .778 .925 r
.36364 .49809 .36457 .49884 .36609 .49822 .36515 .49753 Mtetra
.644 .787 .95 r
.36515 .49753 .36609 .49822 .36759 .49793 .36666 .49709 Mtetra
.618 .742 .935 r
.36666 .49709 .36759 .49793 .36903 .49877 .36816 .49677 Mtetra
.561 .537 .785 r
.36816 .49677 .36903 .49877 .37041 .50123 .36965 .49678 Mtetra
.501 .391 .66 r
.36965 .49678 .37041 .50123 .37121 .51618 .37111 .4975 Mtetra
.441 .272 .555 r
.37111 .4975 .37121 .51618 .36452 .69582 .37236 .50257 Mtetra
0 0 .299 r
.37236 .50257 .36452 .69582 .36597 .6988 .36513 .69468 Mtetra
0 0 .474 r
.36513 .69468 .36597 .6988 .36749 .70015 .36653 .69891 Mtetra
0 .301 .796 r
.36653 .69891 .36749 .70015 .36905 .7008 .36806 .70002 Mtetra
.504 .731 .975 r
.36806 .70002 .36905 .7008 .37064 .70077 .36966 .69993 Mtetra
.757 .782 .874 r
.36966 .69993 .37064 .70077 .37226 .69996 .37129 .69892 Mtetra
.886 .741 .696 r
.37129 .69892 .37226 .69996 .374 .69639 .37304 .69517 Mtetra
.944 .688 .519 r
.37304 .69517 .374 .69639 .38369 .50554 .38285 .5027 Mtetra
.883 .662 .6 r
.38285 .5027 .38369 .50554 .38571 .49337 .38479 .49236 Mtetra
.83 .747 .772 r
.38479 .49236 .38571 .49337 .38729 .4914 .38637 .49045 Mtetra
.655 .729 .904 r
.38637 .49045 .38729 .4914 .38881 .49094 .38789 .48999 Mtetra
.493 .671 .943 r
.38789 .48999 .38881 .49094 .39031 .49098 .38939 .49002 Mtetra
.589 .705 .924 r
.38939 .49002 .39031 .49098 .39182 .49078 .39091 .4898 Mtetra
.645 .721 .904 r
.39091 .4898 .39182 .49078 .39334 .49037 .39243 .48939 Mtetra
.65 .721 .9 r
.39243 .48939 .39334 .49037 .39486 .48994 .39395 .48895 Mtetra
.721 .739 .865 r
.39395 .48895 .39486 .48994 .3964 .48926 .39549 .48816 Mtetra
.708 .716 .854 r
.39549 .48816 .3964 .48926 .39793 .48858 .39703 .48742 Mtetra
.607 .67 .885 r
.39703 .48742 .39793 .48858 .39945 .48819 .39855 .48716 Mtetra
.664 .184 0 r
.39855 .48716 .39945 .48819 .40094 .48895 .39998 .48911 Mtetra
.946 .682 .505 r
.39998 .48911 .40094 .48895 .40236 .49131 .39493 .66538 Mtetra
.597 .374 .549 r
.39493 .66538 .40236 .49131 .40362 .49816 .39569 .68786 Mtetra
.56 .344 .544 r
.39569 .68786 .40362 .49816 .39869 .67715 .39724 .68936 Mtetra
.539 .296 .496 r
.39724 .68936 .39869 .67715 .40031 .67645 .39887 .68895 Mtetra
.521 .283 .494 r
.39887 .68895 .40031 .67645 .40227 .6664 .40051 .68797 Mtetra
.547 .317 .518 r
.40051 .68797 .40227 .6664 .40381 .66805 .40213 .68758 Mtetra
.549 .317 .516 r
.40213 .68758 .40381 .66805 .40527 .67233 .40375 .68737 Mtetra
.529 .294 .503 r
.40375 .68737 .40527 .67233 .41258 .50326 .4054 .68641 Mtetra
.548 .334 .542 r
.4054 .68641 .41258 .50326 .41458 .48921 .40717 .6816 Mtetra
0 0 .305 r
.40717 .6816 .41458 .48921 .41626 .48449 .41524 .48697 Mtetra
.899 .863 .419 r
.41524 .48697 .41626 .48449 .41787 .48179 .41694 .48138 Mtetra
.878 .853 .814 r
.41694 .48138 .41787 .48179 .41943 .48049 .41853 .47951 Mtetra
.69 .736 .886 r
.41853 .47951 .41943 .48049 .42097 .47992 .42007 .47889 Mtetra
.6 .696 .911 r
.42007 .47889 .42097 .47992 .42251 .47958 .4216 .47864 Mtetra
.622 .723 .919 r
.4216 .47864 .42251 .47958 .42404 .47919 .42314 .47831 Mtetra
.661 .749 .915 r
.42314 .47831 .42404 .47919 .42559 .47869 .42468 .47782 Mtetra
.659 .75 .917 r
.42468 .47782 .42559 .47869 .42713 .4782 .42622 .47734 Mtetra
.659 .753 .919 r
.42622 .47734 .42713 .4782 .42867 .47771 .42777 .47685 Mtetra
.659 .755 .921 r
.42777 .47685 .42867 .47771 .43022 .47722 .42931 .47637 Mtetra
.658 .757 .923 r
.42931 .47637 .43022 .47722 .43176 .47673 .43086 .47589 Mtetra
.657 .758 .924 r
.43086 .47589 .43176 .47673 .43331 .47624 .4324 .47541 Mtetra
.655 .761 .927 r
.4324 .47541 .43331 .47624 .43485 .47575 .43395 .47494 Mtetra
.65 .763 .932 r
.43395 .47494 .43485 .47575 .4364 .4753 .4355 .47449 Mtetra
.635 .761 .938 r
.4355 .47449 .4364 .4753 .43795 .47492 .43704 .47409 Mtetra
.624 .751 .938 r
.43704 .47409 .43795 .47492 .43949 .47461 .43859 .47372 Mtetra
.626 .74 .929 r
.43859 .47372 .43949 .47461 .44104 .4743 .44014 .47336 Mtetra
.639 .731 .915 r
.44014 .47336 .44104 .4743 .44258 .47392 .44169 .47296 Mtetra
.653 .729 .905 r
.44169 .47296 .44258 .47392 .44414 .47346 .44324 .4725 Mtetra
.662 .734 .903 r
.44324 .4725 .44414 .47346 .44569 .47293 .44479 .47201 Mtetra
.675 .744 .902 r
.44479 .47201 .44569 .47293 .44725 .47232 .44635 .47145 Mtetra
.686 .761 .909 r
.44635 .47145 .44725 .47232 .44881 .47164 .44791 .47086 Mtetra
.687 .782 .923 r
.44791 .47086 .44881 .47164 .45037 .47095 .44947 .47026 Mtetra
.676 .8 .941 r
.44947 .47026 .45037 .47095 .45193 .47034 .45103 .4697 Mtetra
.66 .811 .955 r
.45103 .4697 .45193 .47034 .45349 .46981 .45259 .46918 Mtetra
.654 .814 .96 r
.45259 .46918 .45349 .46981 .45504 .4693 .45414 .46868 Mtetra
.653 .816 .962 r
.45414 .46868 .45504 .4693 .4566 .46879 .4557 .46818 Mtetra
.654 .818 .962 r
.4557 .46818 .4566 .46879 .45816 .46827 .45727 .46767 Mtetra
.653 .821 .964 r
.45727 .46767 .45816 .46827 .45973 .46776 .45883 .46717 Mtetra
.67 .827 .959 r
.45883 .46717 .45973 .46776 .46129 .46713 .46039 .46661 Mtetra
.675 .847 .965 r
.46039 .46661 .46129 .46713 .46286 .46645 .46196 .46602 Mtetra
.623 .86 .988 r
.46196 .46602 .46286 .46645 .46442 .46603 .46352 .46553 Mtetra
.463 .785 .999 r
.46352 .46553 .46442 .46603 .46597 .46649 .46508 .46539 Mtetra
.394 .589 .922 r
.46508 .46539 .46597 .46649 .46749 .46868 .46663 .46571 Mtetra
.503 .442 .721 r
.46663 .46571 .46749 .46868 .46894 .47482 .46818 .4662 Mtetra
.556 .387 .608 r
.46818 .4662 .46894 .47482 .46743 .66123 .46974 .46639 Mtetra
.559 .347 .549 r
.46974 .46639 .46743 .66123 .46908 .66182 .47131 .46592 Mtetra
.47131 .46592 .46908 .66182 .47076 .65994 .47289 .46524 Mtetra
.47289 .46524 .47076 .65994 .47248 .65596 .47446 .46433 Mtetra
.56 .348 .549 r
.47446 .46433 .47248 .65596 .47422 .64973 .47604 .46337 Mtetra
.558 .347 .549 r
.47604 .46337 .47422 .64973 .47585 .65176 .47761 .46303 Mtetra
.554 .343 .549 r
.47761 .46303 .47585 .65176 .47739 .66054 .47916 .46493 Mtetra
0 0 .358 r
.47916 .46493 .47739 .66054 .47898 .66545 .47813 .65823 Mtetra
0 0 .44 r
.47813 .65823 .47898 .66545 .48062 .66773 .47969 .66579 Mtetra
0 .198 .718 r
.47969 .66579 .48062 .66773 .48228 .66853 .48134 .6676 Mtetra
.568 .722 .946 r
.48134 .6676 .48228 .66853 .48395 .66821 .48301 .66739 Mtetra
.693 .788 .923 r
.48301 .66739 .48395 .66821 .48563 .66762 .4847 .66672 Mtetra
.698 .771 .908 r
.4847 .66672 .48563 .66762 .48731 .66707 .48638 .66602 Mtetra
.627 .72 .913 r
.48638 .66602 .48731 .66707 .48899 .66676 .48806 .66563 Mtetra
.63 .704 .899 r
.48806 .66563 .48899 .66676 .49067 .66646 .48974 .66524 Mtetra
.637 .691 .884 r
.48974 .66524 .49067 .66646 .49235 .6661 .49142 .66482 Mtetra
.646 .684 .871 r
.49142 .66482 .49235 .6661 .49403 .66566 .4931 .66435 Mtetra
.652 .681 .865 r
.4931 .66435 .49403 .66566 .49571 .66517 .49478 .66385 Mtetra
.66 .683 .861 r
.49478 .66385 .49571 .66517 .4974 .66461 .49647 .66331 Mtetra
.669 .688 .86 r
.49647 .66331 .4974 .66461 .49909 .66398 .49816 .66272 Mtetra
.671 .695 .864 r
.49816 .66272 .49909 .66398 .50077 .66334 .49985 .66212 Mtetra
.659 .699 .876 r
.49985 .66212 .50077 .66334 .50246 .66283 .50153 .66159 Mtetra
.633 .687 .883 r
.50153 .66159 .50246 .66283 .50415 .66254 .50322 .66119 Mtetra
.649 .674 .86 r
.50322 .66119 .50415 .66254 .50584 .66203 .50491 .6607 Mtetra
.698 .696 .844 r
.50491 .6607 .50584 .66203 .50753 .66077 .50661 .65993 Mtetra
.797 .801 .855 r
.50661 .65993 .50753 .66077 .50924 .65765 .5083 .6586 Mtetra
0 0 0 r
.5083 .6586 .50924 .65765 .51095 .65169 .51 .65708 Mtetra
.44 .171 .409 r
.51 .65708 .51095 .65169 .5133 .46298 .5117 .65572 Mtetra
.556 .341 .543 r
.5117 .65572 .5133 .46298 .51491 .46029 .51339 .65512 Mtetra
.51339 .65512 .51491 .46029 .51651 .46096 .51508 .65477 Mtetra
.557 .341 .543 r
.51508 .65477 .51651 .46096 .5181 .46348 .51678 .65447 Mtetra
.556 .341 .543 r
.51678 .65447 .5181 .46348 .5197 .46329 .51848 .65401 Mtetra
.51848 .65401 .5197 .46329 .52131 .46319 .52018 .65355 Mtetra
.52018 .65355 .52131 .46319 .52291 .46307 .52188 .65309 Mtetra
.52188 .65309 .52291 .46307 .52452 .46273 .52358 .65262 Mtetra
.52358 .65262 .52452 .46273 .52613 .46232 .52528 .65214 Mtetra
.52528 .65214 .52613 .46232 .52773 .46187 .52698 .65166 Mtetra
.52698 .65166 .52773 .46187 .52934 .4614 .52868 .65118 Mtetra
.52868 .65118 .52934 .4614 .53095 .46091 .53039 .6507 Mtetra
.53039 .6507 .53095 .46091 .53257 .46041 .53209 .65021 Mtetra
.53209 .65021 .53257 .46041 .53418 .45991 .5338 .64973 Mtetra
.5338 .64973 .53418 .45991 .53579 .45941 .53551 .64925 Mtetra
.53551 .64925 .53579 .45941 .53741 .45891 .53722 .64876 Mtetra
.53722 .64876 .53741 .45891 .53902 .45842 .53893 .64827 Mtetra
.53893 .64827 .53902 .45842 .54064 .45791 .54064 .64779 Mtetra
.54064 .64779 .54064 .45791 .54225 .45737 .54235 .6473 Mtetra
.54235 .6473 .54225 .45737 .54387 .45681 .54406 .64681 Mtetra
.54406 .64681 .54387 .45681 .54549 .45619 .54578 .64631 Mtetra
.54578 .64631 .54549 .45619 .54711 .45544 .54749 .64581 Mtetra
.54749 .64581 .54711 .45544 .54873 .45449 .54921 .6453 Mtetra
.54921 .6453 .54873 .45449 .55034 .45356 .55093 .64478 Mtetra
.55093 .64478 .55034 .45356 .55196 .45205 .55264 .64424 Mtetra
.556 .34 .543 r
.55264 .64424 .55196 .45205 .55355 .44844 .55436 .64354 Mtetra
.556 .341 .543 r
.55436 .64354 .55355 .44844 .55517 .4477 .55608 .64299 Mtetra
.557 .341 .543 r
.55608 .64299 .55517 .4477 .55691 .45904 .55781 .64281 Mtetra
.558 .342 .543 r
.55781 .64281 .55691 .45904 .5604 .64023 .55954 .64338 Mtetra
.569 .243 .376 r
.55954 .64338 .5604 .64023 .56217 .64376 .56127 .64387 Mtetra
.237 0 0 r
.56127 .64387 .56217 .64376 .56392 .64529 .56301 .64409 Mtetra
.626 .695 .893 r
.56301 .64409 .56392 .64529 .56565 .6451 .56474 .6437 Mtetra
.656 .673 .854 r
.56474 .6437 .56565 .6451 .56737 .64453 .56646 .64316 Mtetra
.668 .683 .855 r
.56646 .64316 .56737 .64453 .5691 .64378 .56819 .64256 Mtetra
.651 .7 .882 r
.56819 .64256 .5691 .64378 .57083 .64327 .56992 .64206 Mtetra
.647 .7 .885 r
.56992 .64206 .57083 .64327 .57256 .64278 .57165 .64158 Mtetra
.64 .7 .89 r
.57165 .64158 .57256 .64278 .57429 .64233 .57339 .64113 Mtetra
.621 .693 .895 r
.57339 .64113 .57429 .64233 .57603 .64201 .57512 .64076 Mtetra
.62 .684 .889 r
.57512 .64076 .57603 .64201 .57777 .6417 .57686 .64041 Mtetra
.623 .677 .881 r
.57686 .64041 .57777 .6417 .5795 .64137 .5786 .64004 Mtetra
.635 .676 .872 r
.5786 .64004 .5795 .64137 .58124 .64095 .58034 .63961 Mtetra
.642 .679 .869 r
.58034 .63961 .58124 .64095 .58298 .64047 .58207 .63915 Mtetra
.649 .684 .87 r
.58207 .63915 .58298 .64047 .58472 .63994 .58381 .63865 Mtetra
.587 .665 .892 r
.58381 .63865 .58472 .63994 .58646 .63951 .58556 .63844 Mtetra
.656 .732 .905 r
.58556 .63844 .58646 .63951 .5882 .63889 .5873 .63792 Mtetra
.764 .78 .866 r
.5873 .63792 .5882 .63889 .58993 .63791 .58903 .63678 Mtetra
.911 .756 .675 r
.58903 .63678 .58993 .63791 .59164 .63545 .5907 .63253 Mtetra
.964 .688 .462 r
.5907 .63253 .59164 .63545 .59331 .6316 .58869 .43983 Mtetra
.579 .363 .551 r
.58869 .43983 .59331 .6316 .59491 .62377 .5901 .42765 Mtetra
.56 .348 .549 r
.5901 .42765 .59491 .62377 .59663 .62249 .59173 .42642 Mtetra
.558 .347 .549 r
.59173 .42642 .59663 .62249 .59839 .62303 .59337 .42603 Mtetra
.558 .346 .549 r
.59337 .42603 .59839 .62303 .60011 .62126 .59502 .4259 Mtetra
.561 .348 .549 r
.59502 .4259 .60011 .62126 .59758 .42993 .59664 .42439 Mtetra
.644 .475 .64 r
.59664 .42439 .59758 .42993 .59913 .4251 .59827 .42292 Mtetra
.712 .61 .742 r
.59827 .42292 .59913 .4251 .60073 .42246 .59989 .42168 Mtetra
.698 .799 .927 r
.59989 .42168 .60073 .42246 .60236 .42153 .60154 .421 Mtetra
.628 .846 .983 r
.60154 .421 .60236 .42153 .60401 .42105 .60318 .4205 Mtetra
.59 .83 .99 r
.60318 .4205 .60401 .42105 .60566 .4208 .60483 .42011 Mtetra
.622 .798 .967 r
.60483 .42011 .60566 .4208 .60731 .42046 .60648 .41968 Mtetra
.626 .778 .954 r
.60648 .41968 .60731 .42046 .60897 .42013 .60814 .41927 Mtetra
.635 .758 .937 r
.60814 .41927 .60897 .42013 .61062 .4198 .60979 .41884 Mtetra
.655 .742 .914 r
.60979 .41884 .61062 .4198 .61227 .41936 .61144 .41834 Mtetra
.664 .734 .902 r
.61144 .41834 .61227 .41936 .61393 .41885 .61309 .41781 Mtetra
.672 .732 .895 r
.61309 .41781 .61393 .41885 .61558 .41828 .61474 .41724 Mtetra
.684 .736 .89 r
.61474 .41724 .61558 .41828 .61723 .4176 .6164 .41661 Mtetra
.688 .746 .896 r
.6164 .41661 .61723 .4176 .61888 .4169 .61805 .41596 Mtetra
.687 .758 .906 r
.61805 .41596 .61888 .4169 .62053 .41622 .6197 .41532 Mtetra
.673 .764 .919 r
.6197 .41532 .62053 .41622 .62218 .41564 .62136 .41475 Mtetra
.666 .764 .923 r
.62136 .41475 .62218 .41564 .62384 .4151 .62301 .4142 Mtetra
.661 .761 .924 r
.62301 .4142 .62384 .4151 .6255 .41458 .62467 .41368 Mtetra
.662 .759 .922 r
.62467 .41368 .6255 .41458 .62716 .41404 .62633 .41315 Mtetra
.658 .76 .925 r
.62633 .41315 .62716 .41404 .62882 .41352 .62799 .41263 Mtetra
.652 .761 .929 r
.62799 .41263 .62882 .41352 .63048 .41302 .62966 .41214 Mtetra
.635 .756 .935 r
.62966 .41214 .63048 .41302 .63215 .41263 .63132 .41171 Mtetra
.631 .746 .931 r
.63132 .41171 .63215 .41263 .63381 .41227 .63299 .4113 Mtetra
.634 .736 .922 r
.63299 .4113 .63381 .41227 .63548 .41189 .63466 .41088 Mtetra
.648 .731 .91 r
.63466 .41088 .63548 .41189 .63715 .41142 .63633 .41041 Mtetra
.659 .735 .906 r
.63633 .41041 .63715 .41142 .63882 .41088 .638 .40989 Mtetra
.669 .745 .907 r
.638 .40989 .63882 .41088 .64048 .41028 .63966 .40933 Mtetra
.708 .766 .898 r
.63966 .40933 .64048 .41028 .64214 .40933 .64132 .40859 Mtetra
.706 .814 .932 r
.64132 .40859 .64214 .40933 .64379 .40848 .64299 .40786 Mtetra
.658 .834 .968 r
.64299 .40786 .64379 .40848 .64547 .40801 .64466 .4073 Mtetra
.585 .783 .974 r
.64466 .4073 .64547 .40801 .64719 .40883 .64634 .40697 Mtetra
.538 .548 .814 r
.64634 .40697 .64719 .40883 .64898 .4114 .64803 .40708 Mtetra
.486 .39 .672 r
.64803 .40708 .64898 .4114 .65772 .59261 .64976 .40802 Mtetra
.545 .337 .548 r
.64976 .40802 .65772 .59261 .6603 .6124 .65172 .41468 Mtetra
.023 0 .425 r
.65172 .41468 .6603 .6124 .66222 .61533 .66123 .61135 Mtetra
.057 .118 .611 r
.66123 .61135 .66222 .61533 .66408 .6166 .66319 .61513 Mtetra
.371 .523 .879 r
.66319 .61513 .66408 .6166 .6659 .61685 .66503 .61572 Mtetra
.636 .718 .907 r
.66503 .61572 .6659 .61685 .6677 .61647 .66682 .61527 Mtetra
.727 .738 .86 r
.66682 .61527 .6677 .61647 .66947 .61552 .6686 .61432 Mtetra
.766 .749 .837 r
.6686 .61432 .66947 .61552 .67119 .61322 .67036 .61306 Mtetra
.831 .972 .888 r
.67036 .61306 .67119 .61322 .67282 .60905 .67211 .61156 Mtetra
.229 0 .207 r
.67211 .61156 .67282 .60905 .6741 .59681 .67386 .60991 Mtetra
.538 .298 .499 r
.67386 .60991 .6741 .59681 .66782 .41361 .67565 .60942 Mtetra
.557 .341 .543 r
.67565 .60942 .66782 .41361 .66957 .41435 .67746 .6092 Mtetra
.556 .34 .543 r
.67746 .6092 .66957 .41435 .6713 .41457 .67925 .60831 Mtetra
.548 .334 .542 r
.67925 .60831 .6713 .41457 .67261 .40575 .68081 .60256 Mtetra
.022 0 .42 r
.68081 .60256 .67261 .40575 .67412 .40132 .67346 .40343 Mtetra
.749 .759 .25 r
.67346 .40343 .67412 .40132 .67571 .3987 .67493 .39818 Mtetra
.86 .885 .854 r
.67493 .39818 .67571 .3987 .67738 .39761 .67657 .39657 Mtetra
.655 .731 .905 r
.67657 .39657 .67738 .39761 .67907 .39719 .67826 .39606 Mtetra
.567 .675 .912 r
.67826 .39606 .67907 .39719 .68078 .39697 .67997 .39591 Mtetra
.636 .719 .907 r
.67997 .39591 .68078 .39697 .68247 .39645 .68167 .39548 Mtetra
.68 .756 .909 r
.68167 .39548 .68247 .39645 .68416 .39573 .68336 .39486 Mtetra
.682 .78 .925 r
.68336 .39486 .68416 .39573 .68584 .395 .68505 .39423 Mtetra
.688 .806 .938 r
.68505 .39423 .68584 .395 .68752 .3942 .68674 .39358 Mtetra
.668 .84 .965 r
.68674 .39358 .68752 .3942 .68921 .39351 .68843 .39296 Mtetra
.612 .844 .987 r
.68843 .39296 .68921 .39351 .69092 .39314 .69014 .39249 Mtetra
.449 .741 .99 r
.69014 .39249 .69092 .39314 .69269 .39397 .69186 .39244 Mtetra
.47 .555 .86 r
.69186 .39244 .69269 .39397 .69455 .39659 .69361 .39276 Mtetra
.526 .43 .689 r
.69361 .39276 .69455 .39659 .69679 .40615 .69536 .39322 Mtetra
.573 .386 .59 r
.69536 .39322 .69679 .40615 .70849 .59127 .69707 .39278 Mtetra
.559 .347 .549 r
.69707 .39278 .70849 .59127 .71027 .5901 .69876 .39193 Mtetra
.558 .346 .549 r
.69876 .39193 .71027 .5901 .71205 .58903 .70048 .39165 Mtetra
.552 .341 .549 r
.70048 .39165 .71205 .58903 .71422 .595 .70241 .39518 Mtetra
.051 0 .442 r
.70241 .39518 .71422 .595 .71628 .59885 .71522 .59397 Mtetra
.009 .061 .568 r
.71522 .59397 .71628 .59885 .71824 .60078 .71736 .59913 Mtetra
.247 .421 .838 r
.71736 .59913 .71824 .60078 .72012 .60128 .71928 .60022 Mtetra
.594 .72 .932 r
.71928 .60022 .72012 .60128 .72196 .60101 .72112 .59992 Mtetra
.692 .751 .897 r
.72112 .59992 .72196 .60101 .72379 .60046 .72293 .59919 Mtetra
.687 .716 .871 r
.72293 .59919 .72379 .60046 .72561 .59982 .72475 .59846 Mtetra
.67 .695 .865 r
.72475 .59846 .72561 .59982 .72743 .59914 .72657 .59782 Mtetra
.674 .702 .868 r
.72657 .59782 .72743 .59914 .72925 .59844 .72839 .59716 Mtetra
.651 .701 .883 r
.72839 .59716 .72925 .59844 .73108 .59798 .73023 .59663 Mtetra
.637 .682 .876 r
.73023 .59663 .73108 .59798 .73293 .59761 .73206 .59617 Mtetra
.656 .676 .857 r
.73206 .59617 .73293 .59761 .73475 .59695 .73389 .59559 Mtetra
.726 .717 .842 r
.73389 .59559 .73475 .59695 .7365 .59511 .7357 .59458 Mtetra
.83 .903 .89 r
.7357 .59458 .7365 .59511 .73814 .59136 .73748 .59312 Mtetra
.093 0 .06 r
.73748 .59312 .73814 .59136 .73947 .58284 .73925 .5915 Mtetra
.501 .252 .469 r
.73925 .5915 .73947 .58284 .72923 .39243 .74104 .59031 Mtetra
.556 .341 .543 r
.74104 .59031 .72923 .39243 .7309 .39099 .74288 .58975 Mtetra
.74288 .58975 .7309 .39099 .73275 .39227 .74473 .58941 Mtetra
.74473 .58941 .73275 .39227 .73462 .39386 .74658 .58901 Mtetra
.74658 .58901 .73462 .39386 .73637 .39366 .74842 .58852 Mtetra
.74842 .58852 .73637 .39366 .73813 .39353 .75027 .58802 Mtetra
.75027 .58802 .73813 .39353 .73989 .39331 .75211 .58752 Mtetra
.75211 .58752 .73989 .39331 .74164 .39294 .75396 .58701 Mtetra
.75396 .58701 .74164 .39294 .74338 .39248 .75581 .58649 Mtetra
.75581 .58649 .74338 .39248 .74512 .39197 .75766 .58596 Mtetra
.75766 .58596 .74512 .39197 .74686 .3914 .75951 .58544 Mtetra
.75951 .58544 .74686 .3914 .74859 .39074 .76136 .5849 Mtetra
.76136 .5849 .74859 .39074 .75032 .39001 .76321 .58437 Mtetra
.76321 .58437 .75032 .39001 .75204 .3892 .76506 .58382 Mtetra
.76506 .58382 .75204 .3892 .75376 .3883 .76691 .58327 Mtetra
.76691 .58327 .75376 .3883 .75547 .38724 .76876 .5827 Mtetra
.76876 .5827 .75547 .38724 .75717 .3861 .77062 .58212 Mtetra
.77062 .58212 .75717 .3861 .75887 .38496 .77247 .58152 Mtetra
.77247 .58152 .75887 .38496 .76048 .38251 .77431 .58081 Mtetra
.77431 .58081 .76048 .38251 .76209 .3801 .77616 .58002 Mtetra
.77616 .58002 .76209 .3801 .76386 .37983 .77801 .57943 Mtetra
.557 .341 .543 r
.77801 .57943 .76386 .37983 .77973 .56721 .77992 .57947 Mtetra
.564 .315 .497 r
.77992 .57947 .77973 .56721 .78243 .57784 .78186 .58003 Mtetra
.547 .174 .285 r
.78186 .58003 .78243 .57784 .78457 .58083 .7838 .5804 Mtetra
.377 .781 .984 r
.7838 .5804 .78457 .58083 .78653 .58163 .7857 .58027 Mtetra
.68 .703 .864 r
.7857 .58027 .78653 .58163 .78839 .58099 .78755 .57956 Mtetra
.703 .701 .845 r
.78755 .57956 .78839 .58099 .79022 .57995 .78939 .57868 Mtetra
.704 .728 .869 r
.78939 .57868 .79022 .57995 .79205 .57891 .79124 .57784 Mtetra
.674 .754 .911 r
.79124 .57784 .79205 .57891 .79391 .57821 .7931 .57719 Mtetra
.658 .758 .924 r
.7931 .57719 .79391 .57821 .79578 .57759 .79497 .57661 Mtetra
.636 .76 .937 r
.79497 .57661 .79578 .57759 .79765 .57705 .79685 .57612 Mtetra
.61 .761 .951 r
.79685 .57612 .79765 .57705 .79953 .5766 .79874 .57572 Mtetra
.591 .765 .962 r
.79874 .57572 .79953 .5766 .80142 .57622 .80063 .57536 Mtetra
.493 .726 .976 r
.80063 .57536 .80142 .57622 .80334 .57618 .80254 .57529 Mtetra
.409 .674 .969 r
.80254 .57529 .80334 .57618 .80528 .57642 .80448 .57545 Mtetra
.622 .754 .941 r
.80448 .57545 .80528 .57642 .80717 .57605 .80637 .57501 Mtetra
.87 .806 .784 r
.80637 .57501 .80717 .57605 .80891 .57378 .80811 .57275 Mtetra
.979 .741 .505 r
.80811 .57275 .80891 .57378 .80978 .56121 .80908 .56138 Mtetra
.978 .681 .367 r
.80908 .56138 .80978 .56121 .79484 .36233 .79412 .36167 Mtetra
.952 .838 .693 r
.79412 .36167 .79484 .36233 .79637 .359 .79564 .35823 Mtetra
.708 .823 .937 r
.79564 .35823 .79637 .359 .79812 .35831 .79738 .35746 Mtetra
.545 .74 .966 r
.79738 .35746 .79812 .35831 .79992 .3582 .79918 .35727 Mtetra
.527 .709 .955 r
.79918 .35727 .79992 .3582 .80173 .35819 .80098 .35717 Mtetra
.655 .745 .916 r
.80098 .35717 .80173 .35819 .80351 .35771 .80275 .35664 Mtetra
.664 .737 .904 r
.80275 .35664 .80351 .35771 .80528 .35717 .80452 .35607 Mtetra
.699 .745 .887 r
.80452 .35607 .80528 .35717 .80703 .35645 .80627 .35532 Mtetra
.74 .754 .863 r
.80627 .35532 .80703 .35645 .80877 .35551 .808 .35432 Mtetra
.676 .719 .881 r
.808 .35432 .80877 .35551 .81052 .35478 .80977 .35368 Mtetra
.367 .581 .924 r
.80977 .35368 .81052 .35478 .81234 .35471 .81163 .35411 Mtetra
.817 .36 0 r
.81163 .35411 .81234 .35471 .81429 .35615 .81381 .35809 Mtetra
.974 .666 .351 r
.81381 .35809 .81429 .35615 .8164 .35926 .83394 .55822 Mtetra
.564 .347 .543 r
.83394 .55822 .8164 .35926 .81882 .36559 .83636 .56337 Mtetra
.557 .341 .543 r
.83636 .56337 .81882 .36559 .82051 .36408 .83829 .56317 Mtetra
.556 .34 .543 r
.83829 .56317 .82051 .36408 .82215 .36199 .84015 .56219 Mtetra
.556 .341 .543 r
.84015 .56219 .82215 .36199 .82437 .36602 .84203 .56136 Mtetra
.558 .342 .543 r
.84203 .56136 .82437 .36602 .84435 .55801 .84402 .56177 Mtetra
.553 .236 .386 r
.84402 .56177 .84435 .55801 .84667 .56183 .84601 .5621 Mtetra
.199 0 0 r
.84601 .5621 .84667 .56183 .84876 .56323 .84797 .56214 Mtetra
.635 .738 .922 r
.84797 .56214 .84876 .56323 .85069 .56295 .84989 .56166 Mtetra
.661 .71 .884 r
.84989 .56166 .85069 .56295 .85259 .56229 .85179 .56105 Mtetra
.63 .706 .9 r
.85179 .56105 .85259 .56229 .8545 .56174 .85371 .5606 Mtetra
.475 .65 .935 r
.85371 .5606 .8545 .56174 .85649 .56195 .85569 .56072 Mtetra
.621 .704 .905 r
.85569 .56072 .85649 .56195 .85842 .56162 .85762 .56031 Mtetra
.816 .763 .803 r
.85762 .56031 .85842 .56162 .86022 .5599 .85941 .55851 Mtetra
.972 .74 .528 r
.85941 .55851 .86022 .5599 .8613 .55094 .86044 .54907 Mtetra
.977 .674 .347 r
.86044 .54907 .8613 .55094 .84288 .34767 .84214 .34663 Mtetra
.945 .792 .66 r
.84214 .34663 .84288 .34767 .84431 .34351 .84358 .34259 Mtetra
.745 .801 .897 r
.84358 .34259 .84431 .34351 .84605 .34246 .84534 .34161 Mtetra
.582 .757 .962 r
.84534 .34161 .84605 .34246 .84787 .3422 .84716 .3413 Mtetra
.469 .689 .963 r
.84716 .3413 .84787 .3422 .84977 .34264 .84901 .34135 Mtetra
.598 .666 .887 r
.84901 .34135 .84977 .34264 .85176 .34394 .85084 .34108 Mtetra
.546 .484 .738 r
.85084 .34108 .85176 .34394 .85396 .34721 .85272 .34126 Mtetra
.487 .368 .643 r
.85272 .34126 .85396 .34721 .87623 .5427 .85472 .34263 Mtetra
.521 .32 .548 r
.85472 .34263 .87623 .5427 .87906 .55087 .85887 .36452 Mtetra
.124 .041 .482 r
.85887 .36452 .87906 .55087 .8813 .55331 .88032 .55028 Mtetra
.171 .246 .699 r
.88032 .55028 .8813 .55331 .88339 .55421 .8826 .55303 Mtetra
.567 .689 .923 r
.8826 .55303 .88339 .55421 .88533 .55375 .88457 .55283 Mtetra
.7 .805 .93 r
.88457 .55283 .88533 .55375 .88723 .55292 .88648 .55203 Mtetra
.741 .825 .916 r
.88648 .55203 .88723 .55292 .88913 .55205 .88837 .55103 Mtetra
.591 .736 .945 r
.88837 .55103 .88913 .55205 .89112 .55197 .89033 .5507 Mtetra
.619 .697 .9 r
.89033 .5507 .89112 .55197 .89308 .55168 .89228 .5503 Mtetra
.656 .695 .875 r
.89228 .5503 .89308 .55168 .89499 .55084 .89421 .5497 Mtetra
.713 .764 .892 r
.89421 .5497 .89499 .55084 .8967 .54825 .89612 .54882 Mtetra
0 0 0 r
.89612 .54882 .8967 .54825 .89816 .54338 .89796 .54737 Mtetra
.279 .028 .343 r
.89796 .54737 .89816 .54338 .87807 .34523 .89966 .54467 Mtetra
.526 .319 .542 r
.89966 .54467 .87807 .34523 .87902 .3369 .89935 .52393 Mtetra
.124 .038 .478 r
.89935 .52393 .87902 .3369 .88054 .33371 .88003 .33451 Mtetra
.808 .857 .406 r
.88003 .33451 .88054 .33371 .8822 .33182 .8815 .33089 Mtetra
.732 .8 .906 r
.8815 .33089 .8822 .33182 .88401 .33116 .88328 .32998 Mtetra
.611 .698 .905 r
.88328 .32998 .88401 .33116 .88586 .33085 .88513 .32963 Mtetra
.545 .656 .909 r
.88513 .32963 .88586 .33085 .88773 .33071 .887 .32957 Mtetra
.648 .722 .902 r
.887 .32957 .88773 .33071 .88955 .33018 .88883 .32905 Mtetra
.658 .728 .901 r
.88883 .32905 .88955 .33018 .89137 .32958 .89065 .32849 Mtetra
.67 .742 .904 r
.89065 .32849 .89137 .32958 .89318 .3289 .89247 .32787 Mtetra
.715 .773 .898 r
.89247 .32787 .89318 .3289 .89494 .32783 .89426 .32703 Mtetra
.703 .826 .941 r
.89426 .32703 .89494 .32783 .89673 .32696 .89607 .32626 Mtetra
.653 .833 .969 r
.89607 .32626 .89673 .32696 .89857 .32651 .89789 .32566 Mtetra
.782 .818 .881 r
.30747 .51496 .30843 .51557 .30989 .51533 .30898 .51392 Mtetra
.686 .657 .816 r
.30898 .51392 .30989 .51533 .31133 .51554 .31047 .51325 Mtetra
.565 .515 .758 r
.31047 .51325 .31133 .51554 .31271 .5166 .31192 .51325 Mtetra
0 0 .319 r
.31192 .51325 .31271 .5166 .31363 .52499 .31311 .51738 Mtetra
.948 .693 .518 r
.31311 .51738 .31363 .52499 .30326 .71367 .30236 .71113 Mtetra
.897 .56 .074 r
.30236 .71113 .30326 .71367 .30459 .71701 .30357 .71634 Mtetra
.238 .631 .958 r
.30357 .71634 .30459 .71701 .30611 .71737 .3051 .71661 Mtetra
.675 .784 .932 r
.3051 .71661 .30611 .71737 .30768 .717 .30668 .71605 Mtetra
.743 .753 .861 r
.30668 .71605 .30768 .717 .30927 .71617 .30828 .7151 Mtetra
.491 .651 .93 r
.30828 .7151 .30927 .71617 .31086 .71543 .30982 .71516 Mtetra
.425 .825 .981 r
.30982 .71516 .31086 .71543 .31248 .71423 .31139 .71492 Mtetra
0 0 0 r
.31139 .71492 .31248 .71423 .31415 .71215 .31299 .71397 Mtetra
.973 .91 .571 r
.31299 .71397 .31415 .71215 .3162 .70371 .31484 .70891 Mtetra
.946 .695 .526 r
.31484 .70891 .3162 .70371 .32894 .51305 .32789 .51406 Mtetra
.985 .836 .612 r
.32789 .51406 .32894 .51305 .33065 .50893 .32972 .50792 Mtetra
.778 .738 .816 r
.32972 .50792 .33065 .50893 .33218 .50781 .33125 .50667 Mtetra
.637 .683 .876 r
.33125 .50667 .33218 .50781 .33366 .50737 .33274 .5063 Mtetra
.517 .651 .918 r
.33274 .5063 .33366 .50737 .33514 .50722 .3342 .50631 Mtetra
.725 .752 .873 r
.3342 .50631 .33514 .50722 .33666 .50625 .33571 .50553 Mtetra
.699 .788 .92 r
.33571 .50553 .33666 .50625 .33816 .50551 .33721 .50491 Mtetra
.473 .752 .991 r
.33721 .50491 .33816 .50551 .33964 .50542 .33869 .50483 Mtetra
.879 .445 .144 r
.33869 .50483 .33964 .50542 .34091 .50898 .34 .50754 Mtetra
.942 .684 .518 r
.34 .50754 .34091 .50898 .33175 .70309 .33105 .6968 Mtetra
0 0 .092 r
.33105 .6968 .33175 .70309 .33299 .70895 .3321 .70608 Mtetra
.355 .359 .726 r
.3321 .70608 .33299 .70895 .33452 .70943 .3336 .70727 Mtetra
.557 .531 .782 r
.3336 .70727 .33452 .70943 .33612 .70884 .33516 .7073 Mtetra
.637 .634 .83 r
.33516 .7073 .33612 .70884 .33774 .70782 .33675 .70688 Mtetra
.473 .675 .953 r
.33675 .70688 .33774 .70782 .3393 .70778 .33831 .70693 Mtetra
.587 .743 .95 r
.33831 .70693 .3393 .70778 .34088 .70762 .33989 .70667 Mtetra
.749 .759 .86 r
.33989 .70667 .34088 .70762 .34249 .7068 .34151 .70568 Mtetra
.892 .727 .67 r
.34151 .70568 .34249 .7068 .34428 .7025 .34332 .701 Mtetra
.941 .687 .525 r
.34332 .701 .34428 .7025 .35572 .50809 .35485 .50601 Mtetra
.873 .674 .631 r
.35485 .50601 .35572 .50809 .35758 .50058 .35667 .49943 Mtetra
.787 .721 .79 r
.35667 .49943 .35758 .50058 .35914 .49902 .35822 .49797 Mtetra
.637 .703 .893 r
.35822 .49797 .35914 .49902 .36065 .49857 .35972 .4976 Mtetra
.497 .664 .937 r
.35972 .4976 .36065 .49857 .36213 .49854 .36121 .49763 Mtetra
.625 .726 .919 r
.36121 .49763 .36213 .49854 .36364 .49809 .36271 .49728 Mtetra
.667 .765 .923 r
.36271 .49728 .36364 .49809 .36515 .49753 .36422 .49678 Mtetra
.675 .779 .929 r
.36422 .49678 .36515 .49753 .36666 .49709 .36573 .49625 Mtetra
.756 .77 .864 r
.36573 .49625 .36666 .49709 .36816 .49677 .36726 .49528 Mtetra
.699 .656 .804 r
.36726 .49528 .36816 .49677 .36965 .49678 .36879 .49449 Mtetra
.597 .534 .755 r
.36879 .49449 .36965 .49678 .37111 .4975 .37029 .49428 Mtetra
0 .08 .598 r
.37029 .49428 .37111 .4975 .37236 .50257 .37166 .49698 Mtetra
.951 .691 .506 r
.37166 .49698 .37236 .50257 .36513 .69468 .36433 .68987 Mtetra
.754 .517 0 r
.36433 .68987 .36513 .69468 .36653 .69891 .36555 .6978 Mtetra
0 .117 .637 r
.36555 .6978 .36653 .69891 .36806 .70002 .36708 .69919 Mtetra
.548 .735 .962 r
.36708 .69919 .36806 .70002 .36966 .69993 .36867 .69902 Mtetra
.776 .771 .848 r
.36867 .69902 .36966 .69993 .37129 .69892 .37032 .69783 Mtetra
.888 .735 .686 r
.37032 .69783 .37129 .69892 .37304 .69517 .37208 .69376 Mtetra
.944 .688 .519 r
.37208 .69376 .37304 .69517 .38285 .5027 .38203 .49955 Mtetra
.861 .647 .612 r
.38203 .49955 .38285 .5027 .38479 .49236 .38389 .49114 Mtetra
.807 .718 .767 r
.38389 .49114 .38479 .49236 .38637 .49045 .38546 .48936 Mtetra
.642 .697 .885 r
.38546 .48936 .38637 .49045 .38789 .48999 .38698 .48896 Mtetra
.489 .648 .929 r
.38698 .48896 .38789 .48999 .38939 .49002 .38848 .48903 Mtetra
.585 .697 .92 r
.38848 .48903 .38939 .49002 .39091 .4898 .38999 .48883 Mtetra
.646 .722 .904 r
.38999 .48883 .39091 .4898 .39243 .48939 .39152 .48841 Mtetra
.652 .723 .901 r
.39152 .48841 .39243 .48939 .39395 .48895 .39304 .48796 Mtetra
.732 .742 .859 r
.39304 .48796 .39395 .48895 .39549 .48816 .39458 .4871 Mtetra
.717 .725 .857 r
.39458 .4871 .39549 .48816 .39703 .48742 .39612 .48632 Mtetra
.583 .674 .902 r
.39612 .48632 .39703 .48742 .39855 .48716 .39764 .48614 Mtetra
.848 .404 0 r
.39764 .48614 .39855 .48716 .39998 .48911 .39904 .48895 Mtetra
.947 .683 .505 r
.39904 .48895 .39998 .48911 .39493 .66538 .39326 .68325 Mtetra
.656 .407 .532 r
.39326 .68325 .39493 .66538 .39569 .68786 .39461 .68989 Mtetra
.643 .284 .346 r
.39461 .68989 .39569 .68786 .39724 .68936 .39618 .691 Mtetra
.381 0 .151 r
.39618 .691 .39724 .68936 .39887 .68895 .3978 .6906 Mtetra
.225 0 .062 r
.3978 .6906 .39887 .68895 .40051 .68797 .39945 .68973 Mtetra
.382 0 .17 r
.39945 .68973 .40051 .68797 .40213 .68758 .40107 .68928 Mtetra
.414 .02 .179 r
.40107 .68928 .40213 .68758 .40375 .68737 .4027 .68898 Mtetra
.243 0 .066 r
.4027 .68898 .40375 .68737 .4054 .68641 .40434 .68817 Mtetra
.655 .819 .389 r
.40434 .68817 .4054 .68641 .40717 .6816 .40606 .68519 Mtetra
.997 .82 .469 r
.40606 .68519 .40717 .6816 .41524 .48697 .4081 .67245 Mtetra
0 0 .299 r
.4081 .67245 .41524 .48697 .41694 .48138 .41596 .48264 Mtetra
.765 .911 .527 r
.41596 .48264 .41694 .48138 .41853 .47951 .41757 .48006 Mtetra
0 0 0 r
.41757 .48006 .41853 .47951 .42007 .47889 .41912 .47939 Mtetra
.213 0 0 r
.41912 .47939 .42007 .47889 .4216 .47864 .42065 .47924 Mtetra
.187 0 0 r
.42065 .47924 .4216 .47864 .42314 .47831 .42218 .47898 Mtetra
.078 0 0 r
.42218 .47898 .42314 .47831 .42468 .47782 .42373 .47851 Mtetra
.094 0 0 r
.42373 .47851 .42468 .47782 .42622 .47734 .42527 .47804 Mtetra
.104 0 0 r
.42527 .47804 .42622 .47734 .42777 .47685 .42681 .47758 Mtetra
.112 0 0 r
.42681 .47758 .42777 .47685 .42931 .47637 .42836 .47711 Mtetra
.124 0 0 r
.42836 .47711 .42931 .47637 .43086 .47589 .42991 .47665 Mtetra
.172 0 0 r
.42991 .47665 .43086 .47589 .4324 .47541 .43145 .47625 Mtetra
.214 0 0 r
.43145 .47625 .4324 .47541 .43395 .47494 .433 .47586 Mtetra
.188 0 0 r
.433 .47586 .43395 .47494 .4355 .47449 .43455 .47537 Mtetra
0 0 0 r
.43455 .47537 .4355 .47449 .43704 .47409 .43611 .47454 Mtetra
.543 .911 .735 r
.43611 .47454 .43704 .47409 .43859 .47372 .43767 .47348 Mtetra
.775 .926 .935 r
.43767 .47348 .43859 .47372 .44014 .47336 .43924 .47247 Mtetra
.716 .761 .888 r
.43924 .47247 .44014 .47336 .44169 .47296 .4408 .47172 Mtetra
.659 .68 .859 r
.4408 .47172 .44169 .47296 .44324 .4725 .44235 .47122 Mtetra
.644 .668 .858 r
.44235 .47122 .44324 .4725 .44479 .47201 .4439 .4708 Mtetra
.649 .681 .867 r
.4439 .4708 .44479 .47201 .44635 .47145 .44546 .47035 Mtetra
.66 .704 .88 r
.44546 .47035 .44635 .47145 .44791 .47086 .44701 .46986 Mtetra
.662 .725 .896 r
.44701 .46986 .44791 .47086 .44947 .47026 .44857 .46936 Mtetra
.663 .748 .913 r
.44857 .46936 .44947 .47026 .45103 .4697 .45013 .46886 Mtetra
.662 .762 .924 r
.45013 .46886 .45103 .4697 .45259 .46918 .45169 .46836 Mtetra
.659 .765 .928 r
.45169 .46836 .45259 .46918 .45414 .46868 .45325 .46787 Mtetra
.651 .766 .933 r
.45325 .46787 .45414 .46868 .4557 .46818 .45481 .46741 Mtetra
.641 .773 .944 r
.45481 .46741 .4557 .46818 .45727 .46767 .45637 .46698 Mtetra
.637 .791 .956 r
.45637 .46698 .45727 .46767 .45883 .46717 .45793 .46654 Mtetra
.642 .811 .965 r
.45793 .46654 .45883 .46717 .46039 .46661 .45949 .46608 Mtetra
.647 .839 .974 r
.45949 .46608 .46039 .46661 .46196 .46602 .46106 .46557 Mtetra
.645 .862 .981 r
.46106 .46557 .46196 .46602 .46352 .46553 .46262 .46504 Mtetra
.662 .852 .973 r
.46262 .46504 .46352 .46553 .46508 .46539 .46419 .46447 Mtetra
.682 .75 .902 r
.46419 .46447 .46508 .46539 .46663 .46571 .46576 .46389 Mtetra
.657 .607 .786 r
.46576 .46389 .46663 .46571 .46818 .4662 .46733 .46329 Mtetra
.63 .524 .714 r
.46733 .46329 .46818 .4662 .46974 .46639 .4689 .46271 Mtetra
.617 .489 .684 r
.4689 .46271 .46974 .46639 .47131 .46592 .47047 .46215 Mtetra
.614 .485 .681 r
.47047 .46215 .47131 .46592 .47289 .46524 .47204 .46161 Mtetra
.628 .497 .684 r
.47204 .46161 .47289 .46524 .47446 .46433 .47362 .46091 Mtetra
.64 .511 .69 r
.47362 .46091 .47446 .46433 .47604 .46337 .47519 .46011 Mtetra
.608 .496 .701 r
.47519 .46011 .47604 .46337 .47761 .46303 .47676 .45971 Mtetra
.445 .39 .702 r
.47676 .45971 .47761 .46303 .47916 .46493 .47832 .46067 Mtetra
0 0 .35 r
.47832 .46067 .47916 .46493 .47813 .65823 .47981 .46639 Mtetra
0 0 .347 r
.47981 .46639 .47813 .65823 .47969 .66579 .4788 .66162 Mtetra
.103 .134 .608 r
.4788 .66162 .47969 .66579 .48134 .6676 .48042 .66489 Mtetra
.577 .51 .744 r
.48042 .66489 .48134 .6676 .48301 .66739 .4821 .66481 Mtetra
.655 .562 .737 r
.4821 .66481 .48301 .66739 .4847 .66672 .48378 .66404 Mtetra
.662 .56 .73 r
.48378 .66404 .4847 .66672 .48638 .66602 .48546 .66316 Mtetra
.622 .529 .728 r
.48546 .66316 .48638 .66602 .48806 .66563 .48714 .66267 Mtetra
.621 .524 .722 r
.48714 .66267 .48806 .66563 .48974 .66524 .48882 .66217 Mtetra
.623 .521 .717 r
.48882 .66217 .48974 .66524 .49142 .66482 .4905 .66163 Mtetra
.626 .517 .711 r
.4905 .66163 .49142 .66482 .4931 .66435 .49219 .66104 Mtetra
.615 .506 .707 r
.49219 .66104 .4931 .66435 .49478 .66385 .49387 .66056 Mtetra
.587 .49 .711 r
.49387 .66056 .49478 .66385 .49647 .66331 .49555 .66037 Mtetra
.545 .48 .733 r
.49555 .66037 .49647 .66331 .49816 .66272 .49723 .66054 Mtetra
.539 .526 .789 r
.49723 .66054 .49816 .66272 .49985 .66212 .49892 .66068 Mtetra
.564 .623 .87 r
.49892 .66068 .49985 .66212 .50153 .66159 .5006 .66059 Mtetra
.634 .733 .92 r
.5006 .66059 .50153 .66159 .50322 .66119 .50229 .66017 Mtetra
.654 .736 .91 r
.50229 .66017 .50322 .66119 .50491 .6607 .50398 .65967 Mtetra
.652 .732 .908 r
.50398 .65967 .50491 .6607 .50661 .65993 .50567 .65917 Mtetra
.613 .785 .964 r
.50567 .65917 .50661 .65993 .5083 .6586 .50737 .65878 Mtetra
.19 .718 .724 r
.50737 .65878 .5083 .6586 .51 .65708 .50906 .65839 Mtetra
.333 0 .058 r
.50906 .65839 .51 .65708 .5117 .65572 .51076 .65798 Mtetra
.43 .073 .257 r
.51076 .65798 .5117 .65572 .51339 .65512 .51245 .65754 Mtetra
.437 .089 .275 r
.51245 .65754 .51339 .65512 .51508 .65477 .51415 .65708 Mtetra
.43 .076 .262 r
.51415 .65708 .51508 .65477 .51678 .65447 .51585 .65662 Mtetra
.418 .056 .24 r
.51585 .65662 .51678 .65447 .51848 .65401 .51755 .65615 Mtetra
.416 .053 .238 r
.51755 .65615 .51848 .65401 .52018 .65355 .51925 .65568 Mtetra
.415 .051 .235 r
.51925 .65568 .52018 .65355 .52188 .65309 .52095 .6552 Mtetra
.413 .049 .233 r
.52095 .6552 .52188 .65309 .52358 .65262 .52265 .65473 Mtetra
.412 .048 .232 r
.52265 .65473 .52358 .65262 .52528 .65214 .52435 .65425 Mtetra
.412 .047 .232 r
.52435 .65425 .52528 .65214 .52698 .65166 .52606 .65377 Mtetra
.412 .046 .232 r
.52606 .65377 .52698 .65166 .52868 .65118 .52776 .65328 Mtetra
.411 .046 .231 r
.52776 .65328 .52868 .65118 .53039 .6507 .52947 .6528 Mtetra
.52947 .6528 .53039 .6507 .53209 .65021 .53118 .65232 Mtetra
.53118 .65232 .53209 .65021 .5338 .64973 .53289 .65183 Mtetra
.53289 .65183 .5338 .64973 .53551 .64925 .5346 .65135 Mtetra
.5346 .65135 .53551 .64925 .53722 .64876 .53631 .65086 Mtetra
.53631 .65086 .53722 .64876 .53893 .64827 .53802 .65037 Mtetra
.411 .045 .231 r
.53802 .65037 .53893 .64827 .54064 .64779 .53973 .64989 Mtetra
.53973 .64989 .54064 .64779 .54235 .6473 .54145 .6494 Mtetra
.54145 .6494 .54235 .6473 .54406 .64681 .54316 .64891 Mtetra
.41 .045 .231 r
.54316 .64891 .54406 .64681 .54578 .64631 .54488 .64842 Mtetra
.54488 .64842 .54578 .64631 .54749 .64581 .5466 .64792 Mtetra
.41 .046 .232 r
.5466 .64792 .54749 .64581 .54921 .6453 .54832 .64742 Mtetra
.41 .047 .234 r
.54832 .64742 .54921 .6453 .55093 .64478 .55004 .64692 Mtetra
.41 .048 .235 r
.55004 .64692 .55093 .64478 .55264 .64424 .55176 .64642 Mtetra
.413 .052 .241 r
.55176 .64642 .55264 .64424 .55436 .64354 .55348 .6459 Mtetra
.424 .074 .265 r
.55348 .6459 .55436 .64354 .55608 .64299 .5552 .64538 Mtetra
.422 .073 .266 r
.5552 .64538 .55608 .64299 .55781 .64281 .55692 .64484 Mtetra
.385 .017 .211 r
.55692 .64484 .55781 .64281 .55954 .64338 .55865 .64425 Mtetra
.132 0 0 r
.55865 .64425 .55954 .64338 .56127 .64387 .56037 .64366 Mtetra
.563 .905 .976 r
.56037 .64366 .56127 .64387 .56301 .64409 .5621 .64308 Mtetra
.657 .744 .914 r
.5621 .64308 .56301 .64409 .56474 .6437 .56383 .64255 Mtetra
.653 .714 .893 r
.56383 .64255 .56474 .6437 .56646 .64316 .56555 .64204 Mtetra
.649 .719 .899 r
.56555 .64204 .56646 .64316 .56819 .64256 .56728 .64155 Mtetra
.629 .735 .924 r
.56728 .64155 .56819 .64256 .56992 .64206 .56902 .64114 Mtetra
.64 .758 .934 r
.56902 .64114 .56992 .64206 .57165 .64158 .57075 .64067 Mtetra
.672 .771 .925 r
.57075 .64067 .57165 .64158 .57339 .64113 .57248 .64007 Mtetra
.743 .759 .866 r
.57248 .64007 .57339 .64113 .57512 .64076 .57421 .63906 Mtetra
.722 .663 .791 r
.57421 .63906 .57512 .64076 .57686 .64041 .57593 .63795 Mtetra
.686 .588 .739 r
.57593 .63795 .57686 .64041 .5786 .64004 .57766 .63686 Mtetra
.623 .518 .714 r
.57766 .63686 .5786 .64004 .58034 .63961 .5794 .63629 Mtetra
.608 .504 .709 r
.5794 .63629 .58034 .63961 .58207 .63915 .58114 .63587 Mtetra
.602 .502 .712 r
.58114 .63587 .58207 .63915 .58381 .63865 .58288 .63552 Mtetra
.561 .482 .724 r
.58288 .63552 .58381 .63865 .58556 .63844 .58463 .63558 Mtetra
.612 .526 .732 r
.58463 .63558 .58556 .63844 .5873 .63792 .58637 .63518 Mtetra
.694 .578 .721 r
.58637 .63518 .5873 .63792 .58903 .63678 .5881 .63388 Mtetra
.88 .665 .606 r
.5881 .63388 .58903 .63678 .5907 .63253 .5897 .62609 Mtetra
.96 .683 .467 r
.5897 .62609 .5907 .63253 .58869 .43983 .58764 .42849 Mtetra
.671 .462 .593 r
.58764 .42849 .58869 .43983 .5901 .42765 .5892 .42395 Mtetra
.653 .513 .68 r
.5892 .42395 .5901 .42765 .59173 .42642 .59083 .42287 Mtetra
.609 .49 .692 r
.59083 .42287 .59173 .42642 .59337 .42603 .59247 .42241 Mtetra
.58 .469 .692 r
.59247 .42241 .59337 .42603 .59502 .4259 .59412 .42228 Mtetra
.607 .486 .69 r
.59412 .42228 .59502 .4259 .59664 .42439 .59577 .42184 Mtetra
.621 .539 .74 r
.59577 .42184 .59664 .42439 .59827 .42292 .59741 .4214 Mtetra
.642 .639 .832 r
.59741 .4214 .59827 .42292 .59989 .42168 .59906 .42094 Mtetra
.664 .8 .947 r
.59906 .42094 .59989 .42168 .60154 .421 .60071 .42039 Mtetra
.665 .834 .965 r
.60071 .42039 .60154 .421 .60318 .4205 .60235 .41981 Mtetra
.671 .814 .952 r
.60235 .41981 .60318 .4205 .60483 .42011 .604 .41923 Mtetra
.665 .765 .925 r
.604 .41923 .60483 .42011 .60648 .41968 .60565 .41869 Mtetra
.663 .738 .906 r
.60565 .41869 .60648 .41968 .60814 .41927 .6073 .41816 Mtetra
.662 .715 .888 r
.6073 .41816 .60814 .41927 .60979 .41884 .60895 .41763 Mtetra
.676 .702 .866 r
.60895 .41763 .60979 .41884 .61144 .41834 .6106 .41702 Mtetra
.666 .679 .853 r
.6106 .41702 .61144 .41834 .61309 .41781 .61225 .41645 Mtetra
.646 .666 .854 r
.61225 .41645 .61309 .41781 .61474 .41724 .6139 .41598 Mtetra
.559 .644 .891 r
.6139 .41598 .61474 .41724 .6164 .41661 .61557 .41589 Mtetra
.415 .706 .983 r
.61557 .41589 .6164 .41661 .61805 .41596 .61724 .41595 Mtetra
.059 0 0 r
.61724 .41595 .61805 .41596 .6197 .41532 .61892 .41603 Mtetra
.201 0 0 r
.61892 .41603 .6197 .41532 .62136 .41475 .62058 .41568 Mtetra
.193 0 0 r
.62058 .41568 .62136 .41475 .62301 .4142 .62224 .41513 Mtetra
.154 0 0 r
.62224 .41513 .62301 .4142 .62467 .41368 .6239 .4145 Mtetra
.206 0 0 r
.6239 .4145 .62467 .41368 .62633 .41315 .62556 .41406 Mtetra
.227 0 0 r
.62556 .41406 .62633 .41315 .62799 .41263 .62723 .41359 Mtetra
.182 0 0 r
.62723 .41359 .62799 .41263 .62966 .41214 .62889 .41299 Mtetra
0 0 0 r
.62889 .41299 .62966 .41214 .63132 .41171 .63054 .41192 Mtetra
.642 .964 .821 r
.63054 .41192 .63132 .41171 .63299 .4113 .63218 .41078 Mtetra
.772 .882 .925 r
.63218 .41078 .63299 .4113 .63466 .41088 .63383 .40976 Mtetra
.677 .719 .88 r
.63383 .40976 .63466 .41088 .63633 .41041 .63549 .40914 Mtetra
.642 .68 .871 r
.63549 .40914 .63633 .41041 .638 .40989 .63717 .4087 Mtetra
.631 .689 .886 r
.63717 .4087 .638 .40989 .63966 .40933 .63884 .40831 Mtetra
.659 .733 .905 r
.63884 .40831 .63966 .40933 .64132 .40859 .64051 .40779 Mtetra
.67 .79 .938 r
.64051 .40779 .64132 .40859 .64299 .40786 .64218 .40721 Mtetra
.669 .829 .96 r
.64218 .40721 .64299 .40786 .64466 .4073 .64385 .40662 Mtetra
.758 .841 .914 r
.64385 .40662 .64466 .4073 .64634 .40697 .6455 .40565 Mtetra
.701 .695 .841 r
.6455 .40565 .64634 .40697 .64803 .40708 .64717 .40486 Mtetra
.599 .549 .77 r
.64717 .40486 .64803 .40708 .64976 .40802 .64885 .40462 Mtetra
.244 .259 .678 r
.64885 .40462 .64976 .40802 .65172 .41468 .65064 .40691 Mtetra
.978 .69 .401 r
.65064 .40691 .65172 .41468 .66123 .61135 .65987 .59765 Mtetra
0 0 .467 r
.65987 .59765 .66123 .61135 .66319 .61513 .66223 .61176 Mtetra
.362 .348 .709 r
.66223 .61176 .66319 .61513 .66503 .61572 .66411 .61335 Mtetra
.544 .518 .777 r
.66411 .61335 .66503 .61572 .66682 .61527 .66592 .61349 Mtetra
.619 .612 .821 r
.66592 .61349 .66682 .61527 .6686 .61432 .66772 .61312 Mtetra
.632 .704 .897 r
.66772 .61312 .6686 .61432 .67036 .61306 .66952 .61269 Mtetra
.566 .879 .993 r
.66952 .61269 .67036 .61306 .67211 .61156 .67132 .61218 Mtetra
.034 0 0 r
.67132 .61218 .67211 .61156 .67386 .60991 .67311 .61159 Mtetra
.438 .04 .185 r
.67311 .61159 .67386 .60991 .67565 .60942 .67492 .61139 Mtetra
.44 .064 .227 r
.67492 .61139 .67565 .60942 .67746 .6092 .67673 .61109 Mtetra
.314 0 .163 r
.67673 .61109 .67746 .6092 .67925 .60831 .67852 .61022 Mtetra
0 0 0 r
.67852 .61022 .67925 .60831 .68081 .60256 .68019 .60692 Mtetra
.891 .742 .237 r
.68019 .60692 .68081 .60256 .67346 .40343 .68139 .5932 Mtetra
.015 0 .418 r
.68139 .5932 .67346 .40343 .67493 .39818 .67423 .3995 Mtetra
0 0 0 r
.67423 .3995 .67493 .39818 .67657 .39657 .67582 .39673 Mtetra
.667 .974 .831 r
.67582 .39673 .67657 .39657 .67826 .39606 .67748 .39554 Mtetra
.685 .874 .97 r
.67748 .39554 .67826 .39606 .67997 .39591 .67916 .39485 Mtetra
.676 .735 .895 r
.67916 .39485 .67997 .39591 .68167 .39548 .68085 .39424 Mtetra
.659 .695 .872 r
.68085 .39424 .68167 .39548 .68336 .39486 .68255 .39371 Mtetra
.643 .704 .891 r
.68255 .39371 .68336 .39486 .68505 .39423 .68425 .39325 Mtetra
.643 .74 .919 r
.68425 .39325 .68505 .39423 .68674 .39358 .68595 .39279 Mtetra
.64 .787 .952 r
.68595 .39279 .68674 .39358 .68843 .39296 .68765 .39231 Mtetra
.635 .821 .972 r
.68765 .39231 .68843 .39296 .69014 .39249 .68935 .39181 Mtetra
.663 .824 .961 r
.68935 .39181 .69014 .39249 .69186 .39244 .69105 .39123 Mtetra
.678 .707 .87 r
.69105 .39123 .69186 .39244 .69361 .39276 .69274 .3906 Mtetra
.65 .583 .766 r
.69274 .3906 .69361 .39276 .69536 .39322 .69444 .38996 Mtetra
.645 .523 .7 r
.69444 .38996 .69536 .39322 .69707 .39278 .69613 .3891 Mtetra
.631 .501 .686 r
.69613 .3891 .69707 .39278 .69876 .39193 .69782 .38832 Mtetra
.594 .48 .694 r
.69782 .38832 .69876 .39193 .70048 .39165 .69954 .38803 Mtetra
.368 .334 .689 r
.69954 .38803 .70048 .39165 .70241 .39518 .70137 .38975 Mtetra
0 0 .256 r
.70137 .38975 .70241 .39518 .71522 .59397 .70369 .40031 Mtetra
.043 0 .439 r
.70369 .40031 .71522 .59397 .71736 .59913 .71637 .59548 Mtetra
.357 .335 .697 r
.71637 .59548 .71736 .59913 .71928 .60022 .71833 .5973 Mtetra
.609 .524 .733 r
.71833 .5973 .71928 .60022 .72112 .59992 .72016 .5969 Mtetra
.654 .545 .72 r
.72016 .5969 .72112 .59992 .72293 .59919 .72196 .59599 Mtetra
.602 .508 .72 r
.72196 .59599 .72293 .59919 .72475 .59846 .7238 .59564 Mtetra
.551 .495 .746 r
.7238 .59564 .72475 .59846 .72657 .59782 .72567 .59577 Mtetra
.551 .551 .807 r
.72567 .59577 .72657 .59782 .72839 .59716 .72754 .59582 Mtetra
.594 .665 .888 r
.72754 .59582 .72839 .59716 .73023 .59663 .72938 .59556 Mtetra
.643 .738 .918 r
.72938 .59556 .73023 .59663 .73206 .59617 .73122 .59506 Mtetra
.658 .736 .908 r
.73122 .59506 .73206 .59617 .73389 .59559 .73305 .5945 Mtetra
.645 .733 .913 r
.73305 .5945 .73389 .59559 .7357 .59458 .73489 .594 Mtetra
.581 .834 .993 r
.73489 .594 .7357 .59458 .73748 .59312 .73673 .59356 Mtetra
.027 0 0 r
.73673 .59356 .73748 .59312 .73925 .5915 .73858 .59313 Mtetra
.379 0 .149 r
.73858 .59313 .73925 .5915 .74104 .59031 .74042 .59267 Mtetra
.434 .083 .268 r
.74042 .59267 .74104 .59031 .74288 .58975 .74226 .59218 Mtetra
.437 .089 .276 r
.74226 .59218 .74288 .58975 .74473 .58941 .74411 .59168 Mtetra
.427 .072 .257 r
.74411 .59168 .74473 .58941 .74658 .58901 .74595 .59117 Mtetra
.419 .057 .242 r
.74595 .59117 .74658 .58901 .74842 .58852 .7478 .59067 Mtetra
.417 .055 .24 r
.7478 .59067 .74842 .58852 .75027 .58802 .74965 .59015 Mtetra
.415 .052 .237 r
.74965 .59015 .75027 .58802 .75211 .58752 .75149 .58964 Mtetra
.414 .05 .235 r
.75149 .58964 .75211 .58752 .75396 .58701 .75334 .58912 Mtetra
.413 .049 .234 r
.75334 .58912 .75396 .58701 .75581 .58649 .75519 .5886 Mtetra
.413 .048 .234 r
.75519 .5886 .75581 .58649 .75766 .58596 .75704 .58807 Mtetra
.412 .048 .233 r
.75704 .58807 .75766 .58596 .75951 .58544 .7589 .58754 Mtetra
.412 .047 .233 r
.7589 .58754 .75951 .58544 .76136 .5849 .76075 .58701 Mtetra
.411 .048 .234 r
.76075 .58701 .76136 .5849 .76321 .58437 .7626 .58648 Mtetra
.7626 .58648 .76321 .58437 .76506 .58382 .76446 .58594 Mtetra
.411 .048 .235 r
.76446 .58594 .76506 .58382 .76691 .58327 .76631 .5854 Mtetra
.411 .049 .237 r
.76631 .5854 .76691 .58327 .76876 .5827 .76817 .58485 Mtetra
.411 .051 .239 r
.76817 .58485 .76876 .5827 .77062 .58212 .77003 .5843 Mtetra
.412 .052 .242 r
.77003 .5843 .77062 .58212 .77247 .58152 .77188 .58373 Mtetra
.412 .055 .246 r
.77188 .58373 .77247 .58152 .77431 .58081 .77374 .58315 Mtetra
.418 .068 .262 r
.77374 .58315 .77431 .58081 .77616 .58002 .7756 .58256 Mtetra
.427 .086 .283 r
.7756 .58256 .77616 .58002 .77801 .57943 .77746 .58194 Mtetra
.42 .079 .279 r
.77746 .58194 .77801 .57943 .77992 .57947 .77931 .58129 Mtetra
.352 0 .172 r
.77931 .58129 .77992 .57947 .78186 .58003 .78117 .58059 Mtetra
0 0 0 r
.78117 .58059 .78186 .58003 .7838 .5804 .78302 .57987 Mtetra
.677 .884 .975 r
.78302 .57987 .7838 .5804 .7857 .58027 .78487 .57911 Mtetra
.698 .744 .887 r
.78487 .57911 .7857 .58027 .78755 .57956 .78672 .57832 Mtetra
.693 .729 .878 r
.78672 .57832 .78755 .57956 .78939 .57868 .78857 .57755 Mtetra
.685 .746 .898 r
.78857 .57755 .78939 .57868 .79124 .57784 .79043 .57684 Mtetra
.666 .766 .925 r
.79043 .57684 .79124 .57784 .7931 .57719 .7923 .57623 Mtetra
.646 .766 .936 r
.7923 .57623 .7931 .57719 .79497 .57661 .79417 .57569 Mtetra
.603 .76 .954 r
.79417 .57569 .79497 .57661 .79685 .57612 .79606 .57531 Mtetra
.544 .762 .978 r
.79606 .57531 .79685 .57612 .79874 .57572 .79796 .57507 Mtetra
.54 .805 .995 r
.79796 .57507 .79874 .57572 .80063 .57536 .79985 .57476 Mtetra
.57 .83 .994 r
.79985 .57476 .80063 .57536 .80254 .57529 .80174 .57434 Mtetra
.663 .778 .935 r
.80174 .57434 .80254 .57529 .80448 .57545 .80362 .57373 Mtetra
.729 .678 .8 r
.80362 .57373 .80448 .57545 .80637 .57501 .80544 .57253 Mtetra
.815 .657 .687 r
.80544 .57253 .80637 .57501 .80811 .57275 .80711 .56938 Mtetra
.976 .678 .378 r
.80711 .56938 .80811 .57275 .80908 .56138 .79252 .37218 Mtetra
.578 .361 .55 r
.79252 .37218 .80908 .56138 .79412 .36167 .79334 .36043 Mtetra
.891 .768 .72 r
.79334 .36043 .79412 .36167 .79564 .35823 .79491 .35751 Mtetra
.716 .838 .94 r
.79491 .35751 .79564 .35823 .79738 .35746 .79665 .3567 Mtetra
.58 .778 .973 r
.79665 .3567 .79738 .35746 .79918 .35727 .79843 .35638 Mtetra
.586 .745 .952 r
.79843 .35638 .79918 .35727 .80098 .35717 .80022 .35608 Mtetra
.689 .743 .892 r
.80022 .35608 .80098 .35717 .80275 .35664 .80198 .35538 Mtetra
.673 .705 .871 r
.80198 .35538 .80275 .35664 .80452 .35607 .80374 .35475 Mtetra
.658 .688 .867 r
.80374 .35475 .80452 .35607 .80627 .35532 .80551 .3542 Mtetra
.636 .715 .904 r
.80551 .3542 .80627 .35532 .808 .35432 .80729 .35375 Mtetra
.363 .726 .988 r
.80729 .35375 .808 .35432 .80977 .35368 .80912 .35379 Mtetra
.666 .117 0 r
.80912 .35379 .80977 .35368 .81163 .35411 .81108 .35536 Mtetra
.974 .667 .35 r
.81108 .35536 .81163 .35411 .81381 .35809 .83037 .54798 Mtetra
.579 .357 .543 r
.83037 .54798 .81381 .35809 .83394 .55822 .83368 .56297 Mtetra
.659 .344 .429 r
.83368 .56297 .83394 .55822 .83636 .56337 .83585 .56538 Mtetra
.467 .089 .238 r
.83585 .56538 .83636 .56337 .83829 .56317 .83778 .56522 Mtetra
.369 .008 .214 r
.83778 .56522 .83829 .56317 .84015 .56219 .83967 .56446 Mtetra
.349 .006 .235 r
.83967 .56446 .84015 .56219 .84203 .56136 .84153 .56346 Mtetra
.371 .013 .221 r
.84153 .56346 .84203 .56136 .84402 .56177 .84342 .56267 Mtetra
.107 0 0 r
.84342 .56267 .84402 .56177 .84601 .5621 .8453 .56186 Mtetra
.601 .929 .962 r
.8453 .56186 .84601 .5621 .84797 .56214 .84718 .56109 Mtetra
.666 .758 .919 r
.84718 .56109 .84797 .56214 .84989 .56166 .84909 .56046 Mtetra
.655 .725 .901 r
.84909 .56046 .84989 .56166 .85179 .56105 .851 .55989 Mtetra
.621 .717 .915 r
.851 .55989 .85179 .56105 .85371 .5606 .85292 .55947 Mtetra
.527 .68 .935 r
.85292 .55947 .85371 .5606 .85569 .56072 .85488 .55942 Mtetra
.64 .699 .889 r
.85488 .55942 .85569 .56072 .85762 .56031 .8568 .55892 Mtetra
.797 .745 .805 r
.8568 .55892 .85762 .56031 .85941 .55851 .85861 .55725 Mtetra
.964 .76 .58 r
.85861 .55725 .85941 .55851 .86044 .54907 .85991 .55054 Mtetra
.977 .676 .336 r
.85991 .55054 .86044 .54907 .84214 .34663 .84166 .34813 Mtetra
.755 .757 .245 r
.84166 .34813 .84214 .34663 .84358 .34259 .84301 .34312 Mtetra
0 0 0 r
.84301 .34312 .84358 .34259 .84534 .34161 .84471 .34165 Mtetra
.507 .911 .843 r
.84471 .34165 .84534 .34161 .84716 .3413 .84648 .3408 Mtetra
.648 .881 .983 r
.84648 .3408 .84716 .3413 .84901 .34135 .84827 .34015 Mtetra
.739 .745 .856 r
.84827 .34015 .84901 .34135 .85084 .34108 .85002 .33912 Mtetra
.651 .606 .791 r
.85002 .33912 .85084 .34108 .85272 .34126 .85181 .33851 Mtetra
.539 .486 .745 r
.85181 .33851 .85272 .34126 .85472 .34263 .85369 .33873 Mtetra
.18 .205 .651 r
.85369 .33873 .85472 .34263 .85887 .36452 .85592 .3422 Mtetra
.949 .655 .208 r
.85592 .3422 .85887 .36452 .88032 .55028 .87891 .54305 Mtetra
.145 .127 .578 r
.87891 .54305 .88032 .55028 .8826 .55303 .88162 .54998 Mtetra
.474 .441 .741 r
.88162 .54998 .8826 .55303 .88457 .55283 .8837 .55078 Mtetra
.57 .567 .81 r
.8837 .55078 .88457 .55283 .88648 .55203 .88568 .55071 Mtetra
.637 .696 .888 r
.88568 .55071 .88648 .55203 .88837 .55103 .88763 .55022 Mtetra
.622 .803 .969 r
.88763 .55022 .88837 .55103 .89033 .5507 .88957 .54971 Mtetra
.662 .775 .933 r
.88957 .54971 .89033 .5507 .89228 .5503 .8915 .54908 Mtetra
.659 .727 .9 r
.8915 .54908 .89228 .5503 .89421 .5497 .89343 .54848 Mtetra
.525 .661 .922 r
.89343 .54848 .89421 .5497 .89612 .54882 .89543 .54846 Mtetra
.466 .85 .983 r
.89543 .54846 .89612 .54882 .89796 .54737 .89739 .54806 Mtetra
0 0 0 r
.89739 .54806 .89796 .54737 .89966 .54467 .89926 .54684 Mtetra
.89926 .54684 .89966 .54467 .89935 .52393 .9007 .54181 Mtetra
.96 .667 .241 r
.9007 .54181 .89935 .52393 .88003 .33451 .87996 .3392 Mtetra
0 0 .237 r
.87996 .3392 .88003 .33451 .8815 .33089 .88099 .33161 Mtetra
0 0 0 r
.88099 .33161 .8815 .33089 .88328 .32998 .88267 .32984 Mtetra
.656 .966 .916 r
.88267 .32984 .88328 .32998 .88513 .32963 .88444 .32885 Mtetra
.658 .812 .957 r
.88444 .32885 .88513 .32963 .887 .32957 .88626 .32826 Mtetra
.658 .695 .873 r
.88626 .32826 .887 .32957 .88883 .32905 .88808 .32769 Mtetra
.637 .676 .871 r
.88808 .32769 .88883 .32905 .89065 .32849 .88992 .32723 Mtetra
.631 .691 .888 r
.88992 .32723 .89065 .32849 .89247 .32787 .89176 .3268 Mtetra
.668 .746 .908 r
.89176 .3268 .89247 .32787 .89426 .32703 .89358 .32619 Mtetra
.674 .802 .943 r
.89358 .32619 .89426 .32703 .89607 .32626 .8954 .32554 Mtetra
.675 .835 .96 r
.8954 .32554 .89607 .32626 .89789 .32566 .89721 .32486 Mtetra
.78 .766 .841 r
.30652 .51412 .30747 .51496 .30898 .51392 .30804 .51297 Mtetra
.72 .738 .865 r
.30804 .51297 .30898 .51392 .31047 .51325 .30954 .5122 Mtetra
.547 .667 .916 r
.30954 .5122 .31047 .51325 .31192 .51325 .31099 .51213 Mtetra
.935 .561 .24 r
.31099 .51213 .31192 .51325 .31311 .51738 .31217 .51635 Mtetra
.938 .683 .525 r
.31217 .51635 .31311 .51738 .30236 .71113 .30132 .71077 Mtetra
.916 .567 .362 r
.30132 .71077 .30236 .71113 .30357 .71634 .30254 .71589 Mtetra
.198 .663 .94 r
.30254 .71589 .30357 .71634 .3051 .71661 .30408 .71605 Mtetra
.701 .837 .948 r
.30408 .71605 .3051 .71661 .30668 .71605 .30566 .71537 Mtetra
.775 .811 .882 r
.30566 .71537 .30668 .71605 .30828 .7151 .30727 .7143 Mtetra
.388 .673 .973 r
.30727 .7143 .30828 .7151 .30982 .71516 .30881 .71444 Mtetra
.525 .751 .979 r
.30881 .71444 .30982 .71516 .31139 .71492 .31037 .71429 Mtetra
.744 .823 .913 r
.31037 .71429 .31139 .71492 .31299 .71397 .31197 .71342 Mtetra
.921 .758 .663 r
.31197 .71342 .31299 .71397 .31484 .70891 .31383 .70828 Mtetra
.939 .687 .53 r
.31383 .70828 .31484 .70891 .32789 .51406 .32698 .51272 Mtetra
.893 .704 .64 r
.32698 .51272 .32789 .51406 .32972 .50792 .3288 .50669 Mtetra
.754 .702 .802 r
.3288 .50669 .32972 .50792 .33125 .50667 .33033 .50553 Mtetra
.611 .673 .884 r
.33033 .50553 .33125 .50667 .33274 .5063 .33181 .50526 Mtetra
.46 .633 .929 r
.33181 .50526 .33274 .5063 .3342 .50631 .33327 .5054 Mtetra
.693 .743 .889 r
.33327 .5054 .3342 .50631 .33571 .50553 .33477 .50478 Mtetra
.688 .78 .922 r
.33477 .50478 .33571 .50553 .33721 .50491 .33627 .5042 Mtetra
.579 .765 .967 r
.33627 .5042 .33721 .50491 .33869 .50483 .33775 .50395 Mtetra
0 .216 .7 r
.33775 .50395 .33869 .50483 .34 .50754 .33916 .50496 Mtetra
0 0 .522 r
.33916 .50496 .34 .50754 .33105 .6968 .34048 .50767 Mtetra
0 0 .297 r
.34048 .50767 .33105 .6968 .3321 .70608 .33197 .68942 Mtetra
.064 0 .448 r
.33197 .68942 .3321 .70608 .3336 .70727 .33285 .70192 Mtetra
.29 .228 .613 r
.33285 .70192 .3336 .70727 .33516 .7073 .33426 .70462 Mtetra
.333 .358 .737 r
.33426 .70462 .33516 .7073 .33675 .70688 .33576 .70581 Mtetra
.297 .558 .927 r
.33576 .70581 .33675 .70688 .33831 .70693 .33731 .70626 Mtetra
.568 .779 .978 r
.33731 .70626 .33831 .70693 .33989 .70667 .33889 .70599 Mtetra
.784 .814 .876 r
.33889 .70599 .33989 .70667 .34151 .70568 .34052 .70485 Mtetra
.909 .745 .665 r
.34052 .70485 .34151 .70568 .34332 .701 .34235 .69987 Mtetra
.941 .687 .525 r
.34235 .69987 .34332 .701 .35485 .50601 .35396 .50428 Mtetra
.881 .688 .637 r
.35396 .50428 .35485 .50601 .35667 .49943 .35576 .49819 Mtetra
.772 .706 .79 r
.35576 .49819 .35667 .49943 .35822 .49797 .35731 .49683 Mtetra
.614 .675 .884 r
.35731 .49683 .35822 .49797 .35972 .4976 .3588 .49655 Mtetra
.462 .632 .927 r
.3588 .49655 .35972 .4976 .36121 .49763 .36028 .49668 Mtetra
.606 .714 .921 r
.36028 .49668 .36121 .49763 .36271 .49728 .36178 .49641 Mtetra
.66 .746 .913 r
.36178 .49641 .36271 .49728 .36422 .49678 .36329 .49593 Mtetra
.678 .756 .91 r
.36329 .49593 .36422 .49678 .36573 .49625 .3648 .49539 Mtetra
.768 .768 .853 r
.3648 .49539 .36573 .49625 .36726 .49528 .36634 .49433 Mtetra
.74 .747 .857 r
.36634 .49433 .36726 .49528 .36879 .49449 .36787 .49342 Mtetra
.618 .694 .898 r
.36787 .49342 .36879 .49449 .37029 .49428 .36938 .49312 Mtetra
.799 .351 0 r
.36938 .49312 .37029 .49428 .37166 .49698 .37075 .49567 Mtetra
.945 .685 .51 r
.37075 .49567 .37166 .49698 .36433 .68987 .36339 .68816 Mtetra
.964 .642 .349 r
.36339 .68816 .36433 .68987 .36555 .6978 .36457 .69694 Mtetra
.519 0 0 r
.36457 .69694 .36555 .6978 .36708 .69919 .36609 .69837 Mtetra
.549 .738 .964 r
.36609 .69837 .36708 .69919 .36867 .69902 .36769 .6982 Mtetra
.786 .788 .854 r
.36769 .6982 .36867 .69902 .37032 .69783 .36933 .69696 Mtetra
.904 .751 .682 r
.36933 .69696 .37032 .69783 .37208 .69376 .37111 .69267 Mtetra
.944 .688 .518 r
.37111 .69267 .37208 .69376 .38203 .49955 .38116 .49734 Mtetra
.88 .674 .619 r
.38116 .49734 .38203 .49955 .38389 .49114 .38298 .48985 Mtetra
.794 .706 .768 r
.38298 .48985 .38389 .49114 .38546 .48936 .38456 .48817 Mtetra
.622 .671 .876 r
.38456 .48817 .38546 .48936 .38698 .48896 .38607 .48785 Mtetra
.462 .62 .919 r
.38607 .48785 .38698 .48896 .38848 .48903 .38757 .48801 Mtetra
.571 .687 .919 r
.38757 .48801 .38848 .48903 .38999 .48883 .38908 .48786 Mtetra
.644 .722 .905 r
.38908 .48786 .38999 .48883 .39152 .48841 .3906 .48744 Mtetra
.655 .727 .902 r
.3906 .48744 .39152 .48841 .39304 .48796 .39213 .48698 Mtetra
.735 .744 .859 r
.39213 .48698 .39304 .48796 .39458 .4871 .39367 .48611 Mtetra
.721 .738 .865 r
.39367 .48611 .39458 .4871 .39612 .48632 .39521 .48531 Mtetra
.578 .693 .92 r
.39521 .48531 .39612 .48632 .39764 .48614 .39672 .48513 Mtetra
.858 .418 .007 r
.39672 .48513 .39764 .48614 .39904 .48895 .39812 .48803 Mtetra
.948 .684 .504 r
.39812 .48803 .39904 .48895 .39326 .68325 .39227 .68285 Mtetra
.928 .585 .361 r
.39227 .68285 .39326 .68325 .39461 .68989 .39363 .6893 Mtetra
.459 0 0 r
.39363 .6893 .39461 .68989 .39618 .691 .3952 .69039 Mtetra
.613 .813 .977 r
.3952 .69039 .39618 .691 .3978 .6906 .39682 .68997 Mtetra
.744 .833 .92 r
.39682 .68997 .3978 .6906 .39945 .68973 .39847 .68909 Mtetra
.66 .819 .96 r
.39847 .68909 .39945 .68973 .40107 .68928 .4001 .68854 Mtetra
.614 .781 .961 r
.4001 .68854 .40107 .68928 .4027 .68898 .40172 .68816 Mtetra
.705 .784 .913 r
.40172 .68816 .4027 .68898 .40434 .68817 .40336 .68745 Mtetra
.856 .802 .796 r
.40336 .68745 .40434 .68817 .40606 .68519 .40505 .68545 Mtetra
.968 .861 .68 r
.40505 .68545 .40606 .68519 .4081 .67245 .4068 .68131 Mtetra
.803 .716 .182 r
.4068 .68131 .4081 .67245 .41596 .48264 .40896 .66518 Mtetra
0 0 .321 r
.40896 .66518 .41596 .48264 .41757 .48006 .41643 .48627 Mtetra
.484 .222 .441 r
.41643 .48627 .41757 .48006 .41912 .47939 .41799 .48533 Mtetra
.575 .301 .463 r
.41799 .48533 .41912 .47939 .42065 .47924 .4195 .48593 Mtetra
.564 .297 .469 r
.4195 .48593 .42065 .47924 .42218 .47898 .42102 .48632 Mtetra
.528 .27 .467 r
.42102 .48632 .42218 .47898 .42373 .47851 .42256 .48598 Mtetra
.532 .274 .469 r
.42256 .48598 .42373 .47851 .42527 .47804 .4241 .48569 Mtetra
.535 .277 .472 r
.4241 .48569 .42527 .47804 .42681 .47758 .42565 .48545 Mtetra
.537 .28 .474 r
.42565 .48545 .42681 .47758 .42836 .47711 .42719 .48524 Mtetra
.538 .282 .476 r
.42719 .48524 .42836 .47711 .42991 .47665 .42873 .48504 Mtetra
.598 .337 .492 r
.42873 .48504 .42991 .47665 .43145 .47625 .43023 .4864 Mtetra
.64 .38 .51 r
.43023 .4864 .43145 .47625 .433 .47586 .43168 .48961 Mtetra
.47 .244 .488 r
.43168 .48961 .433 .47586 .43455 .47537 .4333 .48683 Mtetra
.166 0 .382 r
.4333 .48683 .43455 .47537 .43611 .47454 .43506 .47901 Mtetra
0 0 .139 r
.43506 .47901 .43611 .47454 .43767 .47348 .43672 .4744 Mtetra
.891 .965 .639 r
.43672 .4744 .43767 .47348 .43924 .47247 .43833 .47169 Mtetra
.813 .795 .836 r
.43833 .47169 .43924 .47247 .4408 .47172 .43991 .4703 Mtetra
.668 .655 .828 r
.43991 .4703 .4408 .47172 .44235 .47122 .44147 .46972 Mtetra
.624 .627 .833 r
.44147 .46972 .44235 .47122 .4439 .4708 .44302 .46939 Mtetra
.631 .642 .843 r
.44302 .46939 .4439 .4708 .44546 .47035 .44457 .46902 Mtetra
.655 .663 .846 r
.44457 .46902 .44546 .47035 .44701 .46986 .44613 .46853 Mtetra
.654 .664 .847 r
.44613 .46853 .44701 .46986 .44857 .46936 .44768 .46805 Mtetra
.656 .667 .849 r
.44768 .46805 .44857 .46936 .45013 .46886 .44924 .46755 Mtetra
.657 .668 .849 r
.44924 .46755 .45013 .46886 .45169 .46836 .4508 .46706 Mtetra
.652 .667 .852 r
.4508 .46706 .45169 .46836 .45325 .46787 .45236 .46659 Mtetra
.638 .665 .86 r
.45236 .46659 .45325 .46787 .45481 .46741 .45392 .46619 Mtetra
.622 .669 .874 r
.45392 .46619 .45481 .46741 .45637 .46698 .45548 .46586 Mtetra
.62 .688 .892 r
.45548 .46586 .45637 .46698 .45793 .46654 .45704 .46554 Mtetra
.633 .716 .907 r
.45704 .46554 .45793 .46654 .45949 .46608 .4586 .46516 Mtetra
.655 .742 .913 r
.4586 .46516 .45949 .46608 .46106 .46557 .46016 .46469 Mtetra
.67 .754 .914 r
.46016 .46469 .46106 .46557 .46262 .46504 .46173 .46415 Mtetra
.69 .76 .905 r
.46173 .46415 .46262 .46504 .46419 .46447 .4633 .46353 Mtetra
.704 .751 .889 r
.4633 .46353 .46419 .46447 .46576 .46389 .46487 .46284 Mtetra
.7 .729 .873 r
.46487 .46284 .46576 .46389 .46733 .46329 .46644 .46215 Mtetra
.686 .706 .863 r
.46644 .46215 .46733 .46329 .4689 .46271 .46801 .46151 Mtetra
.669 .692 .862 r
.46801 .46151 .4689 .46271 .47047 .46215 .46959 .46096 Mtetra
.664 .691 .866 r
.46959 .46096 .47047 .46215 .47204 .46161 .47116 .46044 Mtetra
.683 .702 .861 r
.47116 .46044 .47204 .46161 .47362 .46091 .47273 .45982 Mtetra
.701 .72 .864 r
.47273 .45982 .47362 .46091 .47519 .46011 .47431 .45911 Mtetra
.649 .723 .902 r
.47431 .45911 .47519 .46011 .47676 .45971 .47588 .45866 Mtetra
.348 .577 .927 r
.47588 .45866 .47676 .45971 .47832 .46067 .47744 .45904 Mtetra
0 0 .566 r
.47744 .45904 .47832 .46067 .47981 .46639 .47898 .46118 Mtetra
0 0 .429 r
.47898 .46118 .47981 .46639 .4788 .66162 .48047 .4671 Mtetra
0 0 .368 r
.48047 .4671 .4788 .66162 .48042 .66489 .47961 .65462 Mtetra
.537 .368 .6 r
.47961 .65462 .48042 .66489 .4821 .66481 .48126 .65537 Mtetra
.616 .43 .608 r
.48126 .65537 .4821 .66481 .48378 .66404 .48295 .65379 Mtetra
.63 .438 .603 r
.48295 .65379 .48378 .66404 .48546 .66316 .48465 .65153 Mtetra
.582 .397 .596 r
.48465 .65153 .48546 .66316 .48714 .66267 .48632 .65086 Mtetra
.582 .396 .595 r
.48632 .65086 .48714 .66267 .48882 .66217 .488 .65018 Mtetra
.608 .416 .596 r
.488 .65018 .48882 .66217 .4905 .66163 .48969 .64846 Mtetra
.662 .454 .592 r
.48969 .64846 .4905 .66163 .49219 .66104 .49141 .64374 Mtetra
.543 .356 .577 r
.49141 .64374 .49219 .66104 .49387 .66056 .49307 .64461 Mtetra
.347 .21 .549 r
.49307 .64461 .49387 .66056 .49555 .66037 .49468 .6519 Mtetra
.261 .176 .568 r
.49468 .6519 .49555 .66037 .49723 .66054 .49632 .6569 Mtetra
.223 .238 .665 r
.49632 .6569 .49723 .66054 .49892 .66068 .49799 .65924 Mtetra
.211 .433 .858 r
.49799 .65924 .49892 .66068 .5006 .66059 .49967 .66014 Mtetra
.512 .827 1 r
.49967 .66014 .5006 .66059 .50229 .66017 .50135 .65985 Mtetra
.612 .893 .988 r
.50135 .65985 .50229 .66017 .50398 .65967 .50305 .65927 Mtetra
.627 .881 .988 r
.50305 .65927 .50398 .65967 .50567 .65917 .50474 .6587 Mtetra
.521 .825 1 r
.50474 .6587 .50567 .65917 .50737 .65878 .50643 .6584 Mtetra
.487 .835 .996 r
.50643 .6584 .50737 .65878 .50906 .65839 .50813 .6581 Mtetra
.475 .851 .986 r
.50813 .6581 .50906 .65839 .51076 .65798 .50982 .65775 Mtetra
.503 .875 .978 r
.50982 .65775 .51076 .65798 .51245 .65754 .51152 .65731 Mtetra
.52 .883 .979 r
.51152 .65731 .51245 .65754 .51415 .65708 .51322 .65684 Mtetra
.532 .885 .982 r
.51322 .65684 .51415 .65708 .51585 .65662 .51492 .65636 Mtetra
.533 .882 .985 r
.51492 .65636 .51585 .65662 .51755 .65615 .51662 .65589 Mtetra
.537 .883 .985 r
.51662 .65589 .51755 .65615 .51925 .65568 .51832 .65541 Mtetra
.539 .883 .986 r
.51832 .65541 .51925 .65568 .52095 .6552 .52002 .65494 Mtetra
.541 .883 .986 r
.52002 .65494 .52095 .6552 .52265 .65473 .52173 .65446 Mtetra
.542 .883 .986 r
.52173 .65446 .52265 .65473 .52435 .65425 .52343 .65398 Mtetra
.543 .884 .986 r
.52343 .65398 .52435 .65425 .52606 .65377 .52514 .6535 Mtetra
.52514 .6535 .52606 .65377 .52776 .65328 .52684 .65301 Mtetra
.543 .884 .987 r
.52684 .65301 .52776 .65328 .52947 .6528 .52855 .65253 Mtetra
.544 .884 .987 r
.52855 .65253 .52947 .6528 .53118 .65232 .53026 .65204 Mtetra
.544 .884 .986 r
.53026 .65204 .53118 .65232 .53289 .65183 .53197 .65156 Mtetra
.53197 .65156 .53289 .65183 .5346 .65135 .53368 .65107 Mtetra
.53368 .65107 .5346 .65135 .53631 .65086 .53539 .65059 Mtetra
.53539 .65059 .53631 .65086 .53802 .65037 .53711 .6501 Mtetra
.53711 .6501 .53802 .65037 .53973 .64989 .53882 .64961 Mtetra
.53882 .64961 .53973 .64989 .54145 .6494 .54053 .64912 Mtetra
.545 .885 .986 r
.54053 .64912 .54145 .6494 .54316 .64891 .54225 .64863 Mtetra
.54225 .64863 .54316 .64891 .54488 .64842 .54397 .64814 Mtetra
.546 .885 .986 r
.54397 .64814 .54488 .64842 .5466 .64792 .54569 .64765 Mtetra
.546 .886 .986 r
.54569 .64765 .5466 .64792 .54832 .64742 .54741 .64716 Mtetra
.547 .887 .986 r
.54741 .64716 .54832 .64742 .55004 .64692 .54913 .64666 Mtetra
.546 .887 .985 r
.54913 .64666 .55004 .64692 .55176 .64642 .55085 .64616 Mtetra
.539 .886 .984 r
.55085 .64616 .55176 .64642 .55348 .6459 .55257 .64566 Mtetra
.542 .891 .981 r
.55257 .64566 .55348 .6459 .5552 .64538 .55429 .64515 Mtetra
.563 .9 .98 r
.55429 .64515 .5552 .64538 .55692 .64484 .55602 .64459 Mtetra
.622 .917 .979 r
.55602 .64459 .55692 .64484 .55865 .64425 .55774 .64392 Mtetra
.651 .907 .981 r
.55774 .64392 .55865 .64425 .56037 .64366 .55947 .64323 Mtetra
.66 .885 .98 r
.55947 .64323 .56037 .64366 .5621 .64308 .56119 .64257 Mtetra
.627 .855 .986 r
.56119 .64257 .5621 .64308 .56383 .64255 .56292 .64203 Mtetra
.613 .849 .988 r
.56292 .64203 .56383 .64255 .56555 .64204 .56465 .64153 Mtetra
.595 .847 .992 r
.56465 .64153 .56555 .64204 .56728 .64155 .56638 .64108 Mtetra
.498 .818 1 r
.56638 .64108 .56728 .64155 .56902 .64114 .56812 .64081 Mtetra
.547 .874 .992 r
.56812 .64081 .56902 .64114 .57075 .64067 .56985 .64035 Mtetra
.715 .923 .962 r
.56985 .64035 .57075 .64067 .57248 .64007 .57158 .63946 Mtetra
.899 .837 .775 r
.57158 .63946 .57248 .64007 .57421 .63906 .57329 .637 Mtetra
.849 .681 .674 r
.57329 .637 .57421 .63906 .57593 .63795 .57498 .63309 Mtetra
.826 .607 .605 r
.57498 .63309 .57593 .63795 .57766 .63686 .5766 .62527 Mtetra
.673 .465 .595 r
.5766 .62527 .57766 .63686 .5794 .63629 .57827 .62055 Mtetra
.539 .356 .581 r
.57827 .62055 .5794 .63629 .58114 .63587 .58002 .62158 Mtetra
.492 .324 .581 r
.58002 .62158 .58114 .63587 .58288 .63552 .58181 .62424 Mtetra
.51 .345 .594 r
.58181 .62424 .58288 .63552 .58463 .63558 .58358 .62587 Mtetra
.568 .394 .606 r
.58358 .62587 .58463 .63558 .58637 .63518 .58532 .62576 Mtetra
.661 .463 .606 r
.58532 .62576 .58637 .63518 .5881 .63388 .58701 .62246 Mtetra
.953 .676 .475 r
.58701 .62246 .5881 .63388 .5897 .62609 .5852 .43024 Mtetra
.566 .352 .549 r
.5852 .43024 .5897 .62609 .58764 .42849 .58675 .42532 Mtetra
.754 .589 .671 r
.58675 .42532 .58764 .42849 .5892 .42395 .58835 .42267 Mtetra
.719 .703 .834 r
.58835 .42267 .5892 .42395 .59083 .42287 .58999 .42177 Mtetra
.654 .712 .891 r
.58999 .42177 .59083 .42287 .59247 .42241 .59163 .42128 Mtetra
.598 .685 .903 r
.59163 .42128 .59247 .42241 .59412 .42228 .59328 .42103 Mtetra
.623 .672 .876 r
.59328 .42103 .59412 .42228 .59577 .42184 .59492 .42068 Mtetra
.621 .688 .891 r
.59492 .42068 .59577 .42184 .59741 .4214 .59657 .42033 Mtetra
.631 .711 .904 r
.59657 .42033 .59741 .4214 .59906 .42094 .59822 .41994 Mtetra
.687 .744 .895 r
.59822 .41994 .59906 .42094 .60071 .42039 .59986 .4193 Mtetra
.697 .73 .876 r
.59986 .4193 .60071 .42039 .60235 .41981 .60151 .4186 Mtetra
.693 .706 .858 r
.60151 .4186 .60235 .41981 .604 .41923 .60315 .41789 Mtetra
.668 .677 .849 r
.60315 .41789 .604 .41923 .60565 .41869 .6048 .4173 Mtetra
.66 .667 .846 r
.6048 .4173 .60565 .41869 .6073 .41816 .60645 .41676 Mtetra
.657 .663 .844 r
.60645 .41676 .6073 .41816 .60895 .41763 .6081 .41623 Mtetra
.692 .677 .831 r
.6081 .41623 .60895 .41763 .6106 .41702 .60975 .41548 Mtetra
.665 .648 .823 r
.60975 .41548 .6106 .41702 .61225 .41645 .6114 .41487 Mtetra
.611 .618 .834 r
.6114 .41487 .61225 .41645 .6139 .41598 .61306 .41459 Mtetra
.159 .392 .839 r
.61306 .41459 .6139 .41598 .61557 .41589 .61476 .41564 Mtetra
.805 .314 0 r
.61476 .41564 .61557 .41589 .61724 .41595 .6165 .41806 Mtetra
.851 .512 .41 r
.6165 .41806 .61724 .41595 .61892 .41603 .61836 .42441 Mtetra
.954 .667 .454 r
.61836 .42441 .61892 .41603 .62058 .41568 .62481 .58732 Mtetra
.148 .033 .455 r
.62481 .58732 .62058 .41568 .62224 .41513 .62243 .44845 Mtetra
.241 .089 .466 r
.62243 .44845 .62224 .41513 .6239 .4145 .62346 .42629 Mtetra
.716 .444 .512 r
.62346 .42629 .6239 .4145 .62556 .41406 .62541 .43489 Mtetra
.933 .647 .474 r
.62541 .43489 .62556 .41406 .62723 .41359 .63229 .60025 Mtetra
.055 0 .425 r
.63229 .60025 .62723 .41359 .62889 .41299 .62849 .42555 Mtetra
.128 0 .397 r
.62849 .42555 .62889 .41299 .63054 .41192 .62984 .41511 Mtetra
0 0 .099 r
.62984 .41511 .63054 .41192 .63218 .41078 .6314 .41102 Mtetra
.93 .971 .734 r
.6314 .41102 .63218 .41078 .63383 .40976 .633 .40857 Mtetra
.722 .724 .851 r
.633 .40857 .63383 .40976 .63549 .40914 .63465 .40769 Mtetra
.622 .641 .848 r
.63465 .40769 .63549 .40914 .63717 .4087 .63633 .40734 Mtetra
.576 .634 .872 r
.63633 .40734 .63717 .4087 .63884 .40831 .63801 .4072 Mtetra
.634 .706 .898 r
.63801 .4072 .63884 .40831 .64051 .40779 .63969 .40679 Mtetra
.662 .739 .907 r
.63969 .40679 .64051 .40779 .64218 .40721 .64136 .40625 Mtetra
.677 .753 .909 r
.64136 .40625 .64218 .40721 .64385 .40662 .64303 .40565 Mtetra
.743 .772 .877 r
.64303 .40565 .64385 .40662 .6455 .40565 .64469 .40471 Mtetra
.728 .773 .889 r
.64469 .40471 .6455 .40565 .64717 .40486 .64635 .40386 Mtetra
.65 .735 .911 r
.64635 .40386 .64717 .40486 .64885 .40462 .64802 .40338 Mtetra
.232 .467 .879 r
.64802 .40338 .64885 .40462 .65064 .40691 .64975 .40418 Mtetra
.066 .176 .67 r
.64975 .40418 .65064 .40691 .65987 .59765 .65155 .40673 Mtetra
.074 0 .443 r
.65155 .40673 .65987 .59765 .66223 .61176 .66023 .5823 Mtetra
.112 .032 .477 r
.66023 .5823 .66223 .61176 .66411 .61335 .66306 .60795 Mtetra
.324 .265 .635 r
.66306 .60795 .66411 .61335 .66592 .61349 .66499 .61089 Mtetra
.349 .384 .756 r
.66499 .61089 .66592 .61349 .66772 .61312 .66686 .61216 Mtetra
.463 .681 .959 r
.66686 .61216 .66772 .61312 .66952 .61269 .66868 .61223 Mtetra
.581 .863 .995 r
.66868 .61223 .66952 .61269 .67132 .61218 .67048 .61174 Mtetra
.664 .895 .98 r
.67048 .61174 .67132 .61218 .67311 .61159 .67227 .61103 Mtetra
.556 .825 .996 r
.67227 .61103 .67311 .61159 .67492 .61139 .67407 .61066 Mtetra
.591 .795 .977 r
.67407 .61066 .67492 .61139 .67673 .61109 .67588 .61028 Mtetra
.698 .811 .935 r
.67588 .61028 .67673 .61109 .67852 .61022 .67767 .60954 Mtetra
.871 .853 .822 r
.67767 .60954 .67852 .61022 .68019 .60692 .67941 .60758 Mtetra
.948 .936 .597 r
.67941 .60758 .68019 .60692 .68139 .5932 .68106 .60386 Mtetra
0 0 .338 r
.68106 .60386 .68139 .5932 .67423 .3995 .68237 .59253 Mtetra
.033 0 .424 r
.68237 .59253 .67423 .3995 .67582 .39673 .67521 .40007 Mtetra
0 0 .164 r
.67521 .40007 .67582 .39673 .67748 .39554 .67674 .39611 Mtetra
.807 .961 .638 r
.67674 .39611 .67748 .39554 .67916 .39485 .67836 .39387 Mtetra
.77 .779 .86 r
.67836 .39387 .67916 .39485 .68085 .39424 .68002 .39274 Mtetra
.66 .654 .833 r
.68002 .39274 .68085 .39424 .68255 .39371 .68172 .39216 Mtetra
.617 .628 .839 r
.68172 .39216 .68255 .39371 .68425 .39325 .68342 .39183 Mtetra
.616 .646 .857 r
.68342 .39183 .68425 .39325 .68595 .39279 .68513 .3915 Mtetra
.622 .67 .876 r
.68513 .3915 .68595 .39279 .68765 .39231 .68684 .39115 Mtetra
.628 .696 .894 r
.68684 .39115 .68765 .39231 .68935 .39181 .68855 .39076 Mtetra
.673 .736 .898 r
.68855 .39076 .68935 .39181 .69105 .39123 .69024 .39017 Mtetra
.699 .744 .886 r
.69024 .39017 .69105 .39123 .69274 .3906 .69194 .38944 Mtetra
.698 .726 .872 r
.69194 .38944 .69274 .3906 .69444 .38996 .69363 .3887 Mtetra
.706 .711 .852 r
.69363 .3887 .69444 .38996 .69613 .3891 .69532 .38789 Mtetra
.691 .714 .867 r
.69532 .38789 .69613 .3891 .69782 .38832 .69701 .38719 Mtetra
.625 .702 .901 r
.69701 .38719 .69782 .38832 .69954 .38803 .69873 .38681 Mtetra
.24 .479 .886 r
.69873 .38681 .69954 .38803 .70137 .38975 .70051 .38759 Mtetra
0 .113 .656 r
.70051 .38759 .70137 .38975 .70369 .40031 .70239 .3902 Mtetra
.083 .049 .516 r
.70239 .3902 .70369 .40031 .71637 .59548 .70466 .39977 Mtetra
.079 0 .451 r
.70466 .39977 .71637 .59548 .71833 .5973 .71689 .58584 Mtetra
.592 .405 .598 r
.71689 .58584 .71833 .5973 .72016 .5969 .71868 .58477 Mtetra
.593 .404 .595 r
.71868 .58477 .72016 .5969 .72196 .59599 .72047 .58358 Mtetra
.389 .258 .579 r
.72047 .58358 .72196 .59599 .7238 .59564 .72263 .58894 Mtetra
.317 .243 .614 r
.72263 .58894 .7238 .59564 .72567 .59577 .72471 .59279 Mtetra
.276 .314 .721 r
.72471 .59279 .72567 .59577 .72754 .59582 .72669 .5947 Mtetra
.364 .591 .932 r
.72669 .5947 .72754 .59582 .72938 .59556 .72858 .59511 Mtetra
.55 .856 .997 r
.72858 .59511 .72938 .59556 .73122 .59506 .73042 .59467 Mtetra
.629 .9 .985 r
.73042 .59467 .73122 .59506 .73305 .5945 .73225 .594 Mtetra
.595 .862 .993 r
.73225 .594 .73305 .5945 .73489 .594 .73408 .59348 Mtetra
.522 .828 1 r
.73408 .59348 .73489 .594 .73673 .59356 .73593 .59314 Mtetra
.491 .84 .996 r
.73593 .59314 .73673 .59356 .73858 .59313 .73778 .5928 Mtetra
.491 .861 .985 r
.73778 .5928 .73858 .59313 .74042 .59267 .73963 .59238 Mtetra
.509 .878 .978 r
.73963 .59238 .74042 .59267 .74226 .59218 .74148 .59189 Mtetra
.524 .884 .98 r
.74148 .59189 .74226 .59218 .74411 .59168 .74332 .59137 Mtetra
.531 .884 .983 r
.74332 .59137 .74411 .59168 .74595 .59117 .74517 .59085 Mtetra
.534 .882 .985 r
.74517 .59085 .74595 .59117 .7478 .59067 .74701 .59034 Mtetra
.537 .883 .985 r
.74701 .59034 .7478 .59067 .74965 .59015 .74886 .58983 Mtetra
.539 .883 .986 r
.74886 .58983 .74965 .59015 .75149 .58964 .75071 .58931 Mtetra
.541 .883 .986 r
.75071 .58931 .75149 .58964 .75334 .58912 .75256 .58879 Mtetra
.542 .884 .986 r
.75256 .58879 .75334 .58912 .75519 .5886 .75441 .58826 Mtetra
.543 .884 .986 r
.75441 .58826 .75519 .5886 .75704 .58807 .75626 .58774 Mtetra
.544 .884 .986 r
.75626 .58774 .75704 .58807 .7589 .58754 .75812 .58721 Mtetra
.545 .885 .986 r
.75812 .58721 .7589 .58754 .76075 .58701 .75997 .58668 Mtetra
.546 .885 .986 r
.75997 .58668 .76075 .58701 .7626 .58648 .76183 .58615 Mtetra
.547 .886 .986 r
.76183 .58615 .7626 .58648 .76446 .58594 .76368 .58561 Mtetra
.548 .887 .986 r
.76368 .58561 .76446 .58594 .76631 .5854 .76554 .58507 Mtetra
.549 .888 .985 r
.76554 .58507 .76631 .5854 .76817 .58485 .7674 .58453 Mtetra
.55 .889 .985 r
.7674 .58453 .76817 .58485 .77003 .5843 .76926 .58398 Mtetra
.553 .891 .984 r
.76926 .58398 .77003 .5843 .77188 .58373 .77111 .58342 Mtetra
.552 .892 .983 r
.77111 .58342 .77188 .58373 .77374 .58315 .77298 .58285 Mtetra
.549 .894 .98 r
.77298 .58285 .77374 .58315 .7756 .58256 .77484 .58228 Mtetra
.558 .902 .976 r
.77484 .58228 .7756 .58256 .77746 .58194 .7767 .58167 Mtetra
.592 .917 .973 r
.7767 .58167 .77746 .58194 .77931 .58129 .77855 .58098 Mtetra
.643 .928 .973 r
.77855 .58098 .77931 .58129 .78117 .58059 .7804 .58019 Mtetra
.683 .919 .972 r
.7804 .58019 .78117 .58059 .78302 .57987 .78224 .57934 Mtetra
.71 .897 .964 r
.78224 .57934 .78302 .57987 .78487 .57911 .78409 .57846 Mtetra
.723 .869 .95 r
.78409 .57846 .78487 .57911 .78672 .57832 .78593 .57756 Mtetra
.719 .839 .939 r
.78593 .57756 .78672 .57832 .78857 .57755 .78777 .57669 Mtetra
.698 .809 .934 r
.78777 .57669 .78857 .57755 .79043 .57684 .78963 .57593 Mtetra
.663 .784 .939 r
.78963 .57593 .79043 .57684 .7923 .57623 .7915 .57532 Mtetra
.633 .774 .948 r
.7915 .57532 .7923 .57623 .79417 .57569 .79337 .57482 Mtetra
.548 .748 .969 r
.79337 .57482 .79417 .57569 .79606 .57531 .79527 .5746 Mtetra
.42 .728 .989 r
.79527 .5746 .79606 .57531 .79796 .57507 .7972 .57461 Mtetra
.473 .822 .997 r
.7972 .57461 .79796 .57507 .79985 .57476 .79909 .57432 Mtetra
.749 .928 .948 r
.79909 .57432 .79985 .57476 .80174 .57434 .80093 .57325 Mtetra
.882 .797 .762 r
.80093 .57325 .80174 .57434 .80362 .57373 .80265 .57072 Mtetra
.84 .647 .641 r
.80265 .57072 .80362 .57373 .80544 .57253 .80419 .566 Mtetra
.974 .675 .388 r
.80419 .566 .80544 .57253 .80711 .56938 .78986 .37018 Mtetra
.572 .356 .549 r
.78986 .37018 .80711 .56938 .79252 .37218 .79095 .36152 Mtetra
.647 .445 .595 r
.79095 .36152 .79252 .37218 .79334 .36043 .79249 .35828 Mtetra
.753 .639 .735 r
.79249 .35828 .79334 .36043 .79491 .35751 .79416 .35655 Mtetra
.693 .773 .913 r
.79416 .35655 .79491 .35751 .79665 .3567 .79591 .35585 Mtetra
.617 .769 .953 r
.79591 .35585 .79665 .3567 .79843 .35638 .79769 .35543 Mtetra
.65 .76 .93 r
.79769 .35543 .79843 .35638 .80022 .35608 .79946 .35491 Mtetra
.728 .743 .864 r
.79946 .35491 .80022 .35608 .80198 .35538 .80119 .35398 Mtetra
.681 .686 .847 r
.80119 .35398 .80198 .35538 .80374 .35475 .80295 .35328 Mtetra
.571 .622 .864 r
.80295 .35328 .80374 .35475 .80551 .3542 .80476 .35316 Mtetra
.052 .393 .852 r
.80476 .35316 .80551 .3542 .80729 .35375 .80668 .35425 Mtetra
.807 .344 .128 r
.80668 .35425 .80729 .35375 .80912 .35379 .80876 .35709 Mtetra
.973 .665 .358 r
.80876 .35709 .80912 .35379 .81108 .35536 .82792 .5501 Mtetra
.573 .352 .543 r
.82792 .5501 .81108 .35536 .83037 .54798 .83085 .56094 Mtetra
.609 .351 .501 r
.83085 .56094 .83037 .54798 .83368 .56297 .83304 .56369 Mtetra
.601 .094 .018 r
.83304 .56369 .83368 .56297 .83585 .56538 .83509 .5647 Mtetra
.491 .775 .995 r
.83509 .5647 .83585 .56538 .83778 .56522 .83702 .56452 Mtetra
.642 .835 .974 r
.83702 .56452 .83778 .56522 .83967 .56446 .83893 .56392 Mtetra
.698 .896 .968 r
.83893 .56392 .83967 .56446 .84153 .56346 .8408 .56306 Mtetra
.708 .934 .962 r
.8408 .56306 .84153 .56346 .84342 .56267 .84267 .5621 Mtetra
.749 .9 .945 r
.84267 .5621 .84342 .56267 .8453 .56186 .84453 .56105 Mtetra
.739 .84 .927 r
.84453 .56105 .8453 .56186 .84718 .56109 .8464 .56007 Mtetra
.675 .772 .923 r
.8464 .56007 .84718 .56109 .84909 .56046 .8483 .5594 Mtetra
.652 .752 .923 r
.8483 .5594 .84909 .56046 .851 .55989 .85021 .55883 Mtetra
.62 .74 .932 r
.85021 .55883 .851 .55989 .85292 .55947 .85213 .5584 Mtetra
.564 .711 .94 r
.85213 .5584 .85292 .55947 .85488 .55942 .85408 .55819 Mtetra
.636 .713 .903 r
.85408 .55819 .85488 .55942 .8568 .55892 .856 .55771 Mtetra
.752 .762 .861 r
.856 .55771 .8568 .55892 .85861 .55725 .85786 .55656 Mtetra
.939 .864 .738 r
.85786 .55656 .85861 .55725 .85991 .55054 .85954 .55357 Mtetra
0 0 .034 r
.85954 .55357 .85991 .55054 .84166 .34813 .86087 .54718 Mtetra
.117 .03 .471 r
.86087 .54718 .84166 .34813 .84301 .34312 .84297 .34902 Mtetra
.158 0 .372 r
.84297 .34902 .84301 .34312 .84471 .34165 .84428 .34362 Mtetra
0 0 .076 r
.84428 .34362 .84471 .34165 .84648 .3408 .84586 .34087 Mtetra
.822 .998 .782 r
.84586 .34087 .84648 .3408 .84827 .34015 .84753 .33907 Mtetra
.766 .778 .863 r
.84753 .33907 .84827 .34015 .85002 .33912 .84927 .33792 Mtetra
.679 .722 .881 r
.84927 .33792 .85002 .33912 .85181 .33851 .85106 .33725 Mtetra
.546 .649 .902 r
.85106 .33725 .85181 .33851 .85369 .33873 .85291 .33719 Mtetra
.211 .399 .831 r
.85291 .33719 .85369 .33873 .85592 .3422 .8549 .33842 Mtetra
.201 .224 .66 r
.8549 .33842 .85592 .3422 .87891 .54305 .8571 .34164 Mtetra
.135 .049 .485 r
.8571 .34164 .87891 .54305 .88162 .54998 .87968 .53781 Mtetra
.284 .192 .572 r
.87968 .53781 .88162 .54998 .8837 .55078 .88256 .54623 Mtetra
.36 .315 .672 r
.88256 .54623 .8837 .55078 .88568 .55071 .88481 .54867 Mtetra
.388 .462 .815 r
.88481 .54867 .88568 .55071 .88763 .55022 .8869 .54957 Mtetra
.572 .826 .993 r
.8869 .54957 .88763 .55022 .88957 .54971 .88886 .54915 Mtetra
.678 .889 .975 r
.88886 .54915 .88957 .54971 .8915 .54908 .89077 .54835 Mtetra
.71 .855 .952 r
.89077 .54835 .8915 .54908 .89343 .54848 .89267 .54749 Mtetra
.512 .706 .958 r
.89267 .54749 .89343 .54848 .89543 .54846 .89467 .54742 Mtetra
.582 .729 .943 r
.89467 .54742 .89543 .54846 .89739 .54806 .89664 .54712 Mtetra
.704 .802 .926 r
.89664 .54712 .89739 .54806 .89926 .54684 .89856 .5463 Mtetra
.932 .907 .775 r
.89856 .5463 .89926 .54684 .9007 .54181 .90028 .54373 Mtetra
0 0 0 r
.90028 .54373 .9007 .54181 .87996 .3392 .90175 .53894 Mtetra
.135 .045 .481 r
.90175 .53894 .87996 .3392 .88099 .33161 .88143 .34084 Mtetra
.152 .007 .417 r
.88143 .34084 .88099 .33161 .88267 .32984 .88232 .33201 Mtetra
0 0 .107 r
.88232 .33201 .88267 .32984 .88444 .32885 .88384 .32876 Mtetra
.873 .994 .8 r
.88384 .32876 .88444 .32885 .88626 .32826 .8855 .32685 Mtetra
.677 .688 .853 r
.8855 .32685 .88626 .32826 .88808 .32769 .88731 .32616 Mtetra
.612 .638 .853 r
.88731 .32616 .88808 .32769 .88992 .32723 .88916 .32583 Mtetra
.577 .64 .877 r
.88916 .32583 .88992 .32723 .89176 .3268 .89104 .32566 Mtetra
.655 .727 .902 r
.89104 .32566 .89176 .3268 .89358 .32619 .89286 .32511 Mtetra
.67 .746 .908 r
.89286 .32511 .89358 .32619 .8954 .32554 .89469 .32449 Mtetra
.683 .759 .909 r
.89469 .32449 .8954 .32554 .89721 .32486 .8965 .32381 Mtetra
.769 .767 .85 r
.30557 .51328 .30652 .51412 .30804 .51297 .30708 .51222 Mtetra
.714 .782 .905 r
.30708 .51222 .30804 .51297 .30954 .5122 .30858 .51153 Mtetra
.447 .722 .984 r
.30858 .51153 .30954 .5122 .31099 .51213 .31003 .51153 Mtetra
.923 .56 .319 r
.31003 .51153 .31099 .51213 .31217 .51635 .3112 .5159 Mtetra
.937 .682 .525 r
.3112 .5159 .31217 .51635 .30132 .71077 .30031 .71002 Mtetra
.929 .571 .322 r
.30031 .71002 .30132 .71077 .30254 .71589 .30154 .71495 Mtetra
.406 .646 .955 r
.30154 .71495 .30254 .71589 .30408 .71605 .30307 .71513 Mtetra
.692 .753 .899 r
.30307 .71513 .30408 .71605 .30566 .71537 .30466 .7145 Mtetra
.759 .771 .862 r
.30466 .7145 .30566 .71537 .30727 .7143 .30627 .71346 Mtetra
.45 .691 .969 r
.30627 .71346 .30727 .7143 .30881 .71444 .30781 .71351 Mtetra
.587 .722 .937 r
.30781 .71351 .30881 .71444 .31037 .71429 .30937 .71328 Mtetra
.74 .743 .853 r
.30937 .71328 .31037 .71429 .31197 .71342 .31098 .71232 Mtetra
.896 .723 .659 r
.31098 .71232 .31197 .71342 .31383 .70828 .31285 .70706 Mtetra
.938 .686 .531 r
.31285 .70706 .31383 .70828 .32698 .51272 .32604 .51178 Mtetra
.908 .725 .643 r
.32604 .51178 .32698 .51272 .3288 .50669 .32785 .50591 Mtetra
.788 .782 .848 r
.32785 .50591 .3288 .50669 .33033 .50553 .32939 .50473 Mtetra
.609 .749 .944 r
.32939 .50473 .33033 .50553 .33181 .50526 .33087 .50443 Mtetra
.443 .676 .963 r
.33087 .50443 .33181 .50526 .33327 .5054 .33233 .50451 Mtetra
.664 .741 .908 r
.33233 .50451 .33327 .5054 .33477 .50478 .33382 .50402 Mtetra
.674 .774 .925 r
.33382 .50402 .33477 .50478 .33627 .5042 .33532 .5035 Mtetra
.639 .779 .948 r
.33532 .5035 .33627 .5042 .33775 .50395 .33681 .50308 Mtetra
.608 .73 .932 r
.33681 .50308 .33775 .50395 .33916 .50496 .3383 .50279 Mtetra
.549 .516 .771 r
.3383 .50279 .33916 .50496 .34048 .50767 .33976 .50288 Mtetra
.494 .378 .65 r
.33976 .50288 .34048 .50767 .33197 .68942 .34119 .50371 Mtetra
.544 .334 .546 r
.34119 .50371 .33197 .68942 .33285 .70192 .34232 .50994 Mtetra
0 0 .279 r
.34232 .50994 .33285 .70192 .33426 .70462 .33342 .70096 Mtetra
0 0 .477 r
.33342 .70096 .33426 .70462 .33576 .70581 .33478 .70472 Mtetra
.034 .398 .854 r
.33478 .70472 .33576 .70581 .33731 .70626 .3363 .70556 Mtetra
.575 .777 .975 r
.3363 .70556 .33731 .70626 .33889 .70599 .33789 .70528 Mtetra
.798 .808 .859 r
.33789 .70528 .33889 .70599 .34052 .70485 .33952 .70401 Mtetra
.908 .745 .667 r
.33952 .70401 .34052 .70485 .34235 .69987 .34135 .6991 Mtetra
.942 .688 .525 r
.34135 .6991 .34235 .69987 .35396 .50428 .35302 .50368 Mtetra
.927 .744 .635 r
.35302 .50368 .35396 .50428 .35576 .49819 .35482 .49743 Mtetra
.813 .788 .829 r
.35482 .49743 .35576 .49819 .35731 .49683 .35637 .49603 Mtetra
.617 .751 .942 r
.35637 .49603 .35731 .49683 .3588 .49655 .35787 .49569 Mtetra
.447 .674 .961 r
.35787 .49569 .3588 .49655 .36028 .49668 .35935 .49578 Mtetra
.609 .724 .927 r
.35935 .49578 .36028 .49668 .36178 .49641 .36085 .49549 Mtetra
.657 .734 .907 r
.36085 .49549 .36178 .49641 .36329 .49593 .36236 .49502 Mtetra
.669 .74 .904 r
.36236 .49502 .36329 .49593 .3648 .49539 .36387 .49451 Mtetra
.758 .764 .858 r
.36387 .49451 .3648 .49539 .36634 .49433 .36541 .49352 Mtetra
.737 .777 .885 r
.36541 .49352 .36634 .49433 .36787 .49342 .36694 .49269 Mtetra
.577 .756 .963 r
.36694 .49269 .36787 .49342 .36938 .49312 .36844 .49244 Mtetra
.871 .428 .096 r
.36844 .49244 .36938 .49312 .37075 .49567 .36981 .49514 Mtetra
.944 .683 .511 r
.36981 .49514 .37075 .49567 .36339 .68816 .36236 .68819 Mtetra
.92 .599 .419 r
.36236 .68819 .36339 .68816 .36457 .69694 .36358 .69615 Mtetra
.524 0 0 r
.36358 .69615 .36457 .69694 .36609 .69837 .36511 .69751 Mtetra
.562 .733 .955 r
.36511 .69751 .36609 .69837 .36769 .6982 .36671 .69732 Mtetra
.783 .777 .847 r
.36671 .69732 .36769 .6982 .36933 .69696 .36835 .69608 Mtetra
.902 .75 .683 r
.36835 .69608 .36933 .69696 .37111 .69267 .37013 .69183 Mtetra
.945 .688 .518 r
.37013 .69183 .37111 .69267 .38116 .49734 .38022 .49676 Mtetra
.935 .738 .612 r
.38022 .49676 .38116 .49734 .38298 .48985 .38206 .48907 Mtetra
.838 .785 .801 r
.38206 .48907 .38298 .48985 .38456 .48817 .38363 .48734 Mtetra
.63 .752 .935 r
.38363 .48734 .38456 .48817 .38607 .48785 .38515 .48697 Mtetra
.45 .669 .956 r
.38515 .48697 .38607 .48785 .38757 .48801 .38665 .48706 Mtetra
.578 .703 .928 r
.38665 .48706 .38757 .48801 .38908 .48786 .38816 .48687 Mtetra
.644 .718 .902 r
.38816 .48687 .38908 .48786 .3906 .48744 .38969 .48645 Mtetra
.653 .721 .899 r
.38969 .48645 .3906 .48744 .39213 .48698 .39121 .486 Mtetra
.733 .743 .86 r
.39121 .486 .39213 .48698 .39367 .48611 .39275 .48514 Mtetra
.722 .743 .868 r
.39275 .48514 .39367 .48611 .39521 .48531 .39429 .48435 Mtetra
.581 .702 .925 r
.39429 .48435 .39521 .48531 .39672 .48513 .39581 .48415 Mtetra
.841 .391 0 r
.39581 .48415 .39672 .48513 .39812 .48803 .39722 .48686 Mtetra
.948 .685 .504 r
.39722 .48686 .39812 .48803 .39227 .68285 .39133 .68109 Mtetra
.957 .615 .269 r
.39133 .68109 .39227 .68285 .39363 .6893 .39267 .6881 Mtetra
0 .294 .79 r
.39267 .6881 .39363 .6893 .3952 .69039 .39423 .68923 Mtetra
.642 .698 .886 r
.39423 .68923 .3952 .69039 .39682 .68997 .39586 .6888 Mtetra
.726 .72 .844 r
.39586 .6888 .39682 .68997 .39847 .68909 .39751 .68788 Mtetra
.688 .704 .86 r
.39751 .68788 .39847 .68909 .4001 .68854 .39914 .6872 Mtetra
.649 .671 .858 r
.39914 .6872 .4001 .68854 .40172 .68816 .40077 .68673 Mtetra
.671 .665 .836 r
.40077 .68673 .40172 .68816 .40336 .68745 .40241 .68611 Mtetra
.74 .701 .814 r
.40241 .68611 .40336 .68745 .40505 .68545 .40406 .68501 Mtetra
.847 .867 .856 r
.40406 .68501 .40505 .68545 .4068 .68131 .40573 .68343 Mtetra
.01 0 .023 r
.40573 .68343 .4068 .68131 .40896 .66518 .40741 .68165 Mtetra
.524 .292 .505 r
.40741 .68165 .40896 .66518 .41643 .48627 .40907 .68042 Mtetra
.556 .34 .542 r
.40907 .68042 .41643 .48627 .41799 .48533 .41071 .67991 Mtetra
.556 .34 .543 r
.41071 .67991 .41799 .48533 .4195 .48593 .41233 .67966 Mtetra
.41233 .67966 .4195 .48593 .42102 .48632 .41397 .67934 Mtetra
.41397 .67934 .42102 .48632 .42256 .48598 .4156 .67892 Mtetra
.4156 .67892 .42256 .48598 .4241 .48569 .41724 .67851 Mtetra
.41724 .67851 .4241 .48569 .42565 .48545 .41887 .67812 Mtetra
.41887 .67812 .42565 .48545 .42719 .48524 .42051 .67774 Mtetra
.42051 .67774 .42719 .48524 .42873 .48504 .42215 .67735 Mtetra
.556 .341 .543 r
.42215 .67735 .42873 .48504 .43023 .4864 .42378 .67735 Mtetra
.42378 .67735 .43023 .4864 .43168 .48961 .42541 .67734 Mtetra
.555 .34 .542 r
.42541 .67734 .43168 .48961 .4333 .48683 .42707 .67657 Mtetra
.549 .335 .541 r
.42707 .67657 .4333 .48683 .43506 .47901 .42882 .67232 Mtetra
0 0 .317 r
.42882 .67232 .43506 .47901 .43672 .4744 .43571 .47739 Mtetra
.829 .813 .327 r
.43571 .47739 .43672 .4744 .43833 .47169 .43742 .4714 Mtetra
.899 .872 .802 r
.43742 .4714 .43833 .47169 .43991 .4703 .43901 .46934 Mtetra
.694 .742 .888 r
.43901 .46934 .43991 .4703 .44147 .46972 .44057 .4687 Mtetra
.6 .698 .912 r
.44057 .4687 .44147 .46972 .44302 .46939 .44212 .46844 Mtetra
.607 .719 .924 r
.44212 .46844 .44302 .46939 .44457 .46902 .44367 .46815 Mtetra
.657 .752 .921 r
.44367 .46815 .44457 .46902 .44613 .46853 .44523 .46767 Mtetra
.655 .754 .923 r
.44523 .46767 .44613 .46853 .44768 .46805 .44678 .4672 Mtetra
.656 .758 .925 r
.44678 .4672 .44768 .46805 .44924 .46755 .44834 .46672 Mtetra
.656 .762 .928 r
.44834 .46672 .44924 .46755 .4508 .46706 .4499 .46625 Mtetra
.652 .765 .932 r
.4499 .46625 .4508 .46706 .45236 .46659 .45146 .46578 Mtetra
.639 .764 .938 r
.45146 .46578 .45236 .46659 .45392 .46619 .45302 .46536 Mtetra
.626 .755 .939 r
.45302 .46536 .45392 .46619 .45548 .46586 .45458 .46498 Mtetra
.628 .743 .93 r
.45458 .46498 .45548 .46586 .45704 .46554 .45614 .46461 Mtetra
.64 .735 .917 r
.45614 .46461 .45704 .46554 .4586 .46516 .45771 .4642 Mtetra
.654 .732 .907 r
.45771 .4642 .4586 .46516 .46016 .46469 .45927 .46373 Mtetra
.663 .736 .904 r
.45927 .46373 .46016 .46469 .46173 .46415 .46084 .46322 Mtetra
.676 .745 .903 r
.46084 .46322 .46173 .46415 .4633 .46353 .46241 .46266 Mtetra
.687 .762 .909 r
.46241 .46266 .4633 .46353 .46487 .46284 .46398 .46206 Mtetra
.689 .783 .922 r
.46398 .46206 .46487 .46284 .46644 .46215 .46555 .46145 Mtetra
.679 .801 .94 r
.46555 .46145 .46644 .46215 .46801 .46151 .46712 .46087 Mtetra
.662 .812 .955 r
.46712 .46087 .46801 .46151 .46959 .46096 .46869 .46034 Mtetra
.657 .817 .96 r
.46869 .46034 .46959 .46096 .47116 .46044 .47026 .45982 Mtetra
.671 .822 .956 r
.47026 .45982 .47116 .46044 .47273 .45982 .47184 .45926 Mtetra
.682 .84 .959 r
.47184 .45926 .47273 .45982 .47431 .45911 .47341 .45865 Mtetra
.632 .856 .984 r
.47341 .45865 .47431 .45911 .47588 .45866 .47499 .45815 Mtetra
.484 .79 .999 r
.47499 .45815 .47588 .45866 .47744 .45904 .47656 .45798 Mtetra
.383 .593 .927 r
.47656 .45798 .47744 .45904 .47898 .46118 .47812 .4583 Mtetra
.496 .442 .727 r
.47812 .4583 .47898 .46118 .48047 .4671 .47968 .45881 Mtetra
.552 .386 .61 r
.47968 .45881 .48047 .4671 .47961 .65462 .48125 .45909 Mtetra
.558 .346 .549 r
.48125 .45909 .47961 .65462 .48126 .65537 .48283 .45866 Mtetra
.48283 .45866 .48126 .65537 .48295 .65379 .48442 .458 Mtetra
.559 .346 .549 r
.48442 .458 .48295 .65379 .48465 .65153 .486 .45732 Mtetra
.558 .346 .549 r
.486 .45732 .48465 .65153 .48632 .65086 .48758 .45676 Mtetra
.48758 .45676 .48632 .65086 .488 .65018 .48917 .45622 Mtetra
.559 .346 .549 r
.48917 .45622 .488 .65018 .48969 .64846 .49076 .45547 Mtetra
.559 .347 .549 r
.49076 .45547 .48969 .64846 .49141 .64374 .49235 .45451 Mtetra
.558 .346 .549 r
.49235 .45451 .49141 .64374 .49307 .64461 .49393 .45412 Mtetra
.554 .343 .548 r
.49393 .45412 .49307 .64461 .49468 .6519 .4955 .45572 Mtetra
0 0 .367 r
.4955 .45572 .49468 .6519 .49632 .6569 .49545 .64871 Mtetra
0 0 .441 r
.49545 .64871 .49632 .6569 .49799 .65924 .49706 .65717 Mtetra
0 .161 .692 r
.49706 .65717 .49799 .65924 .49967 .66014 .49873 .65919 Mtetra
.553 .714 .947 r
.49873 .65919 .49967 .66014 .50135 .65985 .50042 .65903 Mtetra
.685 .789 .929 r
.50042 .65903 .50135 .65985 .50305 .65927 .50211 .65838 Mtetra
.701 .777 .911 r
.50211 .65838 .50305 .65927 .50474 .6587 .50381 .65766 Mtetra
.623 .723 .918 r
.50381 .65766 .50474 .6587 .50643 .6584 .5055 .65729 Mtetra
.625 .708 .906 r
.5055 .65729 .50643 .6584 .50813 .6581 .5072 .65691 Mtetra
.632 .696 .891 r
.5072 .65691 .50813 .6581 .50982 .65775 .50889 .6565 Mtetra
.643 .69 .879 r
.50889 .6565 .50982 .65775 .51152 .65731 .51059 .65605 Mtetra
.646 .688 .875 r
.51059 .65605 .51152 .65731 .51322 .65684 .51229 .65557 Mtetra
.647 .689 .875 r
.51229 .65557 .51322 .65684 .51492 .65636 .51399 .6551 Mtetra
.646 .689 .875 r
.51399 .6551 .51492 .65636 .51662 .65589 .51569 .65462 Mtetra
.647 .688 .875 r
.51569 .65462 .51662 .65589 .51832 .65541 .51739 .65415 Mtetra
.51739 .65415 .51832 .65541 .52002 .65494 .5191 .65367 Mtetra
.5191 .65367 .52002 .65494 .52173 .65446 .5208 .65319 Mtetra
.648 .689 .874 r
.5208 .65319 .52173 .65446 .52343 .65398 .52251 .65271 Mtetra
.52251 .65271 .52343 .65398 .52514 .6535 .52421 .65222 Mtetra
.52421 .65222 .52514 .6535 .52684 .65301 .52592 .65174 Mtetra
.52592 .65174 .52684 .65301 .52855 .65253 .52763 .65126 Mtetra
.52763 .65126 .52855 .65253 .53026 .65204 .52934 .65077 Mtetra
.52934 .65077 .53026 .65204 .53197 .65156 .53105 .65029 Mtetra
.53105 .65029 .53197 .65156 .53368 .65107 .53276 .6498 Mtetra
.53276 .6498 .53368 .65107 .53539 .65059 .53447 .64931 Mtetra
.648 .689 .875 r
.53447 .64931 .53539 .65059 .53711 .6501 .53618 .64883 Mtetra
.53618 .64883 .53711 .6501 .53882 .64961 .5379 .64834 Mtetra
.5379 .64834 .53882 .64961 .54053 .64912 .53961 .64785 Mtetra
.649 .69 .875 r
.53961 .64785 .54053 .64912 .54225 .64863 .54133 .64736 Mtetra
.54133 .64736 .54225 .64863 .54397 .64814 .54305 .64687 Mtetra
.54305 .64687 .54397 .64814 .54569 .64765 .54477 .64638 Mtetra
.54477 .64638 .54569 .64765 .54741 .64716 .54649 .64588 Mtetra
.65 .691 .875 r
.54649 .64588 .54741 .64716 .54913 .64666 .54821 .64539 Mtetra
.54821 .64539 .54913 .64666 .55085 .64616 .54993 .64489 Mtetra
.649 .691 .876 r
.54993 .64489 .55085 .64616 .55257 .64566 .55165 .64439 Mtetra
.652 .692 .875 r
.55165 .64439 .55257 .64566 .55429 .64515 .55338 .64389 Mtetra
.657 .695 .874 r
.55338 .64389 .55429 .64515 .55602 .64459 .5551 .64335 Mtetra
.67 .704 .873 r
.5551 .64335 .55602 .64459 .55774 .64392 .55683 .64275 Mtetra
.673 .717 .882 r
.55683 .64275 .55774 .64392 .55947 .64323 .55856 .64214 Mtetra
.67 .731 .896 r
.55856 .64214 .55947 .64323 .56119 .64257 .56028 .64155 Mtetra
.653 .74 .913 r
.56028 .64155 .56119 .64257 .56292 .64203 .56201 .64104 Mtetra
.648 .743 .919 r
.56201 .64104 .56292 .64203 .56465 .64153 .56374 .64054 Mtetra
.638 .742 .924 r
.56374 .64054 .56465 .64153 .56638 .64108 .56548 .64009 Mtetra
.544 .707 .946 r
.56548 .64009 .56638 .64108 .56812 .64081 .56721 .63996 Mtetra
.633 .773 .947 r
.56721 .63996 .56812 .64081 .56985 .64035 .56895 .6395 Mtetra
.775 .807 .879 r
.56895 .6395 .56985 .64035 .57158 .63946 .57067 .63835 Mtetra
.913 .754 .672 r
.57067 .63835 .57158 .63946 .57329 .637 .57236 .63397 Mtetra
.962 .688 .467 r
.57236 .63397 .57329 .637 .57498 .63309 .57133 .43978 Mtetra
.576 .36 .55 r
.57133 .43978 .57498 .63309 .5766 .62527 .57283 .42943 Mtetra
.56 .347 .549 r
.57283 .42943 .5766 .62527 .57827 .62055 .57445 .42814 Mtetra
.558 .346 .549 r
.57445 .42814 .57827 .62055 .58002 .62158 .57609 .42775 Mtetra
.557 .345 .548 r
.57609 .42775 .58002 .62158 .58181 .62424 .57773 .42783 Mtetra
.558 .346 .548 r
.57773 .42783 .58181 .62424 .58358 .62587 .57937 .42752 Mtetra
.57937 .42752 .58358 .62587 .58532 .62576 .58101 .42708 Mtetra
.559 .346 .549 r
.58101 .42708 .58532 .62576 .58701 .62246 .58265 .42635 Mtetra
.56 .348 .549 r
.58265 .42635 .58701 .62246 .5852 .43024 .58427 .42473 Mtetra
.647 .477 .64 r
.58427 .42473 .5852 .43024 .58675 .42532 .58589 .4232 Mtetra
.718 .617 .744 r
.58589 .4232 .58675 .42532 .58835 .42267 .58751 .42192 Mtetra
.698 .805 .931 r
.58751 .42192 .58835 .42267 .58999 .42177 .58915 .42124 Mtetra
.634 .846 .981 r
.58915 .42124 .58999 .42177 .59163 .42128 .59079 .42073 Mtetra
.6 .829 .987 r
.59079 .42073 .59163 .42128 .59328 .42103 .59244 .42031 Mtetra
.629 .794 .962 r
.59244 .42031 .59328 .42103 .59492 .42068 .59409 .41987 Mtetra
.636 .774 .946 r
.59409 .41987 .59492 .42068 .59657 .42033 .59573 .41943 Mtetra
.649 .754 .926 r
.59573 .41943 .59657 .42033 .59822 .41994 .59738 .41895 Mtetra
.684 .746 .899 r
.59738 .41895 .59822 .41994 .59986 .4193 .59903 .41833 Mtetra
.692 .752 .898 r
.59903 .41833 .59986 .4193 .60151 .4186 .60067 .41767 Mtetra
.693 .762 .905 r
.60067 .41767 .60151 .4186 .60315 .41789 .60232 .417 Mtetra
.678 .767 .918 r
.60232 .417 .60315 .41789 .6048 .4173 .60396 .4164 Mtetra
.672 .763 .919 r
.60396 .4164 .6048 .4173 .60645 .41676 .60561 .41583 Mtetra
.667 .757 .917 r
.60561 .41583 .60645 .41676 .6081 .41623 .60727 .41528 Mtetra
.732 .77 .883 r
.60727 .41528 .6081 .41623 .60975 .41548 .60891 .41441 Mtetra
.685 .731 .885 r
.60891 .41441 .60975 .41548 .6114 .41487 .61056 .41377 Mtetra
.559 .675 .916 r
.61056 .41377 .6114 .41487 .61306 .41459 .61223 .41365 Mtetra
.674 .198 0 r
.61223 .41365 .61306 .41459 .61476 .41564 .61396 .41608 Mtetra
.967 .681 .436 r
.61396 .41608 .61476 .41564 .6165 .41806 .62043 .58722 Mtetra
.611 .383 .546 r
.62043 .58722 .6165 .41806 .61836 .42441 .62312 .61971 Mtetra
.558 .342 .543 r
.62312 .61971 .61836 .42441 .62481 .58732 .62493 .62061 Mtetra
.55 .325 .527 r
.62493 .62061 .62481 .58732 .62243 .44845 .6267 .62011 Mtetra
.554 .339 .542 r
.6267 .62011 .62243 .44845 .62346 .42629 .62845 .61905 Mtetra
.556 .341 .543 r
.62845 .61905 .62346 .42629 .62541 .43489 .63024 .61904 Mtetra
.556 .34 .542 r
.63024 .61904 .62541 .43489 .63229 .60025 .63202 .61874 Mtetra
.53 .3 .51 r
.63202 .61874 .63229 .60025 .62849 .42555 .63377 .61755 Mtetra
.544 .331 .541 r
.63377 .61755 .62849 .42555 .62984 .41511 .63532 .61 Mtetra
0 0 .403 r
.63532 .61 .62984 .41511 .6314 .41102 .63065 .41242 Mtetra
.897 .876 .441 r
.63065 .41242 .6314 .41102 .633 .40857 .63218 .40786 Mtetra
.805 .835 .874 r
.63218 .40786 .633 .40857 .63465 .40769 .63382 .40659 Mtetra
.635 .709 .9 r
.63382 .40659 .63465 .40769 .63633 .40734 .6355 .40618 Mtetra
.547 .658 .909 r
.6355 .40618 .63633 .40734 .63801 .4072 .63718 .40611 Mtetra
.627 .707 .904 r
.63718 .40611 .63801 .4072 .63969 .40679 .63886 .40572 Mtetra
.655 .724 .899 r
.63886 .40572 .63969 .40679 .64136 .40625 .64053 .40522 Mtetra
.665 .734 .901 r
.64053 .40522 .64136 .40625 .64303 .40565 .64221 .40467 Mtetra
.705 .758 .894 r
.64221 .40467 .64303 .40565 .64469 .40471 .64387 .40394 Mtetra
.706 .807 .928 r
.64387 .40394 .64469 .40471 .64635 .40386 .64554 .40321 Mtetra
.661 .828 .964 r
.64554 .40321 .64635 .40386 .64802 .40338 .64721 .40264 Mtetra
.585 .777 .971 r
.64721 .40264 .64802 .40338 .64975 .40418 .6489 .40232 Mtetra
.536 .548 .815 r
.6489 .40232 .64975 .40418 .65155 .40673 .6506 .40244 Mtetra
.485 .391 .673 r
.6506 .40244 .65155 .40673 .66023 .5823 .65234 .40337 Mtetra
.545 .336 .548 r
.65234 .40337 .66023 .5823 .66306 .60795 .6543 .4097 Mtetra
.023 0 .425 r
.6543 .4097 .66306 .60795 .66499 .61089 .664 .60681 Mtetra
.059 .116 .608 r
.664 .60681 .66499 .61089 .66686 .61216 .66597 .61067 Mtetra
.387 .53 .878 r
.66597 .61067 .66686 .61216 .66868 .61223 .66781 .61122 Mtetra
.642 .747 .925 r
.66781 .61122 .66868 .61223 .67048 .61174 .66961 .61073 Mtetra
.72 .772 .893 r
.66961 .61073 .67048 .61174 .67227 .61103 .67139 .60987 Mtetra
.656 .721 .896 r
.67139 .60987 .67227 .61103 .67407 .61066 .67319 .60932 Mtetra
.638 .682 .875 r
.67319 .60932 .67407 .61066 .67588 .61028 .67499 .60886 Mtetra
.665 .681 .855 r
.67499 .60886 .67588 .61028 .67767 .60954 .67679 .60824 Mtetra
.702 .715 .859 r
.67679 .60824 .67767 .60954 .67941 .60758 .67858 .60742 Mtetra
.772 .974 .919 r
.67858 .60742 .67941 .60758 .68106 .60386 .68035 .60618 Mtetra
.089 0 .131 r
.68035 .60618 .68106 .60386 .68237 .59253 .68209 .6041 Mtetra
.289 .099 .441 r
.68209 .6041 .68237 .59253 .67521 .40007 .68359 .5972 Mtetra
.024 0 .421 r
.68359 .5972 .67521 .40007 .67674 .39611 .67608 .3982 Mtetra
.692 .734 .223 r
.67608 .3982 .67674 .39611 .67836 .39387 .67757 .39337 Mtetra
.866 .891 .851 r
.67757 .39337 .67836 .39387 .68002 .39274 .67921 .39171 Mtetra
.676 .743 .902 r
.67921 .39171 .68002 .39274 .68172 .39216 .68091 .39111 Mtetra
.583 .701 .923 r
.68091 .39111 .68172 .39216 .68342 .39183 .68262 .39088 Mtetra
.6 .732 .937 r
.68262 .39088 .68342 .39183 .68513 .3915 .68433 .39057 Mtetra
.626 .746 .933 r
.68433 .39057 .68513 .3915 .68684 .39115 .68603 .39017 Mtetra
.632 .737 .924 r
.68603 .39017 .68684 .39115 .68855 .39076 .68774 .38975 Mtetra
.662 .742 .909 r
.68774 .38975 .68855 .39076 .69024 .39017 .68944 .3892 Mtetra
.681 .759 .91 r
.68944 .3892 .69024 .39017 .69194 .38944 .69114 .38857 Mtetra
.686 .782 .924 r
.69114 .38857 .69194 .38944 .69363 .3887 .69284 .38793 Mtetra
.69 .806 .937 r
.69284 .38793 .69363 .3887 .69532 .38789 .69454 .38726 Mtetra
.671 .838 .964 r
.69454 .38726 .69532 .38789 .69701 .38719 .69624 .38663 Mtetra
.615 .844 .986 r
.69624 .38663 .69701 .38719 .69873 .38681 .69795 .38615 Mtetra
.453 .743 .991 r
.69795 .38615 .69873 .38681 .70051 .38759 .69968 .38609 Mtetra
.461 .556 .866 r
.69968 .38609 .70051 .38759 .70239 .3902 .70144 .38643 Mtetra
.521 .429 .692 r
.70144 .38643 .70239 .3902 .70466 .39977 .70321 .38692 Mtetra
.571 .385 .59 r
.70321 .38692 .70466 .39977 .71689 .58584 .70493 .38655 Mtetra
.559 .346 .549 r
.70493 .38655 .71689 .58584 .71868 .58477 .70662 .38567 Mtetra
.558 .346 .549 r
.70662 .38567 .71868 .58477 .72047 .58358 .70835 .38536 Mtetra
.552 .341 .548 r
.70835 .38536 .72047 .58358 .72263 .58894 .71029 .38868 Mtetra
.054 0 .443 r
.71029 .38868 .72263 .58894 .72471 .59279 .72364 .58774 Mtetra
.019 .065 .568 r
.72364 .58774 .72471 .59279 .72669 .5947 .72581 .59303 Mtetra
.246 .418 .836 r
.72581 .59303 .72669 .5947 .72858 .59511 .72774 .59414 Mtetra
.607 .747 .944 r
.72774 .59414 .72858 .59511 .73042 .59467 .72959 .59377 Mtetra
.704 .797 .923 r
.72959 .59377 .73042 .59467 .73225 .594 .73141 .59299 Mtetra
.674 .763 .917 r
.73141 .59299 .73225 .594 .73408 .59348 .73324 .59235 Mtetra
.625 .718 .913 r
.73324 .59235 .73408 .59348 .73593 .59314 .73508 .59193 Mtetra
.628 .703 .9 r
.73508 .59193 .73593 .59314 .73778 .5928 .73693 .5915 Mtetra
.637 .693 .885 r
.73693 .5915 .73778 .5928 .73963 .59238 .73878 .59104 Mtetra
.645 .688 .876 r
.73878 .59104 .73963 .59238 .74148 .59189 .74062 .59054 Mtetra
.647 .688 .874 r
.74062 .59054 .74148 .59189 .74332 .59137 .74246 .59002 Mtetra
.74246 .59002 .74332 .59137 .74517 .59085 .74431 .5895 Mtetra
.647 .687 .874 r
.74431 .5895 .74517 .59085 .74701 .59034 .74616 .58898 Mtetra
.74616 .58898 .74701 .59034 .74886 .58983 .74801 .58847 Mtetra
.74801 .58847 .74886 .58983 .75071 .58931 .74986 .58795 Mtetra
.74986 .58795 .75071 .58931 .75256 .58879 .75171 .58743 Mtetra
.648 .688 .874 r
.75171 .58743 .75256 .58879 .75441 .58826 .75356 .5869 Mtetra
.75356 .5869 .75441 .58826 .75626 .58774 .75541 .58638 Mtetra
.75541 .58638 .75626 .58774 .75812 .58721 .75726 .58585 Mtetra
.649 .688 .874 r
.75726 .58585 .75812 .58721 .75997 .58668 .75912 .58532 Mtetra
.649 .689 .874 r
.75912 .58532 .75997 .58668 .76183 .58615 .76098 .58479 Mtetra
.65 .689 .873 r
.76098 .58479 .76183 .58615 .76368 .58561 .76283 .58425 Mtetra
.651 .69 .873 r
.76283 .58425 .76368 .58561 .76554 .58507 .76469 .58371 Mtetra
.76469 .58371 .76554 .58507 .7674 .58453 .76655 .58317 Mtetra
.652 .691 .873 r
.76655 .58317 .7674 .58453 .76926 .58398 .76841 .58262 Mtetra
.654 .691 .872 r
.76841 .58262 .76926 .58398 .77111 .58342 .77027 .58205 Mtetra
.655 .692 .872 r
.77027 .58205 .77111 .58342 .77298 .58285 .77213 .58149 Mtetra
.657 .692 .871 r
.77213 .58149 .77298 .58285 .77484 .58228 .77399 .58091 Mtetra
.662 .694 .869 r
.77399 .58091 .77484 .58228 .7767 .58167 .77585 .5803 Mtetra
.672 .699 .866 r
.77585 .5803 .7767 .58167 .77855 .58098 .77771 .57963 Mtetra
.685 .708 .865 r
.77771 .57963 .77855 .58098 .7804 .58019 .77956 .5789 Mtetra
.692 .72 .871 r
.77956 .5789 .7804 .58019 .78224 .57934 .78141 .57813 Mtetra
.698 .734 .879 r
.78141 .57813 .78224 .57934 .78409 .57846 .78326 .57733 Mtetra
.701 .752 .891 r
.78326 .57733 .78409 .57846 .78593 .57756 .78511 .57653 Mtetra
.698 .771 .908 r
.78511 .57653 .78593 .57756 .78777 .57669 .78697 .57576 Mtetra
.68 .786 .93 r
.78697 .57576 .78777 .57669 .78963 .57593 .78883 .57508 Mtetra
.649 .795 .952 r
.78883 .57508 .78963 .57593 .7915 .57532 .7907 .57451 Mtetra
.625 .797 .965 r
.7907 .57451 .7915 .57532 .79337 .57482 .79258 .57401 Mtetra
.531 .758 .98 r
.79258 .57401 .79337 .57482 .79527 .5746 .79448 .57381 Mtetra
.436 .714 .983 r
.79448 .57381 .79527 .5746 .7972 .57461 .79641 .57384 Mtetra
.605 .798 .974 r
.79641 .57384 .7972 .57461 .79909 .57432 .79829 .5734 Mtetra
.85 .826 .825 r
.79829 .5734 .79909 .57432 .80093 .57325 .80007 .57154 Mtetra
.93 .731 .612 r
.80007 .57154 .80093 .57325 .80265 .57072 .8015 .56546 Mtetra
.975 .677 .385 r
.8015 .56546 .80265 .57072 .80419 .566 .78688 .36429 Mtetra
.566 .352 .549 r
.78688 .36429 .80419 .566 .78986 .37018 .78826 .35906 Mtetra
.608 .416 .596 r
.78826 .35906 .78986 .37018 .79095 .36152 .78993 .35735 Mtetra
.64 .496 .671 r
.78993 .35735 .79095 .36152 .79249 .35828 .79165 .35631 Mtetra
.665 .611 .784 r
.79165 .35631 .79249 .35828 .79416 .35655 .7934 .35558 Mtetra
.672 .763 .919 r
.7934 .35558 .79416 .35655 .79591 .35585 .79517 .35497 Mtetra
.644 .776 .944 r
.79517 .35497 .79591 .35585 .79769 .35543 .79694 .35447 Mtetra
.685 .77 .916 r
.79694 .35447 .79769 .35543 .79946 .35491 .7987 .3538 Mtetra
.739 .757 .867 r
.7987 .3538 .79946 .35491 .80119 .35398 .80043 .35281 Mtetra
.673 .722 .886 r
.80043 .35281 .80119 .35398 .80295 .35328 .80219 .35219 Mtetra
.36 .581 .926 r
.80219 .35219 .80295 .35328 .80476 .35316 .80405 .35263 Mtetra
.812 .347 0 r
.80405 .35263 .80476 .35316 .80668 .35425 .8062 .35634 Mtetra
.974 .667 .354 r
.8062 .35634 .80668 .35425 .80876 .35709 .82585 .5564 Mtetra
.565 .347 .543 r
.82585 .5564 .80876 .35709 .82792 .5501 .82833 .56238 Mtetra
.574 .322 .497 r
.82833 .56238 .82792 .5501 .83085 .56094 .83037 .5634 Mtetra
.525 .166 .301 r
.83037 .5634 .83085 .56094 .83304 .56369 .83233 .56357 Mtetra
.239 .75 .868 r
.83233 .56357 .83304 .56369 .83509 .5647 .83427 .56334 Mtetra
.621 .681 .885 r
.83427 .56334 .83509 .5647 .83702 .56452 .83618 .56294 Mtetra
.654 .663 .847 r
.83618 .56294 .83702 .56452 .83893 .56392 .83809 .56235 Mtetra
.676 .674 .841 r
.83809 .56235 .83893 .56392 .8408 .56306 .83998 .56161 Mtetra
.694 .699 .851 r
.83998 .56161 .8408 .56306 .84267 .5621 .84186 .56078 Mtetra
.706 .725 .865 r
.84186 .56078 .84267 .5621 .84453 .56105 .84374 .55991 Mtetra
.704 .755 .892 r
.84374 .55991 .84453 .56105 .8464 .56007 .84562 .55908 Mtetra
.67 .775 .928 r
.84562 .55908 .8464 .56007 .8483 .5594 .84752 .55843 Mtetra
.653 .774 .937 r
.84752 .55843 .8483 .5594 .85021 .55883 .84943 .55785 Mtetra
.634 .762 .94 r
.84943 .55785 .85021 .55883 .85213 .5584 .85135 .55735 Mtetra
.606 .736 .936 r
.85135 .55735 .85213 .5584 .85408 .55819 .85328 .55698 Mtetra
.633 .713 .905 r
.85328 .55698 .85408 .55819 .856 .55771 .85521 .55651 Mtetra
.668 .731 .897 r
.85521 .55651 .856 .55771 .85786 .55656 .85712 .55587 Mtetra
.716 .864 .952 r
.85712 .55587 .85786 .55656 .85954 .55357 .859 .55498 Mtetra
.065 0 0 r
.859 .55498 .85954 .55357 .86087 .54718 .86083 .5535 Mtetra
.359 .126 .419 r
.86083 .5535 .86087 .54718 .84297 .34902 .86249 .55036 Mtetra
.122 .033 .473 r
.86249 .55036 .84297 .34902 .84428 .34362 .84447 .35173 Mtetra
0 0 .34 r
.84447 .35173 .84428 .34362 .84586 .34087 .84527 .34126 Mtetra
.915 .938 .575 r
.84527 .34126 .84586 .34087 .84753 .33907 .8468 .33804 Mtetra
.762 .785 .872 r
.8468 .33804 .84753 .33907 .84927 .33792 .84854 .33693 Mtetra
.656 .757 .924 r
.84854 .33693 .84927 .33792 .85106 .33725 .85034 .33638 Mtetra
.551 .739 .963 r
.85034 .33638 .85106 .33725 .85291 .33719 .85218 .33617 Mtetra
.572 .714 .938 r
.85218 .33617 .85291 .33719 .8549 .33842 .85402 .33595 Mtetra
.527 .496 .765 r
.85402 .33595 .8549 .33842 .8571 .34164 .85591 .33622 Mtetra
.47 .364 .652 r
.85591 .33622 .8571 .34164 .87968 .53781 .85793 .3377 Mtetra
.164 .069 .492 r
.85793 .3377 .87968 .53781 .88256 .54623 .87924 .52111 Mtetra
.135 .068 .509 r
.87924 .52111 .88256 .54623 .88481 .54867 .88383 .54565 Mtetra
.167 .245 .7 r
.88383 .54565 .88481 .54867 .8869 .54957 .88612 .5484 Mtetra
.56 .69 .927 r
.88612 .5484 .8869 .54957 .88886 .54915 .8881 .54823 Mtetra
.695 .805 .933 r
.8881 .54823 .88886 .54915 .89077 .54835 .89002 .54745 Mtetra
.739 .824 .917 r
.89002 .54745 .89077 .54835 .89267 .54749 .89191 .54646 Mtetra
.588 .734 .944 r
.89191 .54646 .89267 .54749 .89467 .54742 .89388 .54614 Mtetra
.618 .697 .901 r
.89388 .54614 .89467 .54742 .89664 .54712 .89584 .54574 Mtetra
.656 .696 .876 r
.89584 .54574 .89664 .54712 .89856 .5463 .89778 .54514 Mtetra
.717 .762 .888 r
.89778 .54514 .89856 .5463 .90028 .54373 .89969 .54423 Mtetra
0 0 0 r
.89969 .54423 .90028 .54373 .90175 .53894 .90153 .54276 Mtetra
.266 .013 .331 r
.90153 .54276 .90175 .53894 .88143 .34084 .90325 .54009 Mtetra
.532 .323 .542 r
.90325 .54009 .88143 .34084 .88232 .33201 .90336 .52336 Mtetra
.124 .038 .478 r
.90336 .52336 .88232 .33201 .88384 .32876 .88334 .32963 Mtetra
.792 .842 .38 r
.88334 .32963 .88384 .32876 .8855 .32685 .8848 .32592 Mtetra
.737 .803 .905 r
.8848 .32592 .8855 .32685 .88731 .32616 .88658 .32498 Mtetra
.616 .701 .905 r
.88658 .32498 .88731 .32616 .88916 .32583 .88843 .32461 Mtetra
.548 .659 .909 r
.88843 .32461 .88916 .32583 .89104 .32566 .89031 .32452 Mtetra
.655 .727 .902 r
.89031 .32452 .89104 .32566 .89286 .32511 .89214 .32398 Mtetra
.662 .731 .901 r
.89214 .32398 .89286 .32511 .89469 .32449 .89397 .32339 Mtetra
.671 .742 .904 r
.89397 .32339 .89469 .32449 .8965 .32381 .89579 .32277 Mtetra
.743 .758 .865 r
.30462 .51241 .30557 .51328 .30708 .51222 .30612 .51153 Mtetra
.69 .792 .928 r
.30612 .51153 .30708 .51222 .30858 .51153 .30761 .51094 Mtetra
.413 .733 .991 r
.30761 .51094 .30858 .51153 .31003 .51153 .30906 .51094 Mtetra
.904 .506 .241 r
.30906 .51094 .31003 .51153 .3112 .5159 .3103 .51424 Mtetra
.939 .684 .524 r
.3103 .51424 .3112 .5159 .30031 .71002 .29955 .70537 Mtetra
.721 .494 0 r
.29955 .70537 .30031 .71002 .30154 .71495 .30065 .71229 Mtetra
.402 .401 .744 r
.30065 .71229 .30154 .71495 .30307 .71513 .30213 .71318 Mtetra
.559 .55 .801 r
.30213 .71318 .30307 .71513 .30466 .7145 .30368 .71318 Mtetra
.642 .667 .859 r
.30368 .71318 .30466 .7145 .30627 .71346 .30525 .71276 Mtetra
.464 .734 .986 r
.30525 .71276 .30627 .71346 .30781 .71351 .3068 .71272 Mtetra
.637 .768 .942 r
.3068 .71272 .30781 .71351 .30937 .71328 .30837 .7123 Mtetra
.76 .752 .845 r
.30837 .7123 .30937 .71328 .31098 .71232 .30999 .7112 Mtetra
.884 .726 .681 r
.30999 .7112 .31098 .71232 .31285 .70706 .3118 .70694 Mtetra
.939 .688 .53 r
.3118 .70694 .31285 .70706 .32604 .51178 .32483 .51537 Mtetra
.969 .855 .452 r
.32483 .51537 .32604 .51178 .32785 .50591 .32681 .50678 Mtetra
.728 .954 .66 r
.32681 .50678 .32785 .50591 .32939 .50473 .32838 .50501 Mtetra
.577 .942 .849 r
.32838 .50501 .32939 .50473 .33087 .50443 .32989 .50416 Mtetra
.591 .885 .991 r
.32989 .50416 .33087 .50443 .33233 .50451 .33138 .50369 Mtetra
.677 .762 .915 r
.33138 .50369 .33233 .50451 .33382 .50402 .33288 .50315 Mtetra
.665 .747 .911 r
.33288 .50315 .33382 .50402 .33532 .5035 .33438 .50267 Mtetra
.656 .754 .922 r
.33438 .50267 .33532 .5035 .33681 .50308 .33587 .50221 Mtetra
.757 .762 .857 r
.33587 .50221 .33681 .50308 .3383 .50279 .3374 .50123 Mtetra
.688 .641 .798 r
.3374 .50123 .3383 .50279 .33976 .50288 .33891 .50049 Mtetra
.584 .521 .749 r
.33891 .50049 .33976 .50288 .34119 .50371 .34039 .50037 Mtetra
0 0 .523 r
.34039 .50037 .34119 .50371 .34232 .50994 .34169 .50356 Mtetra
.949 .692 .512 r
.34169 .50356 .34232 .50994 .33342 .70096 .33259 .69704 Mtetra
.804 .533 0 r
.33259 .69704 .33342 .70096 .33478 .70472 .33379 .70374 Mtetra
0 .265 .75 r
.33379 .70374 .33478 .70472 .3363 .70556 .3353 .70477 Mtetra
.598 .761 .956 r
.3353 .70477 .3363 .70556 .33789 .70528 .33689 .70446 Mtetra
.793 .785 .846 r
.33689 .70446 .33789 .70528 .33952 .70401 .33853 .70317 Mtetra
.897 .754 .695 r
.33853 .70317 .33952 .70401 .34135 .6991 .3403 .69928 Mtetra
.943 .689 .524 r
.3403 .69928 .34135 .6991 .35302 .50368 .35174 .50937 Mtetra
.885 .795 .307 r
.35174 .50937 .35302 .50368 .35482 .49743 .35379 .49839 Mtetra
.772 .956 .638 r
.35379 .49839 .35482 .49743 .35637 .49603 .35538 .49634 Mtetra
.56 .934 .823 r
.35538 .49634 .35637 .49603 .35787 .49569 .35691 .49546 Mtetra
.575 .889 .989 r
.35691 .49546 .35787 .49569 .35935 .49578 .35842 .49499 Mtetra
.665 .769 .927 r
.35842 .49499 .35935 .49578 .36085 .49549 .35993 .4945 Mtetra
.658 .721 .896 r
.35993 .4945 .36085 .49549 .36236 .49502 .36144 .49403 Mtetra
.648 .718 .899 r
.36144 .49403 .36236 .49502 .36387 .49451 .36295 .49361 Mtetra
.742 .757 .865 r
.36295 .49361 .36387 .49451 .36541 .49352 .36448 .49272 Mtetra
.721 .776 .896 r
.36448 .49272 .36541 .49352 .36694 .49269 .366 .49197 Mtetra
.535 .748 .974 r
.366 .49197 .36694 .49269 .36844 .49244 .3675 .49182 Mtetra
.883 .451 .14 r
.3675 .49182 .36844 .49244 .36981 .49514 .36886 .49469 Mtetra
.944 .683 .511 r
.36886 .49469 .36981 .49514 .36236 .68819 .36134 .68819 Mtetra
.917 .589 .407 r
.36134 .68819 .36236 .68819 .36358 .69615 .36259 .69536 Mtetra
.46 0 0 r
.36259 .69536 .36358 .69615 .36511 .69751 .36412 .69661 Mtetra
.583 .73 .944 r
.36412 .69661 .36511 .69751 .36671 .69732 .36572 .69637 Mtetra
.774 .764 .844 r
.36572 .69637 .36671 .69732 .36835 .69608 .36737 .69517 Mtetra
.889 .756 .709 r
.36737 .69517 .36835 .69608 .37013 .69183 .36911 .69173 Mtetra
.95 .721 .557 r
.36911 .69173 .37013 .69183 .38022 .49676 .37149 .67372 Mtetra
0 0 .268 r
.37149 .67372 .38022 .49676 .38206 .48907 .38105 .49015 Mtetra
.82 .953 .61 r
.38105 .49015 .38206 .48907 .38363 .48734 .38266 .48771 Mtetra
.553 .926 .791 r
.38266 .48771 .38363 .48734 .38515 .48697 .3842 .48677 Mtetra
.566 .896 .984 r
.3842 .48677 .38515 .48697 .38665 .48706 .38572 .48628 Mtetra
.651 .771 .937 r
.38572 .48628 .38665 .48706 .38816 .48687 .38725 .48583 Mtetra
.65 .711 .892 r
.38725 .48583 .38816 .48687 .38969 .48645 .38877 .48539 Mtetra
.638 .703 .893 r
.38877 .48539 .38969 .48645 .39121 .486 .3903 .485 Mtetra
.727 .739 .861 r
.3903 .485 .39121 .486 .39275 .48514 .39184 .48418 Mtetra
.721 .744 .87 r
.39184 .48418 .39275 .48514 .39429 .48435 .39338 .48339 Mtetra
.582 .705 .927 r
.39338 .48339 .39429 .48435 .39581 .48415 .3949 .48319 Mtetra
.835 .38 0 r
.3949 .48319 .39581 .48415 .39722 .48686 .39631 .48582 Mtetra
.948 .685 .504 r
.39631 .48582 .39722 .48686 .39133 .68109 .39037 .67974 Mtetra
.955 .616 .318 r
.39037 .67974 .39133 .68109 .39267 .6881 .3917 .68707 Mtetra
0 .262 .755 r
.3917 .68707 .39267 .6881 .39423 .68923 .39326 .68818 Mtetra
.658 .724 .898 r
.39326 .68818 .39423 .68923 .39586 .6888 .39489 .68767 Mtetra
.742 .733 .843 r
.39489 .68767 .39586 .6888 .39751 .68788 .39654 .68666 Mtetra
.71 .71 .848 r
.39654 .68666 .39751 .68788 .39914 .6872 .39819 .68584 Mtetra
.666 .674 .848 r
.39819 .68584 .39914 .6872 .40077 .68673 .39982 .68527 Mtetra
.659 .658 .838 r
.39982 .68527 .40077 .68673 .40241 .68611 .40145 .68473 Mtetra
.652 .665 .85 r
.40145 .68473 .40241 .68611 .40406 .68501 .40309 .68423 Mtetra
.64 .779 .948 r
.40309 .68423 .40406 .68501 .40573 .68343 .40472 .68378 Mtetra
0 0 0 r
.40472 .68378 .40573 .68343 .40741 .68165 .40635 .68334 Mtetra
.374 0 .153 r
.40635 .68334 .40741 .68165 .40907 .68042 .40799 .6829 Mtetra
.439 .093 .281 r
.40799 .6829 .40907 .68042 .41071 .67991 .40962 .68246 Mtetra
.443 .101 .289 r
.40962 .68246 .41071 .67991 .41233 .67966 .41126 .68201 Mtetra
.432 .081 .267 r
.41126 .68201 .41233 .67966 .41397 .67934 .4129 .68157 Mtetra
.425 .067 .251 r
.4129 .68157 .41397 .67934 .4156 .67892 .41454 .68113 Mtetra
.425 .065 .249 r
.41454 .68113 .4156 .67892 .41724 .67851 .41618 .6807 Mtetra
.426 .065 .247 r
.41618 .6807 .41724 .67851 .41887 .67812 .41782 .68028 Mtetra
.426 .063 .244 r
.41782 .68028 .41887 .67812 .42051 .67774 .41946 .67987 Mtetra
.423 .059 .239 r
.41946 .67987 .42051 .67774 .42215 .67735 .4211 .67946 Mtetra
.471 .105 .261 r
.4211 .67946 .42215 .67735 .42378 .67735 .42273 .6793 Mtetra
.464 .088 .24 r
.42273 .6793 .42378 .67735 .42541 .67734 .42437 .67915 Mtetra
.326 0 .145 r
.42437 .67915 .42541 .67734 .42707 .67657 .42602 .67848 Mtetra
0 0 0 r
.42602 .67848 .42707 .67657 .42882 .67232 .42773 .67583 Mtetra
.976 .835 .431 r
.42773 .67583 .42882 .67232 .43571 .47739 .42965 .66559 Mtetra
0 0 .309 r
.42965 .66559 .43571 .47739 .43742 .4714 .43645 .47285 Mtetra
.765 .887 .476 r
.43645 .47285 .43742 .4714 .43901 .46934 .43807 .46991 Mtetra
0 0 0 r
.43807 .46991 .43901 .46934 .44057 .4687 .43963 .46921 Mtetra
.221 0 0 r
.43963 .46921 .44057 .4687 .44212 .46844 .44118 .46906 Mtetra
.244 0 0 r
.44118 .46906 .44212 .46844 .44367 .46815 .44273 .46887 Mtetra
.124 0 0 r
.44273 .46887 .44367 .46815 .44523 .46767 .44429 .46842 Mtetra
.14 0 0 r
.44429 .46842 .44523 .46767 .44678 .4672 .44584 .46797 Mtetra
.178 0 0 r
.44584 .46797 .44678 .4672 .44834 .46672 .4474 .46757 Mtetra
.215 0 0 r
.4474 .46757 .44834 .46672 .4499 .46625 .44896 .46718 Mtetra
.19 0 0 r
.44896 .46718 .4499 .46625 .45146 .46578 .45052 .46668 Mtetra
0 0 0 r
.45052 .46668 .45146 .46578 .45302 .46536 .45209 .46586 Mtetra
.504 .884 .693 r
.45209 .46586 .45302 .46536 .45458 .46498 .45367 .46479 Mtetra
.773 .94 .935 r
.45367 .46479 .45458 .46498 .45614 .46461 .45525 .46376 Mtetra
.724 .775 .893 r
.45525 .46376 .45614 .46461 .45771 .4642 .45682 .46298 Mtetra
.663 .686 .862 r
.45682 .46298 .45771 .4642 .45927 .46373 .45838 .46246 Mtetra
.647 .671 .86 r
.45838 .46246 .45927 .46373 .46084 .46322 .45995 .46201 Mtetra
.65 .683 .868 r
.45995 .46201 .46084 .46322 .46241 .46266 .46152 .46156 Mtetra
.662 .706 .881 r
.46152 .46156 .46241 .46266 .46398 .46206 .46309 .46105 Mtetra
.662 .727 .898 r
.46309 .46105 .46398 .46206 .46555 .46145 .46466 .46055 Mtetra
.655 .749 .919 r
.46466 .46055 .46555 .46145 .46712 .46087 .46623 .46008 Mtetra
.645 .771 .94 r
.46623 .46008 .46712 .46087 .46869 .46034 .4678 .45963 Mtetra
.641 .791 .954 r
.4678 .45963 .46869 .46034 .47026 .45982 .46937 .45918 Mtetra
.645 .81 .962 r
.46937 .45918 .47026 .45982 .47184 .45926 .47094 .4587 Mtetra
.651 .835 .971 r
.47094 .4587 .47184 .45926 .47341 .45865 .47252 .45818 Mtetra
.649 .86 .98 r
.47252 .45818 .47341 .45865 .47499 .45815 .47409 .45764 Mtetra
.663 .852 .972 r
.47409 .45764 .47499 .45815 .47656 .45798 .47567 .45707 Mtetra
.682 .755 .906 r
.47567 .45707 .47656 .45798 .47812 .4583 .47725 .45648 Mtetra
.657 .608 .788 r
.47725 .45648 .47812 .4583 .47968 .45881 .47883 .45589 Mtetra
.629 .523 .714 r
.47883 .45589 .47968 .45881 .48125 .45909 .48041 .45532 Mtetra
.614 .485 .681 r
.48041 .45532 .48125 .45909 .48283 .45866 .48199 .45477 Mtetra
.612 .481 .678 r
.48199 .45477 .48283 .45866 .48442 .458 .48357 .45423 Mtetra
.613 .485 .681 r
.48357 .45423 .48442 .458 .486 .45732 .48515 .45369 Mtetra
.615 .49 .686 r
.48515 .45369 .486 .45732 .48758 .45676 .48673 .45315 Mtetra
.615 .49 .687 r
.48673 .45315 .48758 .45676 .48917 .45622 .48832 .45262 Mtetra
.625 .497 .686 r
.48832 .45262 .48917 .45622 .49076 .45547 .4899 .45196 Mtetra
.638 .507 .687 r
.4899 .45196 .49076 .45547 .49235 .45451 .49149 .45115 Mtetra
.609 .494 .697 r
.49149 .45115 .49235 .45451 .49393 .45412 .49307 .45073 Mtetra
.473 .405 .701 r
.49307 .45073 .49393 .45412 .4955 .45572 .49465 .45151 Mtetra
0 0 .417 r
.49465 .45151 .4955 .45572 .49545 .64871 .49619 .45674 Mtetra
0 0 .352 r
.49619 .45674 .49545 .64871 .49706 .65717 .49615 .65282 Mtetra
.051 .093 .586 r
.49615 .65282 .49706 .65717 .49873 .65919 .49781 .65652 Mtetra
.567 .508 .748 r
.49781 .65652 .49873 .65919 .50042 .65903 .4995 .65651 Mtetra
.652 .564 .743 r
.4995 .65651 .50042 .65903 .50211 .65838 .50119 .65578 Mtetra
.665 .567 .735 r
.50119 .65578 .50211 .65838 .50381 .65766 .50289 .65489 Mtetra
.621 .533 .734 r
.50289 .65489 .50381 .65766 .5055 .65729 .50458 .65442 Mtetra
.62 .528 .729 r
.50458 .65442 .5055 .65729 .5072 .65691 .50628 .65395 Mtetra
.619 .523 .724 r
.50628 .65395 .5072 .65691 .50889 .6565 .50797 .65347 Mtetra
.617 .519 .72 r
.50797 .65347 .50889 .6565 .51059 .65605 .50967 .653 Mtetra
.616 .518 .72 r
.50967 .653 .51059 .65605 .51229 .65557 .51137 .65253 Mtetra
.617 .518 .72 r
.51137 .65253 .51229 .65557 .51399 .6551 .51307 .65206 Mtetra
.617 .519 .721 r
.51307 .65206 .51399 .6551 .51569 .65462 .51477 .65159 Mtetra
.51477 .65159 .51569 .65462 .51739 .65415 .51647 .65111 Mtetra
.51647 .65111 .51739 .65415 .5191 .65367 .51817 .65064 Mtetra
.618 .52 .721 r
.51817 .65064 .5191 .65367 .5208 .65319 .51988 .65016 Mtetra
.51988 .65016 .5208 .65319 .52251 .65271 .52158 .64968 Mtetra
.52158 .64968 .52251 .65271 .52421 .65222 .52329 .6492 Mtetra
.52329 .6492 .52421 .65222 .52592 .65174 .52499 .64871 Mtetra
.52499 .64871 .52592 .65174 .52763 .65126 .5267 .64823 Mtetra
.5267 .64823 .52763 .65126 .52934 .65077 .52841 .64775 Mtetra
.52841 .64775 .52934 .65077 .53105 .65029 .53012 .64726 Mtetra
.618 .521 .721 r
.53012 .64726 .53105 .65029 .53276 .6498 .53183 .64677 Mtetra
.53183 .64677 .53276 .6498 .53447 .64931 .53354 .64629 Mtetra
.53354 .64629 .53447 .64931 .53618 .64883 .53526 .6458 Mtetra
.53526 .6458 .53618 .64883 .5379 .64834 .53697 .64531 Mtetra
.53697 .64531 .5379 .64834 .53961 .64785 .53869 .64483 Mtetra
.618 .521 .722 r
.53869 .64483 .53961 .64785 .54133 .64736 .5404 .64434 Mtetra
.619 .521 .722 r
.5404 .64434 .54133 .64736 .54305 .64687 .54212 .64385 Mtetra
.54212 .64385 .54305 .64687 .54477 .64638 .54384 .64336 Mtetra
.54384 .64336 .54477 .64638 .54649 .64588 .54556 .64286 Mtetra
.619 .522 .722 r
.54556 .64286 .54649 .64588 .54821 .64539 .54728 .64237 Mtetra
.54728 .64237 .54821 .64539 .54993 .64489 .549 .64187 Mtetra
.62 .522 .722 r
.549 .64187 .54993 .64489 .55165 .64439 .55072 .64136 Mtetra
.62 .522 .721 r
.55072 .64136 .55165 .64439 .55338 .64389 .55245 .64086 Mtetra
.55245 .64086 .55338 .64389 .5551 .64335 .55417 .64034 Mtetra
.621 .524 .722 r
.55417 .64034 .5551 .64335 .55683 .64275 .5559 .63983 Mtetra
.622 .528 .727 r
.5559 .63983 .55683 .64275 .55856 .64214 .55763 .63931 Mtetra
.623 .533 .732 r
.55763 .63931 .55856 .64214 .56028 .64155 .55935 .6388 Mtetra
.622 .537 .737 r
.55935 .6388 .56028 .64155 .56201 .64104 .56108 .63832 Mtetra
.623 .538 .739 r
.56108 .63832 .56201 .64104 .56374 .64054 .56281 .63783 Mtetra
.618 .536 .74 r
.56281 .63783 .56374 .64054 .56548 .64009 .56455 .63738 Mtetra
.562 .504 .748 r
.56455 .63738 .56548 .64009 .56721 .63996 .56629 .63741 Mtetra
.62 .547 .75 r
.56629 .63741 .56721 .63996 .56895 .6395 .56802 .63697 Mtetra
.713 .598 .726 r
.56802 .63697 .56895 .6395 .57067 .63835 .56974 .63551 Mtetra
.886 .669 .602 r
.56974 .63551 .57067 .63835 .57236 .63397 .57137 .62726 Mtetra
.958 .683 .472 r
.57137 .62726 .57236 .63397 .57133 .43978 .57036 .43008 Mtetra
.682 .475 .6 r
.57036 .43008 .57133 .43978 .57283 .42943 .57194 .42575 Mtetra
.65 .511 .681 r
.57194 .42575 .57283 .42943 .57445 .42814 .57356 .42471 Mtetra
.609 .493 .696 r
.57356 .42471 .57445 .42814 .57609 .42775 .5752 .42426 Mtetra
.582 .474 .697 r
.5752 .42426 .57609 .42775 .57773 .42783 .57684 .42411 Mtetra
.611 .486 .685 r
.57684 .42411 .57773 .42783 .57937 .42752 .57847 .4236 Mtetra
.608 .479 .679 r
.57847 .4236 .57937 .42752 .58101 .42708 .58011 .42311 Mtetra
.606 .476 .678 r
.58011 .42311 .58101 .42708 .58265 .42635 .58175 .42263 Mtetra
.607 .483 .686 r
.58175 .42263 .58265 .42635 .58427 .42473 .58339 .42217 Mtetra
.623 .539 .739 r
.58339 .42217 .58427 .42473 .58589 .4232 .58503 .4217 Mtetra
.648 .645 .833 r
.58503 .4217 .58589 .4232 .58751 .42192 .58667 .42121 Mtetra
.67 .809 .95 r
.58667 .42121 .58751 .42192 .58915 .42124 .58831 .42064 Mtetra
.67 .838 .964 r
.58831 .42064 .58915 .42124 .59079 .42073 .58996 .42004 Mtetra
.676 .816 .951 r
.58996 .42004 .59079 .42073 .59244 .42031 .5916 .41944 Mtetra
.686 .772 .917 r
.5916 .41944 .59244 .42031 .59409 .41987 .59324 .41881 Mtetra
.671 .727 .891 r
.59324 .41881 .59409 .41987 .59573 .41943 .59489 .41824 Mtetra
.649 .694 .879 r
.59489 .41824 .59573 .41943 .59738 .41895 .59653 .41777 Mtetra
.561 .659 .902 r
.59653 .41777 .59738 .41895 .59903 .41833 .59819 .41766 Mtetra
.433 .727 .988 r
.59819 .41766 .59903 .41833 .60067 .41767 .59985 .41766 Mtetra
.013 .587 .719 r
.59985 .41766 .60067 .41767 .60232 .417 .60152 .41765 Mtetra
.116 0 0 r
.60152 .41765 .60232 .417 .60396 .4164 .60317 .4172 Mtetra
.1 0 0 r
.60317 .4172 .60396 .4164 .60561 .41583 .60482 .41659 Mtetra
.046 0 0 r
.60482 .41659 .60561 .41583 .60727 .41528 .60647 .41592 Mtetra
0 0 0 r
.60647 .41592 .60727 .41528 .60891 .41441 .60811 .41488 Mtetra
.60811 .41488 .60891 .41441 .61056 .41377 .60976 .41419 Mtetra
.293 0 0 r
.60976 .41419 .61056 .41377 .61223 .41365 .61143 .41424 Mtetra
.881 .499 .31 r
.61143 .41424 .61223 .41365 .61396 .41608 .61324 .41903 Mtetra
.964 .678 .442 r
.61324 .41903 .61396 .41608 .62043 .58722 .62042 .61731 Mtetra
.6 .364 .53 r
.62042 .61731 .62043 .58722 .62312 .61971 .62233 .62192 Mtetra
.555 .188 .3 r
.62233 .62192 .62312 .61971 .62493 .62061 .62412 .62233 Mtetra
.376 0 .162 r
.62412 .62233 .62493 .62061 .6267 .62011 .6259 .62184 Mtetra
.276 0 .116 r
.6259 .62184 .6267 .62011 .62845 .61905 .62766 .62096 Mtetra
.459 .077 .227 r
.62766 .62096 .62845 .61905 .63024 .61904 .62944 .62079 Mtetra
.409 .017 .181 r
.62944 .62079 .63024 .61904 .63202 .61874 .63122 .62043 Mtetra
.242 0 .094 r
.63122 .62043 .63202 .61874 .63377 .61755 .63298 .61945 Mtetra
0 0 0 r
.63298 .61945 .63377 .61755 .63532 .61 .63465 .61553 Mtetra
.977 .697 .428 r
.63465 .61553 .63532 .61 .63065 .41242 .63014 .42138 Mtetra
0 0 .196 r
.63014 .42138 .63065 .41242 .63218 .40786 .63142 .4088 Mtetra
.634 .853 .473 r
.63142 .4088 .63218 .40786 .63382 .40659 .63303 .40658 Mtetra
.699 .978 .907 r
.63303 .40658 .63382 .40659 .6355 .40618 .63468 .40554 Mtetra
.666 .832 .963 r
.63468 .40554 .6355 .40618 .63718 .40611 .63635 .40495 Mtetra
.658 .708 .884 r
.63635 .40495 .63718 .40611 .63886 .40572 .63802 .40443 Mtetra
.639 .675 .869 r
.63802 .40443 .63886 .40572 .64053 .40522 .6397 .404 Mtetra
.628 .684 .883 r
.6397 .404 .64053 .40522 .64221 .40467 .64138 .40362 Mtetra
.657 .728 .901 r
.64138 .40362 .64221 .40467 .64387 .40394 .64306 .40311 Mtetra
.67 .784 .934 r
.64306 .40311 .64387 .40394 .64554 .40321 .64473 .40253 Mtetra
.67 .823 .957 r
.64473 .40253 .64554 .40321 .64721 .40264 .6464 .40194 Mtetra
.755 .836 .914 r
.6464 .40194 .64721 .40264 .6489 .40232 .64807 .40098 Mtetra
.7 .693 .84 r
.64807 .40098 .6489 .40232 .6506 .40244 .64973 .4002 Mtetra
.6 .549 .769 r
.64973 .4002 .6506 .40244 .65234 .40337 .65143 .39994 Mtetra
.261 .27 .68 r
.65143 .39994 .65234 .40337 .6543 .4097 .65322 .40216 Mtetra
.978 .689 .399 r
.65322 .40216 .6543 .4097 .664 .60681 .66254 .59106 Mtetra
0 0 .46 r
.66254 .59106 .664 .60681 .66597 .61067 .66501 .6073 Mtetra
.353 .343 .708 r
.66501 .6073 .66597 .61067 .66781 .61122 .66689 .60895 Mtetra
.544 .526 .786 r
.66689 .60895 .66781 .61122 .66961 .61073 .66872 .60907 Mtetra
.623 .629 .835 r
.66872 .60907 .66961 .61073 .67139 .60987 .67052 .60868 Mtetra
.634 .708 .9 r
.67052 .60868 .67139 .60987 .67319 .60932 .67232 .60824 Mtetra
.648 .734 .912 r
.67232 .60824 .67319 .60932 .67499 .60886 .67413 .60773 Mtetra
.665 .731 .899 r
.67413 .60773 .67499 .60886 .67679 .60824 .67592 .60714 Mtetra
.576 .7 .927 r
.67592 .60714 .67679 .60824 .67858 .60742 .67774 .60692 Mtetra
.515 .827 1 r
.67774 .60692 .67858 .60742 .68035 .60618 .67956 .6066 Mtetra
0 0 0 r
.67956 .6066 .68035 .60618 .68209 .6041 .68134 .60572 Mtetra
.68134 .60572 .68209 .6041 .68359 .5972 .68302 .60228 Mtetra
.949 .747 .285 r
.68302 .60228 .68359 .5972 .67608 .3982 .6839 .58197 Mtetra
.016 0 .418 r
.6839 .58197 .67608 .3982 .67757 .39337 .67687 .39457 Mtetra
0 0 0 r
.67687 .39457 .67757 .39337 .67921 .39171 .67848 .39232 Mtetra
.032 0 0 r
.67848 .39232 .67921 .39171 .68091 .39111 .68018 .39174 Mtetra
.269 0 0 r
.68018 .39174 .68091 .39111 .68262 .39088 .6819 .39158 Mtetra
0 0 0 r
.6819 .39158 .68262 .39088 .68433 .39057 .68359 .39083 Mtetra
.556 .923 .766 r
.68359 .39083 .68433 .39057 .68603 .39017 .68526 .38974 Mtetra
.765 .913 .939 r
.68526 .38974 .68603 .39017 .68774 .38975 .68694 .38872 Mtetra
.703 .751 .89 r
.68694 .38872 .68774 .38975 .68944 .3892 .68863 .38798 Mtetra
.661 .699 .874 r
.68863 .38798 .68944 .3892 .69114 .38857 .69033 .38743 Mtetra
.647 .708 .892 r
.69033 .38743 .69114 .38857 .69284 .38793 .69204 .38695 Mtetra
.645 .743 .921 r
.69204 .38695 .69284 .38793 .69454 .38726 .69375 .38648 Mtetra
.641 .79 .954 r
.69375 .38648 .69454 .38726 .69624 .38663 .69546 .38599 Mtetra
.635 .825 .973 r
.69546 .38599 .69624 .38663 .69795 .38615 .69717 .38548 Mtetra
.661 .827 .964 r
.69717 .38548 .69795 .38615 .69968 .38609 .69887 .3849 Mtetra
.678 .712 .874 r
.69887 .3849 .69968 .38609 .70144 .38643 .70058 .38427 Mtetra
.65 .583 .767 r
.70058 .38427 .70144 .38643 .70321 .38692 .70228 .38363 Mtetra
.644 .522 .699 r
.70228 .38363 .70321 .38692 .70493 .38655 .70397 .38277 Mtetra
.631 .499 .683 r
.70397 .38277 .70493 .38655 .70662 .38567 .70567 .38197 Mtetra
.595 .478 .691 r
.70567 .38197 .70662 .38567 .70835 .38536 .7074 .38166 Mtetra
.386 .344 .689 r
.7074 .38166 .70835 .38536 .71029 .38868 .70924 .38329 Mtetra
0 0 .3 r
.70924 .38329 .71029 .38868 .72364 .58774 .71156 .3932 Mtetra
.045 0 .44 r
.71156 .3932 .72364 .58774 .72581 .59303 .72481 .58941 Mtetra
.324 .315 .695 r
.72481 .58941 .72581 .59303 .72774 .59414 .7268 .59143 Mtetra
.601 .531 .748 r
.7268 .59143 .72774 .59414 .72959 .59377 .72865 .59113 Mtetra
.664 .571 .74 r
.72865 .59113 .72959 .59377 .73141 .59299 .73046 .59021 Mtetra
.65 .556 .735 r
.73046 .59021 .73141 .59299 .73324 .59235 .73228 .58942 Mtetra
.621 .532 .732 r
.73228 .58942 .73324 .59235 .73508 .59193 .73412 .5889 Mtetra
.62 .526 .726 r
.73412 .5889 .73508 .59193 .73693 .5915 .73596 .58837 Mtetra
.618 .521 .722 r
.73596 .58837 .73693 .5915 .73878 .59104 .7378 .58785 Mtetra
.617 .518 .719 r
.7378 .58785 .73878 .59104 .74062 .59054 .73965 .58734 Mtetra
.616 .517 .719 r
.73965 .58734 .74062 .59054 .74246 .59002 .74149 .58683 Mtetra
.617 .518 .719 r
.74149 .58683 .74246 .59002 .74431 .5895 .74334 .58632 Mtetra
.74334 .58632 .74431 .5895 .74616 .58898 .74518 .5858 Mtetra
.74518 .5858 .74616 .58898 .74801 .58847 .74703 .58528 Mtetra
.74703 .58528 .74801 .58847 .74986 .58795 .74888 .58477 Mtetra
.617 .518 .72 r
.74888 .58477 .74986 .58795 .75171 .58743 .75073 .58425 Mtetra
.617 .519 .72 r
.75073 .58425 .75171 .58743 .75356 .5869 .75258 .58373 Mtetra
.618 .519 .72 r
.75258 .58373 .75356 .5869 .75541 .58638 .75444 .5832 Mtetra
.75444 .5832 .75541 .58638 .75726 .58585 .75629 .58268 Mtetra
.75629 .58268 .75726 .58585 .75912 .58532 .75814 .58215 Mtetra
.618 .52 .72 r
.75814 .58215 .75912 .58532 .76098 .58479 .76 .58162 Mtetra
.619 .52 .72 r
.76 .58162 .76098 .58479 .76283 .58425 .76186 .58108 Mtetra
.76186 .58108 .76283 .58425 .76469 .58371 .76371 .58054 Mtetra
.62 .521 .72 r
.76371 .58054 .76469 .58371 .76655 .58317 .76557 .57998 Mtetra
.621 .521 .719 r
.76557 .57998 .76655 .58317 .76841 .58262 .76743 .57942 Mtetra
.622 .521 .719 r
.76743 .57942 .76841 .58262 .77027 .58205 .76929 .57885 Mtetra
.623 .521 .718 r
.76929 .57885 .77027 .58205 .77213 .58149 .77115 .57826 Mtetra
.624 .521 .717 r
.77115 .57826 .77213 .58149 .77399 .58091 .77301 .57765 Mtetra
.625 .521 .715 r
.77301 .57765 .77399 .58091 .77585 .5803 .77486 .57702 Mtetra
.631 .523 .713 r
.77486 .57702 .77585 .5803 .77771 .57963 .77672 .57631 Mtetra
.636 .525 .71 r
.77672 .57631 .77771 .57963 .77956 .5789 .77857 .57553 Mtetra
.628 .518 .71 r
.77857 .57553 .77956 .5789 .78141 .57813 .78042 .57485 Mtetra
.601 .506 .718 r
.78042 .57485 .78141 .57813 .78326 .57733 .78231 .57449 Mtetra
.567 .505 .746 r
.78231 .57449 .78326 .57733 .78511 .57653 .78422 .57449 Mtetra
.56 .559 .81 r
.78422 .57449 .78511 .57653 .78697 .57576 .78613 .57448 Mtetra
.572 .669 .904 r
.78613 .57448 .78697 .57576 .78883 .57508 .78803 .5743 Mtetra
.599 .795 .974 r
.78803 .5743 .78883 .57508 .7907 .57451 .78992 .57388 Mtetra
.628 .846 .983 r
.78992 .57388 .7907 .57451 .79258 .57401 .79179 .57331 Mtetra
.641 .83 .973 r
.79179 .57331 .79258 .57401 .79448 .57381 .79367 .57273 Mtetra
.663 .749 .914 r
.79367 .57273 .79448 .57381 .79641 .57384 .79554 .57213 Mtetra
.729 .678 .801 r
.79554 .57213 .79641 .57384 .79829 .5734 .79737 .57093 Mtetra
.823 .661 .682 r
.79737 .57093 .79829 .5734 .80007 .57154 .79902 .56758 Mtetra
.976 .678 .382 r
.79902 .56758 .80007 .57154 .8015 .56546 .78469 .36789 Mtetra
.573 .356 .549 r
.78469 .36789 .8015 .56546 .78688 .36429 .78573 .35854 Mtetra
.69 .503 .629 r
.78573 .35854 .78688 .36429 .78826 .35906 .78732 .3558 Mtetra
.634 .518 .705 r
.78732 .3558 .78826 .35906 .78993 .35735 .78906 .35506 Mtetra
.599 .549 .77 r
.78906 .35506 .78993 .35735 .79165 .35631 .79085 .3548 Mtetra
.599 .63 .854 r
.79085 .3548 .79165 .35631 .7934 .35558 .79264 .35455 Mtetra
.684 .753 .904 r
.79264 .35455 .7934 .35558 .79517 .35497 .7944 .35388 Mtetra
.672 .736 .898 r
.7944 .35388 .79517 .35497 .79694 .35447 .79617 .35327 Mtetra
.659 .71 .885 r
.79617 .35327 .79694 .35447 .7987 .3538 .79793 .35271 Mtetra
.637 .723 .91 r
.79793 .35271 .7987 .3538 .80043 .35281 .79971 .35226 Mtetra
.36 .729 .988 r
.79971 .35226 .80043 .35281 .80219 .35219 .80154 .3523 Mtetra
.671 .124 0 r
.80154 .3523 .80219 .35219 .80405 .35263 .8035 .35389 Mtetra
.974 .667 .352 r
.8035 .35389 .80405 .35263 .8062 .35634 .82239 .54722 Mtetra
.578 .356 .543 r
.82239 .54722 .8062 .35634 .82585 .5564 .82561 .56167 Mtetra
.65 .343 .439 r
.82561 .56167 .82585 .5564 .82833 .56238 .82777 .56404 Mtetra
.448 .044 .179 r
.82777 .56404 .82833 .56238 .83037 .5634 .82971 .56391 Mtetra
0 0 0 r
.82971 .56391 .83037 .5634 .83233 .56357 .83159 .56312 Mtetra
.77 .933 .938 r
.83159 .56312 .83233 .56357 .83427 .56334 .83344 .56195 Mtetra
.759 .733 .828 r
.83344 .56195 .83427 .56334 .83618 .56294 .83528 .56065 Mtetra
.717 .623 .752 r
.83528 .56065 .83618 .56294 .83809 .56235 .83711 .55927 Mtetra
.658 .548 .719 r
.83711 .55927 .83809 .56235 .83998 .56161 .83897 .55829 Mtetra
.567 .484 .721 r
.83897 .55829 .83998 .56161 .84186 .56078 .84093 .55829 Mtetra
.547 .516 .773 r
.84093 .55829 .84186 .56078 .84374 .55991 .8429 .55841 Mtetra
.552 .625 .878 r
.8429 .55841 .84374 .55991 .84562 .55908 .84486 .55836 Mtetra
.62 .821 .978 r
.84486 .55836 .84562 .55908 .84752 .55843 .84678 .55784 Mtetra
.634 .862 .985 r
.84678 .55784 .84752 .55843 .84943 .55785 .84868 .55722 Mtetra
.647 .856 .979 r
.84868 .55722 .84943 .55785 .85135 .55735 .85059 .55657 Mtetra
.639 .814 .967 r
.85059 .55657 .85135 .55735 .85328 .55698 .8525 .55601 Mtetra
.645 .77 .939 r
.8525 .55601 .85328 .55698 .85521 .55651 .85442 .55546 Mtetra
.608 .737 .936 r
.85442 .55546 .85521 .55651 .85712 .55587 .85636 .55508 Mtetra
.418 .706 .982 r
.85636 .55508 .85712 .55587 .859 .55498 .85834 .55514 Mtetra
0 0 0 r
.85834 .55514 .859 .55498 .86083 .5535 .86027 .55471 Mtetra
.86027 .55471 .86083 .5535 .86249 .55036 .86208 .55298 Mtetra
.757 .686 .14 r
.86208 .55298 .86249 .55036 .84447 .35173 .8632 .5445 Mtetra
.081 .005 .461 r
.8632 .5445 .84447 .35173 .84527 .34126 .84463 .34112 Mtetra
.992 .877 .606 r
.84463 .34112 .84527 .34126 .8468 .33804 .84605 .33684 Mtetra
.733 .742 .859 r
.84605 .33684 .8468 .33804 .84854 .33693 .84781 .33585 Mtetra
.616 .719 .919 r
.84781 .33585 .84854 .33693 .85034 .33638 .84963 .33548 Mtetra
.556 .733 .958 r
.84963 .33548 .85034 .33638 .85218 .33617 .85147 .33526 Mtetra
.746 .808 .902 r
.85147 .33526 .85218 .33617 .85402 .33595 .85323 .33429 Mtetra
.663 .645 .822 r
.85323 .33429 .85402 .33595 .85591 .33622 .85502 .33364 Mtetra
.546 .5 .756 r
.85502 .33364 .85591 .33622 .85793 .3377 .8569 .33379 Mtetra
.173 .201 .649 r
.8569 .33379 .85793 .3377 .87924 .52111 .85914 .33732 Mtetra
.072 .006 .468 r
.85914 .33732 .87924 .52111 .88383 .54565 .88244 .5387 Mtetra
.138 .126 .58 r
.88244 .5387 .88383 .54565 .88612 .5484 .88515 .54545 Mtetra
.474 .446 .747 r
.88515 .54545 .88612 .5484 .8881 .54823 .88723 .54621 Mtetra
.571 .571 .815 r
.88723 .54621 .8881 .54823 .89002 .54745 .88922 .54613 Mtetra
.636 .696 .889 r
.88922 .54613 .89002 .54745 .89191 .54646 .89117 .54564 Mtetra
.6 .793 .973 r
.89117 .54564 .89191 .54646 .89388 .54614 .89313 .54521 Mtetra
.641 .783 .949 r
.89313 .54521 .89388 .54614 .89584 .54574 .89508 .54466 Mtetra
.651 .752 .924 r
.89508 .54466 .89584 .54574 .89778 .54514 .89702 .54409 Mtetra
.529 .701 .948 r
.89702 .54409 .89778 .54514 .89969 .54423 .89902 .54398 Mtetra
.446 .862 .954 r
.89902 .54398 .89969 .54423 .90153 .54276 .90098 .54351 Mtetra
0 0 0 r
.90098 .54351 .90153 .54276 .90325 .54009 .90285 .54225 Mtetra
.90285 .54225 .90325 .54009 .90336 .52336 .9043 .53729 Mtetra
.965 .668 .257 r
.9043 .53729 .90336 .52336 .88334 .32963 .8833 .33455 Mtetra
0 0 .246 r
.8833 .33455 .88334 .32963 .8848 .32592 .88429 .32662 Mtetra
0 0 0 r
.88429 .32662 .8848 .32592 .88658 .32498 .88597 .32483 Mtetra
.662 .967 .919 r
.88597 .32483 .88658 .32498 .88843 .32461 .88775 .32383 Mtetra
.657 .814 .958 r
.88775 .32383 .88843 .32461 .89031 .32452 .88957 .32323 Mtetra
.664 .702 .875 r
.88957 .32323 .89031 .32452 .89214 .32398 .8914 .32262 Mtetra
.642 .682 .872 r
.8914 .32262 .89214 .32398 .89397 .32339 .89323 .32213 Mtetra
.633 .694 .889 r
.89323 .32213 .89397 .32339 .89579 .32277 .89508 .32169 Mtetra
.712 .744 .877 r
.30367 .51149 .30462 .51241 .30612 .51153 .30517 .51078 Mtetra
.681 .777 .923 r
.30517 .51078 .30612 .51153 .30761 .51094 .30665 .51023 Mtetra
.555 .753 .97 r
.30665 .51023 .30761 .51094 .30906 .51094 .30812 .51004 Mtetra
0 .064 .559 r
.30812 .51004 .30906 .51094 .3103 .51424 .30949 .51127 Mtetra
0 0 .45 r
.30949 .51127 .3103 .51424 .29955 .70537 .31073 .51449 Mtetra
0 0 .267 r
.31073 .51449 .29955 .70537 .30065 .71229 .30028 .70129 Mtetra
.121 .046 .491 r
.30028 .70129 .30065 .71229 .30213 .71318 .30135 .70876 Mtetra
.255 .225 .631 r
.30135 .70876 .30213 .71318 .30368 .71318 .30274 .71113 Mtetra
.272 .376 .787 r
.30274 .71113 .30368 .71318 .30525 .71276 .30423 .71217 Mtetra
.407 .739 .992 r
.30423 .71217 .30525 .71276 .3068 .71272 .30577 .71216 Mtetra
.671 .834 .962 r
.30577 .71216 .3068 .71272 .30837 .7123 .30736 .71158 Mtetra
.783 .804 .87 r
.30736 .71158 .30837 .7123 .30999 .7112 .30898 .71044 Mtetra
.861 .778 .768 r
.30898 .71044 .30999 .7112 .3118 .70694 .31067 .70814 Mtetra
.976 .922 .64 r
.31067 .70814 .3118 .70694 .32483 .51537 .31247 .70399 Mtetra
0 0 .268 r
.31247 .70399 .32483 .51537 .32681 .50678 .32507 .51916 Mtetra
0 0 .256 r
.32507 .51916 .32681 .50678 .32838 .50501 .3272 .50809 Mtetra
0 0 0 r
.3272 .50809 .32838 .50501 .32989 .50416 .32886 .50487 Mtetra
.832 .991 .735 r
.32886 .50487 .32989 .50416 .33138 .50369 .33043 .50297 Mtetra
.742 .794 .894 r
.33043 .50297 .33138 .50369 .33288 .50315 .33195 .50214 Mtetra
.66 .714 .888 r
.33195 .50214 .33288 .50315 .33438 .50267 .33345 .50166 Mtetra
.626 .707 .904 r
.33345 .50166 .33438 .50267 .33587 .50221 .33493 .50133 Mtetra
.767 .762 .848 r
.33493 .50133 .33587 .50221 .3374 .50123 .33646 .50026 Mtetra
.731 .741 .86 r
.33646 .50026 .3374 .50123 .33891 .50049 .33798 .49942 Mtetra
.594 .682 .903 r
.33798 .49942 .33891 .50049 .34039 .50037 .33947 .4992 Mtetra
.876 .451 .037 r
.33947 .4992 .34039 .50037 .34169 .50356 .34077 .50224 Mtetra
.942 .684 .517 r
.34077 .50224 .34169 .50356 .33259 .69704 .33162 .69568 Mtetra
.956 .624 .345 r
.33162 .69568 .33259 .69704 .33379 .70374 .33279 .70292 Mtetra
0 .271 .728 r
.33279 .70292 .33379 .70374 .3353 .70477 .33431 .70386 Mtetra
.624 .739 .929 r
.33431 .70386 .3353 .70477 .33689 .70446 .3359 .70349 Mtetra
.769 .757 .842 r
.3359 .70349 .33689 .70446 .33853 .70317 .33753 .70232 Mtetra
.852 .774 .775 r
.33753 .70232 .33853 .70317 .3403 .69928 .33921 .70017 Mtetra
.976 .917 .667 r
.33921 .70017 .3403 .69928 .35174 .50937 .34099 .69627 Mtetra
0 0 .314 r
.34099 .69627 .35174 .50937 .35379 .49839 .35156 .52257 Mtetra
0 0 .276 r
.35156 .52257 .35379 .49839 .35538 .49634 .35423 .49974 Mtetra
0 0 .049 r
.35423 .49974 .35538 .49634 .35691 .49546 .35589 .49634 Mtetra
.776 .964 .661 r
.35589 .49634 .35691 .49546 .35842 .49499 .35747 .49437 Mtetra
.761 .822 .9 r
.35747 .49437 .35842 .49499 .35993 .4945 .359 .49345 Mtetra
.661 .71 .885 r
.359 .49345 .35993 .4945 .36144 .49403 .36052 .49297 Mtetra
.615 .692 .899 r
.36052 .49297 .36144 .49403 .36295 .49361 .36202 .49267 Mtetra
.734 .75 .865 r
.36202 .49267 .36295 .49361 .36448 .49272 .36355 .49182 Mtetra
.717 .755 .882 r
.36355 .49182 .36448 .49272 .366 .49197 .36508 .49108 Mtetra
.557 .71 .943 r
.36508 .49108 .366 .49197 .3675 .49182 .36657 .49093 Mtetra
.877 .441 .071 r
.36657 .49093 .3675 .49182 .36886 .49469 .36793 .49383 Mtetra
.945 .684 .511 r
.36793 .49383 .36886 .49469 .36134 .68819 .36035 .68743 Mtetra
.941 .606 .367 r
.36035 .68743 .36134 .68819 .36259 .69536 .3616 .69453 Mtetra
0 .162 .632 r
.3616 .69453 .36259 .69536 .36412 .69661 .36314 .69566 Mtetra
.607 .728 .931 r
.36314 .69566 .36412 .69661 .36572 .69637 .36474 .69535 Mtetra
.756 .751 .847 r
.36474 .69535 .36572 .69637 .36737 .69517 .36638 .69427 Mtetra
.842 .77 .782 r
.36638 .69427 .36737 .69517 .36911 .69173 .36807 .69224 Mtetra
.969 .904 .697 r
.36807 .69224 .36911 .69173 .37149 .67372 .36982 .68865 Mtetra
.086 0 .356 r
.36982 .68865 .37149 .67372 .38105 .49015 .3719 .67752 Mtetra
0 0 .294 r
.3719 .67752 .38105 .49015 .38266 .48771 .38153 .49159 Mtetra
0 0 .112 r
.38153 .49159 .38266 .48771 .3842 .48677 .38319 .48785 Mtetra
.706 .913 .565 r
.38319 .48785 .3842 .48677 .38572 .48628 .38479 .48576 Mtetra
.779 .848 .903 r
.38479 .48576 .38572 .48628 .38725 .48583 .38633 .48475 Mtetra
.66 .705 .88 r
.38633 .48475 .38725 .48583 .38877 .48539 .38786 .48426 Mtetra
.61 .679 .89 r
.38786 .48426 .38877 .48539 .3903 .485 .38938 .48399 Mtetra
.718 .734 .864 r
.38938 .48399 .3903 .485 .39184 .48418 .39092 .48321 Mtetra
.72 .744 .871 r
.39092 .48321 .39184 .48418 .39338 .48339 .39246 .48243 Mtetra
.575 .702 .929 r
.39246 .48243 .39338 .48339 .3949 .48319 .39398 .48225 Mtetra
.856 .41 .009 r
.39398 .48225 .3949 .48319 .39631 .48582 .39538 .48504 Mtetra
.948 .684 .504 r
.39538 .48504 .39631 .48582 .39037 .67974 .38936 .6798 Mtetra
.915 .58 .392 r
.38936 .6798 .39037 .67974 .3917 .68707 .39071 .68657 Mtetra
.455 0 0 r
.39071 .68657 .3917 .68707 .39326 .68818 .39228 .68757 Mtetra
.675 .829 .957 r
.39228 .68757 .39326 .68818 .39489 .68767 .39391 .68696 Mtetra
.781 .815 .88 r
.39391 .68696 .39489 .68767 .39654 .68666 .39557 .68583 Mtetra
.742 .787 .888 r
.39557 .68583 .39654 .68666 .39819 .68584 .39721 .68491 Mtetra
.685 .755 .905 r
.39721 .68491 .39819 .68584 .39982 .68527 .39885 .68428 Mtetra
.67 .741 .903 r
.39885 .68428 .39982 .68527 .40145 .68473 .40049 .68373 Mtetra
.639 .729 .914 r
.40049 .68373 .40145 .68473 .40309 .68423 .40212 .6833 Mtetra
.611 .736 .934 r
.40212 .6833 .40309 .68423 .40472 .68378 .40375 .68297 Mtetra
.597 .761 .957 r
.40375 .68297 .40472 .68378 .40635 .68334 .40538 .68265 Mtetra
.612 .795 .969 r
.40538 .68265 .40635 .68334 .40799 .6829 .40701 .68226 Mtetra
.629 .812 .97 r
.40701 .68226 .40799 .6829 .40962 .68246 .40865 .6818 Mtetra
.635 .811 .967 r
.40865 .6818 .40962 .68246 .41126 .68201 .41028 .68133 Mtetra
.634 .803 .964 r
.41028 .68133 .41126 .68201 .4129 .68157 .41192 .68087 Mtetra
.63 .797 .963 r
.41192 .68087 .4129 .68157 .41454 .68113 .41356 .68043 Mtetra
.627 .796 .963 r
.41356 .68043 .41454 .68113 .41618 .6807 .4152 .68 Mtetra
.622 .794 .965 r
.4152 .68 .41618 .6807 .41782 .68028 .41684 .67958 Mtetra
.618 .793 .966 r
.41684 .67958 .41782 .68028 .41946 .67987 .41849 .67917 Mtetra
.617 .793 .966 r
.41849 .67917 .41946 .67987 .4211 .67946 .42013 .67877 Mtetra
.548 .773 .982 r
.42013 .67877 .4211 .67946 .42273 .6793 .42177 .67854 Mtetra
.555 .758 .972 r
.42177 .67854 .42273 .6793 .42437 .67915 .4234 .67831 Mtetra
.669 .776 .93 r
.4234 .67831 .42437 .67915 .42602 .67848 .42506 .67775 Mtetra
.842 .81 .819 r
.42506 .67775 .42602 .67848 .42773 .67583 .42674 .676 Mtetra
.964 .868 .693 r
.42674 .676 .42773 .67583 .42965 .66559 .42848 .67217 Mtetra
0 0 0 r
.42848 .67217 .42965 .66559 .43645 .47285 .4304 .66166 Mtetra
0 0 .332 r
.4304 .66166 .43645 .47285 .43807 .46991 .43696 .47679 Mtetra
.487 .23 .45 r
.43696 .47679 .43807 .46991 .43963 .46921 .43853 .47578 Mtetra
.586 .315 .473 r
.43853 .47578 .43963 .46921 .44118 .46906 .44006 .47666 Mtetra
.591 .326 .484 r
.44006 .47666 .44118 .46906 .44273 .46887 .44158 .47775 Mtetra
.545 .292 .483 r
.44158 .47775 .44273 .46887 .44429 .46842 .44313 .47771 Mtetra
.546 .295 .486 r
.44313 .47771 .44429 .46842 .44584 .46797 .44469 .47768 Mtetra
.608 .35 .501 r
.44469 .47768 .44584 .46797 .4474 .46757 .4462 .47955 Mtetra
.722 .457 .526 r
.4462 .47955 .4474 .46757 .44896 .46718 .44754 .48866 Mtetra
.4 .197 .485 r
.44754 .48866 .44896 .46718 .45052 .46668 .44927 .4812 Mtetra
.156 0 .393 r
.44927 .4812 .45052 .46668 .45209 .46586 .45106 .47103 Mtetra
0 0 .19 r
.45106 .47103 .45209 .46586 .45367 .46479 .45273 .46594 Mtetra
.845 .937 .566 r
.45273 .46594 .45367 .46479 .45525 .46376 .45435 .46308 Mtetra
.832 .816 .834 r
.45435 .46308 .45525 .46376 .45682 .46298 .45593 .46156 Mtetra
.674 .66 .828 r
.45593 .46156 .45682 .46298 .45838 .46246 .4575 .46094 Mtetra
.628 .628 .831 r
.4575 .46094 .45838 .46246 .45995 .46201 .45907 .46058 Mtetra
.63 .64 .842 r
.45907 .46058 .45995 .46201 .46152 .46156 .46063 .46021 Mtetra
.657 .664 .845 r
.46063 .46021 .46152 .46156 .46309 .46105 .4622 .45971 Mtetra
.652 .662 .847 r
.4622 .45971 .46309 .46105 .46466 .46055 .46377 .45923 Mtetra
.64 .66 .854 r
.46377 .45923 .46466 .46055 .46623 .46008 .46534 .45881 Mtetra
.624 .664 .868 r
.46534 .45881 .46623 .46008 .4678 .45963 .46691 .45847 Mtetra
.622 .683 .886 r
.46691 .45847 .4678 .45963 .46937 .45918 .46848 .45814 Mtetra
.634 .711 .902 r
.46848 .45814 .46937 .45918 .47094 .4587 .47005 .45775 Mtetra
.656 .737 .909 r
.47005 .45775 .47094 .4587 .47252 .45818 .47163 .45727 Mtetra
.671 .75 .91 r
.47163 .45727 .47252 .45818 .47409 .45764 .4732 .45673 Mtetra
.689 .756 .902 r
.4732 .45673 .47409 .45764 .47567 .45707 .47478 .45611 Mtetra
.703 .747 .886 r
.47478 .45611 .47567 .45707 .47725 .45648 .47636 .45541 Mtetra
.7 .725 .87 r
.47636 .45541 .47725 .45648 .47883 .45589 .47794 .45471 Mtetra
.685 .702 .859 r
.47794 .45471 .47883 .45589 .48041 .45532 .47952 .45407 Mtetra
.667 .685 .857 r
.47952 .45407 .48041 .45532 .48199 .45477 .4811 .45352 Mtetra
.662 .683 .859 r
.4811 .45352 .48199 .45477 .48357 .45423 .48269 .45299 Mtetra
.662 .685 .862 r
.48269 .45299 .48357 .45423 .48515 .45369 .48427 .45248 Mtetra
.664 .69 .864 r
.48427 .45248 .48515 .45369 .48673 .45315 .48585 .45194 Mtetra
.663 .691 .866 r
.48585 .45194 .48673 .45315 .48832 .45262 .48743 .45142 Mtetra
.678 .697 .861 r
.48743 .45142 .48832 .45262 .4899 .45196 .48902 .45081 Mtetra
.698 .713 .86 r
.48902 .45081 .4899 .45196 .49149 .45115 .49061 .45011 Mtetra
.65 .716 .897 r
.49061 .45011 .49149 .45115 .49307 .45073 .49219 .44965 Mtetra
.398 .599 .927 r
.49219 .44965 .49307 .45073 .49465 .45151 .49377 .44995 Mtetra
0 .01 .582 r
.49377 .44995 .49465 .45151 .49619 .45674 .49534 .45202 Mtetra
0 0 .421 r
.49534 .45202 .49619 .45674 .49615 .65282 .49688 .45769 Mtetra
0 0 .372 r
.49688 .45769 .49615 .65282 .49781 .65652 .49695 .64657 Mtetra
.528 .363 .601 r
.49695 .64657 .49781 .65652 .4995 .65651 .49862 .6475 Mtetra
.608 .426 .61 r
.49862 .6475 .4995 .65651 .50119 .65578 .50032 .64623 Mtetra
.626 .437 .607 r
.50032 .64623 .50119 .65578 .50289 .65489 .50202 .64429 Mtetra
.576 .396 .6 r
.50202 .64429 .50289 .65489 .50458 .65442 .50371 .64387 Mtetra
.577 .397 .601 r
.50371 .64387 .50458 .65442 .50628 .65395 .5054 .64342 Mtetra
.5054 .64342 .50628 .65395 .50797 .65347 .50709 .64299 Mtetra
.576 .396 .601 r
.50709 .64299 .50797 .65347 .50967 .653 .50878 .64257 Mtetra
.576 .397 .601 r
.50878 .64257 .50967 .653 .51137 .65253 .51048 .64216 Mtetra
.576 .397 .602 r
.51048 .64216 .51137 .65253 .51307 .65206 .51217 .64175 Mtetra
.577 .397 .602 r
.51217 .64175 .51307 .65206 .51477 .65159 .51387 .64132 Mtetra
.577 .398 .602 r
.51387 .64132 .51477 .65159 .51647 .65111 .51557 .64089 Mtetra
.577 .398 .603 r
.51557 .64089 .51647 .65111 .51817 .65064 .51726 .64045 Mtetra
.578 .399 .603 r
.51726 .64045 .51817 .65064 .51988 .65016 .51896 .64 Mtetra
.51896 .64 .51988 .65016 .52158 .64968 .52067 .63955 Mtetra
.52067 .63955 .52158 .64968 .52329 .6492 .52237 .63909 Mtetra
.578 .4 .603 r
.52237 .63909 .52329 .6492 .52499 .64871 .52407 .63862 Mtetra
.52407 .63862 .52499 .64871 .5267 .64823 .52577 .63816 Mtetra
.579 .4 .603 r
.52577 .63816 .5267 .64823 .52841 .64775 .52748 .63769 Mtetra
.579 .4 .604 r
.52748 .63769 .52841 .64775 .53012 .64726 .52919 .63722 Mtetra
.52919 .63722 .53012 .64726 .53183 .64677 .53089 .63674 Mtetra
.53089 .63674 .53183 .64677 .53354 .64629 .5326 .63627 Mtetra
.5326 .63627 .53354 .64629 .53526 .6458 .53431 .6358 Mtetra
.53431 .6358 .53526 .6458 .53697 .64531 .53602 .63533 Mtetra
.53602 .63533 .53697 .64531 .53869 .64483 .53773 .63486 Mtetra
.579 .401 .604 r
.53773 .63486 .53869 .64483 .5404 .64434 .53945 .63438 Mtetra
.53945 .63438 .5404 .64434 .54212 .64385 .54116 .63391 Mtetra
.54116 .63391 .54212 .64385 .54384 .64336 .54288 .63343 Mtetra
.54288 .63343 .54384 .64336 .54556 .64286 .54459 .63294 Mtetra
.58 .401 .604 r
.54459 .63294 .54556 .64286 .54728 .64237 .54631 .63244 Mtetra
.58 .402 .604 r
.54631 .63244 .54728 .64237 .549 .64187 .54803 .63193 Mtetra
.581 .402 .604 r
.54803 .63193 .549 .64187 .55072 .64136 .54974 .63141 Mtetra
.54974 .63141 .55072 .64136 .55245 .64086 .55146 .63086 Mtetra
.582 .403 .604 r
.55146 .63086 .55245 .64086 .55417 .64034 .55319 .6303 Mtetra
.583 .403 .604 r
.55319 .6303 .55417 .64034 .5559 .63983 .55491 .62969 Mtetra
.582 .403 .603 r
.55491 .62969 .5559 .63983 .55763 .63931 .55663 .6291 Mtetra
.581 .401 .603 r
.55663 .6291 .55763 .63931 .55935 .6388 .55835 .62853 Mtetra
.578 .399 .603 r
.55835 .62853 .55935 .6388 .56108 .63832 .56008 .62807 Mtetra
.577 .398 .603 r
.56008 .62807 .56108 .63832 .56281 .63783 .56181 .62763 Mtetra
.572 .395 .603 r
.56181 .62763 .56281 .63783 .56455 .63738 .56353 .62735 Mtetra
.52 .358 .601 r
.56353 .62735 .56455 .63738 .56629 .63741 .56528 .62852 Mtetra
.575 .403 .611 r
.56528 .62852 .56629 .63741 .56802 .63697 .56702 .62823 Mtetra
.675 .476 .609 r
.56702 .62823 .56802 .63697 .56974 .63551 .56871 .62465 Mtetra
.952 .677 .479 r
.56871 .62465 .56974 .63551 .57137 .62726 .5679 .43208 Mtetra
.566 .352 .549 r
.5679 .43208 .57137 .62726 .57036 .43008 .56948 .42711 Mtetra
.76 .598 .677 r
.56948 .42711 .57036 .43008 .57194 .42575 .57108 .42451 Mtetra
.716 .709 .842 r
.57108 .42451 .57194 .42575 .57356 .42471 .57271 .42365 Mtetra
.651 .719 .898 r
.57271 .42365 .57356 .42471 .5752 .42426 .57434 .42317 Mtetra
.605 .695 .907 r
.57434 .42317 .5752 .42426 .57684 .42411 .57598 .42289 Mtetra
.662 .692 .868 r
.57598 .42289 .57684 .42411 .57847 .4236 .57762 .42235 Mtetra
.657 .686 .865 r
.57762 .42235 .57847 .4236 .58011 .42311 .57926 .42184 Mtetra
.651 .68 .865 r
.57926 .42184 .58011 .42311 .58175 .42263 .5809 .42135 Mtetra
.626 .67 .873 r
.5809 .42135 .58175 .42263 .58339 .42217 .58254 .42099 Mtetra
.625 .688 .888 r
.58254 .42099 .58339 .42217 .58503 .4217 .58418 .42063 Mtetra
.637 .713 .902 r
.58418 .42063 .58503 .4217 .58667 .42121 .58583 .42021 Mtetra
.694 .747 .892 r
.58583 .42021 .58667 .42121 .58831 .42064 .58747 .41954 Mtetra
.701 .73 .873 r
.58747 .41954 .58831 .42064 .58996 .42004 .58911 .41881 Mtetra
.695 .705 .855 r
.58911 .41881 .58996 .42004 .5916 .41944 .59075 .41809 Mtetra
.701 .689 .835 r
.59075 .41809 .5916 .41944 .59324 .41881 .59239 .4173 Mtetra
.666 .652 .826 r
.59239 .4173 .59324 .41881 .59489 .41824 .59403 .41669 Mtetra
.607 .621 .839 r
.59403 .41669 .59489 .41824 .59653 .41777 .59568 .41642 Mtetra
.123 .378 .836 r
.59568 .41642 .59653 .41777 .59819 .41766 .59737 .4175 Mtetra
.803 .313 .019 r
.59737 .4175 .59819 .41766 .59985 .41766 .59908 .41981 Mtetra
.833 .492 .41 r
.59908 .41981 .59985 .41766 .60152 .41765 .60088 .42528 Mtetra
.665 .387 .489 r
.60088 .42528 .60152 .41765 .60317 .4172 .60263 .42881 Mtetra
.499 .264 .488 r
.60263 .42881 .60317 .4172 .60482 .41659 .60426 .42719 Mtetra
.427 .202 .468 r
.60426 .42719 .60482 .41659 .60647 .41592 .60586 .42392 Mtetra
.42 .184 .448 r
.60586 .42392 .60647 .41592 .60811 .41488 .60746 .42137 Mtetra
.481 .222 .445 r
.60746 .42137 .60811 .41488 .60976 .41419 .60911 .42026 Mtetra
.597 .317 .462 r
.60911 .42026 .60976 .41419 .61143 .41424 .61081 .42139 Mtetra
.958 .672 .451 r
.61081 .42139 .61143 .41424 .61324 .41903 .61769 .61392 Mtetra
.565 .347 .543 r
.61769 .61392 .61324 .41903 .62042 .61731 .61961 .61923 Mtetra
.717 .342 .338 r
.61961 .61923 .62042 .61731 .62233 .62192 .62145 .62138 Mtetra
.311 .711 .978 r
.62145 .62138 .62233 .62192 .62412 .62233 .62324 .62146 Mtetra
.643 .776 .944 r
.62324 .62146 .62412 .62233 .6259 .62184 .62501 .62096 Mtetra
.702 .792 .92 r
.62501 .62096 .6259 .62184 .62766 .62096 .62678 .62021 Mtetra
.556 .775 .98 r
.62678 .62021 .62766 .62096 .62944 .62079 .62856 .61994 Mtetra
.609 .77 .957 r
.62856 .61994 .62944 .62079 .63122 .62043 .63034 .61955 Mtetra
.711 .795 .917 r
.63034 .61955 .63122 .62043 .63298 .61945 .63211 .61876 Mtetra
.886 .839 .795 r
.63211 .61876 .63298 .61945 .63465 .61553 .63383 .61653 Mtetra
.939 .917 .541 r
.63383 .61653 .63465 .61553 .63014 .42138 .63549 .61234 Mtetra
.01 0 .409 r
.63549 .61234 .63014 .42138 .63142 .4088 .63109 .423 Mtetra
.027 0 .368 r
.63109 .423 .63142 .4088 .63303 .40658 .63232 .40923 Mtetra
0 0 .051 r
.63232 .40923 .63303 .40658 .63468 .40554 .6339 .4058 Mtetra
.874 .994 .767 r
.6339 .4058 .63468 .40554 .63635 .40495 .63552 .4038 Mtetra
.714 .727 .86 r
.63552 .4038 .63635 .40495 .63802 .40443 .63718 .40297 Mtetra
.62 .64 .849 r
.63718 .40297 .63802 .40443 .6397 .404 .63886 .40262 Mtetra
.575 .633 .871 r
.63886 .40262 .6397 .404 .64138 .40362 .64055 .40249 Mtetra
.633 .702 .896 r
.64055 .40249 .64138 .40362 .64306 .40311 .64223 .40208 Mtetra
.663 .735 .904 r
.64223 .40208 .64306 .40311 .64473 .40253 .64391 .40154 Mtetra
.677 .748 .904 r
.64391 .40154 .64473 .40253 .6464 .40194 .64558 .40094 Mtetra
.738 .765 .875 r
.64558 .40094 .6464 .40194 .64807 .40098 .64725 .40001 Mtetra
.725 .767 .886 r
.64725 .40001 .64807 .40098 .64973 .4002 .64891 .39916 Mtetra
.649 .73 .908 r
.64891 .39916 .64973 .4002 .65143 .39994 .6506 .39868 Mtetra
.244 .473 .88 r
.6506 .39868 .65143 .39994 .65322 .40216 .65233 .39947 Mtetra
.06 .175 .671 r
.65233 .39947 .65322 .40216 .66254 .59106 .65413 .40199 Mtetra
.519 .316 .545 r
.65413 .40199 .66254 .59106 .66501 .6073 .65664 .42166 Mtetra
.033 0 .429 r
.65664 .42166 .66501 .6073 .66689 .60895 .66584 .60351 Mtetra
.324 .264 .635 r
.66584 .60351 .66689 .60895 .66872 .60907 .66778 .60647 Mtetra
.349 .384 .757 r
.66778 .60647 .66872 .60907 .67052 .60868 .66966 .60774 Mtetra
.456 .682 .963 r
.66966 .60774 .67052 .60868 .67232 .60824 .67148 .60781 Mtetra
.572 .869 .995 r
.67148 .60781 .67232 .60824 .67413 .60773 .67329 .60732 Mtetra
.661 .902 .98 r
.67329 .60732 .67413 .60773 .67592 .60714 .67508 .60659 Mtetra
.558 .832 .997 r
.67508 .60659 .67592 .60714 .67774 .60692 .67689 .60621 Mtetra
.589 .8 .98 r
.67689 .60621 .67774 .60692 .67956 .6066 .6787 .60582 Mtetra
.698 .819 .94 r
.6787 .60582 .67956 .6066 .68134 .60572 .6805 .60507 Mtetra
.891 .857 .802 r
.6805 .60507 .68134 .60572 .68302 .60228 .68223 .60287 Mtetra
.976 .913 .589 r
.68223 .60287 .68302 .60228 .6839 .58197 .68386 .59858 Mtetra
.082 0 .398 r
.68386 .59858 .6839 .58197 .67687 .39457 .68497 .5832 Mtetra
.055 0 .431 r
.68497 .5832 .67687 .39457 .67848 .39232 .67812 .40066 Mtetra
.552 .293 .477 r
.67812 .40066 .67848 .39232 .68018 .39174 .67986 .40082 Mtetra
.55 .295 .482 r
.67986 .40082 .68018 .39174 .6819 .39158 .68159 .40091 Mtetra
.242 .056 .418 r
.68159 .40091 .6819 .39158 .68359 .39083 .68301 .39457 Mtetra
0 0 .202 r
.68301 .39457 .68359 .39083 .68526 .38974 .68453 .39033 Mtetra
.862 .959 .621 r
.68453 .39033 .68526 .38974 .68694 .38872 .68613 .38772 Mtetra
.786 .78 .848 r
.68613 .38772 .68694 .38872 .68863 .38798 .6878 .38645 Mtetra
.662 .654 .831 r
.6878 .38645 .68863 .38798 .69033 .38743 .6895 .38585 Mtetra
.62 .628 .837 r
.6895 .38585 .69033 .38743 .69204 .38695 .69121 .3855 Mtetra
.617 .644 .854 r
.69121 .3855 .69204 .38695 .69375 .38648 .69293 .38517 Mtetra
.622 .669 .874 r
.69293 .38517 .69375 .38648 .69546 .38599 .69465 .38481 Mtetra
.628 .695 .893 r
.69465 .38481 .69546 .38599 .69717 .38548 .69636 .38442 Mtetra
.671 .735 .898 r
.69636 .38442 .69717 .38548 .69887 .3849 .69807 .38383 Mtetra
.699 .744 .886 r
.69807 .38383 .69887 .3849 .70058 .38427 .69977 .3831 Mtetra
.698 .726 .871 r
.69977 .3831 .70058 .38427 .70228 .38363 .70147 .38236 Mtetra
.706 .71 .852 r
.70147 .38236 .70228 .38363 .70397 .38277 .70317 .38155 Mtetra
.692 .712 .864 r
.70317 .38155 .70397 .38277 .70567 .38197 .70487 .38083 Mtetra
.627 .701 .898 r
.70487 .38083 .70567 .38197 .7074 .38166 .70659 .38044 Mtetra
.258 .489 .889 r
.70659 .38044 .7074 .38166 .70924 .38329 .70838 .38118 Mtetra
0 .102 .65 r
.70838 .38118 .70924 .38329 .71156 .3932 .71028 .38382 Mtetra
0 0 .488 r
.71028 .38382 .71156 .3932 .72481 .58941 .71263 .3941 Mtetra
.076 0 .45 r
.71263 .3941 .72481 .58941 .7268 .59143 .72544 .58168 Mtetra
.561 .39 .607 r
.72544 .58168 .7268 .59143 .72865 .59113 .72731 .58175 Mtetra
.622 .434 .607 r
.72731 .58175 .72865 .59113 .73046 .59021 .72906 .57991 Mtetra
.61 .422 .603 r
.72906 .57991 .73046 .59021 .73228 .58942 .73083 .57831 Mtetra
.578 .396 .599 r
.73083 .57831 .73228 .58942 .73412 .5889 .73267 .57779 Mtetra
.73267 .57779 .73412 .5889 .73596 .58837 .7345 .57726 Mtetra
.577 .396 .599 r
.7345 .57726 .73596 .58837 .7378 .58785 .73634 .57676 Mtetra
.576 .395 .6 r
.73634 .57676 .7378 .58785 .73965 .58734 .73818 .57629 Mtetra
.73818 .57629 .73965 .58734 .74149 .58683 .74002 .57582 Mtetra
.576 .396 .6 r
.74002 .57582 .74149 .58683 .74334 .58632 .74187 .57536 Mtetra
.74187 .57536 .74334 .58632 .74518 .5858 .74371 .57489 Mtetra
.576 .396 .601 r
.74371 .57489 .74518 .5858 .74703 .58528 .74556 .57443 Mtetra
.74556 .57443 .74703 .58528 .74888 .58477 .74741 .57396 Mtetra
.577 .397 .601 r
.74741 .57396 .74888 .58477 .75073 .58425 .74926 .57349 Mtetra
.74926 .57349 .75073 .58425 .75258 .58373 .75111 .57301 Mtetra
.577 .397 .602 r
.75111 .57301 .75258 .58373 .75444 .5832 .75296 .57253 Mtetra
.577 .398 .602 r
.75296 .57253 .75444 .5832 .75629 .58268 .75481 .57204 Mtetra
.578 .398 .602 r
.75481 .57204 .75629 .58268 .75814 .58215 .75666 .57154 Mtetra
.579 .399 .602 r
.75666 .57154 .75814 .58215 .76 .58162 .75851 .571 Mtetra
.58 .4 .602 r
.75851 .571 .76 .58162 .76186 .58108 .76036 .57045 Mtetra
.581 .4 .602 r
.76036 .57045 .76186 .58108 .76371 .58054 .76221 .56985 Mtetra
.582 .401 .602 r
.76221 .56985 .76371 .58054 .76557 .57998 .76406 .5692 Mtetra
.583 .402 .601 r
.76406 .5692 .76557 .57998 .76743 .57942 .7659 .56849 Mtetra
.585 .403 .6 r
.7659 .56849 .76743 .57942 .76929 .57885 .76774 .56769 Mtetra
.588 .404 .599 r
.76774 .56769 .76929 .57885 .77115 .57826 .76957 .56676 Mtetra
.592 .405 .598 r
.76957 .56676 .77115 .57826 .77301 .57765 .77139 .56566 Mtetra
.595 .406 .595 r
.77139 .56566 .77301 .57765 .77486 .57702 .77319 .56438 Mtetra
.637 .434 .591 r
.77319 .56438 .77486 .57702 .77672 .57631 .77485 .56106 Mtetra
.962 .666 .424 r
.77485 .56106 .77672 .57631 .77857 .57553 .7638 .38712 Mtetra
.563 .349 .549 r
.7638 .38712 .77857 .57553 .78042 .57485 .76535 .38373 Mtetra
.109 .023 .467 r
.76535 .38373 .78042 .57485 .78231 .57449 .7808 .56438 Mtetra
.324 .224 .584 r
.7808 .56438 .78231 .57449 .78422 .57449 .78315 .5702 Mtetra
.324 .295 .671 r
.78315 .5702 .78422 .57449 .78613 .57448 .78526 .57267 Mtetra
.341 .459 .835 r
.78526 .57267 .78613 .57448 .78803 .5743 .78724 .57359 Mtetra
.494 .767 .992 r
.78724 .57359 .78803 .5743 .78992 .57388 .78915 .57343 Mtetra
.65 .899 .983 r
.78915 .57343 .78992 .57388 .79179 .57331 .79101 .5727 Mtetra
.822 .894 .893 r
.79101 .5727 .79179 .57331 .79367 .57273 .79282 .57127 Mtetra
.854 .746 .743 r
.79282 .57127 .79367 .57273 .79554 .57213 .79454 .56869 Mtetra
.827 .629 .634 r
.79454 .56869 .79554 .57213 .79737 .57093 .79607 .56377 Mtetra
.973 .675 .392 r
.79607 .56377 .79737 .57093 .79902 .56758 .78211 .36688 Mtetra
.569 .354 .549 r
.78211 .36688 .79902 .56758 .78469 .36789 .78331 .35934 Mtetra
.664 .464 .605 r
.78331 .35934 .78469 .36789 .78573 .35854 .78486 .35619 Mtetra
.735 .618 .728 r
.78486 .35619 .78573 .35854 .78732 .3558 .78654 .35456 Mtetra
.655 .701 .88 r
.78654 .35456 .78732 .3558 .78906 .35506 .7883 .35403 Mtetra
.576 .707 .932 r
.7883 .35403 .78906 .35506 .79085 .3548 .7901 .3538 Mtetra
.615 .734 .93 r
.7901 .3538 .79085 .3548 .79264 .35455 .79188 .35342 Mtetra
.723 .75 .873 r
.79188 .35342 .79264 .35455 .7944 .35388 .79362 .35253 Mtetra
.682 .694 .855 r
.79362 .35253 .7944 .35388 .79617 .35327 .79537 .35183 Mtetra
.568 .627 .87 r
.79537 .35183 .79617 .35327 .79793 .35271 .79718 .35172 Mtetra
.03 .388 .848 r
.79718 .35172 .79793 .35271 .79971 .35226 .79909 .3528 Mtetra
.806 .344 .138 r
.79909 .3528 .79971 .35226 .80154 .3523 .80116 .35562 Mtetra
.973 .666 .361 r
.80116 .35562 .80154 .3523 .8035 .35389 .81989 .5488 Mtetra
.572 .352 .543 r
.81989 .5488 .8035 .35389 .82239 .54722 .82279 .55968 Mtetra
.611 .35 .498 r
.82279 .55968 .82239 .54722 .82561 .56167 .82497 .56242 Mtetra
.6 .095 .025 r
.82497 .56242 .82561 .56167 .82777 .56404 .82701 .56341 Mtetra
.47 .777 .997 r
.82701 .56341 .82777 .56404 .82971 .56391 .82895 .56324 Mtetra
.684 .859 .966 r
.82895 .56324 .82971 .56391 .83159 .56312 .83083 .56248 Mtetra
.843 .894 .875 r
.83083 .56248 .83159 .56312 .83344 .56195 .83264 .56088 Mtetra
.922 .802 .71 r
.83264 .56088 .83344 .56195 .83528 .56065 .83429 .5575 Mtetra
.859 .652 .622 r
.83429 .5575 .83528 .56065 .83711 .55927 .83573 .55184 Mtetra
.746 .528 .6 r
.83573 .55184 .83711 .55927 .83897 .55829 .83713 .54595 Mtetra
.329 .221 .576 r
.83713 .54595 .83897 .55829 .84093 .55829 .83976 .55313 Mtetra
.301 .261 .645 r
.83976 .55313 .84093 .55829 .8429 .55841 .84203 .55644 Mtetra
.254 .385 .803 r
.84203 .55644 .8429 .55841 .84486 .55836 .84412 .55784 Mtetra
.498 .823 1 r
.84412 .55784 .84486 .55836 .84678 .55784 .84606 .55753 Mtetra
.585 .911 .977 r
.84606 .55753 .84678 .55784 .84868 .55722 .84796 .55685 Mtetra
.659 .927 .973 r
.84796 .55685 .84868 .55722 .85059 .55657 .84985 .55602 Mtetra
.658 .881 .981 r
.84985 .55602 .85059 .55657 .8525 .55601 .85175 .5553 Mtetra
.67 .845 .967 r
.85175 .5553 .8525 .55601 .85442 .55546 .85366 .5546 Mtetra
.617 .785 .962 r
.85366 .5546 .85442 .55546 .85636 .55508 .85558 .55413 Mtetra
.416 .665 .963 r
.85558 .55413 .85636 .55508 .85834 .55514 .85758 .5543 Mtetra
.573 .772 .973 r
.85758 .5543 .85834 .55514 .86027 .55471 .85952 .55397 Mtetra
.844 .876 .865 r
.85952 .55397 .86027 .55471 .86208 .55298 .86134 .55232 Mtetra
.991 .775 .515 r
.86134 .55232 .86208 .55298 .8632 .5445 .86246 .54378 Mtetra
.977 .674 .34 r
.86246 .54378 .8632 .5445 .84463 .34112 .84385 .33971 Mtetra
.925 .755 .653 r
.84385 .33971 .84463 .34112 .84605 .33684 .84528 .33545 Mtetra
.709 .703 .843 r
.84528 .33545 .84605 .33684 .84781 .33585 .84705 .33457 Mtetra
.596 .669 .891 r
.84705 .33457 .84781 .33585 .84963 .33548 .84888 .3343 Mtetra
.551 .668 .915 r
.84888 .3343 .84963 .33548 .85147 .33526 .85073 .3342 Mtetra
.733 .769 .882 r
.85073 .3342 .85147 .33526 .85323 .33429 .8525 .33325 Mtetra
.698 .764 .903 r
.8525 .33325 .85323 .33429 .85502 .33364 .85428 .33251 Mtetra
.584 .694 .918 r
.85428 .33251 .85502 .33364 .8569 .33379 .85612 .33226 Mtetra
.19 .389 .828 r
.85612 .33226 .8569 .33379 .85914 .33732 .85813 .33354 Mtetra
.175 .206 .655 r
.85813 .33354 .85914 .33732 .88244 .5387 .86036 .33694 Mtetra
.132 .047 .484 r
.86036 .33694 .88244 .5387 .88515 .54545 .8833 .53429 Mtetra
.295 .204 .579 r
.8833 .53429 .88515 .54545 .88723 .54621 .8861 .54175 Mtetra
.364 .32 .675 r
.8861 .54175 .88723 .54621 .88922 .54613 .88835 .54409 Mtetra
.38 .459 .816 r
.88835 .54409 .88922 .54613 .89117 .54564 .89045 .54503 Mtetra
.492 .797 .999 r
.89045 .54503 .89117 .54564 .89313 .54521 .89243 .54479 Mtetra
.582 .889 .99 r
.89243 .54479 .89313 .54521 .89508 .54466 .89437 .54418 Mtetra
.646 .901 .983 r
.89437 .54418 .89508 .54466 .89702 .54409 .8963 .54344 Mtetra
.507 .794 .997 r
.8963 .54344 .89702 .54409 .89902 .54398 .89828 .54318 Mtetra
.615 .804 .972 r
.89828 .54318 .89902 .54398 .90098 .54351 .90024 .54269 Mtetra
.736 .844 .931 r
.90024 .54269 .90098 .54351 .90285 .54225 .90214 .54171 Mtetra
.934 .907 .771 r
.90214 .54171 .90285 .54225 .9043 .53729 .90387 .5391 Mtetra
0 0 0 r
.90387 .5391 .9043 .53729 .8833 .33455 .90534 .53432 Mtetra
.135 .045 .481 r
.90534 .53432 .8833 .33455 .88429 .32662 .88478 .33615 Mtetra
.152 .009 .419 r
.88478 .33615 .88429 .32662 .88597 .32483 .88563 .32704 Mtetra
0 0 .115 r
.88563 .32704 .88597 .32483 .88775 .32383 .88715 .32377 Mtetra
.87 .995 .791 r
.88715 .32377 .88775 .32383 .88957 .32323 .88882 .32182 Mtetra
.682 .692 .853 r
.88882 .32182 .88957 .32323 .8914 .32262 .89063 .3211 Mtetra
.617 .643 .853 r
.89063 .3211 .8914 .32262 .89323 .32213 .89248 .32074 Mtetra
.579 .644 .879 r
.89248 .32074 .89323 .32213 .89508 .32169 .89436 .32056 Mtetra
.682 .739 .894 r
.30272 .51057 .30367 .51149 .30517 .51078 .30421 .51001 Mtetra
.67 .77 .925 r
.30421 .51001 .30517 .51078 .30665 .51023 .30569 .50951 Mtetra
.628 .772 .949 r
.30569 .50951 .30665 .51023 .30812 .51004 .30717 .50913 Mtetra
.589 .715 .931 r
.30717 .50913 .30812 .51004 .30949 .51127 .30863 .50891 Mtetra
.529 .489 .756 r
.30863 .50891 .30949 .51127 .31073 .51449 .31007 .50912 Mtetra
.476 .355 .636 r
.31007 .50912 .31073 .51449 .30028 .70129 .31146 .51023 Mtetra
.531 .323 .543 r
.31146 .51023 .30028 .70129 .30135 .70876 .31213 .52251 Mtetra
0 0 .258 r
.31213 .52251 .30135 .70876 .30274 .71113 .30188 .70804 Mtetra
0 0 .521 r
.30188 .70804 .30274 .71113 .30423 .71217 .30323 .71109 Mtetra
.446 .631 .933 r
.30323 .71109 .30423 .71217 .30577 .71216 .30477 .71125 Mtetra
.677 .752 .908 r
.30477 .71125 .30577 .71216 .30736 .71158 .30635 .71068 Mtetra
.757 .766 .86 r
.30635 .71068 .30736 .71158 .30898 .71044 .30797 .70965 Mtetra
.722 .786 .903 r
.30797 .70965 .30898 .71044 .31067 .70814 .30957 .70887 Mtetra
.46 .845 .626 r
.30957 .70887 .31067 .70814 .31247 .70399 .31119 .70771 Mtetra
.234 0 .26 r
.31119 .70771 .31247 .70399 .32507 .51916 .31286 .70571 Mtetra
.54 .327 .539 r
.31286 .70571 .32507 .51916 .3272 .50809 .3149 .69752 Mtetra
0 0 .25 r
.3149 .69752 .3272 .50809 .32886 .50487 .32777 .50645 Mtetra
.958 .925 .581 r
.32777 .50645 .32886 .50487 .33043 .50297 .32948 .50226 Mtetra
.791 .797 .857 r
.32948 .50226 .33043 .50297 .33195 .50214 .33102 .5011 Mtetra
.659 .709 .885 r
.33102 .5011 .33195 .50214 .33345 .50166 .33251 .50063 Mtetra
.583 .685 .911 r
.33251 .50063 .33345 .50166 .33493 .50133 .33399 .50044 Mtetra
.756 .761 .857 r
.33399 .50044 .33493 .50133 .33646 .50026 .33552 .49947 Mtetra
.727 .776 .892 r
.33552 .49947 .33646 .50026 .33798 .49942 .33704 .49869 Mtetra
.535 .744 .972 r
.33704 .49869 .33798 .49942 .33947 .4992 .33852 .49855 Mtetra
.901 .49 .197 r
.33852 .49855 .33947 .4992 .34077 .50224 .33981 .50175 Mtetra
.941 .683 .518 r
.33981 .50175 .34077 .50224 .33162 .69568 .33059 .69548 Mtetra
.92 .589 .399 r
.33059 .69548 .33162 .69568 .33279 .70292 .33179 .70215 Mtetra
0 .37 .802 r
.33179 .70215 .33279 .70292 .33431 .70386 .33331 .70291 Mtetra
.641 .737 .918 r
.33331 .70291 .33431 .70386 .3359 .70349 .33491 .70248 Mtetra
.747 .748 .853 r
.33491 .70248 .3359 .70349 .33753 .70232 .33653 .70148 Mtetra
.723 .777 .895 r
.33653 .70148 .33753 .70232 .33921 .70017 .33814 .70068 Mtetra
.547 .915 .742 r
.33814 .70068 .33921 .70017 .34099 .69627 .33977 .69959 Mtetra
.211 0 .23 r
.33977 .69959 .34099 .69627 .35156 .52257 .34145 .69769 Mtetra
.542 .328 .539 r
.34145 .69769 .35156 .52257 .35423 .49974 .34337 .69085 Mtetra
0 0 .269 r
.34337 .69085 .35423 .49974 .35589 .49634 .3548 .49837 Mtetra
.919 .902 .499 r
.3548 .49837 .35589 .49634 .35747 .49437 .35653 .49378 Mtetra
.823 .822 .848 r
.35653 .49378 .35747 .49437 .359 .49345 .35808 .4924 Mtetra
.664 .711 .883 r
.35808 .4924 .359 .49345 .36052 .49297 .35959 .4919 Mtetra
.578 .678 .908 r
.35959 .4919 .36052 .49297 .36202 .49267 .36109 .49173 Mtetra
.727 .748 .869 r
.36109 .49173 .36202 .49267 .36355 .49182 .36262 .49092 Mtetra
.715 .755 .883 r
.36262 .49092 .36355 .49182 .36508 .49108 .36415 .49019 Mtetra
.552 .71 .945 r
.36415 .49019 .36508 .49108 .36657 .49093 .36564 .49006 Mtetra
.879 .445 .079 r
.36564 .49006 .36657 .49093 .36793 .49383 .367 .49298 Mtetra
.945 .684 .511 r
.367 .49298 .36793 .49383 .36035 .68743 .35936 .68667 Mtetra
.941 .605 .365 r
.35936 .68667 .36035 .68743 .3616 .69453 .36061 .69369 Mtetra
0 .243 .708 r
.36061 .69369 .3616 .69453 .36314 .69566 .36215 .6947 Mtetra
.627 .732 .923 r
.36215 .6947 .36314 .69566 .36474 .69535 .36376 .69432 Mtetra
.739 .746 .857 r
.36376 .69432 .36474 .69535 .36638 .69427 .3654 .69337 Mtetra
.728 .768 .885 r
.3654 .69337 .36638 .69427 .36807 .69224 .36703 .69253 Mtetra
.644 .967 .856 r
.36703 .69253 .36807 .69224 .36982 .68865 .36867 .69148 Mtetra
.169 0 .176 r
.36867 .69148 .36982 .68865 .3719 .67752 .37034 .68969 Mtetra
.313 .105 .429 r
.37034 .68969 .3719 .67752 .38153 .49159 .37218 .68401 Mtetra
0 0 .287 r
.37218 .68401 .38153 .49159 .38319 .48785 .38212 .49047 Mtetra
.853 .85 .391 r
.38212 .49047 .38319 .48785 .38479 .48576 .38385 .48528 Mtetra
.853 .844 .835 r
.38385 .48528 .38479 .48576 .38633 .48475 .38542 .48366 Mtetra
.669 .708 .877 r
.38542 .48366 .38633 .48475 .38786 .48426 .38695 .48314 Mtetra
.577 .668 .9 r
.38695 .48314 .38786 .48426 .38938 .48399 .38846 .48298 Mtetra
.706 .733 .871 r
.38846 .48298 .38938 .48399 .39092 .48321 .39 .48227 Mtetra
.718 .749 .876 r
.39 .48227 .39092 .48321 .39246 .48243 .39154 .48151 Mtetra
.569 .709 .936 r
.39154 .48151 .39246 .48243 .39398 .48225 .39306 .48134 Mtetra
.851 .4 0 r
.39306 .48134 .39398 .48225 .39538 .48504 .39447 .48405 Mtetra
.948 .685 .504 r
.39447 .48405 .39538 .48504 .38936 .6798 .3884 .67848 Mtetra
.954 .612 .311 r
.3884 .67848 .38936 .6798 .39071 .68657 .38973 .68552 Mtetra
0 .295 .781 r
.38973 .68552 .39071 .68657 .39228 .68757 .3913 .68657 Mtetra
.671 .739 .902 r
.3913 .68657 .39228 .68757 .39391 .68696 .39294 .68601 Mtetra
.761 .766 .857 r
.39294 .68601 .39391 .68696 .39557 .68583 .39459 .68492 Mtetra
.737 .772 .882 r
.39459 .68492 .39557 .68583 .39721 .68491 .39624 .68402 Mtetra
.69 .767 .911 r
.39624 .68402 .39721 .68491 .39885 .68428 .39788 .68338 Mtetra
.681 .761 .912 r
.39788 .68338 .39885 .68428 .40049 .68373 .39951 .68277 Mtetra
.66 .746 .913 r
.39951 .68277 .40049 .68373 .40212 .6833 .40115 .68226 Mtetra
.644 .722 .905 r
.40115 .68226 .40212 .6833 .40375 .68297 .40278 .68181 Mtetra
.64 .699 .889 r
.40278 .68181 .40375 .68297 .40538 .68265 .40442 .68139 Mtetra
.646 .683 .87 r
.40442 .68139 .40538 .68265 .40701 .68226 .40605 .68093 Mtetra
.651 .674 .859 r
.40605 .68093 .40701 .68226 .40865 .6818 .40769 .68044 Mtetra
.65 .669 .855 r
.40769 .68044 .40865 .6818 .41028 .68133 .40933 .67996 Mtetra
.647 .666 .854 r
.40933 .67996 .41028 .68133 .41192 .68087 .41097 .67949 Mtetra
.643 .663 .855 r
.41097 .67949 .41192 .68087 .41356 .68043 .41261 .67904 Mtetra
.64 .661 .855 r
.41261 .67904 .41356 .68043 .4152 .68 .41425 .67861 Mtetra
.636 .66 .856 r
.41425 .67861 .4152 .68 .41684 .67958 .41589 .67819 Mtetra
.633 .66 .858 r
.41589 .67819 .41684 .67958 .41849 .67917 .41753 .6778 Mtetra
.631 .66 .86 r
.41753 .6778 .41849 .67917 .42013 .67877 .41917 .67741 Mtetra
.613 .656 .869 r
.41917 .67741 .42013 .67877 .42177 .67854 .42082 .67711 Mtetra
.61 .645 .86 r
.42082 .67711 .42177 .67854 .4234 .67831 .42246 .67682 Mtetra
.639 .647 .842 r
.42246 .67682 .4234 .67831 .42506 .67775 .4241 .67639 Mtetra
.717 .692 .826 r
.4241 .67639 .42506 .67775 .42674 .676 .42577 .67547 Mtetra
.828 .855 .867 r
.42577 .67547 .42674 .676 .42848 .67217 .42744 .67403 Mtetra
0 0 0 r
.42744 .67403 .42848 .67217 .4304 .66166 .42912 .67239 Mtetra
.507 .264 .481 r
.42912 .67239 .4304 .66166 .43696 .47679 .43079 .67121 Mtetra
.555 .339 .542 r
.43079 .67121 .43696 .47679 .43853 .47578 .43244 .67075 Mtetra
.556 .34 .542 r
.43244 .67075 .43853 .47578 .44006 .47666 .43409 .67053 Mtetra
.43409 .67053 .44006 .47666 .44158 .47775 .43574 .67027 Mtetra
.555 .339 .542 r
.43574 .67027 .44158 .47775 .44313 .47771 .43739 .66988 Mtetra
.43739 .66988 .44313 .47771 .44469 .47768 .43905 .66947 Mtetra
.556 .34 .542 r
.43905 .66947 .44469 .47768 .4462 .47955 .44069 .66937 Mtetra
.44069 .66937 .4462 .47955 .44754 .48866 .44234 .66933 Mtetra
.555 .339 .542 r
.44234 .66933 .44754 .48866 .44927 .4812 .44401 .66859 Mtetra
.549 .335 .541 r
.44401 .66859 .44927 .4812 .45106 .47103 .44574 .66496 Mtetra
0 0 .326 r
.44574 .66496 .45106 .47103 .45273 .46594 .45172 .46986 Mtetra
.729 .728 .205 r
.45172 .46986 .45273 .46594 .45435 .46308 .45343 .46291 Mtetra
.92 .887 .783 r
.45343 .46291 .45435 .46308 .45593 .46156 .45504 .4606 Mtetra
.705 .749 .886 r
.45504 .4606 .45593 .46156 .4575 .46094 .45661 .4599 Mtetra
.609 .701 .909 r
.45661 .4599 .4575 .46094 .45907 .46058 .45817 .45961 Mtetra
.604 .715 .923 r
.45817 .45961 .45907 .46058 .46063 .46021 .45974 .45933 Mtetra
.658 .753 .92 r
.45974 .45933 .46063 .46021 .4622 .45971 .46131 .45884 Mtetra
.652 .755 .925 r
.46131 .45884 .4622 .45971 .46377 .45923 .46288 .45837 Mtetra
.641 .754 .931 r
.46288 .45837 .46377 .45923 .46534 .45881 .46445 .45795 Mtetra
.629 .748 .933 r
.46445 .45795 .46534 .45881 .46691 .45847 .46602 .45756 Mtetra
.63 .738 .925 r
.46602 .45756 .46691 .45847 .46848 .45814 .46759 .45718 Mtetra
.641 .73 .913 r
.46759 .45718 .46848 .45814 .47005 .45775 .46916 .45676 Mtetra
.656 .728 .902 r
.46916 .45676 .47005 .45775 .47163 .45727 .47074 .45628 Mtetra
.665 .732 .899 r
.47074 .45628 .47163 .45727 .4732 .45673 .47231 .45577 Mtetra
.677 .74 .899 r
.47231 .45577 .4732 .45673 .47478 .45611 .47389 .4552 Mtetra
.688 .755 .903 r
.47389 .4552 .47478 .45611 .47636 .45541 .47547 .45458 Mtetra
.69 .774 .916 r
.47547 .45458 .47636 .45541 .47794 .45471 .47705 .45396 Mtetra
.681 .791 .933 r
.47705 .45396 .47794 .45471 .47952 .45407 .47863 .45337 Mtetra
.665 .801 .947 r
.47863 .45337 .47952 .45407 .4811 .45352 .48021 .45284 Mtetra
.659 .804 .952 r
.48021 .45284 .4811 .45352 .48269 .45299 .4818 .45232 Mtetra
.658 .805 .954 r
.4818 .45232 .48269 .45299 .48427 .45248 .48338 .4518 Mtetra
.659 .807 .954 r
.48338 .4518 .48427 .45248 .48585 .45194 .48496 .45128 Mtetra
.658 .809 .956 r
.48496 .45128 .48585 .45194 .48743 .45142 .48655 .45076 Mtetra
.668 .814 .953 r
.48655 .45076 .48743 .45142 .48902 .45081 .48813 .45021 Mtetra
.679 .83 .956 r
.48813 .45021 .48902 .45081 .49061 .45011 .48972 .44961 Mtetra
.631 .848 .983 r
.48972 .44961 .49061 .45011 .49219 .44965 .49131 .44912 Mtetra
.497 .791 .998 r
.49131 .44912 .49219 .44965 .49377 .44995 .49289 .44893 Mtetra
.357 .593 .935 r
.49289 .44893 .49377 .44995 .49534 .45202 .49447 .44927 Mtetra
.483 .443 .737 r
.49447 .44927 .49534 .45202 .49688 .45769 .49605 .44984 Mtetra
.545 .384 .613 r
.49605 .44984 .49688 .45769 .49695 .64657 .49764 .45024 Mtetra
.557 .345 .548 r
.49764 .45024 .49695 .64657 .49862 .6475 .49923 .44986 Mtetra
.558 .345 .548 r
.49923 .44986 .49862 .6475 .50032 .64623 .50083 .44923 Mtetra
.558 .346 .548 r
.50083 .44923 .50032 .64623 .50202 .64429 .50242 .44856 Mtetra
.558 .345 .548 r
.50242 .44856 .50202 .64429 .50371 .64387 .50402 .44805 Mtetra
.50402 .44805 .50371 .64387 .5054 .64342 .50562 .44755 Mtetra
.50562 .44755 .5054 .64342 .50709 .64299 .50721 .44704 Mtetra
.50721 .44704 .50709 .64299 .50878 .64257 .50881 .44654 Mtetra
.50881 .44654 .50878 .64257 .51048 .64216 .51041 .44604 Mtetra
.51041 .44604 .51048 .64216 .51217 .64175 .51201 .44554 Mtetra
.51201 .44554 .51217 .64175 .51387 .64132 .51361 .44504 Mtetra
.51361 .44504 .51387 .64132 .51557 .64089 .51522 .44453 Mtetra
.51522 .44453 .51557 .64089 .51726 .64045 .51682 .44403 Mtetra
.51682 .44403 .51726 .64045 .51896 .64 .51843 .44352 Mtetra
.51843 .44352 .51896 .64 .52067 .63955 .52003 .44301 Mtetra
.52003 .44301 .52067 .63955 .52237 .63909 .52164 .4425 Mtetra
.52164 .4425 .52237 .63909 .52407 .63862 .52324 .44199 Mtetra
.52324 .44199 .52407 .63862 .52577 .63816 .52485 .44147 Mtetra
.52485 .44147 .52577 .63816 .52748 .63769 .52646 .44096 Mtetra
.52646 .44096 .52748 .63769 .52919 .63722 .52807 .44045 Mtetra
.52807 .44045 .52919 .63722 .53089 .63674 .52968 .43993 Mtetra
.52968 .43993 .53089 .63674 .5326 .63627 .5313 .43942 Mtetra
.5313 .43942 .5326 .63627 .53431 .6358 .53291 .4389 Mtetra
.53291 .4389 .53431 .6358 .53602 .63533 .53452 .43839 Mtetra
.53452 .43839 .53602 .63533 .53773 .63486 .53614 .43788 Mtetra
.53614 .43788 .53773 .63486 .53945 .63438 .53775 .43737 Mtetra
.53775 .43737 .53945 .63438 .54116 .63391 .53937 .43685 Mtetra
.53937 .43685 .54116 .63391 .54288 .63343 .54099 .43634 Mtetra
.54099 .43634 .54288 .63343 .54459 .63294 .54261 .43583 Mtetra
.54261 .43583 .54459 .63294 .54631 .63244 .54423 .43531 Mtetra
.54423 .43531 .54631 .63244 .54803 .63193 .54585 .43479 Mtetra
.54585 .43479 .54803 .63193 .54974 .63141 .54747 .43427 Mtetra
.54747 .43427 .54974 .63141 .55146 .63086 .54909 .43374 Mtetra
.54909 .43374 .55146 .63086 .55319 .6303 .55072 .4332 Mtetra
.55072 .4332 .55319 .6303 .55491 .62969 .55234 .43266 Mtetra
.55234 .43266 .55491 .62969 .55663 .6291 .55397 .43212 Mtetra
.55397 .43212 .55663 .6291 .55835 .62853 .55559 .43159 Mtetra
.55559 .43159 .55835 .62853 .56008 .62807 .55722 .43107 Mtetra
.55722 .43107 .56008 .62807 .56181 .62763 .55885 .43055 Mtetra
.55885 .43055 .56181 .62763 .56353 .62735 .56048 .43006 Mtetra
.557 .345 .548 r
.56048 .43006 .56353 .62735 .56528 .62852 .56211 .42976 Mtetra
.558 .345 .548 r
.56211 .42976 .56528 .62852 .56702 .62823 .56374 .4293 Mtetra
.558 .346 .548 r
.56374 .4293 .56702 .62823 .56871 .62465 .56537 .42845 Mtetra
.56 .347 .548 r
.56537 .42845 .56871 .62465 .5679 .43208 .56699 .42672 Mtetra
.652 .482 .641 r
.56699 .42672 .5679 .43208 .56948 .42711 .56861 .42513 Mtetra
.726 .63 .751 r
.56861 .42513 .56948 .42711 .57108 .42451 .57023 .42383 Mtetra
.695 .821 .943 r
.57023 .42383 .57108 .42451 .57271 .42365 .57186 .42316 Mtetra
.626 .855 .986 r
.57186 .42316 .57271 .42365 .57434 .42317 .5735 .42265 Mtetra
.599 .838 .989 r
.5735 .42265 .57434 .42317 .57598 .42289 .57514 .42222 Mtetra
.658 .817 .96 r
.57514 .42222 .57598 .42289 .57762 .42235 .57677 .42168 Mtetra
.656 .815 .96 r
.57677 .42168 .57762 .42235 .57926 .42184 .57841 .42115 Mtetra
.652 .809 .958 r
.57841 .42115 .57926 .42184 .5809 .42135 .58005 .42063 Mtetra
.633 .793 .959 r
.58005 .42063 .5809 .42135 .58254 .42099 .58169 .42018 Mtetra
.641 .773 .943 r
.58169 .42018 .58254 .42099 .58418 .42063 .58334 .41972 Mtetra
.654 .755 .924 r
.58334 .41972 .58418 .42063 .58583 .42021 .58498 .41923 Mtetra
.691 .749 .896 r
.58498 .41923 .58583 .42021 .58747 .41954 .58662 .41857 Mtetra
.698 .754 .895 r
.58662 .41857 .58747 .41954 .58911 .41881 .58826 .41788 Mtetra
.696 .762 .902 r
.58826 .41788 .58911 .41881 .59075 .41809 .5899 .4172 Mtetra
.744 .783 .885 r
.5899 .4172 .59075 .41809 .59239 .4173 .59154 .41627 Mtetra
.686 .74 .892 r
.59154 .41627 .59239 .4173 .59403 .41669 .59319 .41563 Mtetra
.551 .68 .924 r
.59319 .41563 .59403 .41669 .59568 .41642 .59484 .41552 Mtetra
.722 .244 0 r
.59484 .41552 .59568 .41642 .59737 .4175 .59656 .41806 Mtetra
.966 .681 .442 r
.59656 .41806 .59737 .4175 .59908 .41981 .60236 .60066 Mtetra
.59 .366 .545 r
.60236 .60066 .59908 .41981 .60088 .42528 .60459 .62135 Mtetra
.557 .341 .542 r
.60459 .62135 .60088 .42528 .60263 .42881 .60638 .622 Mtetra
.555 .339 .542 r
.60638 .622 .60263 .42881 .60426 .42719 .60814 .62137 Mtetra
.554 .338 .542 r
.60814 .62137 .60426 .42719 .60586 .42392 .60988 .62014 Mtetra
.555 .339 .542 r
.60988 .62014 .60586 .42392 .60746 .42137 .61164 .61927 Mtetra
.61164 .61927 .60746 .42137 .60911 .42026 .61339 .61858 Mtetra
.61339 .61858 .60911 .42026 .61081 .42139 .61516 .61824 Mtetra
.557 .341 .542 r
.61516 .61824 .61081 .42139 .61769 .61392 .61696 .619 Mtetra
.58 .288 .436 r
.61696 .619 .61769 .61392 .61961 .61923 .61876 .61974 Mtetra
.475 0 0 r
.61876 .61974 .61961 .61923 .62145 .62138 .62056 .62019 Mtetra
.593 .689 .908 r
.62056 .62019 .62145 .62138 .62324 .62146 .62234 .61993 Mtetra
.646 .655 .844 r
.62234 .61993 .62324 .62146 .62501 .62096 .62411 .61942 Mtetra
.662 .661 .838 r
.62411 .61942 .62501 .62096 .62678 .62021 .62588 .61881 Mtetra
.622 .664 .87 r
.62588 .61881 .62678 .62021 .62856 .61994 .62766 .61844 Mtetra
.631 .652 .853 r
.62766 .61844 .62856 .61994 .63034 .61955 .62944 .61802 Mtetra
.66 .661 .84 r
.62944 .61802 .63034 .61955 .63211 .61876 .63121 .61742 Mtetra
.705 .707 .849 r
.63121 .61742 .63211 .61876 .63383 .61653 .63298 .61657 Mtetra
.762 .992 .882 r
.63298 .61657 .63383 .61653 .63549 .61234 .63473 .61523 Mtetra
.138 0 .2 r
.63473 .61523 .63549 .61234 .63109 .423 .63645 .61293 Mtetra
.539 .327 .54 r
.63645 .61293 .63109 .423 .63232 .40923 .63793 .60311 Mtetra
0 0 .404 r
.63793 .60311 .63232 .40923 .6339 .4058 .63315 .4072 Mtetra
.846 .867 .42 r
.63315 .4072 .6339 .4058 .63552 .4038 .6347 .4031 Mtetra
.802 .84 .88 r
.6347 .4031 .63552 .4038 .63718 .40297 .63635 .40186 Mtetra
.633 .707 .899 r
.63635 .40186 .63718 .40297 .63886 .40262 .63803 .40145 Mtetra
.547 .657 .908 r
.63803 .40145 .63886 .40262 .64055 .40249 .63972 .40138 Mtetra
.626 .704 .902 r
.63972 .40138 .64055 .40249 .64223 .40208 .6414 .401 Mtetra
.656 .721 .897 r
.6414 .401 .64223 .40208 .64391 .40154 .64308 .40049 Mtetra
.665 .731 .898 r
.64308 .40049 .64391 .40154 .64558 .40094 .64476 .39993 Mtetra
.702 .753 .892 r
.64476 .39993 .64558 .40094 .64725 .40001 .64643 .39921 Mtetra
.703 .799 .925 r
.64643 .39921 .64725 .40001 .64891 .39916 .6481 .39849 Mtetra
.659 .821 .961 r
.6481 .39849 .64891 .39916 .6506 .39868 .64978 .39793 Mtetra
.579 .771 .97 r
.64978 .39793 .6506 .39868 .65233 .39947 .65148 .39763 Mtetra
.53 .548 .818 r
.65148 .39763 .65233 .39947 .65413 .40199 .65318 .39777 Mtetra
.481 .39 .675 r
.65318 .39777 .65413 .40199 .65664 .42166 .65493 .39872 Mtetra
.456 .285 .56 r
.65493 .39872 .65664 .42166 .66584 .60351 .65689 .40492 Mtetra
.023 0 .425 r
.65689 .40492 .66584 .60351 .66778 .60647 .66678 .60236 Mtetra
.055 .113 .607 r
.66678 .60236 .66778 .60647 .66966 .60774 .66877 .60627 Mtetra
.368 .524 .88 r
.66877 .60627 .66966 .60774 .67148 .60781 .67062 .60686 Mtetra
.636 .759 .937 r
.67062 .60686 .67148 .60781 .67329 .60732 .67242 .60639 Mtetra
.721 .789 .906 r
.67242 .60639 .67329 .60732 .67508 .60659 .67421 .60553 Mtetra
.662 .743 .91 r
.67421 .60553 .67508 .60659 .67689 .60621 .67601 .60495 Mtetra
.643 .699 .887 r
.67601 .60495 .67689 .60621 .6787 .60582 .67782 .60446 Mtetra
.67 .693 .863 r
.67782 .60446 .6787 .60582 .6805 .60507 .67962 .60382 Mtetra
.752 .739 .84 r
.67962 .60382 .6805 .60507 .68223 .60287 .6814 .60265 Mtetra
.845 .962 .882 r
.6814 .60265 .68223 .60287 .68386 .59858 .68316 .60108 Mtetra
.206 0 .197 r
.68316 .60108 .68386 .59858 .68497 .5832 .68492 .59933 Mtetra
.539 .303 .506 r
.68492 .59933 .68497 .5832 .67812 .40066 .68672 .59872 Mtetra
.556 .34 .542 r
.68672 .59872 .67812 .40066 .67986 .40082 .68855 .59854 Mtetra
.555 .339 .542 r
.68855 .59854 .67986 .40082 .68159 .40091 .69035 .59768 Mtetra
.547 .333 .541 r
.69035 .59768 .68159 .40091 .68301 .39457 .69191 .59207 Mtetra
.026 0 .422 r
.69191 .59207 .68301 .39457 .68453 .39033 .68388 .39248 Mtetra
.732 .746 .233 r
.68388 .39248 .68453 .39033 .68613 .38772 .68535 .38719 Mtetra
.876 .884 .836 r
.68535 .38719 .68613 .38772 .6878 .38645 .68699 .38541 Mtetra
.68 .742 .898 r
.68699 .38541 .6878 .38645 .6895 .38585 .68869 .38478 Mtetra
.588 .699 .919 r
.68869 .38478 .6895 .38585 .69121 .3855 .69041 .38453 Mtetra
.599 .727 .934 r
.69041 .38453 .69121 .3855 .69293 .38517 .69213 .38423 Mtetra
.625 .744 .932 r
.69213 .38423 .69293 .38517 .69465 .38481 .69384 .38382 Mtetra
.631 .736 .924 r
.69384 .38382 .69465 .38481 .69636 .38442 .69556 .3834 Mtetra
.661 .741 .91 r
.69556 .3834 .69636 .38442 .69807 .38383 .69727 .38286 Mtetra
.682 .759 .91 r
.69727 .38286 .69807 .38383 .69977 .3831 .69897 .38223 Mtetra
.686 .782 .923 r
.69897 .38223 .69977 .3831 .70147 .38236 .70068 .38157 Mtetra
.691 .805 .936 r
.70068 .38157 .70147 .38236 .70317 .38155 .70239 .38089 Mtetra
.673 .836 .962 r
.70239 .38089 .70317 .38155 .70487 .38083 .7041 .38026 Mtetra
.616 .843 .986 r
.7041 .38026 .70487 .38083 .70659 .38044 .70581 .37977 Mtetra
.449 .742 .991 r
.70581 .37977 .70659 .38044 .70838 .38118 .70756 .37972 Mtetra
.442 .553 .873 r
.70756 .37972 .70838 .38118 .71028 .38382 .70933 .3801 Mtetra
.513 .426 .695 r
.70933 .3801 .71028 .38382 .71263 .3941 .71111 .38067 Mtetra
.559 .374 .587 r
.71111 .38067 .71263 .3941 .72544 .58168 .71287 .38077 Mtetra
.558 .345 .548 r
.71287 .38077 .72544 .58168 .72731 .58175 .71459 .38026 Mtetra
.71459 .38026 .72731 .58175 .72906 .57991 .7163 .37952 Mtetra
.7163 .37952 .72906 .57991 .73083 .57831 .71802 .37885 Mtetra
.71802 .37885 .73083 .57831 .73267 .57779 .71975 .37829 Mtetra
.71975 .37829 .73267 .57779 .7345 .57726 .72147 .37773 Mtetra
.72147 .37773 .7345 .57726 .73634 .57676 .7232 .37718 Mtetra
.7232 .37718 .73634 .57676 .73818 .57629 .72492 .37662 Mtetra
.72492 .37662 .73818 .57629 .74002 .57582 .72665 .37608 Mtetra
.72665 .37608 .74002 .57582 .74187 .57536 .72838 .37553 Mtetra
.72838 .37553 .74187 .57536 .74371 .57489 .73012 .37498 Mtetra
.73012 .37498 .74371 .57489 .74556 .57443 .73185 .37444 Mtetra
.73185 .37444 .74556 .57443 .74741 .57396 .73358 .3739 Mtetra
.73358 .3739 .74741 .57396 .74926 .57349 .73532 .37335 Mtetra
.73532 .37335 .74926 .57349 .75111 .57301 .73705 .37281 Mtetra
.73705 .37281 .75111 .57301 .75296 .57253 .73879 .37226 Mtetra
.73879 .37226 .75296 .57253 .75481 .57204 .74053 .37172 Mtetra
.74053 .37172 .75481 .57204 .75666 .57154 .74227 .37117 Mtetra
.74227 .37117 .75666 .57154 .75851 .571 .74401 .37061 Mtetra
.74401 .37061 .75851 .571 .76036 .57045 .74575 .37005 Mtetra
.74575 .37005 .76036 .57045 .76221 .56985 .74749 .36948 Mtetra
.74749 .36948 .76221 .56985 .76406 .5692 .74923 .36889 Mtetra
.74923 .36889 .76406 .5692 .7659 .56849 .75097 .36829 Mtetra
.75097 .36829 .7659 .56849 .76774 .56769 .75271 .36768 Mtetra
.75271 .36768 .76774 .56769 .76957 .56676 .75445 .36703 Mtetra
.75445 .36703 .76957 .56676 .77139 .56566 .75619 .36636 Mtetra
.75619 .36636 .77139 .56566 .77319 .56438 .75793 .36569 Mtetra
.558 .346 .548 r
.75793 .36569 .77319 .56438 .77485 .56106 .75965 .36474 Mtetra
.559 .346 .548 r
.75965 .36474 .77485 .56106 .7638 .38712 .76136 .36366 Mtetra
.566 .367 .57 r
.76136 .36366 .7638 .38712 .76535 .38373 .76311 .36317 Mtetra
.534 .346 .572 r
.76311 .36317 .76535 .38373 .7808 .56438 .76502 .36474 Mtetra
.091 .01 .461 r
.76502 .36474 .7808 .56438 .78315 .5702 .78163 .55983 Mtetra
.047 .031 .513 r
.78163 .55983 .78315 .5702 .78526 .57267 .78437 .57071 Mtetra
.011 .223 .732 r
.78437 .57071 .78526 .57267 .78724 .57359 .78645 .57288 Mtetra
.396 .715 .987 r
.78645 .57288 .78724 .57359 .78915 .57343 .78838 .57294 Mtetra
.699 .904 .969 r
.78838 .57294 .78915 .57343 .79101 .5727 .79023 .57208 Mtetra
.908 .878 .794 r
.79023 .57208 .79101 .5727 .79282 .57127 .79197 .56972 Mtetra
.944 .739 .596 r
.79197 .56972 .79282 .57127 .79454 .56869 .79336 .56306 Mtetra
.974 .677 .388 r
.79336 .56306 .79454 .56869 .79607 .56377 .77924 .36222 Mtetra
.565 .35 .548 r
.77924 .36222 .79607 .56377 .78211 .36688 .78066 .35741 Mtetra
.618 .428 .603 r
.78066 .35741 .78211 .36688 .78331 .35934 .78233 .35564 Mtetra
.653 .516 .684 r
.78233 .35564 .78331 .35934 .78486 .35619 .78405 .35453 Mtetra
.676 .649 .815 r
.78405 .35453 .78486 .35619 .78654 .35456 .7858 .3538 Mtetra
.635 .802 .963 r
.7858 .3538 .78654 .35456 .7883 .35403 .78757 .3533 Mtetra
.591 .795 .977 r
.78757 .3533 .7883 .35403 .7901 .3538 .78935 .35293 Mtetra
.663 .783 .938 r
.78935 .35293 .7901 .3538 .79188 .35342 .79111 .35235 Mtetra
.737 .763 .874 r
.79111 .35235 .79188 .35342 .79362 .35253 .79285 .35138 Mtetra
.672 .726 .89 r
.79285 .35138 .79362 .35253 .79537 .35183 .79461 .35076 Mtetra
.342 .576 .927 r
.79461 .35076 .79537 .35183 .79718 .35172 .79647 .35123 Mtetra
.823 .359 0 r
.79647 .35123 .79718 .35172 .79909 .3528 .79862 .35499 Mtetra
.974 .667 .358 r
.79862 .35499 .79909 .3528 .80116 .35562 .8178 .55517 Mtetra
.564 .346 .542 r
.8178 .55517 .80116 .35562 .81989 .5488 .82025 .56103 Mtetra
.574 .322 .496 r
.82025 .56103 .81989 .5488 .82279 .55968 .82229 .56209 Mtetra
.527 .165 .295 r
.82229 .56209 .82279 .55968 .82497 .56242 .82426 .56229 Mtetra
.177 .707 .848 r
.82426 .56229 .82497 .56242 .82701 .56341 .8262 .56216 Mtetra
.565 .675 .913 r
.8262 .56216 .82701 .56341 .82895 .56324 .82813 .56199 Mtetra
.68 .726 .885 r
.82813 .56199 .82895 .56324 .83083 .56248 .83002 .56129 Mtetra
.843 .784 .794 r
.83002 .56129 .83083 .56248 .83264 .56088 .8318 .55926 Mtetra
.95 .736 .578 r
.8318 .55926 .83264 .56088 .83429 .5575 .83309 .55195 Mtetra
.975 .674 .37 r
.83309 .55195 .83429 .5575 .83573 .55184 .81647 .34991 Mtetra
.562 .348 .548 r
.81647 .34991 .83573 .55184 .83713 .54595 .81801 .3467 Mtetra
.543 .335 .548 r
.81801 .3467 .83713 .54595 .83976 .55313 .8206 .35479 Mtetra
.102 .022 .471 r
.8206 .35479 .83976 .55313 .84203 .55644 .84106 .55354 Mtetra
.04 .164 .668 r
.84106 .55354 .84203 .55644 .84412 .55784 .84333 .55675 Mtetra
.547 .7 .94 r
.84333 .55675 .84412 .55784 .84606 .55753 .84528 .55661 Mtetra
.686 .798 .934 r
.84528 .55661 .84606 .55753 .84796 .55685 .84718 .55587 Mtetra
.729 .8 .908 r
.84718 .55587 .84796 .55685 .84985 .55602 .84906 .55493 Mtetra
.673 .756 .914 r
.84906 .55493 .84985 .55602 .85175 .5553 .85097 .55427 Mtetra
.672 .768 .922 r
.85097 .55427 .85175 .5553 .85366 .5546 .85288 .5536 Mtetra
.629 .759 .941 r
.85288 .5536 .85366 .5546 .85558 .55413 .8548 .55312 Mtetra
.469 .68 .957 r
.8548 .55312 .85558 .55413 .85758 .5543 .85679 .55319 Mtetra
.621 .729 .924 r
.85679 .55319 .85758 .5543 .85952 .55397 .85872 .55276 Mtetra
.818 .779 .816 r
.85872 .55276 .85952 .55397 .86134 .55232 .86053 .55101 Mtetra
.973 .746 .534 r
.86053 .55101 .86134 .55232 .86246 .54378 .86162 .54213 Mtetra
.977 .674 .343 r
.86162 .54213 .86246 .54378 .84385 .33971 .84312 .33866 Mtetra
.948 .791 .654 r
.84312 .33866 .84385 .33971 .84528 .33545 .84455 .33448 Mtetra
.731 .789 .899 r
.84455 .33448 .84528 .33545 .84705 .33457 .84632 .33357 Mtetra
.591 .727 .938 r
.84632 .33357 .84705 .33457 .84888 .3343 .84815 .33327 Mtetra
.536 .692 .94 r
.84815 .33327 .84888 .3343 .85073 .3342 .85 .33317 Mtetra
.696 .765 .905 r
.85 .33317 .85073 .3342 .8525 .33325 .85179 .33243 Mtetra
.68 .808 .944 r
.85179 .33243 .8525 .33325 .85428 .33251 .85358 .33176 Mtetra
.626 .809 .97 r
.85358 .33176 .85428 .33251 .85612 .33226 .8554 .33127 Mtetra
.561 .714 .944 r
.8554 .33127 .85612 .33226 .85813 .33354 .85725 .33107 Mtetra
.521 .493 .766 r
.85725 .33107 .85813 .33354 .86036 .33694 .85915 .33139 Mtetra
.468 .361 .649 r
.85915 .33139 .86036 .33694 .8833 .53429 .86119 .33293 Mtetra
.144 .055 .487 r
.86119 .33293 .8833 .53429 .8861 .54175 .8837 .52547 Mtetra
.142 .084 .526 r
.8837 .52547 .8861 .54175 .88835 .54409 .88738 .54115 Mtetra
.159 .244 .703 r
.88738 .54115 .88835 .54409 .89045 .54503 .88968 .54388 Mtetra
.527 .679 .935 r
.88968 .54388 .89045 .54503 .89243 .54479 .89168 .54382 Mtetra
.667 .784 .936 r
.89168 .54382 .89243 .54479 .89437 .54418 .89361 .54316 Mtetra
.721 .792 .908 r
.89361 .54316 .89437 .54418 .8963 .54344 .89552 .54225 Mtetra
.623 .717 .914 r
.89552 .54225 .8963 .54344 .89828 .54318 .89748 .54181 Mtetra
.646 .695 .881 r
.89748 .54181 .89828 .54318 .90024 .54269 .89944 .54127 Mtetra
.678 .702 .865 r
.89944 .54127 .90024 .54269 .90214 .54171 .90137 .54054 Mtetra
.726 .766 .885 r
.90137 .54054 .90214 .54171 .90387 .5391 .90328 .53957 Mtetra
.451 .816 .552 r
.90328 .53957 .90387 .5391 .90534 .53432 .90512 .53807 Mtetra
.263 .008 .326 r
.90512 .53807 .90534 .53432 .88478 .33615 .90684 .53542 Mtetra
.533 .324 .541 r
.90684 .53542 .88478 .33615 .88563 .32704 .90711 .52008 Mtetra
.124 .038 .478 r
.90711 .52008 .88563 .32704 .88715 .32377 .88666 .32468 Mtetra
.779 .829 .36 r
.88666 .32468 .88715 .32377 .88882 .32182 .88812 .32089 Mtetra
.741 .806 .904 r
.88812 .32089 .88882 .32182 .89063 .3211 .8899 .31993 Mtetra
.621 .705 .905 r
.8899 .31993 .89063 .3211 .89248 .32074 .89175 .31953 Mtetra
.55 .663 .911 r
.89175 .31953 .89248 .32074 .89436 .32056 .89364 .31943 Mtetra
.668 .708 .878 r
.30178 .50952 .30272 .51057 .30421 .51001 .30327 .50901 Mtetra
.646 .712 .896 r
.30327 .50901 .30421 .51001 .30569 .50951 .30474 .50861 Mtetra
.635 .731 .917 r
.30474 .50861 .30569 .50951 .30717 .50913 .30622 .50823 Mtetra
.747 .754 .858 r
.30622 .50823 .30717 .50913 .30863 .50891 .30773 .50731 Mtetra
.674 .631 .798 r
.30773 .50731 .30863 .50891 .31007 .50912 .30923 .50667 Mtetra
.575 .51 .745 r
.30923 .50667 .31007 .50912 .31146 .51023 .31069 .5066 Mtetra
0 .02 .551 r
.31069 .5066 .31146 .51023 .31213 .52251 .31194 .50967 Mtetra
.956 .701 .511 r
.31194 .50967 .31213 .52251 .30188 .70804 .30129 .70049 Mtetra
0 0 .342 r
.30129 .70049 .30188 .70804 .30323 .71109 .30234 .70831 Mtetra
.403 .395 .736 r
.30234 .70831 .30323 .71109 .30477 .71125 .30383 .70923 Mtetra
.563 .547 .794 r
.30383 .70923 .30477 .71125 .30635 .71068 .30538 .70921 Mtetra
.64 .645 .839 r
.30538 .70921 .30635 .71068 .30797 .70965 .30696 .70878 Mtetra
.4 .664 .966 r
.30696 .70878 .30797 .70965 .30957 .70887 .3085 .70893 Mtetra
.191 .722 .792 r
.3085 .70893 .30957 .70887 .31119 .70771 .31007 .70869 Mtetra
0 0 0 r
.31007 .70869 .31119 .70771 .31286 .70571 .31168 .70772 Mtetra
.939 .915 .537 r
.31168 .70772 .31286 .70571 .3149 .69752 .31352 .703 Mtetra
.947 .696 .524 r
.31352 .703 .3149 .69752 .32777 .50645 .32666 .50832 Mtetra
.997 .861 .565 r
.32666 .50832 .32777 .50645 .32948 .50226 .32853 .50149 Mtetra
.809 .782 .827 r
.32853 .50149 .32948 .50226 .33102 .5011 .33008 .5001 Mtetra
.657 .718 .893 r
.33008 .5001 .33102 .5011 .33251 .50063 .33158 .49964 Mtetra
.54 .679 .928 r
.33158 .49964 .33251 .50063 .33399 .50044 .33305 .49956 Mtetra
.742 .76 .868 r
.33305 .49956 .33399 .50044 .33552 .49947 .33457 .49869 Mtetra
.709 .777 .905 r
.33457 .49869 .33552 .49947 .33704 .49869 .33608 .49801 Mtetra
.472 .73 .983 r
.33608 .49801 .33704 .49869 .33852 .49855 .33756 .49796 Mtetra
.909 .516 .248 r
.33756 .49796 .33852 .49855 .33981 .50175 .33883 .50153 Mtetra
.941 .682 .518 r
.33883 .50153 .33981 .50175 .33059 .69548 .32953 .69576 Mtetra
.897 .562 .404 r
.32953 .69576 .33059 .69548 .33179 .70215 .33077 .70156 Mtetra
0 .438 .813 r
.33077 .70156 .33179 .70215 .33331 .70291 .33231 .70213 Mtetra
.664 .78 .936 r
.33231 .70213 .33331 .70291 .33491 .70248 .33391 .7016 Mtetra
.746 .772 .874 r
.33391 .7016 .33491 .70248 .33653 .70148 .33553 .70065 Mtetra
.506 .72 .968 r
.33553 .70065 .33653 .70148 .33814 .70068 .33711 .70058 Mtetra
.257 .759 .888 r
.33711 .70058 .33814 .70068 .33977 .69959 .33869 .7004 Mtetra
0 0 0 r
.33869 .7004 .33977 .69959 .34145 .69769 .34031 .69958 Mtetra
.894 .915 .517 r
.34031 .69958 .34145 .69769 .34337 .69085 .3421 .69545 Mtetra
.949 .695 .519 r
.3421 .69545 .34337 .69085 .3548 .49837 .35368 .50124 Mtetra
.987 .858 .489 r
.35368 .50124 .3548 .49837 .35653 .49378 .35558 .49307 Mtetra
.839 .795 .809 r
.35558 .49307 .35653 .49378 .35808 .4924 .35715 .49139 Mtetra
.666 .72 .889 r
.35715 .49139 .35808 .4924 .35959 .4919 .35867 .49089 Mtetra
.545 .677 .925 r
.35867 .49089 .35959 .4919 .36109 .49173 .36016 .49081 Mtetra
.722 .75 .874 r
.36016 .49081 .36109 .49173 .36262 .49092 .36169 .49003 Mtetra
.713 .754 .884 r
.36169 .49003 .36262 .49092 .36415 .49019 .36322 .4893 Mtetra
.544 .706 .946 r
.36322 .4893 .36415 .49019 .36564 .49006 .36471 .48919 Mtetra
.888 .46 .103 r
.36471 .48919 .36564 .49006 .367 .49298 .36606 .49223 Mtetra
.944 .684 .511 r
.36606 .49223 .367 .49298 .35936 .68667 .35834 .68644 Mtetra
.923 .587 .386 r
.35834 .68644 .35936 .68667 .36061 .69369 .35961 .69306 Mtetra
0 .262 .677 r
.35961 .69306 .36061 .69369 .36215 .6947 .36116 .69391 Mtetra
.65 .778 .942 r
.36116 .69391 .36215 .6947 .36376 .69432 .36277 .69343 Mtetra
.743 .772 .877 r
.36277 .69343 .36376 .69432 .3654 .69337 .36441 .6925 Mtetra
.562 .732 .955 r
.36441 .6925 .3654 .69337 .36703 .69253 .36601 .69231 Mtetra
.307 .774 .94 r
.36601 .69231 .36703 .69253 .36867 .69148 .36761 .69216 Mtetra
0 0 0 r
.36761 .69216 .36867 .69148 .37034 .68969 .36924 .69141 Mtetra
.843 .91 .505 r
.36924 .69141 .37034 .68969 .37218 .68401 .37099 .68781 Mtetra
.951 .695 .513 r
.37099 .68781 .37218 .68401 .38212 .49047 .38094 .49538 Mtetra
.925 .814 .351 r
.38094 .49538 .38212 .49047 .38385 .48528 .38291 .48464 Mtetra
.866 .804 .787 r
.38291 .48464 .38385 .48528 .38542 .48366 .3845 .48262 Mtetra
.673 .717 .882 r
.3845 .48262 .38542 .48366 .38695 .48314 .38603 .48208 Mtetra
.547 .669 .917 r
.38603 .48208 .38695 .48314 .38846 .48298 .38754 .482 Mtetra
.689 .734 .885 r
.38754 .482 .38846 .48298 .39 .48227 .38908 .48138 Mtetra
.713 .759 .888 r
.38908 .48138 .39 .48227 .39154 .48151 .39062 .48066 Mtetra
.576 .73 .947 r
.39062 .48066 .39154 .48151 .39306 .48134 .39214 .48045 Mtetra
.734 .242 0 r
.39214 .48045 .39306 .48134 .39447 .48405 .39357 .48245 Mtetra
.949 .685 .503 r
.39357 .48245 .39447 .48405 .3884 .67848 .38787 .66623 Mtetra
0 0 .177 r
.38787 .66623 .3884 .67848 .38973 .68552 .38884 .68257 Mtetra
.214 .264 .698 r
.38884 .68257 .38973 .68552 .3913 .68657 .39038 .68437 Mtetra
.549 .526 .783 r
.39038 .68437 .3913 .68657 .39294 .68601 .39199 .68445 Mtetra
.642 .637 .83 r
.39199 .68445 .39294 .68601 .39459 .68492 .39362 .68399 Mtetra
.68 .755 .908 r
.39362 .68399 .39459 .68492 .39624 .68402 .39525 .68339 Mtetra
.695 .828 .946 r
.39525 .68339 .39624 .68402 .39788 .68338 .39689 .68272 Mtetra
.717 .823 .931 r
.39689 .68272 .39788 .68338 .39951 .68277 .39854 .68195 Mtetra
.7 .784 .916 r
.39854 .68195 .39951 .68277 .40115 .68226 .40018 .68126 Mtetra
.679 .742 .898 r
.40018 .68126 .40115 .68226 .40278 .68181 .40182 .68066 Mtetra
.671 .71 .877 r
.40182 .68066 .40278 .68181 .40442 .68139 .40346 .68009 Mtetra
.664 .683 .858 r
.40346 .68009 .40442 .68139 .40605 .68093 .4051 .67953 Mtetra
.658 .666 .847 r
.4051 .67953 .40605 .68093 .40769 .68044 .40674 .679 Mtetra
.653 .658 .843 r
.40674 .679 .40769 .68044 .40933 .67996 .40838 .67849 Mtetra
.648 .653 .841 r
.40838 .67849 .40933 .67996 .41097 .67949 .41002 .67801 Mtetra
.643 .649 .841 r
.41002 .67801 .41097 .67949 .41261 .67904 .41166 .67755 Mtetra
.638 .646 .841 r
.41166 .67755 .41261 .67904 .41425 .67861 .4133 .67711 Mtetra
.634 .644 .843 r
.4133 .67711 .41425 .67861 .41589 .67819 .41494 .6767 Mtetra
.629 .643 .845 r
.41494 .6767 .41589 .67819 .41753 .6778 .41658 .67632 Mtetra
.623 .643 .849 r
.41658 .67632 .41753 .6778 .41917 .67741 .41822 .67597 Mtetra
.615 .644 .856 r
.41822 .67597 .41917 .67741 .42082 .67711 .41986 .67566 Mtetra
.608 .64 .856 r
.41986 .67566 .42082 .67711 .42246 .67682 .42151 .67538 Mtetra
.607 .641 .858 r
.42151 .67538 .42246 .67682 .4241 .67639 .42315 .67511 Mtetra
.608 .667 .882 r
.42315 .67511 .4241 .67639 .42577 .67547 .42479 .67482 Mtetra
.569 .796 .985 r
.42479 .67482 .42577 .67547 .42744 .67403 .42644 .67452 Mtetra
.074 0 0 r
.42644 .67452 .42744 .67403 .42912 .67239 .42809 .67419 Mtetra
.408 .02 .188 r
.42809 .67419 .42912 .67239 .43079 .67121 .42974 .67384 Mtetra
.455 .115 .299 r
.42974 .67384 .43079 .67121 .43244 .67075 .43139 .67345 Mtetra
.455 .118 .304 r
.43139 .67345 .43244 .67075 .43409 .67053 .43304 .67304 Mtetra
.445 .1 .284 r
.43304 .67304 .43409 .67053 .43574 .67027 .43469 .67263 Mtetra
.436 .083 .267 r
.43469 .67263 .43574 .67027 .43739 .66988 .43635 .6722 Mtetra
.429 .074 .26 r
.43635 .6722 .43739 .66988 .43905 .66947 .43801 .67176 Mtetra
.458 .101 .271 r
.43801 .67176 .43905 .66947 .44069 .66937 .43966 .67148 Mtetra
.454 .087 .251 r
.43966 .67148 .44069 .66937 .44234 .66933 .44131 .67123 Mtetra
.327 0 .159 r
.44131 .67123 .44234 .66933 .44401 .66859 .44298 .67052 Mtetra
0 0 0 r
.44298 .67052 .44401 .66859 .44574 .66496 .44469 .6681 Mtetra
.948 .843 .411 r
.44469 .6681 .44574 .66496 .45172 .46986 .44653 .65979 Mtetra
0 0 .315 r
.44653 .65979 .45172 .46986 .45343 .46291 .45248 .46459 Mtetra
.774 .865 .429 r
.45248 .46459 .45343 .46291 .45504 .4606 .45411 .46118 Mtetra
0 0 0 r
.45411 .46118 .45504 .4606 .45661 .4599 .45568 .46039 Mtetra
.173 0 0 r
.45568 .46039 .45661 .4599 .45817 .45961 .45724 .46019 Mtetra
.257 0 0 r
.45724 .46019 .45817 .45961 .45974 .45933 .45881 .46006 Mtetra
.157 0 0 r
.45881 .46006 .45974 .45933 .46131 .45884 .46038 .45965 Mtetra
.145 0 0 r
.46038 .45965 .46131 .45884 .46288 .45837 .46195 .45916 Mtetra
0 0 0 r
.46195 .45916 .46288 .45837 .46445 .45795 .46353 .45839 Mtetra
.522 .9 .725 r
.46353 .45839 .46445 .45795 .46602 .45756 .46511 .45734 Mtetra
.77 .936 .937 r
.46511 .45734 .46602 .45756 .46759 .45718 .46669 .45633 Mtetra
.726 .777 .893 r
.46669 .45633 .46759 .45718 .46916 .45676 .46827 .45553 Mtetra
.665 .686 .86 r
.46827 .45553 .46916 .45676 .47074 .45628 .46985 .455 Mtetra
.649 .671 .857 r
.46985 .455 .47074 .45628 .47231 .45577 .47143 .45454 Mtetra
.651 .681 .866 r
.47143 .45454 .47231 .45577 .47389 .4552 .473 .45407 Mtetra
.663 .704 .878 r
.473 .45407 .47389 .4552 .47547 .45458 .47458 .45356 Mtetra
.664 .725 .894 r
.47458 .45356 .47547 .45458 .47705 .45396 .47616 .45304 Mtetra
.665 .747 .912 r
.47616 .45304 .47705 .45396 .47863 .45337 .47774 .45252 Mtetra
.664 .764 .924 r
.47774 .45252 .47863 .45337 .48021 .45284 .47932 .45201 Mtetra
.663 .768 .928 r
.47932 .45201 .48021 .45284 .4818 .45232 .48091 .45149 Mtetra
.663 .769 .929 r
.48091 .45149 .4818 .45232 .48338 .4518 .48249 .45098 Mtetra
.662 .77 .929 r
.48249 .45098 .48338 .4518 .48496 .45128 .48407 .45047 Mtetra
.66 .771 .932 r
.48407 .45047 .48496 .45128 .48655 .45076 .48566 .44996 Mtetra
.654 .773 .936 r
.48566 .44996 .48655 .45076 .48813 .45021 .48724 .44948 Mtetra
.642 .787 .952 r
.48724 .44948 .48813 .45021 .48972 .44961 .48883 .44902 Mtetra
.632 .823 .974 r
.48883 .44902 .48972 .44961 .49131 .44912 .49042 .44856 Mtetra
.641 .835 .975 r
.49042 .44856 .49131 .44912 .49289 .44893 .49201 .44806 Mtetra
.674 .763 .918 r
.49201 .44806 .49289 .44893 .49447 .44927 .4936 .4475 Mtetra
.655 .613 .795 r
.4936 .4475 .49447 .44927 .49605 .44984 .49519 .44693 Mtetra
.628 .523 .716 r
.49519 .44693 .49605 .44984 .49764 .45024 .49678 .44637 Mtetra
.612 .481 .679 r
.49678 .44637 .49764 .45024 .49923 .44986 .49837 .44583 Mtetra
.609 .476 .674 r
.49837 .44583 .49923 .44986 .50083 .44923 .49997 .44531 Mtetra
.61 .479 .677 r
.49997 .44531 .50083 .44923 .50242 .44856 .50156 .44479 Mtetra
.611 .483 .682 r
.50156 .44479 .50242 .44856 .50402 .44805 .50316 .44427 Mtetra
.50316 .44427 .50402 .44805 .50562 .44755 .50475 .44376 Mtetra
.61 .483 .682 r
.50475 .44376 .50562 .44755 .50721 .44704 .50635 .44325 Mtetra
.50635 .44325 .50721 .44704 .50881 .44654 .50795 .44275 Mtetra
.61 .482 .682 r
.50795 .44275 .50881 .44654 .51041 .44604 .50955 .44224 Mtetra
.61 .482 .681 r
.50955 .44224 .51041 .44604 .51201 .44554 .51115 .44173 Mtetra
.51115 .44173 .51201 .44554 .51361 .44504 .51275 .44122 Mtetra
.51275 .44122 .51361 .44504 .51522 .44453 .51435 .44071 Mtetra
.51435 .44071 .51522 .44453 .51682 .44403 .51595 .4402 Mtetra
.51595 .4402 .51682 .44403 .51843 .44352 .51756 .43969 Mtetra
.51756 .43969 .51843 .44352 .52003 .44301 .51916 .43917 Mtetra
.61 .481 .68 r
.51916 .43917 .52003 .44301 .52164 .4425 .52077 .43866 Mtetra
.52077 .43866 .52164 .4425 .52324 .44199 .52237 .43814 Mtetra
.52237 .43814 .52324 .44199 .52485 .44147 .52398 .43763 Mtetra
.52398 .43763 .52485 .44147 .52646 .44096 .52559 .43711 Mtetra
.52559 .43711 .52646 .44096 .52807 .44045 .5272 .43659 Mtetra
.5272 .43659 .52807 .44045 .52968 .43993 .52881 .43608 Mtetra
.52881 .43608 .52968 .43993 .5313 .43942 .53042 .43556 Mtetra
.53042 .43556 .5313 .43942 .53291 .4389 .53203 .43504 Mtetra
.53203 .43504 .53291 .4389 .53452 .43839 .53365 .43453 Mtetra
.53365 .43453 .53452 .43839 .53614 .43788 .53526 .43401 Mtetra
.53526 .43401 .53614 .43788 .53775 .43737 .53688 .4335 Mtetra
.53688 .4335 .53775 .43737 .53937 .43685 .53849 .43298 Mtetra
.53849 .43298 .53937 .43685 .54099 .43634 .54011 .43247 Mtetra
.609 .48 .68 r
.54011 .43247 .54099 .43634 .54261 .43583 .54173 .43196 Mtetra
.609 .481 .68 r
.54173 .43196 .54261 .43583 .54423 .43531 .54335 .43145 Mtetra
.61 .481 .68 r
.54335 .43145 .54423 .43531 .54585 .43479 .54497 .43094 Mtetra
.54497 .43094 .54585 .43479 .54747 .43427 .54659 .43042 Mtetra
.61 .482 .681 r
.54659 .43042 .54747 .43427 .54909 .43374 .54821 .42989 Mtetra
.611 .482 .681 r
.54821 .42989 .54909 .43374 .55072 .4332 .54983 .42937 Mtetra
.611 .483 .681 r
.54983 .42937 .55072 .4332 .55234 .43266 .55146 .42884 Mtetra
.55146 .42884 .55234 .43266 .55397 .43212 .55308 .42831 Mtetra
.611 .483 .682 r
.55308 .42831 .55397 .43212 .55559 .43159 .55471 .42778 Mtetra
.55471 .42778 .55559 .43159 .55722 .43107 .55633 .42726 Mtetra
.55633 .42726 .55722 .43107 .55885 .43055 .55796 .42673 Mtetra
.61 .483 .682 r
.55796 .42673 .55885 .43055 .56048 .43006 .55959 .42622 Mtetra
.61 .482 .681 r
.55959 .42622 .56048 .43006 .56211 .42976 .56122 .4257 Mtetra
.607 .475 .675 r
.56122 .4257 .56211 .42976 .56374 .4293 .56285 .42519 Mtetra
.606 .473 .673 r
.56285 .42519 .56374 .4293 .56537 .42845 .56448 .42469 Mtetra
.608 .483 .684 r
.56448 .42469 .56537 .42845 .56699 .42672 .56611 .42421 Mtetra
.626 .543 .741 r
.56611 .42421 .56699 .42672 .56861 .42513 .56775 .42372 Mtetra
.654 .659 .843 r
.56775 .42372 .56861 .42513 .57023 .42383 .56938 .42321 Mtetra
.666 .831 .963 r
.56938 .42321 .57023 .42383 .57186 .42316 .57102 .42263 Mtetra
.663 .855 .973 r
.57102 .42263 .57186 .42316 .5735 .42265 .57265 .42203 Mtetra
.671 .833 .961 r
.57265 .42203 .5735 .42265 .57514 .42222 .57429 .42144 Mtetra
.669 .788 .938 r
.57429 .42144 .57514 .42222 .57677 .42168 .57593 .42087 Mtetra
.668 .783 .935 r
.57593 .42087 .57677 .42168 .57841 .42115 .57757 .42031 Mtetra
.668 .777 .931 r
.57757 .42031 .57841 .42115 .58005 .42063 .5792 .41976 Mtetra
.686 .773 .918 r
.5792 .41976 .58005 .42063 .58169 .42018 .58084 .41913 Mtetra
.674 .731 .893 r
.58084 .41913 .58169 .42018 .58334 .41972 .58249 .41855 Mtetra
.652 .699 .881 r
.58249 .41855 .58334 .41972 .58498 .41923 .58413 .41807 Mtetra
.568 .667 .905 r
.58413 .41807 .58498 .41923 .58662 .41857 .58578 .41792 Mtetra
.45 .743 .991 r
.58578 .41792 .58662 .41857 .58826 .41788 .58743 .41787 Mtetra
.051 .618 .739 r
.58743 .41787 .58826 .41788 .5899 .4172 .58909 .41782 Mtetra
0 0 0 r
.58909 .41782 .5899 .4172 .59154 .41627 .59073 .41685 Mtetra
.59073 .41685 .59154 .41627 .59319 .41563 .59237 .41614 Mtetra
.297 0 0 r
.59237 .41614 .59319 .41563 .59484 .41552 .59403 .41613 Mtetra
.887 .512 .324 r
.59403 .41613 .59484 .41552 .59656 .41806 .59581 .42127 Mtetra
.962 .678 .448 r
.59581 .42127 .59656 .41806 .60236 .60066 .6019 .61926 Mtetra
.621 .372 .52 r
.6019 .61926 .60236 .60066 .60459 .62135 .60377 .62366 Mtetra
.535 .174 .301 r
.60377 .62366 .60459 .62135 .60638 .622 .60555 .6239 Mtetra
.373 0 .187 r
.60555 .6239 .60638 .622 .60814 .62137 .60732 .62332 Mtetra
.285 0 .154 r
.60732 .62332 .60814 .62137 .60988 .62014 .60907 .62235 Mtetra
.398 .039 .235 r
.60907 .62235 .60988 .62014 .61164 .61927 .61083 .62174 Mtetra
.422 .076 .272 r
.61083 .62174 .61164 .61927 .61339 .61858 .61259 .62117 Mtetra
.429 .089 .285 r
.61259 .62117 .61339 .61858 .61516 .61824 .61436 .6206 Mtetra
.421 .068 .26 r
.61436 .6206 .61516 .61824 .61696 .619 .61613 .62006 Mtetra
.239 0 0 r
.61613 .62006 .61696 .619 .61876 .61974 .6179 .61954 Mtetra
.506 .886 .967 r
.6179 .61954 .61876 .61974 .62056 .62019 .61967 .61903 Mtetra
.651 .716 .895 r
.61967 .61903 .62056 .62019 .62234 .61993 .62144 .61851 Mtetra
.648 .672 .859 r
.62144 .61851 .62234 .61993 .62411 .61942 .62321 .618 Mtetra
.645 .671 .86 r
.62321 .618 .62411 .61942 .62588 .61881 .62499 .61751 Mtetra
.639 .686 .879 r
.62499 .61751 .62588 .61881 .62766 .61844 .62676 .61705 Mtetra
.636 .672 .868 r
.62676 .61705 .62766 .61844 .62944 .61802 .62854 .6166 Mtetra
.636 .668 .864 r
.62854 .6166 .62944 .61802 .63121 .61742 .63032 .61615 Mtetra
.543 .652 .906 r
.63032 .61615 .63121 .61742 .63298 .61657 .63211 .6161 Mtetra
.506 .828 1 r
.63211 .6161 .63298 .61657 .63473 .61523 .6339 .61579 Mtetra
0 0 0 r
.6339 .61579 .63473 .61523 .63645 .61293 .63566 .61484 Mtetra
.655 .754 .27 r
.63566 .61484 .63645 .61293 .63793 .60311 .63733 .61079 Mtetra
.979 .699 .422 r
.63733 .61079 .63793 .60311 .63315 .4072 .63259 .41426 Mtetra
0 0 .155 r
.63259 .41426 .63315 .4072 .6347 .4031 .63394 .40395 Mtetra
.664 .882 .518 r
.63394 .40395 .6347 .4031 .63635 .40186 .63556 .40179 Mtetra
.702 .973 .923 r
.63556 .40179 .63635 .40186 .63803 .40145 .63722 .40079 Mtetra
.662 .826 .962 r
.63722 .40079 .63803 .40145 .63972 .40138 .63889 .40022 Mtetra
.667 .711 .881 r
.63889 .40022 .63972 .40138 .6414 .401 .64057 .39965 Mtetra
.651 .673 .857 r
.64057 .39965 .6414 .401 .64308 .40049 .64224 .39915 Mtetra
.64 .669 .862 r
.64224 .39915 .64308 .40049 .64476 .39993 .64393 .39871 Mtetra
.649 .692 .876 r
.64393 .39871 .64476 .39993 .64643 .39921 .64561 .39822 Mtetra
.654 .743 .915 r
.64561 .39822 .64643 .39921 .6481 .39849 .64729 .39772 Mtetra
.652 .793 .95 r
.64729 .39772 .6481 .39849 .64978 .39793 .64897 .3972 Mtetra
.743 .828 .917 r
.64897 .3972 .64978 .39793 .65148 .39763 .65064 .3963 Mtetra
.698 .694 .843 r
.65064 .3963 .65148 .39763 .65318 .39777 .65232 .39552 Mtetra
.599 .549 .769 r
.65232 .39552 .65318 .39777 .65493 .39872 .65401 .39527 Mtetra
.253 .264 .678 r
.65401 .39527 .65493 .39872 .65689 .40492 .65581 .39754 Mtetra
.978 .689 .397 r
.65581 .39754 .65689 .40492 .66678 .60236 .66541 .58901 Mtetra
0 0 .464 r
.66541 .58901 .66678 .60236 .66877 .60627 .6678 .60299 Mtetra
.424 .393 .72 r
.6678 .60299 .66877 .60627 .67062 .60686 .66968 .60413 Mtetra
.623 .541 .742 r
.66968 .60413 .67062 .60686 .67242 .60639 .67148 .60363 Mtetra
.664 .563 .731 r
.67148 .60363 .67242 .60639 .67421 .60553 .67327 .60268 Mtetra
.593 .518 .739 r
.67327 .60268 .67421 .60553 .67601 .60495 .67508 .60244 Mtetra
.552 .514 .767 r
.67508 .60244 .67601 .60495 .67782 .60446 .67692 .60253 Mtetra
.555 .565 .819 r
.67692 .60253 .67782 .60446 .67962 .60382 .67875 .60254 Mtetra
.605 .679 .894 r
.67875 .60254 .67962 .60382 .6814 .60265 .68057 .60223 Mtetra
.574 .871 .995 r
.68057 .60223 .6814 .60265 .68316 .60108 .68238 .60173 Mtetra
.056 0 0 r
.68238 .60173 .68316 .60108 .68492 .59933 .68419 .60115 Mtetra
.444 .054 .205 r
.68419 .60115 .68492 .59933 .68672 .59872 .68601 .60093 Mtetra
.455 .091 .258 r
.68601 .60093 .68672 .59872 .68855 .59854 .68784 .60065 Mtetra
.345 0 .205 r
.68784 .60065 .68855 .59854 .69035 .59768 .68964 .5998 Mtetra
0 0 0 r
.68964 .5998 .69035 .59768 .69191 .59207 .69132 .59649 Mtetra
.925 .748 .264 r
.69132 .59649 .69191 .59207 .68388 .39248 .69237 .58048 Mtetra
.017 0 .419 r
.69237 .58048 .68388 .39248 .68535 .38719 .68465 .38834 Mtetra
0 0 0 r
.68465 .38834 .68535 .38719 .68699 .38541 .68626 .38595 Mtetra
.68626 .38595 .68699 .38541 .68869 .38478 .68796 .38534 Mtetra
.235 0 0 r
.68796 .38534 .68869 .38478 .69041 .38453 .68969 .38517 Mtetra
0 0 0 r
.68969 .38517 .69041 .38453 .69213 .38423 .69139 .38447 Mtetra
.553 .923 .774 r
.69139 .38447 .69213 .38423 .69384 .38382 .69307 .3834 Mtetra
.76 .915 .942 r
.69307 .3834 .69384 .38382 .69556 .3834 .69476 .38239 Mtetra
.704 .757 .893 r
.69476 .38239 .69556 .3834 .69727 .38286 .69646 .38164 Mtetra
.662 .701 .876 r
.69646 .38164 .69727 .38286 .69897 .38223 .69817 .38109 Mtetra
.648 .711 .894 r
.69817 .38109 .69897 .38223 .70068 .38157 .69988 .3806 Mtetra
.645 .746 .923 r
.69988 .3806 .70068 .38157 .70239 .38089 .7016 .38012 Mtetra
.641 .794 .956 r
.7016 .38012 .70239 .38089 .7041 .38026 .70332 .37963 Mtetra
.633 .828 .975 r
.70332 .37963 .7041 .38026 .70581 .37977 .70503 .37912 Mtetra
.654 .83 .968 r
.70503 .37912 .70581 .37977 .70756 .37972 .70675 .37855 Mtetra
.674 .715 .88 r
.70675 .37855 .70756 .37972 .70933 .3801 .70846 .37793 Mtetra
.648 .583 .767 r
.70846 .37793 .70933 .3801 .71111 .38067 .71018 .37731 Mtetra
.622 .506 .701 r
.71018 .37731 .71111 .38067 .71287 .38077 .71189 .3767 Mtetra
.611 .479 .677 r
.71189 .3767 .71287 .38077 .71459 .38026 .71361 .37612 Mtetra
.61 .477 .675 r
.71361 .37612 .71459 .38026 .7163 .37952 .71533 .37554 Mtetra
.611 .481 .679 r
.71533 .37554 .7163 .37952 .71802 .37885 .71706 .37497 Mtetra
.612 .484 .682 r
.71706 .37497 .71802 .37885 .71975 .37829 .71878 .3744 Mtetra
.71878 .3744 .71975 .37829 .72147 .37773 .7205 .37384 Mtetra
.611 .484 .683 r
.7205 .37384 .72147 .37773 .7232 .37718 .72223 .37329 Mtetra
.611 .484 .682 r
.72223 .37329 .7232 .37718 .72492 .37662 .72395 .37273 Mtetra
.72395 .37273 .72492 .37662 .72665 .37608 .72568 .37218 Mtetra
.611 .483 .682 r
.72568 .37218 .72665 .37608 .72838 .37553 .72741 .37162 Mtetra
.72741 .37162 .72838 .37553 .73012 .37498 .72914 .37107 Mtetra
.61 .483 .682 r
.72914 .37107 .73012 .37498 .73185 .37444 .73087 .37052 Mtetra
.73087 .37052 .73185 .37444 .73358 .3739 .73261 .36997 Mtetra
.61 .482 .682 r
.73261 .36997 .73358 .3739 .73532 .37335 .73434 .36942 Mtetra
.61 .482 .681 r
.73434 .36942 .73532 .37335 .73705 .37281 .73607 .36887 Mtetra
.73607 .36887 .73705 .37281 .73879 .37226 .73781 .36833 Mtetra
.73781 .36833 .73879 .37226 .74053 .37172 .73955 .36778 Mtetra
.73955 .36778 .74053 .37172 .74227 .37117 .74129 .36723 Mtetra
.74129 .36723 .74227 .37117 .74401 .37061 .74302 .36668 Mtetra
.611 .483 .681 r
.74302 .36668 .74401 .37061 .74575 .37005 .74476 .36612 Mtetra
.611 .483 .682 r
.74476 .36612 .74575 .37005 .74749 .36948 .7465 .36556 Mtetra
.612 .484 .682 r
.7465 .36556 .74749 .36948 .74923 .36889 .74824 .36498 Mtetra
.613 .485 .682 r
.74824 .36498 .74923 .36889 .75097 .36829 .74999 .3644 Mtetra
.614 .486 .683 r
.74999 .3644 .75097 .36829 .75271 .36768 .75173 .3638 Mtetra
.615 .487 .683 r
.75173 .3638 .75271 .36768 .75445 .36703 .75347 .36319 Mtetra
.617 .489 .684 r
.75347 .36319 .75445 .36703 .75619 .36636 .75521 .36256 Mtetra
.618 .491 .685 r
.75521 .36256 .75619 .36636 .75793 .36569 .75695 .36192 Mtetra
.633 .501 .684 r
.75695 .36192 .75793 .36569 .75965 .36474 .75868 .36109 Mtetra
.642 .51 .687 r
.75868 .36109 .75965 .36474 .76136 .36366 .7604 .36015 Mtetra
.609 .494 .697 r
.7604 .36015 .76136 .36366 .76311 .36317 .76215 .35966 Mtetra
.449 .394 .704 r
.76215 .35966 .76311 .36317 .76502 .36474 .76403 .36076 Mtetra
0 0 .368 r
.76403 .36076 .76502 .36474 .78163 .55983 .76639 .36824 Mtetra
.049 0 .448 r
.76639 .36824 .78163 .55983 .78437 .57071 .7835 .56906 Mtetra
0 0 .549 r
.7835 .56906 .78437 .57071 .78645 .57288 .78566 .57211 Mtetra
.357 .677 .977 r
.78566 .57211 .78645 .57288 .78838 .57294 .78759 .57229 Mtetra
.732 .873 .946 r
.78759 .57229 .78838 .57294 .79023 .57208 .78944 .57135 Mtetra
.93 .848 .741 r
.78944 .57135 .79023 .57208 .79197 .56972 .79113 .56838 Mtetra
.976 .718 .475 r
.79113 .56838 .79197 .56972 .79336 .56306 .79173 .55165 Mtetra
.969 .671 .404 r
.79173 .55165 .79336 .56306 .77924 .36222 .77817 .35735 Mtetra
.724 .536 .636 r
.77817 .35735 .77924 .36222 .78066 .35741 .77973 .35421 Mtetra
.637 .523 .707 r
.77973 .35421 .78066 .35741 .78233 .35564 .78147 .35345 Mtetra
.593 .554 .779 r
.78147 .35345 .78233 .35564 .78405 .35453 .78326 .35324 Mtetra
.576 .654 .89 r
.78326 .35324 .78405 .35453 .7858 .3538 .78506 .35307 Mtetra
.653 .816 .962 r
.78506 .35307 .7858 .3538 .78757 .3533 .78682 .3525 Mtetra
.644 .795 .954 r
.78682 .3525 .78757 .3533 .78935 .35293 .78859 .35198 Mtetra
.65 .76 .93 r
.78859 .35198 .78935 .35293 .79111 .35235 .79037 .35146 Mtetra
.644 .773 .941 r
.79037 .35146 .79111 .35235 .79285 .35138 .79214 .35095 Mtetra
.332 .748 .978 r
.79214 .35095 .79285 .35138 .79461 .35076 .79395 .35092 Mtetra
.679 .137 0 r
.79395 .35092 .79461 .35076 .79647 .35123 .79591 .35252 Mtetra
.974 .668 .355 r
.79591 .35252 .79647 .35123 .79862 .35499 .81445 .547 Mtetra
.576 .354 .542 r
.81445 .547 .79862 .35499 .8178 .55517 .81754 .5604 Mtetra
.649 .341 .437 r
.81754 .5604 .8178 .55517 .82025 .56103 .81969 .56272 Mtetra
.451 .048 .183 r
.81969 .56272 .82025 .56103 .82229 .56209 .82163 .56259 Mtetra
0 0 0 r
.82163 .56259 .82229 .56209 .82426 .56229 .82351 .56183 Mtetra
.722 .922 .96 r
.82351 .56183 .82426 .56229 .8262 .56216 .82537 .56086 Mtetra
.684 .718 .875 r
.82537 .56086 .8262 .56216 .82813 .56199 .82726 .56012 Mtetra
.729 .663 .785 r
.82726 .56012 .82813 .56199 .83002 .56129 .8291 .55883 Mtetra
.82 .661 .686 r
.8291 .55883 .83002 .56129 .8318 .55926 .83076 .55561 Mtetra
.976 .675 .365 r
.83076 .55561 .8318 .55926 .83309 .55195 .81431 .35353 Mtetra
.571 .355 .548 r
.81431 .35353 .83309 .55195 .81647 .34991 .81534 .34472 Mtetra
.668 .496 .643 r
.81534 .34472 .81647 .34991 .81801 .3467 .817 .34277 Mtetra
.237 .241 .661 r
.817 .34277 .81801 .3467 .8206 .35479 .81911 .34576 Mtetra
.974 .67 .302 r
.81911 .34576 .8206 .35479 .84106 .55354 .83974 .54679 Mtetra
.087 .091 .566 r
.83974 .54679 .84106 .55354 .84333 .55675 .84235 .55374 Mtetra
.57 .5 .737 r
.84235 .55374 .84333 .55675 .84528 .55661 .84432 .5537 Mtetra
.646 .55 .732 r
.84432 .5537 .84528 .55661 .84718 .55587 .84621 .55289 Mtetra
.646 .547 .727 r
.84621 .55289 .84718 .55587 .84906 .55493 .8481 .55206 Mtetra
.548 .495 .748 r
.8481 .55206 .84906 .55493 .85097 .55427 .85008 .55221 Mtetra
.542 .551 .813 r
.85008 .55221 .85097 .55427 .85288 .5536 .85207 .55231 Mtetra
.529 .649 .911 r
.85207 .55231 .85288 .5536 .8548 .55312 .85404 .55229 Mtetra
.497 .738 .98 r
.85404 .55229 .8548 .55312 .85679 .55319 .85601 .55218 Mtetra
.666 .771 .929 r
.85601 .55218 .85679 .55319 .85872 .55276 .85792 .55154 Mtetra
.821 .781 .814 r
.85792 .55154 .85872 .55276 .86053 .55101 .85973 .54977 Mtetra
.965 .764 .583 r
.85973 .54977 .86053 .55101 .86162 .54213 .86105 .54319 Mtetra
.977 .675 .334 r
.86105 .54319 .86162 .54213 .84312 .33866 .84262 .34006 Mtetra
.799 .781 .278 r
.84262 .34006 .84312 .33866 .84455 .33448 .84396 .33489 Mtetra
.545 .875 .608 r
.84396 .33489 .84455 .33448 .84632 .33357 .84567 .33338 Mtetra
.632 .95 .941 r
.84567 .33338 .84632 .33357 .84815 .33327 .84744 .33252 Mtetra
.644 .814 .965 r
.84744 .33252 .84815 .33327 .85 .33317 .84925 .33197 Mtetra
.661 .716 .889 r
.84925 .33197 .85 .33317 .85179 .33243 .85106 .33139 Mtetra
.641 .741 .921 r
.85106 .33139 .85179 .33243 .85358 .33176 .85287 .33091 Mtetra
.644 .786 .95 r
.85287 .33091 .85358 .33176 .8554 .33127 .85468 .33038 Mtetra
.746 .814 .906 r
.85468 .33038 .8554 .33127 .85725 .33107 .85645 .3294 Mtetra
.663 .645 .822 r
.85645 .3294 .85725 .33107 .85915 .33139 .85825 .32875 Mtetra
.547 .498 .753 r
.85825 .32875 .85915 .33139 .86119 .33293 .86014 .3289 Mtetra
.142 .176 .637 r
.86014 .3289 .86119 .33293 .8837 .52547 .86243 .33277 Mtetra
.096 .022 .474 r
.86243 .33277 .8837 .52547 .88738 .54115 .88607 .53506 Mtetra
.141 .139 .595 r
.88607 .53506 .88738 .54115 .88968 .54388 .8887 .54094 Mtetra
.559 .498 .744 r
.8887 .54094 .88968 .54388 .89168 .54382 .89072 .541 Mtetra
.64 .553 .74 r
.89072 .541 .89168 .54382 .89361 .54316 .89265 .54028 Mtetra
.659 .559 .732 r
.89265 .54028 .89361 .54316 .89552 .54225 .89455 .53933 Mtetra
.556 .498 .746 r
.89455 .53933 .89552 .54225 .89748 .54181 .89657 .53942 Mtetra
.552 .53 .783 r
.89657 .53942 .89748 .54181 .89944 .54127 .89859 .53949 Mtetra
.559 .592 .843 r
.89859 .53949 .89944 .54127 .90137 .54054 .9006 .53945 Mtetra
.516 .685 .943 r
.9006 .53945 .90137 .54054 .90328 .53957 .90261 .5394 Mtetra
.419 .857 .926 r
.90261 .5394 .90328 .53957 .90512 .53807 .90458 .53889 Mtetra
0 0 0 r
.90458 .53889 .90512 .53807 .90684 .53542 .90645 .5376 Mtetra
.90645 .5376 .90684 .53542 .90711 .52008 .90791 .53268 Mtetra
.966 .667 .259 r
.90791 .53268 .90711 .52008 .88666 .32468 .88665 .32978 Mtetra
0 0 .251 r
.88665 .32978 .88666 .32468 .88812 .32089 .8876 .32156 Mtetra
0 0 0 r
.8876 .32156 .88812 .32089 .8899 .31993 .88929 .31976 Mtetra
.666 .967 .921 r
.88929 .31976 .8899 .31993 .89175 .31953 .89107 .31876 Mtetra
.655 .817 .961 r
.89107 .31876 .89175 .31953 .89364 .31943 .8929 .31816 Mtetra
.683 .692 .853 r
.30085 .50836 .30178 .50952 .30327 .50901 .30234 .50776 Mtetra
.614 .653 .865 r
.30234 .50776 .30327 .50901 .30474 .50861 .30381 .50748 Mtetra
.574 .663 .898 r
.30381 .50748 .30474 .50861 .30622 .50823 .30527 .50734 Mtetra
.742 .755 .863 r
.30527 .50734 .30622 .50823 .30773 .50731 .30678 .50646 Mtetra
.718 .76 .886 r
.30678 .50646 .30773 .50731 .30923 .50667 .30828 .50572 Mtetra
.629 .721 .913 r
.30828 .50572 .30923 .50667 .31069 .5066 .30976 .50537 Mtetra
0 .219 .739 r
.30976 .50537 .31069 .5066 .31194 .50967 .31114 .50654 Mtetra
0 0 .508 r
.31114 .50654 .31194 .50967 .30129 .70049 .3124 .5096 Mtetra
0 0 .268 r
.3124 .5096 .30129 .70049 .30234 .70831 .30205 .69616 Mtetra
.124 .044 .485 r
.30205 .69616 .30234 .70831 .30383 .70923 .30307 .70436 Mtetra
.293 .24 .625 r
.30307 .70436 .30383 .70923 .30538 .70921 .30447 .70675 Mtetra
.33 .372 .754 r
.30447 .70675 .30538 .70921 .30696 .70878 .30596 .70782 Mtetra
.176 .518 .917 r
.30596 .70782 .30696 .70878 .3085 .70893 .30747 .70837 Mtetra
.484 .778 .996 r
.30747 .70837 .3085 .70893 .31007 .70869 .30904 .70822 Mtetra
.768 .862 .919 r
.30904 .70822 .31007 .70869 .31168 .70772 .31065 .70723 Mtetra
.921 .772 .679 r
.31065 .70723 .31168 .70772 .31352 .703 .31248 .70271 Mtetra
.94 .688 .529 r
.31248 .70271 .31352 .703 .32666 .50832 .32568 .50801 Mtetra
.938 .747 .619 r
.32568 .50801 .32666 .50832 .32853 .50149 .32759 .50059 Mtetra
.802 .761 .815 r
.32759 .50059 .32853 .50149 .33008 .5001 .32914 .49918 Mtetra
.654 .734 .908 r
.32914 .49918 .33008 .5001 .33158 .49964 .33064 .49873 Mtetra
.517 .691 .947 r
.33064 .49873 .33158 .49964 .33305 .49956 .33211 .49869 Mtetra
.742 .761 .868 r
.33211 .49869 .33305 .49956 .33457 .49869 .33363 .49781 Mtetra
.706 .756 .891 r
.33363 .49781 .33457 .49869 .33608 .49801 .33514 .49714 Mtetra
.498 .692 .955 r
.33514 .49714 .33608 .49801 .33756 .49796 .33662 .49712 Mtetra
.922 .535 .235 r
.33662 .49712 .33756 .49796 .33883 .50153 .33787 .50101 Mtetra
.941 .683 .518 r
.33787 .50101 .33883 .50153 .32953 .69576 .32847 .69582 Mtetra
.901 .556 .382 r
.32847 .69582 .32953 .69576 .33077 .70156 .32975 .70112 Mtetra
0 .481 .806 r
.32975 .70112 .33077 .70156 .33231 .70213 .33129 .70155 Mtetra
.69 .835 .952 r
.33129 .70155 .33231 .70213 .33391 .7016 .3329 .7009 Mtetra
.771 .811 .885 r
.3329 .7009 .33391 .7016 .33553 .70065 .33453 .69985 Mtetra
.472 .711 .973 r
.33453 .69985 .33553 .70065 .33711 .70058 .3361 .69984 Mtetra
.488 .733 .98 r
.3361 .69984 .33711 .70058 .33869 .7004 .33768 .69977 Mtetra
.707 .823 .937 r
.33768 .69977 .33869 .7004 .34031 .69958 .33929 .69906 Mtetra
.917 .782 .696 r
.33929 .69906 .34031 .69958 .3421 .69545 .34107 .69509 Mtetra
.943 .688 .523 r
.34107 .69509 .3421 .69545 .35368 .50124 .35269 .5012 Mtetra
.951 .75 .597 r
.35269 .5012 .35368 .50124 .35558 .49307 .35465 .49217 Mtetra
.826 .762 .792 r
.35465 .49217 .35558 .49307 .35715 .49139 .35622 .49045 Mtetra
.665 .734 .902 r
.35622 .49045 .35715 .49139 .35867 .49089 .35774 .48996 Mtetra
.525 .689 .942 r
.35774 .48996 .35867 .49089 .36016 .49081 .35923 .4899 Mtetra
.722 .754 .878 r
.35923 .4899 .36016 .49081 .36169 .49003 .36076 .48912 Mtetra
.712 .754 .885 r
.36076 .48912 .36169 .49003 .36322 .4893 .36228 .48841 Mtetra
.534 .702 .947 r
.36228 .48841 .36322 .4893 .36471 .48919 .36378 .48832 Mtetra
.9 .484 .141 r
.36378 .48832 .36471 .48919 .36606 .49223 .36512 .4916 Mtetra
.944 .684 .511 r
.36512 .4916 .36606 .49223 .35834 .68644 .3573 .68658 Mtetra
.905 .567 .393 r
.3573 .68658 .35834 .68644 .35961 .69306 .3586 .6926 Mtetra
.306 0 0 r
.3586 .6926 .35961 .69306 .36116 .69391 .36016 .69332 Mtetra
.676 .832 .958 r
.36016 .69332 .36116 .69391 .36277 .69343 .36178 .69272 Mtetra
.768 .812 .888 r
.36178 .69272 .36277 .69343 .36441 .6925 .36342 .69168 Mtetra
.539 .735 .965 r
.36342 .69168 .36441 .6925 .36601 .69231 .36502 .69152 Mtetra
.478 .721 .977 r
.36502 .69152 .36601 .69231 .36761 .69216 .36661 .69149 Mtetra
.688 .814 .943 r
.36661 .69149 .36761 .69216 .36924 .69141 .36824 .69085 Mtetra
.912 .791 .714 r
.36824 .69085 .36924 .69141 .37099 .68781 .36999 .68738 Mtetra
.946 .689 .517 r
.36999 .68738 .37099 .68781 .38094 .49538 .37995 .49595 Mtetra
.966 .753 .564 r
.37995 .49595 .38094 .49538 .38291 .48464 .38199 .48369 Mtetra
.843 .756 .768 r
.38199 .48369 .38291 .48464 .3845 .48262 .38358 .48164 Mtetra
.671 .728 .893 r
.38358 .48164 .3845 .48262 .38603 .48208 .38511 .48111 Mtetra
.529 .682 .936 r
.38511 .48111 .38603 .48208 .38754 .482 .38662 .48105 Mtetra
.663 .734 .903 r
.38662 .48105 .38754 .482 .38908 .48138 .38815 .48056 Mtetra
.699 .77 .907 r
.38815 .48056 .38908 .48138 .39062 .48066 .38969 .47991 Mtetra
.608 .765 .955 r
.38969 .47991 .39062 .48066 .39214 .48045 .39122 .47958 Mtetra
0 .408 .851 r
.39122 .47958 .39214 .48045 .39357 .48245 .3927 .48032 Mtetra
0 0 .535 r
.3927 .48032 .39357 .48245 .38787 .66623 .39412 .48279 Mtetra
.518 .313 .541 r
.39412 .48279 .38787 .66623 .38884 .68257 .39494 .50046 Mtetra
0 0 .317 r
.39494 .50046 .38884 .68257 .39038 .68437 .38958 .67876 Mtetra
.283 .221 .609 r
.38958 .67876 .39038 .68437 .39199 .68445 .39108 .68171 Mtetra
.326 .352 .735 r
.39108 .68171 .39199 .68445 .39362 .68399 .39264 .68298 Mtetra
.498 .674 .943 r
.39264 .68298 .39362 .68399 .39525 .68339 .39426 .68299 Mtetra
.689 .886 .971 r
.39426 .68299 .39525 .68339 .39689 .68272 .3959 .68228 Mtetra
.767 .883 .929 r
.3959 .68228 .39689 .68272 .39854 .68195 .39755 .68128 Mtetra
.734 .823 .92 r
.39755 .68128 .39854 .68195 .40018 .68126 .3992 .68043 Mtetra
.69 .78 .92 r
.3992 .68043 .40018 .68126 .40182 .68066 .40084 .67979 Mtetra
.681 .769 .918 r
.40084 .67979 .40182 .68066 .40346 .68009 .40248 .67918 Mtetra
.678 .761 .914 r
.40248 .67918 .40346 .68009 .4051 .67953 .40413 .67859 Mtetra
.674 .752 .909 r
.40413 .67859 .4051 .67953 .40674 .679 .40577 .67801 Mtetra
.667 .741 .905 r
.40577 .67801 .40674 .679 .40838 .67849 .40741 .67746 Mtetra
.659 .731 .902 r
.40741 .67746 .40838 .67849 .41002 .67801 .40905 .67695 Mtetra
.651 .722 .901 r
.40905 .67695 .41002 .67801 .41166 .67755 .41069 .67647 Mtetra
.642 .716 .901 r
.41069 .67647 .41166 .67755 .4133 .67711 .41234 .67603 Mtetra
.635 .712 .903 r
.41234 .67603 .4133 .67711 .41494 .6767 .41398 .67562 Mtetra
.625 .709 .907 r
.41398 .67562 .41494 .6767 .41658 .67632 .41562 .67525 Mtetra
.61 .707 .913 r
.41562 .67525 .41658 .67632 .41822 .67597 .41726 .67494 Mtetra
.583 .706 .927 r
.41726 .67494 .41822 .67597 .41986 .67566 .4189 .67471 Mtetra
.554 .714 .946 r
.4189 .67471 .41986 .67566 .42151 .67538 .42054 .67455 Mtetra
.531 .734 .968 r
.42054 .67455 .42151 .67538 .42315 .67511 .42218 .67441 Mtetra
.502 .757 .987 r
.42218 .67441 .42315 .67511 .42479 .67482 .42382 .67428 Mtetra
.468 .783 .998 r
.42382 .67428 .42479 .67482 .42644 .67452 .42546 .67413 Mtetra
.437 .808 .994 r
.42546 .67413 .42644 .67452 .42809 .67419 .4271 .67393 Mtetra
.44 .837 .979 r
.4271 .67393 .42809 .67419 .42974 .67384 .42875 .67363 Mtetra
.47 .862 .972 r
.42875 .67363 .42974 .67384 .43139 .67345 .4304 .67325 Mtetra
.495 .874 .975 r
.4304 .67325 .43139 .67345 .43304 .67304 .43206 .67282 Mtetra
.504 .874 .979 r
.43206 .67282 .43304 .67304 .43469 .67263 .43371 .67239 Mtetra
.51 .874 .982 r
.43371 .67239 .43469 .67263 .43635 .6722 .43537 .67197 Mtetra
.534 .883 .984 r
.43537 .67197 .43635 .6722 .43801 .67176 .43703 .6715 Mtetra
.511 .871 .985 r
.43703 .6715 .43801 .67176 .43966 .67148 .43869 .67109 Mtetra
.574 .863 .996 r
.43869 .67109 .43966 .67148 .44131 .67123 .44035 .67064 Mtetra
.708 .845 .948 r
.44035 .67064 .44131 .67123 .44298 .67052 .44202 .6699 Mtetra
.85 .834 .831 r
.44202 .6699 .44298 .67052 .44469 .6681 .44371 .66816 Mtetra
.959 .867 .703 r
.44371 .66816 .44469 .6681 .44653 .65979 .44544 .66452 Mtetra
.74 .721 .192 r
.44544 .66452 .44653 .65979 .45248 .46459 .44728 .65608 Mtetra
0 0 .339 r
.44728 .65608 .45248 .46459 .45411 .46118 .45303 .46858 Mtetra
.468 .217 .45 r
.45303 .46858 .45411 .46118 .45568 .46039 .45462 .46716 Mtetra
.575 .306 .471 r
.45462 .46716 .45568 .46039 .45724 .46019 .45617 .46782 Mtetra
.629 .359 .49 r
.45617 .46782 .45724 .46019 .45881 .46006 .45769 .47 Mtetra
.629 .369 .505 r
.45769 .47 .45881 .46006 .46038 .45965 .4592 .47277 Mtetra
.489 .257 .489 r
.4592 .47277 .46038 .45965 .46195 .45916 .46081 .4707 Mtetra
.215 .03 .402 r
.46081 .4707 .46195 .45916 .46353 .45839 .46252 .46345 Mtetra
0 0 .196 r
.46252 .46345 .46353 .45839 .46511 .45734 .46418 .45852 Mtetra
.827 .929 .549 r
.46418 .45852 .46511 .45734 .46669 .45633 .46579 .45567 Mtetra
.839 .822 .832 r
.46579 .45567 .46669 .45633 .46827 .45553 .46739 .4541 Mtetra
.676 .66 .826 r
.46739 .4541 .46827 .45553 .46985 .455 .46897 .45346 Mtetra
.631 .627 .828 r
.46897 .45346 .46985 .455 .47143 .45454 .47054 .45307 Mtetra
.629 .636 .838 r
.47054 .45307 .47143 .45454 .473 .45407 .47212 .4527 Mtetra
.657 .661 .842 r
.47212 .4527 .473 .45407 .47458 .45356 .4737 .45219 Mtetra
.656 .661 .843 r
.4737 .45219 .47458 .45356 .47616 .45304 .47528 .45168 Mtetra
.656 .663 .844 r
.47528 .45168 .47616 .45304 .47774 .45252 .47686 .45117 Mtetra
.656 .664 .846 r
.47686 .45117 .47774 .45252 .47932 .45201 .47844 .45066 Mtetra
.656 .665 .847 r
.47844 .45066 .47932 .45201 .48091 .45149 .48002 .45015 Mtetra
.657 .667 .848 r
.48002 .45015 .48091 .45149 .48249 .45098 .48161 .44965 Mtetra
.657 .668 .849 r
.48161 .44965 .48249 .45098 .48407 .45047 .48319 .44913 Mtetra
.653 .667 .85 r
.48319 .44913 .48407 .45047 .48566 .44996 .48478 .44865 Mtetra
.641 .664 .857 r
.48478 .44865 .48566 .44996 .48724 .44948 .48636 .44822 Mtetra
.622 .667 .872 r
.48636 .44822 .48724 .44948 .48883 .44902 .48795 .44789 Mtetra
.624 .69 .891 r
.48795 .44789 .48883 .44902 .49042 .44856 .48953 .44755 Mtetra
.651 .723 .902 r
.48953 .44755 .49042 .44856 .49201 .44806 .49112 .44708 Mtetra
.693 .744 .89 r
.49112 .44708 .49201 .44806 .4936 .4475 .49272 .44643 Mtetra
.697 .727 .873 r
.49272 .44643 .4936 .4475 .49519 .44693 .49431 .44574 Mtetra
.685 .702 .86 r
.49431 .44574 .49519 .44693 .49678 .44637 .4959 .4451 Mtetra
.663 .682 .857 r
.4959 .4451 .49678 .44637 .49837 .44583 .49749 .44457 Mtetra
.658 .68 .859 r
.49749 .44457 .49837 .44583 .49997 .44531 .49909 .44406 Mtetra
.657 .682 .862 r
.49909 .44406 .49997 .44531 .50156 .44479 .50068 .44355 Mtetra
.659 .686 .864 r
.50068 .44355 .50156 .44479 .50316 .44427 .50228 .44304 Mtetra
.658 .687 .865 r
.50228 .44304 .50316 .44427 .50475 .44376 .50388 .44254 Mtetra
.658 .687 .866 r
.50388 .44254 .50475 .44376 .50635 .44325 .50547 .44203 Mtetra
.658 .688 .866 r
.50547 .44203 .50635 .44325 .50795 .44275 .50707 .44152 Mtetra
.50707 .44152 .50795 .44275 .50955 .44224 .50867 .44102 Mtetra
.658 .688 .867 r
.50867 .44102 .50955 .44224 .51115 .44173 .51027 .44051 Mtetra
.659 .688 .867 r
.51027 .44051 .51115 .44173 .51275 .44122 .51187 .44 Mtetra
.51187 .44 .51275 .44122 .51435 .44071 .51348 .43949 Mtetra
.51348 .43949 .51435 .44071 .51595 .4402 .51508 .43898 Mtetra
.659 .689 .866 r
.51508 .43898 .51595 .4402 .51756 .43969 .51668 .43846 Mtetra
.51668 .43846 .51756 .43969 .51916 .43917 .51829 .43795 Mtetra
.51829 .43795 .51916 .43917 .52077 .43866 .5199 .43743 Mtetra
.5199 .43743 .52077 .43866 .52237 .43814 .5215 .43692 Mtetra
.66 .689 .867 r
.5215 .43692 .52237 .43814 .52398 .43763 .52311 .4364 Mtetra
.52311 .4364 .52398 .43763 .52559 .43711 .52472 .43588 Mtetra
.659 .689 .867 r
.52472 .43588 .52559 .43711 .5272 .43659 .52633 .43537 Mtetra
.52633 .43537 .5272 .43659 .52881 .43608 .52794 .43485 Mtetra
.52794 .43485 .52881 .43608 .53042 .43556 .52955 .43434 Mtetra
.52955 .43434 .53042 .43556 .53203 .43504 .53116 .43382 Mtetra
.659 .69 .868 r
.53116 .43382 .53203 .43504 .53365 .43453 .53278 .43331 Mtetra
.53278 .43331 .53365 .43453 .53526 .43401 .53439 .43279 Mtetra
.658 .69 .868 r
.53439 .43279 .53526 .43401 .53688 .4335 .53601 .43228 Mtetra
.658 .691 .869 r
.53601 .43228 .53688 .4335 .53849 .43298 .53763 .43177 Mtetra
.657 .691 .87 r
.53763 .43177 .53849 .43298 .54011 .43247 .53924 .43127 Mtetra
.656 .692 .872 r
.53924 .43127 .54011 .43247 .54173 .43196 .54086 .43077 Mtetra
.656 .694 .873 r
.54086 .43077 .54173 .43196 .54335 .43145 .54248 .43027 Mtetra
.657 .696 .875 r
.54248 .43027 .54335 .43145 .54497 .43094 .5441 .42976 Mtetra
.659 .699 .876 r
.5441 .42976 .54497 .43094 .54659 .43042 .54572 .42925 Mtetra
.66 .701 .877 r
.54572 .42925 .54659 .43042 .54821 .42989 .54735 .42873 Mtetra
.661 .703 .878 r
.54735 .42873 .54821 .42989 .54983 .42937 .54897 .42821 Mtetra
.661 .704 .878 r
.54897 .42821 .54983 .42937 .55146 .42884 .55059 .42769 Mtetra
.662 .705 .879 r
.55059 .42769 .55146 .42884 .55308 .42831 .55222 .42716 Mtetra
.55222 .42716 .55308 .42831 .55471 .42778 .55384 .42663 Mtetra
.55384 .42663 .55471 .42778 .55633 .42726 .55547 .42611 Mtetra
.55547 .42611 .55633 .42726 .55796 .42673 .5571 .42558 Mtetra
.662 .704 .878 r
.5571 .42558 .55796 .42673 .55959 .42622 .55873 .42505 Mtetra
.665 .703 .876 r
.55873 .42505 .55959 .42622 .56122 .4257 .56036 .42451 Mtetra
.661 .697 .873 r
.56036 .42451 .56122 .4257 .56285 .42519 .56199 .42398 Mtetra
.654 .691 .872 r
.56199 .42398 .56285 .42519 .56448 .42469 .56362 .42348 Mtetra
.63 .683 .881 r
.56362 .42348 .56448 .42469 .56611 .42421 .56526 .4231 Mtetra
.63 .703 .898 r
.56526 .4231 .56611 .42421 .56775 .42372 .56689 .42272 Mtetra
.644 .73 .911 r
.56689 .42272 .56775 .42372 .56938 .42321 .56853 .42227 Mtetra
.697 .761 .901 r
.56853 .42227 .56938 .42321 .57102 .42263 .57016 .42159 Mtetra
.703 .742 .881 r
.57016 .42159 .57102 .42263 .57265 .42203 .5718 .42086 Mtetra
.698 .715 .863 r
.5718 .42086 .57265 .42203 .57429 .42144 .57343 .42014 Mtetra
.674 .686 .854 r
.57343 .42014 .57429 .42144 .57593 .42087 .57507 .41953 Mtetra
.667 .676 .85 r
.57507 .41953 .57593 .42087 .57757 .42031 .57671 .41895 Mtetra
.663 .672 .848 r
.57671 .41895 .57757 .42031 .5792 .41976 .57835 .41839 Mtetra
.697 .684 .834 r
.57835 .41839 .5792 .41976 .58084 .41913 .57998 .41762 Mtetra
.666 .651 .826 r
.57998 .41762 .58084 .41913 .58249 .41855 .58163 .41702 Mtetra
.609 .623 .84 r
.58163 .41702 .58249 .41855 .58413 .41807 .58327 .41674 Mtetra
.093 .364 .83 r
.58327 .41674 .58413 .41807 .58578 .41792 .58495 .41784 Mtetra
.805 .322 .051 r
.58495 .41784 .58578 .41792 .58743 .41787 .58665 .42014 Mtetra
.826 .487 .414 r
.58665 .42014 .58743 .41787 .58909 .41782 .58841 .42547 Mtetra
.531 .272 .468 r
.58841 .42547 .58909 .41782 .59073 .41685 .59007 .42517 Mtetra
.474 .229 .462 r
.59007 .42517 .59073 .41685 .59237 .41614 .5917 .42357 Mtetra
.546 .283 .468 r
.5917 .42357 .59237 .41614 .59403 .41613 .59337 .42361 Mtetra
.956 .672 .457 r
.59337 .42361 .59403 .41613 .59581 .42127 .59919 .61606 Mtetra
.564 .346 .542 r
.59919 .61606 .59581 .42127 .6019 .61926 .60107 .62105 Mtetra
.715 .335 .328 r
.60107 .62105 .6019 .61926 .60377 .62366 .60289 .62309 Mtetra
.406 .755 .994 r
.60289 .62309 .60377 .62366 .60555 .6239 .60466 .62304 Mtetra
.665 .784 .938 r
.60466 .62304 .60555 .6239 .60732 .62332 .60642 .62246 Mtetra
.72 .798 .913 r
.60642 .62246 .60732 .62332 .60907 .62235 .60818 .62162 Mtetra
.656 .814 .959 r
.60818 .62162 .60907 .62235 .61083 .62174 .60994 .62104 Mtetra
.648 .819 .966 r
.60994 .62104 .61083 .62174 .61259 .62117 .61171 .62049 Mtetra
.647 .824 .968 r
.61171 .62049 .61259 .62117 .61436 .6206 .61348 .61993 Mtetra
.648 .828 .97 r
.61348 .61993 .61436 .6206 .61613 .62006 .61524 .61936 Mtetra
.649 .821 .966 r
.61524 .61936 .61613 .62006 .6179 .61954 .61701 .6188 Mtetra
.648 .811 .961 r
.61701 .6188 .6179 .61954 .61967 .61903 .61878 .61825 Mtetra
.641 .799 .959 r
.61878 .61825 .61967 .61903 .62144 .61851 .62056 .61774 Mtetra
.635 .797 .96 r
.62056 .61774 .62144 .61851 .62321 .618 .62233 .61724 Mtetra
.629 .799 .964 r
.62233 .61724 .62321 .618 .62499 .61751 .62411 .61676 Mtetra
.623 .801 .967 r
.62411 .61676 .62499 .61751 .62676 .61705 .62588 .61629 Mtetra
.621 .798 .967 r
.62588 .61629 .62676 .61705 .62854 .6166 .62766 .61584 Mtetra
.619 .795 .966 r
.62766 .61584 .62854 .6166 .63032 .61615 .62944 .61539 Mtetra
.512 .753 .983 r
.62944 .61539 .63032 .61615 .63211 .6161 .63123 .61524 Mtetra
.585 .759 .961 r
.63123 .61524 .63211 .6161 .6339 .61579 .63302 .61493 Mtetra
.699 .796 .925 r
.63302 .61493 .6339 .61579 .63566 .61484 .63479 .61419 Mtetra
.891 .848 .794 r
.63479 .61419 .63566 .61484 .63733 .61079 .63652 .61192 Mtetra
.931 .906 .512 r
.63652 .61192 .63733 .61079 .63259 .41426 .63817 .60749 Mtetra
.003 0 .407 r
.63817 .60749 .63259 .41426 .63394 .40395 .63348 .4141 Mtetra
.029 0 .348 r
.63348 .4141 .63394 .40395 .63556 .40179 .63485 .40428 Mtetra
0 0 .031 r
.63485 .40428 .63556 .40179 .63722 .40079 .63643 .40102 Mtetra
.873 .994 .775 r
.63643 .40102 .63722 .40079 .63889 .40022 .63806 .39905 Mtetra
.734 .733 .849 r
.63806 .39905 .63889 .40022 .64057 .39965 .63972 .39809 Mtetra
.649 .641 .828 r
.63972 .39809 .64057 .39965 .64224 .39915 .6414 .39757 Mtetra
.611 .621 .836 r
.6414 .39757 .64224 .39915 .64393 .39871 .64309 .39727 Mtetra
.62 .645 .854 r
.64309 .39727 .64393 .39871 .64561 .39822 .64477 .39692 Mtetra
.625 .67 .873 r
.64477 .39692 .64561 .39822 .64729 .39772 .64646 .39656 Mtetra
.633 .698 .892 r
.64646 .39656 .64729 .39772 .64897 .3972 .64815 .39615 Mtetra
.719 .75 .877 r
.64815 .39615 .64897 .3972 .65064 .3963 .64982 .39532 Mtetra
.72 .765 .888 r
.64982 .39532 .65064 .3963 .65232 .39552 .65149 .3945 Mtetra
.649 .732 .909 r
.65149 .3945 .65232 .39552 .65401 .39527 .65318 .39401 Mtetra
.146 .411 .856 r
.65318 .39401 .65401 .39527 .65581 .39754 .65493 .395 Mtetra
0 .066 .615 r
.65493 .395 .65581 .39754 .66541 .58901 .65676 .398 Mtetra
.04 0 .431 r
.65676 .398 .66541 .58901 .6678 .60299 .66615 .58305 Mtetra
.338 .204 .547 r
.66615 .58305 .6678 .60299 .66968 .60413 .66839 .59323 Mtetra
.6 .413 .6 r
.66839 .59323 .66968 .60413 .67148 .60363 .67016 .59191 Mtetra
.591 .403 .596 r
.67016 .59191 .67148 .60363 .67327 .60268 .67193 .59083 Mtetra
.36 .237 .575 r
.67193 .59083 .67327 .60268 .67508 .60244 .674 .59645 Mtetra
.311 .247 .622 r
.674 .59645 .67508 .60244 .67692 .60253 .67598 .59984 Mtetra
.263 .323 .738 r
.67598 .59984 .67692 .60253 .67875 .60254 .67788 .60156 Mtetra
.401 .646 .956 r
.67788 .60156 .67875 .60254 .68057 .60223 .67973 .60179 Mtetra
.562 .861 .997 r
.67973 .60179 .68057 .60223 .68238 .60173 .68154 .60132 Mtetra
.648 .901 .983 r
.68154 .60132 .68238 .60173 .68419 .60115 .68335 .60062 Mtetra
.553 .836 .998 r
.68335 .60062 .68419 .60115 .68601 .60093 .68517 .60023 Mtetra
.582 .801 .983 r
.68517 .60023 .68601 .60093 .68784 .60065 .68699 .59986 Mtetra
.695 .817 .941 r
.68699 .59986 .68784 .60065 .68964 .5998 .68879 .59912 Mtetra
.886 .854 .805 r
.68879 .59912 .68964 .5998 .69132 .59649 .69053 .59696 Mtetra
.981 .91 .603 r
.69053 .59696 .69132 .59649 .69237 .58048 .69217 .59269 Mtetra
0 0 .302 r
.69217 .59269 .69237 .58048 .68465 .38834 .69327 .57766 Mtetra
.056 0 .432 r
.69327 .57766 .68465 .38834 .68626 .38595 .6859 .39391 Mtetra
.547 .286 .472 r
.6859 .39391 .68626 .38595 .68796 .38534 .68764 .39396 Mtetra
.552 .294 .478 r
.68764 .39396 .68796 .38534 .68969 .38517 .68939 .39413 Mtetra
.259 .068 .42 r
.68939 .39413 .68969 .38517 .69139 .38447 .69084 .38831 Mtetra
0 0 .216 r
.69084 .38831 .69139 .38447 .69307 .3834 .69235 .38405 Mtetra
.839 .948 .593 r
.69235 .38405 .69307 .3834 .69476 .38239 .69396 .38142 Mtetra
.793 .789 .849 r
.69396 .38142 .69476 .38239 .69646 .38164 .69563 .38011 Mtetra
.664 .655 .831 r
.69563 .38011 .69646 .38164 .69817 .38109 .69733 .3795 Mtetra
.621 .628 .835 r
.69733 .3795 .69817 .38109 .69988 .3806 .69906 .37913 Mtetra
.616 .642 .853 r
.69906 .37913 .69988 .3806 .7016 .38012 .70078 .3788 Mtetra
.623 .668 .873 r
.70078 .3788 .7016 .38012 .70332 .37963 .70251 .37843 Mtetra
.628 .694 .892 r
.70251 .37843 .70332 .37963 .70503 .37912 .70423 .37804 Mtetra
.667 .733 .899 r
.70423 .37804 .70503 .37912 .70675 .37855 .70595 .37747 Mtetra
.696 .742 .886 r
.70595 .37747 .70675 .37855 .70846 .37793 .70766 .37675 Mtetra
.697 .722 .869 r
.70766 .37675 .70846 .37793 .71018 .37731 .70937 .376 Mtetra
.679 .695 .859 r
.70937 .376 .71018 .37731 .71189 .3767 .71108 .37534 Mtetra
.664 .681 .856 r
.71108 .37534 .71189 .3767 .71361 .37612 .7128 .37476 Mtetra
.659 .679 .858 r
.7128 .37476 .71361 .37612 .71533 .37554 .71452 .3742 Mtetra
.66 .683 .861 r
.71452 .3742 .71533 .37554 .71706 .37497 .71624 .37364 Mtetra
.661 .685 .862 r
.71624 .37364 .71706 .37497 .71878 .3744 .71797 .37308 Mtetra
.66 .685 .862 r
.71797 .37308 .71878 .3744 .7205 .37384 .71969 .37252 Mtetra
.66 .685 .863 r
.71969 .37252 .7205 .37384 .72223 .37329 .72142 .37196 Mtetra
.72142 .37196 .72223 .37329 .72395 .37273 .72314 .3714 Mtetra
.659 .685 .863 r
.72314 .3714 .72395 .37273 .72568 .37218 .72487 .37085 Mtetra
.659 .684 .863 r
.72487 .37085 .72568 .37218 .72741 .37162 .7266 .3703 Mtetra
.658 .684 .863 r
.7266 .3703 .72741 .37162 .72914 .37107 .72833 .36974 Mtetra
.72833 .36974 .72914 .37107 .73087 .37052 .73007 .36919 Mtetra
.73007 .36919 .73087 .37052 .73261 .36997 .7318 .36864 Mtetra
.657 .684 .864 r
.7318 .36864 .73261 .36997 .73434 .36942 .73353 .3681 Mtetra
.73353 .3681 .73434 .36942 .73607 .36887 .73527 .36755 Mtetra
.656 .685 .865 r
.73527 .36755 .73607 .36887 .73781 .36833 .73701 .36701 Mtetra
.656 .686 .866 r
.73701 .36701 .73781 .36833 .73955 .36778 .73874 .36647 Mtetra
.656 .687 .868 r
.73874 .36647 .73955 .36778 .74129 .36723 .74048 .36593 Mtetra
.657 .689 .869 r
.74048 .36593 .74129 .36723 .74302 .36668 .74222 .36539 Mtetra
.659 .692 .87 r
.74222 .36539 .74302 .36668 .74476 .36612 .74396 .36484 Mtetra
.66 .693 .87 r
.74396 .36484 .74476 .36612 .7465 .36556 .7457 .36428 Mtetra
.662 .695 .871 r
.7457 .36428 .7465 .36556 .74824 .36498 .74745 .36371 Mtetra
.664 .697 .871 r
.74745 .36371 .74824 .36498 .74999 .3644 .74919 .36313 Mtetra
.666 .699 .871 r
.74919 .36313 .74999 .3644 .75173 .3638 .75093 .36254 Mtetra
.67 .701 .87 r
.75093 .36254 .75173 .3638 .75347 .36319 .75267 .36193 Mtetra
.674 .703 .869 r
.75267 .36193 .75347 .36319 .75521 .36256 .75441 .36129 Mtetra
.75441 .36129 .75521 .36256 .75695 .36192 .75616 .36066 Mtetra
.708 .716 .855 r
.75616 .36066 .75695 .36192 .75868 .36109 .75788 .35982 Mtetra
.725 .722 .848 r
.75788 .35982 .75868 .36109 .7604 .36015 .75961 .35887 Mtetra
.645 .69 .877 r
.75961 .35887 .7604 .36015 .76215 .35966 .76136 .35839 Mtetra
.15 .409 .854 r
.76136 .35839 .76215 .35966 .76403 .36076 .76324 .35946 Mtetra
.89 .507 .05 r
.76324 .35946 .76403 .36076 .76639 .36824 .76558 .36669 Mtetra
.976 .674 .362 r
.76558 .36669 .76639 .36824 .7835 .56906 .7827 .56814 Mtetra
.678 .208 0 r
.7827 .56814 .7835 .56906 .78566 .57211 .78485 .57125 Mtetra
.383 .669 .972 r
.78485 .57125 .78566 .57211 .78759 .57229 .78679 .57144 Mtetra
.735 .824 .919 r
.78679 .57144 .78759 .57229 .78944 .57135 .78864 .57049 Mtetra
.922 .827 .735 r
.78864 .57049 .78944 .57135 .79113 .56838 .79032 .56746 Mtetra
.982 .716 .445 r
.79032 .56746 .79113 .56838 .79173 .55165 .79056 .54602 Mtetra
.974 .677 .389 r
.79056 .54602 .79173 .55165 .77817 .35735 .77737 .35598 Mtetra
.884 .75 .71 r
.77737 .35598 .77817 .35735 .77973 .35421 .77894 .35293 Mtetra
.679 .703 .865 r
.77894 .35293 .77973 .35421 .78147 .35345 .78069 .35226 Mtetra
.555 .663 .909 r
.78069 .35226 .78147 .35345 .78326 .35324 .78249 .35215 Mtetra
.555 .686 .926 r
.78249 .35215 .78326 .35324 .78506 .35307 .78429 .35201 Mtetra
.686 .749 .899 r
.78429 .35201 .78506 .35307 .78682 .3525 .78605 .35133 Mtetra
.648 .711 .894 r
.78605 .35133 .78682 .3525 .78859 .35198 .78782 .35083 Mtetra
.514 .653 .921 r
.78782 .35083 .78859 .35198 .79037 .35146 .78964 .35085 Mtetra
0 .296 .739 r
.78964 .35085 .79037 .35146 .79214 .35095 .79155 .35193 Mtetra
.791 .357 .218 r
.79155 .35193 .79214 .35095 .79395 .35092 .7936 .35473 Mtetra
.972 .666 .365 r
.7936 .35473 .79395 .35092 .79591 .35252 .81191 .54829 Mtetra
.57 .35 .542 r
.81191 .54829 .79591 .35252 .81445 .547 .81471 .55837 Mtetra
.615 .35 .494 r
.81471 .55837 .81445 .547 .81754 .5604 .81689 .56109 Mtetra
.598 .087 .007 r
.81689 .56109 .81754 .5604 .81969 .56272 .81892 .56209 Mtetra
.461 .773 .997 r
.81892 .56209 .81969 .56272 .82163 .56259 .82086 .56194 Mtetra
.676 .859 .969 r
.82086 .56194 .82163 .56259 .82351 .56183 .82274 .56121 Mtetra
.815 .896 .9 r
.82274 .56121 .82351 .56183 .82537 .56086 .82457 .5598 Mtetra
.883 .809 .772 r
.82457 .5598 .82537 .56086 .82726 .56012 .82631 .55735 Mtetra
.844 .658 .651 r
.82631 .55735 .82726 .56012 .8291 .55883 .82787 .553 Mtetra
.975 .674 .373 r
.82787 .553 .8291 .55883 .83076 .55561 .81208 .35652 Mtetra
.574 .357 .548 r
.81208 .35652 .83076 .55561 .81431 .35353 .81293 .34568 Mtetra
.674 .475 .608 r
.81293 .34568 .81431 .35353 .81534 .34472 .81447 .34243 Mtetra
.705 .608 .746 r
.81447 .34243 .81534 .34472 .817 .34277 .8162 .34121 Mtetra
.179 .377 .822 r
.8162 .34121 .817 .34277 .81911 .34576 .81816 .34251 Mtetra
.003 .11 .624 r
.81816 .34251 .81911 .34576 .83974 .54679 .82035 .3463 Mtetra
.125 .039 .477 r
.82035 .3463 .83974 .54679 .84235 .55374 .84021 .53825 Mtetra
.55 .366 .585 r
.84021 .53825 .84235 .55374 .84432 .5537 .84221 .53875 Mtetra
.62 .416 .584 r
.84221 .53875 .84432 .5537 .84621 .55289 .84389 .53572 Mtetra
.458 .299 .577 r
.84389 .53572 .84621 .55289 .8481 .55206 .84632 .54066 Mtetra
.31 .211 .578 r
.84632 .54066 .8481 .55206 .85008 .55221 .84897 .54775 Mtetra
.315 .286 .667 r
.84897 .54775 .85008 .55221 .85207 .55231 .85121 .55049 Mtetra
.29 .428 .828 r
.85121 .55049 .85207 .55231 .85404 .55229 .85329 .55164 Mtetra
.485 .782 .997 r
.85329 .55164 .85404 .55229 .85601 .55218 .85525 .55144 Mtetra
.697 .848 .955 r
.85525 .55144 .85601 .55218 .85792 .55154 .85715 .55064 Mtetra
.822 .838 .861 r
.85715 .55064 .85792 .55154 .85973 .54977 .85898 .54909 Mtetra
.943 .865 .733 r
.85898 .54909 .85973 .54977 .86105 .54319 .86066 .54602 Mtetra
0 0 0 r
.86066 .54602 .86105 .54319 .84262 .34006 .86198 .53946 Mtetra
.113 .026 .47 r
.86198 .53946 .84262 .34006 .84396 .33489 .84389 .34041 Mtetra
.118 0 .352 r
.84389 .34041 .84396 .33489 .84567 .33338 .8452 .33498 Mtetra
0 0 0 r
.8452 .33498 .84567 .33338 .84744 .33252 .84679 .33224 Mtetra
.862 .97 .862 r
.84679 .33224 .84744 .33252 .84925 .33197 .84848 .33058 Mtetra
.668 .685 .857 r
.84848 .33058 .84925 .33197 .85106 .33139 .85028 .32994 Mtetra
.612 .65 .864 r
.85028 .32994 .85106 .33139 .85287 .33091 .85211 .32961 Mtetra
.605 .672 .888 r
.85211 .32961 .85287 .33091 .85468 .33038 .85395 .32931 Mtetra
.732 .769 .882 r
.85395 .32931 .85468 .33038 .85645 .3294 .85572 .32836 Mtetra
.698 .764 .903 r
.85572 .32836 .85645 .3294 .85825 .32875 .85751 .32761 Mtetra
.58 .692 .918 r
.85751 .32761 .85825 .32875 .86014 .3289 .85936 .32738 Mtetra
.058 .302 .788 r
.85936 .32738 .86014 .3289 .86243 .33277 .86141 .32905 Mtetra
.046 .122 .62 r
.86141 .32905 .86243 .33277 .88607 .53506 .86374 .33327 Mtetra
.136 .049 .485 r
.86374 .33327 .88607 .53506 .8887 .54094 .88679 .52924 Mtetra
.551 .377 .598 r
.88679 .52924 .8887 .54094 .89072 .541 .88883 .52965 Mtetra
.602 .412 .598 r
.88883 .52965 .89072 .541 .89265 .54028 .89067 .52813 Mtetra
.545 .371 .596 r
.89067 .52813 .89265 .54028 .89455 .53933 .89274 .52879 Mtetra
.343 .239 .59 r
.89274 .52879 .89455 .53933 .89657 .53942 .89541 .53478 Mtetra
.341 .301 .668 r
.89541 .53478 .89657 .53942 .89859 .53949 .89772 .53745 Mtetra
.301 .408 .805 r
.89772 .53745 .89859 .53949 .9006 .53945 .89988 .53874 Mtetra
.404 .726 .99 r
.89988 .53874 .9006 .53945 .90261 .5394 .9019 .53877 Mtetra
.608 .848 .989 r
.9019 .53877 .90261 .5394 .90458 .53889 .90386 .53822 Mtetra
.773 .89 .928 r
.90386 .53822 .90458 .53889 .90645 .5376 .90575 .53704 Mtetra
.934 .906 .771 r
.90575 .53704 .90645 .5376 .90791 .53268 .90747 .53442 Mtetra
0 0 0 r
.90747 .53442 .90791 .53268 .88665 .32978 .90895 .52964 Mtetra
.134 .045 .48 r
.90895 .52964 .88665 .32978 .8876 .32156 .88811 .33111 Mtetra
.153 .009 .419 r
.88811 .33111 .8876 .32156 .88929 .31976 .88896 .322 Mtetra
0 0 .122 r
.88896 .322 .88929 .31976 .89107 .31876 .89048 .31873 Mtetra
.863 .996 .781 r
.89048 .31873 .89107 .31876 .8929 .31816 .89215 .31678 Mtetra
.744 .793 .893 r
.29989 .50764 .30085 .50836 .30234 .50776 .30139 .5068 Mtetra
.616 .713 .915 r
.30139 .5068 .30234 .50776 .30381 .50748 .30286 .5065 Mtetra
.526 .675 .932 r
.30286 .5065 .30381 .50748 .30527 .50734 .30432 .50646 Mtetra
.707 .753 .888 r
.30432 .50646 .30527 .50734 .30678 .50646 .30581 .50579 Mtetra
.702 .8 .926 r
.30581 .50579 .30678 .50646 .30828 .50572 .30731 .50515 Mtetra
.652 .817 .963 r
.30731 .50515 .30828 .50572 .30976 .50537 .3088 .50467 Mtetra
.546 .755 .974 r
.3088 .50467 .30976 .50537 .31114 .50654 .31026 .5045 Mtetra
.504 .501 .787 r
.31026 .5045 .31114 .50654 .3124 .5096 .3117 .50477 Mtetra
.458 .352 .646 r
.3117 .50477 .3124 .5096 .30205 .69616 .31309 .50593 Mtetra
.538 .328 .544 r
.31309 .50593 .30205 .69616 .30307 .70436 .314 .51467 Mtetra
0 0 .258 r
.314 .51467 .30307 .70436 .30447 .70675 .30361 .70353 Mtetra
0 0 .485 r
.30361 .70353 .30447 .70675 .30596 .70782 .30495 .70684 Mtetra
.012 .411 .857 r
.30495 .70684 .30596 .70782 .30747 .70837 .30646 .70761 Mtetra
.566 .757 .968 r
.30646 .70761 .30747 .70837 .30904 .70822 .30803 .70737 Mtetra
.779 .779 .852 r
.30803 .70737 .30904 .70822 .31065 .70723 .30965 .70619 Mtetra
.894 .73 .672 r
.30965 .70619 .31065 .70723 .31248 .70271 .31149 .7015 Mtetra
.938 .686 .53 r
.31149 .7015 .31248 .70271 .32568 .50801 .32476 .50664 Mtetra
.899 .703 .628 r
.32476 .50664 .32568 .50801 .32759 .50059 .32665 .49966 Mtetra
.797 .755 .815 r
.32665 .49966 .32759 .50059 .32914 .49918 .3282 .49829 Mtetra
.651 .738 .914 r
.3282 .49829 .32914 .49918 .33064 .49873 .32969 .49785 Mtetra
.51 .694 .952 r
.32969 .49785 .33064 .49873 .33211 .49869 .33117 .49782 Mtetra
.739 .761 .871 r
.33117 .49782 .33211 .49869 .33363 .49781 .33269 .49695 Mtetra
.703 .76 .896 r
.33269 .49695 .33363 .49781 .33514 .49714 .3342 .49629 Mtetra
.489 .696 .96 r
.3342 .49629 .33514 .49714 .33662 .49712 .33567 .49629 Mtetra
.921 .533 .233 r
.33567 .49629 .33662 .49712 .33787 .50101 .33693 .50014 Mtetra
.941 .683 .518 r
.33693 .50014 .33787 .50101 .32847 .69582 .32748 .69481 Mtetra
.94 .582 .3 r
.32748 .69481 .32847 .69582 .32975 .70112 .32875 .70016 Mtetra
.236 .554 .932 r
.32875 .70016 .32975 .70112 .33129 .70155 .33029 .70063 Mtetra
.683 .754 .905 r
.33029 .70063 .33129 .70155 .3329 .7009 .3319 .70002 Mtetra
.757 .774 .867 r
.3319 .70002 .3329 .7009 .33453 .69985 .33352 .699 Mtetra
.508 .717 .966 r
.33352 .699 .33453 .69985 .3361 .69984 .3351 .69893 Mtetra
.55 .718 .951 r
.3351 .69893 .3361 .69984 .33768 .69977 .33668 .69878 Mtetra
.716 .748 .877 r
.33668 .69878 .33768 .69977 .33929 .69906 .3383 .69799 Mtetra
.888 .735 .685 r
.3383 .69799 .33929 .69906 .34107 .69509 .34009 .69388 Mtetra
.942 .687 .524 r
.34009 .69388 .34107 .69509 .35269 .5012 .3518 .49948 Mtetra
.898 .691 .614 r
.3518 .49948 .35269 .5012 .35465 .49217 .35372 .49121 Mtetra
.818 .753 .791 r
.35372 .49121 .35465 .49217 .35622 .49045 .35529 .48954 Mtetra
.662 .739 .907 r
.35529 .48954 .35622 .49045 .35774 .48996 .3568 .48905 Mtetra
.519 .693 .948 r
.3568 .48905 .35774 .48996 .35923 .4899 .3583 .489 Mtetra
.72 .756 .881 r
.3583 .489 .35923 .4899 .36076 .48912 .35982 .48824 Mtetra
.71 .757 .889 r
.35982 .48824 .36076 .48912 .36228 .48841 .36135 .48754 Mtetra
.529 .706 .952 r
.36135 .48754 .36228 .48841 .36378 .48832 .36285 .48745 Mtetra
.898 .479 .135 r
.36285 .48745 .36378 .48832 .36512 .4916 .36418 .49069 Mtetra
.945 .684 .511 r
.36418 .49069 .36512 .4916 .3573 .68658 .35632 .68548 Mtetra
.946 .597 .312 r
.35632 .68548 .3573 .68658 .3586 .6926 .35761 .69161 Mtetra
.038 .425 .867 r
.35761 .69161 .3586 .6926 .36016 .69332 .35917 .69238 Mtetra
.672 .748 .908 r
.35917 .69238 .36016 .69332 .36178 .69272 .36079 .69182 Mtetra
.753 .772 .868 r
.36079 .69182 .36178 .69272 .36342 .69168 .36243 .69081 Mtetra
.565 .733 .954 r
.36243 .69081 .36342 .69168 .36502 .69152 .36403 .6906 Mtetra
.539 .711 .951 r
.36403 .6906 .36502 .69152 .36661 .69149 .36563 .69048 Mtetra
.703 .744 .883 r
.36563 .69048 .36661 .69149 .36824 .69085 .36726 .68976 Mtetra
.881 .738 .7 r
.36726 .68976 .36824 .69085 .36999 .68738 .36902 .68613 Mtetra
.945 .688 .517 r
.36902 .68613 .36999 .68738 .37995 .49595 .37911 .49299 Mtetra
.881 .66 .599 r
.37911 .49299 .37995 .49595 .38199 .48369 .38107 .48266 Mtetra
.833 .746 .768 r
.38107 .48266 .38199 .48369 .38358 .48164 .38266 .48068 Mtetra
.668 .733 .899 r
.38266 .48068 .38358 .48164 .38511 .48111 .38419 .48017 Mtetra
.523 .687 .942 r
.38419 .48017 .38511 .48111 .38662 .48105 .3857 .48011 Mtetra
.633 .728 .916 r
.3857 .48011 .38662 .48105 .38815 .48056 .38723 .47974 Mtetra
.68 .767 .917 r
.38723 .47974 .38815 .48056 .38969 .47991 .38876 .47917 Mtetra
.646 .78 .945 r
.38876 .47917 .38969 .47991 .39122 .47958 .39029 .47873 Mtetra
.608 .739 .938 r
.39029 .47873 .39122 .47958 .3927 .48032 .39182 .47842 Mtetra
.555 .546 .799 r
.39182 .47842 .3927 .48032 .39412 .48279 .39333 .47844 Mtetra
.498 .392 .664 r
.39333 .47844 .39412 .48279 .39494 .50046 .39482 .47917 Mtetra
.464 .287 .555 r
.39482 .47917 .39494 .50046 .38958 .67876 .39615 .48392 Mtetra
0 0 .311 r
.39615 .48392 .38958 .67876 .39108 .68171 .39024 .67713 Mtetra
0 0 .51 r
.39024 .67713 .39108 .68171 .39264 .68298 .39169 .68143 Mtetra
.291 .461 .857 r
.39169 .68143 .39264 .68298 .39426 .68299 .39327 .68218 Mtetra
.675 .78 .929 r
.39327 .68218 .39426 .68299 .3959 .68228 .39491 .68159 Mtetra
.769 .821 .894 r
.39491 .68159 .3959 .68228 .39755 .68128 .39657 .68055 Mtetra
.741 .81 .907 r
.39657 .68055 .39755 .68128 .3992 .68043 .39822 .67966 Mtetra
.695 .794 .926 r
.39822 .67966 .3992 .68043 .40084 .67979 .39986 .67899 Mtetra
.691 .788 .924 r
.39986 .67899 .40084 .67979 .40248 .67918 .40151 .67833 Mtetra
.688 .777 .919 r
.40151 .67833 .40248 .67918 .40413 .67859 .40315 .6777 Mtetra
.683 .766 .914 r
.40315 .6777 .40413 .67859 .40577 .67801 .4048 .67708 Mtetra
.676 .755 .91 r
.4048 .67708 .40577 .67801 .40741 .67746 .40644 .67649 Mtetra
.666 .744 .908 r
.40644 .67649 .40741 .67746 .40905 .67695 .40808 .67594 Mtetra
.656 .735 .908 r
.40808 .67594 .40905 .67695 .41069 .67647 .40973 .67544 Mtetra
.644 .727 .909 r
.40973 .67544 .41069 .67647 .41234 .67603 .41137 .67499 Mtetra
.631 .721 .912 r
.41137 .67499 .41234 .67603 .41398 .67562 .41301 .67459 Mtetra
.617 .718 .918 r
.41301 .67459 .41398 .67562 .41562 .67525 .41465 .67425 Mtetra
.604 .719 .925 r
.41465 .67425 .41562 .67525 .41726 .67494 .41629 .67395 Mtetra
.589 .716 .931 r
.41629 .67395 .41726 .67494 .4189 .67471 .41793 .6737 Mtetra
.579 .707 .93 r
.41793 .6737 .4189 .67471 .42054 .67455 .41957 .67348 Mtetra
.579 .695 .921 r
.41957 .67348 .42054 .67455 .42218 .67441 .42121 .67328 Mtetra
.578 .682 .911 r
.42121 .67328 .42218 .67441 .42382 .67428 .42286 .67309 Mtetra
.583 .673 .901 r
.42286 .67309 .42382 .67428 .42546 .67413 .4245 .67289 Mtetra
.594 .669 .892 r
.4245 .67289 .42546 .67413 .4271 .67393 .42615 .67266 Mtetra
.613 .671 .881 r
.42615 .67266 .4271 .67393 .42875 .67363 .4278 .67234 Mtetra
.63 .675 .874 r
.4278 .67234 .42875 .67363 .4304 .67325 .42945 .67196 Mtetra
.637 .678 .872 r
.42945 .67196 .4304 .67325 .43206 .67282 .4311 .67154 Mtetra
.639 .679 .872 r
.4311 .67154 .43206 .67282 .43371 .67239 .43276 .67111 Mtetra
.641 .68 .871 r
.43276 .67111 .43371 .67239 .43537 .67197 .43442 .67067 Mtetra
.646 .68 .868 r
.43442 .67067 .43537 .67197 .43703 .6715 .43608 .6702 Mtetra
.646 .68 .867 r
.43608 .6702 .43703 .6715 .43869 .67109 .43774 .66973 Mtetra
.652 .673 .858 r
.43774 .66973 .43869 .67109 .44035 .67064 .4394 .66924 Mtetra
.673 .673 .842 r
.4394 .66924 .44035 .67064 .44202 .6699 .44106 .6686 Mtetra
.731 .708 .829 r
.44106 .6686 .44202 .6699 .44371 .66816 .44274 .66759 Mtetra
.831 .849 .86 r
.44274 .66759 .44371 .66816 .44544 .66452 .44443 .6661 Mtetra
0 0 0 r
.44443 .6661 .44544 .66452 .44728 .65608 .44612 .66441 Mtetra
.483 .233 .458 r
.44612 .66441 .44728 .65608 .45303 .46858 .4478 .66309 Mtetra
.554 .338 .541 r
.4478 .66309 .45303 .46858 .45462 .46716 .44947 .66254 Mtetra
.555 .339 .541 r
.44947 .66254 .45462 .46716 .45617 .46782 .45113 .66223 Mtetra
.45113 .66223 .45617 .46782 .45769 .47 .45279 .66221 Mtetra
.45279 .66221 .45769 .47 .4592 .47277 .45445 .66219 Mtetra
.554 .338 .541 r
.45445 .66219 .4592 .47277 .46081 .4707 .45613 .66147 Mtetra
.549 .334 .541 r
.45613 .66147 .46081 .4707 .46252 .46345 .45785 .65798 Mtetra
0 0 .331 r
.45785 .65798 .46252 .46345 .46418 .45852 .46319 .4625 Mtetra
.709 .712 .185 r
.46319 .4625 .46418 .45852 .46579 .45567 .46489 .45551 Mtetra
.926 .887 .775 r
.46489 .45551 .46579 .45567 .46739 .4541 .4665 .45311 Mtetra
.709 .744 .879 r
.4665 .45311 .46739 .4541 .46897 .45346 .46808 .45237 Mtetra
.618 .696 .9 r
.46808 .45237 .46897 .45346 .47054 .45307 .46965 .45205 Mtetra
.606 .706 .915 r
.46965 .45205 .47054 .45307 .47212 .4527 .47123 .45176 Mtetra
.662 .743 .91 r
.47123 .45176 .47212 .4527 .4737 .45219 .47281 .45126 Mtetra
.66 .744 .912 r
.47281 .45126 .4737 .45219 .47528 .45168 .47439 .45076 Mtetra
.66 .747 .914 r
.47439 .45076 .47528 .45168 .47686 .45117 .47597 .45026 Mtetra
.66 .749 .916 r
.47597 .45026 .47686 .45117 .47844 .45066 .47755 .44976 Mtetra
.659 .751 .917 r
.47755 .44976 .47844 .45066 .48002 .45015 .47913 .44926 Mtetra
.659 .752 .919 r
.47913 .44926 .48002 .45015 .48161 .44965 .48072 .44876 Mtetra
.658 .755 .921 r
.48072 .44876 .48161 .44965 .48319 .44913 .4823 .44827 Mtetra
.654 .757 .926 r
.4823 .44827 .48319 .44913 .48478 .44865 .48389 .44779 Mtetra
.641 .756 .932 r
.48389 .44779 .48478 .44865 .48636 .44822 .48547 .44736 Mtetra
.624 .748 .936 r
.48547 .44736 .48636 .44822 .48795 .44789 .48706 .44698 Mtetra
.628 .74 .928 r
.48706 .44698 .48795 .44789 .48953 .44755 .48865 .4466 Mtetra
.648 .738 .915 r
.48865 .4466 .48953 .44755 .49112 .44708 .49024 .44615 Mtetra
.677 .749 .905 r
.49024 .44615 .49112 .44708 .49272 .44643 .49183 .44557 Mtetra
.684 .768 .916 r
.49183 .44557 .49272 .44643 .49431 .44574 .49342 .44497 Mtetra
.677 .788 .933 r
.49342 .44497 .49431 .44574 .4959 .4451 .49502 .44439 Mtetra
.658 .799 .95 r
.49502 .44439 .4959 .4451 .49749 .44457 .49661 .44388 Mtetra
.652 .803 .956 r
.49661 .44388 .49749 .44457 .49909 .44406 .4982 .44338 Mtetra
.65 .805 .958 r
.4982 .44338 .49909 .44406 .50068 .44355 .4998 .44288 Mtetra
.652 .807 .958 r
.4998 .44288 .50068 .44355 .50228 .44304 .5014 .44238 Mtetra
.651 .809 .959 r
.5014 .44238 .50228 .44304 .50388 .44254 .50299 .44188 Mtetra
.65 .811 .96 r
.50299 .44188 .50388 .44254 .50547 .44203 .50459 .44137 Mtetra
.65 .812 .961 r
.50459 .44137 .50547 .44203 .50707 .44152 .50619 .44087 Mtetra
.65 .813 .962 r
.50619 .44087 .50707 .44152 .50867 .44102 .50779 .44037 Mtetra
.65 .814 .962 r
.50779 .44037 .50867 .44102 .51027 .44051 .50939 .43986 Mtetra
.651 .815 .962 r
.50939 .43986 .51027 .44051 .51187 .44 .511 .43935 Mtetra
.511 .43935 .51187 .44 .51348 .43949 .5126 .43884 Mtetra
.651 .816 .963 r
.5126 .43884 .51348 .43949 .51508 .43898 .5142 .43833 Mtetra
.5142 .43833 .51508 .43898 .51668 .43846 .51581 .43782 Mtetra
.651 .817 .963 r
.51581 .43782 .51668 .43846 .51829 .43795 .51741 .43731 Mtetra
.652 .817 .963 r
.51741 .43731 .51829 .43795 .5199 .43743 .51902 .43679 Mtetra
.652 .818 .963 r
.51902 .43679 .5199 .43743 .5215 .43692 .52063 .43628 Mtetra
.52063 .43628 .5215 .43692 .52311 .4364 .52224 .43576 Mtetra
.651 .818 .963 r
.52224 .43576 .52311 .4364 .52472 .43588 .52385 .43525 Mtetra
.651 .818 .964 r
.52385 .43525 .52472 .43588 .52633 .43537 .52546 .43473 Mtetra
.651 .819 .964 r
.52546 .43473 .52633 .43537 .52794 .43485 .52707 .43422 Mtetra
.65 .819 .964 r
.52707 .43422 .52794 .43485 .52955 .43434 .52868 .4337 Mtetra
.649 .819 .965 r
.52868 .4337 .52955 .43434 .53116 .43382 .5303 .43319 Mtetra
.648 .82 .966 r
.5303 .43319 .53116 .43382 .53278 .43331 .53191 .43268 Mtetra
.647 .821 .967 r
.53191 .43268 .53278 .43331 .53439 .43279 .53353 .43217 Mtetra
.646 .822 .968 r
.53353 .43217 .53439 .43279 .53601 .43228 .53514 .43167 Mtetra
.644 .823 .969 r
.53514 .43167 .53601 .43228 .53763 .43177 .53676 .43116 Mtetra
.641 .825 .971 r
.53676 .43116 .53763 .43177 .53924 .43127 .53838 .43067 Mtetra
.637 .827 .973 r
.53838 .43067 .53924 .43127 .54086 .43077 .54 .43018 Mtetra
.636 .829 .975 r
.54 .43018 .54086 .43077 .54248 .43027 .54162 .42969 Mtetra
.636 .832 .976 r
.54162 .42969 .54248 .43027 .5441 .42976 .54324 .4292 Mtetra
.637 .836 .977 r
.54324 .4292 .5441 .42976 .54572 .42925 .54486 .42869 Mtetra
.638 .839 .978 r
.54486 .42869 .54572 .42925 .54735 .42873 .54648 .42819 Mtetra
.638 .842 .978 r
.54648 .42819 .54735 .42873 .54897 .42821 .54811 .42768 Mtetra
.64 .845 .979 r
.54811 .42768 .54897 .42821 .55059 .42769 .54973 .42716 Mtetra
.641 .847 .979 r
.54973 .42716 .55059 .42769 .55222 .42716 .55136 .42663 Mtetra
.642 .848 .979 r
.55136 .42663 .55222 .42716 .55384 .42663 .55299 .4261 Mtetra
.643 .848 .979 r
.55299 .4261 .55384 .42663 .55547 .42611 .55462 .42557 Mtetra
.645 .848 .978 r
.55462 .42557 .55547 .42611 .5571 .42558 .55624 .42503 Mtetra
.648 .846 .976 r
.55624 .42503 .5571 .42558 .55873 .42505 .55787 .42449 Mtetra
.654 .845 .973 r
.55787 .42449 .55873 .42505 .56036 .42451 .5595 .42394 Mtetra
.654 .841 .972 r
.5595 .42394 .56036 .42451 .56199 .42398 .56114 .42338 Mtetra
.651 .834 .971 r
.56114 .42338 .56199 .42398 .56362 .42348 .56277 .42285 Mtetra
.633 .818 .971 r
.56277 .42285 .56362 .42348 .56526 .4231 .5644 .42237 Mtetra
.644 .796 .956 r
.5644 .42237 .56526 .4231 .56689 .42272 .56604 .42189 Mtetra
.66 .776 .935 r
.56604 .42189 .56689 .42272 .56853 .42227 .56767 .42137 Mtetra
.694 .768 .908 r
.56767 .42137 .56853 .42227 .57016 .42159 .56931 .4207 Mtetra
.701 .773 .908 r
.56931 .4207 .57016 .42159 .5718 .42086 .57094 .42001 Mtetra
.701 .78 .913 r
.57094 .42001 .5718 .42086 .57343 .42014 .57258 .41932 Mtetra
.686 .784 .925 r
.57258 .41932 .57343 .42014 .57507 .41953 .57422 .41869 Mtetra
.68 .778 .924 r
.57422 .41869 .57507 .41953 .57671 .41895 .57586 .41808 Mtetra
.676 .771 .922 r
.57586 .41808 .57671 .41895 .57835 .41839 .5775 .4175 Mtetra
.742 .782 .885 r
.5775 .4175 .57835 .41839 .57998 .41762 .57913 .41658 Mtetra
.683 .737 .891 r
.57913 .41658 .57998 .41762 .58163 .41702 .58077 .41596 Mtetra
.544 .678 .925 r
.58077 .41596 .58163 .41702 .58327 .41674 .58243 .41586 Mtetra
.763 .29 0 r
.58243 .41586 .58327 .41674 .58495 .41784 .58413 .41856 Mtetra
.965 .681 .447 r
.58413 .41856 .58495 .41784 .58665 .42014 .58934 .60767 Mtetra
.578 .357 .543 r
.58934 .60767 .58665 .42014 .58841 .42547 .59137 .62172 Mtetra
.556 .339 .541 r
.59137 .62172 .58841 .42547 .59007 .42517 .59314 .62199 Mtetra
.554 .338 .541 r
.59314 .62199 .59007 .42517 .5917 .42357 .59489 .62123 Mtetra
.59489 .62123 .5917 .42357 .59337 .42361 .59664 .62018 Mtetra
.557 .34 .542 r
.59664 .62018 .59337 .42361 .59919 .61606 .59842 .62087 Mtetra
.576 .28 .429 r
.59842 .62087 .59919 .61606 .60107 .62105 .6002 .62152 Mtetra
.437 0 0 r
.6002 .62152 .60107 .62105 .60289 .62309 .60199 .62188 Mtetra
.619 .695 .898 r
.60199 .62188 .60289 .62309 .60466 .62304 .60375 .62152 Mtetra
.66 .661 .84 r
.60375 .62152 .60466 .62304 .60642 .62246 .60551 .62092 Mtetra
.676 .667 .833 r
.60551 .62092 .60642 .62246 .60818 .62162 .60727 .62022 Mtetra
.657 .679 .859 r
.60727 .62022 .60818 .62162 .60994 .62104 .60904 .61966 Mtetra
.654 .68 .862 r
.60904 .61966 .60994 .62104 .61171 .62049 .61081 .61912 Mtetra
.654 .682 .864 r
.61081 .61912 .61171 .62049 .61348 .61993 .61257 .61858 Mtetra
.658 .686 .865 r
.61257 .61858 .61348 .61993 .61524 .61936 .61434 .61802 Mtetra
.657 .687 .867 r
.61434 .61802 .61524 .61936 .61701 .6188 .61611 .61746 Mtetra
.655 .687 .869 r
.61611 .61746 .61701 .6188 .61878 .61825 .61788 .61692 Mtetra
.647 .686 .872 r
.61788 .61692 .61878 .61825 .62056 .61774 .61966 .61642 Mtetra
.643 .687 .876 r
.61966 .61642 .62056 .61774 .62233 .61724 .62143 .61594 Mtetra
.641 .688 .879 r
.62143 .61594 .62233 .61724 .62411 .61676 .62321 .61547 Mtetra
.642 .691 .88 r
.62321 .61547 .62411 .61676 .62588 .61629 .62499 .615 Mtetra
.64 .689 .88 r
.62499 .615 .62588 .61629 .62766 .61584 .62676 .61453 Mtetra
.637 .687 .88 r
.62676 .61453 .62766 .61584 .62944 .61539 .62854 .61408 Mtetra
.604 .671 .888 r
.62854 .61408 .62944 .61539 .63123 .61524 .63033 .61379 Mtetra
.618 .655 .864 r
.63033 .61379 .63123 .61524 .63302 .61493 .63212 .61343 Mtetra
.654 .664 .848 r
.63212 .61343 .63302 .61493 .63479 .61419 .6339 .61287 Mtetra
.708 .713 .852 r
.6339 .61287 .63479 .61419 .63652 .61192 .63567 .61201 Mtetra
.763 .995 .867 r
.63567 .61201 .63652 .61192 .63817 .60749 .63743 .61061 Mtetra
.151 0 .222 r
.63743 .61061 .63817 .60749 .63348 .4141 .63915 .60818 Mtetra
.537 .325 .54 r
.63915 .60818 .63348 .4141 .63485 .40428 .64057 .59683 Mtetra
0 0 .404 r
.64057 .59683 .63485 .40428 .63643 .40102 .63568 .4023 Mtetra
.862 .882 .448 r
.63568 .4023 .63643 .40102 .63806 .39905 .63724 .39833 Mtetra
.813 .836 .868 r
.63724 .39833 .63806 .39905 .63972 .39809 .63889 .39699 Mtetra
.658 .721 .895 r
.63889 .39699 .63972 .39809 .6414 .39757 .64057 .39647 Mtetra
.575 .686 .917 r
.64057 .39647 .6414 .39757 .64309 .39727 .64226 .39628 Mtetra
.61 .726 .928 r
.64226 .39628 .64309 .39727 .64477 .39692 .64395 .39595 Mtetra
.626 .734 .925 r
.64395 .39595 .64477 .39692 .64646 .39656 .64564 .39555 Mtetra
.633 .731 .919 r
.64564 .39555 .64646 .39656 .64815 .39615 .64732 .39513 Mtetra
.686 .747 .898 r
.64732 .39513 .64815 .39615 .64982 .39532 .649 .39448 Mtetra
.695 .791 .925 r
.649 .39448 .64982 .39532 .65149 .3945 .65068 .3938 Mtetra
.656 .816 .96 r
.65068 .3938 .65149 .3945 .65318 .39401 .65237 .39325 Mtetra
.447 .711 .979 r
.65237 .39325 .65318 .39401 .65493 .395 .65408 .39327 Mtetra
.462 .523 .834 r
.65408 .39327 .65493 .395 .65676 .398 .6558 .39367 Mtetra
.518 .412 .673 r
.6558 .39367 .65676 .398 .66615 .58305 .65754 .39425 Mtetra
.557 .345 .548 r
.65754 .39425 .66615 .58305 .66839 .59323 .65923 .39369 Mtetra
.558 .345 .547 r
.65923 .39369 .66839 .59323 .67016 .59191 .66091 .39284 Mtetra
.557 .344 .547 r
.66091 .39284 .67016 .59191 .67193 .59083 .66262 .39262 Mtetra
.548 .338 .547 r
.66262 .39262 .67193 .59083 .674 .59645 .66453 .39715 Mtetra
.025 0 .427 r
.66453 .39715 .674 .59645 .67598 .59984 .67497 .59555 Mtetra
0 .06 .576 r
.67497 .59555 .67598 .59984 .67788 .60156 .677 .60006 Mtetra
.326 .494 .872 r
.677 .60006 .67788 .60156 .67973 .60179 .67886 .60079 Mtetra
.632 .749 .932 r
.67886 .60079 .67973 .60179 .68154 .60132 .68068 .60033 Mtetra
.717 .778 .9 r
.68068 .60033 .68154 .60132 .68335 .60062 .68248 .59948 Mtetra
.662 .729 .899 r
.68248 .59948 .68335 .60062 .68517 .60023 .68429 .5989 Mtetra
.638 .686 .878 r
.68429 .5989 .68517 .60023 .68699 .59986 .68611 .59843 Mtetra
.665 .682 .857 r
.68611 .59843 .68699 .59986 .68879 .59912 .68792 .59781 Mtetra
.747 .73 .836 r
.68792 .59781 .68879 .59912 .69053 .59696 .68971 .59665 Mtetra
.85 .945 .881 r
.68971 .59665 .69053 .59696 .69217 .59269 .69147 .59506 Mtetra
.175 0 .17 r
.69147 .59506 .69217 .59269 .69327 .57766 .69323 .59327 Mtetra
.536 .299 .503 r
.69323 .59327 .69327 .57766 .6859 .39391 .69504 .5926 Mtetra
.555 .339 .541 r
.69504 .5926 .6859 .39391 .68764 .39396 .69688 .59244 Mtetra
.554 .338 .541 r
.69688 .59244 .68764 .39396 .68939 .39413 .69869 .59163 Mtetra
.547 .333 .541 r
.69869 .59163 .68939 .39413 .69084 .38831 .70027 .58633 Mtetra
.029 0 .424 r
.70027 .58633 .69084 .38831 .69235 .38405 .69172 .38639 Mtetra
.69 .711 .188 r
.69172 .38639 .69235 .38405 .69396 .38142 .69318 .38093 Mtetra
.886 .892 .829 r
.69318 .38093 .69396 .38142 .69563 .38011 .69482 .37906 Mtetra
.683 .743 .896 r
.69482 .37906 .69563 .38011 .69733 .3795 .69653 .37841 Mtetra
.592 .699 .917 r
.69653 .37841 .69733 .3795 .69906 .37913 .69826 .37815 Mtetra
.597 .723 .932 r
.69826 .37815 .69906 .37913 .70078 .3788 .69998 .37785 Mtetra
.626 .743 .931 r
.69998 .37785 .70078 .3788 .70251 .37843 .70171 .37744 Mtetra
.631 .735 .923 r
.70171 .37744 .70251 .37843 .70423 .37804 .70343 .37701 Mtetra
.66 .74 .909 r
.70343 .37701 .70423 .37804 .70595 .37747 .70515 .37647 Mtetra
.681 .756 .907 r
.70515 .37647 .70595 .37747 .70766 .37675 .70686 .37584 Mtetra
.686 .776 .919 r
.70686 .37584 .70766 .37675 .70937 .376 .70858 .37518 Mtetra
.675 .792 .937 r
.70858 .37518 .70937 .376 .71108 .37534 .7103 .37456 Mtetra
.661 .8 .949 r
.7103 .37456 .71108 .37534 .7128 .37476 .71202 .37399 Mtetra
.657 .802 .952 r
.71202 .37399 .7128 .37476 .71452 .3742 .71374 .37344 Mtetra
.657 .803 .953 r
.71374 .37344 .71452 .3742 .71624 .37364 .71546 .37288 Mtetra
.658 .803 .952 r
.71546 .37288 .71624 .37364 .71797 .37308 .71719 .37232 Mtetra
.658 .804 .953 r
.71719 .37232 .71797 .37308 .71969 .37252 .71891 .37176 Mtetra
.657 .804 .953 r
.71891 .37176 .71969 .37252 .72142 .37196 .72064 .3712 Mtetra
.657 .803 .953 r
.72064 .3712 .72142 .37196 .72314 .3714 .72237 .37064 Mtetra
.656 .803 .954 r
.72237 .37064 .72314 .3714 .72487 .37085 .7241 .37008 Mtetra
.655 .803 .954 r
.7241 .37008 .72487 .37085 .7266 .3703 .72583 .36953 Mtetra
.72583 .36953 .7266 .3703 .72833 .36974 .72756 .36898 Mtetra
.654 .803 .955 r
.72756 .36898 .72833 .36974 .73007 .36919 .72929 .36843 Mtetra
.652 .803 .955 r
.72929 .36843 .73007 .36919 .7318 .36864 .73103 .36788 Mtetra
.651 .804 .956 r
.73103 .36788 .7318 .36864 .73353 .3681 .73276 .36734 Mtetra
.65 .805 .957 r
.73276 .36734 .73353 .3681 .73527 .36755 .7345 .3668 Mtetra
.648 .806 .959 r
.7345 .3668 .73527 .36755 .73701 .36701 .73624 .36627 Mtetra
.646 .807 .961 r
.73624 .36627 .73701 .36701 .73874 .36647 .73798 .36574 Mtetra
.645 .809 .962 r
.73798 .36574 .73874 .36647 .74048 .36593 .73972 .36521 Mtetra
.645 .812 .963 r
.73972 .36521 .74048 .36593 .74222 .36539 .74146 .36468 Mtetra
.647 .816 .964 r
.74146 .36468 .74222 .36539 .74396 .36484 .7432 .36414 Mtetra
.648 .819 .965 r
.7432 .36414 .74396 .36484 .7457 .36428 .74495 .36358 Mtetra
.651 .823 .966 r
.74495 .36358 .7457 .36428 .74745 .36371 .74669 .36302 Mtetra
.654 .826 .966 r
.74669 .36302 .74745 .36371 .74919 .36313 .74843 .36245 Mtetra
.658 .829 .965 r
.74843 .36245 .74919 .36313 .75093 .36254 .75018 .36186 Mtetra
.665 .832 .964 r
.75018 .36186 .75093 .36254 .75267 .36193 .75192 .36124 Mtetra
.672 .834 .961 r
.75192 .36124 .75267 .36193 .75441 .36129 .75366 .3606 Mtetra
.674 .833 .96 r
.75366 .3606 .75441 .36129 .75616 .36066 .7554 .35996 Mtetra
.729 .846 .936 r
.7554 .35996 .75616 .36066 .75788 .35982 .75713 .3591 Mtetra
.752 .846 .921 r
.75713 .3591 .75788 .35982 .75961 .35887 .75885 .35813 Mtetra
.634 .804 .964 r
.75885 .35813 .75961 .35887 .76136 .35839 .76061 .35763 Mtetra
0 .307 .772 r
.76061 .35763 .76136 .35839 .76324 .35946 .76249 .35877 Mtetra
.929 .549 .171 r
.76249 .35877 .76324 .35946 .76558 .36669 .7649 .36703 Mtetra
.975 .672 .368 r
.7649 .36703 .76558 .36669 .7827 .56814 .7819 .56744 Mtetra
.71 .217 0 r
.7819 .56744 .7827 .56814 .78485 .57125 .78404 .57036 Mtetra
.405 .673 .969 r
.78404 .57036 .78485 .57125 .78679 .57144 .78598 .57052 Mtetra
.732 .807 .911 r
.78598 .57052 .78679 .57144 .78864 .57049 .78783 .56957 Mtetra
.914 .822 .741 r
.78783 .56957 .78864 .57049 .79032 .56746 .78952 .56664 Mtetra
.983 .733 .474 r
.78952 .56664 .79032 .56746 .79056 .54602 .7903 .55197 Mtetra
.98 .686 .354 r
.7903 .55197 .79056 .54602 .77737 .35598 .77663 .35529 Mtetra
.944 .84 .711 r
.77663 .35529 .77737 .35598 .77894 .35293 .77819 .35211 Mtetra
.701 .81 .933 r
.77819 .35211 .77894 .35293 .78069 .35226 .77994 .35137 Mtetra
.545 .73 .961 r
.77994 .35137 .78069 .35226 .78249 .35215 .78173 .35119 Mtetra
.576 .728 .946 r
.78173 .35119 .78249 .35215 .78429 .35201 .78352 .35094 Mtetra
.712 .757 .888 r
.78352 .35094 .78429 .35201 .78605 .35133 .78527 .35012 Mtetra
.641 .702 .891 r
.78527 .35012 .78605 .35133 .78782 .35083 .78705 .34965 Mtetra
.298 .526 .905 r
.78705 .34965 .78782 .35083 .78964 .35085 .78892 .3503 Mtetra
.843 .395 0 r
.78892 .3503 .78964 .35085 .79155 .35193 .79109 .35453 Mtetra
.973 .667 .362 r
.79109 .35453 .79155 .35193 .7936 .35473 .8098 .55473 Mtetra
.563 .344 .542 r
.8098 .55473 .7936 .35473 .81191 .54829 .81217 .55976 Mtetra
.573 .318 .492 r
.81217 .55976 .81191 .54829 .81471 .55837 .8142 .56075 Mtetra
.525 .161 .292 r
.8142 .56075 .81471 .55837 .81689 .56109 .81616 .56095 Mtetra
.171 .701 .851 r
.81616 .56095 .81689 .56109 .81892 .56209 .8181 .56085 Mtetra
.558 .673 .915 r
.8181 .56085 .81892 .56209 .82086 .56194 .82004 .5607 Mtetra
.675 .726 .889 r
.82004 .5607 .82086 .56194 .82274 .56121 .82193 .56003 Mtetra
.827 .784 .811 r
.82193 .56003 .82274 .56121 .82457 .5598 .82372 .5582 Mtetra
.928 .742 .631 r
.82372 .5582 .82457 .5598 .82631 .55735 .82521 .55293 Mtetra
.976 .675 .369 r
.82521 .55293 .82631 .55735 .82787 .553 .80908 .35105 Mtetra
.567 .352 .548 r
.80908 .35105 .82787 .553 .81208 .35652 .81031 .34424 Mtetra
.613 .415 .59 r
.81031 .34424 .81208 .35652 .81293 .34568 .81195 .34208 Mtetra
.665 .526 .685 r
.81195 .34208 .81293 .34568 .81447 .34243 .81367 .34081 Mtetra
.66 .648 .827 r
.81367 .34081 .81447 .34243 .8162 .34121 .81545 .34019 Mtetra
.47 .661 .945 r
.81545 .34019 .8162 .34121 .81816 .34251 .8173 .34029 Mtetra
.488 .491 .787 r
.8173 .34029 .81816 .34251 .82035 .3463 .81918 .34074 Mtetra
.547 .412 .648 r
.81918 .34074 .82035 .3463 .84021 .53825 .82105 .34105 Mtetra
.558 .345 .548 r
.82105 .34105 .84021 .53825 .84221 .53875 .82281 .3401 Mtetra
.557 .345 .547 r
.82281 .3401 .84221 .53875 .84389 .53572 .8246 .33947 Mtetra
.555 .343 .547 r
.8246 .33947 .84389 .53572 .84632 .54066 .82652 .34023 Mtetra
.144 .052 .483 r
.82652 .34023 .84632 .54066 .84897 .54775 .84619 .52592 Mtetra
.104 .047 .501 r
.84619 .52592 .84897 .54775 .85121 .55049 .85026 .5478 Mtetra
.109 .226 .705 r
.85026 .5478 .85121 .55049 .85329 .55164 .85249 .55047 Mtetra
.543 .681 .929 r
.85249 .55047 .85329 .55164 .85525 .55144 .85446 .55036 Mtetra
.698 .768 .905 r
.85446 .55036 .85525 .55144 .85715 .55064 .85636 .54956 Mtetra
.762 .79 .876 r
.85636 .54956 .85715 .55064 .85898 .54909 .85823 .54838 Mtetra
.744 .869 .938 r
.85823 .54838 .85898 .54909 .86066 .54602 .86011 .54736 Mtetra
0 0 0 r
.86011 .54736 .86066 .54602 .86198 .53946 .86193 .54573 Mtetra
.34 .111 .413 r
.86193 .54573 .86198 .53946 .84389 .34041 .86358 .54238 Mtetra
.115 .028 .47 r
.86358 .54238 .84389 .34041 .8452 .33498 .84525 .34164 Mtetra
0 0 .309 r
.84525 .34164 .8452 .33498 .84679 .33224 .8462 .33265 Mtetra
.894 .941 .576 r
.8462 .33265 .84679 .33224 .84848 .33058 .84775 .3296 Mtetra
.714 .783 .906 r
.84775 .3296 .84848 .33058 .85028 .32994 .84953 .32877 Mtetra
.607 .697 .907 r
.84953 .32877 .85028 .32994 .85211 .32961 .85137 .32844 Mtetra
.568 .678 .914 r
.85137 .32844 .85211 .32961 .85395 .32931 .85322 .32826 Mtetra
.694 .762 .904 r
.85322 .32826 .85395 .32931 .85572 .32836 .85501 .32753 Mtetra
.678 .807 .944 r
.85501 .32753 .85572 .32836 .85751 .32761 .85681 .32687 Mtetra
.612 .804 .973 r
.85681 .32687 .85751 .32761 .85936 .32738 .85864 .32642 Mtetra
.417 .645 .952 r
.85864 .32642 .85936 .32738 .86141 .32905 .86054 .32663 Mtetra
.495 .481 .771 r
.86054 .32663 .86141 .32905 .86374 .33327 .86247 .3271 Mtetra
.541 .4 .639 r
.86247 .3271 .86374 .33327 .88679 .52924 .8644 .32756 Mtetra
.558 .345 .547 r
.8644 .32756 .88679 .52924 .88883 .52965 .86617 .32657 Mtetra
.557 .345 .547 r
.86617 .32657 .88883 .52965 .89067 .52813 .86797 .32585 Mtetra
.556 .343 .547 r
.86797 .32585 .89067 .52813 .89274 .52879 .8699 .3262 Mtetra
.203 .096 .502 r
.8699 .3262 .89274 .52879 .89541 .53478 .89057 .49669 Mtetra
.128 .056 .499 r
.89057 .49669 .89541 .53478 .89772 .53745 .89675 .53453 Mtetra
.11 .212 .691 r
.89675 .53453 .89772 .53745 .89988 .53874 .8991 .53752 Mtetra
.5 .65 .925 r
.8991 .53752 .89988 .53874 .9019 .53877 .90112 .53758 Mtetra
.662 .736 .905 r
.90112 .53758 .9019 .53877 .90386 .53822 .90307 .53695 Mtetra
.74 .753 .863 r
.90307 .53695 .90386 .53822 .90575 .53704 .90497 .53586 Mtetra
.729 .765 .882 r
.90497 .53586 .90575 .53704 .90747 .53442 .90688 .53486 Mtetra
.49 .843 .581 r
.90688 .53486 .90747 .53442 .90895 .52964 .90873 .53332 Mtetra
.255 0 .32 r
.90873 .53332 .90895 .52964 .88811 .33111 .91045 .53067 Mtetra
.534 .324 .541 r
.91045 .53067 .88811 .33111 .88896 .322 .91079 .51605 Mtetra
.124 .038 .478 r
.91079 .51605 .88896 .322 .89048 .31873 .89 .3197 Mtetra
.758 .812 .336 r
.89 .3197 .89048 .31873 .89215 .31678 .89145 .31586 Mtetra
.693 .952 .684 r
.29882 .50844 .29989 .50764 .30139 .5068 .30037 .50687 Mtetra
.667 .962 .935 r
.30037 .50687 .30139 .5068 .30286 .5065 .30188 .50605 Mtetra
.623 .846 .985 r
.30188 .50605 .30286 .5065 .30432 .50646 .30336 .50561 Mtetra
.686 .755 .904 r
.30336 .50561 .30432 .50646 .30581 .50579 .30485 .50504 Mtetra
.668 .776 .93 r
.30485 .50504 .30581 .50579 .30731 .50515 .30634 .50453 Mtetra
.652 .807 .957 r
.30634 .50453 .30731 .50515 .3088 .50467 .30783 .50406 Mtetra
.775 .819 .887 r
.30783 .50406 .3088 .50467 .31026 .5045 .30935 .50306 Mtetra
.685 .655 .815 r
.30935 .50306 .31026 .5045 .3117 .50477 .31085 .50239 Mtetra
.569 .511 .751 r
.31085 .50239 .3117 .50477 .31309 .50593 .31231 .50236 Mtetra
0 0 .426 r
.31231 .50236 .31309 .50593 .314 .51467 .31353 .50616 Mtetra
.95 .694 .515 r
.31353 .50616 .314 .51467 .30361 .70353 .30275 .70026 Mtetra
.826 .528 0 r
.30275 .70026 .30361 .70353 .30495 .70684 .30394 .70592 Mtetra
0 .341 .802 r
.30394 .70592 .30495 .70684 .30646 .70761 .30544 .70678 Mtetra
.611 .755 .947 r
.30544 .70678 .30646 .70761 .30803 .70737 .30702 .70644 Mtetra
.793 .763 .826 r
.30702 .70644 .30803 .70737 .30965 .70619 .30866 .70506 Mtetra
.892 .724 .666 r
.30866 .70506 .30965 .70619 .31149 .7015 .31052 .70013 Mtetra
.938 .686 .53 r
.31052 .70013 .31149 .7015 .32476 .50664 .32385 .50521 Mtetra
.893 .7 .634 r
.32385 .50521 .32476 .50664 .32665 .49966 .32571 .49874 Mtetra
.793 .755 .818 r
.32571 .49874 .32665 .49966 .3282 .49829 .32725 .4974 Mtetra
.647 .739 .916 r
.32725 .4974 .3282 .49829 .32969 .49785 .32875 .49697 Mtetra
.507 .694 .953 r
.32875 .49697 .32969 .49785 .33117 .49782 .33022 .49694 Mtetra
.728 .76 .878 r
.33022 .49694 .33117 .49782 .33269 .49695 .33174 .49615 Mtetra
.699 .77 .906 r
.33174 .49615 .33269 .49695 .3342 .49629 .33325 .49551 Mtetra
.508 .719 .967 r
.33325 .49551 .3342 .49629 .33567 .49629 .33473 .49544 Mtetra
.882 .448 .095 r
.33473 .49544 .33567 .49629 .33693 .50014 .33604 .49828 Mtetra
.943 .685 .517 r
.33604 .49828 .33693 .50014 .32748 .69481 .32674 .68928 Mtetra
0 0 .099 r
.32674 .68928 .32748 .69481 .32875 .70016 .32785 .69748 Mtetra
.352 .37 .74 r
.32785 .69748 .32875 .70016 .33029 .70063 .32936 .69858 Mtetra
.568 .549 .793 r
.32936 .69858 .33029 .70063 .3319 .70002 .33093 .69854 Mtetra
.649 .648 .835 r
.33093 .69854 .3319 .70002 .33352 .699 .33253 .69805 Mtetra
.489 .684 .953 r
.33253 .69805 .33352 .699 .3351 .69893 .3341 .69807 Mtetra
.584 .739 .95 r
.3341 .69807 .3351 .69893 .33668 .69878 .33569 .69781 Mtetra
.742 .756 .864 r
.33569 .69781 .33668 .69878 .3383 .69799 .33732 .69686 Mtetra
.888 .729 .679 r
.33732 .69686 .3383 .69799 .34009 .69388 .33912 .69254 Mtetra
.941 .687 .524 r
.33912 .69254 .34009 .69388 .3518 .49948 .3509 .49777 Mtetra
.894 .691 .621 r
.3509 .49777 .3518 .49948 .35372 .49121 .35278 .49026 Mtetra
.815 .753 .795 r
.35278 .49026 .35372 .49121 .35529 .48954 .35436 .48863 Mtetra
.659 .74 .91 r
.35436 .48863 .35529 .48954 .3568 .48905 .35587 .48816 Mtetra
.517 .695 .95 r
.35587 .48816 .3568 .48905 .3583 .489 .35736 .48811 Mtetra
.71 .755 .888 r
.35736 .48811 .3583 .489 .35982 .48824 .35889 .48741 Mtetra
.706 .767 .9 r
.35889 .48741 .35982 .48824 .36135 .48754 .36041 .48673 Mtetra
.544 .728 .96 r
.36041 .48673 .36135 .48754 .36285 .48745 .36191 .48659 Mtetra
.83 .365 0 r
.36191 .48659 .36285 .48745 .36418 .49069 .36329 .489 Mtetra
.946 .685 .51 r
.36329 .489 .36418 .49069 .35632 .68548 .35563 .67838 Mtetra
0 0 .106 r
.35563 .67838 .35632 .68548 .35761 .69161 .35671 .68884 Mtetra
.284 .321 .724 r
.35671 .68884 .35761 .69161 .35917 .69238 .35824 .69025 Mtetra
.561 .539 .788 r
.35824 .69025 .35917 .69238 .36079 .69182 .35983 .69025 Mtetra
.644 .637 .829 r
.35983 .69025 .36079 .69182 .36243 .69081 .36144 .68978 Mtetra
.529 .684 .937 r
.36144 .68978 .36243 .69081 .36403 .6906 .36304 .68972 Mtetra
.571 .733 .951 r
.36304 .68972 .36403 .6906 .36563 .69048 .36464 .6895 Mtetra
.732 .755 .87 r
.36464 .6895 .36563 .69048 .36726 .68976 .36628 .68861 Mtetra
.883 .732 .689 r
.36628 .68861 .36726 .68976 .36902 .68613 .36806 .68467 Mtetra
.944 .688 .518 r
.36806 .68467 .36902 .68613 .37911 .49299 .37828 .48983 Mtetra
.861 .647 .611 r
.37828 .48983 .37911 .49299 .38107 .48266 .38015 .48145 Mtetra
.812 .722 .765 r
.38015 .48145 .38107 .48266 .38266 .48068 .38174 .4796 Mtetra
.653 .705 .886 r
.38174 .4796 .38266 .48068 .38419 .48017 .38327 .47915 Mtetra
.512 .665 .931 r
.38327 .47915 .38419 .48017 .3857 .48011 .38478 .47915 Mtetra
.601 .712 .922 r
.38478 .47915 .3857 .48011 .38723 .47974 .3863 .47889 Mtetra
.662 .756 .92 r
.3863 .47889 .38723 .47974 .38876 .47917 .38783 .47839 Mtetra
.67 .775 .929 r
.38783 .47839 .38876 .47917 .39029 .47873 .38937 .47787 Mtetra
.74 .77 .877 r
.38937 .47787 .39029 .47873 .39182 .47842 .39092 .477 Mtetra
.704 .668 .812 r
.39092 .477 .39182 .47842 .39333 .47844 .39246 .47617 Mtetra
.613 .547 .756 r
.39246 .47617 .39333 .47844 .39482 .47917 .39399 .47584 Mtetra
.288 .283 .679 r
.39399 .47584 .39482 .47917 .39615 .48392 .39544 .47756 Mtetra
.739 .536 0 r
.39544 .47756 .39615 .48392 .39024 .67713 .39655 .48809 Mtetra
0 0 .305 r
.39655 .48809 .39024 .67713 .39169 .68143 .3908 .678 Mtetra
.218 .24 .67 r
.3908 .678 .39169 .68143 .39327 .68218 .39234 .68008 Mtetra
.538 .53 .794 r
.39234 .68008 .39327 .68218 .39491 .68159 .39395 .6802 Mtetra
.644 .661 .852 r
.39395 .6802 .39491 .68159 .39657 .68055 .39559 .67974 Mtetra
.683 .784 .927 r
.39559 .67974 .39657 .68055 .39822 .67966 .39723 .67912 Mtetra
.695 .853 .958 r
.39723 .67912 .39822 .67966 .39986 .67899 .39887 .67842 Mtetra
.722 .85 .942 r
.39887 .67842 .39986 .67899 .40151 .67833 .40052 .67763 Mtetra
.71 .813 .93 r
.40052 .67763 .40151 .67833 .40315 .6777 .40217 .67689 Mtetra
.691 .788 .925 r
.40217 .67689 .40315 .6777 .4048 .67708 .40382 .67624 Mtetra
.682 .779 .924 r
.40382 .67624 .4048 .67708 .40644 .67649 .40546 .67563 Mtetra
.671 .771 .925 r
.40546 .67563 .40644 .67649 .40808 .67594 .40711 .67506 Mtetra
.66 .763 .926 r
.40711 .67506 .40808 .67594 .40973 .67544 .40875 .67454 Mtetra
.647 .755 .928 r
.40875 .67454 .40973 .67544 .41137 .67499 .4104 .67407 Mtetra
.616 .74 .935 r
.4104 .67407 .41137 .67499 .41301 .67459 .41204 .67371 Mtetra
.597 .744 .947 r
.41204 .67371 .41301 .67459 .41465 .67425 .41368 .67341 Mtetra
.619 .762 .947 r
.41368 .67341 .41465 .67425 .41629 .67395 .41532 .67303 Mtetra
.702 .765 .901 r
.41532 .67303 .41629 .67395 .41793 .6737 .41698 .67231 Mtetra
.727 .694 .819 r
.41698 .67231 .41793 .6737 .41957 .67348 .41864 .6713 Mtetra
.693 .605 .753 r
.41864 .6713 .41957 .67348 .42121 .67328 .42031 .67027 Mtetra
.632 .527 .717 r
.42031 .67027 .42121 .67328 .42286 .67309 .42196 .66965 Mtetra
.585 .482 .704 r
.42196 .66965 .42286 .67309 .4245 .67289 .42361 .66946 Mtetra
.576 .477 .705 r
.42361 .66946 .4245 .67289 .42615 .67266 .42525 .66937 Mtetra
.589 .49 .71 r
.42525 .66937 .42615 .67266 .4278 .67234 .42689 .66916 Mtetra
.604 .503 .713 r
.42689 .66916 .4278 .67234 .42945 .67196 .42854 .66881 Mtetra
.608 .507 .714 r
.42854 .66881 .42945 .67196 .4311 .67154 .4302 .66842 Mtetra
.616 .513 .715 r
.4302 .66842 .4311 .67154 .43276 .67111 .43185 .66795 Mtetra
.618 .513 .712 r
.43185 .66795 .43276 .67111 .43442 .67067 .43351 .66744 Mtetra
.609 .505 .711 r
.43351 .66744 .43442 .67067 .43608 .6702 .43517 .66703 Mtetra
.578 .489 .717 r
.43517 .66703 .43608 .6702 .43774 .66973 .43682 .66692 Mtetra
.548 .487 .739 r
.43682 .66692 .43774 .66973 .4394 .66924 .43847 .66705 Mtetra
.547 .529 .787 r
.43847 .66705 .4394 .66924 .44106 .6686 .44012 .66713 Mtetra
.578 .626 .863 r
.44012 .66713 .44106 .6686 .44274 .66759 .44177 .66699 Mtetra
.592 .815 .985 r
.44177 .66699 .44274 .66759 .44443 .6661 .44343 .6666 Mtetra
0 0 0 r
.44343 .6666 .44443 .6661 .44612 .66441 .4451 .66614 Mtetra
.371 0 .155 r
.4451 .66614 .44612 .66441 .4478 .66309 .44677 .66567 Mtetra
.443 .1 .288 r
.44677 .66567 .4478 .66309 .44947 .66254 .44843 .66523 Mtetra
.444 .106 .297 r
.44843 .66523 .44947 .66254 .45113 .66223 .4501 .66476 Mtetra
.462 .116 .293 r
.4501 .66476 .45113 .66223 .45279 .66221 .45177 .66444 Mtetra
.461 .101 .266 r
.45177 .66444 .45279 .66221 .45445 .66219 .45343 .6642 Mtetra
.345 0 .183 r
.45343 .6642 .45445 .66219 .45613 .66147 .45511 .6635 Mtetra
0 0 0 r
.45511 .6635 .45613 .66147 .45785 .65798 .45682 .66117 Mtetra
.942 .839 .399 r
.45682 .66117 .45785 .65798 .46319 .4625 .45864 .65276 Mtetra
0 0 .32 r
.45864 .65276 .46319 .4625 .46489 .45551 .46394 .45707 Mtetra
.831 .894 .472 r
.46394 .45707 .46489 .45551 .4665 .45311 .46558 .45354 Mtetra
.374 .816 .673 r
.46558 .45354 .4665 .45311 .46808 .45237 .46716 .4527 Mtetra
.039 0 0 r
.46716 .4527 .46808 .45237 .46965 .45205 .46873 .45246 Mtetra
.137 0 0 r
.46873 .45246 .46965 .45205 .47123 .45176 .47031 .45227 Mtetra
0 0 0 r
.47031 .45227 .47123 .45176 .47281 .45126 .47189 .45177 Mtetra
.47189 .45177 .47281 .45126 .47439 .45076 .47347 .45129 Mtetra
.47347 .45129 .47439 .45076 .47597 .45026 .47505 .45081 Mtetra
.002 0 0 r
.47505 .45081 .47597 .45026 .47755 .44976 .47664 .45032 Mtetra
.014 0 0 r
.47664 .45032 .47755 .44976 .47913 .44926 .47822 .44984 Mtetra
.05 0 0 r
.47822 .44984 .47913 .44926 .48072 .44876 .47981 .44939 Mtetra
.11 0 0 r
.47981 .44939 .48072 .44876 .4823 .44827 .48139 .44899 Mtetra
.107 0 0 r
.48139 .44899 .4823 .44827 .48389 .44779 .48298 .4485 Mtetra
0 0 0 r
.48298 .4485 .48389 .44779 .48547 .44736 .48457 .44779 Mtetra
.485 .88 .712 r
.48457 .44779 .48547 .44736 .48706 .44698 .48616 .44679 Mtetra
.755 .945 .943 r
.48616 .44679 .48706 .44698 .48865 .4466 .48776 .44581 Mtetra
.728 .792 .903 r
.48776 .44581 .48865 .4466 .49024 .44615 .48935 .445 Mtetra
.666 .703 .875 r
.48935 .445 .49024 .44615 .49183 .44557 .49095 .44447 Mtetra
.649 .705 .888 r
.49095 .44447 .49183 .44557 .49342 .44497 .49254 .44401 Mtetra
.646 .734 .913 r
.49254 .44401 .49342 .44497 .49502 .44439 .49413 .44356 Mtetra
.655 .768 .932 r
.49413 .44356 .49502 .44439 .49661 .44388 .49572 .44307 Mtetra
.655 .774 .937 r
.49572 .44307 .49661 .44388 .4982 .44338 .49732 .44258 Mtetra
.654 .776 .938 r
.49732 .44258 .4982 .44338 .4998 .44288 .49892 .44209 Mtetra
.654 .777 .939 r
.49892 .44209 .4998 .44288 .5014 .44238 .50051 .4416 Mtetra
.654 .78 .941 r
.50051 .4416 .5014 .44238 .50299 .44188 .50211 .44111 Mtetra
.654 .783 .943 r
.50211 .44111 .50299 .44188 .50459 .44137 .50371 .44061 Mtetra
.654 .785 .944 r
.50371 .44061 .50459 .44137 .50619 .44087 .50531 .44012 Mtetra
.654 .787 .945 r
.50531 .44012 .50619 .44087 .50779 .44037 .50691 .43962 Mtetra
.655 .789 .946 r
.50691 .43962 .50779 .44037 .50939 .43986 .50851 .43912 Mtetra
.655 .79 .946 r
.50851 .43912 .50939 .43986 .511 .43935 .51012 .43861 Mtetra
.656 .791 .947 r
.51012 .43861 .511 .43935 .5126 .43884 .51172 .4381 Mtetra
.656 .792 .947 r
.51172 .4381 .5126 .43884 .5142 .43833 .51332 .4376 Mtetra
.656 .793 .947 r
.51332 .4376 .5142 .43833 .51581 .43782 .51493 .43708 Mtetra
.657 .793 .948 r
.51493 .43708 .51581 .43782 .51741 .43731 .51654 .43657 Mtetra
.657 .794 .948 r
.51654 .43657 .51741 .43731 .51902 .43679 .51814 .43606 Mtetra
.51814 .43606 .51902 .43679 .52063 .43628 .51975 .43554 Mtetra
.657 .795 .948 r
.51975 .43554 .52063 .43628 .52224 .43576 .52136 .43503 Mtetra
.657 .795 .949 r
.52136 .43503 .52224 .43576 .52385 .43525 .52297 .43452 Mtetra
.656 .795 .949 r
.52297 .43452 .52385 .43525 .52546 .43473 .52458 .434 Mtetra
.656 .796 .95 r
.52458 .434 .52546 .43473 .52707 .43422 .5262 .43349 Mtetra
.655 .796 .95 r
.5262 .43349 .52707 .43422 .52868 .4337 .52781 .43298 Mtetra
.654 .797 .951 r
.52781 .43298 .52868 .4337 .5303 .43319 .52942 .43247 Mtetra
.652 .798 .952 r
.52942 .43247 .5303 .43319 .53191 .43268 .53104 .43197 Mtetra
.65 .799 .954 r
.53104 .43197 .53191 .43268 .53353 .43217 .53266 .43147 Mtetra
.649 .801 .956 r
.53266 .43147 .53353 .43217 .53514 .43167 .53427 .43097 Mtetra
.645 .802 .959 r
.53427 .43097 .53514 .43167 .53676 .43116 .53589 .43048 Mtetra
.638 .805 .963 r
.53589 .43048 .53676 .43116 .53838 .43067 .53751 .43002 Mtetra
.623 .808 .971 r
.53751 .43002 .53838 .43067 .54 .43018 .53913 .42958 Mtetra
.614 .821 .98 r
.53913 .42958 .54 .43018 .54162 .42969 .54075 .42915 Mtetra
.608 .836 .987 r
.54075 .42915 .54162 .42969 .54324 .4292 .54238 .42872 Mtetra
.612 .853 .989 r
.54238 .42872 .54324 .4292 .54486 .42869 .544 .42824 Mtetra
.613 .861 .99 r
.544 .42824 .54486 .42869 .54648 .42819 .54562 .42776 Mtetra
.614 .867 .99 r
.54562 .42776 .54648 .42819 .54811 .42768 .54725 .42726 Mtetra
.614 .87 .99 r
.54725 .42726 .54811 .42768 .54973 .42716 .54887 .42675 Mtetra
.616 .874 .99 r
.54887 .42675 .54973 .42716 .55136 .42663 .5505 .42623 Mtetra
.62 .876 .99 r
.5505 .42623 .55136 .42663 .55299 .4261 .55213 .4257 Mtetra
.624 .877 .989 r
.55213 .4257 .55299 .4261 .55462 .42557 .55376 .42516 Mtetra
.63 .877 .987 r
.55376 .42516 .55462 .42557 .55624 .42503 .55539 .42461 Mtetra
.637 .875 .986 r
.55539 .42461 .55624 .42503 .55787 .42449 .55702 .42404 Mtetra
.644 .872 .983 r
.55702 .42404 .55787 .42449 .5595 .42394 .55865 .42347 Mtetra
.652 .87 .981 r
.55865 .42347 .5595 .42394 .56114 .42338 .56028 .42289 Mtetra
.665 .864 .975 r
.56028 .42289 .56114 .42338 .56277 .42285 .56191 .42227 Mtetra
.703 .852 .954 r
.56191 .42227 .56277 .42285 .5644 .42237 .56355 .42156 Mtetra
.694 .788 .923 r
.56355 .42156 .5644 .42237 .56604 .42189 .56518 .4209 Mtetra
.666 .739 .905 r
.56518 .4209 .56604 .42189 .56767 .42137 .56682 .42036 Mtetra
.556 .694 .932 r
.56682 .42036 .56767 .42137 .56931 .4207 .56846 .42022 Mtetra
.382 .755 .991 r
.56846 .42022 .56931 .4207 .57094 .42001 .5701 .42017 Mtetra
.069 0 0 r
.5701 .42017 .57094 .42001 .57258 .41932 .57175 .4201 Mtetra
.123 0 0 r
.57175 .4201 .57258 .41932 .57422 .41869 .57339 .41956 Mtetra
.095 0 0 r
.57339 .41956 .57422 .41869 .57586 .41808 .57503 .41889 Mtetra
.035 0 0 r
.57503 .41889 .57586 .41808 .5775 .4175 .57667 .41818 Mtetra
0 0 0 r
.57667 .41818 .5775 .4175 .57913 .41658 .57831 .41707 Mtetra
.57831 .41707 .57913 .41658 .58077 .41596 .57995 .4164 Mtetra
.334 0 0 r
.57995 .4164 .58077 .41596 .58243 .41586 .5816 .41651 Mtetra
.895 .531 .343 r
.5816 .41651 .58243 .41586 .58413 .41856 .58336 .42232 Mtetra
.961 .678 .453 r
.58336 .42232 .58413 .41856 .58934 .60767 .58869 .62 Mtetra
.641 .38 .508 r
.58869 .62 .58934 .60767 .59137 .62172 .59053 .62409 Mtetra
.519 .162 .3 r
.59053 .62409 .59137 .62172 .59314 .62199 .5923 .62421 Mtetra
.391 .032 .232 r
.5923 .62421 .59314 .62199 .59489 .62123 .59406 .62358 Mtetra
.322 0 .217 r
.59406 .62358 .59489 .62123 .59664 .62018 .59581 .62254 Mtetra
.397 .047 .25 r
.59581 .62254 .59664 .62018 .59842 .62087 .59756 .62188 Mtetra
.159 0 0 r
.59756 .62188 .59842 .62087 .6002 .62152 .59932 .62122 Mtetra
.622 .911 .982 r
.59932 .62122 .6002 .62152 .60199 .62188 .60108 .62055 Mtetra
.67 .694 .863 r
.60108 .62055 .60199 .62188 .60375 .62152 .60284 .61993 Mtetra
.66 .653 .832 r
.60284 .61993 .60375 .62152 .60551 .62092 .6046 .61932 Mtetra
.658 .651 .832 r
.6046 .61932 .60551 .62092 .60727 .62022 .60637 .61873 Mtetra
.644 .66 .851 r
.60637 .61873 .60727 .62022 .60904 .61966 .60813 .61824 Mtetra
.651 .673 .858 r
.60813 .61824 .60904 .61966 .61081 .61912 .6099 .61771 Mtetra
.671 .683 .853 r
.6099 .61771 .61081 .61912 .61257 .61858 .61167 .61707 Mtetra
.73 .691 .813 r
.61167 .61707 .61257 .61858 .61434 .61802 .61342 .61596 Mtetra
.721 .634 .76 r
.61342 .61596 .61434 .61802 .61611 .61746 .61517 .61466 Mtetra
.693 .576 .719 r
.61517 .61466 .61611 .61746 .61788 .61692 .61692 .61333 Mtetra
.629 .509 .697 r
.61692 .61333 .61788 .61692 .61966 .61642 .61869 .6126 Mtetra
.605 .487 .692 r
.61869 .6126 .61966 .61642 .62143 .61594 .62046 .61215 Mtetra
.595 .481 .694 r
.62046 .61215 .62143 .61594 .62321 .61547 .62224 .61182 Mtetra
.615 .498 .697 r
.62224 .61182 .62321 .61547 .62499 .615 .62402 .61126 Mtetra
.609 .492 .694 r
.62402 .61126 .62499 .615 .62676 .61453 .62579 .61076 Mtetra
.593 .481 .695 r
.62579 .61076 .62676 .61453 .62854 .61408 .62758 .61046 Mtetra
.538 .451 .705 r
.62758 .61046 .62854 .61408 .63033 .61379 .62938 .61075 Mtetra
.525 .466 .733 r
.62938 .61075 .63033 .61379 .63212 .61343 .63119 .61109 Mtetra
.532 .514 .781 r
.63119 .61109 .63212 .61343 .6339 .61287 .63299 .61128 Mtetra
.501 .577 .864 r
.63299 .61128 .6339 .61287 .63567 .61201 .6348 .61147 Mtetra
.493 .805 1 r
.6348 .61147 .63567 .61201 .63743 .61061 .63659 .61123 Mtetra
0 0 0 r
.63659 .61123 .63743 .61061 .63915 .60818 .63837 .61026 Mtetra
.63837 .61026 .63915 .60818 .64057 .59683 .64003 .60597 Mtetra
.98 .7 .416 r
.64003 .60597 .64057 .59683 .63568 .4023 .63507 .40761 Mtetra
0 0 .072 r
.63507 .40761 .63568 .4023 .63724 .39833 .63647 .39905 Mtetra
.541 .845 .532 r
.63647 .39905 .63724 .39833 .63889 .39699 .63811 .39739 Mtetra
0 0 0 r
.63811 .39739 .63889 .39699 .64057 .39647 .63979 .39691 Mtetra
.204 0 0 r
.63979 .39691 .64057 .39647 .64226 .39628 .64149 .39679 Mtetra
0 0 0 r
.64149 .39679 .64226 .39628 .64395 .39595 .64316 .396 Mtetra
.653 .969 .888 r
.64316 .396 .64395 .39595 .64564 .39555 .64483 .39499 Mtetra
.751 .873 .935 r
.64483 .39499 .64564 .39555 .64732 .39513 .6465 .39406 Mtetra
.681 .733 .89 r
.6465 .39406 .64732 .39513 .649 .39448 .64818 .39343 Mtetra
.649 .726 .905 r
.64818 .39343 .649 .39448 .65068 .3938 .64987 .39295 Mtetra
.634 .767 .943 r
.64987 .39295 .65068 .3938 .65237 .39325 .65156 .3925 Mtetra
.661 .803 .951 r
.65156 .3925 .65237 .39325 .65408 .39327 .65324 .39194 Mtetra
.672 .685 .855 r
.65324 .39194 .65408 .39327 .6558 .39367 .65493 .39132 Mtetra
.643 .566 .753 r
.65493 .39132 .6558 .39367 .65754 .39425 .65662 .3907 Mtetra
.642 .512 .689 r
.65662 .3907 .65754 .39425 .65923 .39369 .65829 .38981 Mtetra
.626 .493 .68 r
.65829 .38981 .65923 .39369 .66091 .39284 .65997 .38905 Mtetra
.587 .471 .687 r
.65997 .38905 .66091 .39284 .66262 .39262 .66168 .38881 Mtetra
.33 .302 .676 r
.66168 .38881 .66262 .39262 .66453 .39715 .66348 .39082 Mtetra
.77 .528 0 r
.66348 .39082 .66453 .39715 .67497 .59555 .66589 .40657 Mtetra
.018 0 .424 r
.66589 .40657 .67497 .59555 .677 .60006 .67602 .5967 Mtetra
.319 .321 .705 r
.67602 .5967 .677 .60006 .67886 .60079 .67794 .59854 Mtetra
.542 .529 .79 r
.67794 .59854 .67886 .60079 .68068 .60033 .67978 .59866 Mtetra
.626 .631 .836 r
.67978 .59866 .68068 .60033 .68248 .59948 .6816 .59825 Mtetra
.641 .704 .893 r
.6816 .59825 .68248 .59948 .68429 .5989 .68342 .59777 Mtetra
.649 .728 .906 r
.68342 .59777 .68429 .5989 .68611 .59843 .68524 .59725 Mtetra
.664 .723 .893 r
.68524 .59725 .68611 .59843 .68792 .59781 .68705 .59665 Mtetra
.654 .724 .9 r
.68705 .59665 .68792 .59781 .68971 .59665 .68887 .59611 Mtetra
.603 .852 .991 r
.68887 .59611 .68971 .59665 .69147 .59506 .69069 .5956 Mtetra
.033 0 0 r
.69069 .5956 .69147 .59506 .69323 .59327 .69251 .59509 Mtetra
.447 .056 .204 r
.69251 .59509 .69323 .59327 .69504 .5926 .69435 .59489 Mtetra
.462 .102 .268 r
.69435 .59489 .69504 .5926 .69688 .59244 .69619 .59463 Mtetra
.36 .005 .219 r
.69619 .59463 .69688 .59244 .69869 .59163 .698 .59382 Mtetra
0 0 0 r
.698 .59382 .69869 .59163 .70027 .58633 .69969 .59065 Mtetra
.88 .734 .222 r
.69969 .59065 .70027 .58633 .69172 .38639 .70083 .57693 Mtetra
.02 0 .421 r
.70083 .57693 .69172 .38639 .69318 .38093 .69249 .38211 Mtetra
0 0 0 r
.69249 .38211 .69318 .38093 .69482 .37906 .6941 .37956 Mtetra
.6941 .37956 .69482 .37906 .69653 .37841 .6958 .37892 Mtetra
.205 0 0 r
.6958 .37892 .69653 .37841 .69826 .37815 .69754 .37873 Mtetra
0 0 0 r
.69754 .37873 .69826 .37815 .69998 .37785 .69925 .37807 Mtetra
.552 .924 .78 r
.69925 .37807 .69998 .37785 .70171 .37744 .70094 .37701 Mtetra
.757 .916 .944 r
.70094 .37701 .70171 .37744 .70343 .37701 .70263 .37601 Mtetra
.706 .76 .895 r
.70263 .37601 .70343 .37701 .70515 .37647 .70434 .37525 Mtetra
.663 .702 .876 r
.70434 .37525 .70515 .37647 .70686 .37584 .70606 .37468 Mtetra
.651 .711 .892 r
.70606 .37468 .70686 .37584 .70858 .37518 .70778 .37418 Mtetra
.655 .746 .917 r
.70778 .37418 .70858 .37518 .7103 .37456 .7095 .37366 Mtetra
.661 .769 .93 r
.7095 .37366 .7103 .37456 .71202 .37399 .71123 .3731 Mtetra
.662 .773 .932 r
.71123 .3731 .71202 .37399 .71374 .37344 .71295 .37254 Mtetra
.71295 .37254 .71374 .37344 .71546 .37288 .71467 .37198 Mtetra
.71467 .37198 .71546 .37288 .71719 .37232 .7164 .37142 Mtetra
.7164 .37142 .71719 .37232 .71891 .37176 .71813 .37086 Mtetra
.71813 .37086 .71891 .37176 .72064 .3712 .71985 .3703 Mtetra
.661 .773 .932 r
.71985 .3703 .72064 .3712 .72237 .37064 .72158 .36975 Mtetra
.72158 .36975 .72237 .37064 .7241 .37008 .72331 .36919 Mtetra
.66 .773 .933 r
.72331 .36919 .7241 .37008 .72583 .36953 .72505 .36864 Mtetra
.659 .772 .933 r
.72505 .36864 .72583 .36953 .72756 .36898 .72678 .36808 Mtetra
.658 .772 .934 r
.72678 .36808 .72756 .36898 .72929 .36843 .72851 .36754 Mtetra
.657 .773 .934 r
.72851 .36754 .72929 .36843 .73103 .36788 .73025 .36699 Mtetra
.656 .773 .935 r
.73025 .36699 .73103 .36788 .73276 .36734 .73198 .36645 Mtetra
.653 .772 .937 r
.73198 .36645 .73276 .36734 .7345 .3668 .73372 .36593 Mtetra
.643 .772 .941 r
.73372 .36593 .7345 .3668 .73624 .36627 .73546 .36543 Mtetra
.633 .778 .95 r
.73546 .36543 .73624 .36627 .73798 .36574 .73721 .36497 Mtetra
.628 .793 .961 r
.73721 .36497 .73798 .36574 .73972 .36521 .73896 .3645 Mtetra
.629 .811 .97 r
.73896 .3645 .73972 .36521 .74146 .36468 .7407 .36401 Mtetra
.635 .826 .974 r
.7407 .36401 .74146 .36468 .7432 .36414 .74245 .36349 Mtetra
.639 .833 .975 r
.74245 .36349 .7432 .36414 .74495 .36358 .74419 .36295 Mtetra
.641 .837 .976 r
.74419 .36295 .74495 .36358 .74669 .36302 .74593 .3624 Mtetra
.643 .841 .976 r
.74593 .3624 .74669 .36302 .74843 .36245 .74768 .36184 Mtetra
.648 .846 .976 r
.74768 .36184 .74843 .36245 .75018 .36186 .74942 .36126 Mtetra
.657 .852 .974 r
.74942 .36126 .75018 .36186 .75192 .36124 .75117 .36064 Mtetra
.667 .855 .972 r
.75117 .36064 .75192 .36124 .75366 .3606 .75291 .36 Mtetra
.67 .855 .97 r
.75291 .36 .75366 .3606 .7554 .35996 .75465 .35934 Mtetra
.733 .869 .945 r
.75465 .35934 .7554 .35996 .75713 .3591 .75638 .35846 Mtetra
.759 .868 .928 r
.75638 .35846 .75713 .3591 .75885 .35813 .7581 .35746 Mtetra
.628 .823 .975 r
.7581 .35746 .75885 .35813 .76061 .35763 .75986 .35696 Mtetra
0 .251 .714 r
.75986 .35696 .76061 .35763 .76249 .35877 .76174 .35816 Mtetra
.942 .575 .217 r
.76174 .35816 .76249 .35877 .7649 .36703 .76429 .3682 Mtetra
.974 .671 .37 r
.76429 .3682 .7649 .36703 .7819 .56744 .78111 .56672 Mtetra
.675 .178 0 r
.78111 .56672 .7819 .56744 .78404 .57036 .78323 .56945 Mtetra
.424 .676 .968 r
.78323 .56945 .78404 .57036 .78598 .57052 .78516 .56957 Mtetra
.73 .801 .908 r
.78516 .56957 .78598 .57052 .78783 .56957 .78702 .56864 Mtetra
.908 .819 .748 r
.78702 .56864 .78783 .56957 .78952 .56664 .78872 .56582 Mtetra
.983 .745 .498 r
.78872 .56582 .78952 .56664 .7903 .55197 .78973 .55406 Mtetra
.979 .683 .367 r
.78973 .55406 .7903 .55197 .77663 .35529 .7759 .35472 Mtetra
.956 .851 .698 r
.7759 .35472 .77663 .35529 .77819 .35211 .77744 .35136 Mtetra
.722 .833 .933 r
.77744 .35136 .77819 .35211 .77994 .35137 .77919 .35052 Mtetra
.571 .752 .963 r
.77919 .35052 .77994 .35137 .78173 .35119 .78097 .35025 Mtetra
.61 .745 .941 r
.78097 .35025 .78173 .35119 .78352 .35094 .78276 .34988 Mtetra
.73 .765 .881 r
.78276 .34988 .78352 .35094 .78527 .35012 .7845 .34896 Mtetra
.637 .709 .899 r
.7845 .34896 .78527 .35012 .78705 .34965 .78627 .34851 Mtetra
.096 .401 .855 r
.78627 .34851 .78705 .34965 .78892 .3503 .78818 .3496 Mtetra
.939 .571 .196 r
.78818 .3496 .78892 .3503 .79109 .35453 .79087 .36 Mtetra
.971 .665 .371 r
.79087 .36 .79109 .35453 .8098 .55473 .80942 .55876 Mtetra
.683 .354 .411 r
.80942 .55876 .8098 .55473 .81217 .55976 .81159 .56145 Mtetra
.439 .036 .177 r
.81159 .56145 .81217 .55976 .8142 .56075 .81352 .56127 Mtetra
0 0 0 r
.81352 .56127 .8142 .56075 .81616 .56095 .8154 .56039 Mtetra
.746 .901 .947 r
.8154 .56039 .81616 .56095 .8181 .56085 .81726 .55935 Mtetra
.663 .68 .856 r
.81726 .55935 .8181 .56085 .82004 .5607 .81915 .55871 Mtetra
.711 .644 .781 r
.81915 .55871 .82004 .5607 .82193 .56003 .821 .55755 Mtetra
.802 .653 .697 r
.821 .55755 .82193 .56003 .82372 .5582 .82271 .55471 Mtetra
.976 .676 .368 r
.82271 .55471 .82372 .5582 .82521 .55293 .80775 .36416 Mtetra
.59 .368 .548 r
.80775 .36416 .82521 .55293 .80908 .35105 .8078 .34409 Mtetra
.687 .489 .614 r
.8078 .34409 .80908 .35105 .81031 .34424 .80934 .34083 Mtetra
.646 .521 .697 r
.80934 .34083 .81031 .34424 .81195 .34208 .81109 .33989 Mtetra
.621 .571 .777 r
.81109 .33989 .81195 .34208 .81367 .34081 .81289 .33947 Mtetra
.603 .661 .879 r
.81289 .33947 .81367 .34081 .81545 .34019 .8147 .33918 Mtetra
.666 .754 .916 r
.8147 .33918 .81545 .34019 .8173 .34029 .81649 .33858 Mtetra
.653 .635 .819 r
.81649 .33858 .8173 .34029 .81918 .34074 .81828 .338 Mtetra
.639 .545 .732 r
.81828 .338 .81918 .34074 .82105 .34105 .82005 .33732 Mtetra
.639 .507 .686 r
.82005 .33732 .82105 .34105 .82281 .3401 .82181 .33639 Mtetra
.614 .492 .69 r
.82181 .33639 .82281 .3401 .8246 .33947 .8236 .33581 Mtetra
.534 .444 .7 r
.8236 .33581 .8246 .33947 .82652 .34023 .82548 .33616 Mtetra
.142 .174 .634 r
.82548 .33616 .82652 .34023 .84619 .52592 .8277 .33996 Mtetra
.059 0 .459 r
.8277 .33996 .84619 .52592 .85026 .5478 .84898 .54163 Mtetra
.127 .126 .587 r
.84898 .54163 .85026 .5478 .85249 .55047 .85153 .54758 Mtetra
.489 .459 .75 r
.85153 .54758 .85249 .55047 .85446 .55036 .85357 .54819 Mtetra
.59 .568 .798 r
.85357 .54819 .85446 .55036 .85636 .54956 .85553 .54798 Mtetra
.63 .655 .855 r
.85553 .54798 .85636 .54956 .85823 .54838 .85746 .54752 Mtetra
.463 .717 .978 r
.85746 .54752 .85823 .54838 .86011 .54736 .85945 .54751 Mtetra
.213 .731 .71 r
.85945 .54751 .86011 .54736 .86193 .54573 .86138 .54698 Mtetra
0 0 0 r
.86138 .54698 .86193 .54573 .86358 .54238 .86321 .54534 Mtetra
0 0 .033 r
.86321 .54534 .86358 .54238 .84525 .34164 .86457 .53916 Mtetra
.093 .013 .464 r
.86457 .53916 .84525 .34164 .8462 .33265 .84586 .33552 Mtetra
0 0 .069 r
.84586 .33552 .8462 .33265 .84775 .3296 .84716 .32998 Mtetra
.57 .891 .626 r
.84716 .32998 .84775 .3296 .84953 .32877 .84887 .32845 Mtetra
.675 .94 .964 r
.84887 .32845 .84953 .32877 .85137 .32844 .85065 .32759 Mtetra
.645 .789 .951 r
.85065 .32759 .85137 .32844 .85322 .32826 .85247 .32706 Mtetra
.658 .714 .889 r
.85247 .32706 .85322 .32826 .85501 .32753 .85428 .32649 Mtetra
.638 .74 .922 r
.85428 .32649 .85501 .32753 .85681 .32687 .8561 .32602 Mtetra
.627 .781 .955 r
.8561 .32602 .85681 .32687 .85864 .32642 .85793 .32554 Mtetra
.669 .794 .941 r
.85793 .32554 .85864 .32642 .86054 .32663 .85974 .32492 Mtetra
.661 .64 .819 r
.85974 .32492 .86054 .32663 .86247 .3271 .86155 .32428 Mtetra
.637 .541 .729 r
.86155 .32428 .86247 .3271 .8644 .32756 .86335 .32359 Mtetra
.639 .501 .679 r
.86335 .32359 .8644 .32756 .86617 .32657 .86513 .3226 Mtetra
.615 .486 .682 r
.86513 .3226 .86617 .32657 .86797 .32585 .86694 .32196 Mtetra
.558 .453 .691 r
.86694 .32196 .86797 .32585 .8699 .3262 .86883 .32206 Mtetra
.184 .202 .645 r
.86883 .32206 .8699 .3262 .89057 .49669 .87112 .32573 Mtetra
.03 0 .456 r
.87112 .32573 .89057 .49669 .89675 .53453 .8954 .52817 Mtetra
.114 .118 .584 r
.8954 .52817 .89675 .53453 .8991 .53752 .89813 .53465 Mtetra
.476 .453 .753 r
.89813 .53465 .8991 .53752 .90112 .53758 .90023 .53537 Mtetra
.577 .559 .797 r
.90023 .53537 .90112 .53758 .90307 .53695 .90224 .53524 Mtetra
.639 .644 .839 r
.90224 .53524 .90307 .53695 .90497 .53586 .9042 .53472 Mtetra
.524 .682 .938 r
.9042 .53472 .90497 .53586 .90688 .53486 .90622 .53466 Mtetra
.439 .865 .937 r
.90622 .53466 .90688 .53486 .90873 .53332 .90819 .53414 Mtetra
0 0 0 r
.90819 .53414 .90873 .53332 .91045 .53067 .91007 .53286 Mtetra
.91007 .53286 .91045 .53067 .91079 .51605 .91154 .52799 Mtetra
.966 .666 .258 r
.91154 .52799 .91079 .51605 .89 .3197 .89002 .32498 Mtetra
0 0 .258 r
.89002 .32498 .89 .3197 .89145 .31586 .89094 .31653 Mtetra
0 0 .228 r
.29713 .51834 .29882 .50844 .30037 .50687 .29917 .5096 Mtetra
0 0 0 r
.29917 .5096 .30037 .50687 .30188 .50605 .30083 .50659 Mtetra
.86 .997 .792 r
.30083 .50659 .30188 .50605 .30336 .50561 .3024 .5048 Mtetra
.729 .771 .886 r
.3024 .5048 .30336 .50561 .30485 .50504 .30391 .50402 Mtetra
.661 .714 .887 r
.30391 .50402 .30485 .50504 .30634 .50453 .30539 .50354 Mtetra
.63 .71 .904 r
.30539 .50354 .30634 .50453 .30783 .50406 .30687 .50319 Mtetra
.774 .763 .843 r
.30687 .50319 .30783 .50406 .30935 .50306 .3084 .50208 Mtetra
.721 .735 .862 r
.3084 .50208 .30935 .50306 .31085 .50239 .30991 .50129 Mtetra
.568 .668 .905 r
.30991 .50129 .31085 .50239 .31231 .50236 .31138 .50117 Mtetra
.915 .517 .146 r
.31138 .50117 .31231 .50236 .31353 .50616 .31261 .50473 Mtetra
.94 .684 .522 r
.31261 .50473 .31353 .50616 .30275 .70026 .30176 .69898 Mtetra
.95 .608 .324 r
.30176 .69898 .30275 .70026 .30394 .70592 .30293 .70509 Mtetra
0 .297 .751 r
.30293 .70509 .30394 .70592 .30544 .70678 .30443 .70597 Mtetra
.612 .76 .95 r
.30443 .70597 .30544 .70678 .30702 .70644 .306 .70562 Mtetra
.803 .784 .835 r
.306 .70562 .30702 .70644 .30866 .70506 .30765 .70422 Mtetra
.906 .742 .667 r
.30765 .70422 .30866 .70506 .31052 .70013 .30951 .69928 Mtetra
.939 .687 .53 r
.30951 .69928 .31052 .70013 .32385 .50521 .3229 .50428 Mtetra
.912 .724 .635 r
.3229 .50428 .32385 .50521 .32571 .49874 .32476 .49783 Mtetra
.794 .759 .822 r
.32476 .49783 .32571 .49874 .32725 .4974 .32631 .4965 Mtetra
.644 .737 .917 r
.32631 .4965 .32725 .4974 .32875 .49697 .3278 .49609 Mtetra
.503 .691 .952 r
.3278 .49609 .32875 .49697 .33022 .49694 .32928 .49607 Mtetra
.704 .756 .892 r
.32928 .49607 .33022 .49694 .33174 .49615 .33079 .4954 Mtetra
.691 .783 .921 r
.33079 .4954 .33174 .49615 .33325 .49551 .3323 .4948 Mtetra
.572 .763 .969 r
.3323 .4948 .33325 .49551 .33473 .49544 .33378 .49456 Mtetra
0 .163 .65 r
.33378 .49456 .33473 .49544 .33604 .49828 .3352 .49565 Mtetra
0 0 .446 r
.3352 .49565 .33604 .49828 .32674 .68928 .3365 .49869 Mtetra
0 0 .282 r
.3365 .49869 .32674 .68928 .32785 .69748 .32749 .68509 Mtetra
.131 .05 .488 r
.32749 .68509 .32785 .69748 .32936 .69858 .32859 .69348 Mtetra
.311 .248 .624 r
.32859 .69348 .32936 .69858 .33093 .69854 .33002 .69589 Mtetra
.355 .375 .743 r
.33002 .69589 .33093 .69854 .33253 .69805 .33154 .69696 Mtetra
.319 .568 .928 r
.33154 .69696 .33253 .69805 .3341 .69807 .33309 .69737 Mtetra
.561 .776 .979 r
.33309 .69737 .3341 .69807 .33569 .69781 .33468 .69712 Mtetra
.774 .815 .886 r
.33468 .69712 .33569 .69781 .33732 .69686 .33631 .69605 Mtetra
.905 .753 .681 r
.33631 .69605 .33732 .69686 .33912 .69254 .33812 .69169 Mtetra
.942 .688 .524 r
.33812 .69169 .33912 .69254 .3509 .49777 .34996 .49685 Mtetra
.92 .723 .619 r
.34996 .49685 .3509 .49777 .35278 .49026 .35185 .48934 Mtetra
.818 .76 .799 r
.35185 .48934 .35278 .49026 .35436 .48863 .35342 .48772 Mtetra
.656 .739 .911 r
.35342 .48772 .35436 .48863 .35587 .48816 .35493 .48726 Mtetra
.514 .693 .95 r
.35493 .48726 .35587 .48816 .35736 .48811 .35642 .48722 Mtetra
.685 .751 .901 r
.35642 .48722 .35736 .48811 .35889 .48741 .35795 .48663 Mtetra
.696 .78 .916 r
.35795 .48663 .35889 .48741 .36041 .48673 .35947 .48601 Mtetra
.59 .767 .963 r
.35947 .48601 .36041 .48673 .36191 .48659 .36098 .48572 Mtetra
0 .283 .755 r
.36098 .48572 .36191 .48659 .36329 .489 .36243 .48665 Mtetra
0 0 .478 r
.36243 .48665 .36329 .489 .35563 .67838 .36379 .48941 Mtetra
0 0 .3 r
.36379 .48941 .35563 .67838 .35671 .68884 .35641 .67354 Mtetra
.087 .008 .462 r
.35641 .67354 .35671 .68884 .35824 .69025 .35746 .68478 Mtetra
.313 .244 .617 r
.35746 .68478 .35824 .69025 .35983 .69025 .35893 .68738 Mtetra
.363 .366 .729 r
.35893 .68738 .35983 .69025 .36144 .68978 .36047 .68853 Mtetra
.34 .545 .907 r
.36047 .68853 .36144 .68978 .36304 .68972 .36204 .689 Mtetra
.54 .763 .979 r
.36204 .689 .36304 .68972 .36464 .6895 .36365 .6888 Mtetra
.766 .816 .892 r
.36365 .6888 .36464 .6895 .36628 .68861 .36529 .68777 Mtetra
.905 .755 .685 r
.36529 .68777 .36628 .68861 .36806 .68467 .36708 .68356 Mtetra
.945 .688 .517 r
.36708 .68356 .36806 .68467 .37828 .48983 .37741 .48758 Mtetra
.879 .673 .619 r
.37741 .48758 .37828 .48983 .38015 .48145 .37925 .48013 Mtetra
.796 .705 .765 r
.37925 .48013 .38015 .48145 .38174 .4796 .38083 .4784 Mtetra
.63 .673 .873 r
.38083 .4784 .38174 .4796 .38327 .47915 .38235 .47804 Mtetra
.481 .63 .919 r
.38235 .47804 .38327 .47915 .38478 .47915 .38386 .47815 Mtetra
.575 .694 .922 r
.38386 .47815 .38478 .47915 .3863 .47889 .38538 .47797 Mtetra
.651 .739 .914 r
.38538 .47797 .3863 .47889 .38783 .47839 .38691 .47752 Mtetra
.671 .754 .913 r
.38691 .47752 .38783 .47839 .38937 .47787 .38844 .47699 Mtetra
.739 .767 .876 r
.38844 .47699 .38937 .47787 .39092 .477 .38999 .47613 Mtetra
.741 .769 .875 r
.38999 .47613 .39092 .477 .39246 .47617 .39154 .47525 Mtetra
.674 .743 .902 r
.39154 .47525 .39246 .47617 .39399 .47584 .39308 .4747 Mtetra
.254 .506 .902 r
.39308 .4747 .39399 .47584 .39544 .47756 .39457 .47528 Mtetra
0 .066 .62 r
.39457 .47528 .39544 .47756 .39655 .48809 .39601 .4775 Mtetra
.014 0 .457 r
.39601 .4775 .39655 .48809 .3908 .678 .39719 .48623 Mtetra
0 0 .316 r
.39719 .48623 .3908 .678 .39234 .68008 .39155 .67422 Mtetra
.263 .203 .599 r
.39155 .67422 .39234 .68008 .39395 .6802 .39304 .67745 Mtetra
.311 .342 .732 r
.39304 .67745 .39395 .6802 .39559 .67974 .39461 .67877 Mtetra
.478 .677 .952 r
.39461 .67877 .39559 .67974 .39723 .67912 .39623 .67881 Mtetra
.676 .906 .976 r
.39623 .67881 .39723 .67912 .39887 .67842 .39788 .6781 Mtetra
.768 .91 .937 r
.39788 .6781 .39887 .67842 .40052 .67763 .39953 .67708 Mtetra
.741 .854 .933 r
.39953 .67708 .40052 .67763 .40217 .67689 .40119 .6762 Mtetra
.692 .814 .94 r
.40119 .6762 .40217 .67689 .40382 .67624 .40284 .67554 Mtetra
.681 .809 .944 r
.40284 .67554 .40382 .67624 .40546 .67563 .40448 .67492 Mtetra
.67 .806 .948 r
.40448 .67492 .40546 .67563 .40711 .67506 .40613 .67434 Mtetra
.66 .802 .951 r
.40613 .67434 .40711 .67506 .40875 .67454 .40777 .6738 Mtetra
.65 .795 .952 r
.40777 .6738 .40875 .67454 .4104 .67407 .40942 .6733 Mtetra
.576 .765 .968 r
.40942 .6733 .4104 .67407 .41204 .67371 .41106 .67302 Mtetra
.549 .776 .983 r
.41106 .67302 .41204 .67371 .41368 .67341 .4127 .67278 Mtetra
.665 .826 .961 r
.4127 .67278 .41368 .67341 .41532 .67303 .41435 .67221 Mtetra
.844 .792 .801 r
.41435 .67221 .41532 .67303 .41698 .67231 .41604 .67031 Mtetra
.851 .679 .668 r
.41604 .67031 .41698 .67231 .41864 .6713 .41781 .66603 Mtetra
.944 .683 .51 r
.41781 .66603 .41864 .6713 .42031 .67027 .4249 .48554 Mtetra
.58 .363 .55 r
.4249 .48554 .42031 .67027 .42196 .66965 .42682 .47307 Mtetra
.554 .342 .547 r
.42682 .47307 .42196 .66965 .42361 .66946 .42834 .47385 Mtetra
.543 .333 .545 r
.42834 .47385 .42361 .66946 .42525 .66937 .4297 .4803 Mtetra
0 0 .361 r
.4297 .4803 .42525 .66937 .42689 .66916 .42634 .65376 Mtetra
.531 .349 .579 r
.42634 .65376 .42689 .66916 .42854 .66881 .42794 .65494 Mtetra
.553 .369 .585 r
.42794 .65494 .42854 .66881 .4302 .66842 .42957 .65522 Mtetra
.608 .412 .591 r
.42957 .65522 .4302 .66842 .43185 .66795 .43126 .65327 Mtetra
.641 .435 .588 r
.43126 .65327 .43185 .66795 .43351 .66744 .433 .64933 Mtetra
.492 .315 .568 r
.433 .64933 .43351 .66744 .43517 .66703 .43456 .65237 Mtetra
.311 .183 .54 r
.43456 .65237 .43517 .66703 .43682 .66692 .43602 .6596 Mtetra
.256 .18 .576 r
.43602 .6596 .43682 .66692 .43847 .66705 .43756 .6638 Mtetra
.202 .241 .679 r
.43756 .6638 .43847 .66705 .44012 .66713 .43916 .66588 Mtetra
.221 .479 .889 r
.43916 .66588 .44012 .66713 .44177 .66699 .4408 .6666 Mtetra
.418 .801 .991 r
.4408 .6666 .44177 .66699 .44343 .6666 .44245 .66642 Mtetra
.494 .877 .971 r
.44245 .66642 .44343 .6666 .4451 .66614 .44412 .66598 Mtetra
.515 .889 .969 r
.44412 .66598 .4451 .66614 .44677 .66567 .44579 .66548 Mtetra
.5 .879 .973 r
.44579 .66548 .44677 .66567 .44843 .66523 .44746 .66503 Mtetra
.537 .893 .977 r
.44746 .66503 .44843 .66523 .4501 .66476 .44913 .66453 Mtetra
.524 .881 .982 r
.44913 .66453 .4501 .66476 .45177 .66444 .4508 .66407 Mtetra
.57 .866 .996 r
.4508 .66407 .45177 .66444 .45343 .6642 .45247 .66362 Mtetra
.708 .848 .949 r
.45247 .66362 .45343 .6642 .45511 .6635 .45415 .66287 Mtetra
.848 .834 .833 r
.45415 .66287 .45511 .6635 .45682 .66117 .45585 .66115 Mtetra
.958 .855 .697 r
.45585 .66115 .45682 .66117 .45864 .65276 .45758 .65735 Mtetra
.872 .786 .29 r
.45758 .65735 .45864 .65276 .46394 .45707 .45944 .64732 Mtetra
0 0 .34 r
.45944 .64732 .46394 .45707 .46558 .45354 .46455 .45958 Mtetra
.45 .189 .426 r
.46455 .45958 .46558 .45354 .46716 .4527 .46615 .45823 Mtetra
.552 .273 .447 r
.46615 .45823 .46716 .4527 .46873 .45246 .46772 .45844 Mtetra
.568 .292 .458 r
.46772 .45844 .46873 .45246 .47031 .45227 .46929 .45895 Mtetra
.519 .255 .454 r
.46929 .45895 .47031 .45227 .47189 .45177 .47087 .45853 Mtetra
.523 .259 .456 r
.47087 .45853 .47189 .45177 .47347 .45129 .47245 .45817 Mtetra
.525 .262 .458 r
.47245 .45817 .47347 .45129 .47505 .45081 .47404 .45784 Mtetra
.527 .265 .461 r
.47404 .45784 .47505 .45081 .47664 .45032 .47562 .45753 Mtetra
.528 .267 .463 r
.47562 .45753 .47664 .45032 .47822 .44984 .47721 .45723 Mtetra
.56 .296 .472 r
.47721 .45723 .47822 .44984 .47981 .44939 .47879 .4576 Mtetra
.61 .344 .489 r
.47879 .4576 .47981 .44939 .48139 .44899 .48035 .45934 Mtetra
.518 .273 .484 r
.48035 .45934 .48139 .44899 .48298 .4485 .48195 .4585 Mtetra
.277 .074 .415 r
.48195 .4585 .48298 .4485 .48457 .44779 .4836 .45305 Mtetra
0 0 .228 r
.4836 .45305 .48457 .44779 .48616 .44679 .48525 .44815 Mtetra
.745 .878 .465 r
.48525 .44815 .48616 .44679 .48776 .44581 .48687 .44527 Mtetra
.858 .85 .834 r
.48687 .44527 .48776 .44581 .48935 .445 .48847 .4436 Mtetra
.68 .667 .831 r
.48847 .4436 .48935 .445 .49095 .44447 .49007 .44294 Mtetra
.632 .63 .831 r
.49007 .44294 .49095 .44447 .49254 .44401 .49166 .44254 Mtetra
.622 .635 .843 r
.49166 .44254 .49254 .44401 .49413 .44356 .49325 .44221 Mtetra
.651 .663 .849 r
.49325 .44221 .49413 .44356 .49572 .44307 .49484 .44172 Mtetra
.65 .664 .85 r
.49484 .44172 .49572 .44307 .49732 .44258 .49644 .44124 Mtetra
.65 .666 .852 r
.49644 .44124 .49732 .44258 .49892 .44209 .49804 .44077 Mtetra
.651 .668 .854 r
.49804 .44077 .49892 .44209 .50051 .4416 .49963 .44029 Mtetra
.651 .67 .855 r
.49963 .44029 .50051 .4416 .50211 .44111 .50123 .4398 Mtetra
.652 .672 .857 r
.50123 .4398 .50211 .44111 .50371 .44061 .50283 .43932 Mtetra
.653 .674 .858 r
.50283 .43932 .50371 .44061 .50531 .44012 .50443 .43883 Mtetra
.654 .676 .858 r
.50443 .43883 .50531 .44012 .50691 .43962 .50603 .43833 Mtetra
.655 .677 .859 r
.50603 .43833 .50691 .43962 .50851 .43912 .50763 .43784 Mtetra
.656 .678 .859 r
.50763 .43784 .50851 .43912 .51012 .43861 .50924 .43733 Mtetra
.656 .679 .86 r
.50924 .43733 .51012 .43861 .51172 .4381 .51084 .43683 Mtetra
.657 .68 .86 r
.51084 .43683 .51172 .4381 .51332 .4376 .51245 .43632 Mtetra
.51245 .43632 .51332 .4376 .51493 .43708 .51405 .43581 Mtetra
.657 .681 .861 r
.51405 .43581 .51493 .43708 .51654 .43657 .51566 .4353 Mtetra
.658 .681 .861 r
.51566 .4353 .51654 .43657 .51814 .43606 .51727 .43479 Mtetra
.51727 .43479 .51814 .43606 .51975 .43554 .51888 .43428 Mtetra
.658 .682 .861 r
.51888 .43428 .51975 .43554 .52136 .43503 .52049 .43376 Mtetra
.52049 .43376 .52136 .43503 .52297 .43452 .5221 .43325 Mtetra
.658 .682 .862 r
.5221 .43325 .52297 .43452 .52458 .434 .52371 .43274 Mtetra
.657 .682 .862 r
.52371 .43274 .52458 .434 .5262 .43349 .52532 .43223 Mtetra
.657 .682 .863 r
.52532 .43223 .5262 .43349 .52781 .43298 .52694 .43172 Mtetra
.656 .683 .864 r
.52694 .43172 .52781 .43298 .52942 .43247 .52855 .43122 Mtetra
.655 .683 .865 r
.52855 .43122 .52942 .43247 .53104 .43197 .53017 .43072 Mtetra
.653 .684 .866 r
.53017 .43072 .53104 .43197 .53266 .43147 .53178 .43023 Mtetra
.653 .686 .868 r
.53178 .43023 .53266 .43147 .53427 .43097 .5334 .42974 Mtetra
.649 .685 .871 r
.5334 .42974 .53427 .43097 .53589 .43048 .53502 .42928 Mtetra
.64 .686 .877 r
.53502 .42928 .53589 .43048 .53751 .43002 .53664 .42885 Mtetra
.62 .686 .891 r
.53664 .42885 .53751 .43002 .53913 .42958 .53826 .42851 Mtetra
.613 .703 .909 r
.53826 .42851 .53913 .42958 .54075 .42915 .53989 .4282 Mtetra
.614 .728 .927 r
.53989 .4282 .54075 .42915 .54238 .42872 .54151 .42786 Mtetra
.635 .759 .937 r
.54151 .42786 .54238 .42872 .544 .42824 .54313 .42743 Mtetra
.643 .773 .942 r
.54313 .42743 .544 .42824 .54562 .42776 .54476 .42697 Mtetra
.649 .781 .944 r
.54476 .42697 .54562 .42776 .54725 .42726 .54638 .42648 Mtetra
.65 .785 .946 r
.54638 .42648 .54725 .42726 .54887 .42675 .54801 .42599 Mtetra
.655 .791 .947 r
.54801 .42599 .54887 .42675 .5505 .42623 .54964 .42548 Mtetra
.66 .794 .947 r
.54964 .42548 .5505 .42623 .55213 .4257 .55127 .42495 Mtetra
.665 .796 .944 r
.55127 .42495 .55213 .4257 .55376 .42516 .5529 .4244 Mtetra
.671 .795 .941 r
.5529 .4244 .55376 .42516 .55539 .42461 .55453 .42383 Mtetra
.677 .791 .935 r
.55453 .42383 .55539 .42461 .55702 .42404 .55616 .42324 Mtetra
.681 .785 .929 r
.55616 .42324 .55702 .42404 .55865 .42347 .55779 .42263 Mtetra
.687 .779 .921 r
.55779 .42263 .55865 .42347 .56028 .42289 .55942 .422 Mtetra
.697 .773 .91 r
.55942 .422 .56028 .42289 .56191 .42227 .56106 .42132 Mtetra
.749 .77 .87 r
.56106 .42132 .56191 .42227 .56355 .42156 .56269 .42034 Mtetra
.703 .709 .853 r
.56269 .42034 .56355 .42156 .56518 .4209 .56432 .41958 Mtetra
.622 .661 .867 r
.56432 .41958 .56518 .4209 .56682 .42036 .56596 .41923 Mtetra
0 .265 .769 r
.56596 .41923 .56682 .42036 .56846 .42022 .56762 .4205 Mtetra
.834 .398 .2 r
.56762 .4205 .56846 .42022 .5701 .42017 .5693 .42328 Mtetra
.858 .542 .451 r
.5693 .42328 .5701 .42017 .57175 .4201 .57109 .43255 Mtetra
.945 .662 .473 r
.57109 .43255 .57175 .4201 .57339 .41956 .57525 .60343 Mtetra
.036 0 .411 r
.57525 .60343 .57339 .41956 .57503 .41889 .57443 .43477 Mtetra
.361 .162 .47 r
.57443 .43477 .57503 .41889 .57667 .41818 .57598 .42784 Mtetra
.402 .177 .454 r
.57598 .42784 .57667 .41818 .57831 .41707 .57759 .42444 Mtetra
.483 .23 .454 r
.57759 .42444 .57831 .41707 .57995 .4164 .57923 .42324 Mtetra
.617 .34 .475 r
.57923 .42324 .57995 .4164 .5816 .41651 .58092 .425 Mtetra
.954 .67 .462 r
.58092 .425 .5816 .41651 .58336 .42232 .58599 .6172 Mtetra
.562 .344 .542 r
.58599 .6172 .58336 .42232 .58869 .62 .58783 .62167 Mtetra
.71 .323 .314 r
.58783 .62167 .58869 .62 .59053 .62409 .58964 .62358 Mtetra
.42 .776 .996 r
.58964 .62358 .59053 .62409 .5923 .62421 .5914 .62347 Mtetra
.669 .813 .952 r
.5914 .62347 .5923 .62421 .59406 .62358 .59316 .62285 Mtetra
.736 .832 .924 r
.59316 .62285 .59406 .62358 .59581 .62254 .59491 .62194 Mtetra
.705 .858 .955 r
.59491 .62194 .59581 .62254 .59756 .62188 .59667 .62116 Mtetra
.716 .83 .936 r
.59667 .62116 .59756 .62188 .59932 .62122 .59842 .62034 Mtetra
.715 .795 .914 r
.59842 .62034 .59932 .62122 .60108 .62055 .60018 .61953 Mtetra
.682 .754 .906 r
.60018 .61953 .60108 .62055 .60284 .61993 .60194 .61887 Mtetra
.671 .743 .905 r
.60194 .61887 .60284 .61993 .6046 .61932 .6037 .61826 Mtetra
.665 .742 .907 r
.6037 .61826 .6046 .61932 .60637 .61873 .60547 .61768 Mtetra
.606 .722 .927 r
.60547 .61768 .60637 .61873 .60813 .61824 .60724 .61734 Mtetra
.647 .771 .939 r
.60724 .61734 .60813 .61824 .6099 .61771 .60901 .61683 Mtetra
.738 .799 .901 r
.60901 .61683 .6099 .61771 .61167 .61707 .61077 .61588 Mtetra
.879 .761 .728 r
.61077 .61588 .61167 .61707 .61342 .61596 .61248 .61292 Mtetra
.86 .653 .622 r
.61248 .61292 .61342 .61596 .61517 .61466 .6141 .60662 Mtetra
.961 .681 .459 r
.6141 .60662 .61517 .61466 .61692 .61333 .61076 .41375 Mtetra
.561 .347 .547 r
.61076 .41375 .61692 .61333 .61869 .6126 .61237 .41101 Mtetra
.557 .344 .547 r
.61237 .41101 .61869 .6126 .62046 .61215 .61404 .41056 Mtetra
.555 .343 .547 r
.61404 .41056 .62046 .61215 .62224 .61182 .61574 .41107 Mtetra
.558 .345 .547 r
.61574 .41107 .62224 .61182 .62402 .61126 .61739 .40981 Mtetra
.557 .344 .547 r
.61739 .40981 .62402 .61126 .62579 .61076 .61906 .40905 Mtetra
.554 .342 .547 r
.61906 .40905 .62579 .61076 .62758 .61046 .62077 .40988 Mtetra
.031 0 .423 r
.62077 .40988 .62758 .61046 .62938 .61075 .62822 .60055 Mtetra
.241 .158 .557 r
.62822 .60055 .62938 .61075 .63119 .61109 .63022 .6073 Mtetra
.25 .256 .671 r
.63022 .6073 .63119 .61109 .63299 .61128 .63209 .60975 Mtetra
.333 .494 .869 r
.63209 .60975 .63299 .61128 .6348 .61147 .63391 .61046 Mtetra
.528 .7 .949 r
.63391 .61046 .6348 .61147 .63659 .61123 .63571 .61037 Mtetra
.705 .799 .924 r
.63571 .61037 .63659 .61123 .63837 .61026 .63749 .6096 Mtetra
.906 .841 .769 r
.63749 .6096 .63837 .61026 .64003 .60597 .63921 .60702 Mtetra
.973 .889 .522 r
.63921 .60702 .64003 .60597 .63507 .40761 .64084 .60175 Mtetra
.002 0 .406 r
.64084 .60175 .63507 .40761 .63647 .39905 .63596 .4072 Mtetra
.373 .147 .437 r
.63596 .4072 .63647 .39905 .63811 .39739 .63754 .4038 Mtetra
.551 .279 .456 r
.63754 .4038 .63811 .39739 .63979 .39691 .63925 .404 Mtetra
.541 .276 .463 r
.63925 .404 .63979 .39691 .64149 .39679 .64096 .40397 Mtetra
.204 .009 .379 r
.64096 .40397 .64149 .39679 .64316 .396 .64247 .39883 Mtetra
0 0 .081 r
.64247 .39883 .64316 .396 .64483 .39499 .64405 .39525 Mtetra
.912 .981 .739 r
.64405 .39525 .64483 .39499 .6465 .39406 .64567 .39293 Mtetra
.733 .74 .858 r
.64567 .39293 .6465 .39406 .64818 .39343 .64734 .39199 Mtetra
.627 .649 .852 r
.64734 .39199 .64818 .39343 .64987 .39295 .64903 .3916 Mtetra
.59 .648 .875 r
.64903 .3916 .64987 .39295 .65156 .3925 .65073 .39139 Mtetra
.662 .72 .892 r
.65073 .39139 .65156 .3925 .65324 .39194 .65242 .39084 Mtetra
.695 .735 .881 r
.65242 .39084 .65324 .39194 .65493 .39132 .6541 .39013 Mtetra
.694 .717 .867 r
.6541 .39013 .65493 .39132 .65662 .3907 .65578 .38941 Mtetra
.708 .705 .846 r
.65578 .38941 .65662 .3907 .65829 .38981 .65746 .38858 Mtetra
.689 .71 .864 r
.65746 .38858 .65829 .38981 .65997 .38905 .65915 .38788 Mtetra
.618 .693 .897 r
.65915 .38788 .65997 .38905 .66168 .38881 .66085 .38754 Mtetra
.245 .473 .88 r
.66085 .38754 .66168 .38881 .66348 .39082 .6626 .38832 Mtetra
.023 .165 .674 r
.6626 .38832 .66348 .39082 .66589 .40657 .66443 .39081 Mtetra
.111 .046 .497 r
.66443 .39081 .66589 .40657 .67602 .5967 .66676 .40458 Mtetra
.036 0 .431 r
.66676 .40458 .67602 .5967 .67794 .59854 .67687 .59295 Mtetra
.326 .263 .633 r
.67687 .59295 .67794 .59854 .67978 .59866 .67884 .59597 Mtetra
.355 .383 .751 r
.67884 .59597 .67978 .59866 .6816 .59825 .68074 .59725 Mtetra
.452 .669 .956 r
.68074 .59725 .6816 .59825 .68342 .59777 .68258 .59736 Mtetra
.564 .87 .995 r
.68258 .59736 .68342 .59777 .68524 .59725 .6844 .59686 Mtetra
.652 .908 .981 r
.6844 .59686 .68524 .59725 .68705 .59665 .68621 .59614 Mtetra
.634 .869 .986 r
.68621 .59614 .68705 .59665 .68887 .59611 .68803 .59553 Mtetra
.61 .845 .988 r
.68803 .59553 .68887 .59611 .69069 .5956 .68985 .59502 Mtetra
.68985 .59502 .69069 .5956 .69251 .59509 .69167 .59451 Mtetra
.529 .814 .998 r
.69167 .59451 .69251 .59509 .69435 .59489 .6935 .5942 Mtetra
.571 .8 .986 r
.6935 .5942 .69435 .59489 .69619 .59463 .69534 .59385 Mtetra
.686 .817 .945 r
.69534 .59385 .69619 .59463 .698 .59382 .69715 .59314 Mtetra
.881 .858 .814 r
.69715 .59314 .698 .59382 .69969 .59065 .6989 .59106 Mtetra
.981 .912 .611 r
.6989 .59106 .69969 .59065 .70083 .57693 .70054 .58688 Mtetra
0 0 .267 r
.70054 .58688 .70083 .57693 .69249 .38211 .70172 .57384 Mtetra
.057 0 .434 r
.70172 .57384 .69249 .38211 .6941 .37956 .69376 .38754 Mtetra
.541 .281 .471 r
.69376 .38754 .6941 .37956 .6958 .37892 .69551 .38746 Mtetra
.55 .291 .477 r
.69551 .38746 .6958 .37892 .69754 .37873 .69726 .38759 Mtetra
.273 .077 .422 r
.69726 .38759 .69754 .37873 .69925 .37807 .69872 .38204 Mtetra
0 0 .23 r
.69872 .38204 .69925 .37807 .70094 .37701 .70023 .37772 Mtetra
.816 .934 .564 r
.70023 .37772 .70094 .37701 .70263 .37601 .70183 .37506 Mtetra
.801 .797 .848 r
.70183 .37506 .70263 .37601 .70434 .37525 .70351 .3737 Mtetra
.666 .655 .83 r
.70351 .3737 .70434 .37525 .70606 .37468 .70522 .37307 Mtetra
.628 .629 .832 r
.70522 .37307 .70606 .37468 .70778 .37418 .70695 .37267 Mtetra
.638 .647 .842 r
.70695 .37267 .70778 .37418 .7095 .37366 .70868 .37221 Mtetra
.656 .664 .846 r
.70868 .37221 .7095 .37366 .71123 .3731 .7104 .37166 Mtetra
.656 .665 .847 r
.7104 .37166 .71123 .3731 .71295 .37254 .71213 .37111 Mtetra
.657 .666 .847 r
.71213 .37111 .71295 .37254 .71467 .37198 .71385 .37055 Mtetra
.658 .667 .848 r
.71385 .37055 .71467 .37198 .7164 .37142 .71558 .36999 Mtetra
.71558 .36999 .7164 .37142 .71813 .37086 .71731 .36943 Mtetra
.71731 .36943 .71813 .37086 .71985 .3703 .71904 .36887 Mtetra
.657 .667 .848 r
.71904 .36887 .71985 .3703 .72158 .36975 .72076 .36831 Mtetra
.72076 .36831 .72158 .36975 .72331 .36919 .7225 .36775 Mtetra
.656 .667 .848 r
.7225 .36775 .72331 .36919 .72505 .36864 .72423 .3672 Mtetra
.656 .666 .848 r
.72423 .3672 .72505 .36864 .72678 .36808 .72596 .36664 Mtetra
.655 .666 .849 r
.72596 .36664 .72678 .36808 .72851 .36754 .72769 .3661 Mtetra
.72769 .3661 .72851 .36754 .73025 .36699 .72943 .36555 Mtetra
.654 .665 .849 r
.72943 .36555 .73025 .36699 .73198 .36645 .73117 .36501 Mtetra
.649 .663 .85 r
.73117 .36501 .73198 .36645 .73372 .36593 .73291 .36449 Mtetra
.634 .658 .856 r
.73291 .36449 .73372 .36593 .73546 .36543 .73465 .36406 Mtetra
.619 .661 .869 r
.73465 .36406 .73546 .36543 .73721 .36497 .73641 .36371 Mtetra
.615 .679 .887 r
.73641 .36371 .73721 .36497 .73896 .3645 .73816 .36336 Mtetra
.628 .707 .903 r
.73816 .36336 .73896 .3645 .7407 .36401 .73991 .36296 Mtetra
.647 .732 .911 r
.73991 .36296 .7407 .36401 .74245 .36349 .74166 .36246 Mtetra
.655 .741 .913 r
.74166 .36246 .74245 .36349 .74419 .36295 .74341 .36193 Mtetra
.657 .744 .914 r
.74341 .36193 .74419 .36295 .74593 .3624 .74515 .36139 Mtetra
.657 .747 .916 r
.74515 .36139 .74593 .3624 .74768 .36184 .7469 .36085 Mtetra
.662 .754 .918 r
.7469 .36085 .74768 .36184 .74942 .36126 .74865 .36029 Mtetra
.671 .762 .918 r
.74865 .36029 .74942 .36126 .75117 .36064 .75039 .35969 Mtetra
.68 .767 .917 r
.75039 .35969 .75117 .36064 .75291 .36 .75214 .35904 Mtetra
.683 .769 .916 r
.75214 .35904 .75291 .36 .75465 .35934 .75388 .35839 Mtetra
.73 .784 .895 r
.75388 .35839 .75465 .35934 .75638 .35846 .75561 .35749 Mtetra
.751 .788 .883 r
.75561 .35749 .75638 .35846 .7581 .35746 .75733 .35648 Mtetra
.648 .751 .925 r
.75733 .35648 .7581 .35746 .75986 .35696 .75908 .35597 Mtetra
0 .323 .806 r
.75908 .35597 .75986 .35696 .76174 .35816 .76097 .3572 Mtetra
.942 .581 .198 r
.76097 .3572 .76174 .35816 .76429 .3682 .76357 .36793 Mtetra
.975 .672 .366 r
.76357 .36793 .76429 .3682 .78111 .56672 .7803 .56583 Mtetra
.613 .131 0 r
.7803 .56583 .78111 .56672 .78323 .56945 .78242 .56851 Mtetra
.431 .676 .966 r
.78242 .56851 .78323 .56945 .78516 .56957 .78435 .56863 Mtetra
.729 .802 .909 r
.78435 .56863 .78516 .56957 .78702 .56864 .78621 .5677 Mtetra
.907 .819 .749 r
.78621 .5677 .78702 .56864 .78872 .56582 .78791 .56489 Mtetra
.981 .744 .506 r
.78791 .56489 .78872 .56582 .78973 .55406 .78895 .55354 Mtetra
.978 .681 .374 r
.78895 .55354 .78973 .55406 .7759 .35472 .77513 .35373 Mtetra
.927 .797 .698 r
.77513 .35373 .7759 .35472 .77744 .35136 .77668 .35034 Mtetra
.719 .769 .893 r
.77668 .35034 .77744 .35136 .77919 .35052 .77842 .34949 Mtetra
.588 .716 .932 r
.77842 .34949 .77919 .35052 .78097 .35025 .78021 .34922 Mtetra
.618 .729 .925 r
.78021 .34922 .78097 .35025 .78276 .34988 .78199 .34883 Mtetra
.735 .77 .881 r
.78199 .34883 .78276 .34988 .7845 .34896 .78373 .34789 Mtetra
.638 .728 .914 r
.78373 .34789 .7845 .34896 .78627 .34851 .78551 .34743 Mtetra
.038 .375 .841 r
.78551 .34743 .78627 .34851 .78818 .3496 .78742 .34858 Mtetra
.946 .593 .209 r
.78742 .34858 .78818 .3496 .79087 .36 .79033 .36166 Mtetra
.974 .668 .358 r
.79033 .36166 .79087 .36 .80942 .55876 .80866 .55825 Mtetra
.692 .176 0 r
.80866 .55825 .80942 .55876 .81159 .56145 .81082 .56083 Mtetra
.482 .786 .998 r
.81082 .56083 .81159 .56145 .81352 .56127 .81275 .56063 Mtetra
.747 .882 .941 r
.81275 .56063 .81352 .56127 .8154 .56039 .81461 .5596 Mtetra
.845 .86 .854 r
.81461 .5596 .8154 .56039 .81726 .55935 .81642 .5579 Mtetra
.845 .749 .758 r
.81642 .5579 .81726 .55935 .81915 .55871 .81816 .55553 Mtetra
.816 .631 .652 r
.81816 .55553 .81915 .55871 .821 .55755 .81976 .55145 Mtetra
.975 .674 .377 r
.81976 .55145 .821 .55755 .82271 .55471 .80479 .35914 Mtetra
.579 .36 .548 r
.80479 .35914 .82271 .55471 .80775 .36416 .80539 .34511 Mtetra
.615 .405 .574 r
.80539 .34511 .80775 .36416 .8078 .34409 .8069 .34145 Mtetra
.744 .608 .706 r
.8069 .34145 .8078 .34409 .80934 .34083 .80856 .33949 Mtetra
.696 .704 .854 r
.80856 .33949 .80934 .34083 .81109 .33989 .81033 .3387 Mtetra
.637 .705 .896 r
.81033 .3387 .81109 .33989 .81289 .33947 .81212 .33824 Mtetra
.62 .692 .896 r
.81212 .33824 .81289 .33947 .8147 .33918 .81393 .33787 Mtetra
.665 .696 .87 r
.81393 .33787 .8147 .33918 .81649 .33858 .81571 .33727 Mtetra
.665 .695 .869 r
.81571 .33727 .81649 .33858 .81828 .338 .8175 .33667 Mtetra
.675 .697 .863 r
.8175 .33667 .81828 .338 .82005 .33732 .81928 .336 Mtetra
.702 .711 .856 r
.81928 .336 .82005 .33732 .82181 .33639 .82105 .33518 Mtetra
.665 .715 .886 r
.82105 .33518 .82181 .33639 .8236 .33581 .82284 .33459 Mtetra
.534 .651 .91 r
.82284 .33459 .8236 .33581 .82548 .33616 .82468 .33456 Mtetra
.164 .361 .812 r
.82468 .33456 .82548 .33616 .8277 .33996 .82667 .33595 Mtetra
.165 .191 .643 r
.82667 .33595 .8277 .33996 .84898 .54163 .82886 .33952 Mtetra
.119 .034 .476 r
.82886 .33952 .84898 .54163 .85153 .54758 .84976 .5364 Mtetra
.31 .212 .579 r
.84976 .5364 .85153 .54758 .85357 .54819 .85241 .54334 Mtetra
.39 .327 .666 r
.85241 .54334 .85357 .54819 .85553 .54798 .8546 .54555 Mtetra
.418 .445 .782 r
.8546 .54555 .85553 .54798 .85746 .54752 .85668 .54646 Mtetra
.439 .652 .949 r
.85668 .54646 .85746 .54752 .85945 .54751 .85868 .54664 Mtetra
.607 .782 .964 r
.85868 .54664 .85945 .54751 .86138 .54698 .86063 .5462 Mtetra
.78 .862 .91 r
.86063 .5462 .86138 .54698 .86321 .54534 .86249 .54498 Mtetra
.955 .918 .734 r
.86249 .54498 .86321 .54534 .86457 .53916 .86418 .54202 Mtetra
0 0 .011 r
.86418 .54202 .86457 .53916 .84586 .33552 .86554 .5358 Mtetra
.112 .026 .469 r
.86554 .5358 .84586 .33552 .84716 .32998 .84711 .3356 Mtetra
.115 0 .353 r
.84711 .3356 .84716 .32998 .84887 .32845 .84841 .33003 Mtetra
0 0 0 r
.84841 .33003 .84887 .32845 .85065 .32759 .85 .3273 Mtetra
.861 .969 .863 r
.85 .3273 .85065 .32759 .85247 .32706 .8517 .32564 Mtetra
.666 .682 .856 r
.8517 .32564 .85247 .32706 .85428 .32649 .8535 .32502 Mtetra
.61 .646 .861 r
.8535 .32502 .85428 .32649 .8561 .32602 .85534 .32469 Mtetra
.593 .663 .887 r
.85534 .32469 .8561 .32602 .85793 .32554 .85719 .32444 Mtetra
.686 .747 .898 r
.85719 .32444 .85793 .32554 .85974 .32492 .85899 .32374 Mtetra
.694 .735 .883 r
.85899 .32374 .85974 .32492 .86155 .32428 .86079 .32299 Mtetra
.693 .716 .867 r
.86079 .32299 .86155 .32428 .86335 .32359 .86259 .32223 Mtetra
.708 .709 .849 r
.86259 .32223 .86335 .32359 .86513 .3226 .86438 .32135 Mtetra
.67 .712 .88 r
.86438 .32135 .86513 .3226 .86694 .32196 .86619 .32072 Mtetra
.566 .665 .905 r
.86619 .32072 .86694 .32196 .86883 .32206 .86806 .32057 Mtetra
.148 .366 .821 r
.86806 .32057 .86883 .32206 .87112 .32573 .8701 .32195 Mtetra
.125 .174 .643 r
.8701 .32195 .87112 .32573 .8954 .52817 .8724 .32571 Mtetra
.132 .047 .485 r
.8724 .32571 .8954 .52817 .89813 .53465 .89638 .5247 Mtetra
.315 .223 .59 r
.89638 .5247 .89813 .53465 .90023 .53537 .89909 .53095 Mtetra
.38 .332 .679 r
.89909 .53095 .90023 .53537 .90224 .53524 .90135 .53311 Mtetra
.399 .461 .808 r
.90135 .53311 .90224 .53524 .9042 .53472 .90348 .534 Mtetra
.413 .728 .99 r
.90348 .534 .9042 .53472 .90622 .53466 .9055 .53401 Mtetra
.612 .847 .988 r
.9055 .53401 .90622 .53466 .90819 .53414 .90747 .53345 Mtetra
.772 .888 .928 r
.90747 .53345 .90819 .53414 .91007 .53286 .90936 .53228 Mtetra
.934 .903 .77 r
.90936 .53228 .91007 .53286 .91154 .52799 .91109 .52965 Mtetra
0 0 0 r
.91109 .52965 .91154 .52799 .89002 .32498 .91257 .52489 Mtetra
.135 .046 .481 r
.91257 .52489 .89002 .32498 .89094 .31653 .89153 .32674 Mtetra
.535 .322 .537 r
.28317 .70725 .29713 .51834 .29917 .5096 .2854 .69702 Mtetra
0 0 .228 r
.2854 .69702 .29917 .5096 .30083 .50659 .29973 .50783 Mtetra
.971 .93 .636 r
.29973 .50783 .30083 .50659 .3024 .5048 .30144 .50399 Mtetra
.764 .774 .861 r
.30144 .50399 .3024 .5048 .30391 .50402 .30296 .50298 Mtetra
.655 .707 .886 r
.30296 .50298 .30391 .50402 .30539 .50354 .30445 .50253 Mtetra
.583 .689 .914 r
.30445 .50253 .30539 .50354 .30687 .50319 .30592 .50234 Mtetra
.767 .765 .852 r
.30592 .50234 .30687 .50319 .3084 .50208 .30744 .50129 Mtetra
.719 .775 .897 r
.30744 .50129 .3084 .50208 .30991 .50129 .30895 .50056 Mtetra
.496 .728 .976 r
.30895 .50056 .30991 .50129 .31138 .50117 .31041 .50049 Mtetra
.916 .532 .264 r
.31041 .50049 .31138 .50117 .31261 .50473 .31163 .50425 Mtetra
.938 .682 .523 r
.31163 .50425 .31261 .50473 .30176 .69898 .30072 .69856 Mtetra
.923 .581 .373 r
.30072 .69856 .30176 .69898 .30293 .70509 .30191 .70429 Mtetra
0 .311 .758 r
.30191 .70429 .30293 .70509 .30443 .70597 .30341 .70514 Mtetra
.617 .755 .944 r
.30341 .70514 .30443 .70597 .306 .70562 .30499 .70478 Mtetra
.801 .779 .832 r
.30499 .70478 .306 .70562 .30765 .70422 .30663 .70337 Mtetra
.906 .741 .667 r
.30663 .70337 .30765 .70422 .30951 .69928 .30849 .69841 Mtetra
.939 .687 .53 r
.30849 .69841 .30951 .69928 .3229 .50428 .32195 .50334 Mtetra
.912 .723 .635 r
.32195 .50334 .3229 .50428 .32476 .49783 .32381 .49692 Mtetra
.793 .759 .822 r
.32381 .49692 .32476 .49783 .32631 .4965 .32536 .49561 Mtetra
.641 .736 .918 r
.32536 .49561 .32631 .4965 .3278 .49609 .32686 .4952 Mtetra
.5 .69 .953 r
.32686 .4952 .3278 .49609 .32928 .49607 .32833 .49519 Mtetra
.674 .749 .907 r
.32833 .49519 .32928 .49607 .33079 .4954 .32983 .49466 Mtetra
.68 .782 .927 r
.32983 .49466 .33079 .4954 .3323 .4948 .33134 .4941 Mtetra
.639 .784 .951 r
.33134 .4941 .3323 .4948 .33378 .49456 .33284 .49368 Mtetra
.594 .726 .936 r
.33284 .49368 .33378 .49456 .3352 .49565 .33433 .49343 Mtetra
.537 .506 .769 r
.33433 .49343 .3352 .49565 .3365 .49869 .3358 .49357 Mtetra
.486 .367 .643 r
.3358 .49357 .3365 .49869 .32749 .68509 .33722 .49452 Mtetra
.541 .331 .544 r
.33722 .49452 .32749 .68509 .32859 .69348 .33831 .50151 Mtetra
0 0 .274 r
.33831 .50151 .32859 .69348 .33002 .69589 .32917 .69226 Mtetra
0 0 .498 r
.32917 .69226 .33002 .69589 .33154 .69696 .33055 .69585 Mtetra
.046 .401 .856 r
.33055 .69585 .33154 .69696 .33309 .69737 .33207 .69668 Mtetra
.561 .776 .979 r
.33207 .69668 .33309 .69737 .33468 .69712 .33366 .69643 Mtetra
.79 .814 .871 r
.33366 .69643 .33468 .69712 .33631 .69605 .33531 .69523 Mtetra
.905 .752 .68 r
.33531 .69523 .33631 .69605 .33812 .69169 .33712 .69083 Mtetra
.942 .688 .524 r
.33712 .69083 .33812 .69169 .34996 .49685 .34903 .49591 Mtetra
.92 .722 .619 r
.34903 .49591 .34996 .49685 .35185 .48934 .35091 .48843 Mtetra
.817 .761 .8 r
.35091 .48843 .35185 .48934 .35342 .48772 .35248 .48682 Mtetra
.654 .739 .912 r
.35248 .48682 .35342 .48772 .35493 .48726 .354 .48636 Mtetra
.511 .692 .95 r
.354 .48636 .35493 .48726 .35642 .48722 .35549 .48633 Mtetra
.655 .743 .915 r
.35549 .48633 .35642 .48722 .35795 .48663 .357 .48587 Mtetra
.681 .779 .924 r
.357 .48587 .35795 .48663 .35947 .48601 .35852 .4853 Mtetra
.644 .785 .949 r
.35852 .4853 .35947 .48601 .36098 .48572 .36004 .48486 Mtetra
.6 .734 .938 r
.36004 .48486 .36098 .48572 .36243 .48665 .36155 .48458 Mtetra
.545 .525 .784 r
.36155 .48458 .36243 .48665 .36379 .48941 .36304 .48467 Mtetra
.492 .379 .653 r
.36304 .48467 .36379 .48941 .35641 .67354 .3645 .48549 Mtetra
.544 .334 .545 r
.3645 .48549 .35641 .67354 .35746 .68478 .36573 .49098 Mtetra
0 0 .292 r
.36573 .49098 .35746 .68478 .35893 .68738 .35809 .68323 Mtetra
0 0 .499 r
.35809 .68323 .35893 .68738 .36047 .68853 .35949 .68725 Mtetra
.024 .346 .824 r
.35949 .68725 .36047 .68853 .36204 .689 .36104 .68827 Mtetra
.538 .759 .978 r
.36104 .68827 .36204 .689 .36365 .6888 .36265 .68808 Mtetra
.783 .811 .875 r
.36265 .68808 .36365 .6888 .36529 .68777 .3643 .68693 Mtetra
.905 .755 .684 r
.3643 .68693 .36529 .68777 .36708 .68356 .36609 .6827 Mtetra
.945 .688 .517 r
.36609 .6827 .36708 .68356 .37741 .48758 .37647 .48689 Mtetra
.932 .735 .614 r
.37647 .48689 .37741 .48758 .37925 .48013 .37831 .47931 Mtetra
.837 .779 .796 r
.37831 .47931 .37925 .48013 .38083 .4784 .3799 .47754 Mtetra
.636 .748 .929 r
.3799 .47754 .38083 .4784 .38235 .47804 .38143 .47714 Mtetra
.465 .673 .955 r
.38143 .47714 .38235 .47804 .38386 .47815 .38293 .4772 Mtetra
.575 .707 .932 r
.38293 .4772 .38386 .47815 .38538 .47797 .38445 .47701 Mtetra
.646 .728 .908 r
.38445 .47701 .38538 .47797 .38691 .47752 .38598 .47658 Mtetra
.661 .737 .906 r
.38598 .47658 .38691 .47752 .38844 .47699 .38752 .4761 Mtetra
.706 .756 .891 r
.38752 .4761 .38844 .47699 .38999 .47613 .38906 .47541 Mtetra
.72 .799 .914 r
.38906 .47541 .38999 .47613 .39154 .47525 .3906 .47467 Mtetra
.683 .831 .954 r
.3906 .47467 .39154 .47525 .39308 .4747 .39215 .47407 Mtetra
.592 .794 .977 r
.39215 .47407 .39308 .4747 .39457 .47528 .39368 .47375 Mtetra
.526 .577 .849 r
.39368 .47375 .39457 .47528 .39601 .4775 .39519 .47383 Mtetra
.472 .394 .686 r
.39519 .47383 .39601 .4775 .39719 .48623 .39668 .47463 Mtetra
.38 .24 .563 r
.39668 .47463 .39719 .48623 .39155 .67422 .39803 .47903 Mtetra
0 0 .311 r
.39803 .47903 .39155 .67422 .39304 .67745 .39221 .67267 Mtetra
0 0 .496 r
.39221 .67267 .39304 .67745 .39461 .67877 .39365 .67724 Mtetra
.252 .442 .854 r
.39365 .67724 .39461 .67877 .39623 .67881 .39524 .67806 Mtetra
.669 .795 .942 r
.39524 .67806 .39623 .67881 .39788 .6781 .39689 .67749 Mtetra
.771 .841 .905 r
.39689 .67749 .39788 .6781 .39953 .67708 .39855 .67645 Mtetra
.744 .836 .921 r
.39855 .67645 .39953 .67708 .40119 .6762 .4002 .67555 Mtetra
.689 .825 .948 r
.4002 .67555 .40119 .6762 .40284 .67554 .40185 .6749 Mtetra
.681 .826 .953 r
.40185 .6749 .40284 .67554 .40448 .67492 .4035 .67427 Mtetra
.67 .821 .956 r
.4035 .67427 .40448 .67492 .40613 .67434 .40514 .67368 Mtetra
.66 .816 .958 r
.40514 .67368 .40613 .67434 .40777 .6738 .40679 .67313 Mtetra
.654 .812 .959 r
.40679 .67313 .40777 .6738 .40942 .6733 .40844 .6726 Mtetra
.54 .771 .983 r
.40844 .6726 .40942 .6733 .41106 .67302 .41007 .67238 Mtetra
.518 .778 .991 r
.41007 .67238 .41106 .67302 .4127 .67278 .41171 .67219 Mtetra
.711 .842 .945 r
.41171 .67219 .4127 .67278 .41435 .67221 .41337 .67144 Mtetra
.896 .781 .726 r
.41337 .67144 .41435 .67221 .41604 .67031 .4151 .66829 Mtetra
.949 .688 .507 r
.4151 .66829 .41604 .67031 .41781 .66603 .42261 .47875 Mtetra
.579 .362 .55 r
.42261 .47875 .41781 .66603 .4249 .48554 .42453 .46637 Mtetra
.599 .395 .576 r
.42453 .46637 .4249 .48554 .42682 .47307 .42615 .46403 Mtetra
.58 .402 .605 r
.42615 .46403 .42682 .47307 .42834 .47385 .4277 .46357 Mtetra
.559 .381 .597 r
.4277 .46357 .42834 .47385 .4297 .4803 .42925 .46364 Mtetra
.56 .368 .577 r
.42925 .46364 .4297 .4803 .42634 .65376 .43079 .46359 Mtetra
.556 .344 .547 r
.43079 .46359 .42634 .65376 .42794 .65494 .43235 .46319 Mtetra
.557 .344 .547 r
.43235 .46319 .42794 .65494 .42957 .65522 .43391 .46276 Mtetra
.43391 .46276 .42957 .65522 .43126 .65327 .43548 .46202 Mtetra
.43548 .46202 .43126 .65327 .433 .64933 .43705 .4612 Mtetra
.556 .343 .547 r
.43705 .4612 .433 .64933 .43456 .65237 .43861 .46098 Mtetra
.551 .339 .546 r
.43861 .46098 .43456 .65237 .43602 .6596 .4401 .46343 Mtetra
0 0 .334 r
.4401 .46343 .43602 .6596 .43756 .6638 .43673 .65757 Mtetra
0 0 .437 r
.43673 .65757 .43756 .6638 .43916 .66588 .43822 .66406 Mtetra
.012 .244 .75 r
.43822 .66406 .43916 .66588 .4408 .6666 .43983 .66562 Mtetra
.554 .708 .943 r
.43983 .66562 .4408 .6666 .44245 .66642 .44149 .66546 Mtetra
.677 .754 .909 r
.44149 .66546 .44245 .66642 .44412 .66598 .44316 .66486 Mtetra
.681 .724 .882 r
.44316 .66486 .44412 .66598 .44579 .66548 .44484 .66422 Mtetra
.649 .688 .873 r
.44484 .66422 .44579 .66548 .44746 .66503 .4465 .66374 Mtetra
.657 .686 .865 r
.4465 .66374 .44746 .66503 .44913 .66453 .44818 .66321 Mtetra
.655 .682 .864 r
.44818 .66321 .44913 .66453 .4508 .66407 .44985 .66269 Mtetra
.655 .673 .855 r
.44985 .66269 .4508 .66407 .45247 .66362 .45152 .66217 Mtetra
.676 .67 .837 r
.45152 .66217 .45247 .66362 .45415 .66287 .4532 .66151 Mtetra
.733 .702 .822 r
.4532 .66151 .45415 .66287 .45585 .66115 .45488 .66046 Mtetra
.835 .826 .839 r
.45488 .66046 .45585 .66115 .45758 .65735 .45658 .65885 Mtetra
0 0 0 r
.45658 .65885 .45758 .65735 .45944 .64732 .45828 .65696 Mtetra
.482 .238 .467 r
.45828 .65696 .45944 .64732 .46455 .45958 .45998 .65539 Mtetra
.554 .337 .541 r
.45998 .65539 .46455 .45958 .46615 .45823 .46166 .65474 Mtetra
.554 .338 .541 r
.46166 .65474 .46615 .45823 .46772 .45844 .46333 .65443 Mtetra
.46333 .65443 .46772 .45844 .46929 .45895 .46501 .65414 Mtetra
.46501 .65414 .46929 .45895 .47087 .45853 .46669 .6537 Mtetra
.46669 .6537 .47087 .45853 .47245 .45817 .46837 .65327 Mtetra
.46837 .65327 .47245 .45817 .47404 .45784 .47005 .65285 Mtetra
.47005 .65285 .47404 .45784 .47562 .45753 .47173 .65245 Mtetra
.47173 .65245 .47562 .45753 .47721 .45723 .47341 .65204 Mtetra
.555 .338 .541 r
.47341 .65204 .47721 .45723 .47879 .4576 .47509 .65189 Mtetra
.47509 .65189 .47879 .4576 .48035 .45934 .47677 .65199 Mtetra
.554 .337 .541 r
.47677 .65199 .48035 .45934 .48195 .4585 .47846 .65139 Mtetra
.55 .334 .54 r
.47846 .65139 .48195 .4585 .4836 .45305 .48018 .64838 Mtetra
0 0 .343 r
.48018 .64838 .4836 .45305 .48525 .44815 .48429 .45303 Mtetra
0 0 0 r
.48429 .45303 .48525 .44815 .48687 .44527 .48597 .44527 Mtetra
.944 .906 .755 r
.48597 .44527 .48687 .44527 .48847 .4436 .48758 .44264 Mtetra
.715 .755 .883 r
.48758 .44264 .48847 .4436 .49007 .44294 .48918 .44187 Mtetra
.617 .702 .905 r
.48918 .44187 .49007 .44294 .49166 .44254 .49077 .44154 Mtetra
.587 .705 .924 r
.49077 .44154 .49166 .44254 .49325 .44221 .49236 .44131 Mtetra
.652 .752 .923 r
.49236 .44131 .49325 .44221 .49484 .44172 .49396 .44084 Mtetra
.65 .753 .925 r
.49396 .44084 .49484 .44172 .49644 .44124 .49555 .44037 Mtetra
.649 .756 .928 r
.49555 .44037 .49644 .44124 .49804 .44077 .49715 .4399 Mtetra
.65 .76 .93 r
.49715 .4399 .49804 .44077 .49963 .44029 .49875 .43943 Mtetra
.65 .762 .931 r
.49875 .43943 .49963 .44029 .50123 .4398 .50035 .43896 Mtetra
.651 .765 .933 r
.50035 .43896 .50123 .4398 .50283 .43932 .50195 .43849 Mtetra
.652 .768 .934 r
.50195 .43849 .50283 .43932 .50443 .43883 .50355 .43801 Mtetra
.653 .77 .935 r
.50355 .43801 .50443 .43883 .50603 .43833 .50515 .43752 Mtetra
.654 .772 .936 r
.50515 .43752 .50603 .43833 .50763 .43784 .50675 .43703 Mtetra
.655 .774 .937 r
.50675 .43703 .50763 .43784 .50924 .43733 .50836 .43653 Mtetra
.656 .776 .937 r
.50836 .43653 .50924 .43733 .51084 .43683 .50996 .43603 Mtetra
.657 .777 .938 r
.50996 .43603 .51084 .43683 .51245 .43632 .51157 .43553 Mtetra
.657 .778 .938 r
.51157 .43553 .51245 .43632 .51405 .43581 .51317 .43502 Mtetra
.658 .779 .938 r
.51317 .43502 .51405 .43581 .51566 .4353 .51478 .43451 Mtetra
.658 .78 .938 r
.51478 .43451 .51566 .4353 .51727 .43479 .51639 .434 Mtetra
.658 .78 .939 r
.51639 .434 .51727 .43479 .51888 .43428 .518 .43349 Mtetra
.658 .781 .939 r
.518 .43349 .51888 .43428 .52049 .43376 .51961 .43297 Mtetra
.51961 .43297 .52049 .43376 .5221 .43325 .52122 .43246 Mtetra
.657 .781 .94 r
.52122 .43246 .5221 .43325 .52371 .43274 .52284 .43195 Mtetra
.656 .782 .941 r
.52284 .43195 .52371 .43274 .52532 .43223 .52445 .43144 Mtetra
.655 .782 .942 r
.52445 .43144 .52532 .43223 .52694 .43172 .52606 .43094 Mtetra
.653 .783 .943 r
.52606 .43094 .52694 .43172 .52855 .43122 .52768 .43044 Mtetra
.65 .784 .945 r
.52768 .43044 .52855 .43122 .53017 .43072 .5293 .42995 Mtetra
.646 .785 .948 r
.5293 .42995 .53017 .43072 .53178 .43023 .53091 .42948 Mtetra
.64 .787 .952 r
.53091 .42948 .53178 .43023 .5334 .42974 .53253 .42902 Mtetra
.633 .792 .958 r
.53253 .42902 .5334 .42974 .53502 .42928 .53415 .42857 Mtetra
.624 .795 .964 r
.53415 .42857 .53502 .42928 .53664 .42885 .53577 .42815 Mtetra
.61 .792 .968 r
.53577 .42815 .53664 .42885 .53826 .42851 .53739 .42777 Mtetra
.612 .779 .961 r
.53739 .42777 .53826 .42851 .53989 .4282 .53902 .42739 Mtetra
.619 .767 .951 r
.53902 .42739 .53989 .4282 .54151 .42786 .54064 .42701 Mtetra
.632 .76 .939 r
.54064 .42701 .54151 .42786 .54313 .42743 .54227 .42659 Mtetra
.637 .764 .94 r
.54227 .42659 .54313 .42743 .54476 .42697 .54389 .42616 Mtetra
.642 .772 .942 r
.54389 .42616 .54476 .42697 .54638 .42648 .54552 .4257 Mtetra
.646 .781 .946 r
.54552 .4257 .54638 .42648 .54801 .42599 .54715 .42522 Mtetra
.652 .787 .946 r
.54715 .42522 .54801 .42599 .54964 .42548 .54878 .42472 Mtetra
.66 .791 .945 r
.54878 .42472 .54964 .42548 .55127 .42495 .55041 .42419 Mtetra
.669 .794 .942 r
.55041 .42419 .55127 .42495 .5529 .4244 .55204 .42363 Mtetra
.677 .793 .936 r
.55204 .42363 .5529 .4244 .55453 .42383 .55367 .42303 Mtetra
.684 .79 .93 r
.55367 .42303 .55453 .42383 .55616 .42324 .5553 .42241 Mtetra
.692 .785 .922 r
.5553 .42241 .55616 .42324 .55779 .42263 .55693 .42176 Mtetra
.695 .775 .913 r
.55693 .42176 .55779 .42263 .55942 .422 .55856 .42109 Mtetra
.701 .768 .904 r
.55856 .42109 .55942 .422 .56106 .42132 .5602 .42039 Mtetra
.764 .778 .864 r
.5602 .42039 .56106 .42132 .56269 .42034 .56183 .41932 Mtetra
.702 .745 .885 r
.56183 .41932 .56269 .42034 .56432 .41958 .56346 .41861 Mtetra
.511 .683 .944 r
.56346 .41861 .56432 .41958 .56596 .41923 .5651 .41858 Mtetra
.868 .424 .052 r
.5651 .41858 .56596 .41923 .56762 .4205 .56679 .422 Mtetra
.962 .681 .453 r
.56679 .422 .56762 .4205 .5693 .42328 .57107 .61758 Mtetra
.566 .347 .542 r
.57107 .61758 .5693 .42328 .57109 .43255 .57291 .62438 Mtetra
.555 .339 .541 r
.57291 .62438 .57109 .43255 .57525 .60343 .57467 .62457 Mtetra
.54 .309 .514 r
.57467 .62457 .57525 .60343 .57443 .43477 .57642 .62386 Mtetra
.553 .337 .54 r
.57642 .62386 .57443 .43477 .57598 .42784 .57815 .62265 Mtetra
.554 .337 .541 r
.57815 .62265 .57598 .42784 .57759 .42444 .5799 .62182 Mtetra
.5799 .62182 .57759 .42444 .57923 .42324 .58165 .62114 Mtetra
.554 .338 .541 r
.58165 .62114 .57923 .42324 .58092 .425 .5834 .62079 Mtetra
.556 .339 .541 r
.5834 .62079 .58092 .425 .58599 .6172 .58518 .62149 Mtetra
.574 .27 .414 r
.58518 .62149 .58599 .6172 .58783 .62167 .58696 .62211 Mtetra
.418 0 0 r
.58696 .62211 .58783 .62167 .58964 .62358 .58873 .62244 Mtetra
.623 .71 .908 r
.58873 .62244 .58964 .62358 .5914 .62347 .59049 .62206 Mtetra
.666 .68 .854 r
.59049 .62206 .5914 .62347 .59316 .62285 .59225 .62144 Mtetra
.688 .69 .846 r
.59225 .62144 .59316 .62285 .59491 .62194 .594 .62069 Mtetra
.689 .715 .869 r
.594 .62069 .59491 .62194 .59667 .62116 .59576 .61997 Mtetra
.694 .727 .876 r
.59576 .61997 .59667 .62116 .59842 .62034 .59752 .61923 Mtetra
.695 .742 .887 r
.59752 .61923 .59842 .62034 .60018 .61953 .59928 .6185 Mtetra
.675 .751 .908 r
.59928 .6185 .60018 .61953 .60194 .61887 .60104 .61787 Mtetra
.669 .756 .915 r
.60104 .61787 .60194 .61887 .6037 .61826 .6028 .61727 Mtetra
.668 .757 .917 r
.6028 .61727 .6037 .61826 .60547 .61768 .60457 .61667 Mtetra
.564 .715 .943 r
.60457 .61667 .60547 .61768 .60724 .61734 .60635 .61647 Mtetra
.643 .776 .944 r
.60635 .61647 .60724 .61734 .60901 .61683 .60812 .61597 Mtetra
.782 .811 .876 r
.60812 .61597 .60901 .61683 .61077 .61588 .60987 .61475 Mtetra
.932 .751 .635 r
.60987 .61475 .61077 .61588 .61248 .61292 .61151 .60915 Mtetra
.966 .686 .452 r
.61151 .60915 .61248 .61292 .6141 .60662 .60818 .41058 Mtetra
.566 .351 .548 r
.60818 .41058 .6141 .60662 .61076 .41375 .60971 .40481 Mtetra
.611 .426 .607 r
.60971 .40481 .61076 .41375 .61237 .41101 .61135 .40341 Mtetra
.586 .415 .618 r
.61135 .40341 .61237 .41101 .61404 .41056 .61302 .40288 Mtetra
.57 .404 .617 r
.61302 .40288 .61404 .41056 .61574 .41107 .6147 .40273 Mtetra
.595 .418 .611 r
.6147 .40273 .61574 .41107 .61739 .40981 .61636 .40189 Mtetra
.59 .416 .615 r
.61636 .40189 .61739 .40981 .61906 .40905 .61802 .40122 Mtetra
.565 .399 .616 r
.61802 .40122 .61906 .40905 .62077 .40988 .61971 .40117 Mtetra
.408 .282 .596 r
.61971 .40117 .62077 .40988 .62822 .60055 .62149 .4044 Mtetra
0 0 .409 r
.62149 .4044 .62822 .60055 .63022 .6073 .62918 .60144 Mtetra
0 0 .487 r
.62918 .60144 .63022 .6073 .63209 .60975 .63119 .60819 Mtetra
.226 .424 .847 r
.63119 .60819 .63209 .60975 .63391 .61046 .63302 .60921 Mtetra
.57 .668 .904 r
.63302 .60921 .63391 .61046 .63571 .61037 .63482 .60904 Mtetra
.691 .705 .858 r
.63482 .60904 .63571 .61037 .63749 .6096 .6366 .60828 Mtetra
.762 .73 .824 r
.6366 .60828 .63749 .6096 .63921 .60702 .63836 .60699 Mtetra
.851 .985 .858 r
.63836 .60699 .63921 .60702 .64084 .60175 .64011 .6053 Mtetra
.289 .006 .298 r
.64011 .6053 .64084 .60175 .63596 .4072 .64185 .60336 Mtetra
.554 .338 .541 r
.64185 .60336 .63596 .4072 .63754 .4038 .64365 .60306 Mtetra
.555 .338 .541 r
.64365 .60306 .63754 .4038 .63925 .404 .64546 .60298 Mtetra
.553 .337 .541 r
.64546 .60298 .63925 .404 .64096 .40397 .64724 .60207 Mtetra
.542 .328 .54 r
.64724 .60207 .64096 .40397 .64247 .39883 .64875 .59383 Mtetra
0 0 .406 r
.64875 .59383 .64247 .39883 .64405 .39525 .64331 .39663 Mtetra
.876 .871 .429 r
.64331 .39663 .64405 .39525 .64567 .39293 .64485 .39224 Mtetra
.818 .846 .87 r
.64485 .39224 .64567 .39293 .64734 .39199 .64651 .39088 Mtetra
.639 .711 .899 r
.64651 .39088 .64734 .39199 .64903 .3916 .6482 .39044 Mtetra
.558 .665 .909 r
.6482 .39044 .64903 .3916 .65073 .39139 .6499 .39032 Mtetra
.64 .72 .906 r
.6499 .39032 .65073 .39139 .65242 .39084 .65159 .38987 Mtetra
.679 .755 .909 r
.65159 .38987 .65242 .39084 .6541 .39013 .65328 .38925 Mtetra
.682 .778 .923 r
.65328 .38925 .6541 .39013 .65578 .38941 .65497 .38862 Mtetra
.694 .803 .933 r
.65497 .38862 .65578 .38941 .65746 .38858 .65666 .38793 Mtetra
.675 .836 .96 r
.65666 .38793 .65746 .38858 .65915 .38788 .65834 .3873 Mtetra
.616 .836 .984 r
.65834 .3873 .65915 .38788 .66085 .38754 .66004 .38683 Mtetra
.549 .774 .982 r
.66004 .38683 .66085 .38754 .6626 .38832 .66175 .38658 Mtetra
.52 .555 .832 r
.66175 .38658 .6626 .38832 .66443 .39081 .66348 .38674 Mtetra
.477 .392 .681 r
.66348 .38674 .66443 .39081 .66676 .40458 .66524 .38769 Mtetra
.426 .27 .565 r
.66524 .38769 .66676 .40458 .67687 .59295 .66721 .39338 Mtetra
.027 0 .427 r
.66721 .39338 .67687 .59295 .67884 .59597 .67782 .59164 Mtetra
.064 .113 .602 r
.67782 .59164 .67884 .59597 .68074 .59725 .67985 .59572 Mtetra
.342 .5 .871 r
.67985 .59572 .68074 .59725 .68258 .59736 .68172 .59642 Mtetra
.629 .763 .943 r
.68172 .59642 .68258 .59736 .6844 .59686 .68354 .59596 Mtetra
.719 .799 .914 r
.68354 .59596 .6844 .59686 .68621 .59614 .68534 .5951 Mtetra
.685 .761 .909 r
.68534 .5951 .68621 .59614 .68803 .59553 .68716 .59441 Mtetra
.655 .733 .907 r
.68716 .59441 .68803 .59553 .68985 .59502 .68898 .59386 Mtetra
.655 .725 .9 r
.68898 .59386 .68985 .59502 .69167 .59451 .6908 .59331 Mtetra
.632 .709 .901 r
.6908 .59331 .69167 .59451 .6935 .5942 .69263 .59286 Mtetra
.633 .685 .881 r
.69263 .59286 .6935 .5942 .69534 .59385 .69446 .59242 Mtetra
.659 .681 .86 r
.69446 .59242 .69534 .59385 .69715 .59314 .69628 .59183 Mtetra
.743 .73 .84 r
.69628 .59183 .69715 .59314 .6989 .59106 .69808 .5907 Mtetra
.849 .938 .882 r
.69808 .5907 .6989 .59106 .70054 .58688 .69985 .58912 Mtetra
.148 0 .143 r
.69985 .58912 .70054 .58688 .70172 .57384 .70161 .58732 Mtetra
.53 .29 .496 r
.70161 .58732 .70172 .57384 .69376 .38754 .70343 .58657 Mtetra
.555 .338 .541 r
.70343 .58657 .69376 .38754 .69551 .38746 .70528 .5864 Mtetra
.554 .337 .541 r
.70528 .5864 .69551 .38746 .69726 .38759 .7071 .5856 Mtetra
.547 .332 .54 r
.7071 .5856 .69726 .38759 .69872 .38204 .70869 .58061 Mtetra
.033 0 .426 r
.70869 .58061 .69872 .38204 .70023 .37772 .69962 .38027 Mtetra
0 0 0 r
.69962 .38027 .70023 .37772 .70183 .37506 .70106 .3746 Mtetra
.896 .897 .82 r
.70106 .3746 .70183 .37506 .70351 .3737 .7027 .37263 Mtetra
.69 .742 .891 r
.7027 .37263 .70351 .3737 .70522 .37307 .70442 .37194 Mtetra
.607 .697 .908 r
.70442 .37194 .70522 .37307 .70695 .37267 .70615 .37163 Mtetra
.624 .724 .918 r
.70615 .37163 .70695 .37267 .70868 .37221 .70788 .37123 Mtetra
.661 .752 .918 r
.70788 .37123 .70868 .37221 .7104 .37166 .70961 .37068 Mtetra
.66 .752 .918 r
.70961 .37068 .7104 .37166 .71213 .37111 .71133 .37013 Mtetra
.662 .754 .918 r
.71133 .37013 .71213 .37111 .71385 .37055 .71306 .36958 Mtetra
.663 .755 .918 r
.71306 .36958 .71385 .37055 .71558 .36999 .71479 .36902 Mtetra
.664 .755 .918 r
.71479 .36902 .71558 .36999 .71731 .36943 .71651 .36845 Mtetra
.664 .754 .918 r
.71651 .36845 .71731 .36943 .71904 .36887 .71824 .36789 Mtetra
.663 .754 .918 r
.71824 .36789 .71904 .36887 .72076 .36831 .71997 .36733 Mtetra
.662 .754 .918 r
.71997 .36733 .72076 .36831 .7225 .36775 .7217 .36677 Mtetra
.662 .753 .918 r
.7217 .36677 .7225 .36775 .72423 .3672 .72344 .36621 Mtetra
.66 .753 .918 r
.72344 .36621 .72423 .3672 .72596 .36664 .72517 .36566 Mtetra
.659 .752 .919 r
.72517 .36566 .72596 .36664 .72769 .3661 .72691 .36512 Mtetra
.658 .753 .92 r
.72691 .36512 .72769 .3661 .72943 .36555 .72864 .36458 Mtetra
.655 .754 .922 r
.72864 .36458 .72943 .36555 .73117 .36501 .73038 .36405 Mtetra
.65 .754 .926 r
.73038 .36405 .73117 .36501 .73291 .36449 .73212 .36354 Mtetra
.635 .75 .931 r
.73212 .36354 .73291 .36449 .73465 .36406 .73387 .36309 Mtetra
.621 .74 .931 r
.73387 .36309 .73465 .36406 .73641 .36371 .73562 .36269 Mtetra
.621 .729 .924 r
.73562 .36269 .73641 .36371 .73816 .36336 .73737 .3623 Mtetra
.632 .724 .914 r
.73737 .3623 .73816 .36336 .73991 .36296 .73912 .36187 Mtetra
.645 .725 .907 r
.73912 .36187 .73991 .36296 .74166 .36246 .74087 .36139 Mtetra
.65 .73 .907 r
.74087 .36139 .74166 .36246 .74341 .36193 .74262 .36088 Mtetra
.652 .735 .911 r
.74262 .36088 .74341 .36193 .74515 .36139 .74437 .36037 Mtetra
.653 .741 .915 r
.74437 .36037 .74515 .36139 .7469 .36085 .74612 .35984 Mtetra
.658 .748 .916 r
.74612 .35984 .7469 .36085 .74865 .36029 .74787 .3593 Mtetra
.668 .756 .916 r
.74787 .3593 .74865 .36029 .75039 .35969 .74961 .35871 Mtetra
.679 .762 .914 r
.74961 .35871 .75039 .35969 .75214 .35904 .75136 .35807 Mtetra
.683 .765 .914 r
.75136 .35807 .75214 .35904 .75388 .35839 .7531 .35741 Mtetra
.731 .782 .893 r
.7531 .35741 .75388 .35839 .75561 .35749 .75483 .35652 Mtetra
.752 .787 .882 r
.75483 .35652 .75561 .35749 .75733 .35648 .75655 .3555 Mtetra
.649 .751 .924 r
.75655 .3555 .75733 .35648 .75908 .35597 .75831 .35499 Mtetra
0 .316 .801 r
.75831 .35499 .75908 .35597 .76097 .3572 .7602 .35623 Mtetra
.945 .588 .209 r
.7602 .35623 .76097 .3572 .76357 .36793 .76285 .36768 Mtetra
.975 .672 .366 r
.76285 .36768 .76357 .36793 .7803 .56583 .77948 .56492 Mtetra
.596 .116 0 r
.77948 .56492 .7803 .56583 .78242 .56851 .7816 .56756 Mtetra
.438 .676 .964 r
.7816 .56756 .78242 .56851 .78435 .56863 .78354 .56767 Mtetra
.729 .799 .907 r
.78354 .56767 .78435 .56863 .78621 .5677 .78539 .56674 Mtetra
.905 .817 .75 r
.78539 .56674 .78621 .5677 .78791 .56489 .7871 .56395 Mtetra
.98 .745 .51 r
.7871 .56395 .78791 .56489 .78895 .55354 .78817 .55293 Mtetra
.978 .681 .375 r
.78817 .55293 .78895 .55354 .77513 .35373 .77437 .35275 Mtetra
.928 .797 .696 r
.77437 .35275 .77513 .35373 .77668 .35034 .77591 .34932 Mtetra
.72 .77 .892 r
.77591 .34932 .77668 .35034 .77842 .34949 .77765 .34847 Mtetra
.59 .717 .932 r
.77765 .34847 .77842 .34949 .78021 .34922 .77944 .34818 Mtetra
.62 .729 .924 r
.77944 .34818 .78021 .34922 .78199 .34883 .78122 .34779 Mtetra
.736 .771 .881 r
.78122 .34779 .78199 .34883 .78373 .34789 .78296 .34684 Mtetra
.641 .734 .917 r
.78296 .34684 .78373 .34789 .78551 .34743 .78474 .34636 Mtetra
.055 .392 .851 r
.78474 .34636 .78551 .34743 .78742 .34858 .78665 .34746 Mtetra
.935 .573 .168 r
.78665 .34746 .78742 .34858 .79033 .36166 .78938 .35843 Mtetra
.976 .672 .341 r
.78938 .35843 .79033 .36166 .80866 .55825 .80783 .55691 Mtetra
0 0 .549 r
.80783 .55691 .80866 .55825 .81082 .56083 .81 .55965 Mtetra
.518 .667 .93 r
.81 .55965 .81082 .56083 .81275 .56063 .81195 .55963 Mtetra
.735 .796 .901 r
.81195 .55963 .81275 .56063 .81461 .5596 .81381 .55865 Mtetra
.879 .827 .792 r
.81381 .55865 .81461 .5596 .81642 .5579 .81557 .55639 Mtetra
.936 .748 .624 r
.81557 .55639 .81642 .5579 .81816 .55553 .81705 .55089 Mtetra
.976 .676 .373 r
.81705 .55089 .81816 .55553 .81976 .55145 .80141 .3492 Mtetra
.566 .351 .547 r
.80141 .3492 .81976 .55145 .80479 .35914 .8027 .34291 Mtetra
.598 .396 .579 r
.8027 .34291 .80479 .35914 .80539 .34511 .80435 .34087 Mtetra
.653 .503 .667 r
.80435 .34087 .80539 .34511 .8069 .34145 .80607 .33958 Mtetra
.688 .634 .789 r
.80607 .33958 .8069 .34145 .80856 .33949 .80783 .33868 Mtetra
.68 .811 .945 r
.80783 .33868 .80856 .33949 .81033 .3387 .8096 .33802 Mtetra
.629 .826 .976 r
.8096 .33802 .81033 .3387 .81212 .33824 .8114 .3375 Mtetra
.625 .807 .97 r
.8114 .3375 .81212 .33824 .81393 .33787 .81319 .33702 Mtetra
.659 .792 .945 r
.81319 .33702 .81393 .33787 .81571 .33727 .81498 .33644 Mtetra
.659 .797 .948 r
.81498 .33644 .81571 .33727 .8175 .33667 .81677 .33585 Mtetra
.668 .805 .949 r
.81677 .33585 .8175 .33667 .81928 .336 .81856 .33523 Mtetra
.688 .824 .948 r
.81856 .33523 .81928 .336 .82105 .33518 .82034 .33453 Mtetra
.654 .843 .973 r
.82034 .33453 .82105 .33518 .82284 .33459 .82213 .33392 Mtetra
.6 .817 .983 r
.82213 .33392 .82284 .33459 .82468 .33456 .82393 .33348 Mtetra
.558 .694 .931 r
.82393 .33348 .82468 .33456 .82667 .33595 .82577 .33331 Mtetra
.521 .483 .754 r
.82577 .33331 .82667 .33595 .82886 .33952 .82765 .33364 Mtetra
.467 .354 .642 r
.82765 .33364 .82886 .33952 .84976 .5364 .82966 .33524 Mtetra
.523 .32 .546 r
.82966 .33524 .84976 .5364 .85241 .54334 .83335 .35412 Mtetra
.108 .027 .474 r
.83335 .35412 .85241 .54334 .8546 .54555 .85363 .5426 Mtetra
.143 .232 .698 r
.85363 .5426 .8546 .54555 .85668 .54646 .85588 .54534 Mtetra
.461 .651 .941 r
.85588 .54534 .85668 .54646 .85868 .54664 .85788 .54548 Mtetra
.649 .735 .912 r
.85788 .54548 .85868 .54664 .86063 .5462 .85982 .54492 Mtetra
.725 .743 .866 r
.85982 .54492 .86063 .5462 .86249 .54498 .86171 .54393 Mtetra
.746 .791 .889 r
.86171 .54393 .86249 .54498 .86418 .54202 .86359 .54286 Mtetra
0 0 0 r
.86359 .54286 .86418 .54202 .86554 .5358 .86541 .54112 Mtetra
.285 .056 .38 r
.86541 .54112 .86554 .5358 .84711 .3356 .86705 .53767 Mtetra
.115 .028 .47 r
.86705 .53767 .84711 .3356 .84841 .33003 .84848 .33686 Mtetra
0 0 .314 r
.84848 .33686 .84841 .33003 .85 .3273 .84941 .32773 Mtetra
.89 .938 .567 r
.84941 .32773 .85 .3273 .8517 .32564 .85097 .32464 Mtetra
.713 .779 .904 r
.85097 .32464 .8517 .32564 .8535 .32502 .85275 .32382 Mtetra
.604 .692 .905 r
.85275 .32382 .8535 .32502 .85534 .32469 .85459 .3235 Mtetra
.557 .669 .913 r
.85459 .3235 .85534 .32469 .85719 .32444 .85646 .32336 Mtetra
.669 .746 .909 r
.85646 .32336 .85719 .32444 .85899 .32374 .85827 .32275 Mtetra
.676 .769 .92 r
.85827 .32275 .85899 .32374 .86079 .32299 .86008 .3221 Mtetra
.68 .793 .935 r
.86008 .3221 .86079 .32299 .86259 .32223 .86189 .32143 Mtetra
.692 .822 .945 r
.86189 .32143 .86259 .32223 .86438 .32135 .86369 .3207 Mtetra
.653 .849 .975 r
.86369 .3207 .86438 .32135 .86619 .32072 .86551 .32008 Mtetra
.589 .825 .989 r
.86551 .32008 .86619 .32072 .86806 .32057 .86735 .31964 Mtetra
.539 .724 .959 r
.86735 .31964 .86806 .32057 .8701 .32195 .86921 .31948 Mtetra
.512 .489 .768 r
.86921 .31948 .8701 .32195 .8724 .32571 .87114 .31984 Mtetra
.472 .359 .644 r
.87114 .31984 .8724 .32571 .89638 .5247 .87321 .3214 Mtetra
.143 .055 .487 r
.87321 .3214 .89638 .5247 .89909 .53095 .89688 .51692 Mtetra
.16 .102 .538 r
.89688 .51692 .89909 .53095 .90135 .53311 .90036 .53003 Mtetra
.181 .252 .701 r
.90036 .53003 .90135 .53311 .90348 .534 .90269 .53277 Mtetra
.504 .651 .924 r
.90269 .53277 .90348 .534 .9055 .53401 .90472 .53281 Mtetra
.663 .735 .904 r
.90472 .53281 .9055 .53401 .90747 .53345 .90668 .53218 Mtetra
.74 .753 .863 r
.90668 .53218 .90747 .53345 .90936 .53228 .90859 .53107 Mtetra
.729 .762 .879 r
.90859 .53107 .90936 .53228 .91109 .52965 .9105 .53006 Mtetra
.493 .848 .592 r
.9105 .53006 .91109 .52965 .91257 .52489 .91236 .52854 Mtetra
.267 .007 .321 r
.91236 .52854 .91257 .52489 .89153 .32674 .9141 .52601 Mtetra
.96 .908 .544 r
.28194 .70943 .28317 .70725 .2854 .69702 .28384 .70416 Mtetra
.946 .697 .528 r
.28384 .70416 .2854 .69702 .29973 .50783 .29862 .50921 Mtetra
.992 .856 .604 r
.29862 .50921 .29973 .50783 .30144 .50399 .30049 .50314 Mtetra
.781 .767 .84 r
.30049 .50314 .30144 .50399 .30296 .50298 .30202 .50197 Mtetra
.65 .714 .894 r
.30202 .50197 .30296 .50298 .30445 .50253 .3035 .50154 Mtetra
.537 .679 .93 r
.3035 .50154 .30445 .50253 .30592 .50234 .30496 .50147 Mtetra
.753 .763 .861 r
.30496 .50147 .30592 .50234 .30744 .50129 .30648 .50052 Mtetra
.701 .778 .911 r
.30648 .50052 .30744 .50129 .30895 .50056 .30798 .49988 Mtetra
.426 .714 .984 r
.30798 .49988 .30895 .50056 .31041 .50049 .30944 .49991 Mtetra
.918 .544 .296 r
.30944 .49991 .31041 .50049 .31163 .50425 .31064 .50394 Mtetra
.938 .682 .523 r
.31064 .50394 .31163 .50425 .30072 .69856 .29968 .69819 Mtetra
.917 .57 .363 r
.29968 .69819 .30072 .69856 .30191 .70429 .30089 .70348 Mtetra
0 .339 .781 r
.30089 .70348 .30191 .70429 .30341 .70514 .3024 .70429 Mtetra
.621 .754 .941 r
.3024 .70429 .30341 .70514 .30499 .70478 .30397 .70392 Mtetra
.801 .777 .831 r
.30397 .70392 .30499 .70478 .30663 .70337 .30562 .70251 Mtetra
.906 .741 .666 r
.30562 .70251 .30663 .70337 .30849 .69841 .30748 .69752 Mtetra
.939 .687 .53 r
.30748 .69752 .30849 .69841 .32195 .50334 .32101 .50237 Mtetra
.91 .723 .636 r
.32101 .50237 .32195 .50334 .32381 .49692 .32287 .49601 Mtetra
.791 .758 .823 r
.32287 .49601 .32381 .49692 .32536 .49561 .32442 .4947 Mtetra
.639 .734 .917 r
.32442 .4947 .32536 .49561 .32686 .4952 .32591 .49431 Mtetra
.497 .686 .951 r
.32591 .49431 .32686 .4952 .32833 .49519 .32738 .4943 Mtetra
.648 .741 .917 r
.32738 .4943 .32833 .49519 .32983 .49466 .32888 .49387 Mtetra
.671 .77 .924 r
.32888 .49387 .32983 .49466 .33134 .4941 .33039 .49335 Mtetra
.677 .78 .927 r
.33039 .49335 .33134 .4941 .33284 .49368 .33189 .49281 Mtetra
.76 .764 .856 r
.33189 .49281 .33284 .49368 .33433 .49343 .33343 .4918 Mtetra
.687 .636 .792 r
.33343 .4918 .33433 .49343 .3358 .49357 .33495 .49104 Mtetra
.584 .513 .74 r
.33495 .49104 .3358 .49357 .33722 .49452 .33643 .4909 Mtetra
0 .003 .543 r
.33643 .4909 .33722 .49452 .33831 .50151 .33773 .49409 Mtetra
.951 .693 .51 r
.33773 .49409 .33831 .50151 .32917 .69226 .32835 .68819 Mtetra
.772 .512 0 r
.32835 .68819 .32917 .69226 .33055 .69585 .32955 .69482 Mtetra
0 .223 .719 r
.32955 .69482 .33055 .69585 .33207 .69668 .33106 .69595 Mtetra
.57 .767 .971 r
.33106 .69595 .33207 .69668 .33366 .69643 .33265 .69569 Mtetra
.798 .803 .856 r
.33265 .69569 .33366 .69643 .33531 .69523 .3343 .6944 Mtetra
.905 .75 .679 r
.3343 .6944 .33531 .69523 .33712 .69083 .33612 .68996 Mtetra
.942 .688 .524 r
.33612 .68996 .33712 .69083 .34903 .49591 .34809 .49495 Mtetra
.919 .721 .62 r
.34809 .49495 .34903 .49591 .35091 .48843 .34997 .4875 Mtetra
.816 .759 .8 r
.34997 .4875 .35091 .48843 .35248 .48682 .35154 .4859 Mtetra
.651 .737 .912 r
.35154 .4859 .35248 .48682 .354 .48636 .35306 .48546 Mtetra
.508 .689 .949 r
.35306 .48546 .354 .48636 .35549 .48633 .35455 .48543 Mtetra
.63 .735 .923 r
.35455 .48543 .35549 .48633 .357 .48587 .35606 .48506 Mtetra
.67 .767 .923 r
.35606 .48506 .357 .48587 .35852 .4853 .35758 .48454 Mtetra
.676 .78 .928 r
.35758 .48454 .35852 .4853 .36004 .48486 .3591 .484 Mtetra
.755 .769 .864 r
.3591 .484 .36004 .48486 .36155 .48458 .36065 .48303 Mtetra
.697 .649 .798 r
.36065 .48303 .36155 .48458 .36304 .48467 .36218 .48221 Mtetra
.597 .525 .745 r
.36218 .48221 .36304 .48467 .3645 .48549 .36369 .48198 Mtetra
.069 .122 .611 r
.36369 .48198 .3645 .48549 .36573 .49098 .36506 .48462 Mtetra
.953 .692 .503 r
.36506 .48462 .36573 .49098 .35809 .68323 .35731 .67794 Mtetra
.701 .488 0 r
.35731 .67794 .35809 .68323 .35949 .68725 .35851 .68609 Mtetra
0 .14 .662 r
.35851 .68609 .35949 .68725 .36104 .68827 .36004 .68746 Mtetra
.56 .747 .965 r
.36004 .68746 .36104 .68827 .36265 .68808 .36165 .68725 Mtetra
.781 .789 .859 r
.36165 .68725 .36265 .68808 .3643 .68693 .3633 .68605 Mtetra
.893 .759 .707 r
.3633 .68605 .3643 .68693 .36609 .6827 .36506 .68252 Mtetra
.946 .69 .517 r
.36506 .68252 .36609 .6827 .37647 .48689 .37497 .49856 Mtetra
.719 .657 .104 r
.37497 .49856 .37647 .48689 .37831 .47931 .37731 .48015 Mtetra
.88 .979 .686 r
.37731 .48015 .37831 .47931 .3799 .47754 .37892 .47776 Mtetra
.614 .957 .868 r
.37892 .47776 .3799 .47754 .38143 .47714 .38047 .47686 Mtetra
.571 .88 .992 r
.38047 .47686 .38143 .47714 .38293 .4772 .382 .47642 Mtetra
.643 .767 .938 r
.382 .47642 .38293 .4772 .38445 .47701 .38353 .47598 Mtetra
.648 .714 .896 r
.38353 .47598 .38445 .47701 .38598 .47658 .38506 .47555 Mtetra
.64 .71 .898 r
.38506 .47555 .38598 .47658 .38752 .4761 .38659 .47515 Mtetra
.661 .735 .905 r
.38659 .47515 .38752 .4761 .38906 .47541 .38813 .47466 Mtetra
.677 .786 .932 r
.38813 .47466 .38906 .47541 .3906 .47467 .38967 .4741 Mtetra
.677 .833 .958 r
.38967 .4741 .3906 .47467 .39215 .47407 .39121 .47352 Mtetra
.754 .846 .92 r
.39121 .47352 .39215 .47407 .39368 .47375 .39276 .47263 Mtetra
.721 .72 .848 r
.39276 .47263 .39368 .47375 .39519 .47383 .39431 .4718 Mtetra
.617 .568 .776 r
.39431 .4718 .39519 .47383 .39668 .47463 .39585 .47146 Mtetra
.289 .291 .689 r
.39585 .47146 .39668 .47463 .39803 .47903 .3973 .47309 Mtetra
0 0 .107 r
.3973 .47309 .39803 .47903 .39221 .67267 .39847 .48232 Mtetra
0 0 .304 r
.39847 .48232 .39221 .67267 .39365 .67724 .39277 .67381 Mtetra
.186 .22 .663 r
.39277 .67381 .39365 .67724 .39524 .67806 .3943 .67601 Mtetra
.533 .533 .801 r
.3943 .67601 .39524 .67806 .39689 .67749 .39592 .67615 Mtetra
.641 .67 .862 r
.39592 .67615 .39689 .67749 .39855 .67645 .39756 .67571 Mtetra
.666 .797 .945 r
.39756 .67571 .39855 .67645 .4002 .67555 .3992 .67515 Mtetra
.647 .878 .983 r
.3992 .67515 .4002 .67555 .40185 .6749 .40085 .67455 Mtetra
.672 .898 .977 r
.40085 .67455 .40185 .6749 .4035 .67427 .4025 .67387 Mtetra
.672 .884 .977 r
.4025 .67387 .4035 .67427 .40514 .67368 .40415 .6732 Mtetra
.666 .864 .975 r
.40415 .6732 .40514 .67368 .40679 .67313 .4058 .67258 Mtetra
.67 .848 .968 r
.4058 .67258 .40679 .67313 .40844 .6726 .40745 .67197 Mtetra
.545 .792 .99 r
.40745 .67197 .40844 .6726 .41007 .67238 .40909 .67171 Mtetra
.533 .777 .987 r
.40909 .67171 .41007 .67238 .41171 .67219 .41073 .6715 Mtetra
.724 .822 .925 r
.41073 .6715 .41171 .67219 .41337 .67144 .41239 .67069 Mtetra
.903 .781 .716 r
.41239 .67069 .41337 .67144 .4151 .66829 .41413 .66731 Mtetra
.95 .689 .506 r
.41413 .66731 .4151 .66829 .42261 .47875 .42182 .4738 Mtetra
.834 .611 .601 r
.42182 .4738 .42261 .47875 .42453 .46637 .42365 .46444 Mtetra
.803 .661 .707 r
.42365 .46444 .42453 .46637 .42615 .46403 .42527 .46191 Mtetra
.692 .6 .748 r
.42527 .46191 .42615 .46403 .4277 .46357 .42684 .46091 Mtetra
.633 .537 .727 r
.42684 .46091 .4277 .46357 .42925 .46364 .4284 .46034 Mtetra
.611 .497 .698 r
.4284 .46034 .42925 .46364 .43079 .46359 .42996 .45988 Mtetra
.606 .481 .684 r
.42996 .45988 .43079 .46359 .43235 .46319 .43152 .45944 Mtetra
.6 .476 .683 r
.43152 .45944 .43235 .46319 .43391 .46276 .43308 .45907 Mtetra
.619 .49 .683 r
.43308 .45907 .43391 .46276 .43548 .46202 .43464 .45846 Mtetra
.63 .501 .686 r
.43464 .45846 .43548 .46202 .43705 .4612 .43621 .45775 Mtetra
.597 .483 .694 r
.43621 .45775 .43705 .4612 .43861 .46098 .43777 .45743 Mtetra
.406 .354 .688 r
.43777 .45743 .43861 .46098 .4401 .46343 .43929 .45866 Mtetra
0 0 .284 r
.43929 .45866 .4401 .46343 .43673 .65757 .44067 .46519 Mtetra
0 0 .324 r
.44067 .46519 .43673 .65757 .43822 .66406 .43733 .66023 Mtetra
.138 .17 .632 r
.43733 .66023 .43822 .66406 .43983 .66562 .43891 .66298 Mtetra
.585 .519 .747 r
.43891 .66298 .43983 .66562 .44149 .66546 .44057 .66282 Mtetra
.658 .561 .733 r
.44057 .66282 .44149 .66546 .44316 .66486 .44225 .662 Mtetra
.658 .55 .721 r
.44225 .662 .44316 .66486 .44484 .66422 .44392 .66111 Mtetra
.627 .521 .714 r
.44392 .66111 .44484 .66422 .4465 .66374 .4456 .66052 Mtetra
.618 .511 .71 r
.4456 .66052 .4465 .66374 .44818 .66321 .44727 .66 Mtetra
.589 .494 .714 r
.44727 .66 .44818 .66321 .44985 .66269 .44893 .65978 Mtetra
.557 .488 .733 r
.44893 .65978 .44985 .66269 .45152 .66217 .45059 .65985 Mtetra
.558 .525 .774 r
.45059 .65985 .45152 .66217 .4532 .66151 .45225 .65988 Mtetra
.593 .611 .839 r
.45225 .65988 .4532 .66151 .45488 .66046 .45392 .65967 Mtetra
.643 .784 .949 r
.45392 .65967 .45488 .66046 .45658 .65885 .4556 .65919 Mtetra
0 0 0 r
.4556 .65919 .45658 .65885 .45828 .65696 .45728 .65863 Mtetra
.339 0 .126 r
.45728 .65863 .45828 .65696 .45998 .65539 .45896 .65808 Mtetra
.441 .103 .295 r
.45896 .65808 .45998 .65539 .46166 .65474 .46064 .65759 Mtetra
.45 .118 .31 r
.46064 .65759 .46166 .65474 .46333 .65443 .46232 .65712 Mtetra
.444 .105 .295 r
.46232 .65712 .46333 .65443 .46501 .65414 .464 .65665 Mtetra
.435 .088 .277 r
.464 .65665 .46501 .65414 .46669 .6537 .46568 .65618 Mtetra
.435 .088 .275 r
.46568 .65618 .46669 .6537 .46837 .65327 .46736 .65573 Mtetra
.436 .087 .274 r
.46736 .65573 .46837 .65327 .47005 .65285 .46904 .65528 Mtetra
.437 .087 .271 r
.46904 .65528 .47005 .65285 .47173 .65245 .47073 .65485 Mtetra
.435 .083 .268 r
.47073 .65485 .47173 .65245 .47341 .65204 .47241 .65442 Mtetra
.462 .107 .278 r
.47241 .65442 .47341 .65204 .47509 .65189 .4741 .65415 Mtetra
.484 .123 .277 r
.4741 .65415 .47509 .65189 .47677 .65199 .47578 .65405 Mtetra
.384 .013 .206 r
.47578 .65405 .47677 .65199 .47846 .65139 .47747 .65348 Mtetra
0 0 0 r
.47747 .65348 .47846 .65139 .48018 .64838 .47918 .65147 Mtetra
.892 .826 .357 r
.47918 .65147 .48018 .64838 .48429 .45303 .48096 .64408 Mtetra
0 0 .329 r
.48096 .64408 .48429 .45303 .48597 .44527 .48504 .44711 Mtetra
.807 .857 .405 r
.48504 .44711 .48597 .44527 .48758 .44264 .48668 .44311 Mtetra
.359 .8 .643 r
.48668 .44311 .48758 .44264 .48918 .44187 .48828 .44224 Mtetra
.071 0 0 r
.48828 .44224 .48918 .44187 .49077 .44154 .48987 .442 Mtetra
.225 0 0 r
.48987 .442 .49077 .44154 .49236 .44131 .49146 .4419 Mtetra
.055 0 0 r
.49146 .4419 .49236 .44131 .49396 .44084 .49306 .44145 Mtetra
.082 0 0 r
.49306 .44145 .49396 .44084 .49555 .44037 .49465 .44101 Mtetra
.118 0 0 r
.49465 .44101 .49555 .44037 .49715 .4399 .49625 .44061 Mtetra
.167 0 0 r
.49625 .44061 .49715 .4399 .49875 .43943 .49785 .44023 Mtetra
.209 0 0 r
.49785 .44023 .49875 .43943 .50035 .43896 .49945 .43986 Mtetra
.234 0 0 r
.49945 .43986 .50035 .43896 .50195 .43849 .50105 .43946 Mtetra
.236 0 0 r
.50105 .43946 .50195 .43849 .50355 .43801 .50265 .43902 Mtetra
.237 0 0 r
.50265 .43902 .50355 .43801 .50515 .43752 .50426 .43855 Mtetra
.238 0 0 r
.50426 .43855 .50515 .43752 .50675 .43703 .50586 .43807 Mtetra
.241 0 0 r
.50586 .43807 .50675 .43703 .50836 .43653 .50747 .43759 Mtetra
.243 0 0 r
.50747 .43759 .50836 .43653 .50996 .43603 .50907 .4371 Mtetra
.244 0 0 r
.50907 .4371 .50996 .43603 .51157 .43553 .51068 .4366 Mtetra
.245 0 0 r
.51068 .4366 .51157 .43553 .51317 .43502 .51229 .4361 Mtetra
.246 0 0 r
.51229 .4361 .51317 .43502 .51478 .43451 .5139 .4356 Mtetra
.247 0 0 r
.5139 .4356 .51478 .43451 .51639 .434 .51551 .4351 Mtetra
.248 0 0 r
.51551 .4351 .51639 .434 .518 .43349 .51712 .43459 Mtetra
.25 0 0 r
.51712 .43459 .518 .43349 .51961 .43297 .51873 .43408 Mtetra
.252 0 0 r
.51873 .43408 .51961 .43297 .52122 .43246 .52034 .43358 Mtetra
.255 0 0 r
.52034 .43358 .52122 .43246 .52284 .43195 .52196 .43307 Mtetra
.259 0 0 r
.52196 .43307 .52284 .43195 .52445 .43144 .52357 .43257 Mtetra
.265 0 0 r
.52357 .43257 .52445 .43144 .52606 .43094 .52519 .43208 Mtetra
.273 0 0 r
.52519 .43208 .52606 .43094 .52768 .43044 .52681 .4316 Mtetra
.283 0 .004 r
.52681 .4316 .52768 .43044 .5293 .42995 .52843 .43114 Mtetra
.303 0 .022 r
.52843 .43114 .5293 .42995 .53091 .42948 .53004 .43071 Mtetra
.353 0 .063 r
.53004 .43071 .53091 .42948 .53253 .42902 .53167 .43039 Mtetra
.353 0 .097 r
.53167 .43039 .53253 .42902 .53415 .42857 .53329 .43 Mtetra
.286 0 .072 r
.53329 .43 .53415 .42857 .53577 .42815 .53491 .42938 Mtetra
.007 0 0 r
.53491 .42938 .53577 .42815 .53739 .42777 .53653 .42825 Mtetra
.484 .869 .671 r
.53653 .42825 .53739 .42777 .53902 .42739 .53815 .42714 Mtetra
.743 .938 .95 r
.53815 .42714 .53902 .42739 .54064 .42701 .53977 .4262 Mtetra
.662 .779 .936 r
.53977 .4262 .54064 .42701 .54227 .42659 .5414 .42567 Mtetra
.636 .743 .926 r
.5414 .42567 .54227 .42659 .54389 .42616 .54303 .42524 Mtetra
.625 .743 .932 r
.54303 .42524 .54389 .42616 .54552 .4257 .54465 .42486 Mtetra
.646 .768 .938 r
.54465 .42486 .54552 .4257 .54715 .42522 .54628 .42439 Mtetra
.651 .772 .937 r
.54628 .42439 .54715 .42522 .54878 .42472 .54791 .4239 Mtetra
.66 .777 .936 r
.54791 .4239 .54878 .42472 .55041 .42419 .54954 .42338 Mtetra
.674 .783 .931 r
.54954 .42338 .55041 .42419 .55204 .42363 .55117 .4228 Mtetra
.682 .782 .926 r
.55117 .4228 .55204 .42363 .55367 .42303 .5528 .42219 Mtetra
.69 .78 .92 r
.5528 .42219 .55367 .42303 .5553 .42241 .55444 .42155 Mtetra
.712 .78 .906 r
.55444 .42155 .5553 .42241 .55693 .42176 .55607 .4208 Mtetra
.696 .756 .898 r
.55607 .4208 .55693 .42176 .55856 .42109 .5577 .42012 Mtetra
.669 .745 .907 r
.5577 .42012 .55856 .42109 .5602 .42039 .55934 .41956 Mtetra
.671 .778 .93 r
.55934 .41956 .5602 .42039 .56183 .41932 .56097 .419 Mtetra
.318 .761 .963 r
.56097 .419 .56183 .41932 .56346 .41861 .56261 .41892 Mtetra
.627 .098 0 r
.56261 .41892 .56346 .41861 .5651 .41858 .56427 .41991 Mtetra
.962 .681 .454 r
.56427 .41991 .5651 .41858 .56679 .422 .56828 .60649 Mtetra
.583 .36 .543 r
.56828 .60649 .56679 .422 .57107 .61758 .57025 .62375 Mtetra
.662 .372 .47 r
.57025 .62375 .57107 .61758 .57291 .62438 .57204 .62663 Mtetra
.494 .13 .277 r
.57204 .62663 .57291 .62438 .57467 .62457 .5738 .6266 Mtetra
.372 .001 .199 r
.5738 .6266 .57467 .62457 .57642 .62386 .57555 .62597 Mtetra
.31 0 .182 r
.57555 .62597 .57642 .62386 .57815 .62265 .5773 .62503 Mtetra
.413 .061 .256 r
.5773 .62503 .57815 .62265 .5799 .62182 .57905 .62446 Mtetra
.426 .087 .284 r
.57905 .62446 .5799 .62182 .58165 .62114 .5808 .62388 Mtetra
.429 .094 .293 r
.5808 .62388 .58165 .62114 .5834 .62079 .58256 .62328 Mtetra
.411 .065 .265 r
.58256 .62328 .5834 .62079 .58518 .62149 .58431 .62265 Mtetra
.218 0 0 r
.58431 .62265 .58518 .62149 .58696 .62211 .58606 .62202 Mtetra
.521 .908 .938 r
.58606 .62202 .58696 .62211 .58873 .62244 .58782 .62139 Mtetra
.671 .744 .905 r
.58782 .62139 .58873 .62244 .59049 .62206 .58958 .62078 Mtetra
.667 .702 .873 r
.58958 .62078 .59049 .62206 .59225 .62144 .59134 .62018 Mtetra
.667 .704 .874 r
.59134 .62018 .59225 .62144 .594 .62069 .5931 .61957 Mtetra
.671 .731 .895 r
.5931 .61957 .594 .62069 .59576 .61997 .59486 .61896 Mtetra
.673 .754 .912 r
.59486 .61896 .59576 .61997 .59752 .61923 .59662 .61835 Mtetra
.674 .782 .931 r
.59662 .61835 .59752 .61923 .59928 .6185 .59838 .61772 Mtetra
.675 .808 .947 r
.59838 .61772 .59928 .6185 .60104 .61787 .60014 .61708 Mtetra
.679 .807 .944 r
.60014 .61708 .60104 .61787 .6028 .61727 .60191 .61643 Mtetra
.683 .795 .934 r
.60191 .61643 .6028 .61727 .60457 .61667 .60367 .61576 Mtetra
.548 .731 .96 r
.60367 .61576 .60457 .61667 .60635 .61647 .60545 .61558 Mtetra
.644 .771 .94 r
.60545 .61558 .60635 .61647 .60812 .61597 .60722 .61507 Mtetra
.789 .805 .866 r
.60722 .61507 .60812 .61597 .60987 .61475 .60897 .61378 Mtetra
.947 .756 .612 r
.60897 .61378 .60987 .61475 .61151 .60915 .61059 .60727 Mtetra
.968 .688 .449 r
.61059 .60727 .61151 .60915 .60818 .41058 .60729 .40797 Mtetra
.854 .658 .637 r
.60729 .40797 .60818 .41058 .60971 .40481 .60884 .4029 Mtetra
.734 .642 .757 r
.60884 .4029 .60971 .40481 .61135 .40341 .61049 .40155 Mtetra
.645 .606 .795 r
.61049 .40155 .61135 .40341 .61302 .40288 .61215 .40102 Mtetra
.592 .577 .806 r
.61215 .40102 .61302 .40288 .6147 .40273 .61383 .40082 Mtetra
.683 .619 .778 r
.61383 .40082 .6147 .40273 .61636 .40189 .61549 .39998 Mtetra
.662 .61 .785 r
.61549 .39998 .61636 .40189 .61802 .40122 .61716 .3993 Mtetra
.579 .565 .803 r
.61716 .3993 .61802 .40122 .61971 .40117 .61884 .39919 Mtetra
0 .007 .583 r
.61884 .39919 .61971 .40117 .62149 .4044 .62061 .40189 Mtetra
.972 .685 .424 r
.62061 .40189 .62149 .4044 .62918 .60144 .6282 .59717 Mtetra
.747 .477 0 r
.6282 .59717 .62918 .60144 .63119 .60819 .63029 .60691 Mtetra
.152 .429 .867 r
.63029 .60691 .63119 .60819 .63302 .60921 .63212 .60787 Mtetra
.608 .671 .885 r
.63212 .60787 .63302 .60921 .63482 .60904 .63392 .60756 Mtetra
.688 .681 .839 r
.63392 .60756 .63482 .60904 .6366 .60828 .6357 .60678 Mtetra
.632 .656 .856 r
.6357 .60678 .6366 .60828 .63836 .60699 .63749 .60635 Mtetra
.568 .811 .99 r
.63749 .60635 .63836 .60699 .64011 .6053 .63928 .60599 Mtetra
.169 0 0 r
.63928 .60599 .64011 .6053 .64185 .60336 .64108 .60561 Mtetra
.499 .133 .276 r
.64108 .60561 .64185 .60336 .64365 .60306 .64289 .60561 Mtetra
.476 .128 .296 r
.64289 .60561 .64365 .60306 .64546 .60298 .6447 .60538 Mtetra
.362 .018 .24 r
.6447 .60538 .64546 .60298 .64724 .60207 .64648 .6045 Mtetra
0 0 0 r
.64648 .6045 .64724 .60207 .64875 .59383 .64815 .60059 Mtetra
.979 .697 .417 r
.64815 .60059 .64875 .59383 .64331 .39663 .64278 .40379 Mtetra
0 0 .147 r
.64278 .40379 .64331 .39663 .64485 .39224 .64409 .39301 Mtetra
.726 .916 .559 r
.64409 .39301 .64485 .39224 .64651 .39088 .64571 .39076 Mtetra
.707 .969 .933 r
.64571 .39076 .64651 .39088 .6482 .39044 .64738 .38978 Mtetra
.652 .825 .966 r
.64738 .38978 .6482 .39044 .6499 .39032 .64907 .38923 Mtetra
.654 .722 .899 r
.64907 .38923 .6499 .39032 .65159 .38987 .65076 .38872 Mtetra
.643 .706 .892 r
.65076 .38872 .65159 .38987 .65328 .38925 .65246 .38826 Mtetra
.629 .733 .923 r
.65246 .38826 .65328 .38925 .65497 .38862 .65416 .38785 Mtetra
.646 .794 .953 r
.65416 .38785 .65497 .38862 .65666 .38793 .65585 .38734 Mtetra
.649 .844 .975 r
.65585 .38734 .65666 .38793 .65834 .3873 .65754 .38678 Mtetra
.646 .862 .981 r
.65754 .38678 .65834 .3873 .66004 .38683 .65924 .3862 Mtetra
.744 .857 .932 r
.65924 .3862 .66004 .38683 .66175 .38658 .66092 .38529 Mtetra
.702 .704 .849 r
.66092 .38529 .66175 .38658 .66348 .38674 .6626 .38449 Mtetra
.602 .551 .77 r
.6626 .38449 .66348 .38674 .66524 .38769 .66431 .38422 Mtetra
.287 .286 .684 r
.66431 .38422 .66524 .38769 .66721 .39338 .66613 .3863 Mtetra
.978 .687 .391 r
.66613 .3863 .66721 .39338 .67782 .59164 .67621 .57378 Mtetra
0 0 .453 r
.67621 .57378 .67782 .59164 .67985 .59572 .67888 .59245 Mtetra
.391 .373 .719 r
.67888 .59245 .67985 .59572 .68172 .59642 .68078 .5938 Mtetra
.621 .547 .751 r
.68078 .5938 .68172 .59642 .68354 .59596 .6826 .59333 Mtetra
.668 .573 .739 r
.6826 .59333 .68354 .59596 .68534 .5951 .6844 .59238 Mtetra
.605 .532 .746 r
.6844 .59238 .68534 .5951 .68716 .59441 .68623 .59204 Mtetra
.558 .528 .778 r
.68623 .59204 .68716 .59441 .68898 .59386 .68808 .59206 Mtetra
.559 .583 .835 r
.68808 .59206 .68898 .59386 .6908 .59331 .68992 .59202 Mtetra
.605 .681 .896 r
.68992 .59202 .6908 .59331 .69263 .59286 .69176 .59171 Mtetra
.644 .722 .905 r
.69176 .59171 .69263 .59286 .69446 .59242 .69358 .59121 Mtetra
.655 .716 .893 r
.69358 .59121 .69446 .59242 .69628 .59183 .69541 .59065 Mtetra
.64 .717 .904 r
.69541 .59065 .69628 .59183 .69808 .5907 .69724 .59017 Mtetra
.57 .844 .996 r
.69724 .59017 .69808 .5907 .69985 .58912 .69907 .58973 Mtetra
.106 0 0 r
.69907 .58973 .69985 .58912 .70161 .58732 .70091 .58928 Mtetra
.448 .066 .221 r
.70091 .58928 .70161 .58732 .70343 .58657 .70276 .58905 Mtetra
.461 .11 .283 r
.70276 .58905 .70343 .58657 .70528 .5864 .7046 .58873 Mtetra
.365 .017 .235 r
.7046 .58873 .70528 .5864 .7071 .5856 .70642 .58788 Mtetra
0 0 .013 r
.70642 .58788 .7071 .5856 .70869 .58061 .70812 .5848 Mtetra
.846 .721 .194 r
.70812 .5848 .70869 .58061 .69962 .38027 .70931 .57237 Mtetra
.022 0 .422 r
.70931 .57237 .69962 .38027 .70106 .3746 .70038 .37578 Mtetra
0 0 0 r
.70038 .37578 .70106 .3746 .7027 .37263 .70198 .37302 Mtetra
.70198 .37302 .7027 .37263 .70442 .37194 .70369 .37227 Mtetra
.095 0 0 r
.70369 .37227 .70442 .37194 .70615 .37163 .70543 .37207 Mtetra
.092 0 0 r
.70543 .37207 .70615 .37163 .70788 .37123 .70717 .37175 Mtetra
0 0 0 r
.70717 .37175 .70788 .37123 .70961 .37068 .7089 .3712 Mtetra
.004 0 0 r
.7089 .3712 .70961 .37068 .71133 .37013 .71062 .37065 Mtetra
0 0 0 r
.71062 .37065 .71133 .37013 .71306 .36958 .71235 .3701 Mtetra
.71235 .3701 .71306 .36958 .71479 .36902 .71408 .36953 Mtetra
.71408 .36953 .71479 .36902 .71651 .36845 .71581 .36896 Mtetra
.71581 .36896 .71651 .36845 .71824 .36789 .71754 .36839 Mtetra
.71754 .36839 .71824 .36789 .71997 .36733 .71927 .36783 Mtetra
.71927 .36783 .71997 .36733 .7217 .36677 .721 .36727 Mtetra
.721 .36727 .7217 .36677 .72344 .36621 .72274 .36671 Mtetra
.72274 .36671 .72344 .36621 .72517 .36566 .72447 .36617 Mtetra
.006 0 0 r
.72447 .36617 .72517 .36566 .72691 .36512 .72621 .36563 Mtetra
.044 0 0 r
.72621 .36563 .72691 .36512 .72864 .36458 .72795 .36515 Mtetra
.095 0 0 r
.72795 .36515 .72864 .36458 .73038 .36405 .7297 .3647 Mtetra
.092 0 0 r
.7297 .3647 .73038 .36405 .73212 .36354 .73144 .36416 Mtetra
0 0 0 r
.73144 .36416 .73212 .36354 .73387 .36309 .73316 .36334 Mtetra
.495 .891 .738 r
.73316 .36334 .73387 .36309 .73562 .36269 .73487 .36231 Mtetra
.746 .931 .949 r
.73487 .36231 .73562 .36269 .73737 .3623 .73659 .36131 Mtetra
.706 .769 .901 r
.73659 .36131 .73737 .3623 .73912 .36187 .73832 .36054 Mtetra
.653 .684 .867 r
.73832 .36054 .73912 .36187 .74087 .36139 .74006 .36002 Mtetra
.636 .669 .865 r
.74006 .36002 .74087 .36139 .74262 .36088 .74182 .35957 Mtetra
.633 .679 .875 r
.74182 .35957 .74262 .36088 .74437 .36037 .74357 .35914 Mtetra
.638 .696 .888 r
.74357 .35914 .74437 .36037 .74612 .35984 .74533 .35869 Mtetra
.642 .712 .898 r
.74533 .35869 .74612 .35984 .74787 .3593 .74708 .35822 Mtetra
.657 .734 .906 r
.74708 .35822 .74787 .3593 .74961 .35871 .74883 .35769 Mtetra
.674 .752 .909 r
.74883 .35769 .74961 .35871 .75136 .35807 .75058 .35707 Mtetra
.681 .758 .91 r
.75058 .35707 .75136 .35807 .7531 .35741 .75233 .35642 Mtetra
.73 .776 .89 r
.75233 .35642 .7531 .35741 .75483 .35652 .75405 .35552 Mtetra
.751 .782 .878 r
.75405 .35552 .75483 .35652 .75655 .3555 .75577 .3545 Mtetra
.649 .747 .921 r
.75577 .3545 .75655 .3555 .75831 .35499 .75753 .35398 Mtetra
0 .313 .8 r
.75753 .35398 .75831 .35499 .7602 .35623 .75942 .35525 Mtetra
.948 .594 .218 r
.75942 .35525 .7602 .35623 .76285 .36768 .76213 .36737 Mtetra
.975 .672 .366 r
.76213 .36737 .76285 .36768 .77948 .56492 .77867 .56398 Mtetra
.581 .104 0 r
.77867 .56398 .77948 .56492 .7816 .56756 .78079 .56659 Mtetra
.442 .675 .962 r
.78079 .56659 .7816 .56756 .78354 .56767 .78272 .5667 Mtetra
.728 .796 .906 r
.78272 .5667 .78354 .56767 .78539 .56674 .78458 .56577 Mtetra
.903 .816 .751 r
.78458 .56577 .78539 .56674 .7871 .56395 .78629 .56299 Mtetra
.979 .746 .513 r
.78629 .56299 .7871 .56395 .78817 .55293 .78738 .55222 Mtetra
.978 .681 .375 r
.78738 .55222 .78817 .55293 .77437 .35275 .7736 .35175 Mtetra
.927 .795 .694 r
.7736 .35175 .77437 .35275 .77591 .34932 .77514 .34829 Mtetra
.721 .769 .891 r
.77514 .34829 .77591 .34932 .77765 .34847 .77688 .34743 Mtetra
.592 .717 .93 r
.77688 .34743 .77765 .34847 .77944 .34818 .77867 .34714 Mtetra
.621 .728 .923 r
.77867 .34714 .77944 .34818 .78122 .34779 .78045 .34674 Mtetra
.736 .77 .881 r
.78045 .34674 .78122 .34779 .78296 .34684 .78219 .34579 Mtetra
.643 .736 .916 r
.78219 .34579 .78296 .34684 .78474 .34636 .78397 .3453 Mtetra
.085 .414 .863 r
.78397 .3453 .78474 .34636 .78665 .34746 .78587 .34632 Mtetra
.92 .548 .125 r
.78587 .34632 .78665 .34746 .78938 .35843 .78846 .35553 Mtetra
.976 .671 .342 r
.78846 .35553 .78938 .35843 .80783 .55691 .80698 .55543 Mtetra
0 0 .544 r
.80698 .55543 .80783 .55691 .81 .55965 .80917 .55838 Mtetra
.475 .625 .917 r
.80917 .55838 .81 .55965 .81195 .55963 .81113 .55854 Mtetra
.719 .772 .894 r
.81113 .55854 .81195 .55963 .81381 .55865 .81301 .55764 Mtetra
.895 .815 .761 r
.81301 .55764 .81381 .55865 .81557 .55639 .81474 .55501 Mtetra
.972 .735 .522 r
.81474 .55501 .81557 .55639 .81705 .55089 .81579 .54458 Mtetra
.975 .674 .377 r
.81579 .54458 .81705 .55089 .80141 .3492 .80021 .34303 Mtetra
.714 .514 .618 r
.80021 .34303 .80141 .3492 .8027 .34291 .80172 .33933 Mtetra
.642 .513 .691 r
.80172 .33933 .8027 .34291 .80435 .34087 .80347 .3384 Mtetra
.602 .54 .757 r
.80347 .3384 .80435 .34087 .80607 .33958 .80527 .33809 Mtetra
.542 .608 .869 r
.80527 .33809 .80607 .33958 .80783 .33868 .80711 .33809 Mtetra
.427 .758 .995 r
.80711 .33809 .80783 .33868 .8096 .33802 .80894 .33802 Mtetra
.052 .619 .733 r
.80894 .33802 .8096 .33802 .8114 .3375 .81078 .33794 Mtetra
.071 0 0 r
.81078 .33794 .8114 .3375 .81319 .33702 .81258 .33756 Mtetra
0 0 0 r
.81258 .33756 .81319 .33702 .81498 .33644 .81433 .3365 Mtetra
.627 .961 .837 r
.81433 .3365 .81498 .33644 .81677 .33585 .81607 .33538 Mtetra
.743 .916 .951 r
.81607 .33538 .81677 .33585 .81856 .33523 .81782 .3344 Mtetra
.671 .8 .944 r
.81782 .3344 .81856 .33523 .82034 .33453 .81961 .33377 Mtetra
.647 .811 .962 r
.81961 .33377 .82034 .33453 .82213 .33392 .82141 .33321 Mtetra
.674 .836 .961 r
.82141 .33321 .82213 .33392 .82393 .33348 .82319 .33255 Mtetra
.759 .806 .89 r
.82319 .33255 .82393 .33348 .82577 .33331 .82495 .33148 Mtetra
.66 .625 .804 r
.82495 .33148 .82577 .33331 .82765 .33364 .82673 .33082 Mtetra
.518 .47 .742 r
.82673 .33082 .82765 .33364 .82966 .33524 .82862 .3312 Mtetra
0 .07 .587 r
.82862 .3312 .82966 .33524 .83335 .35412 .83095 .33605 Mtetra
.963 .665 .248 r
.83095 .33605 .83335 .35412 .85363 .5426 .85267 .53977 Mtetra
0 0 .562 r
.85267 .53977 .85363 .5426 .85588 .54534 .85509 .54423 Mtetra
.49 .669 .943 r
.85509 .54423 .85588 .54534 .85788 .54548 .85708 .54427 Mtetra
.681 .738 .894 r
.85708 .54427 .85788 .54548 .85982 .54492 .859 .54356 Mtetra
.707 .721 .861 r
.859 .54356 .85982 .54492 .86171 .54393 .8609 .54265 Mtetra
.532 .657 .915 r
.8609 .54265 .86171 .54393 .86359 .54286 .86289 .54261 Mtetra
.453 .864 .956 r
.86289 .54261 .86359 .54286 .86541 .54112 .86483 .54213 Mtetra
0 0 0 r
.86483 .54213 .86541 .54112 .86705 .53767 .86668 .54061 Mtetra
0 0 .034 r
.86668 .54061 .86705 .53767 .84848 .33686 .86805 .53448 Mtetra
.093 .013 .464 r
.86805 .53448 .84848 .33686 .84941 .32773 .84908 .33061 Mtetra
0 0 .068 r
.84908 .33061 .84941 .32773 .85097 .32464 .85038 .32498 Mtetra
.587 .906 .65 r
.85038 .32498 .85097 .32464 .85275 .32382 .85209 .32347 Mtetra
.671 .934 .968 r
.85209 .32347 .85275 .32382 .85459 .3235 .85388 .32264 Mtetra
.635 .784 .953 r
.85388 .32264 .85459 .3235 .85646 .32336 .85571 .32214 Mtetra
.653 .709 .889 r
.85571 .32214 .85646 .32336 .85827 .32275 .85753 .3216 Mtetra
.633 .715 .906 r
.85753 .3216 .85827 .32275 .86008 .3221 .85936 .32114 Mtetra
.623 .755 .941 r
.85936 .32114 .86008 .3221 .86189 .32143 .86119 .32071 Mtetra
.647 .825 .969 r
.86119 .32071 .86189 .32143 .86369 .3207 .86301 .32013 Mtetra
.638 .865 .984 r
.86301 .32013 .86369 .3207 .86551 .32008 .86483 .31952 Mtetra
.653 .875 .981 r
.86483 .31952 .86551 .32008 .86735 .31964 .86665 .31886 Mtetra
.762 .847 .915 r
.86665 .31886 .86735 .31964 .86921 .31948 .86842 .3178 Mtetra
.67 .649 .82 r
.86842 .3178 .86921 .31948 .87114 .31984 .87023 .31709 Mtetra
.561 .501 .745 r
.87023 .31709 .87114 .31984 .87321 .3214 .87212 .31712 Mtetra
.192 .204 .642 r
.87212 .31712 .87321 .3214 .89688 .51692 .87443 .32084 Mtetra
.106 .03 .478 r
.87443 .32084 .89688 .51692 .90036 .53003 .89899 .52358 Mtetra
.135 .131 .588 r
.89899 .52358 .90036 .53003 .90269 .53277 .90173 .52991 Mtetra
.489 .462 .754 r
.90173 .52991 .90269 .53277 .90472 .53281 .90382 .53052 Mtetra
.588 .559 .789 r
.90382 .53052 .90472 .53281 .90668 .53218 .90583 .53032 Mtetra
.646 .63 .82 r
.90583 .53032 .90668 .53218 .90859 .53107 .90779 .52973 Mtetra
.508 .633 .908 r
.90779 .52973 .90859 .53107 .9105 .53006 .90983 .5298 Mtetra
.421 .846 .955 r
.90983 .5298 .9105 .53006 .91236 .52854 .91182 .52938 Mtetra
0 0 0 r
.91182 .52938 .91236 .52854 .9141 .52601 .91371 .52816 Mtetra
.922 .764 .668 r
.28089 .70895 .28194 .70943 .28384 .70416 .28278 .70393 Mtetra
.937 .687 .534 r
.28278 .70393 .28384 .70416 .29862 .50921 .29763 .50874 Mtetra
.928 .745 .634 r
.29763 .50874 .29862 .50921 .30049 .50314 .29953 .50223 Mtetra
.778 .756 .833 r
.29953 .50223 .30049 .50314 .30202 .50197 .30106 .50105 Mtetra
.647 .731 .91 r
.30106 .50105 .30202 .50197 .3035 .50154 .30255 .50063 Mtetra
.516 .689 .946 r
.30255 .50063 .3035 .50154 .30496 .50147 .30401 .50059 Mtetra
.752 .759 .859 r
.30401 .50059 .30496 .50147 .30648 .50052 .30553 .49964 Mtetra
.698 .752 .893 r
.30553 .49964 .30648 .50052 .30798 .49988 .30703 .499 Mtetra
.479 .682 .955 r
.30703 .499 .30798 .49988 .30944 .49991 .30849 .49903 Mtetra
.927 .549 .258 r
.30849 .49903 .30944 .49991 .31064 .50394 .30968 .50308 Mtetra
.939 .683 .523 r
.30968 .50308 .31064 .50394 .29968 .69819 .29866 .69738 Mtetra
.933 .579 .328 r
.29866 .69738 .29968 .69819 .30089 .70348 .29987 .70265 Mtetra
0 .351 .795 r
.29987 .70265 .30089 .70348 .3024 .70429 .30138 .70345 Mtetra
.622 .756 .942 r
.30138 .70345 .3024 .70429 .30397 .70392 .30296 .70308 Mtetra
.803 .779 .832 r
.30296 .70308 .30397 .70392 .30562 .70251 .3046 .70166 Mtetra
.906 .741 .666 r
.3046 .70166 .30562 .70251 .30748 .69752 .30647 .69663 Mtetra
.939 .687 .53 r
.30647 .69663 .30748 .69752 .32101 .50237 .32006 .50139 Mtetra
.909 .722 .637 r
.32006 .50139 .32101 .50237 .32287 .49601 .32192 .49508 Mtetra
.789 .755 .823 r
.32192 .49508 .32287 .49601 .32442 .4947 .32347 .49378 Mtetra
.636 .73 .916 r
.32347 .49378 .32442 .4947 .32591 .49431 .32496 .4934 Mtetra
.494 .682 .95 r
.32496 .4934 .32591 .49431 .32738 .4943 .32643 .49341 Mtetra
.64 .736 .918 r
.32643 .49341 .32738 .4943 .32888 .49387 .32793 .493 Mtetra
.667 .75 .912 r
.32793 .493 .32888 .49387 .33039 .49335 .32944 .4925 Mtetra
.68 .757 .909 r
.32944 .4925 .33039 .49335 .33189 .49281 .33094 .49194 Mtetra
.776 .768 .846 r
.33094 .49194 .33189 .49281 .33343 .4918 .33249 .49082 Mtetra
.736 .741 .856 r
.33249 .49082 .33343 .4918 .33495 .49104 .33401 .48994 Mtetra
.603 .68 .896 r
.33401 .48994 .33495 .49104 .33643 .4909 .33551 .48969 Mtetra
.865 .439 .007 r
.33551 .48969 .33643 .4909 .33773 .49409 .33682 .49267 Mtetra
.943 .684 .516 r
.33682 .49267 .33773 .49409 .32835 .68819 .32738 .68668 Mtetra
.958 .626 .334 r
.32738 .68668 .32835 .68819 .32955 .69482 .32854 .69398 Mtetra
0 .138 .61 r
.32854 .69398 .32955 .69482 .33106 .69595 .33005 .69513 Mtetra
.582 .752 .958 r
.33005 .69513 .33106 .69595 .33265 .69569 .33164 .69486 Mtetra
.795 .787 .846 r
.33164 .69486 .33265 .69569 .3343 .6944 .33329 .69355 Mtetra
.905 .749 .678 r
.33329 .69355 .3343 .6944 .33612 .68996 .33511 .68909 Mtetra
.942 .688 .524 r
.33511 .68909 .33612 .68996 .34809 .49495 .34715 .49395 Mtetra
.917 .72 .621 r
.34715 .49395 .34809 .49495 .34997 .4875 .34903 .48657 Mtetra
.814 .758 .8 r
.34903 .48657 .34997 .4875 .35154 .4859 .35061 .48498 Mtetra
.649 .734 .911 r
.35061 .48498 .35154 .4859 .35306 .48546 .35212 .48454 Mtetra
.504 .685 .948 r
.35212 .48454 .35306 .48546 .35455 .48543 .35361 .48452 Mtetra
.621 .73 .925 r
.35361 .48452 .35455 .48543 .35606 .48506 .35512 .48419 Mtetra
.665 .749 .913 r
.35512 .48419 .35606 .48506 .35758 .48454 .35664 .48368 Mtetra
.678 .757 .911 r
.35664 .48368 .35758 .48454 .3591 .484 .35816 .48313 Mtetra
.77 .77 .853 r
.35816 .48313 .3591 .484 .36065 .48303 .35971 .48205 Mtetra
.744 .746 .853 r
.35971 .48205 .36065 .48303 .36218 .48221 .36126 .48111 Mtetra
.626 .691 .891 r
.36126 .48111 .36218 .48221 .36369 .48198 .36277 .48077 Mtetra
.769 .32 0 r
.36277 .48077 .36369 .48198 .36506 .48462 .36415 .48324 Mtetra
.946 .685 .509 r
.36415 .48324 .36506 .48462 .35731 .67794 .35636 .67601 Mtetra
.967 .648 .345 r
.35636 .67601 .35731 .67794 .35851 .68609 .35752 .68523 Mtetra
0 .071 .549 r
.35752 .68523 .35851 .68609 .36004 .68746 .35905 .68653 Mtetra
.596 .731 .939 r
.35905 .68653 .36004 .68746 .36165 .68725 .36066 .68625 Mtetra
.76 .756 .85 r
.36066 .68625 .36165 .68725 .3633 .68605 .36231 .68515 Mtetra
.847 .771 .777 r
.36231 .68515 .3633 .68605 .36506 .68252 .36401 .68303 Mtetra
.972 .89 .686 r
.36401 .68303 .36506 .68252 .37497 .49856 .36578 .67915 Mtetra
.512 .303 .533 r
.36578 .67915 .37497 .49856 .37731 .48015 .3683 .6588 Mtetra
0 0 .288 r
.3683 .6588 .37731 .48015 .37892 .47776 .3778 .48124 Mtetra
0 0 .076 r
.3778 .48124 .37892 .47776 .38047 .47686 .37946 .47784 Mtetra
.715 .93 .603 r
.37946 .47784 .38047 .47686 .382 .47642 .38106 .47587 Mtetra
.773 .845 .906 r
.38106 .47587 .382 .47642 .38353 .47598 .38261 .47488 Mtetra
.656 .703 .881 r
.38261 .47488 .38353 .47598 .38506 .47555 .38414 .47441 Mtetra
.609 .679 .891 r
.38414 .47441 .38506 .47555 .38659 .47515 .38567 .47413 Mtetra
.638 .714 .903 r
.38567 .47413 .38659 .47515 .38813 .47466 .3872 .47374 Mtetra
.667 .743 .907 r
.3872 .47374 .38813 .47466 .38967 .4741 .38874 .47323 Mtetra
.679 .756 .909 r
.38874 .47323 .38967 .4741 .39121 .47352 .39028 .47266 Mtetra
.741 .772 .878 r
.39028 .47266 .39121 .47352 .39276 .47263 .39183 .47179 Mtetra
.743 .774 .878 r
.39183 .47179 .39276 .47263 .39431 .4718 .39339 .4709 Mtetra
.674 .748 .906 r
.39339 .4709 .39431 .4718 .39585 .47146 .39493 .47035 Mtetra
.256 .515 .907 r
.39493 .47035 .39585 .47146 .3973 .47309 .39643 .4709 Mtetra
0 .054 .615 r
.39643 .4709 .3973 .47309 .39847 .48232 .39787 .4731 Mtetra
0 0 .429 r
.39787 .4731 .39847 .48232 .39277 .67381 .39907 .48154 Mtetra
0 0 .316 r
.39907 .48154 .39277 .67381 .3943 .67601 .39351 .67014 Mtetra
.257 .199 .598 r
.39351 .67014 .3943 .67601 .39592 .67615 .39501 .67341 Mtetra
.297 .334 .731 r
.39501 .67341 .39592 .67615 .39756 .67571 .39658 .67478 Mtetra
.393 .648 .959 r
.39658 .67478 .39756 .67571 .3992 .67515 .3982 .67497 Mtetra
.528 .891 .974 r
.3982 .67497 .3992 .67515 .40085 .67455 .39984 .67448 Mtetra
.647 .946 .955 r
.39984 .67448 .40085 .67455 .4025 .67387 .4015 .6737 Mtetra
.681 .937 .966 r
.4015 .6737 .4025 .67387 .40415 .6732 .40315 .67289 Mtetra
.687 .909 .973 r
.40315 .67289 .40415 .6732 .4058 .67258 .40481 .67215 Mtetra
.702 .881 .964 r
.40481 .67215 .4058 .67258 .40745 .67197 .40646 .6714 Mtetra
.609 .826 .983 r
.40646 .6714 .40745 .67197 .40909 .67171 .40811 .67097 Mtetra
.587 .775 .969 r
.40811 .67097 .40909 .67171 .41073 .6715 .40975 .67065 Mtetra
.698 .781 .915 r
.40975 .67065 .41073 .6715 .41239 .67069 .41141 .66996 Mtetra
.86 .805 .795 r
.41141 .66996 .41239 .67069 .41413 .66731 .41311 .66791 Mtetra
.984 .857 .634 r
.41311 .66791 .41413 .66731 .42182 .4738 .41491 .66271 Mtetra
0 0 .3 r
.41491 .66271 .42182 .4738 .42365 .46444 .42253 .47015 Mtetra
0 0 .131 r
.42253 .47015 .42365 .46444 .42527 .46191 .42427 .46392 Mtetra
0 0 0 r
.42427 .46392 .42527 .46191 .42684 .46091 .4259 .46113 Mtetra
.883 .982 .823 r
.4259 .46113 .42684 .46091 .4284 .46034 .42749 .45934 Mtetra
.749 .749 .852 r
.42749 .45934 .4284 .46034 .42996 .45988 .42907 .45835 Mtetra
.638 .63 .826 r
.42907 .45835 .42996 .45988 .43152 .45944 .43063 .45792 Mtetra
.598 .614 .839 r
.43063 .45792 .43152 .45944 .43308 .45907 .43218 .45771 Mtetra
.64 .656 .849 r
.43218 .45771 .43308 .45907 .43464 .45846 .43374 .45728 Mtetra
.684 .701 .86 r
.43374 .45728 .43464 .45846 .43621 .45775 .43531 .45666 Mtetra
.634 .7 .893 r
.43531 .45666 .43621 .45775 .43777 .45743 .43687 .45627 Mtetra
.286 .52 .904 r
.43687 .45627 .43777 .45743 .43929 .45866 .4384 .45681 Mtetra
0 0 .559 r
.4384 .45681 .43929 .45866 .44067 .46519 .4399 .45908 Mtetra
0 0 .425 r
.4399 .45908 .44067 .46519 .43733 .66023 .44129 .46552 Mtetra
0 0 .347 r
.44129 .46552 .43733 .66023 .43891 .66298 .43819 .65245 Mtetra
.54 .368 .597 r
.43819 .65245 .43891 .66298 .44057 .66282 .43982 .65304 Mtetra
.622 .433 .605 r
.43982 .65304 .44057 .66282 .44225 .662 .44152 .65115 Mtetra
.662 .459 .599 r
.44152 .65115 .44225 .662 .44392 .66111 .44326 .64732 Mtetra
.67 .458 .59 r
.44326 .64732 .44392 .66111 .4456 .66052 .44504 .64189 Mtetra
.535 .347 .572 r
.44504 .64189 .4456 .66052 .44727 .66 .44667 .64307 Mtetra
.309 .177 .534 r
.44667 .64307 .44727 .66 .44893 .65978 .44813 .65148 Mtetra
.265 .178 .567 r
.44813 .65148 .44893 .65978 .45059 .65985 .44969 .65615 Mtetra
.239 .246 .665 r
.44969 .65615 .45059 .65985 .45225 .65988 .45131 .65836 Mtetra
.299 .474 .865 r
.45131 .65836 .45225 .65988 .45392 .65967 .45296 .65908 Mtetra
.561 .811 .992 r
.45296 .65908 .45392 .65967 .4556 .65919 .45463 .65876 Mtetra
.65 .878 .983 r
.45463 .65876 .4556 .65919 .45728 .65863 .45631 .65815 Mtetra
.666 .869 .976 r
.45631 .65815 .45728 .65863 .45896 .65808 .45799 .65751 Mtetra
.63 .837 .98 r
.45799 .65751 .45896 .65808 .46064 .65759 .45967 .65701 Mtetra
.633 .834 .978 r
.45967 .65701 .46064 .65759 .46232 .65712 .46135 .6565 Mtetra
.632 .825 .975 r
.46135 .6565 .46232 .65712 .464 .65665 .46304 .65601 Mtetra
.627 .818 .974 r
.46304 .65601 .464 .65665 .46568 .65618 .46472 .65553 Mtetra
.624 .815 .974 r
.46472 .65553 .46568 .65618 .46736 .65573 .4664 .65507 Mtetra
.619 .813 .975 r
.4664 .65507 .46736 .65573 .46904 .65528 .46809 .65463 Mtetra
.614 .811 .976 r
.46809 .65463 .46904 .65528 .47073 .65485 .46977 .65419 Mtetra
.613 .81 .976 r
.46977 .65419 .47073 .65485 .47241 .65442 .47146 .65376 Mtetra
.57 .797 .985 r
.47146 .65376 .47241 .65442 .4741 .65415 .47314 .65344 Mtetra
.529 .769 .986 r
.47314 .65344 .4741 .65415 .47578 .65405 .47483 .65324 Mtetra
.648 .785 .947 r
.47483 .65324 .47578 .65405 .47747 .65348 .47652 .65274 Mtetra
.812 .82 .857 r
.47652 .65274 .47747 .65348 .47918 .65147 .47822 .65133 Mtetra
.951 .856 .712 r
.47822 .65133 .47918 .65147 .48096 .64408 .47995 .64782 Mtetra
.846 .79 .292 r
.47995 .64782 .48096 .64408 .48504 .44711 .48174 .63974 Mtetra
0 0 .349 r
.48174 .63974 .48504 .44711 .48668 .44311 .4857 .44985 Mtetra
.457 .201 .437 r
.4857 .44985 .48668 .44311 .48828 .44224 .48731 .44841 Mtetra
.567 .292 .459 r
.48731 .44841 .48828 .44224 .48987 .442 .48889 .44892 Mtetra
.6 .327 .475 r
.48889 .44892 .48987 .442 .49146 .4419 .49047 .45021 Mtetra
.539 .282 .474 r
.49047 .45021 .49146 .4419 .49306 .44145 .49207 .45009 Mtetra
.552 .295 .48 r
.49207 .45009 .49306 .44145 .49465 .44101 .49367 .45028 Mtetra
.586 .327 .491 r
.49367 .45028 .49465 .44101 .49625 .44061 .49526 .45146 Mtetra
.692 .424 .514 r
.49526 .45146 .49625 .44061 .49785 .44023 .4968 .45774 Mtetra
.929 .654 .499 r
.4968 .45774 .49785 .44023 .49945 .43986 .49703 .62911 Mtetra
.559 .342 .541 r
.49703 .62911 .49945 .43986 .50105 .43946 .4987 .63193 Mtetra
.555 .338 .541 r
.4987 .63193 .50105 .43946 .50265 .43902 .50039 .63229 Mtetra
.554 .338 .54 r
.50039 .63229 .50265 .43902 .50426 .43855 .50209 .63214 Mtetra
.554 .337 .54 r
.50209 .63214 .50426 .43855 .50586 .43807 .50379 .63183 Mtetra
.50379 .63183 .50586 .43807 .50747 .43759 .50549 .63159 Mtetra
.50549 .63159 .50747 .43759 .50907 .4371 .50719 .63129 Mtetra
.50719 .63129 .50907 .4371 .51068 .4366 .50889 .63095 Mtetra
.50889 .63095 .51068 .4366 .51229 .4361 .5106 .63058 Mtetra
.5106 .63058 .51229 .4361 .5139 .4356 .5123 .63018 Mtetra
.5123 .63018 .5139 .4356 .51551 .4351 .51401 .62978 Mtetra
.51401 .62978 .51551 .4351 .51712 .43459 .51572 .62936 Mtetra
.51572 .62936 .51712 .43459 .51873 .43408 .51743 .62894 Mtetra
.51743 .62894 .51873 .43408 .52034 .43358 .51914 .62853 Mtetra
.51914 .62853 .52034 .43358 .52196 .43307 .52085 .62813 Mtetra
.52085 .62813 .52196 .43307 .52357 .43257 .52257 .62775 Mtetra
.52257 .62775 .52357 .43257 .52519 .43208 .52428 .6274 Mtetra
.52428 .6274 .52519 .43208 .52681 .4316 .52599 .62711 Mtetra
.52599 .62711 .52681 .4316 .52843 .43114 .52771 .62685 Mtetra
.555 .338 .54 r
.52771 .62685 .52843 .43114 .53004 .43071 .52943 .62687 Mtetra
.556 .339 .541 r
.52943 .62687 .53004 .43071 .53167 .43039 .53115 .62781 Mtetra
.554 .338 .54 r
.53115 .62781 .53167 .43039 .53329 .43 .53287 .62759 Mtetra
.55 .334 .54 r
.53287 .62759 .53329 .43 .53491 .42938 .53459 .62458 Mtetra
0 0 .374 r
.53459 .62458 .53491 .42938 .53653 .42825 .53568 .43358 Mtetra
0 0 .212 r
.53568 .43358 .53653 .42825 .53815 .42714 .53729 .42804 Mtetra
.829 .947 .592 r
.53729 .42804 .53815 .42714 .53977 .4262 .5389 .42544 Mtetra
.73 .809 .913 r
.5389 .42544 .53977 .4262 .5414 .42567 .54053 .42462 Mtetra
.639 .718 .905 r
.54053 .42462 .5414 .42567 .54303 .42524 .54216 .4242 Mtetra
.594 .701 .918 r
.54216 .4242 .54303 .42524 .54465 .42486 .54379 .42394 Mtetra
.649 .75 .923 r
.54379 .42394 .54465 .42486 .54628 .42439 .54541 .42347 Mtetra
.651 .749 .921 r
.54541 .42347 .54628 .42439 .54791 .4239 .54704 .42299 Mtetra
.658 .754 .921 r
.54704 .42299 .54791 .4239 .54954 .42338 .54868 .42247 Mtetra
.678 .763 .915 r
.54868 .42247 .54954 .42338 .55117 .4228 .55031 .42188 Mtetra
.683 .762 .911 r
.55031 .42188 .55117 .4228 .5528 .42219 .55194 .42127 Mtetra
.691 .762 .906 r
.55194 .42127 .5528 .42219 .55444 .42155 .55357 .42061 Mtetra
.737 .772 .881 r
.55357 .42061 .55444 .42155 .55607 .4208 .5552 .41972 Mtetra
.688 .729 .881 r
.5552 .41972 .55607 .4208 .5577 .42012 .55684 .41906 Mtetra
.572 .69 .921 r
.55684 .41906 .5577 .42012 .55934 .41956 .55848 .41888 Mtetra
0 .118 .578 r
.55848 .41888 .55934 .41956 .56097 .419 .56013 .42015 Mtetra
.83 .454 .343 r
.56013 .42015 .56097 .419 .56261 .41892 .56182 .42389 Mtetra
.957 .676 .461 r
.56182 .42389 .56261 .41892 .56427 .41991 .56576 .61655 Mtetra
.565 .346 .542 r
.56576 .61655 .56427 .41991 .56828 .60649 .56759 .62297 Mtetra
.594 .348 .513 r
.56759 .62297 .56828 .60649 .57025 .62375 .56937 .62535 Mtetra
.636 .236 .269 r
.56937 .62535 .57025 .62375 .57204 .62663 .57114 .62642 Mtetra
.334 .796 .937 r
.57114 .62642 .57204 .62663 .5738 .6266 .5729 .62619 Mtetra
.624 .886 .988 r
.5729 .62619 .5738 .6266 .57555 .62597 .57465 .62559 Mtetra
.688 .909 .972 r
.57465 .62559 .57555 .62597 .5773 .62503 .5764 .6248 Mtetra
.54 .895 .976 r
.5764 .6248 .5773 .62503 .57905 .62446 .57815 .62426 Mtetra
.542 .9 .971 r
.57815 .62426 .57905 .62446 .5808 .62388 .5799 .62369 Mtetra
.553 .908 .967 r
.5799 .62369 .5808 .62388 .58256 .62328 .58166 .62309 Mtetra
.611 .928 .967 r
.58166 .62309 .58256 .62328 .58431 .62265 .58341 .62237 Mtetra
.652 .922 .976 r
.58341 .62237 .58431 .62265 .58606 .62202 .58517 .62162 Mtetra
.673 .902 .977 r
.58517 .62162 .58606 .62202 .58782 .62139 .58692 .62088 Mtetra
.649 .869 .982 r
.58692 .62088 .58782 .62139 .58958 .62078 .58868 .62026 Mtetra
.638 .862 .984 r
.58868 .62026 .58958 .62078 .59134 .62018 .59044 .61967 Mtetra
.63 .865 .986 r
.59044 .61967 .59134 .62018 .5931 .61957 .5922 .6191 Mtetra
.629 .873 .987 r
.5922 .6191 .5931 .61957 .59486 .61896 .59396 .61851 Mtetra
.632 .879 .987 r
.59396 .61851 .59486 .61896 .59662 .61835 .59573 .61791 Mtetra
.642 .885 .985 r
.59573 .61791 .59662 .61835 .59838 .61772 .59749 .61727 Mtetra
.68 .891 .975 r
.59749 .61727 .59838 .61772 .60014 .61708 .59925 .61653 Mtetra
.7 .87 .962 r
.59925 .61653 .60014 .61708 .60191 .61643 .60101 .61575 Mtetra
.706 .84 .947 r
.60101 .61575 .60191 .61643 .60367 .61576 .60278 .61497 Mtetra
.588 .777 .97 r
.60278 .61497 .60367 .61576 .60545 .61558 .60455 .61463 Mtetra
.649 .761 .931 r
.60455 .61463 .60545 .61558 .60722 .61507 .60632 .61411 Mtetra
.748 .785 .883 r
.60632 .61411 .60722 .61507 .60897 .61378 .60808 .61309 Mtetra
.933 .81 .7 r
.60808 .61309 .60897 .61378 .61059 .60727 .60978 .6094 Mtetra
.998 .786 .441 r
.60978 .6094 .61059 .60727 .60729 .40797 .61121 .59528 Mtetra
0 0 .393 r
.61121 .59528 .60729 .40797 .60884 .4029 .60812 .40651 Mtetra
.307 .028 .316 r
.60812 .40651 .60884 .4029 .61049 .40155 .60975 .40468 Mtetra
.457 .141 .34 r
.60975 .40468 .61049 .40155 .61215 .40102 .61142 .40413 Mtetra
.517 .194 .359 r
.61142 .40413 .61215 .40102 .61383 .40082 .61311 .4041 Mtetra
.393 .09 .328 r
.61311 .4041 .61383 .40082 .61549 .39998 .61476 .40302 Mtetra
.416 .102 .322 r
.61476 .40302 .61549 .39998 .61716 .3993 .61643 .40219 Mtetra
.516 .186 .345 r
.61643 .40219 .61716 .3993 .61884 .39919 .61812 .40219 Mtetra
.812 .481 .429 r
.61812 .40219 .61884 .39919 .62061 .40189 .61998 .40797 Mtetra
.961 .673 .443 r
.61998 .40797 .62061 .40189 .6282 .59717 .62749 .60219 Mtetra
.713 .405 .455 r
.62749 .60219 .6282 .59717 .63029 .60691 .62941 .60616 Mtetra
.175 .575 .937 r
.62941 .60616 .63029 .60691 .63212 .60787 .63123 .60663 Mtetra
.624 .693 .894 r
.63123 .60663 .63212 .60787 .63392 .60756 .63302 .60623 Mtetra
.677 .701 .865 r
.63302 .60623 .63392 .60756 .6357 .60678 .6348 .60556 Mtetra
.597 .686 .904 r
.6348 .60556 .6357 .60678 .63749 .60635 .6366 .60528 Mtetra
.563 .702 .934 r
.6366 .60528 .63749 .60635 .63928 .60599 .6384 .60509 Mtetra
.556 .739 .962 r
.6384 .60509 .63928 .60599 .64108 .60561 .6402 .60487 Mtetra
.462 .74 .988 r
.6402 .60487 .64108 .60561 .64289 .60561 .64201 .60481 Mtetra
.56 .766 .975 r
.64201 .60481 .64289 .60561 .6447 .60538 .64382 .60454 Mtetra
.694 .803 .932 r
.64382 .60454 .6447 .60538 .64648 .6045 .64561 .60381 Mtetra
.888 .846 .797 r
.64561 .60381 .64648 .6045 .64815 .60059 .64734 .60158 Mtetra
.951 .909 .534 r
.64734 .60158 .64815 .60059 .64278 .40379 .649 .59707 Mtetra
.001 0 .407 r
.649 .59707 .64278 .40379 .64409 .39301 .64365 .40261 Mtetra
.026 0 .343 r
.64365 .40261 .64409 .39301 .64571 .39076 .64502 .39326 Mtetra
0 0 .043 r
.64502 .39326 .64571 .39076 .64738 .38978 .64661 .39006 Mtetra
.848 .996 .761 r
.64661 .39006 .64738 .38978 .64907 .38923 .64824 .38813 Mtetra
.724 .745 .869 r
.64824 .38813 .64907 .38923 .65076 .38872 .64992 .38726 Mtetra
.625 .646 .85 r
.64992 .38726 .65076 .38872 .65246 .38826 .65162 .38688 Mtetra
.581 .638 .872 r
.65162 .38688 .65246 .38826 .65416 .38785 .65333 .3867 Mtetra
.625 .7 .899 r
.65333 .3867 .65416 .38785 .65585 .38734 .65503 .38632 Mtetra
.658 .738 .909 r
.65503 .38632 .65585 .38734 .65754 .38678 .65672 .3858 Mtetra
.671 .751 .911 r
.65672 .3858 .65754 .38678 .65924 .3862 .65842 .38521 Mtetra
.732 .769 .882 r
.65842 .38521 .65924 .3862 .66092 .38529 .6601 .38431 Mtetra
.726 .77 .888 r
.6601 .38431 .66092 .38529 .6626 .38449 .66178 .38346 Mtetra
.652 .734 .909 r
.66178 .38346 .6626 .38449 .66431 .38422 .66348 .38295 Mtetra
.184 .437 .867 r
.66348 .38295 .66431 .38422 .66613 .3863 .66525 .38387 Mtetra
0 .062 .615 r
.66525 .38387 .66613 .3863 .67621 .57378 .6671 .38683 Mtetra
.027 0 .427 r
.6671 .38683 .67621 .57378 .67888 .59245 .67714 .57218 Mtetra
.31 .183 .541 r
.67714 .57218 .67888 .59245 .68078 .5938 .67949 .58354 Mtetra
.595 .411 .603 r
.67949 .58354 .68078 .5938 .6826 .59333 .68128 .58244 Mtetra
.594 .408 .599 r
.68128 .58244 .6826 .59333 .6844 .59238 .68307 .58132 Mtetra
.386 .259 .583 r
.68307 .58132 .6844 .59238 .68623 .59204 .68513 .58599 Mtetra
.319 .252 .623 r
.68513 .58599 .68623 .59204 .68808 .59206 .68713 .58933 Mtetra
.27 .326 .737 r
.68713 .58933 .68808 .59206 .68992 .59202 .68906 .59105 Mtetra
.384 .638 .956 r
.68906 .59105 .68992 .59202 .69176 .59171 .69092 .5913 Mtetra
.547 .866 .995 r
.69092 .5913 .69176 .59171 .69358 .59121 .69275 .59084 Mtetra
.626 .904 .985 r
.69275 .59084 .69358 .59121 .69541 .59065 .69457 .59016 Mtetra
.572 .855 .996 r
.69457 .59016 .69541 .59065 .69724 .59017 .69641 .58969 Mtetra
.503 .83 .999 r
.69641 .58969 .69724 .59017 .69907 .58973 .69825 .58937 Mtetra
.481 .848 .99 r
.69825 .58937 .69907 .58973 .70091 .58928 .70009 .589 Mtetra
.437 .844 .97 r
.70009 .589 .70091 .58928 .70276 .58905 .70193 .58864 Mtetra
.565 .874 .994 r
.70193 .58864 .70276 .58905 .7046 .58873 .70377 .58813 Mtetra
.718 .873 .954 r
.70377 .58813 .7046 .58873 .70642 .58788 .70558 .58726 Mtetra
.89 .872 .814 r
.70558 .58726 .70642 .58788 .70812 .5848 .70733 .58513 Mtetra
.983 .909 .616 r
.70733 .58513 .70812 .5848 .70931 .57237 .70897 .58094 Mtetra
0 0 .203 r
.70897 .58094 .70931 .57237 .70038 .37578 .71014 .56815 Mtetra
.055 0 .433 r
.71014 .56815 .70038 .37578 .70198 .37302 .7016 .37979 Mtetra
.484 .226 .447 r
.7016 .37979 .70198 .37302 .70369 .37227 .7033 .37867 Mtetra
.57 .293 .456 r
.7033 .37867 .70369 .37227 .70543 .37207 .70509 .3793 Mtetra
.559 .29 .465 r
.70509 .3793 .70543 .37207 .70717 .37175 .70688 .37968 Mtetra
.521 .264 .466 r
.70688 .37968 .70717 .37175 .7089 .3712 .70861 .37916 Mtetra
.522 .265 .467 r
.70861 .37916 .7089 .3712 .71062 .37065 .71035 .37864 Mtetra
.519 .263 .466 r
.71035 .37864 .71062 .37065 .71235 .3701 .71208 .37805 Mtetra
.515 .26 .466 r
.71208 .37805 .71235 .3701 .71408 .36953 .7138 .37739 Mtetra
.515 .259 .465 r
.7138 .37739 .71408 .36953 .71581 .36896 .71553 .37672 Mtetra
.515 .259 .464 r
.71553 .37672 .71581 .36896 .71754 .36839 .71726 .37608 Mtetra
.517 .259 .463 r
.71726 .37608 .71754 .36839 .71927 .36783 .719 .37547 Mtetra
.518 .26 .463 r
.719 .37547 .71927 .36783 .721 .36727 .72074 .37491 Mtetra
.521 .262 .463 r
.72074 .37491 .721 .36727 .72274 .36671 .72248 .37441 Mtetra
.524 .265 .464 r
.72248 .37441 .72274 .36671 .72447 .36617 .72423 .37397 Mtetra
.526 .267 .466 r
.72423 .37397 .72447 .36617 .72621 .36563 .72598 .37356 Mtetra
.573 .305 .473 r
.72598 .37356 .72621 .36563 .72795 .36515 .72781 .37433 Mtetra
.606 .338 .485 r
.72781 .37433 .72795 .36515 .7297 .3647 .72971 .37625 Mtetra
.496 .26 .486 r
.72971 .37625 .7297 .3647 .73144 .36416 .73138 .37452 Mtetra
.274 .087 .436 r
.73138 .37452 .73144 .36416 .73316 .36334 .73274 .36792 Mtetra
.044 0 .282 r
.73274 .36792 .73316 .36334 .73487 .36231 .73421 .36327 Mtetra
.709 .856 .435 r
.73421 .36327 .73487 .36231 .73659 .36131 .73581 .36046 Mtetra
.826 .825 .847 r
.73581 .36046 .73659 .36131 .73832 .36054 .73749 .35895 Mtetra
.664 .651 .827 r
.73749 .35895 .73832 .36054 .74006 .36002 .73923 .35832 Mtetra
.616 .615 .827 r
.73923 .35832 .74006 .36002 .74182 .35957 .74099 .35798 Mtetra
.604 .621 .842 r
.74099 .35798 .74182 .35957 .74357 .35914 .74276 .3577 Mtetra
.613 .647 .861 r
.74276 .3577 .74357 .35914 .74533 .35869 .74452 .35737 Mtetra
.612 .668 .879 r
.74452 .35737 .74533 .35869 .74708 .35822 .74629 .35704 Mtetra
.635 .703 .896 r
.74629 .35704 .74708 .35822 .74883 .35769 .74805 .35661 Mtetra
.667 .737 .903 r
.74805 .35661 .74883 .35769 .75058 .35707 .7498 .35602 Mtetra
.678 .749 .904 r
.7498 .35602 .75058 .35707 .75233 .35642 .75154 .35538 Mtetra
.728 .768 .885 r
.75154 .35538 .75233 .35642 .75405 .35552 .75327 .35449 Mtetra
.748 .774 .874 r
.75327 .35449 .75405 .35552 .75577 .3545 .75499 .35347 Mtetra
.649 .741 .917 r
.75499 .35347 .75577 .3545 .75753 .35398 .75675 .35296 Mtetra
0 .313 .801 r
.75675 .35296 .75753 .35398 .75942 .35525 .75865 .35423 Mtetra
.949 .597 .223 r
.75865 .35423 .75942 .35525 .76213 .36737 .76138 .36687 Mtetra
.975 .673 .365 r
.76138 .36687 .76213 .36737 .77867 .56398 .77785 .56303 Mtetra
.568 .094 0 r
.77785 .56303 .77867 .56398 .78079 .56659 .77997 .56562 Mtetra
.445 .675 .961 r
.77997 .56562 .78079 .56659 .78272 .5667 .7819 .56572 Mtetra
.728 .795 .905 r
.7819 .56572 .78272 .5667 .78458 .56577 .78376 .56479 Mtetra
.902 .815 .751 r
.78376 .56479 .78458 .56577 .78629 .56299 .78547 .56202 Mtetra
.979 .746 .515 r
.78547 .56202 .78629 .56299 .78738 .55222 .78658 .5514 Mtetra
.977 .681 .375 r
.78658 .5514 .78738 .55222 .7736 .35175 .77283 .35073 Mtetra
.926 .792 .693 r
.77283 .35073 .7736 .35175 .77514 .34829 .77437 .34725 Mtetra
.721 .767 .888 r
.77437 .34725 .77514 .34829 .77688 .34743 .77611 .34639 Mtetra
.594 .716 .929 r
.77611 .34639 .77688 .34743 .77867 .34714 .7779 .34609 Mtetra
.622 .727 .922 r
.7779 .34609 .77867 .34714 .78045 .34674 .77968 .34569 Mtetra
.737 .769 .879 r
.77968 .34569 .78045 .34674 .78219 .34579 .78142 .34473 Mtetra
.645 .735 .914 r
.78142 .34473 .78219 .34579 .78397 .3453 .7832 .34424 Mtetra
.089 .416 .864 r
.7832 .34424 .78397 .3453 .78587 .34632 .7851 .34526 Mtetra
.922 .549 .132 r
.7851 .34526 .78587 .34632 .78846 .35553 .78768 .35443 Mtetra
.975 .67 .349 r
.78768 .35443 .78846 .35553 .80698 .55543 .80617 .55442 Mtetra
.601 .14 0 r
.80617 .55442 .80698 .55543 .80917 .55838 .80836 .55738 Mtetra
.423 .657 .957 r
.80836 .55738 .80917 .55838 .81113 .55854 .81033 .55756 Mtetra
.721 .794 .909 r
.81033 .55756 .81113 .55854 .81301 .55764 .8122 .55665 Mtetra
.901 .819 .757 r
.8122 .55665 .81301 .55764 .81474 .55501 .81393 .55396 Mtetra
.981 .739 .495 r
.81393 .55396 .81474 .55501 .81579 .54458 .81485 .54196 Mtetra
.977 .677 .367 r
.81485 .54196 .81579 .54458 .80021 .34303 .7994 .34147 Mtetra
.891 .737 .683 r
.7994 .34147 .80021 .34303 .80172 .33933 .80092 .33791 Mtetra
.712 .699 .836 r
.80092 .33791 .80172 .33933 .80347 .3384 .80268 .337 Mtetra
.577 .64 .876 r
.80268 .337 .80347 .3384 .80527 .33809 .8045 .33683 Mtetra
.343 .535 .898 r
.8045 .33683 .80527 .33809 .80711 .33809 .80639 .33741 Mtetra
0 .062 .55 r
.80639 .33741 .80711 .33809 .80894 .33802 .80838 .33919 Mtetra
.803 .381 .245 r
.80838 .33919 .80894 .33802 .81078 .33794 .81052 .3424 Mtetra
.643 .328 .423 r
.81052 .3424 .81078 .33794 .81258 .33756 .81254 .34434 Mtetra
.186 .005 .387 r
.81254 .34434 .81258 .33756 .81433 .3365 .81387 .33868 Mtetra
0 0 .036 r
.81387 .33868 .81433 .3365 .81607 .33538 .81539 .33513 Mtetra
.914 .959 .803 r
.81539 .33513 .81607 .33538 .81782 .3344 .81704 .33303 Mtetra
.675 .692 .858 r
.81704 .33303 .81782 .3344 .81961 .33377 .81883 .33236 Mtetra
.624 .663 .867 r
.81883 .33236 .81961 .33377 .82141 .33321 .82064 .33196 Mtetra
.646 .7 .886 r
.82064 .33196 .82141 .33321 .82319 .33255 .82244 .33146 Mtetra
.767 .777 .861 r
.82244 .33146 .82319 .33255 .82495 .33148 .82418 .33029 Mtetra
.699 .733 .877 r
.82418 .33029 .82495 .33148 .82673 .33082 .82596 .32952 Mtetra
.458 .594 .901 r
.82596 .32952 .82673 .33082 .82862 .3312 .82784 .32978 Mtetra
.674 .28 0 r
.82784 .32978 .82862 .3312 .83095 .33605 .83014 .3343 Mtetra
.974 .665 .322 r
.83014 .3343 .83095 .33605 .85267 .53977 .85185 .53841 Mtetra
.705 .296 0 r
.85185 .53841 .85267 .53977 .85509 .54423 .8543 .54319 Mtetra
.489 .683 .952 r
.8543 .54319 .85509 .54423 .85708 .54427 .85629 .5432 Mtetra
.69 .769 .912 r
.85629 .5432 .85708 .54427 .859 .54356 .85821 .54245 Mtetra
.72 .773 .894 r
.85821 .54245 .859 .54356 .8609 .54265 .86011 .54152 Mtetra
.512 .677 .939 r
.86011 .54152 .8609 .54265 .86289 .54261 .8621 .5415 Mtetra
.592 .721 .933 r
.8621 .5415 .86289 .54261 .86483 .54213 .86406 .54118 Mtetra
.736 .812 .911 r
.86406 .54118 .86483 .54213 .86668 .54061 .86596 .54018 Mtetra
.953 .911 .737 r
.86596 .54018 .86668 .54061 .86805 .53448 .86765 .53723 Mtetra
0 0 0 r
.86765 .53723 .86805 .53448 .84908 .33061 .86901 .531 Mtetra
.112 .026 .469 r
.86901 .531 .84908 .33061 .85038 .32498 .85033 .33064 Mtetra
.12 0 .354 r
.85033 .33064 .85038 .32498 .85209 .32347 .85163 .32509 Mtetra
0 0 0 r
.85163 .32509 .85209 .32347 .85388 .32264 .85323 .32236 Mtetra
.859 .974 .862 r
.85323 .32236 .85388 .32264 .85571 .32214 .85493 .32071 Mtetra
.664 .68 .855 r
.85493 .32071 .85571 .32214 .85753 .3216 .85674 .32008 Mtetra
.604 .639 .858 r
.85674 .32008 .85753 .3216 .85936 .32114 .85859 .31979 Mtetra
.575 .649 .886 r
.85859 .31979 .85936 .32114 .86119 .32071 .86046 .31962 Mtetra
.645 .734 .913 r
.86046 .31962 .86119 .32071 .86301 .32013 .86229 .31911 Mtetra
.661 .756 .92 r
.86229 .31911 .86301 .32013 .86483 .31952 .86411 .31852 Mtetra
.683 .771 .917 r
.86411 .31852 .86483 .31952 .86665 .31886 .86592 .31784 Mtetra
.755 .792 .883 r
.86592 .31784 .86665 .31886 .86842 .3178 .86769 .31677 Mtetra
.714 .775 .901 r
.86769 .31677 .86842 .3178 .87023 .31709 .86949 .31594 Mtetra
.609 .704 .912 r
.86949 .31594 .87023 .31709 .87212 .31712 .87135 .31559 Mtetra
.167 .374 .823 r
.87135 .31559 .87212 .31712 .87443 .32084 .87339 .31695 Mtetra
.14 .18 .643 r
.87339 .31695 .87443 .32084 .89899 .52358 .87571 .32072 Mtetra
.133 .048 .485 r
.87571 .32072 .89899 .52358 .90173 .52991 .89994 .51978 Mtetra
.335 .236 .592 r
.89994 .51978 .90173 .52991 .90382 .53052 .90263 .52568 Mtetra
.406 .339 .669 r
.90263 .52568 .90382 .53052 .90583 .53032 .90489 .52774 Mtetra
.435 .447 .773 r
.90489 .52774 .90583 .53032 .90779 .52973 .90703 .52863 Mtetra
.362 .602 .939 r
.90703 .52863 .90779 .52973 .90983 .5298 .90911 .52905 Mtetra
.549 .791 .989 r
.90911 .52905 .90983 .5298 .91182 .52938 .91111 .52872 Mtetra
.78 .899 .926 r
.91111 .52872 .91182 .52938 .91371 .52816 .913 .5275 Mtetra
.896 .725 .662 r
.27988 .70789 .28089 .70895 .28278 .70393 .28178 .7027 Mtetra
.936 .686 .535 r
.28178 .7027 .28278 .70393 .29763 .50874 .2967 .50749 Mtetra
.896 .707 .64 r
.2967 .50749 .29763 .50874 .29953 .50223 .29857 .5013 Mtetra
.775 .753 .834 r
.29857 .5013 .29953 .50223 .30106 .50105 .30011 .50015 Mtetra
.644 .735 .915 r
.30011 .50015 .30106 .50105 .30255 .50063 .30159 .49974 Mtetra
.512 .692 .95 r
.30159 .49974 .30255 .50063 .30401 .50059 .30305 .4997 Mtetra
.75 .758 .859 r
.30305 .4997 .30401 .50059 .30553 .49964 .30457 .49876 Mtetra
.697 .751 .894 r
.30457 .49876 .30553 .49964 .30703 .499 .30607 .49812 Mtetra
.476 .681 .956 r
.30607 .49812 .30703 .499 .30849 .49903 .30753 .49815 Mtetra
.928 .55 .261 r
.30753 .49815 .30849 .49903 .30968 .50308 .30873 .50223 Mtetra
.939 .683 .523 r
.30873 .50223 .30968 .50308 .29866 .69738 .29764 .69657 Mtetra
.933 .579 .327 r
.29764 .69657 .29866 .69738 .29987 .70265 .29885 .70182 Mtetra
0 .357 .801 r
.29885 .70182 .29987 .70265 .30138 .70345 .30036 .70261 Mtetra
.624 .756 .941 r
.30036 .70261 .30138 .70345 .30296 .70308 .30194 .70223 Mtetra
.803 .778 .83 r
.30194 .70223 .30296 .70308 .3046 .70166 .30359 .7008 Mtetra
.906 .74 .665 r
.30359 .7008 .3046 .70166 .30647 .69663 .30546 .69574 Mtetra
.939 .687 .53 r
.30546 .69574 .30647 .69663 .32006 .50139 .31911 .50041 Mtetra
.909 .723 .637 r
.31911 .50041 .32006 .50139 .32192 .49508 .32097 .49415 Mtetra
.789 .756 .824 r
.32097 .49415 .32192 .49508 .32347 .49378 .32252 .49286 Mtetra
.634 .73 .917 r
.32252 .49286 .32347 .49378 .32496 .4934 .32401 .49248 Mtetra
.491 .679 .949 r
.32401 .49248 .32496 .4934 .32643 .49341 .32549 .4925 Mtetra
.639 .734 .917 r
.32549 .4925 .32643 .49341 .32793 .493 .32698 .4921 Mtetra
.665 .742 .908 r
.32698 .4921 .32793 .493 .32944 .4925 .32849 .49161 Mtetra
.674 .747 .905 r
.32849 .49161 .32944 .4925 .33094 .49194 .33 .49107 Mtetra
.768 .766 .851 r
.33 .49107 .33094 .49194 .33249 .49082 .33153 .49001 Mtetra
.735 .776 .886 r
.33153 .49001 .33249 .49082 .33401 .48994 .33306 .48918 Mtetra
.558 .747 .965 r
.33306 .48918 .33401 .48994 .33551 .48969 .33455 .48899 Mtetra
.898 .482 .177 r
.33455 .48899 .33551 .48969 .33682 .49267 .33585 .49212 Mtetra
.942 .683 .517 r
.33585 .49212 .33682 .49267 .32738 .68668 .32634 .68639 Mtetra
.924 .593 .395 r
.32634 .68639 .32738 .68668 .32854 .69398 .32753 .69317 Mtetra
0 .145 .605 r
.32753 .69317 .32854 .69398 .33005 .69513 .32904 .69429 Mtetra
.589 .747 .953 r
.32904 .69429 .33005 .69513 .33164 .69486 .33064 .69401 Mtetra
.793 .782 .842 r
.33064 .69401 .33164 .69486 .33329 .69355 .33229 .69269 Mtetra
.904 .748 .678 r
.33229 .69269 .33329 .69355 .33511 .68909 .33411 .68821 Mtetra
.942 .688 .524 r
.33411 .68821 .33511 .68909 .34715 .49395 .34621 .49296 Mtetra
.917 .721 .621 r
.34621 .49296 .34715 .49395 .34903 .48657 .34809 .48563 Mtetra
.814 .758 .801 r
.34809 .48563 .34903 .48657 .35061 .48498 .34967 .48405 Mtetra
.648 .734 .912 r
.34967 .48405 .35061 .48498 .35212 .48454 .35118 .48362 Mtetra
.501 .683 .948 r
.35118 .48362 .35212 .48454 .35361 .48452 .35267 .48361 Mtetra
.62 .728 .924 r
.35267 .48361 .35361 .48452 .35512 .48419 .35418 .48328 Mtetra
.662 .742 .91 r
.35418 .48328 .35512 .48419 .35664 .48368 .3557 .48279 Mtetra
.672 .747 .907 r
.3557 .48279 .35664 .48368 .35816 .48313 .35722 .48226 Mtetra
.762 .768 .858 r
.35722 .48226 .35816 .48313 .35971 .48205 .35877 .48123 Mtetra
.744 .779 .881 r
.35877 .48123 .35971 .48205 .36126 .48111 .36031 .48036 Mtetra
.592 .759 .958 r
.36031 .48036 .36126 .48111 .36277 .48077 .36182 .48007 Mtetra
.862 .41 .067 r
.36182 .48007 .36277 .48077 .36415 .48324 .3632 .48267 Mtetra
.945 .684 .51 r
.3632 .48267 .36415 .48324 .35636 .67601 .35532 .67611 Mtetra
.919 .6 .423 r
.35532 .67611 .35636 .67601 .35752 .68523 .35651 .68444 Mtetra
0 .14 .599 r
.35651 .68444 .35752 .68523 .35905 .68653 .35806 .68558 Mtetra
.621 .733 .927 r
.35806 .68558 .35905 .68653 .36066 .68625 .35967 .68521 Mtetra
.741 .747 .857 r
.35967 .68521 .36066 .68625 .36231 .68515 .36132 .68424 Mtetra
.74 .77 .877 r
.36132 .68424 .36231 .68515 .36401 .68303 .36296 .68331 Mtetra
.693 .982 .861 r
.36296 .68331 .36401 .68303 .36578 .67915 .36461 .68215 Mtetra
.153 0 .178 r
.36461 .68215 .36578 .67915 .3683 .6588 .3663 .68021 Mtetra
.42 .208 .484 r
.3663 .68021 .3683 .6588 .3778 .48124 .36819 .67393 Mtetra
0 0 .281 r
.36819 .67393 .3778 .48124 .37946 .47784 .37838 .48021 Mtetra
.867 .869 .424 r
.37838 .48021 .37946 .47784 .38106 .47587 .38011 .47537 Mtetra
.849 .843 .838 r
.38011 .47537 .38106 .47587 .38261 .47488 .38169 .47378 Mtetra
.665 .705 .877 r
.38169 .47378 .38261 .47488 .38414 .47441 .38322 .47327 Mtetra
.575 .665 .899 r
.38322 .47327 .38414 .47441 .38567 .47413 .38475 .47311 Mtetra
.618 .705 .908 r
.38475 .47311 .38567 .47413 .3872 .47374 .38627 .47279 Mtetra
.659 .735 .906 r
.38627 .47279 .3872 .47374 .38874 .47323 .38781 .47231 Mtetra
.668 .744 .907 r
.38781 .47231 .38874 .47323 .39028 .47266 .38935 .47179 Mtetra
.709 .763 .894 r
.38935 .47179 .39028 .47266 .39183 .47179 .3909 .47108 Mtetra
.722 .805 .916 r
.3909 .47108 .39183 .47179 .39339 .4709 .39245 .47034 Mtetra
.682 .835 .957 r
.39245 .47034 .39339 .4709 .39493 .47035 .39399 .46974 Mtetra
.583 .797 .981 r
.39399 .46974 .39493 .47035 .39643 .4709 .39553 .46942 Mtetra
.516 .58 .858 r
.39553 .46942 .39643 .4709 .39787 .4731 .39705 .46953 Mtetra
.464 .391 .69 r
.39705 .46953 .39787 .4731 .39907 .48154 .39854 .47037 Mtetra
.369 .234 .563 r
.39854 .47037 .39907 .48154 .39351 .67014 .3999 .47478 Mtetra
0 0 .31 r
.3999 .47478 .39351 .67014 .39501 .67341 .39417 .66871 Mtetra
0 0 .489 r
.39417 .66871 .39501 .67341 .39658 .67478 .39562 .67329 Mtetra
.177 .405 .845 r
.39562 .67329 .39658 .67478 .3982 .67497 .39721 .67423 Mtetra
.624 .786 .96 r
.39721 .67423 .3982 .67497 .39984 .67448 .39885 .67381 Mtetra
.738 .825 .919 r
.39885 .67381 .39984 .67448 .4015 .6737 .40051 .67294 Mtetra
.728 .805 .912 r
.40051 .67294 .4015 .6737 .40315 .67289 .40217 .67211 Mtetra
.698 .793 .924 r
.40217 .67211 .40315 .67289 .40481 .67215 .40382 .67142 Mtetra
.697 .807 .933 r
.40382 .67142 .40481 .67215 .40646 .6714 .40548 .67073 Mtetra
.646 .812 .963 r
.40548 .67073 .40646 .6714 .40811 .67097 .40713 .67022 Mtetra
.622 .786 .96 r
.40713 .67022 .40811 .67097 .40975 .67065 .40877 .66981 Mtetra
.668 .774 .929 r
.40877 .66981 .40975 .67065 .41141 .66996 .41043 .66925 Mtetra
.733 .816 .916 r
.41043 .66925 .41141 .66996 .41311 .66791 .41209 .66839 Mtetra
.674 .968 .774 r
.41209 .66839 .41311 .66791 .41491 .66271 .41377 .66702 Mtetra
.242 0 .295 r
.41377 .66702 .41491 .66271 .42253 .47015 .41548 .66462 Mtetra
.537 .323 .537 r
.41548 .66462 .42253 .47015 .42427 .46392 .41742 .65488 Mtetra
0 0 .31 r
.41742 .65488 .42427 .46392 .4259 .46113 .42489 .46334 Mtetra
.747 .819 .351 r
.42489 .46334 .4259 .46113 .42749 .45934 .42656 .45929 Mtetra
.88 .944 .851 r
.42656 .45929 .42749 .45934 .42907 .45835 .42815 .45761 Mtetra
.663 .79 .942 r
.42815 .45761 .42907 .45835 .43063 .45792 .42971 .4571 Mtetra
.551 .731 .959 r
.42971 .4571 .43063 .45792 .43218 .45771 .43126 .45693 Mtetra
.595 .759 .957 r
.43126 .45693 .43218 .45771 .43374 .45728 .43282 .45663 Mtetra
.668 .811 .952 r
.43282 .45663 .43374 .45728 .43531 .45666 .43439 .45608 Mtetra
.628 .824 .976 r
.43439 .45608 .43531 .45666 .43687 .45627 .43595 .45563 Mtetra
.467 .749 .991 r
.43595 .45563 .43687 .45627 .4384 .45681 .4375 .45556 Mtetra
.391 .557 .898 r
.4375 .45556 .4384 .45681 .4399 .45908 .43905 .45594 Mtetra
.491 .427 .713 r
.43905 .45594 .4399 .45908 .44129 .46552 .44059 .45651 Mtetra
.552 .382 .604 r
.44059 .45651 .44129 .46552 .43819 .65245 .44214 .45673 Mtetra
.556 .343 .546 r
.44214 .45673 .43819 .65245 .43982 .65304 .44371 .45628 Mtetra
.44371 .45628 .43982 .65304 .44152 .65115 .44528 .45559 Mtetra
.557 .344 .546 r
.44528 .45559 .44152 .65115 .44326 .64732 .44687 .45466 Mtetra
.44687 .45466 .44326 .64732 .44504 .64189 .44845 .45372 Mtetra
.556 .343 .546 r
.44845 .45372 .44504 .64189 .44667 .64307 .45002 .45337 Mtetra
.552 .339 .546 r
.45002 .45337 .44667 .64307 .44813 .65148 .45154 .45518 Mtetra
0 0 .344 r
.45154 .45518 .44813 .65148 .44969 .65615 .4489 .64732 Mtetra
0 0 .425 r
.4489 .64732 .44969 .65615 .45131 .65836 .45037 .65614 Mtetra
.049 .219 .719 r
.45037 .65614 .45131 .65836 .45296 .65908 .452 .65796 Mtetra
.582 .689 .915 r
.452 .65796 .45296 .65908 .45463 .65876 .45367 .65774 Mtetra
.698 .749 .891 r
.45367 .65774 .45463 .65876 .45631 .65815 .45536 .65702 Mtetra
.704 .731 .872 r
.45536 .65702 .45631 .65815 .45799 .65751 .45704 .65625 Mtetra
.657 .694 .873 r
.45704 .65625 .45799 .65751 .45967 .65701 .45872 .65573 Mtetra
.658 .69 .869 r
.45872 .65573 .45967 .65701 .46135 .6565 .4604 .6552 Mtetra
.654 .685 .867 r
.4604 .6552 .46135 .6565 .46304 .65601 .46209 .65468 Mtetra
.647 .679 .867 r
.46209 .65468 .46304 .65601 .46472 .65553 .46377 .6542 Mtetra
.643 .677 .867 r
.46377 .6542 .46472 .65553 .4664 .65507 .46545 .65374 Mtetra
.64 .676 .868 r
.46545 .65374 .4664 .65507 .46809 .65463 .46714 .6533 Mtetra
.637 .675 .869 r
.46714 .6533 .46809 .65463 .46977 .65419 .46882 .65287 Mtetra
.635 .675 .871 r
.46882 .65287 .46977 .65419 .47146 .65376 .47051 .65245 Mtetra
.622 .672 .876 r
.47051 .65245 .47146 .65376 .47314 .65344 .4722 .65209 Mtetra
.609 .659 .874 r
.4722 .65209 .47314 .65344 .47483 .65324 .47388 .65178 Mtetra
.637 .655 .852 r
.47388 .65178 .47483 .65324 .47652 .65274 .47557 .65135 Mtetra
.701 .69 .836 r
.47557 .65135 .47652 .65274 .47822 .65133 .47727 .65053 Mtetra
.814 .81 .847 r
.47727 .65053 .47822 .65133 .47995 .64782 .47897 .64907 Mtetra
0 0 0 r
.47897 .64907 .47995 .64782 .48174 .63974 .48068 .64735 Mtetra
.466 .213 .445 r
.48068 .64735 .48174 .63974 .4857 .44985 .48239 .64588 Mtetra
.553 .337 .54 r
.48239 .64588 .4857 .44985 .48731 .44841 .48408 .64534 Mtetra
.554 .337 .54 r
.48408 .64534 .48731 .44841 .48889 .44892 .48578 .64512 Mtetra
.48578 .64512 .48889 .44892 .49047 .45021 .48747 .64492 Mtetra
.48747 .64492 .49047 .45021 .49207 .45009 .48917 .64453 Mtetra
.48917 .64453 .49207 .45009 .49367 .45028 .49086 .64416 Mtetra
.49086 .64416 .49367 .45028 .49526 .45146 .49256 .64386 Mtetra
.49256 .64386 .49526 .45146 .4968 .45774 .49426 .64367 Mtetra
.49426 .64367 .4968 .45774 .49703 .62911 .49596 .64347 Mtetra
.542 .301 .5 r
.49596 .64347 .49703 .62911 .4987 .63193 .49766 .64319 Mtetra
.534 .287 .487 r
.49766 .64319 .4987 .63193 .50039 .63229 .49937 .64279 Mtetra
.531 .282 .483 r
.49937 .64279 .50039 .63229 .50209 .63214 .50107 .64234 Mtetra
.53 .28 .481 r
.50107 .64234 .50209 .63214 .50379 .63183 .50278 .64188 Mtetra
.529 .279 .48 r
.50278 .64188 .50379 .63183 .50549 .63159 .50449 .64142 Mtetra
.528 .277 .479 r
.50449 .64142 .50549 .63159 .50719 .63129 .5062 .64096 Mtetra
.528 .276 .477 r
.5062 .64096 .50719 .63129 .50889 .63095 .50791 .64048 Mtetra
.527 .275 .476 r
.50791 .64048 .50889 .63095 .5106 .63058 .50962 .64001 Mtetra
.527 .274 .476 r
.50962 .64001 .5106 .63058 .5123 .63018 .51133 .63953 Mtetra
.526 .274 .475 r
.51133 .63953 .5123 .63018 .51401 .62978 .51304 .63904 Mtetra
.526 .273 .474 r
.51304 .63904 .51401 .62978 .51572 .62936 .51476 .63856 Mtetra
.51476 .63856 .51572 .62936 .51743 .62894 .51647 .63808 Mtetra
.526 .272 .473 r
.51647 .63808 .51743 .62894 .51914 .62853 .51819 .63759 Mtetra
.51819 .63759 .51914 .62853 .52085 .62813 .51991 .63711 Mtetra
.525 .271 .472 r
.51991 .63711 .52085 .62813 .52257 .62775 .52163 .63663 Mtetra
.525 .27 .471 r
.52163 .63663 .52257 .62775 .52428 .6274 .52335 .63616 Mtetra
.525 .27 .47 r
.52335 .63616 .52428 .6274 .52599 .62711 .52507 .6357 Mtetra
.525 .268 .469 r
.52507 .6357 .52599 .62711 .52771 .62685 .52679 .63523 Mtetra
.527 .27 .468 r
.52679 .63523 .52771 .62685 .52943 .62687 .52851 .63485 Mtetra
.541 .279 .467 r
.52851 .63485 .52943 .62687 .53115 .62781 .53024 .63481 Mtetra
.518 .252 .451 r
.53024 .63481 .53115 .62781 .53287 .62759 .53196 .63436 Mtetra
.454 .196 .432 r
.53196 .63436 .53287 .62759 .53459 .62458 .53369 .63286 Mtetra
.137 0 .35 r
.53369 .63286 .53459 .62458 .53568 .43358 .5354 .6266 Mtetra
0 0 .358 r
.5354 .6266 .53568 .43358 .53729 .42804 .53642 .42963 Mtetra
.935 .886 .476 r
.53642 .42963 .53729 .42804 .5389 .42544 .53803 .42464 Mtetra
.775 .804 .877 r
.53803 .42464 .5389 .42544 .54053 .42462 .53966 .42354 Mtetra
.641 .713 .9 r
.53966 .42354 .54053 .42462 .54216 .4242 .54129 .42311 Mtetra
.564 .681 .918 r
.54129 .42311 .54216 .4242 .54379 .42394 .54292 .42296 Mtetra
.652 .738 .912 r
.54292 .42296 .54379 .42394 .54541 .42347 .54455 .42248 Mtetra
.65 .735 .911 r
.54455 .42248 .54541 .42347 .54704 .42299 .54618 .422 Mtetra
.656 .738 .911 r
.54618 .422 .54704 .42299 .54868 .42247 .54781 .42151 Mtetra
.679 .749 .904 r
.54781 .42151 .54868 .42247 .55031 .42188 .54944 .42091 Mtetra
.683 .749 .901 r
.54944 .42091 .55031 .42188 .55194 .42127 .55107 .42029 Mtetra
.69 .751 .898 r
.55107 .42029 .55194 .42127 .55357 .42061 .55271 .41963 Mtetra
.753 .767 .864 r
.55271 .41963 .55357 .42061 .5552 .41972 .55434 .41862 Mtetra
.682 .724 .882 r
.55434 .41862 .5552 .41972 .55684 .41906 .55597 .41799 Mtetra
.444 .629 .933 r
.55597 .41799 .55684 .41906 .55848 .41888 .55762 .41817 Mtetra
.905 .494 .143 r
.55762 .41817 .55848 .41888 .56013 .42015 .55931 .42256 Mtetra
.961 .68 .457 r
.55931 .42256 .56013 .42015 .56182 .42389 .56314 .61912 Mtetra
.563 .344 .541 r
.56314 .61912 .56182 .42389 .56576 .61655 .56495 .62417 Mtetra
.583 .312 .472 r
.56495 .62417 .56576 .61655 .56759 .62297 .56671 .62516 Mtetra
.532 .163 .286 r
.56671 .62516 .56759 .62297 .56937 .62535 .56847 .6254 Mtetra
.095 .652 .736 r
.56847 .6254 .56937 .62535 .57114 .62642 .57022 .62523 Mtetra
.63 .702 .898 r
.57022 .62523 .57114 .62642 .5729 .62619 .57198 .62481 Mtetra
.662 .683 .86 r
.57198 .62481 .5729 .62619 .57465 .62559 .57373 .62423 Mtetra
.677 .691 .856 r
.57373 .62423 .57465 .62559 .5764 .6248 .57548 .62356 Mtetra
.658 .704 .882 r
.57548 .62356 .5764 .6248 .57815 .62426 .57723 .62301 Mtetra
.66 .704 .88 r
.57723 .62301 .57815 .62426 .5799 .62369 .57899 .62245 Mtetra
.664 .707 .879 r
.57899 .62245 .5799 .62369 .58166 .62309 .58075 .62187 Mtetra
.679 .715 .876 r
.58075 .62187 .58166 .62309 .58341 .62237 .5825 .62121 Mtetra
.683 .727 .884 r
.5825 .62121 .58341 .62237 .58517 .62162 .58426 .62053 Mtetra
.684 .741 .894 r
.58426 .62053 .58517 .62162 .58692 .62088 .58601 .61986 Mtetra
.669 .75 .911 r
.58601 .61986 .58692 .62088 .58868 .62026 .58777 .61926 Mtetra
.665 .753 .916 r
.58777 .61926 .58868 .62026 .59044 .61967 .58953 .61868 Mtetra
.663 .755 .918 r
.58953 .61868 .59044 .61967 .5922 .6191 .5913 .61811 Mtetra
.666 .756 .917 r
.5913 .61811 .5922 .6191 .59396 .61851 .59306 .61752 Mtetra
.669 .757 .916 r
.59306 .61752 .59396 .61851 .59573 .61791 .59482 .61692 Mtetra
.674 .759 .915 r
.59482 .61692 .59573 .61791 .59749 .61727 .59659 .61629 Mtetra
.689 .767 .911 r
.59659 .61629 .59749 .61727 .59925 .61653 .59835 .6156 Mtetra
.692 .779 .918 r
.59835 .6156 .59925 .61653 .60101 .61575 .60012 .61489 Mtetra
.69 .794 .929 r
.60012 .61489 .60101 .61575 .60278 .61497 .60188 .61419 Mtetra
.63 .795 .962 r
.60188 .61419 .60278 .61497 .60455 .61463 .60365 .61371 Mtetra
.652 .77 .935 r
.60365 .61371 .60455 .61463 .60632 .61411 .60542 .61318 Mtetra
.697 .78 .916 r
.60542 .61318 .60632 .61411 .60808 .61309 .60719 .61245 Mtetra
.841 .861 .859 r
.60719 .61245 .60808 .61309 .60978 .6094 .60894 .61085 Mtetra
0 0 0 r
.60894 .61085 .60978 .6094 .61121 .59528 .61067 .60871 Mtetra
.477 .247 .486 r
.61067 .60871 .61121 .59528 .60812 .40651 .6124 .60616 Mtetra
.552 .336 .54 r
.6124 .60616 .60812 .40651 .60975 .40468 .61415 .60488 Mtetra
.553 .337 .54 r
.61415 .60488 .60975 .40468 .61142 .40413 .61593 .60433 Mtetra
.554 .337 .54 r
.61593 .60433 .61142 .40413 .61311 .4041 .61771 .60409 Mtetra
.553 .336 .54 r
.61771 .60409 .61311 .4041 .61476 .40302 .61947 .60302 Mtetra
.61947 .60302 .61476 .40302 .61643 .40219 .62124 .60204 Mtetra
.554 .337 .54 r
.62124 .60204 .61643 .40219 .61812 .40219 .62302 .60172 Mtetra
.557 .339 .541 r
.62302 .60172 .61812 .40219 .61998 .40797 .62486 .6033 Mtetra
.557 .339 .54 r
.62486 .6033 .61998 .40797 .62749 .60219 .6267 .6047 Mtetra
.6 .243 .335 r
.6267 .6047 .62749 .60219 .62941 .60616 .62853 .60555 Mtetra
.466 .775 .997 r
.62853 .60555 .62941 .60616 .63123 .60663 .63033 .60541 Mtetra
.645 .706 .891 r
.63033 .60541 .63123 .60663 .63302 .60623 .63212 .60491 Mtetra
.662 .696 .871 r
.63212 .60491 .63302 .60623 .6348 .60556 .63391 .60432 Mtetra
.612 .69 .899 r
.63391 .60432 .6348 .60556 .6366 .60528 .6357 .60398 Mtetra
.595 .672 .894 r
.6357 .60398 .6366 .60528 .6384 .60509 .6375 .60372 Mtetra
.597 .66 .882 r
.6375 .60372 .6384 .60509 .6402 .60487 .6393 .60345 Mtetra
.583 .646 .878 r
.6393 .60345 .6402 .60487 .64201 .60481 .64111 .60325 Mtetra
.607 .637 .855 r
.64111 .60325 .64201 .60481 .64382 .60454 .64291 .60295 Mtetra
.646 .651 .84 r
.64291 .60295 .64382 .60454 .64561 .60381 .64471 .60242 Mtetra
.705 .702 .845 r
.64471 .60242 .64561 .60381 .64734 .60158 .6465 .60156 Mtetra
.789 .99 .886 r
.6465 .60156 .64734 .60158 .649 .59707 .64826 .60015 Mtetra
.141 0 .214 r
.64826 .60015 .649 .59707 .64365 .40261 .64999 .5977 Mtetra
.536 .324 .538 r
.64999 .5977 .64365 .40261 .64502 .39326 .65141 .58681 Mtetra
0 0 .407 r
.65141 .58681 .64502 .39326 .64661 .39006 .64587 .39149 Mtetra
.814 .852 .396 r
.64587 .39149 .64661 .39006 .64824 .38813 .64743 .38747 Mtetra
.817 .855 .876 r
.64743 .38747 .64824 .38813 .64992 .38726 .64909 .38613 Mtetra
.638 .71 .899 r
.64909 .38613 .64992 .38726 .65162 .38688 .65079 .3857 Mtetra
.552 .661 .908 r
.65079 .3857 .65162 .38688 .65333 .3867 .6525 .3856 Mtetra
.616 .704 .908 r
.6525 .3856 .65333 .3867 .65503 .38632 .6542 .38525 Mtetra
.653 .727 .903 r
.6542 .38525 .65503 .38632 .65672 .3858 .6559 .38475 Mtetra
.662 .735 .904 r
.6559 .38475 .65672 .3858 .65842 .38521 .65759 .3842 Mtetra
.698 .755 .896 r
.65759 .3842 .65842 .38521 .6601 .38431 .65928 .38349 Mtetra
.702 .798 .925 r
.65928 .38349 .6601 .38431 .66178 .38346 .66097 .38277 Mtetra
.659 .821 .961 r
.66097 .38277 .66178 .38346 .66348 .38295 .66267 .38219 Mtetra
.452 .717 .981 r
.66267 .38219 .66348 .38295 .66525 .38387 .6644 .38219 Mtetra
.446 .524 .844 r
.6644 .38219 .66525 .38387 .6671 .38683 .66614 .38263 Mtetra
.509 .41 .677 r
.66614 .38263 .6671 .38683 .67714 .57218 .6679 .38327 Mtetra
.556 .343 .546 r
.6679 .38327 .67714 .57218 .67949 .58354 .66961 .38282 Mtetra
.557 .343 .546 r
.66961 .38282 .67949 .58354 .68128 .58244 .6713 .38195 Mtetra
.556 .343 .546 r
.6713 .38195 .68128 .58244 .68307 .58132 .67302 .38169 Mtetra
.548 .337 .546 r
.67302 .38169 .68307 .58132 .68513 .58599 .67495 .38597 Mtetra
.029 0 .429 r
.67495 .38597 .68513 .58599 .68713 .58933 .6861 .58493 Mtetra
0 .061 .575 r
.6861 .58493 .68713 .58933 .68906 .59105 .68817 .58954 Mtetra
.282 .47 .867 r
.68817 .58954 .68906 .59105 .69092 .5913 .69006 .5904 Mtetra
.616 .765 .951 r
.69006 .5904 .69092 .5913 .69275 .59084 .6919 .58997 Mtetra
.708 .806 .926 r
.6919 .58997 .69275 .59084 .69457 .59016 .69371 .58917 Mtetra
.662 .763 .925 r
.69371 .58917 .69457 .59016 .69641 .58969 .69554 .58858 Mtetra
.622 .722 .918 r
.69554 .58858 .69641 .58969 .69825 .58937 .69738 .58817 Mtetra
.631 .708 .902 r
.69738 .58817 .69825 .58937 .70009 .589 .69921 .58772 Mtetra
.639 .698 .888 r
.69921 .58772 .70009 .589 .70193 .58864 .70105 .58725 Mtetra
.655 .686 .867 r
.70105 .58725 .70193 .58864 .70377 .58813 .70288 .58668 Mtetra
.681 .688 .85 r
.70288 .58668 .70377 .58813 .70558 .58726 .70471 .58595 Mtetra
.752 .735 .836 r
.70471 .58595 .70558 .58726 .70733 .58513 .70651 .58475 Mtetra
.856 .931 .875 r
.70651 .58475 .70733 .58513 .70897 .58094 .70829 .58309 Mtetra
.114 0 .119 r
.70829 .58309 .70897 .58094 .71014 .56815 .71005 .58124 Mtetra
.514 .276 .491 r
.71005 .58124 .71014 .56815 .7016 .37979 .71185 .57993 Mtetra
.553 .337 .54 r
.71185 .57993 .7016 .37979 .7033 .37867 .71369 .57933 Mtetra
.554 .337 .54 r
.71369 .57933 .7033 .37867 .70509 .3793 .71554 .57899 Mtetra
.71554 .57899 .70509 .3793 .70688 .37968 .71739 .57857 Mtetra
.71739 .57857 .70688 .37968 .70861 .37916 .71923 .57804 Mtetra
.553 .337 .54 r
.71923 .57804 .70861 .37916 .71035 .37864 .72108 .5775 Mtetra
.72108 .5775 .71035 .37864 .71208 .37805 .72292 .57694 Mtetra
.72292 .57694 .71208 .37805 .7138 .37739 .72476 .57637 Mtetra
.72476 .57637 .7138 .37739 .71553 .37672 .72661 .5758 Mtetra
.72661 .5758 .71553 .37672 .71726 .37608 .72846 .57523 Mtetra
.72846 .57523 .71726 .37608 .719 .37547 .73031 .57468 Mtetra
.73031 .57468 .719 .37547 .72074 .37491 .73216 .57414 Mtetra
.554 .337 .54 r
.73216 .57414 .72074 .37491 .72248 .37441 .73401 .57362 Mtetra
.73401 .57362 .72248 .37441 .72423 .37397 .73587 .57312 Mtetra
.73587 .57312 .72423 .37397 .72598 .37356 .73773 .57262 Mtetra
.73773 .57262 .72598 .37356 .72781 .37433 .73961 .5725 Mtetra
.73961 .5725 .72781 .37433 .72971 .37625 .7415 .57244 Mtetra
.553 .337 .54 r
.7415 .57244 .72971 .37625 .73138 .37452 .74334 .57163 Mtetra
.548 .333 .54 r
.74334 .57163 .73138 .37452 .73274 .36792 .74497 .56751 Mtetra
.052 0 .436 r
.74497 .56751 .73274 .36792 .73421 .36327 .73371 .36666 Mtetra
0 0 .004 r
.73371 .36666 .73421 .36327 .73581 .36046 .73506 .36012 Mtetra
.925 .918 .79 r
.73506 .36012 .73581 .36046 .73749 .35895 .7367 .35784 Mtetra
.69 .739 .888 r
.7367 .35784 .73749 .35895 .73923 .35832 .73843 .35714 Mtetra
.594 .684 .905 r
.73843 .35714 .73923 .35832 .74099 .35798 .7402 .35688 Mtetra
.575 .694 .922 r
.7402 .35688 .74099 .35798 .74276 .3577 .74197 .35667 Mtetra
.613 .725 .925 r
.74197 .35667 .74276 .3577 .74452 .35737 .74373 .35631 Mtetra
.615 .718 .919 r
.74373 .35631 .74452 .35737 .74629 .35704 .7455 .35594 Mtetra
.636 .719 .908 r
.7455 .35594 .74629 .35704 .74805 .35661 .74726 .35549 Mtetra
.662 .728 .898 r
.74726 .35549 .74805 .35661 .7498 .35602 .74901 .35492 Mtetra
.672 .735 .897 r
.74901 .35492 .7498 .35602 .75154 .35538 .75076 .35431 Mtetra
.723 .759 .881 r
.75076 .35431 .75154 .35538 .75327 .35449 .75249 .35343 Mtetra
.746 .77 .872 r
.75249 .35343 .75327 .35449 .75499 .35347 .75421 .35242 Mtetra
.648 .737 .915 r
.75421 .35242 .75499 .35347 .75675 .35296 .75597 .35192 Mtetra
0 .312 .801 r
.75597 .35192 .75675 .35296 .75865 .35423 .75787 .3532 Mtetra
.95 .6 .227 r
.75787 .3532 .75865 .35423 .76138 .36687 .76063 .36622 Mtetra
.975 .673 .364 r
.76063 .36622 .76138 .36687 .77785 .56303 .77703 .56206 Mtetra
.559 .088 0 r
.77703 .56206 .77785 .56303 .77997 .56562 .77915 .56464 Mtetra
.448 .674 .96 r
.77915 .56464 .77997 .56562 .7819 .56572 .78108 .56474 Mtetra
.728 .794 .904 r
.78108 .56474 .7819 .56572 .78376 .56479 .78294 .5638 Mtetra
.901 .814 .752 r
.78294 .5638 .78376 .56479 .78547 .56202 .78466 .56104 Mtetra
.979 .746 .517 r
.78466 .56104 .78547 .56202 .78658 .5514 .78577 .55052 Mtetra
.977 .681 .375 r
.78577 .55052 .78658 .5514 .77283 .35073 .77205 .34969 Mtetra
.926 .791 .693 r
.77205 .34969 .77283 .35073 .77437 .34725 .77359 .3462 Mtetra
.722 .765 .887 r
.77359 .3462 .77437 .34725 .77611 .34639 .77534 .34533 Mtetra
.594 .715 .928 r
.77534 .34533 .77611 .34639 .7779 .34609 .77713 .34504 Mtetra
.623 .727 .921 r
.77713 .34504 .7779 .34609 .77968 .34569 .77891 .34463 Mtetra
.737 .769 .879 r
.77891 .34463 .77968 .34569 .78142 .34473 .78065 .34367 Mtetra
.645 .735 .914 r
.78065 .34367 .78142 .34473 .7832 .34424 .78243 .34318 Mtetra
.089 .416 .865 r
.78243 .34318 .7832 .34424 .7851 .34526 .78433 .34419 Mtetra
.922 .549 .131 r
.78433 .34419 .7851 .34526 .78768 .35443 .78691 .35333 Mtetra
.975 .67 .349 r
.78691 .35333 .78768 .35443 .80617 .55442 .80536 .5534 Mtetra
.599 .139 0 r
.80536 .5534 .80617 .55442 .80836 .55738 .80756 .55636 Mtetra
.426 .655 .955 r
.80756 .55636 .80836 .55738 .81033 .55756 .80952 .55654 Mtetra
.719 .787 .906 r
.80952 .55654 .81033 .55756 .8122 .55665 .8114 .55565 Mtetra
.897 .816 .76 r
.8114 .55565 .8122 .55665 .81393 .55396 .81313 .553 Mtetra
.982 .746 .503 r
.81313 .553 .81393 .55396 .81485 .54196 .81414 .54204 Mtetra
.978 .679 .359 r
.81414 .54204 .81485 .54196 .7994 .34147 .79866 .34069 Mtetra
.953 .823 .678 r
.79866 .34069 .7994 .34147 .80092 .33791 .80017 .33699 Mtetra
.761 .806 .889 r
.80017 .33699 .80092 .33791 .80268 .337 .80191 .33592 Mtetra
.571 .698 .928 r
.80191 .33592 .80268 .337 .8045 .33683 .80373 .33571 Mtetra
.104 .413 .862 r
.80373 .33571 .8045 .33683 .80639 .33741 .80566 .33676 Mtetra
.871 .446 .022 r
.80566 .33676 .80639 .33741 .80838 .33919 .80799 .34216 Mtetra
.973 .665 .352 r
.80799 .34216 .80838 .33919 .81052 .3424 .82792 .54307 Mtetra
.558 .34 .54 r
.82792 .54307 .81052 .3424 .81254 .34434 .83009 .54536 Mtetra
.531 .321 .539 r
.83009 .54536 .81254 .34434 .81387 .33868 .83068 .53023 Mtetra
.086 .004 .457 r
.83068 .53023 .81387 .33868 .81539 .33513 .81478 .3357 Mtetra
.915 .917 .528 r
.81478 .3357 .81539 .33513 .81704 .33303 .8163 .33207 Mtetra
.722 .79 .906 r
.8163 .33207 .81704 .33303 .81883 .33236 .81807 .33121 Mtetra
.621 .709 .909 r
.81807 .33121 .81883 .33236 .82064 .33196 .81988 .33082 Mtetra
.623 .71 .909 r
.81988 .33082 .82064 .33196 .82244 .33146 .82169 .33042 Mtetra
.761 .784 .871 r
.82169 .33042 .82244 .33146 .82418 .33029 .82344 .32931 Mtetra
.692 .773 .913 r
.82344 .32931 .82418 .33029 .82596 .32952 .82523 .32859 Mtetra
.354 .621 .953 r
.82523 .32859 .82596 .32952 .82784 .32978 .82711 .32892 Mtetra
.812 .378 0 r
.82711 .32892 .82784 .32978 .83014 .3343 .82943 .33365 Mtetra
.974 .664 .327 r
.82943 .33365 .83014 .3343 .85185 .53841 .85109 .5376 Mtetra
.797 .35 0 r
.85109 .5376 .85185 .53841 .8543 .54319 .85352 .54215 Mtetra
.5 .691 .954 r
.85352 .54215 .8543 .54319 .85629 .5432 .8555 .54212 Mtetra
.697 .771 .909 r
.8555 .54212 .85629 .5432 .85821 .54245 .85741 .54133 Mtetra
.733 .776 .887 r
.85741 .54133 .85821 .54245 .86011 .54152 .85931 .54032 Mtetra
.581 .697 .921 r
.85931 .54032 .86011 .54152 .8621 .5415 .86128 .54006 Mtetra
.614 .67 .88 r
.86128 .54006 .8621 .5415 .86406 .54118 .86323 .53969 Mtetra
.659 .683 .861 r
.86323 .53969 .86406 .54118 .86596 .54018 .86517 .53906 Mtetra
.74 .778 .883 r
.86517 .53906 .86596 .54018 .86765 .53723 .86706 .53801 Mtetra
0 0 0 r
.86706 .53801 .86765 .53723 .86901 .531 .86888 .5363 Mtetra
.292 .06 .38 r
.86888 .5363 .86901 .531 .85033 .33064 .87054 .53294 Mtetra
.117 .029 .471 r
.87054 .53294 .85033 .33064 .85163 .32509 .85176 .33239 Mtetra
0 0 .327 r
.85176 .33239 .85163 .32509 .85323 .32236 .85265 .32285 Mtetra
.877 .929 .544 r
.85265 .32285 .85323 .32236 .85493 .32071 .8542 .3197 Mtetra
.712 .78 .905 r
.8542 .3197 .85493 .32071 .85674 .32008 .856 .31888 Mtetra
.599 .689 .906 r
.856 .31888 .85674 .32008 .85859 .31979 .85784 .31858 Mtetra
.539 .66 .914 r
.85784 .31858 .85859 .31979 .86046 .31962 .85972 .31852 Mtetra
.642 .731 .913 r
.85972 .31852 .86046 .31962 .86229 .31911 .86155 .31802 Mtetra
.654 .739 .912 r
.86155 .31802 .86229 .31911 .86411 .31852 .86338 .31747 Mtetra
.67 .753 .913 r
.86338 .31747 .86411 .31852 .86592 .31784 .8652 .31684 Mtetra
.719 .785 .904 r
.8652 .31684 .86592 .31784 .86769 .31677 .867 .31599 Mtetra
.702 .83 .943 r
.867 .31599 .86769 .31677 .86949 .31594 .8688 .31521 Mtetra
.645 .825 .969 r
.8688 .31521 .86949 .31594 .87135 .31559 .87063 .31463 Mtetra
.553 .724 .954 r
.87063 .31463 .87135 .31559 .87339 .31695 .8725 .31443 Mtetra
.518 .49 .765 r
.8725 .31443 .87339 .31695 .87571 .32072 .87443 .31476 Mtetra
.48 .363 .643 r
.87443 .31476 .87571 .32072 .89994 .51978 .87649 .3162 Mtetra
.172 .075 .495 r
.87649 .3162 .89994 .51978 .90263 .52568 .89908 .49984 Mtetra
.148 .076 .513 r
.89908 .49984 .90263 .52568 .90489 .52774 .90389 .52455 Mtetra
.161 .233 .69 r
.90389 .52455 .90489 .52774 .90703 .52863 .90626 .52752 Mtetra
.316 .569 .929 r
.90626 .52752 .90703 .52863 .90911 .52905 .90835 .52807 Mtetra
.606 .761 .953 r
.90835 .52807 .90911 .52905 .91111 .52872 .91034 .52765 Mtetra
.797 .809 .861 r
.91034 .52765 .91111 .52872 .913 .5275 .91221 .52621 Mtetra
.894 .718 .657 r
.27888 .70673 .27988 .70789 .28178 .7027 .2808 .70126 Mtetra
.935 .685 .535 r
.2808 .70126 .28178 .7027 .2967 .50749 .29577 .50616 Mtetra
.89 .704 .645 r
.29577 .50616 .2967 .50749 .29857 .5013 .29762 .50038 Mtetra
.771 .753 .837 r
.29762 .50038 .29857 .5013 .30011 .50015 .29915 .49925 Mtetra
.642 .736 .917 r
.29915 .49925 .30011 .50015 .30159 .49974 .30063 .49885 Mtetra
.513 .694 .95 r
.30063 .49885 .30159 .49974 .30305 .4997 .30209 .4988 Mtetra
.749 .757 .859 r
.30209 .4988 .30305 .4997 .30457 .49876 .30361 .49787 Mtetra
.696 .75 .894 r
.30361 .49787 .30457 .49876 .30607 .49812 .30511 .49724 Mtetra
.475 .68 .955 r
.30511 .49724 .30607 .49812 .30753 .49815 .30657 .49727 Mtetra
.928 .551 .261 r
.30657 .49727 .30753 .49815 .30873 .50223 .30777 .50136 Mtetra
.939 .683 .523 r
.30777 .50136 .30873 .50223 .29764 .69657 .29662 .69575 Mtetra
.934 .579 .324 r
.29662 .69575 .29764 .69657 .29885 .70182 .29783 .70097 Mtetra
0 .359 .804 r
.29783 .70097 .29885 .70182 .30036 .70261 .29934 .70176 Mtetra
.626 .756 .94 r
.29934 .70176 .30036 .70261 .30194 .70223 .30092 .70138 Mtetra
.804 .778 .829 r
.30092 .70138 .30194 .70223 .30359 .7008 .30257 .69994 Mtetra
.907 .739 .661 r
.30257 .69994 .30359 .7008 .30546 .69574 .30446 .69471 Mtetra
.939 .687 .53 r
.30446 .69471 .30546 .69574 .31911 .50041 .31819 .49908 Mtetra
.894 .706 .641 r
.31819 .49908 .31911 .50041 .32097 .49415 .32003 .49308 Mtetra
.773 .73 .813 r
.32003 .49308 .32097 .49415 .32252 .49286 .32158 .49184 Mtetra
.624 .704 .902 r
.32158 .49184 .32252 .49286 .32401 .49248 .32307 .4915 Mtetra
.479 .658 .94 r
.32307 .4915 .32401 .49248 .32549 .4925 .32454 .49157 Mtetra
.635 .728 .915 r
.32454 .49157 .32549 .4925 .32698 .4921 .32604 .49119 Mtetra
.662 .738 .907 r
.32604 .49119 .32698 .4921 .32849 .49161 .32754 .4907 Mtetra
.669 .742 .906 r
.32754 .4907 .32849 .49161 .33 .49107 .32905 .49019 Mtetra
.755 .763 .86 r
.32905 .49019 .33 .49107 .33153 .49001 .33058 .48922 Mtetra
.719 .779 .9 r
.33058 .48922 .33153 .49001 .33306 .48918 .3321 .48849 Mtetra
.502 .743 .981 r
.3321 .48849 .33306 .48918 .33455 .48899 .33359 .48839 Mtetra
.903 .501 .222 r
.33359 .48839 .33455 .48899 .33585 .49212 .33487 .49175 Mtetra
.941 .683 .517 r
.33487 .49175 .33585 .49212 .32634 .68639 .3253 .68619 Mtetra
.918 .58 .387 r
.3253 .68619 .32634 .68639 .32753 .69317 .32652 .69237 Mtetra
0 .176 .636 r
.32652 .69237 .32753 .69317 .32904 .69429 .32803 .69344 Mtetra
.593 .747 .95 r
.32803 .69344 .32904 .69429 .33064 .69401 .32963 .69315 Mtetra
.793 .78 .841 r
.32963 .69315 .33064 .69401 .33229 .69269 .33128 .69182 Mtetra
.905 .746 .674 r
.33128 .69182 .33229 .69269 .33411 .68821 .33311 .68722 Mtetra
.942 .688 .524 r
.33311 .68722 .33411 .68821 .34621 .49296 .34529 .49153 Mtetra
.9 .703 .626 r
.34529 .49153 .34621 .49296 .34809 .48563 .34716 .48455 Mtetra
.798 .734 .792 r
.34716 .48455 .34809 .48563 .34967 .48405 .34873 .48301 Mtetra
.637 .707 .897 r
.34873 .48301 .34967 .48405 .35118 .48362 .35024 .48263 Mtetra
.49 .661 .938 r
.35024 .48263 .35118 .48362 .35267 .48361 .35173 .48267 Mtetra
.614 .721 .922 r
.35173 .48267 .35267 .48361 .35418 .48328 .35324 .48236 Mtetra
.659 .739 .909 r
.35324 .48236 .35418 .48328 .3557 .48279 .35476 .48188 Mtetra
.666 .744 .908 r
.35476 .48188 .3557 .48279 .35722 .48226 .35628 .48138 Mtetra
.749 .766 .866 r
.35628 .48138 .35722 .48226 .35877 .48123 .35783 .48044 Mtetra
.728 .782 .896 r
.35783 .48044 .35877 .48123 .36031 .48036 .35936 .47966 Mtetra
.539 .758 .977 r
.35936 .47966 .36031 .48036 .36182 .48007 .36087 .47948 Mtetra
.882 .451 .147 r
.36087 .47948 .36182 .48007 .3632 .48267 .36223 .48237 Mtetra
.944 .683 .51 r
.36223 .48237 .3632 .48267 .35532 .67611 .35425 .67681 Mtetra
.893 .569 .428 r
.35425 .67681 .35532 .67611 .35651 .68444 .3555 .68384 Mtetra
.367 0 0 r
.3555 .68384 .35651 .68444 .35806 .68558 .35706 .68477 Mtetra
.646 .774 .941 r
.35706 .68477 .35806 .68558 .35967 .68521 .35868 .68429 Mtetra
.742 .769 .875 r
.35868 .68429 .35967 .68521 .36132 .68424 .36032 .68336 Mtetra
.575 .736 .952 r
.36032 .68336 .36132 .68424 .36296 .68331 .36193 .68312 Mtetra
.302 .776 .93 r
.36193 .68312 .36296 .68331 .36461 .68215 .36354 .68296 Mtetra
0 0 0 r
.36354 .68296 .36461 .68215 .3663 .68021 .36518 .68217 Mtetra
.8 .88 .45 r
.36518 .68217 .3663 .68021 .36819 .67393 .36695 .67842 Mtetra
.953 .696 .511 r
.36695 .67842 .36819 .67393 .37838 .48021 .37725 .48379 Mtetra
.968 .843 .433 r
.37725 .48379 .37838 .48021 .38011 .47537 .37917 .47455 Mtetra
.851 .779 .78 r
.37917 .47455 .38011 .47537 .38169 .47378 .38077 .47256 Mtetra
.668 .686 .858 r
.38077 .47256 .38169 .47378 .38322 .47327 .38231 .47202 Mtetra
.558 .638 .886 r
.38231 .47202 .38322 .47327 .38475 .47311 .38383 .47194 Mtetra
.6 .67 .888 r
.38383 .47194 .38475 .47311 .38627 .47279 .38535 .47169 Mtetra
.641 .699 .888 r
.38535 .47169 .38627 .47279 .38781 .47231 .38689 .47128 Mtetra
.646 .715 .898 r
.38689 .47128 .38781 .47231 .38935 .47179 .38842 .47086 Mtetra
.664 .74 .907 r
.38842 .47086 .38935 .47179 .3909 .47108 .38996 .47035 Mtetra
.677 .792 .935 r
.38996 .47035 .3909 .47108 .39245 .47034 .39151 .46979 Mtetra
.676 .84 .962 r
.39151 .46979 .39245 .47034 .39399 .46974 .39305 .46921 Mtetra
.751 .852 .926 r
.39305 .46921 .39399 .46974 .39553 .46942 .39461 .46834 Mtetra
.72 .725 .854 r
.39461 .46834 .39553 .46942 .39705 .46953 .39617 .46752 Mtetra
.616 .568 .778 r
.39617 .46752 .39705 .46953 .39854 .47037 .3977 .46718 Mtetra
.275 .282 .686 r
.3977 .46718 .39854 .47037 .3999 .47478 .39916 .46887 Mtetra
.812 .582 .023 r
.39916 .46887 .3999 .47478 .39417 .66871 .40029 .47965 Mtetra
0 0 .303 r
.40029 .47965 .39417 .66871 .39562 .67329 .39472 .67005 Mtetra
.263 .281 .692 r
.39472 .67005 .39562 .67329 .39721 .67423 .39628 .67183 Mtetra
.621 .553 .756 r
.39628 .67183 .39721 .67423 .39885 .67381 .39792 .6714 Mtetra
.677 .583 .742 r
.39792 .6714 .39885 .67381 .40051 .67294 .39959 .67045 Mtetra
.626 .55 .749 r
.39959 .67045 .40051 .67294 .40217 .67211 .40123 .66997 Mtetra
.557 .539 .79 r
.40123 .66997 .40217 .67211 .40382 .67142 .40286 .66999 Mtetra
.545 .617 .875 r
.40286 .66999 .40382 .67142 .40548 .67073 .40449 .66997 Mtetra
.564 .764 .972 r
.40449 .66997 .40548 .67073 .40713 .67022 .40613 .66972 Mtetra
.605 .844 .989 r
.40613 .66972 .40713 .67022 .40877 .66981 .40778 .66927 Mtetra
.64 .844 .978 r
.40778 .66927 .40877 .66981 .41043 .66925 .40944 .66874 Mtetra
.513 .812 .999 r
.40944 .66874 .41043 .66925 .41209 .66839 .41108 .66848 Mtetra
.131 .679 .744 r
.41108 .66848 .41209 .66839 .41377 .66702 .41273 .66826 Mtetra
.151 0 0 r
.41273 .66826 .41377 .66702 .41548 .66462 .41439 .6675 Mtetra
0 0 .026 r
.41439 .6675 .41548 .66462 .41742 .65488 .41612 .66459 Mtetra
.761 .685 .139 r
.41612 .66459 .41742 .65488 .42489 .46334 .41828 .64764 Mtetra
0 0 .304 r
.41828 .64764 .42489 .46334 .42656 .45929 .42556 .4609 Mtetra
.686 .838 .41 r
.42556 .4609 .42656 .45929 .42815 .45761 .4272 .45801 Mtetra
.581 .935 .776 r
.4272 .45801 .42815 .45761 .42971 .4571 .42878 .45695 Mtetra
.594 .919 .972 r
.42878 .45695 .42971 .4571 .43126 .45693 .43034 .45635 Mtetra
.642 .828 .972 r
.43034 .45635 .43126 .45693 .43282 .45663 .43191 .45587 Mtetra
.662 .783 .938 r
.43191 .45587 .43282 .45663 .43439 .45608 .43347 .45535 Mtetra
.646 .788 .949 r
.43347 .45535 .43439 .45608 .43595 .45563 .43503 .45489 Mtetra
.658 .787 .943 r
.43503 .45489 .43595 .45563 .4375 .45556 .4366 .45439 Mtetra
.671 .699 .867 r
.4366 .45439 .4375 .45556 .43905 .45594 .43817 .45382 Mtetra
.646 .577 .764 r
.43817 .45382 .43905 .45594 .44059 .45651 .43974 .45325 Mtetra
.622 .505 .7 r
.43974 .45325 .44059 .45651 .44214 .45673 .44131 .45269 Mtetra
.611 .476 .673 r
.44131 .45269 .44214 .45673 .44371 .45628 .44288 .45213 Mtetra
.609 .472 .67 r
.44288 .45213 .44371 .45628 .44528 .45559 .44445 .45158 Mtetra
.622 .484 .673 r
.44445 .45158 .44528 .45559 .44687 .45466 .44603 .45087 Mtetra
.631 .495 .679 r
.44603 .45087 .44687 .45466 .44845 .45372 .44761 .45009 Mtetra
.603 .482 .687 r
.44761 .45009 .44845 .45372 .45002 .45337 .44918 .44968 Mtetra
.467 .391 .687 r
.44918 .44968 .45002 .45337 .45154 .45518 .45072 .45053 Mtetra
0 .002 .525 r
.45072 .45053 .45154 .45518 .4489 .64732 .45219 .45482 Mtetra
0 0 .327 r
.45219 .45482 .4489 .64732 .45037 .65614 .44951 .65064 Mtetra
.059 .067 .552 r
.44951 .65064 .45037 .65614 .452 .65796 .45108 .65509 Mtetra
.491 .451 .74 r
.45108 .65509 .452 .65796 .45367 .65774 .45274 .6556 Mtetra
.599 .562 .784 r
.45274 .6556 .45367 .65774 .45536 .65702 .45441 .65536 Mtetra
.643 .631 .822 r
.45441 .65536 .45536 .65702 .45704 .65625 .45609 .65486 Mtetra
.646 .669 .857 r
.45609 .65486 .45704 .65625 .45872 .65573 .45777 .65438 Mtetra
.665 .682 .857 r
.45777 .65438 .45872 .65573 .4604 .6552 .45945 .6538 Mtetra
.661 .674 .852 r
.45945 .6538 .4604 .6552 .46209 .65468 .46114 .65324 Mtetra
.645 .66 .85 r
.46114 .65324 .46209 .65468 .46377 .6542 .46282 .65276 Mtetra
.641 .659 .852 r
.46282 .65276 .46377 .6542 .46545 .65374 .46451 .6523 Mtetra
.638 .658 .853 r
.46451 .6523 .46545 .65374 .46714 .6533 .46619 .65186 Mtetra
.635 .658 .855 r
.46619 .65186 .46714 .6533 .46882 .65287 .46788 .65144 Mtetra
.632 .658 .857 r
.46788 .65144 .46882 .65287 .47051 .65245 .46956 .65103 Mtetra
.629 .659 .86 r
.46956 .65103 .47051 .65245 .4722 .65209 .47125 .65063 Mtetra
.628 .653 .856 r
.47125 .65063 .4722 .65209 .47388 .65178 .47294 .65025 Mtetra
.623 .639 .845 r
.47294 .65025 .47388 .65178 .47557 .65135 .47463 .64988 Mtetra
.616 .645 .856 r
.47463 .64988 .47557 .65135 .47727 .65053 .47632 .64955 Mtetra
.593 .726 .936 r
.47632 .64955 .47727 .65053 .47897 .64907 .47801 .64926 Mtetra
0 0 0 r
.47801 .64926 .47897 .64907 .48068 .64735 .4797 .64897 Mtetra
.395 0 .148 r
.4797 .64897 .48068 .64735 .48239 .64588 .48139 .64865 Mtetra
.46 .123 .307 r
.48139 .64865 .48239 .64588 .48408 .64534 .48309 .64826 Mtetra
.463 .131 .318 r
.48309 .64826 .48408 .64534 .48578 .64512 .48479 .64786 Mtetra
.457 .119 .304 r
.48479 .64786 .48578 .64512 .48747 .64492 .48648 .64746 Mtetra
.452 .105 .286 r
.48648 .64746 .48747 .64492 .48917 .64453 .48818 .64709 Mtetra
.442 .097 .283 r
.48818 .64709 .48917 .64453 .49086 .64416 .48988 .64665 Mtetra
.412 .065 .264 r
.48988 .64665 .49086 .64416 .49256 .64386 .49159 .64606 Mtetra
.333 0 .197 r
.49159 .64606 .49256 .64386 .49426 .64367 .49329 .64521 Mtetra
.204 0 .029 r
.49329 .64521 .49426 .64367 .49596 .64347 .495 .64432 Mtetra
0 0 0 r
.495 .64432 .49596 .64347 .49766 .64319 .49671 .64353 Mtetra
.49671 .64353 .49766 .64319 .49937 .64279 .49842 .64303 Mtetra
.49842 .64303 .49937 .64279 .50107 .64234 .50012 .6426 Mtetra
.50012 .6426 .50107 .64234 .50278 .64188 .50183 .6422 Mtetra
.50183 .6422 .50278 .64188 .50449 .64142 .50354 .64173 Mtetra
.50354 .64173 .50449 .64142 .5062 .64096 .50525 .64126 Mtetra
.50525 .64126 .5062 .64096 .50791 .64048 .50696 .64079 Mtetra
.50696 .64079 .50791 .64048 .50962 .64001 .50867 .64031 Mtetra
.50867 .64031 .50962 .64001 .51133 .63953 .51039 .63983 Mtetra
.51039 .63983 .51133 .63953 .51304 .63904 .5121 .63934 Mtetra
.5121 .63934 .51304 .63904 .51476 .63856 .51382 .63886 Mtetra
.51382 .63886 .51476 .63856 .51647 .63808 .51553 .63837 Mtetra
.51553 .63837 .51647 .63808 .51819 .63759 .51725 .63788 Mtetra
.51725 .63788 .51819 .63759 .51991 .63711 .51897 .6374 Mtetra
.51897 .6374 .51991 .63711 .52163 .63663 .52069 .63691 Mtetra
.52069 .63691 .52163 .63663 .52335 .63616 .52241 .63643 Mtetra
.52241 .63643 .52335 .63616 .52507 .6357 .52413 .63596 Mtetra
.52413 .63596 .52507 .6357 .52679 .63523 .52586 .63549 Mtetra
.52586 .63549 .52679 .63523 .52851 .63485 .52758 .63509 Mtetra
.097 0 0 r
.52758 .63509 .52851 .63485 .53024 .63481 .52931 .635 Mtetra
.243 .754 .744 r
.52931 .635 .53024 .63481 .53196 .63436 .53103 .63453 Mtetra
.776 .996 .859 r
.53103 .63453 .53196 .63436 .53369 .63286 .53276 .63309 Mtetra
.984 .841 .62 r
.53276 .63309 .53369 .63286 .5354 .6266 .53447 .62765 Mtetra
.965 .693 .468 r
.53447 .62765 .5354 .6266 .53642 .42963 .53555 .42963 Mtetra
.977 .808 .607 r
.53555 .42963 .53642 .42963 .53803 .42464 .53716 .42367 Mtetra
.776 .772 .849 r
.53716 .42367 .53803 .42464 .53966 .42354 .53879 .4225 Mtetra
.644 .72 .904 r
.53879 .4225 .53966 .42354 .54129 .42311 .54041 .42205 Mtetra
.557 .683 .924 r
.54041 .42205 .54129 .42311 .54292 .42296 .54205 .42192 Mtetra
.655 .725 .9 r
.54205 .42192 .54292 .42296 .54455 .42248 .54368 .42142 Mtetra
.65 .722 .901 r
.54368 .42142 .54455 .42248 .54618 .422 .54531 .42095 Mtetra
.654 .723 .899 r
.54531 .42095 .54618 .422 .54781 .42151 .54694 .42046 Mtetra
.676 .731 .892 r
.54694 .42046 .54781 .42151 .54944 .42091 .54857 .41987 Mtetra
.679 .734 .892 r
.54857 .41987 .54944 .42091 .55107 .42029 .55021 .41926 Mtetra
.686 .74 .891 r
.55021 .41926 .55107 .42029 .55271 .41963 .55184 .41862 Mtetra
.754 .76 .858 r
.55184 .41862 .55271 .41963 .55434 .41862 .55347 .41759 Mtetra
.679 .737 .894 r
.55347 .41759 .55434 .41862 .55597 .41799 .55511 .41698 Mtetra
.378 .609 .94 r
.55511 .41698 .55597 .41799 .55762 .41817 .55675 .41728 Mtetra
.938 .565 .228 r
.55675 .41728 .55762 .41817 .55931 .42256 .55846 .4236 Mtetra
.963 .682 .454 r
.55846 .4236 .55931 .42256 .56314 .61912 .56225 .62054 Mtetra
.815 .443 .351 r
.56225 .62054 .56314 .61912 .56495 .62417 .56404 .62433 Mtetra
.087 0 0 r
.56404 .62433 .56495 .62417 .56671 .62516 .5658 .6243 Mtetra
.698 .792 .923 r
.5658 .6243 .56671 .62516 .56847 .6254 .56754 .62357 Mtetra
.712 .648 .784 r
.56754 .62357 .56847 .6254 .57022 .62523 .56929 .62248 Mtetra
.632 .544 .737 r
.56929 .62248 .57022 .62523 .57198 .62481 .57104 .62188 Mtetra
.628 .533 .727 r
.57104 .62188 .57198 .62481 .57373 .62423 .57279 .62129 Mtetra
.628 .532 .727 r
.57279 .62129 .57373 .62423 .57548 .62356 .57454 .6207 Mtetra
.628 .536 .731 r
.57454 .6207 .57548 .62356 .57723 .62301 .57629 .62012 Mtetra
.627 .534 .73 r
.57629 .62012 .57723 .62301 .57899 .62245 .57805 .61955 Mtetra
.627 .534 .729 r
.57805 .61955 .57899 .62245 .58075 .62187 .5798 .61897 Mtetra
.628 .535 .729 r
.5798 .61897 .58075 .62187 .5825 .62121 .58156 .61839 Mtetra
.629 .539 .734 r
.58156 .61839 .5825 .62121 .58426 .62053 .58332 .61781 Mtetra
.631 .545 .739 r
.58332 .61781 .58426 .62053 .58601 .61986 .58508 .61722 Mtetra
.633 .551 .744 r
.58508 .61722 .58601 .61986 .58777 .61926 .58684 .61663 Mtetra
.634 .552 .745 r
.58684 .61663 .58777 .61926 .58953 .61868 .5886 .61604 Mtetra
.634 .551 .744 r
.5886 .61604 .58953 .61868 .5913 .61811 .59036 .61544 Mtetra
.644 .555 .74 r
.59036 .61544 .5913 .61811 .59306 .61752 .59212 .61474 Mtetra
.636 .545 .735 r
.59212 .61474 .59306 .61752 .59482 .61692 .59388 .6141 Mtetra
.621 .534 .735 r
.59388 .6141 .59482 .61692 .59659 .61629 .59565 .61359 Mtetra
.567 .51 .751 r
.59565 .61359 .59659 .61629 .59835 .6156 .59743 .61357 Mtetra
.552 .552 .807 r
.59743 .61357 .59835 .6156 .60012 .61489 .59921 .6136 Mtetra
.542 .647 .902 r
.59921 .6136 .60012 .61489 .60188 .61419 .60099 .61354 Mtetra
.596 .817 .984 r
.60099 .61354 .60188 .61419 .60365 .61371 .60276 .61312 Mtetra
.631 .844 .981 r
.60276 .61312 .60365 .61371 .60542 .61318 .60453 .61258 Mtetra
.65 .846 .976 r
.60453 .61258 .60542 .61318 .60719 .61245 .6063 .61198 Mtetra
.603 .866 .992 r
.6063 .61198 .60719 .61245 .60894 .61085 .60808 .61145 Mtetra
.045 0 0 r
.60808 .61145 .60894 .61085 .61067 .60871 .60985 .61094 Mtetra
.411 .049 .238 r
.60985 .61094 .61067 .60871 .6124 .60616 .61163 .61041 Mtetra
.486 .189 .387 r
.61163 .61041 .6124 .60616 .61415 .60488 .61341 .6099 Mtetra
.496 .211 .411 r
.61341 .6099 .61415 .60488 .61593 .60433 .61519 .60936 Mtetra
.493 .209 .411 r
.61519 .60936 .61593 .60433 .61771 .60409 .61697 .60879 Mtetra
.481 .193 .399 r
.61697 .60879 .61771 .60409 .61947 .60302 .61875 .60812 Mtetra
.484 .202 .41 r
.61875 .60812 .61947 .60302 .62124 .60204 .62052 .60741 Mtetra
.488 .21 .417 r
.62052 .60741 .62124 .60204 .62302 .60172 .6223 .6067 Mtetra
.488 .204 .408 r
.6223 .6067 .62302 .60172 .62486 .6033 .62408 .60606 Mtetra
.431 .096 .295 r
.62408 .60606 .62486 .6033 .6267 .6047 .62587 .60546 Mtetra
.098 0 0 r
.62587 .60546 .6267 .6047 .62853 .60555 .62765 .60488 Mtetra
.655 .833 .969 r
.62765 .60488 .62853 .60555 .63033 .60541 .62944 .60428 Mtetra
.664 .732 .9 r
.62944 .60428 .63033 .60541 .63212 .60491 .63122 .6037 Mtetra
.656 .712 .889 r
.63122 .6037 .63212 .60491 .63391 .60432 .63301 .60314 Mtetra
.64 .713 .9 r
.63301 .60314 .63391 .60432 .6357 .60398 .63481 .60267 Mtetra
.629 .685 .884 r
.63481 .60267 .6357 .60398 .6375 .60372 .6366 .60225 Mtetra
.622 .657 .863 r
.6366 .60225 .6375 .60372 .6393 .60345 .6384 .60187 Mtetra
.615 .637 .849 r
.6384 .60187 .6393 .60345 .64111 .60325 .6402 .60152 Mtetra
.612 .617 .832 r
.6402 .60152 .64111 .60325 .64291 .60295 .642 .60119 Mtetra
.613 .614 .828 r
.642 .60119 .64291 .60295 .64471 .60242 .64381 .60085 Mtetra
.53 .597 .866 r
.64381 .60085 .64471 .60242 .6465 .60156 .64563 .60091 Mtetra
.493 .778 .995 r
.64563 .60091 .6465 .60156 .64826 .60015 .64744 .60073 Mtetra
0 0 0 r
.64744 .60073 .64826 .60015 .64999 .5977 .64923 .59987 Mtetra
.64923 .59987 .64999 .5977 .65141 .58681 .6509 .59591 Mtetra
.981 .7 .409 r
.6509 .59591 .65141 .58681 .64587 .39149 .64532 .39804 Mtetra
0 0 .14 r
.64532 .39804 .64587 .39149 .64743 .38747 .64667 .3882 Mtetra
.738 .927 .579 r
.64667 .3882 .64743 .38747 .64909 .38613 .6483 .38598 Mtetra
.706 .964 .941 r
.6483 .38598 .64909 .38613 .65079 .3857 .64997 .38502 Mtetra
.648 .821 .966 r
.64997 .38502 .65079 .3857 .6525 .3856 .65167 .38449 Mtetra
.66 .721 .894 r
.65167 .38449 .6525 .3856 .6542 .38525 .65336 .38395 Mtetra
.652 .683 .867 r
.65336 .38395 .6542 .38525 .6559 .38475 .65506 .38344 Mtetra
.641 .678 .87 r
.65506 .38344 .6559 .38475 .65759 .3842 .65676 .38299 Mtetra
.646 .697 .882 r
.65676 .38299 .65759 .3842 .65928 .38349 .65846 .38251 Mtetra
.651 .747 .92 r
.65846 .38251 .65928 .38349 .66097 .38277 .66016 .38201 Mtetra
.649 .8 .955 r
.66016 .38201 .66097 .38277 .66267 .38219 .66186 .38149 Mtetra
.665 .818 .957 r
.66186 .38149 .66267 .38219 .6644 .38219 .66356 .3809 Mtetra
.673 .693 .861 r
.66356 .3809 .6644 .38219 .66614 .38263 .66526 .38027 Mtetra
.643 .566 .753 r
.66526 .38027 .66614 .38263 .6679 .38327 .66696 .37964 Mtetra
.639 .508 .687 r
.66696 .37964 .6679 .38327 .66961 .38282 .66865 .37876 Mtetra
.624 .487 .675 r
.66865 .37876 .66961 .38282 .6713 .38195 .67035 .37798 Mtetra
.587 .466 .682 r
.67035 .37798 .6713 .38195 .67302 .38169 .67207 .37772 Mtetra
.347 .309 .673 r
.67207 .37772 .67302 .38169 .67495 .38597 .67389 .3797 Mtetra
.871 .6 .073 r
.67389 .3797 .67495 .38597 .6861 .58493 .67656 .39963 Mtetra
.02 0 .426 r
.67656 .39963 .6861 .58493 .68817 .58954 .6872 .58634 Mtetra
.349 .35 .719 r
.6872 .58634 .68817 .58954 .69006 .5904 .68913 .58792 Mtetra
.611 .552 .763 r
.68913 .58792 .69006 .5904 .6919 .58997 .69096 .58754 Mtetra
.674 .589 .752 r
.69096 .58754 .6919 .58997 .69371 .58917 .69277 .58659 Mtetra
.656 .57 .746 r
.69277 .58659 .69371 .58917 .69554 .58858 .69459 .58578 Mtetra
.629 .543 .738 r
.69459 .58578 .69554 .58858 .69738 .58817 .69642 .58519 Mtetra
.617 .527 .73 r
.69642 .58519 .69738 .58817 .69921 .58772 .69825 .5847 Mtetra
.583 .505 .732 r
.69825 .5847 .69921 .58772 .70105 .58725 .7001 .58453 Mtetra
.562 .509 .754 r
.7001 .58453 .70105 .58725 .70288 .58668 .70197 .58454 Mtetra
.564 .552 .8 r
.70197 .58454 .70288 .58668 .70471 .58595 .70383 .58451 Mtetra
.598 .653 .876 r
.70383 .58451 .70471 .58595 .70651 .58475 .70568 .58423 Mtetra
.571 .851 .996 r
.70568 .58423 .70651 .58475 .70829 .58309 .70752 .58377 Mtetra
.101 0 0 r
.70752 .58377 .70829 .58309 .71005 .58124 .70936 .58325 Mtetra
.397 .023 .207 r
.70936 .58325 .71005 .58124 .71185 .57993 .71121 .58272 Mtetra
.447 .111 .303 r
.71121 .58272 .71185 .57993 .71369 .57933 .71305 .58221 Mtetra
.449 .117 .31 r
.71305 .58221 .71369 .57933 .71554 .57899 .71489 .58168 Mtetra
.44 .101 .293 r
.71489 .58168 .71554 .57899 .71739 .57857 .71674 .58115 Mtetra
.434 .09 .281 r
.71674 .58115 .71739 .57857 .71923 .57804 .71858 .58061 Mtetra
.432 .088 .28 r
.71858 .58061 .71923 .57804 .72108 .5775 .72043 .58006 Mtetra
.426 .082 .277 r
.72043 .58006 .72108 .5775 .72292 .57694 .72228 .57948 Mtetra
.42 .076 .273 r
.72228 .57948 .72292 .57694 .72476 .57637 .72412 .57886 Mtetra
.418 .072 .268 r
.72412 .57886 .72476 .57637 .72661 .5758 .72597 .57825 Mtetra
.419 .071 .265 r
.72597 .57825 .72661 .5758 .72846 .57523 .72782 .57766 Mtetra
.423 .072 .264 r
.72782 .57766 .72846 .57523 .73031 .57468 .72967 .57711 Mtetra
.425 .074 .265 r
.72967 .57711 .73031 .57468 .73216 .57414 .73152 .57656 Mtetra
.427 .076 .265 r
.73152 .57656 .73216 .57414 .73401 .57362 .73338 .57604 Mtetra
.428 .076 .265 r
.73338 .57604 .73401 .57362 .73587 .57312 .73524 .57552 Mtetra
.427 .074 .262 r
.73524 .57552 .73587 .57312 .73773 .57262 .7371 .57499 Mtetra
.462 .104 .272 r
.7371 .57499 .73773 .57262 .73961 .5725 .73897 .57472 Mtetra
.462 .095 .255 r
.73897 .57472 .73961 .5725 .7415 .57244 .74085 .57449 Mtetra
.361 0 .199 r
.74085 .57449 .7415 .57244 .74334 .57163 .7427 .57375 Mtetra
0 0 .041 r
.7427 .57375 .74334 .57163 .74497 .56751 .74443 .57112 Mtetra
.754 .684 .137 r
.74443 .57112 .74497 .56751 .73371 .36666 .7457 .56155 Mtetra
.037 0 .432 r
.7457 .56155 .73371 .36666 .73506 .36012 .73443 .36147 Mtetra
0 0 0 r
.73443 .36147 .73506 .36012 .7367 .35784 .736 .35822 Mtetra
.736 .35822 .7367 .35784 .73843 .35714 .73774 .3575 Mtetra
.138 0 0 r
.73774 .3575 .73843 .35714 .7402 .35688 .73951 .35733 Mtetra
.063 0 0 r
.73951 .35733 .7402 .35688 .74197 .35667 .74127 .35694 Mtetra
.412 .844 .707 r
.74127 .35694 .74197 .35667 .74373 .35631 .743 .35602 Mtetra
.705 .946 .957 r
.743 .35602 .74373 .35631 .7455 .35594 .74472 .3551 Mtetra
.708 .806 .926 r
.74472 .3551 .7455 .35594 .74726 .35549 .74646 .35433 Mtetra
.668 .722 .889 r
.74646 .35433 .74726 .35549 .74901 .35492 .74821 .35374 Mtetra
.659 .713 .888 r
.74821 .35374 .74901 .35492 .75076 .35431 .74997 .35318 Mtetra
.71 .744 .878 r
.74997 .35318 .75076 .35431 .75249 .35343 .7517 .35236 Mtetra
.744 .766 .871 r
.7517 .35236 .75249 .35343 .75421 .35242 .75343 .35136 Mtetra
.646 .734 .913 r
.75343 .35136 .75421 .35242 .75597 .35192 .75519 .35087 Mtetra
0 .311 .801 r
.75519 .35087 .75597 .35192 .75787 .3532 .75709 .35216 Mtetra
.951 .602 .229 r
.75709 .35216 .75787 .3532 .76063 .36622 .75986 .36542 Mtetra
.975 .673 .364 r
.75986 .36542 .76063 .36622 .77703 .56206 .77621 .56108 Mtetra
.553 .083 0 r
.77621 .56108 .77703 .56206 .77915 .56464 .77832 .56365 Mtetra
.449 .674 .959 r
.77832 .56365 .77915 .56464 .78108 .56474 .78026 .56375 Mtetra
.728 .792 .904 r
.78026 .56375 .78108 .56474 .78294 .5638 .78212 .56281 Mtetra
.901 .813 .752 r
.78212 .56281 .78294 .5638 .78466 .56104 .78384 .56005 Mtetra
.978 .746 .518 r
.78384 .56005 .78466 .56104 .78577 .55052 .78496 .54959 Mtetra
.977 .681 .375 r
.78496 .54959 .78577 .55052 .77205 .34969 .77128 .34865 Mtetra
.925 .79 .692 r
.77128 .34865 .77205 .34969 .77359 .3462 .77282 .34515 Mtetra
.722 .764 .886 r
.77282 .34515 .77359 .3462 .77534 .34533 .77456 .34428 Mtetra
.595 .714 .927 r
.77456 .34428 .77534 .34533 .77713 .34504 .77635 .34398 Mtetra
.623 .726 .921 r
.77635 .34398 .77713 .34504 .77891 .34463 .77814 .34358 Mtetra
.737 .769 .879 r
.77814 .34358 .77891 .34463 .78065 .34367 .77988 .34261 Mtetra
.645 .735 .915 r
.77988 .34261 .78065 .34367 .78243 .34318 .78166 .34211 Mtetra
.087 .416 .864 r
.78166 .34211 .78243 .34318 .78433 .34419 .78356 .34313 Mtetra
.922 .549 .132 r
.78356 .34313 .78433 .34419 .78691 .35333 .78614 .35229 Mtetra
.975 .67 .349 r
.78614 .35229 .78691 .35333 .80536 .5534 .80455 .55239 Mtetra
.603 .141 0 r
.80455 .55239 .80536 .5534 .80756 .55636 .80675 .55535 Mtetra
.427 .657 .956 r
.80675 .55535 .80756 .55636 .80952 .55654 .80871 .55552 Mtetra
.717 .786 .906 r
.80871 .55552 .80952 .55654 .8114 .55565 .81059 .55463 Mtetra
.893 .816 .765 r
.81059 .55463 .8114 .55565 .81313 .553 .81233 .55205 Mtetra
.982 .753 .518 r
.81233 .55205 .81313 .553 .81414 .54204 .81344 .54224 Mtetra
.978 .679 .358 r
.81344 .54224 .81414 .54204 .79866 .34069 .79793 .34006 Mtetra
.966 .836 .664 r
.79793 .34006 .79866 .34069 .80017 .33699 .79943 .33615 Mtetra
.793 .834 .884 r
.79943 .33615 .80017 .33699 .80191 .33592 .80116 .33491 Mtetra
.586 .724 .939 r
.80116 .33491 .80191 .33592 .80373 .33571 .80297 .33463 Mtetra
0 .318 .806 r
.80297 .33463 .80373 .33571 .80566 .33676 .80493 .33597 Mtetra
.946 .591 .214 r
.80493 .33597 .80566 .33676 .80799 .34216 .80797 .34949 Mtetra
.97 .661 .366 r
.80797 .34949 .80799 .34216 .82792 .54307 .82752 .54649 Mtetra
.637 .296 .378 r
.82752 .54649 .82792 .54307 .83009 .54536 .82963 .54808 Mtetra
0 0 .062 r
.82963 .54808 .83009 .54536 .83068 .53023 .83118 .54347 Mtetra
.976 .682 .303 r
.83118 .54347 .83068 .53023 .81478 .3357 .81448 .33957 Mtetra
0 0 .115 r
.81448 .33957 .81478 .3357 .8163 .33207 .81568 .33247 Mtetra
.583 .9 .636 r
.81568 .33247 .8163 .33207 .81807 .33121 .81739 .33094 Mtetra
.669 .946 .96 r
.81739 .33094 .81807 .33121 .81988 .33082 .81915 .33007 Mtetra
.686 .829 .952 r
.81915 .33007 .81988 .33082 .82169 .33042 .82094 .32937 Mtetra
.755 .78 .874 r
.82094 .32937 .82169 .33042 .82344 .32931 .82269 .32829 Mtetra
.667 .757 .917 r
.82269 .32829 .82344 .32931 .82523 .32859 .82449 .32769 Mtetra
.283 .584 .943 r
.82449 .32769 .82523 .32859 .82711 .32892 .82639 .32816 Mtetra
.84 .41 0 r
.82639 .32816 .82711 .32892 .82943 .33365 .82874 .33323 Mtetra
.974 .664 .327 r
.82874 .33323 .82943 .33365 .85109 .5376 .85033 .53685 Mtetra
.789 .332 0 r
.85033 .53685 .85109 .5376 .85352 .54215 .85273 .54111 Mtetra
.512 .698 .953 r
.85273 .54111 .85352 .54215 .8555 .54212 .85471 .54105 Mtetra
.703 .774 .907 r
.85471 .54105 .8555 .54212 .85741 .54133 .85662 .54022 Mtetra
.747 .782 .881 r
.85662 .54022 .85741 .54133 .85931 .54032 .85851 .53913 Mtetra
.641 .725 .909 r
.85851 .53913 .85931 .54032 .86128 .54006 .86045 .5386 Mtetra
.637 .677 .871 r
.86045 .5386 .86128 .54006 .86323 .53969 .86239 .53811 Mtetra
.618 .65 .86 r
.86239 .53811 .86323 .53969 .86517 .53906 .86435 .53771 Mtetra
.52 .638 .906 r
.86435 .53771 .86517 .53906 .86706 .53801 .86636 .53774 Mtetra
.427 .847 .959 r
.86636 .53774 .86706 .53801 .86888 .5363 .86831 .53733 Mtetra
0 0 0 r
.86831 .53733 .86888 .5363 .87054 .53294 .87017 .53591 Mtetra
0 0 .05 r
.87017 .53591 .87054 .53294 .85176 .33239 .87156 .52996 Mtetra
.092 .012 .464 r
.87156 .52996 .85176 .33239 .85265 .32285 .85234 .3259 Mtetra
0 0 .088 r
.85234 .3259 .85265 .32285 .8542 .3197 .85361 .32007 Mtetra
.546 .884 .633 r
.85361 .32007 .8542 .3197 .856 .31888 .85534 .31861 Mtetra
.619 .933 .964 r
.85534 .31861 .856 .31888 .85784 .31858 .85714 .31784 Mtetra
.604 .804 .977 r
.85714 .31784 .85784 .31858 .85972 .31852 .85898 .31741 Mtetra
.659 .737 .907 r
.85898 .31741 .85972 .31852 .86155 .31802 .86081 .31684 Mtetra
.645 .715 .899 r
.86081 .31684 .86155 .31802 .86338 .31747 .86264 .31633 Mtetra
.644 .724 .906 r
.86264 .31633 .86338 .31747 .8652 .31684 .86447 .31582 Mtetra
.672 .762 .918 r
.86447 .31582 .8652 .31684 .867 .31599 .86629 .31519 Mtetra
.674 .818 .952 r
.86629 .31519 .867 .31599 .8688 .31521 .86811 .31453 Mtetra
.679 .851 .965 r
.86811 .31453 .8688 .31521 .87063 .31463 .86993 .31382 Mtetra
.779 .846 .902 r
.86993 .31382 .87063 .31463 .8725 .31443 .8717 .31266 Mtetra
.674 .641 .81 r
.8717 .31266 .8725 .31443 .87443 .31476 .87351 .3119 Mtetra
.561 .495 .739 r
.87351 .3119 .87443 .31476 .87649 .3162 .87541 .31193 Mtetra
.078 .127 .612 r
.87541 .31193 .87649 .3162 .89908 .49984 .87783 .31655 Mtetra
.064 .001 .466 r
.87783 .31655 .89908 .49984 .90389 .52455 .90289 .52138 Mtetra
0 0 .561 r
.90289 .52138 .90389 .52455 .90626 .52752 .90549 .52642 Mtetra
.294 .561 .929 r
.90549 .52642 .90626 .52752 .90835 .52807 .90759 .52702 Mtetra
.64 .758 .934 r
.90759 .52702 .90835 .52807 .91034 .52765 .90957 .52648 Mtetra
.815 .794 .833 r
.90957 .52648 .91034 .52765 .91221 .52621 .91141 .52481 Mtetra
.908 .736 .657 r
.27785 .70589 .27888 .70673 .2808 .70126 .27977 .7004 Mtetra
.936 .686 .535 r
.27977 .7004 .2808 .70126 .29577 .50616 .29481 .50523 Mtetra
.906 .726 .647 r
.29481 .50523 .29577 .50616 .29762 .50038 .29666 .49947 Mtetra
.772 .757 .839 r
.29666 .49947 .29762 .50038 .29915 .49925 .29819 .49835 Mtetra
.641 .734 .916 r
.29819 .49835 .29915 .49925 .30063 .49885 .29967 .49795 Mtetra
.513 .691 .949 r
.29967 .49795 .30063 .49885 .30209 .4988 .30114 .49791 Mtetra
.749 .757 .859 r
.30114 .49791 .30209 .4988 .30361 .49787 .30266 .49697 Mtetra
.696 .749 .893 r
.30266 .49697 .30361 .49787 .30511 .49724 .30416 .49634 Mtetra
.477 .678 .953 r
.30416 .49634 .30511 .49724 .30657 .49727 .30562 .49638 Mtetra
.928 .551 .259 r
.30562 .49638 .30657 .49727 .30777 .50136 .30681 .50046 Mtetra
.939 .683 .523 r
.30681 .50046 .30777 .50136 .29662 .69575 .2956 .69489 Mtetra
.935 .579 .322 r
.2956 .69489 .29662 .69575 .29783 .70097 .29681 .70012 Mtetra
0 .357 .803 r
.29681 .70012 .29783 .70097 .29934 .70176 .29832 .70092 Mtetra
.627 .756 .94 r
.29832 .70092 .29934 .70176 .30092 .70138 .2999 .70053 Mtetra
.807 .778 .826 r
.2999 .70053 .30092 .70138 .30257 .69994 .30155 .69905 Mtetra
.909 .736 .654 r
.30155 .69905 .30257 .69994 .30446 .69471 .30346 .69347 Mtetra
.938 .686 .53 r
.30346 .69347 .30446 .69471 .31819 .49908 .31728 .49736 Mtetra
.874 .687 .646 r
.31728 .49736 .31819 .49908 .32003 .49308 .3191 .4918 Mtetra
.749 .698 .803 r
.3191 .4918 .32003 .49308 .32158 .49184 .32064 .49067 Mtetra
.6 .667 .887 r
.32064 .49067 .32158 .49184 .32307 .4915 .32213 .49043 Mtetra
.443 .622 .927 r
.32213 .49043 .32307 .4915 .32454 .49157 .32359 .49061 Mtetra
.623 .718 .914 r
.32359 .49061 .32454 .49157 .32604 .49119 .32509 .49027 Mtetra
.658 .738 .909 r
.32509 .49027 .32604 .49119 .32754 .4907 .32659 .4898 Mtetra
.669 .744 .907 r
.32659 .4898 .32754 .4907 .32905 .49019 .3281 .48929 Mtetra
.753 .759 .858 r
.3281 .48929 .32905 .49019 .33058 .48922 .32963 .48832 Mtetra
.714 .754 .884 r
.32963 .48832 .33058 .48922 .3321 .48849 .33115 .48759 Mtetra
.537 .703 .947 r
.33115 .48759 .3321 .48849 .33359 .48839 .33264 .48749 Mtetra
.908 .499 .166 r
.33264 .48749 .33359 .48839 .33487 .49175 .33392 .49086 Mtetra
.942 .683 .517 r
.33392 .49086 .33487 .49175 .3253 .68619 .32429 .68537 Mtetra
.939 .595 .347 r
.32429 .68537 .3253 .68619 .32652 .69237 .32551 .69152 Mtetra
0 .191 .66 r
.32551 .69152 .32652 .69237 .32803 .69344 .32702 .69259 Mtetra
.594 .749 .951 r
.32702 .69259 .32803 .69344 .32963 .69315 .32862 .6923 Mtetra
.797 .782 .84 r
.32862 .6923 .32963 .69315 .33128 .69182 .33027 .69094 Mtetra
.907 .744 .668 r
.33027 .69094 .33128 .69182 .33311 .68722 .33212 .68606 Mtetra
.942 .687 .524 r
.33212 .68606 .33311 .68722 .34529 .49153 .3444 .48963 Mtetra
.879 .682 .633 r
.3444 .48963 .34529 .49153 .34716 .48455 .34624 .48325 Mtetra
.775 .703 .784 r
.34624 .48325 .34716 .48455 .34873 .48301 .34781 .48183 Mtetra
.614 .671 .881 r
.34781 .48183 .34873 .48301 .35024 .48263 .34931 .48154 Mtetra
.456 .625 .925 r
.34931 .48154 .35024 .48263 .35173 .48267 .3508 .48169 Mtetra
.597 .708 .921 r
.3508 .48169 .35173 .48267 .35324 .48236 .3523 .48144 Mtetra
.653 .738 .912 r
.3523 .48144 .35324 .48236 .35476 .48188 .35382 .48099 Mtetra
.664 .746 .911 r
.35382 .48099 .35476 .48188 .35628 .48138 .35534 .48049 Mtetra
.749 .764 .865 r
.35534 .48049 .35628 .48138 .35783 .48044 .35689 .47955 Mtetra
.723 .76 .882 r
.35689 .47955 .35783 .48044 .35936 .47966 .35843 .47877 Mtetra
.557 .714 .945 r
.35843 .47877 .35936 .47966 .36087 .47948 .35993 .47862 Mtetra
.892 .468 .117 r
.35993 .47862 .36087 .47948 .36223 .48237 .36128 .48175 Mtetra
.945 .684 .51 r
.36128 .48175 .36223 .48237 .35425 .67681 .35319 .67713 Mtetra
.901 .566 .403 r
.35319 .67713 .35425 .67681 .3555 .68384 .35448 .68341 Mtetra
.371 0 0 r
.35448 .68341 .3555 .68384 .35706 .68477 .35604 .68419 Mtetra
.673 .838 .963 r
.35604 .68419 .35706 .68477 .35868 .68429 .35767 .68359 Mtetra
.77 .816 .889 r
.35767 .68359 .35868 .68429 .36032 .68336 .35932 .68253 Mtetra
.548 .74 .965 r
.35932 .68253 .36032 .68336 .36193 .68312 .36093 .68235 Mtetra
.477 .725 .979 r
.36093 .68235 .36193 .68312 .36354 .68296 .36253 .6823 Mtetra
.697 .823 .942 r
.36253 .6823 .36354 .68296 .36518 .68217 .36417 .68162 Mtetra
.917 .789 .704 r
.36417 .68162 .36518 .68217 .36695 .67842 .36594 .67788 Mtetra
.946 .689 .516 r
.36594 .67788 .36695 .67842 .37725 .48379 .37634 .48224 Mtetra
.911 .699 .604 r
.37634 .48224 .37725 .48379 .37917 .47455 .37826 .47321 Mtetra
.811 .707 .75 r
.37826 .47321 .37917 .47455 .38077 .47256 .37986 .47121 Mtetra
.666 .665 .839 r
.37986 .47121 .38077 .47256 .38231 .47202 .3814 .47066 Mtetra
.561 .621 .869 r
.3814 .47066 .38231 .47202 .38383 .47194 .38292 .47059 Mtetra
.584 .632 .865 r
.38292 .47059 .38383 .47194 .38535 .47169 .38444 .47042 Mtetra
.612 .657 .87 r
.38444 .47042 .38535 .47169 .38689 .47128 .38597 .47014 Mtetra
.613 .68 .89 r
.38597 .47014 .38689 .47128 .38842 .47086 .3875 .46985 Mtetra
.639 .716 .903 r
.3875 .46985 .38842 .47086 .38996 .47035 .38904 .46944 Mtetra
.664 .746 .911 r
.38904 .46944 .38996 .47035 .39151 .46979 .39058 .46894 Mtetra
.682 .762 .912 r
.39058 .46894 .39151 .46979 .39305 .46921 .39212 .46836 Mtetra
.739 .774 .881 r
.39212 .46836 .39305 .46921 .39461 .46834 .39368 .46749 Mtetra
.741 .776 .881 r
.39368 .46749 .39461 .46834 .39617 .46752 .39524 .46662 Mtetra
.671 .75 .91 r
.39524 .46662 .39617 .46752 .3977 .46718 .39679 .46608 Mtetra
.14 .447 .88 r
.39679 .46608 .3977 .46718 .39916 .46887 .39828 .46681 Mtetra
0 0 .459 r
.39828 .46681 .39916 .46887 .40029 .47965 .39971 .46949 Mtetra
0 0 .275 r
.39971 .46949 .40029 .47965 .39472 .67005 .40079 .48158 Mtetra
0 0 .328 r
.40079 .48158 .39472 .67005 .39628 .67183 .39564 .66177 Mtetra
.602 .416 .603 r
.39564 .66177 .39628 .67183 .39792 .6714 .39731 .66053 Mtetra
.612 .421 .599 r
.39731 .66053 .39792 .6714 .39959 .67045 .39899 .65881 Mtetra
.367 .233 .563 r
.39899 .65881 .39959 .67045 .40123 .66997 .40045 .66343 Mtetra
.245 .18 .583 r
.40045 .66343 .40123 .66997 .40286 .66999 .40195 .66718 Mtetra
.159 .239 .697 r
.40195 .66718 .40286 .66999 .40449 .66997 .40351 .66907 Mtetra
.225 .567 .938 r
.40351 .66907 .40449 .66997 .40613 .66972 .40513 .66952 Mtetra
.471 .863 .972 r
.40513 .66952 .40613 .66972 .40778 .66927 .40678 .66913 Mtetra
.598 .923 .969 r
.40678 .66913 .40778 .66927 .40944 .66874 .40844 .66848 Mtetra
.519 .873 .986 r
.40844 .66848 .40944 .66874 .41108 .66848 .41009 .66806 Mtetra
.508 .832 .999 r
.41009 .66806 .41108 .66848 .41273 .66826 .41174 .66776 Mtetra
.676 .862 .97 r
.41174 .66776 .41273 .66826 .41439 .6675 .4134 .66711 Mtetra
.866 .877 .844 r
.4134 .66711 .41439 .6675 .41612 .66459 .41509 .66536 Mtetra
.974 .924 .662 r
.41509 .66536 .41612 .66459 .41828 .64764 .41685 .66154 Mtetra
0 0 .128 r
.41685 .66154 .41828 .64764 .42556 .4609 .41902 .64431 Mtetra
0 0 .312 r
.41902 .64431 .42556 .4609 .4272 .45801 .42616 .46126 Mtetra
0 0 .04 r
.42616 .46126 .4272 .45801 .42878 .45695 .42781 .45775 Mtetra
.798 .969 .665 r
.42781 .45775 .42878 .45695 .43034 .45635 .42942 .45568 Mtetra
.794 .82 .873 r
.42942 .45568 .43034 .45635 .43191 .45587 .43101 .45451 Mtetra
.67 .668 .839 r
.43101 .45451 .43191 .45587 .43347 .45535 .43257 .45392 Mtetra
.633 .644 .843 r
.43257 .45392 .43347 .45535 .43503 .45489 .43413 .45353 Mtetra
.653 .662 .846 r
.43413 .45353 .43503 .45489 .4366 .45439 .4357 .45304 Mtetra
.684 .676 .836 r
.4357 .45304 .4366 .45439 .43817 .45382 .43727 .45237 Mtetra
.68 .66 .823 r
.43727 .45237 .43817 .45382 .43974 .45325 .43885 .4517 Mtetra
.669 .643 .815 r
.43885 .4517 .43974 .45325 .44131 .45269 .44042 .45108 Mtetra
.658 .632 .813 r
.44042 .45108 .44131 .45269 .44288 .45213 .44199 .45053 Mtetra
.654 .63 .814 r
.44199 .45053 .44288 .45213 .44445 .45158 .44356 .44999 Mtetra
.67 .639 .81 r
.44356 .44999 .44445 .45158 .44603 .45087 .44514 .44936 Mtetra
.681 .653 .815 r
.44514 .44936 .44603 .45087 .44761 .45009 .44671 .44866 Mtetra
.646 .65 .84 r
.44671 .44866 .44761 .45009 .44918 .44968 .44829 .44821 Mtetra
.488 .569 .864 r
.44829 .44821 .44918 .44968 .45072 .45053 .44984 .44841 Mtetra
.203 .316 .757 r
.44984 .44841 .45072 .45053 .45219 .45482 .45138 .44975 Mtetra
.226 .188 .604 r
.45138 .44975 .45219 .45482 .44951 .65064 .45288 .45286 Mtetra
0 0 .358 r
.45288 .45286 .44951 .65064 .45108 .65509 .45043 .63963 Mtetra
.142 .056 .489 r
.45043 .63963 .45108 .65509 .45274 .6556 .45186 .65067 Mtetra
.306 .254 .634 r
.45186 .65067 .45274 .6556 .45441 .65536 .45347 .65316 Mtetra
.407 .45 .792 r
.45347 .65316 .45441 .65536 .45609 .65486 .45513 .65389 Mtetra
.6 .728 .934 r
.45513 .65389 .45609 .65486 .45777 .65438 .45681 .65358 Mtetra
.687 .793 .93 r
.45681 .65358 .45777 .65438 .45945 .6538 .45849 .65292 Mtetra
.691 .777 .917 r
.45849 .65292 .45945 .6538 .46114 .65324 .46018 .65225 Mtetra
.643 .741 .92 r
.46018 .65225 .46114 .65324 .46282 .65276 .46186 .65179 Mtetra
.639 .744 .924 r
.46186 .65179 .46282 .65276 .46451 .6523 .46355 .65134 Mtetra
.635 .744 .927 r
.46355 .65134 .46451 .6523 .46619 .65186 .46523 .6509 Mtetra
.629 .743 .93 r
.46523 .6509 .46619 .65186 .46788 .65144 .46692 .65049 Mtetra
.625 .743 .932 r
.46692 .65049 .46788 .65144 .46956 .65103 .46861 .65009 Mtetra
.625 .746 .933 r
.46861 .65009 .46956 .65103 .47125 .65063 .4703 .64968 Mtetra
.628 .745 .931 r
.4703 .64968 .47125 .65063 .47294 .65025 .47198 .64927 Mtetra
.611 .734 .933 r
.47198 .64927 .47294 .65025 .47463 .64988 .47367 .64892 Mtetra
.562 .721 .947 r
.47367 .64892 .47463 .64988 .47632 .64955 .47536 .64873 Mtetra
.469 .715 .976 r
.47536 .64873 .47632 .64955 .47801 .64926 .47705 .64871 Mtetra
.396 .752 .993 r
.47705 .64871 .47801 .64926 .4797 .64897 .47874 .64867 Mtetra
.358 .791 .967 r
.47874 .64867 .4797 .64897 .48139 .64865 .48043 .6485 Mtetra
.404 .841 .943 r
.48043 .6485 .48139 .64865 .48309 .64826 .48213 .64814 Mtetra
.437 .861 .944 r
.48213 .64814 .48309 .64826 .48479 .64786 .48383 .64772 Mtetra
.421 .85 .946 r
.48383 .64772 .48479 .64786 .48648 .64746 .48553 .64733 Mtetra
.33 .802 .917 r
.48553 .64733 .48648 .64746 .48818 .64709 .48722 .64706 Mtetra
.417 .86 .909 r
.48722 .64706 .48818 .64709 .48988 .64665 .48893 .64658 Mtetra
.722 .967 .937 r
.48893 .64658 .48988 .64665 .49159 .64606 .49064 .64555 Mtetra
.888 .854 .803 r
.49064 .64555 .49159 .64606 .49329 .64521 .49236 .6434 Mtetra
.831 .688 .706 r
.49236 .6434 .49329 .64521 .495 .64432 .49408 .64041 Mtetra
.756 .577 .654 r
.49408 .64041 .495 .64432 .49671 .64353 .49581 .63704 Mtetra
.617 .449 .632 r
.49581 .63704 .49671 .64353 .49842 .64303 .49752 .63595 Mtetra
.566 .408 .626 r
.49752 .63595 .49842 .64303 .50012 .6426 .49922 .63588 Mtetra
.557 .404 .63 r
.49922 .63588 .50012 .6426 .50183 .6422 .50092 .636 Mtetra
.586 .431 .637 r
.50092 .636 .50183 .6422 .50354 .64173 .50263 .63559 Mtetra
.586 .431 .638 r
.50263 .63559 .50354 .64173 .50525 .64126 .50434 .63518 Mtetra
.587 .433 .639 r
.50434 .63518 .50525 .64126 .50696 .64079 .50605 .63475 Mtetra
.589 .434 .64 r
.50605 .63475 .50696 .64079 .50867 .64031 .50776 .6343 Mtetra
.59 .435 .64 r
.50776 .6343 .50867 .64031 .51039 .63983 .50947 .63384 Mtetra
.59 .436 .64 r
.50947 .63384 .51039 .63983 .5121 .63934 .51118 .63338 Mtetra
.59 .436 .641 r
.51118 .63338 .5121 .63934 .51382 .63886 .5129 .63291 Mtetra
.59 .437 .641 r
.5129 .63291 .51382 .63886 .51553 .63837 .51461 .63243 Mtetra
.591 .437 .641 r
.51461 .63243 .51553 .63837 .51725 .63788 .51633 .63196 Mtetra
.59 .437 .641 r
.51633 .63196 .51725 .63788 .51897 .6374 .51804 .63149 Mtetra
.59 .437 .642 r
.51804 .63149 .51897 .6374 .52069 .63691 .51976 .63103 Mtetra
.51976 .63103 .52069 .63691 .52241 .63643 .52148 .63057 Mtetra
.589 .437 .643 r
.52148 .63057 .52241 .63643 .52413 .63596 .5232 .63014 Mtetra
.5232 .63014 .52413 .63596 .52586 .63549 .52492 .62971 Mtetra
.582 .433 .644 r
.52492 .62971 .52586 .63549 .52758 .63509 .52665 .6294 Mtetra
.553 .414 .646 r
.52665 .6294 .52758 .63509 .52931 .635 .52837 .62958 Mtetra
.59 .443 .65 r
.52837 .62958 .52931 .635 .53103 .63453 .5301 .62916 Mtetra
.665 .495 .645 r
.5301 .62916 .53103 .63453 .53276 .63309 .53182 .62726 Mtetra
.956 .684 .48 r
.53182 .62726 .53276 .63309 .53447 .62765 .53309 .44592 Mtetra
.593 .372 .55 r
.53309 .44592 .53447 .62765 .53555 .42963 .53467 .42586 Mtetra
.761 .578 .65 r
.53467 .42586 .53555 .42963 .53716 .42367 .53629 .42248 Mtetra
.732 .721 .841 r
.53629 .42248 .53716 .42367 .53879 .4225 .53791 .42152 Mtetra
.648 .737 .915 r
.53791 .42152 .53879 .4225 .54041 .42205 .53954 .42106 Mtetra
.589 .712 .929 r
.53954 .42106 .54041 .42205 .54205 .42192 .54117 .42081 Mtetra
.655 .712 .89 r
.54117 .42081 .54205 .42192 .54368 .42142 .5428 .42031 Mtetra
.652 .71 .89 r
.5428 .42031 .54368 .42142 .54531 .42095 .54444 .41982 Mtetra
.655 .709 .888 r
.54444 .41982 .54531 .42095 .54694 .42046 .54607 .41933 Mtetra
.668 .713 .882 r
.54607 .41933 .54694 .42046 .54857 .41987 .5477 .41877 Mtetra
.672 .72 .885 r
.5477 .41877 .54857 .41987 .55021 .41926 .54934 .41819 Mtetra
.679 .728 .887 r
.54934 .41819 .55021 .41926 .55184 .41862 .55097 .41758 Mtetra
.732 .75 .867 r
.55097 .41758 .55184 .41862 .55347 .41759 .55261 .41669 Mtetra
.682 .765 .914 r
.55261 .41669 .55347 .41759 .55511 .41698 .55424 .41607 Mtetra
.489 .69 .957 r
.55424 .41607 .55511 .41698 .55675 .41728 .55588 .41607 Mtetra
.703 .26 0 r
.55588 .41607 .55675 .41728 .55846 .4236 .55756 .41888 Mtetra
.97 .69 .442 r
.55756 .41888 .55846 .4236 .56225 .62054 .5612 .607 Mtetra
.086 .028 .488 r
.5612 .607 .56225 .62054 .56404 .62433 .56307 .61835 Mtetra
.575 .426 .642 r
.56307 .61835 .56404 .62433 .5658 .6243 .56482 .61817 Mtetra
.635 .466 .636 r
.56482 .61817 .5658 .6243 .56754 .62357 .56655 .61672 Mtetra
.662 .478 .625 r
.56655 .61672 .56754 .62357 .56929 .62248 .56828 .61433 Mtetra
.601 .425 .616 r
.56828 .61433 .56929 .62248 .57104 .62188 .57002 .61335 Mtetra
.594 .418 .613 r
.57002 .61335 .57104 .62188 .57279 .62129 .57177 .61252 Mtetra
.589 .413 .611 r
.57177 .61252 .57279 .62129 .57454 .6207 .57351 .61178 Mtetra
.591 .414 .61 r
.57351 .61178 .57454 .6207 .57629 .62012 .57526 .61098 Mtetra
.59 .412 .609 r
.57526 .61098 .57629 .62012 .57805 .61955 .57701 .61019 Mtetra
.589 .41 .607 r
.57701 .61019 .57805 .61955 .5798 .61897 .57876 .6094 Mtetra
.59 .41 .606 r
.57876 .6094 .5798 .61897 .58156 .61839 .58051 .60856 Mtetra
.59 .409 .604 r
.58051 .60856 .58156 .61839 .58332 .61781 .58226 .60769 Mtetra
.59 .408 .603 r
.58226 .60769 .58332 .61781 .58508 .61722 .584 .6068 Mtetra
.59 .407 .601 r
.584 .6068 .58508 .61722 .58684 .61663 .58575 .60586 Mtetra
.59 .405 .599 r
.58575 .60586 .58684 .61663 .5886 .61604 .5875 .60489 Mtetra
.589 .403 .598 r
.5875 .60489 .5886 .61604 .59036 .61544 .58925 .60391 Mtetra
.663 .456 .594 r
.58925 .60391 .59036 .61544 .59212 .61474 .59094 .59969 Mtetra
.627 .422 .585 r
.59094 .59969 .59212 .61474 .59388 .6141 .59264 .59632 Mtetra
.458 .292 .567 r
.59264 .59632 .59388 .6141 .59565 .61359 .5945 .60083 Mtetra
.272 .167 .548 r
.5945 .60083 .59565 .61359 .59743 .61357 .59643 .60844 Mtetra
.273 .233 .629 r
.59643 .60844 .59743 .61357 .59921 .6136 .59828 .6115 Mtetra
.174 .318 .771 r
.59828 .6115 .59921 .6136 .60099 .61354 .60009 .61303 Mtetra
.408 .773 .994 r
.60009 .61303 .60099 .61354 .60276 .61312 .60188 .61293 Mtetra
.519 .894 .966 r
.60188 .61293 .60276 .61312 .60453 .61258 .60365 .61238 Mtetra
.609 .928 .967 r
.60365 .61238 .60453 .61258 .6063 .61198 .60542 .61166 Mtetra
.502 .863 .988 r
.60542 .61166 .6063 .61198 .60808 .61145 .6072 .61125 Mtetra
.422 .846 .956 r
.6072 .61125 .60808 .61145 .60985 .61094 .60898 .61087 Mtetra
.347 .821 .891 r
.60898 .61087 .60985 .61094 .61163 .61041 .61076 .61048 Mtetra
.318 .807 .828 r
.61076 .61048 .61163 .61041 .61341 .6099 .61254 .60999 Mtetra
.336 .818 .817 r
.61254 .60999 .61341 .6099 .61519 .60936 .61432 .60945 Mtetra
.388 .849 .837 r
.61432 .60945 .61519 .60936 .61697 .60879 .6161 .60884 Mtetra
.49 .903 .88 r
.6161 .60884 .61697 .60879 .61875 .60812 .61788 .60811 Mtetra
.561 .932 .913 r
.61788 .60811 .61875 .60812 .62052 .60741 .61965 .60731 Mtetra
.62 .946 .942 r
.61965 .60731 .62052 .60741 .6223 .6067 .62143 .60648 Mtetra
.659 .94 .964 r
.62143 .60648 .6223 .6067 .62408 .60606 .62321 .60565 Mtetra
.694 .907 .97 r
.62321 .60565 .62408 .60606 .62587 .60546 .62498 .60483 Mtetra
.705 .855 .954 r
.62498 .60483 .62587 .60546 .62765 .60488 .62676 .60404 Mtetra
.691 .8 .933 r
.62676 .60404 .62765 .60488 .62944 .60428 .62855 .60333 Mtetra
.677 .771 .922 r
.62855 .60333 .62944 .60428 .63122 .6037 .63033 .60268 Mtetra
.663 .754 .918 r
.63033 .60268 .63122 .6037 .63301 .60314 .63212 .6021 Mtetra
.65 .743 .918 r
.63212 .6021 .63301 .60314 .63481 .60267 .63391 .60158 Mtetra
.637 .728 .914 r
.63391 .60158 .63481 .60267 .6366 .60225 .63571 .60111 Mtetra
.627 .715 .91 r
.63571 .60111 .6366 .60225 .6384 .60187 .63751 .60069 Mtetra
.621 .706 .906 r
.63751 .60069 .6384 .60187 .6402 .60152 .63931 .6003 Mtetra
.613 .694 .901 r
.63931 .6003 .6402 .60152 .642 .60119 .64111 .59995 Mtetra
.603 .686 .901 r
.64111 .59995 .642 .60119 .64381 .60085 .64291 .59964 Mtetra
.484 .637 .922 r
.64291 .59964 .64381 .60085 .64563 .60091 .64473 .59975 Mtetra
.525 .668 .927 r
.64473 .59975 .64563 .60091 .64744 .60073 .64655 .59971 Mtetra
.65 .75 .923 r
.64655 .59971 .64744 .60073 .64923 .59987 .64835 .59918 Mtetra
.885 .848 .802 r
.64835 .59918 .64923 .59987 .6509 .59591 .6501 .597 Mtetra
.943 .902 .513 r
.6501 .597 .6509 .59591 .64532 .39804 .65175 .59235 Mtetra
.001 0 .407 r
.65175 .59235 .64532 .39804 .64667 .3882 .6462 .3967 Mtetra
.024 0 .332 r
.6462 .3967 .64667 .3882 .6483 .38598 .6476 .38839 Mtetra
0 0 .033 r
.6476 .38839 .6483 .38598 .64997 .38502 .6492 .38529 Mtetra
.848 .996 .765 r
.6492 .38529 .64997 .38502 .65167 .38449 .65084 .38337 Mtetra
.742 .748 .857 r
.65084 .38337 .65167 .38449 .65336 .38395 .65251 .38237 Mtetra
.651 .643 .829 r
.65251 .38237 .65336 .38395 .65506 .38344 .65421 .38184 Mtetra
.614 .621 .835 r
.65421 .38184 .65506 .38344 .65676 .38299 .65592 .38151 Mtetra
.616 .641 .852 r
.65592 .38151 .65676 .38299 .65846 .38251 .65763 .38118 Mtetra
.622 .666 .871 r
.65763 .38118 .65846 .38251 .66016 .38201 .65933 .38081 Mtetra
.631 .693 .89 r
.65933 .38081 .66016 .38201 .66186 .38149 .66104 .3804 Mtetra
.676 .734 .894 r
.66104 .3804 .66186 .38149 .66356 .3809 .66274 .37979 Mtetra
.698 .737 .881 r
.66274 .37979 .66356 .3809 .66526 .38027 .66443 .37905 Mtetra
.696 .716 .864 r
.66443 .37905 .66526 .38027 .66696 .37964 .66613 .37831 Mtetra
.705 .7 .843 r
.66613 .37831 .66696 .37964 .66865 .37876 .66782 .37748 Mtetra
.687 .703 .859 r
.66782 .37748 .66865 .37876 .67035 .37798 .66952 .37678 Mtetra
.618 .688 .893 r
.66952 .37678 .67035 .37798 .67207 .37772 .67123 .37643 Mtetra
.178 .428 .862 r
.67123 .37643 .67207 .37772 .67389 .3797 .67301 .37738 Mtetra
0 .036 .6 r
.67301 .37738 .67389 .3797 .67656 .39963 .67489 .38039 Mtetra
.982 .696 .341 r
.67489 .38039 .67656 .39963 .6872 .58634 .68551 .56781 Mtetra
.284 .167 .539 r
.68551 .56781 .6872 .58634 .68913 .58792 .68789 .57904 Mtetra
.57 .4 .612 r
.68789 .57904 .68913 .58792 .69096 .58754 .68973 .57882 Mtetra
.624 .439 .611 r
.68973 .57882 .69096 .58754 .69277 .58659 .69149 .57701 Mtetra
.637 .444 .604 r
.69149 .57701 .69277 .58659 .69459 .58578 .69322 .57453 Mtetra
.61 .418 .597 r
.69322 .57453 .69459 .58578 .69642 .58519 .69498 .57271 Mtetra
.534 .359 .591 r
.69498 .57271 .69642 .58519 .69825 .5847 .69688 .57367 Mtetra
.381 .256 .583 r
.69688 .57367 .69825 .5847 .7001 .58453 .69898 .57844 Mtetra
.33 .259 .625 r
.69898 .57844 .7001 .58453 .70197 .58454 .70101 .58169 Mtetra
.282 .327 .732 r
.70101 .58169 .70197 .58454 .70383 .58451 .70297 .58343 Mtetra
.333 .588 .937 r
.70297 .58343 .70383 .58451 .70568 .58423 .70486 .58387 Mtetra
.43 .823 .985 r
.70486 .58387 .70568 .58423 .70752 .58377 .70671 .58359 Mtetra
.474 .878 .952 r
.70671 .58359 .70752 .58377 .70936 .58325 .70855 .58307 Mtetra
.479 .882 .95 r
.70855 .58307 .70936 .58325 .71121 .58272 .71039 .58254 Mtetra
.476 .879 .953 r
.71039 .58254 .71121 .58272 .71305 .58221 .71224 .58202 Mtetra
.495 .888 .956 r
.71224 .58202 .71305 .58221 .71489 .58168 .71408 .58147 Mtetra
.502 .887 .963 r
.71408 .58147 .71489 .58168 .71674 .58115 .71593 .58092 Mtetra
.506 .887 .966 r
.71593 .58092 .71674 .58115 .71858 .58061 .71778 .58038 Mtetra
.522 .894 .967 r
.71778 .58038 .71858 .58061 .72043 .58006 .71962 .57981 Mtetra
.571 .912 .971 r
.71962 .57981 .72043 .58006 .72228 .57948 .72147 .57916 Mtetra
.625 .918 .978 r
.72147 .57916 .72228 .57948 .72412 .57886 .72331 .57843 Mtetra
.654 .902 .982 r
.72331 .57843 .72412 .57886 .72597 .57825 .72515 .5777 Mtetra
.649 .871 .982 r
.72515 .5777 .72597 .57825 .72782 .57766 .72699 .57704 Mtetra
.632 .847 .982 r
.72699 .57704 .72782 .57766 .72967 .57711 .72884 .57647 Mtetra
.623 .839 .983 r
.72884 .57647 .72967 .57711 .73152 .57656 .7307 .57592 Mtetra
.62 .838 .984 r
.7307 .57592 .73152 .57656 .73338 .57604 .73256 .57539 Mtetra
.62 .837 .983 r
.73256 .57539 .73338 .57604 .73524 .57552 .73441 .57486 Mtetra
.621 .834 .982 r
.73441 .57486 .73524 .57552 .7371 .57499 .73627 .57433 Mtetra
.565 .81 .991 r
.73627 .57433 .7371 .57499 .73897 .57472 .73815 .57396 Mtetra
.566 .787 .982 r
.73815 .57396 .73897 .57472 .74085 .57449 .74002 .57363 Mtetra
.672 .802 .944 r
.74002 .57363 .74085 .57449 .7427 .57375 .74188 .57297 Mtetra
.855 .851 .837 r
.74188 .57297 .7427 .57375 .74443 .57112 .74366 .57115 Mtetra
.982 .902 .649 r
.74366 .57115 .74443 .57112 .7457 .56155 .7453 .56718 Mtetra
0 0 .085 r
.7453 .56718 .7457 .56155 .73443 .36147 .74651 .55675 Mtetra
.071 0 .442 r
.74651 .55675 .73443 .36147 .736 .35822 .73576 .36559 Mtetra
.535 .271 .462 r
.73576 .36559 .736 .35822 .73774 .3575 .73755 .36545 Mtetra
.579 .31 .473 r
.73755 .36545 .73774 .3575 .73951 .35733 .7394 .36642 Mtetra
.369 .152 .449 r
.7394 .36642 .73951 .35733 .74127 .35694 .74092 .36235 Mtetra
.131 0 .335 r
.74092 .36235 .74127 .35694 .743 .35602 .74239 .35759 Mtetra
0 0 0 r
.74239 .35759 .743 .35602 .74472 .3551 .74398 .35472 Mtetra
.859 .936 .872 r
.74398 .35472 .74472 .3551 .74646 .35433 .74566 .35313 Mtetra
.686 .722 .877 r
.74566 .35313 .74646 .35433 .74821 .35374 .74741 .35244 Mtetra
.638 .685 .878 r
.74741 .35244 .74821 .35374 .74997 .35318 .74917 .35199 Mtetra
.689 .724 .877 r
.74917 .35199 .74997 .35318 .7517 .35236 .75092 .35128 Mtetra
.741 .763 .87 r
.75092 .35128 .7517 .35236 .75343 .35136 .75264 .35029 Mtetra
.644 .73 .911 r
.75264 .35029 .75343 .35136 .75519 .35087 .75441 .3498 Mtetra
0 .31 .8 r
.75441 .3498 .75519 .35087 .75709 .35216 .7563 .3511 Mtetra
.951 .602 .229 r
.7563 .3511 .75709 .35216 .75986 .36542 .75909 .36448 Mtetra
.975 .673 .363 r
.75909 .36448 .75986 .36542 .77621 .56108 .77538 .56009 Mtetra
.549 .08 0 r
.77538 .56009 .77621 .56108 .77832 .56365 .7775 .56265 Mtetra
.45 .673 .959 r
.7775 .56265 .77832 .56365 .78026 .56375 .77944 .56275 Mtetra
.727 .792 .903 r
.77944 .56275 .78026 .56375 .78212 .56281 .7813 .56181 Mtetra
.9 .813 .752 r
.7813 .56181 .78212 .56281 .78384 .56005 .78302 .55906 Mtetra
.978 .747 .518 r
.78302 .55906 .78384 .56005 .78496 .54959 .78415 .54862 Mtetra
.977 .681 .375 r
.78415 .54862 .78496 .54959 .77128 .34865 .7705 .34759 Mtetra
.925 .789 .692 r
.7705 .34759 .77128 .34865 .77282 .34515 .77204 .34409 Mtetra
.722 .764 .886 r
.77204 .34409 .77282 .34515 .77456 .34428 .77379 .34322 Mtetra
.595 .714 .927 r
.77379 .34322 .77456 .34428 .77635 .34398 .77558 .34292 Mtetra
.623 .726 .921 r
.77558 .34292 .77635 .34398 .77814 .34358 .77737 .34252 Mtetra
.737 .769 .879 r
.77737 .34252 .77814 .34358 .77988 .34261 .77911 .34155 Mtetra
.645 .735 .915 r
.77911 .34155 .77988 .34261 .78166 .34211 .78089 .34105 Mtetra
.083 .414 .863 r
.78089 .34105 .78166 .34211 .78356 .34313 .78279 .34207 Mtetra
.924 .551 .136 r
.78279 .34207 .78356 .34313 .78614 .35229 .78538 .35135 Mtetra
.975 .67 .35 r
.78538 .35135 .78614 .35229 .80455 .55239 .80374 .55141 Mtetra
.611 .145 0 r
.80374 .55141 .80455 .55239 .80675 .55535 .80594 .55436 Mtetra
.424 .66 .959 r
.80594 .55436 .80675 .55535 .80871 .55552 .8079 .55453 Mtetra
.718 .791 .909 r
.8079 .55453 .80871 .55552 .81059 .55463 .80978 .55363 Mtetra
.894 .818 .765 r
.80978 .55363 .81059 .55463 .81233 .55205 .81152 .55105 Mtetra
.98 .751 .519 r
.81152 .55105 .81233 .55205 .81344 .54224 .81263 .5412 Mtetra
.977 .678 .362 r
.81263 .5412 .81344 .54224 .79793 .34006 .79717 .33897 Mtetra
.935 .785 .67 r
.79717 .33897 .79793 .34006 .79943 .33615 .79867 .33506 Mtetra
.778 .776 .851 r
.79867 .33506 .79943 .33615 .80116 .33491 .80039 .3338 Mtetra
.593 .703 .919 r
.80039 .3338 .80116 .33491 .80297 .33463 .8022 .33351 Mtetra
0 .322 .809 r
.8022 .33351 .80297 .33463 .80493 .33597 .80416 .33486 Mtetra
.943 .59 .193 r
.80416 .33486 .80493 .33597 .80797 .34949 .80721 .34846 Mtetra
.975 .667 .337 r
.80721 .34846 .80797 .34949 .82752 .54649 .82675 .54574 Mtetra
0 .018 .512 r
.82675 .54574 .82752 .54649 .82963 .54808 .8289 .54781 Mtetra
.913 .956 .806 r
.8289 .54781 .82963 .54808 .83118 .54347 .83067 .54557 Mtetra
0 0 0 r
.83067 .54557 .83118 .54347 .81448 .33957 .83215 .54014 Mtetra
.092 .009 .459 r
.83215 .54014 .81448 .33957 .81568 .33247 .8156 .33875 Mtetra
.126 0 .362 r
.8156 .33875 .81568 .33247 .81739 .33094 .8169 .33283 Mtetra
0 0 .027 r
.8169 .33283 .81739 .33094 .81915 .33007 .8185 .33005 Mtetra
.847 .998 .814 r
.8185 .33005 .81915 .33007 .82094 .32937 .82018 .32827 Mtetra
.772 .776 .856 r
.82018 .32827 .82094 .32937 .82269 .32829 .82192 .32705 Mtetra
.657 .708 .885 r
.82192 .32705 .82269 .32829 .82449 .32769 .82373 .32649 Mtetra
.331 .544 .909 r
.82373 .32649 .82449 .32769 .82639 .32816 .82564 .32707 Mtetra
.794 .377 0 r
.82564 .32707 .82639 .32816 .82874 .33323 .82798 .33212 Mtetra
.974 .665 .325 r
.82798 .33212 .82874 .33323 .85033 .53685 .84954 .5358 Mtetra
.73 .291 0 r
.84954 .5358 .85033 .53685 .85273 .54111 .85194 .54007 Mtetra
.519 .699 .952 r
.85194 .54007 .85273 .54111 .85471 .54105 .85392 .53998 Mtetra
.708 .778 .907 r
.85392 .53998 .85471 .54105 .85662 .54022 .85583 .53913 Mtetra
.754 .788 .881 r
.85583 .53913 .85662 .54022 .85851 .53913 .85771 .538 Mtetra
.651 .744 .917 r
.85771 .538 .85851 .53913 .86045 .5386 .85965 .53743 Mtetra
.64 .729 .913 r
.85965 .53743 .86045 .5386 .86239 .53811 .86159 .53691 Mtetra
.607 .71 .917 r
.86159 .53691 .86239 .53811 .86435 .53771 .86356 .53654 Mtetra
.49 .657 .934 r
.86356 .53654 .86435 .53771 .86636 .53774 .86556 .53661 Mtetra
.571 .707 .934 r
.86556 .53661 .86636 .53774 .86831 .53733 .86754 .53637 Mtetra
.718 .806 .92 r
.86754 .53637 .86831 .53733 .87017 .53591 .86945 .53547 Mtetra
.951 .912 .742 r
.86945 .53547 .87017 .53591 .87156 .52996 .87116 .53256 Mtetra
0 0 0 r
.87116 .53256 .87156 .52996 .85234 .3259 .87255 .52662 Mtetra
.113 .027 .47 r
.87255 .52662 .85234 .3259 .85361 .32007 .85364 .32635 Mtetra
.162 0 .378 r
.85364 .32635 .85361 .32007 .85534 .31861 .85494 .32069 Mtetra
0 0 .103 r
.85494 .32069 .85534 .31861 .85714 .31784 .85653 .31797 Mtetra
.763 .989 .766 r
.85653 .31797 .85714 .31784 .85898 .31741 .85824 .31629 Mtetra
.695 .75 .894 r
.85824 .31629 .85898 .31741 .86081 .31684 .86005 .31554 Mtetra
.634 .69 .884 r
.86005 .31554 .86081 .31684 .86264 .31633 .86189 .31508 Mtetra
.609 .687 .898 r
.86189 .31508 .86264 .31633 .86447 .31582 .86374 .31474 Mtetra
.665 .745 .91 r
.86374 .31474 .86447 .31582 .86629 .31519 .86557 .31414 Mtetra
.675 .757 .913 r
.86557 .31414 .86629 .31519 .86811 .31453 .86739 .31349 Mtetra
.693 .767 .909 r
.86739 .31349 .86811 .31453 .86993 .31382 .8692 .31276 Mtetra
.786 .793 .858 r
.8692 .31276 .86993 .31382 .8717 .31266 .87095 .31146 Mtetra
.716 .743 .873 r
.87095 .31146 .8717 .31266 .87351 .3119 .87275 .31057 Mtetra
.555 .645 .893 r
.87275 .31057 .87351 .3119 .87541 .31193 .87464 .31047 Mtetra
0 0 .368 r
.87464 .31047 .87541 .31193 .87783 .31655 .87702 .31476 Mtetra
.97 .657 .292 r
.87702 .31476 .87783 .31655 .90289 .52138 .90208 .51996 Mtetra
.707 .309 0 r
.90208 .51996 .90289 .52138 .90549 .52642 .90473 .52539 Mtetra
.268 .559 .932 r
.90473 .52539 .90549 .52642 .90759 .52702 .90683 .526 Mtetra
.641 .767 .939 r
.90683 .526 .90759 .52702 .90957 .52648 .90881 .52545 Mtetra
.829 .825 .844 r
.90881 .52545 .90957 .52648 .91141 .52481 .91065 .52376 Mtetra
.908 .736 .657 r
.27682 .70504 .27785 .70589 .27977 .7004 .27875 .69953 Mtetra
.936 .686 .535 r
.27875 .69953 .27977 .7004 .29481 .50523 .29385 .5043 Mtetra
.906 .726 .647 r
.29385 .5043 .29481 .50523 .29666 .49947 .2957 .49857 Mtetra
.772 .757 .84 r
.2957 .49857 .29666 .49947 .29819 .49835 .29723 .49745 Mtetra
.641 .734 .917 r
.29723 .49745 .29819 .49835 .29967 .49795 .29872 .49705 Mtetra
.512 .691 .949 r
.29872 .49705 .29967 .49795 .30114 .49791 .30018 .49701 Mtetra
.749 .757 .859 r
.30018 .49701 .30114 .49791 .30266 .49697 .3017 .49607 Mtetra
.696 .749 .892 r
.3017 .49607 .30266 .49697 .30416 .49634 .3032 .49544 Mtetra
.478 .678 .953 r
.3032 .49544 .30416 .49634 .30562 .49638 .30466 .49548 Mtetra
.928 .55 .257 r
.30466 .49548 .30562 .49638 .30681 .50046 .30585 .49955 Mtetra
.939 .683 .523 r
.30585 .49955 .30681 .50046 .2956 .69489 .29458 .69402 Mtetra
.935 .58 .321 r
.29458 .69402 .2956 .69489 .29681 .70012 .29579 .69926 Mtetra
0 .364 .81 r
.29579 .69926 .29681 .70012 .29832 .70092 .2973 .70005 Mtetra
.63 .752 .935 r
.2973 .70005 .29832 .70092 .2999 .70053 .29888 .69965 Mtetra
.806 .774 .824 r
.29888 .69965 .2999 .70053 .30155 .69905 .30053 .69817 Mtetra
.909 .736 .655 r
.30053 .69817 .30155 .69905 .30346 .69347 .30244 .69263 Mtetra
.939 .687 .53 r
.30244 .69263 .30346 .69347 .31728 .49736 .31632 .49659 Mtetra
.915 .737 .648 r
.31632 .49659 .31728 .49736 .3191 .4918 .31814 .49098 Mtetra
.783 .776 .846 r
.31814 .49098 .3191 .4918 .32064 .49067 .31969 .48981 Mtetra
.598 .734 .939 r
.31969 .48981 .32064 .49067 .32213 .49043 .32118 .48954 Mtetra
.426 .657 .956 r
.32118 .48954 .32213 .49043 .32359 .49061 .32264 .48967 Mtetra
.624 .723 .918 r
.32264 .48967 .32359 .49061 .32509 .49027 .32414 .48933 Mtetra
.656 .731 .905 r
.32414 .48933 .32509 .49027 .32659 .4898 .32564 .48887 Mtetra
.664 .736 .903 r
.32564 .48887 .32659 .4898 .3281 .48929 .32715 .48837 Mtetra
.751 .757 .857 r
.32715 .48837 .3281 .48929 .32963 .48832 .32868 .48741 Mtetra
.713 .753 .884 r
.32868 .48741 .32963 .48832 .33115 .48759 .3302 .48669 Mtetra
.535 .702 .947 r
.3302 .48669 .33115 .48759 .33264 .48749 .33169 .4866 Mtetra
.908 .5 .168 r
.33169 .4866 .33264 .48749 .33392 .49086 .33297 .48998 Mtetra
.942 .683 .517 r
.33297 .48998 .33392 .49086 .32429 .68537 .32327 .68454 Mtetra
.939 .595 .346 r
.32327 .68454 .32429 .68537 .32551 .69152 .3245 .69067 Mtetra
0 .202 .671 r
.3245 .69067 .32551 .69152 .32702 .69259 .32601 .69172 Mtetra
.599 .745 .946 r
.32601 .69172 .32702 .69259 .32862 .6923 .32761 .69142 Mtetra
.796 .777 .836 r
.32761 .69142 .32862 .6923 .33027 .69094 .32926 .69006 Mtetra
.906 .744 .669 r
.32926 .69006 .33027 .69094 .33212 .68606 .33111 .68521 Mtetra
.942 .688 .524 r
.33111 .68521 .33212 .68606 .3444 .48963 .34345 .48889 Mtetra
.923 .736 .632 r
.34345 .48889 .3444 .48963 .34624 .48325 .34529 .48242 Mtetra
.812 .777 .821 r
.34529 .48242 .34624 .48325 .34781 .48183 .34686 .48097 Mtetra
.614 .74 .935 r
.34686 .48097 .34781 .48183 .34931 .48154 .34837 .48064 Mtetra
.436 .662 .956 r
.34837 .48064 .34931 .48154 .3508 .48169 .34986 .48076 Mtetra
.597 .716 .927 r
.34986 .48076 .3508 .48169 .3523 .48144 .35136 .4805 Mtetra
.649 .731 .909 r
.35136 .4805 .3523 .48144 .35382 .48099 .35288 .48006 Mtetra
.658 .737 .908 r
.35288 .48006 .35382 .48099 .35534 .48049 .3544 .47958 Mtetra
.745 .761 .866 r
.3544 .47958 .35534 .48049 .35689 .47955 .35595 .47867 Mtetra
.72 .762 .885 r
.35595 .47867 .35689 .47955 .35843 .47877 .35748 .47791 Mtetra
.549 .718 .951 r
.35748 .47791 .35843 .47877 .35993 .47862 .35899 .47776 Mtetra
.892 .468 .121 r
.35899 .47776 .35993 .47862 .36128 .48175 .36033 .4809 Mtetra
.945 .684 .51 r
.36033 .4809 .36128 .48175 .35319 .67713 .3522 .67618 Mtetra
.943 .596 .328 r
.3522 .67618 .35319 .67713 .35448 .68341 .35348 .68247 Mtetra
0 .394 .843 r
.35348 .68247 .35448 .68341 .35604 .68419 .35504 .68327 Mtetra
.674 .756 .913 r
.35504 .68327 .35604 .68419 .35767 .68359 .35667 .6827 Mtetra
.758 .777 .869 r
.35667 .6827 .35767 .68359 .35932 .68253 .35832 .68166 Mtetra
.576 .739 .953 r
.35832 .68166 .35932 .68253 .36093 .68235 .35993 .68142 Mtetra
.542 .712 .951 r
.35993 .68142 .36093 .68235 .36253 .6823 .36154 .68128 Mtetra
.709 .745 .88 r
.36154 .68128 .36253 .6823 .36417 .68162 .36318 .68052 Mtetra
.886 .737 .692 r
.36318 .68052 .36417 .68162 .36594 .67788 .36496 .67663 Mtetra
.945 .688 .516 r
.36496 .67663 .36594 .67788 .37634 .48224 .37544 .48062 Mtetra
.906 .697 .61 r
.37544 .48062 .37634 .48224 .37826 .47321 .37733 .47227 Mtetra
.839 .76 .776 r
.37733 .47227 .37826 .47321 .37986 .47121 .37893 .47032 Mtetra
.674 .751 .909 r
.37893 .47032 .37986 .47121 .3814 .47066 .38047 .46977 Mtetra
.523 .703 .952 r
.38047 .46977 .3814 .47066 .38292 .47059 .38198 .4697 Mtetra
.567 .719 .944 r
.38198 .4697 .38292 .47059 .38444 .47042 .38351 .46951 Mtetra
.611 .729 .929 r
.38351 .46951 .38444 .47042 .38597 .47014 .38504 .4692 Mtetra
.614 .723 .923 r
.38504 .4692 .38597 .47014 .3875 .46985 .38657 .46888 Mtetra
.636 .725 .912 r
.38657 .46888 .3875 .46985 .38904 .46944 .38811 .46848 Mtetra
.656 .732 .905 r
.38811 .46848 .38904 .46944 .39058 .46894 .38965 .46801 Mtetra
.67 .743 .905 r
.38965 .46801 .39058 .46894 .39212 .46836 .39119 .46748 Mtetra
.707 .762 .895 r
.39119 .46748 .39212 .46836 .39368 .46749 .39275 .46678 Mtetra
.717 .804 .918 r
.39275 .46678 .39368 .46749 .39524 .46662 .3943 .46605 Mtetra
.677 .835 .959 r
.3943 .46605 .39524 .46662 .39679 .46608 .39585 .46547 Mtetra
.446 .746 .992 r
.39585 .46547 .39679 .46608 .39828 .46681 .39738 .46541 Mtetra
.391 .532 .877 r
.39738 .46541 .39828 .46681 .39971 .46949 .39889 .46585 Mtetra
.49 .407 .689 r
.39889 .46585 .39971 .46949 .40079 .48158 .40039 .4665 Mtetra
.565 .373 .58 r
.40039 .4665 .40079 .48158 .39564 .66177 .40193 .46621 Mtetra
.556 .343 .546 r
.40193 .46621 .39564 .66177 .39731 .66053 .4035 .46532 Mtetra
.555 .342 .546 r
.4035 .46532 .39731 .66053 .39899 .65881 .40505 .46495 Mtetra
.548 .336 .545 r
.40505 .46495 .39899 .65881 .40045 .66343 .40647 .46802 Mtetra
0 0 .312 r
.40647 .46802 .40045 .66343 .40195 .66718 .40111 .66222 Mtetra
0 0 .425 r
.40111 .66222 .40195 .66718 .40351 .66907 .40255 .66761 Mtetra
.043 .326 .809 r
.40255 .66761 .40351 .66907 .40513 .66952 .40414 .66877 Mtetra
.594 .777 .968 r
.40414 .66877 .40513 .66952 .40678 .66913 .40579 .66844 Mtetra
.714 .819 .93 r
.40579 .66844 .40678 .66913 .40844 .66848 .40745 .66767 Mtetra
.679 .786 .93 r
.40745 .66767 .40844 .66848 .41009 .66806 .40911 .66706 Mtetra
.633 .732 .92 r
.40911 .66706 .41009 .66806 .41174 .66776 .41076 .66665 Mtetra
.67 .721 .887 r
.41076 .66665 .41174 .66776 .4134 .66711 .41242 .66607 Mtetra
.719 .748 .875 r
.41242 .66607 .4134 .66711 .41509 .66536 .41409 .66524 Mtetra
.808 .953 .913 r
.41409 .66524 .41509 .66536 .41685 .66154 .41577 .66396 Mtetra
0 0 .042 r
.41577 .66396 .41685 .66154 .41902 .64431 .41748 .66184 Mtetra
.387 .178 .47 r
.41748 .66184 .41902 .64431 .42616 .46126 .41931 .65562 Mtetra
0 0 .309 r
.41931 .65562 .42616 .46126 .42781 .45775 .42679 .46034 Mtetra
.778 .811 .329 r
.42679 .46034 .42781 .45775 .42942 .45568 .42849 .45547 Mtetra
.896 .9 .822 r
.42849 .45547 .42942 .45568 .43101 .45451 .43009 .45356 Mtetra
.696 .748 .892 r
.43009 .45356 .43101 .45451 .43257 .45392 .43166 .4529 Mtetra
.614 .707 .911 r
.43166 .4529 .43257 .45392 .43413 .45353 .43322 .45258 Mtetra
.633 .73 .918 r
.43322 .45258 .43413 .45353 .4357 .45304 .43479 .45219 Mtetra
.688 .768 .913 r
.43479 .45219 .4357 .45304 .43727 .45237 .43636 .45157 Mtetra
.688 .781 .922 r
.43636 .45157 .43727 .45237 .43885 .4517 .43793 .45096 Mtetra
.68 .793 .935 r
.43793 .45096 .43885 .4517 .44042 .45108 .4395 .45038 Mtetra
.669 .8 .945 r
.4395 .45038 .44042 .45108 .44199 .45053 .44107 .44983 Mtetra
.665 .801 .948 r
.44107 .44983 .44199 .45053 .44356 .44999 .44265 .44929 Mtetra
.679 .804 .942 r
.44265 .44929 .44356 .44999 .44514 .44936 .44422 .44871 Mtetra
.687 .819 .946 r
.44422 .44871 .44514 .44936 .44671 .44866 .4458 .44809 Mtetra
.649 .831 .97 r
.4458 .44809 .44671 .44866 .44829 .44821 .44737 .44758 Mtetra
.588 .799 .98 r
.44737 .44758 .44829 .44821 .44984 .44841 .44894 .44724 Mtetra
.542 .651 .906 r
.44894 .44724 .44984 .44841 .45138 .44975 .45051 .44719 Mtetra
.496 .462 .749 r
.45051 .44719 .45138 .44975 .45288 .45286 .45207 .44761 Mtetra
.392 .302 .633 r
.45207 .44761 .45288 .45286 .45043 .63963 .45359 .44955 Mtetra
.522 .315 .541 r
.45359 .44955 .45043 .63963 .45186 .65067 .45483 .46532 Mtetra
0 0 .336 r
.45483 .46532 .45186 .65067 .45347 .65316 .45254 .65072 Mtetra
0 .144 .668 r
.45254 .65072 .45347 .65316 .45513 .65389 .45417 .65293 Mtetra
.545 .711 .949 r
.45417 .65293 .45513 .65389 .45681 .65358 .45584 .65278 Mtetra
.7 .798 .926 r
.45584 .65278 .45681 .65358 .45849 .65292 .45753 .65207 Mtetra
.709 .787 .912 r
.45753 .65207 .45849 .65292 .46018 .65225 .45922 .65131 Mtetra
.638 .749 .929 r
.45922 .65131 .46018 .65225 .46186 .65179 .4609 .65086 Mtetra
.637 .752 .931 r
.4609 .65086 .46186 .65179 .46355 .65134 .46259 .65041 Mtetra
.632 .752 .934 r
.46259 .65041 .46355 .65134 .46523 .6509 .46428 .64998 Mtetra
.625 .75 .937 r
.46428 .64998 .46523 .6509 .46692 .65049 .46596 .64958 Mtetra
.621 .751 .939 r
.46596 .64958 .46692 .65049 .46861 .65009 .46765 .64918 Mtetra
.62 .753 .941 r
.46765 .64918 .46861 .65009 .4703 .64968 .46934 .64879 Mtetra
.621 .755 .942 r
.46934 .64879 .4703 .64968 .47198 .64927 .47103 .64839 Mtetra
.606 .754 .949 r
.47103 .64839 .47198 .64927 .47367 .64892 .47272 .64804 Mtetra
.574 .742 .956 r
.47272 .64804 .47367 .64892 .47536 .64873 .47441 .64779 Mtetra
.537 .714 .954 r
.47441 .64779 .47536 .64873 .47705 .64871 .4761 .64766 Mtetra
.553 .696 .934 r
.4761 .64766 .47705 .64871 .47874 .64867 .47779 .64752 Mtetra
.586 .688 .912 r
.47779 .64752 .47874 .64867 .48043 .6485 .47948 .64729 Mtetra
.621 .69 .893 r
.47948 .64729 .48043 .6485 .48213 .64814 .48118 .64692 Mtetra
.633 .694 .889 r
.48118 .64692 .48213 .64814 .48383 .64772 .48288 .64651 Mtetra
.612 .688 .897 r
.48288 .64651 .48383 .64772 .48553 .64733 .48458 .64618 Mtetra
.566 .68 .917 r
.48458 .64618 .48553 .64733 .48722 .64706 .48628 .64602 Mtetra
.653 .736 .91 r
.48628 .64602 .48722 .64706 .48893 .64658 .48798 .64551 Mtetra
.797 .763 .821 r
.48798 .64551 .48893 .64658 .49064 .64555 .48969 .64401 Mtetra
.88 .716 .675 r
.48969 .64401 .49064 .64555 .49236 .6434 .49143 .63979 Mtetra
.955 .687 .487 r
.49143 .63979 .49236 .6434 .49408 .64041 .49485 .4522 Mtetra
.583 .364 .549 r
.49485 .4522 .49408 .64041 .49581 .63704 .4966 .43691 Mtetra
.557 .343 .546 r
.4966 .43691 .49581 .63704 .49752 .63595 .49821 .4357 Mtetra
.555 .342 .546 r
.49821 .4357 .49752 .63595 .49922 .63588 .49981 .43555 Mtetra
.554 .341 .546 r
.49981 .43555 .49922 .63588 .50092 .636 .50142 .43573 Mtetra
.555 .342 .546 r
.50142 .43573 .50092 .636 .50263 .63559 .50303 .43528 Mtetra
.50303 .43528 .50263 .63559 .50434 .63518 .50464 .43485 Mtetra
.50464 .43485 .50434 .63518 .50605 .63475 .50625 .43442 Mtetra
.50625 .43442 .50605 .63475 .50776 .6343 .50786 .43394 Mtetra
.50786 .43394 .50776 .6343 .50947 .63384 .50947 .43346 Mtetra
.50947 .43346 .50947 .63384 .51118 .63338 .51109 .43296 Mtetra
.51109 .43296 .51118 .63338 .5129 .63291 .5127 .43247 Mtetra
.5127 .43247 .5129 .63291 .51461 .63243 .51432 .43197 Mtetra
.51432 .43197 .51461 .63243 .51633 .63196 .51594 .43147 Mtetra
.51594 .43147 .51633 .63196 .51804 .63149 .51756 .43097 Mtetra
.51756 .43097 .51804 .63149 .51976 .63103 .51918 .43049 Mtetra
.51918 .43049 .51976 .63103 .52148 .63057 .5208 .43001 Mtetra
.5208 .43001 .52148 .63057 .5232 .63014 .52242 .42955 Mtetra
.52242 .42955 .5232 .63014 .52492 .62971 .52404 .4291 Mtetra
.52404 .4291 .52492 .62971 .52665 .6294 .52567 .42874 Mtetra
.555 .341 .546 r
.52567 .42874 .52665 .6294 .52837 .62958 .52729 .42869 Mtetra
.555 .342 .546 r
.52729 .42869 .52837 .62958 .5301 .62916 .52892 .42834 Mtetra
.557 .343 .546 r
.52892 .42834 .5301 .62916 .53182 .62726 .53054 .42716 Mtetra
.559 .345 .546 r
.53054 .42716 .53182 .62726 .53309 .44592 .53217 .42473 Mtetra
.589 .384 .572 r
.53217 .42473 .53309 .44592 .53467 .42586 .53379 .42271 Mtetra
.693 .554 .692 r
.53379 .42271 .53467 .42586 .53629 .42248 .53541 .42123 Mtetra
.688 .698 .854 r
.53541 .42123 .53629 .42248 .53791 .42152 .53704 .42054 Mtetra
.651 .737 .913 r
.53704 .42054 .53791 .42152 .53954 .42106 .53867 .42006 Mtetra
.628 .727 .918 r
.53867 .42006 .53954 .42106 .54117 .42081 .5403 .41967 Mtetra
.655 .708 .886 r
.5403 .41967 .54117 .42081 .5428 .42031 .54193 .41917 Mtetra
.655 .707 .886 r
.54193 .41917 .5428 .42031 .54444 .41982 .54357 .41868 Mtetra
.657 .706 .883 r
.54357 .41868 .54444 .41982 .54607 .41933 .5452 .41817 Mtetra
.662 .706 .88 r
.5452 .41817 .54607 .41933 .5477 .41877 .54683 .41764 Mtetra
.666 .712 .883 r
.54683 .41764 .5477 .41877 .54934 .41819 .54847 .41708 Mtetra
.672 .719 .884 r
.54847 .41708 .54934 .41819 .55097 .41758 .5501 .41651 Mtetra
.701 .735 .877 r
.5501 .41651 .55097 .41758 .55261 .41669 .55174 .41578 Mtetra
.682 .765 .914 r
.55174 .41578 .55261 .41669 .55424 .41607 .55338 .41516 Mtetra
.618 .743 .936 r
.55338 .41516 .55424 .41607 .55588 .41607 .55502 .4148 Mtetra
.35 .535 .896 r
.55502 .4148 .55588 .41607 .55756 .41888 .55667 .4153 Mtetra
.462 .395 .695 r
.55667 .4153 .55756 .41888 .5612 .607 .55832 .4162 Mtetra
.553 .34 .546 r
.55832 .4162 .5612 .607 .56307 .61835 .55998 .41724 Mtetra
.556 .342 .546 r
.55998 .41724 .56307 .61835 .56482 .61817 .56163 .41658 Mtetra
.557 .343 .546 r
.56163 .41658 .56482 .61817 .56655 .61672 .56326 .41545 Mtetra
.56326 .41545 .56655 .61672 .56828 .61433 .5649 .41423 Mtetra
.556 .342 .546 r
.5649 .41423 .56828 .61433 .57002 .61335 .56655 .4135 Mtetra
.56655 .4135 .57002 .61335 .57177 .61252 .56819 .41283 Mtetra
.56819 .41283 .57177 .61252 .57351 .61178 .56984 .41221 Mtetra
.56984 .41221 .57351 .61178 .57526 .61098 .57149 .41158 Mtetra
.57149 .41158 .57526 .61098 .57701 .61019 .57314 .41096 Mtetra
.57314 .41096 .57701 .61019 .57876 .6094 .57479 .41034 Mtetra
.57479 .41034 .57876 .6094 .58051 .60856 .57644 .40972 Mtetra
.57644 .40972 .58051 .60856 .58226 .60769 .57809 .40911 Mtetra
.57809 .40911 .58226 .60769 .584 .6068 .57975 .40849 Mtetra
.57975 .40849 .584 .6068 .58575 .60586 .5814 .40787 Mtetra
.5814 .40787 .58575 .60586 .5875 .60489 .58306 .40725 Mtetra
.58306 .40725 .5875 .60489 .58925 .60391 .58471 .40665 Mtetra
.557 .343 .546 r
.58471 .40665 .58925 .60391 .59094 .59969 .58636 .40549 Mtetra
.556 .343 .546 r
.58636 .40549 .59094 .59969 .59264 .59632 .58801 .40478 Mtetra
.554 .341 .546 r
.58801 .40478 .59264 .59632 .5945 .60083 .58969 .40493 Mtetra
.541 .331 .544 r
.58969 .40493 .5945 .60083 .59643 .60844 .59151 .41242 Mtetra
0 0 .397 r
.59151 .41242 .59643 .60844 .59828 .6115 .59733 .60836 Mtetra
0 .011 .569 r
.59733 .60836 .59828 .6115 .60009 .61303 .59919 .61199 Mtetra
.42 .64 .948 r
.59919 .61199 .60009 .61303 .60188 .61293 .60098 .61219 Mtetra
.646 .811 .963 r
.60098 .61219 .60188 .61293 .60365 .61238 .60275 .61164 Mtetra
.727 .831 .929 r
.60275 .61164 .60365 .61238 .60542 .61166 .60452 .61077 Mtetra
.636 .771 .945 r
.60452 .61077 .60542 .61166 .6072 .61125 .6063 .61029 Mtetra
.628 .753 .937 r
.6063 .61029 .6072 .61125 .60898 .61087 .60808 .60985 Mtetra
.635 .741 .925 r
.60808 .60985 .60898 .61087 .61076 .61048 .60986 .60939 Mtetra
.65 .734 .911 r
.60986 .60939 .61076 .61048 .61254 .60999 .61164 .60887 Mtetra
.66 .73 .902 r
.61164 .60887 .61254 .60999 .61432 .60945 .61342 .60831 Mtetra
.669 .73 .895 r
.61342 .60831 .61432 .60945 .6161 .60884 .6152 .6077 Mtetra
.684 .735 .89 r
.6152 .6077 .6161 .60884 .61788 .60811 .61698 .60701 Mtetra
.694 .746 .892 r
.61698 .60701 .61788 .60811 .61965 .60731 .61875 .60627 Mtetra
.701 .76 .898 r
.61875 .60627 .61965 .60731 .62143 .60648 .62053 .6055 Mtetra
.705 .775 .907 r
.62053 .6055 .62143 .60648 .62321 .60565 .62231 .60473 Mtetra
.706 .786 .914 r
.62231 .60473 .62321 .60565 .62498 .60483 .62409 .60394 Mtetra
.703 .794 .921 r
.62409 .60394 .62498 .60483 .62676 .60404 .62587 .60318 Mtetra
.693 .797 .929 r
.62587 .60318 .62676 .60404 .62855 .60333 .62766 .60246 Mtetra
.683 .792 .932 r
.62766 .60246 .62855 .60333 .63033 .60268 .62944 .60178 Mtetra
.673 .782 .931 r
.62944 .60178 .63033 .60268 .63212 .6021 .63123 .60115 Mtetra
.662 .767 .928 r
.63123 .60115 .63212 .6021 .63391 .60158 .63302 .60056 Mtetra
.651 .751 .923 r
.63302 .60056 .63391 .60158 .63571 .60111 .63482 .60003 Mtetra
.639 .733 .917 r
.63482 .60003 .63571 .60111 .63751 .60069 .63661 .59956 Mtetra
.629 .718 .911 r
.63661 .59956 .63751 .60069 .63931 .6003 .63841 .59913 Mtetra
.617 .706 .908 r
.63841 .59913 .63931 .6003 .64111 .59995 .64021 .59875 Mtetra
.606 .697 .908 r
.64021 .59875 .64111 .59995 .64291 .59964 .64202 .59843 Mtetra
.542 .665 .917 r
.64202 .59843 .64291 .59964 .64473 .59975 .64384 .59834 Mtetra
.567 .643 .885 r
.64384 .59834 .64473 .59975 .64655 .59971 .64565 .59821 Mtetra
.621 .653 .86 r
.64565 .59821 .64655 .59971 .64835 .59918 .64746 .59783 Mtetra
.701 .708 .853 r
.64746 .59783 .64835 .59918 .6501 .597 .64925 .597 Mtetra
.792 .992 .879 r
.64925 .597 .6501 .597 .65175 .59235 .65102 .59555 Mtetra
.138 0 .221 r
.65102 .59555 .65175 .59235 .6462 .3967 .65275 .593 Mtetra
.534 .321 .538 r
.65275 .593 .6462 .3967 .6476 .38839 .65412 .58095 Mtetra
0 0 .407 r
.65412 .58095 .6476 .38839 .6492 .38529 .64846 .38665 Mtetra
.827 .863 .414 r
.64846 .38665 .6492 .38529 .65084 .38337 .65002 .38268 Mtetra
.828 .849 .863 r
.65002 .38268 .65084 .38337 .65251 .38237 .65168 .38125 Mtetra
.664 .72 .891 r
.65168 .38125 .65251 .38237 .65421 .38184 .65338 .38069 Mtetra
.583 .683 .91 r
.65338 .38069 .65421 .38184 .65592 .38151 .65509 .38047 Mtetra
.604 .715 .922 r
.65509 .38047 .65592 .38151 .65763 .38118 .6568 .38015 Mtetra
.623 .727 .921 r
.6568 .38015 .65763 .38118 .65933 .38081 .65851 .37977 Mtetra
.63 .724 .915 r
.65851 .37977 .65933 .38081 .66104 .3804 .66021 .37935 Mtetra
.664 .736 .903 r
.66021 .37935 .66104 .3804 .66274 .37979 .66192 .37879 Mtetra
.683 .755 .906 r
.66192 .37879 .66274 .37979 .66443 .37905 .66362 .37815 Mtetra
.688 .776 .918 r
.66362 .37815 .66443 .37905 .66613 .37831 .66532 .37748 Mtetra
.693 .797 .929 r
.66532 .37748 .66613 .37831 .66782 .37748 .66701 .3768 Mtetra
.673 .827 .958 r
.66701 .3768 .66782 .37748 .66952 .37678 .66872 .37617 Mtetra
.613 .83 .983 r
.66872 .37617 .66952 .37678 .67123 .37643 .67043 .37571 Mtetra
.41 .707 .984 r
.67043 .37571 .67123 .37643 .67301 .37738 .67217 .37577 Mtetra
.42 .518 .853 r
.67217 .37577 .67301 .37738 .67489 .38039 .67392 .37627 Mtetra
.5 .406 .68 r
.67392 .37627 .67489 .38039 .68551 .56781 .6757 .37699 Mtetra
.554 .341 .546 r
.6757 .37699 .68551 .56781 .68789 .57904 .67744 .3771 Mtetra
.556 .342 .546 r
.67744 .3771 .68789 .57904 .68973 .57882 .67916 .37654 Mtetra
.67916 .37654 .68973 .57882 .69149 .57701 .68086 .37576 Mtetra
.556 .343 .546 r
.68086 .37576 .69149 .57701 .69322 .57453 .68255 .37467 Mtetra
.68255 .37467 .69322 .57453 .69498 .57271 .68425 .37377 Mtetra
.555 .342 .546 r
.68425 .37377 .69498 .57271 .69688 .57367 .68599 .37365 Mtetra
.547 .336 .545 r
.68599 .37365 .69688 .57367 .69898 .57844 .68795 .37776 Mtetra
.035 0 .432 r
.68795 .37776 .69898 .57844 .70101 .58169 .69997 .57713 Mtetra
.006 .067 .577 r
.69997 .57713 .70101 .58169 .70297 .58343 .70208 .58186 Mtetra
.236 .43 .849 r
.70208 .58186 .70297 .58343 .70486 .58387 .704 .5829 Mtetra
.581 .737 .95 r
.704 .5829 .70486 .58387 .70671 .58359 .70585 .58261 Mtetra
.682 .773 .92 r
.70585 .58261 .70671 .58359 .70855 .58307 .70769 .58192 Mtetra
.671 .735 .898 r
.70769 .58192 .70855 .58307 .71039 .58254 .70952 .58128 Mtetra
.649 .707 .889 r
.70952 .58128 .71039 .58254 .71224 .58202 .71137 .58074 Mtetra
.655 .707 .886 r
.71137 .58074 .71224 .58202 .71408 .58147 .71321 .58018 Mtetra
.653 .705 .885 r
.71321 .58018 .71408 .58147 .71593 .58092 .71506 .57963 Mtetra
.653 .703 .883 r
.71506 .57963 .71593 .58092 .71778 .58038 .71691 .57907 Mtetra
.657 .702 .88 r
.71691 .57907 .71778 .58038 .71962 .57981 .71875 .57849 Mtetra
.669 .706 .875 r
.71875 .57849 .71962 .57981 .72147 .57916 .7206 .57785 Mtetra
.679 .711 .873 r
.7206 .57785 .72147 .57916 .72331 .57843 .72244 .57715 Mtetra
.68 .716 .876 r
.72244 .57715 .72331 .57843 .72515 .5777 .72428 .57644 Mtetra
.671 .717 .883 r
.72428 .57644 .72515 .5777 .72699 .57704 .72613 .5758 Mtetra
.659 .714 .889 r
.72613 .5758 .72699 .57704 .72884 .57647 .72798 .57521 Mtetra
.654 .71 .889 r
.72798 .57521 .72884 .57647 .7307 .57592 .72984 .57465 Mtetra
.652 .707 .887 r
.72984 .57465 .7307 .57592 .73256 .57539 .73169 .57409 Mtetra
.651 .703 .885 r
.73169 .57409 .73256 .57539 .73441 .57486 .73355 .57354 Mtetra
.65 .7 .883 r
.73355 .57354 .73441 .57486 .73627 .57433 .73541 .573 Mtetra
.634 .691 .886 r
.73541 .573 .73627 .57433 .73815 .57396 .73728 .57254 Mtetra
.628 .674 .874 r
.73728 .57254 .73815 .57396 .74002 .57363 .73914 .57211 Mtetra
.653 .669 .853 r
.73914 .57211 .74002 .57363 .74188 .57297 .74101 .57154 Mtetra
.726 .711 .836 r
.74101 .57154 .74188 .57297 .74366 .57115 .74284 .57048 Mtetra
.842 .878 .867 r
.74284 .57048 .74366 .57115 .7453 .56718 .74463 .56886 Mtetra
0 0 0 r
.74463 .56886 .7453 .56718 .74651 .55675 .74641 .56701 Mtetra
.511 .264 .477 r
.74641 .56701 .74651 .55675 .73576 .36559 .74825 .56598 Mtetra
.554 .337 .54 r
.74825 .56598 .73576 .36559 .73755 .36545 .75015 .56595 Mtetra
.553 .336 .54 r
.75015 .56595 .73755 .36545 .7394 .36642 .75202 .56544 Mtetra
.549 .333 .539 r
.75202 .56544 .7394 .36642 .74092 .36235 .75371 .56218 Mtetra
.06 0 .44 r
.75371 .56218 .74092 .36235 .74239 .35759 .74203 .36282 Mtetra
0 0 .159 r
.74203 .36282 .74239 .35759 .74398 .35472 .74325 .35447 Mtetra
.943 .925 .759 r
.74325 .35447 .74398 .35472 .74566 .35313 .74487 .35193 Mtetra
.702 .728 .87 r
.74487 .35193 .74566 .35313 .74741 .35244 .7466 .35114 Mtetra
.617 .675 .883 r
.7466 .35114 .74741 .35244 .74917 .35199 .74837 .35079 Mtetra
.668 .714 .883 r
.74837 .35079 .74917 .35199 .75092 .35128 .75013 .35019 Mtetra
.739 .761 .87 r
.75013 .35019 .75092 .35128 .75264 .35029 .75186 .34921 Mtetra
.641 .728 .911 r
.75186 .34921 .75264 .35029 .75441 .3498 .75362 .34873 Mtetra
0 .308 .799 r
.75362 .34873 .75441 .3498 .7563 .3511 .75552 .35004 Mtetra
.951 .603 .229 r
.75552 .35004 .7563 .3511 .75909 .36448 .7583 .36344 Mtetra
.975 .673 .363 r
.7583 .36344 .75909 .36448 .77538 .56009 .77456 .55909 Mtetra
.546 .078 0 r
.77456 .55909 .77538 .56009 .7775 .56265 .77668 .56165 Mtetra
.451 .673 .958 r
.77668 .56165 .7775 .56265 .77944 .56275 .77861 .56175 Mtetra
.727 .791 .903 r
.77861 .56175 .77944 .56275 .7813 .56181 .78047 .56081 Mtetra
.9 .812 .752 r
.78047 .56081 .7813 .56181 .78302 .55906 .7822 .55806 Mtetra
.978 .746 .519 r
.7822 .55806 .78302 .55906 .78415 .54862 .78333 .54762 Mtetra
.977 .681 .376 r
.78333 .54762 .78415 .54862 .7705 .34759 .76972 .34653 Mtetra
.924 .788 .692 r
.76972 .34653 .7705 .34759 .77204 .34409 .77127 .34303 Mtetra
.721 .763 .885 r
.77127 .34303 .77204 .34409 .77379 .34322 .77301 .34215 Mtetra
.595 .713 .926 r
.77301 .34215 .77379 .34322 .77558 .34292 .77481 .34186 Mtetra
.622 .725 .92 r
.77481 .34186 .77558 .34292 .77737 .34252 .77659 .34145 Mtetra
.737 .769 .879 r
.77659 .34145 .77737 .34252 .77911 .34155 .77833 .34049 Mtetra
.644 .736 .915 r
.77833 .34049 .77911 .34155 .78089 .34105 .78011 .34 Mtetra
.078 .411 .862 r
.78011 .34 .78089 .34105 .78279 .34207 .78202 .34102 Mtetra
.925 .553 .14 r
.78202 .34102 .78279 .34207 .78538 .35135 .78462 .35042 Mtetra
.975 .67 .35 r
.78462 .35042 .78538 .35135 .80374 .55141 .80293 .55043 Mtetra
.607 .142 0 r
.80293 .55043 .80374 .55141 .80594 .55436 .80513 .55336 Mtetra
.426 .66 .958 r
.80513 .55336 .80594 .55436 .8079 .55453 .80709 .55352 Mtetra
.719 .791 .909 r
.80709 .55352 .8079 .55453 .80978 .55363 .80897 .55263 Mtetra
.894 .817 .765 r
.80897 .55263 .80978 .55363 .81152 .55105 .81071 .55004 Mtetra
.98 .751 .519 r
.81071 .55004 .81152 .55105 .81263 .5412 .81183 .54021 Mtetra
.977 .678 .362 r
.81183 .54021 .81263 .5412 .79717 .33897 .7964 .33789 Mtetra
.937 .787 .67 r
.7964 .33789 .79717 .33897 .79867 .33506 .7979 .33398 Mtetra
.78 .78 .853 r
.7979 .33398 .79867 .33506 .80039 .3338 .79963 .33271 Mtetra
.595 .71 .924 r
.79963 .33271 .80039 .3338 .8022 .33351 .80144 .33242 Mtetra
.011 .353 .828 r
.80144 .33242 .8022 .33351 .80416 .33486 .80339 .33365 Mtetra
.914 .542 .107 r
.80339 .33365 .80416 .33486 .80721 .34846 .80607 .34313 Mtetra
.975 .67 .321 r
.80607 .34313 .80721 .34846 .82675 .54574 .82589 .54414 Mtetra
0 .056 .621 r
.82589 .54414 .82675 .54574 .8289 .54781 .82811 .54689 Mtetra
.665 .793 .943 r
.82811 .54689 .8289 .54781 .83067 .54557 .83002 .54624 Mtetra
.525 .825 .496 r
.83002 .54624 .83067 .54557 .83215 .54014 .83182 .54433 Mtetra
.11 0 .291 r
.83182 .54433 .83215 .54014 .8156 .33875 .83343 .5403 Mtetra
.102 .016 .462 r
.83343 .5403 .8156 .33875 .8169 .33283 .81701 .34113 Mtetra
0 0 .323 r
.81701 .34113 .8169 .33283 .8185 .33005 .81787 .33038 Mtetra
.934 .944 .604 r
.81787 .33038 .8185 .33005 .82018 .32827 .81943 .32715 Mtetra
.789 .779 .844 r
.81943 .32715 .82018 .32827 .82192 .32705 .82115 .32581 Mtetra
.647 .703 .887 r
.82115 .32581 .82192 .32705 .82373 .32649 .82296 .3253 Mtetra
.29 .519 .902 r
.82296 .3253 .82373 .32649 .82564 .32707 .82488 .32598 Mtetra
.794 .376 0 r
.82488 .32598 .82564 .32707 .82798 .33212 .82723 .33102 Mtetra
.974 .665 .325 r
.82723 .33102 .82798 .33212 .84954 .5358 .84874 .53475 Mtetra
.732 .293 0 r
.84874 .53475 .84954 .5358 .85194 .54007 .85115 .53902 Mtetra
.521 .702 .952 r
.85115 .53902 .85194 .54007 .85392 .53998 .85313 .53893 Mtetra
.711 .782 .907 r
.85313 .53893 .85392 .53998 .85583 .53913 .85504 .53806 Mtetra
.759 .794 .881 r
.85504 .53806 .85583 .53913 .85771 .538 .85692 .5369 Mtetra
.657 .752 .92 r
.85692 .5369 .85771 .538 .85965 .53743 .85885 .5363 Mtetra
.646 .742 .919 r
.85885 .5363 .85965 .53743 .86159 .53691 .8608 .53575 Mtetra
.621 .724 .92 r
.8608 .53575 .86159 .53691 .86356 .53654 .86275 .53531 Mtetra
.557 .68 .921 r
.86275 .53531 .86356 .53654 .86556 .53661 .86474 .53516 Mtetra
.593 .658 .883 r
.86474 .53516 .86556 .53661 .86754 .53637 .86671 .53488 Mtetra
.643 .677 .867 r
.86671 .53488 .86754 .53637 .86945 .53547 .86866 .53434 Mtetra
.734 .776 .887 r
.86866 .53434 .86945 .53547 .87116 .53256 .87057 .53333 Mtetra
0 0 0 r
.87057 .53333 .87116 .53256 .87255 .52662 .8724 .53168 Mtetra
.302 .063 .376 r
.8724 .53168 .87255 .52662 .85364 .32635 .87409 .5286 Mtetra
.13 .039 .474 r
.87409 .5286 .85364 .32635 .85494 .32069 .85558 .33279 Mtetra
.016 0 .388 r
.85558 .33279 .85494 .32069 .85653 .31797 .85598 .31859 Mtetra
.86 .903 .489 r
.85598 .31859 .85653 .31797 .85824 .31629 .8575 .31517 Mtetra
.729 .762 .88 r
.8575 .31517 .85824 .31629 .86005 .31554 .85929 .31423 Mtetra
.626 .684 .885 r
.85929 .31423 .86005 .31554 .86189 .31508 .86113 .31382 Mtetra
.572 .666 .901 r
.86113 .31382 .86189 .31508 .86374 .31474 .863 .31364 Mtetra
.662 .739 .907 r
.863 .31364 .86374 .31474 .86557 .31414 .86483 .31305 Mtetra
.669 .745 .907 r
.86483 .31305 .86557 .31414 .86739 .31349 .86666 .31242 Mtetra
.685 .756 .906 r
.86666 .31242 .86739 .31349 .8692 .31276 .86847 .31172 Mtetra
.78 .797 .867 r
.86847 .31172 .8692 .31276 .87095 .31146 .87023 .31048 Mtetra
.715 .789 .91 r
.87023 .31048 .87095 .31146 .87275 .31057 .87204 .30964 Mtetra
.497 .704 .962 r
.87204 .30964 .87275 .31057 .87464 .31047 .87393 .3096 Mtetra
.766 .328 0 r
.87393 .3096 .87464 .31047 .87702 .31476 .87634 .31412 Mtetra
.971 .656 .297 r
.87634 .31412 .87702 .31476 .90208 .51996 .90135 .51922 Mtetra
.811 .37 0 r
.90135 .51922 .90208 .51996 .90473 .52539 .90397 .52437 Mtetra
.274 .566 .935 r
.90397 .52437 .90473 .52539 .90683 .526 .90607 .52495 Mtetra
.644 .762 .934 r
.90607 .52495 .90683 .526 .90881 .52545 .90804 .52439 Mtetra
.827 .819 .842 r
.90804 .52439 .90881 .52545 .91065 .52376 .90989 .5227 Mtetra
.908 .736 .657 r
.27579 .7042 .27682 .70504 .27875 .69953 .27772 .69866 Mtetra
.936 .686 .535 r
.27772 .69866 .27875 .69953 .29385 .5043 .29288 .50338 Mtetra
.906 .726 .647 r
.29288 .50338 .29385 .5043 .2957 .49857 .29474 .49766 Mtetra
.772 .758 .84 r
.29474 .49766 .2957 .49857 .29723 .49745 .29627 .49654 Mtetra
.64 .735 .917 r
.29627 .49654 .29723 .49745 .29872 .49705 .29776 .49615 Mtetra
.512 .691 .949 r
.29776 .49615 .29872 .49705 .30018 .49701 .29922 .49611 Mtetra
.748 .757 .859 r
.29922 .49611 .30018 .49701 .3017 .49607 .30074 .49517 Mtetra
.696 .748 .892 r
.30074 .49517 .3017 .49607 .3032 .49544 .30224 .49454 Mtetra
.48 .678 .952 r
.30224 .49454 .3032 .49544 .30466 .49548 .3037 .49457 Mtetra
.928 .549 .255 r
.3037 .49457 .30466 .49548 .30585 .49955 .30489 .49863 Mtetra
.939 .683 .523 r
.30489 .49863 .30585 .49955 .29458 .69402 .29356 .69313 Mtetra
.936 .581 .321 r
.29356 .69313 .29458 .69402 .29579 .69926 .29477 .69839 Mtetra
0 .399 .837 r
.29477 .69839 .29579 .69926 .2973 .70005 .29628 .69913 Mtetra
.637 .743 .925 r
.29628 .69913 .2973 .70005 .29888 .69965 .29786 .69871 Mtetra
.796 .764 .824 r
.29786 .69871 .29888 .69965 .30053 .69817 .29951 .69729 Mtetra
.9 .744 .68 r
.29951 .69729 .30053 .69817 .30244 .69263 .30136 .69285 Mtetra
.94 .688 .529 r
.30136 .69285 .30244 .69263 .31632 .49659 .31513 .49947 Mtetra
.988 .863 .504 r
.31513 .49947 .31632 .49659 .31814 .49098 .3171 .49156 Mtetra
.812 .997 .775 r
.3171 .49156 .31814 .49098 .31969 .48981 .31867 .48989 Mtetra
.611 .948 .928 r
.31867 .48989 .31969 .48981 .32118 .48954 .32019 .48915 Mtetra
.557 .846 .998 r
.32019 .48915 .32118 .48954 .32264 .48967 .32169 .4888 Mtetra
.661 .75 .916 r
.32169 .4888 .32264 .48967 .32414 .48933 .32319 .48832 Mtetra
.654 .718 .896 r
.32319 .48832 .32414 .48933 .32564 .48887 .3247 .48787 Mtetra
.648 .718 .899 r
.3247 .48787 .32564 .48887 .32715 .48837 .3262 .48744 Mtetra
.747 .753 .857 r
.3262 .48744 .32715 .48837 .32868 .48741 .32773 .4865 Mtetra
.711 .751 .883 r
.32773 .4865 .32868 .48741 .3302 .48669 .32925 .48579 Mtetra
.533 .7 .946 r
.32925 .48579 .3302 .48669 .33169 .4866 .33074 .4857 Mtetra
.908 .5 .168 r
.33074 .4857 .33169 .4866 .33297 .48998 .33202 .48909 Mtetra
.942 .683 .517 r
.33202 .48909 .33297 .48998 .32327 .68454 .32226 .68368 Mtetra
.94 .595 .343 r
.32226 .68368 .32327 .68454 .3245 .69067 .32348 .6898 Mtetra
0 .239 .707 r
.32348 .6898 .3245 .69067 .32601 .69172 .325 .69081 Mtetra
.61 .737 .936 r
.325 .69081 .32601 .69172 .32761 .69142 .3266 .69048 Mtetra
.786 .766 .835 r
.3266 .69048 .32761 .69142 .32926 .69006 .32825 .68916 Mtetra
.896 .75 .692 r
.32825 .68916 .32926 .69006 .33111 .68521 .33006 .68519 Mtetra
.943 .689 .523 r
.33006 .68519 .33111 .68521 .34345 .48889 .34221 .49321 Mtetra
.96 .838 .414 r
.34221 .49321 .34345 .48889 .34529 .48242 .34426 .48308 Mtetra
.86 .993 .747 r
.34426 .48308 .34529 .48242 .34686 .48097 .34586 .48109 Mtetra
.611 .953 .91 r
.34586 .48109 .34686 .48097 .34837 .48064 .3474 .4803 Mtetra
.549 .856 .997 r
.3474 .4803 .34837 .48064 .34986 .48076 .34891 .47993 Mtetra
.646 .759 .931 r
.34891 .47993 .34986 .48076 .35136 .4805 .35043 .4795 Mtetra
.648 .72 .9 r
.35043 .4795 .35136 .4805 .35288 .48006 .35194 .47906 Mtetra
.64 .718 .904 r
.35194 .47906 .35288 .48006 .3544 .47958 .35346 .47866 Mtetra
.731 .755 .871 r
.35346 .47866 .3544 .47958 .35595 .47867 .355 .47782 Mtetra
.715 .769 .895 r
.355 .47782 .35595 .47867 .35748 .47791 .35654 .4771 Mtetra
.559 .735 .958 r
.35654 .4771 .35748 .47791 .35899 .47776 .35805 .47691 Mtetra
.832 .367 0 r
.35805 .47691 .35899 .47776 .36033 .4809 .35943 .47933 Mtetra
.946 .685 .509 r
.35943 .47933 .36033 .4809 .3522 .67618 .35146 .66999 Mtetra
.744 .536 0 r
.35146 .66999 .3522 .67618 .35348 .68247 .35257 .67989 Mtetra
.259 .321 .737 r
.35257 .67989 .35348 .68247 .35504 .68327 .3541 .68127 Mtetra
.571 .556 .799 r
.3541 .68127 .35504 .68327 .35667 .6827 .3557 .68119 Mtetra
.658 .652 .833 r
.3557 .68119 .35667 .6827 .35832 .68166 .35733 .68065 Mtetra
.564 .702 .934 r
.35733 .68065 .35832 .68166 .35993 .68142 .35894 .68047 Mtetra
.593 .728 .938 r
.35894 .68047 .35993 .68142 .36154 .68128 .36055 .6802 Mtetra
.726 .737 .86 r
.36055 .6802 .36154 .68128 .36318 .68052 .3622 .67931 Mtetra
.873 .731 .702 r
.3622 .67931 .36318 .68052 .36496 .67663 .36397 .67578 Mtetra
.946 .689 .516 r
.36397 .67578 .36496 .67663 .37544 .48062 .37425 .48526 Mtetra
.979 .825 .42 r
.37425 .48526 .37544 .48062 .37733 .47227 .37633 .47282 Mtetra
.884 .991 .762 r
.37633 .47282 .37733 .47227 .37893 .47032 .37793 .47077 Mtetra
0 0 0 r
.37793 .47077 .37893 .47032 .38047 .46977 .37947 .47027 Mtetra
.255 0 0 r
.37947 .47027 .38047 .46977 .38198 .4697 .38099 .4702 Mtetra
0 0 0 r
.38099 .4702 .38198 .4697 .38351 .46951 .38253 .46964 Mtetra
.642 .964 .902 r
.38253 .46964 .38351 .46951 .38504 .4692 .38409 .46876 Mtetra
.742 .877 .942 r
.38409 .46876 .38504 .4692 .38657 .46888 .38564 .46793 Mtetra
.684 .742 .895 r
.38564 .46793 .38657 .46888 .38811 .46848 .38719 .46733 Mtetra
.646 .692 .878 r
.38719 .46733 .38811 .46848 .38965 .46801 .38873 .4669 Mtetra
.637 .696 .888 r
.38873 .4669 .38965 .46801 .39119 .46748 .39027 .46651 Mtetra
.654 .73 .905 r
.39027 .46651 .39119 .46748 .39275 .46678 .39181 .46604 Mtetra
.67 .787 .937 r
.39181 .46604 .39275 .46678 .3943 .46605 .39336 .4655 Mtetra
.669 .837 .964 r
.39336 .4655 .3943 .46605 .39585 .46547 .39491 .46494 Mtetra
.677 .844 .963 r
.39491 .46494 .39585 .46547 .39738 .46541 .39646 .46434 Mtetra
.683 .719 .876 r
.39646 .46434 .39738 .46541 .39889 .46585 .39801 .46374 Mtetra
.65 .579 .762 r
.39801 .46374 .39889 .46585 .40039 .4665 .39956 .46314 Mtetra
.642 .514 .691 r
.39956 .46314 .40039 .4665 .40193 .46621 .40112 .4623 Mtetra
.629 .491 .674 r
.40112 .4623 .40193 .46621 .4035 .46532 .40268 .46151 Mtetra
.594 .47 .681 r
.40268 .46151 .4035 .46532 .40505 .46495 .40423 .4612 Mtetra
.355 .312 .672 r
.40423 .4612 .40505 .46495 .40647 .46802 .4057 .46277 Mtetra
.77 .54 0 r
.4057 .46277 .40647 .46802 .40111 .66222 .40691 .47193 Mtetra
0 0 .304 r
.40691 .47193 .40111 .66222 .40255 .66761 .40165 .66441 Mtetra
.199 .24 .68 r
.40165 .66441 .40255 .66761 .40414 .66877 .40321 .66642 Mtetra
.609 .55 .763 r
.40321 .66642 .40414 .66877 .40579 .66844 .40486 .66609 Mtetra
.67 .583 .749 r
.40486 .66609 .40579 .66844 .40745 .66767 .40652 .66523 Mtetra
.621 .551 .754 r
.40652 .66523 .40745 .66767 .40911 .66706 .40818 .66479 Mtetra
.552 .525 .779 r
.40818 .66479 .40911 .66706 .41076 .66665 .40981 .66485 Mtetra
.555 .572 .826 r
.40981 .66485 .41076 .66665 .41242 .66607 .41145 .66484 Mtetra
.527 .644 .907 r
.41145 .66484 .41242 .66607 .41409 .66524 .4131 .66483 Mtetra
.446 .809 .995 r
.4131 .66483 .41409 .66524 .41577 .66396 .41475 .66462 Mtetra
0 0 0 r
.41475 .66462 .41577 .66396 .41748 .66184 .41641 .66383 Mtetra
.41641 .66383 .41748 .66184 .41931 .65562 .41815 .661 Mtetra
.939 .805 .348 r
.41815 .661 .41931 .65562 .42679 .46034 .42019 .64794 Mtetra
0 0 .301 r
.42019 .64794 .42679 .46034 .42849 .45547 .42751 .45672 Mtetra
.821 .928 .549 r
.42751 .45672 .42849 .45547 .43009 .45356 .42914 .45388 Mtetra
.41 .852 .754 r
.42914 .45388 .43009 .45356 .43166 .4529 .43072 .45313 Mtetra
0 0 0 r
.43072 .45313 .43166 .4529 .43322 .45258 .43227 .4529 Mtetra
.004 0 0 r
.43227 .4529 .43322 .45258 .43479 .45219 .43384 .45263 Mtetra
0 0 0 r
.43384 .45263 .43479 .45219 .43636 .45157 .43541 .4521 Mtetra
.43541 .4521 .43636 .45157 .43793 .45096 .43698 .45158 Mtetra
.43698 .45158 .43793 .45096 .4395 .45038 .43855 .45104 Mtetra
.02 0 0 r
.43855 .45104 .4395 .45038 .44107 .44983 .44012 .4505 Mtetra
.018 0 0 r
.44012 .4505 .44107 .44983 .44265 .44929 .4417 .44995 Mtetra
.003 0 0 r
.4417 .44995 .44265 .44929 .44422 .44871 .44327 .44939 Mtetra
.015 0 0 r
.44327 .44939 .44422 .44871 .4458 .44809 .44485 .44882 Mtetra
.043 0 0 r
.44485 .44882 .4458 .44809 .44737 .44758 .44643 .44825 Mtetra
0 0 0 r
.44643 .44825 .44737 .44758 .44894 .44724 .44801 .44747 Mtetra
.576 .942 .847 r
.44801 .44747 .44894 .44724 .45051 .44719 .4496 .44657 Mtetra
.632 .815 .97 r
.4496 .44657 .45051 .44719 .45207 .44761 .45117 .44612 Mtetra
.128 .358 .819 r
.45117 .44612 .45207 .44761 .45359 .44955 .45272 .44718 Mtetra
.926 .588 .137 r
.45272 .44718 .45359 .44955 .45483 .46532 .45414 .45397 Mtetra
.969 .7 .467 r
.45414 .45397 .45483 .46532 .45254 .65072 .45159 .64914 Mtetra
.659 .247 0 r
.45159 .64914 .45254 .65072 .45417 .65293 .45321 .65201 Mtetra
.517 .711 .96 r
.45321 .65201 .45417 .65293 .45584 .65278 .45488 .65193 Mtetra
.7 .784 .917 r
.45488 .65193 .45584 .65278 .45753 .65207 .45657 .65121 Mtetra
.706 .786 .914 r
.45657 .65121 .45753 .65207 .45922 .65131 .45826 .65047 Mtetra
.614 .765 .952 r
.45826 .65047 .45922 .65131 .4609 .65086 .45994 .65008 Mtetra
.61 .78 .962 r
.45994 .65008 .4609 .65086 .46259 .65041 .46163 .6497 Mtetra
.604 .794 .972 r
.46163 .6497 .46259 .65041 .46428 .64998 .46331 .64931 Mtetra
.6 .803 .977 r
.46331 .64931 .46428 .64998 .46596 .64958 .465 .64892 Mtetra
.598 .806 .979 r
.465 .64892 .46596 .64958 .46765 .64918 .46669 .64852 Mtetra
.587 .803 .982 r
.46669 .64852 .46765 .64918 .46934 .64879 .46838 .64816 Mtetra
.568 .804 .988 r
.46838 .64816 .46934 .64879 .47103 .64839 .47007 .64783 Mtetra
.583 .827 .991 r
.47007 .64783 .47103 .64839 .47272 .64804 .47176 .64744 Mtetra
.656 .837 .969 r
.47176 .64744 .47272 .64804 .47441 .64779 .47345 .64686 Mtetra
.724 .775 .893 r
.47345 .64686 .47441 .64779 .4761 .64766 .47515 .64601 Mtetra
.699 .657 .805 r
.47515 .64601 .4761 .64766 .47779 .64752 .47686 .64511 Mtetra
.656 .574 .751 r
.47686 .64511 .47779 .64752 .47948 .64729 .47856 .64436 Mtetra
.612 .522 .728 r
.47856 .64436 .47948 .64729 .48118 .64692 .48025 .64395 Mtetra
.603 .514 .726 r
.48025 .64395 .48118 .64692 .48288 .64651 .48195 .64361 Mtetra
.585 .507 .733 r
.48195 .64361 .48288 .64651 .48458 .64618 .48365 .64343 Mtetra
.564 .503 .745 r
.48365 .64343 .48458 .64618 .48628 .64602 .48534 .64343 Mtetra
.629 .549 .746 r
.48534 .64343 .48628 .64602 .48798 .64551 .48705 .6429 Mtetra
.749 .612 .706 r
.48705 .6429 .48798 .64551 .48969 .64401 .48877 .64082 Mtetra
.886 .662 .593 r
.48877 .64082 .48969 .64401 .49143 .63979 .49057 .63068 Mtetra
.948 .679 .494 r
.49057 .63068 .49143 .63979 .49485 .4522 .49411 .43544 Mtetra
.624 .416 .58 r
.49411 .43544 .49485 .4522 .4966 .43691 .49574 .43187 Mtetra
.62 .464 .649 r
.49574 .43187 .4966 .43691 .49821 .4357 .49735 .43098 Mtetra
.588 .448 .658 r
.49735 .43098 .49821 .4357 .49981 .43555 .49895 .43064 Mtetra
.577 .437 .654 r
.49895 .43064 .49981 .43555 .50142 .43573 .50056 .43046 Mtetra
.595 .444 .646 r
.50056 .43046 .50142 .43573 .50303 .43528 .50217 .42997 Mtetra
.594 .443 .646 r
.50217 .42997 .50303 .43528 .50464 .43485 .50378 .42949 Mtetra
.594 .442 .645 r
.50378 .42949 .50464 .43485 .50625 .43442 .50539 .429 Mtetra
.595 .442 .644 r
.50539 .429 .50625 .43442 .50786 .43394 .507 .4285 Mtetra
.595 .441 .643 r
.507 .4285 .50786 .43394 .50947 .43346 .50861 .42799 Mtetra
.50861 .42799 .50947 .43346 .51109 .43296 .51022 .42747 Mtetra
.51022 .42747 .51109 .43296 .5127 .43247 .51184 .42696 Mtetra
.595 .441 .642 r
.51184 .42696 .5127 .43247 .51432 .43197 .51345 .42645 Mtetra
.595 .44 .642 r
.51345 .42645 .51432 .43197 .51594 .43147 .51507 .42593 Mtetra
.51507 .42593 .51594 .43147 .51756 .43097 .51669 .42542 Mtetra
.594 .44 .642 r
.51669 .42542 .51756 .43097 .51918 .43049 .5183 .4249 Mtetra
.594 .439 .641 r
.5183 .4249 .51918 .43049 .5208 .43001 .51992 .42439 Mtetra
.593 .438 .641 r
.51992 .42439 .5208 .43001 .52242 .42955 .52154 .42389 Mtetra
.593 .437 .64 r
.52154 .42389 .52242 .42955 .52404 .4291 .52316 .42339 Mtetra
.592 .436 .639 r
.52316 .42339 .52404 .4291 .52567 .42874 .52479 .42291 Mtetra
.59 .434 .637 r
.52479 .42291 .52567 .42874 .52729 .42869 .52641 .42244 Mtetra
.588 .427 .631 r
.52641 .42244 .52729 .42869 .52892 .42834 .52803 .42198 Mtetra
.588 .426 .63 r
.52803 .42198 .52892 .42834 .53054 .42716 .52966 .42151 Mtetra
.593 .437 .64 r
.52966 .42151 .53054 .42716 .53217 .42473 .53128 .42102 Mtetra
.61 .485 .686 r
.53128 .42102 .53217 .42473 .53379 .42271 .53291 .42051 Mtetra
.636 .569 .763 r
.53291 .42051 .53379 .42271 .53541 .42123 .53454 .41999 Mtetra
.662 .691 .867 r
.53454 .41999 .53541 .42123 .53704 .42054 .53617 .41945 Mtetra
.666 .719 .889 r
.53617 .41945 .53704 .42054 .53867 .42006 .5378 .4189 Mtetra
.663 .706 .879 r
.5378 .4189 .53867 .42006 .5403 .41967 .53943 .41836 Mtetra
.656 .677 .858 r
.53943 .41836 .5403 .41967 .54193 .41917 .54106 .41784 Mtetra
.654 .673 .856 r
.54106 .41784 .54193 .41917 .54357 .41868 .54269 .41734 Mtetra
.652 .671 .856 r
.54269 .41734 .54357 .41868 .5452 .41817 .54433 .41684 Mtetra
.647 .671 .859 r
.54433 .41684 .5452 .41817 .54683 .41764 .54596 .41637 Mtetra
.649 .682 .868 r
.54596 .41637 .54683 .41764 .54847 .41708 .5476 .41589 Mtetra
.656 .697 .876 r
.5476 .41589 .54847 .41708 .5501 .41651 .54923 .41538 Mtetra
.672 .716 .882 r
.54923 .41538 .5501 .41651 .55174 .41578 .55087 .4148 Mtetra
.68 .748 .903 r
.55087 .4148 .55174 .41578 .55338 .41516 .55251 .41419 Mtetra
.684 .751 .902 r
.55251 .41419 .55338 .41516 .55502 .4148 .55415 .41356 Mtetra
.677 .699 .863 r
.55415 .41356 .55502 .4148 .55667 .4153 .55579 .41294 Mtetra
.645 .564 .749 r
.55579 .41294 .55667 .4153 .55832 .4162 .55743 .41231 Mtetra
.618 .486 .679 r
.55743 .41231 .55832 .4162 .55998 .41724 .55907 .41167 Mtetra
.602 .445 .642 r
.55907 .41167 .55998 .41724 .56163 .41658 .56071 .41101 Mtetra
.56071 .41101 .56163 .41658 .56326 .41545 .56235 .41036 Mtetra
.605 .454 .65 r
.56235 .41036 .56326 .41545 .5649 .41423 .564 .40972 Mtetra
.608 .466 .663 r
.564 .40972 .5649 .41423 .56655 .4135 .56564 .40911 Mtetra
.609 .469 .666 r
.56564 .40911 .56655 .4135 .56819 .41283 .56729 .40851 Mtetra
.609 .47 .667 r
.56729 .40851 .56819 .41283 .56984 .41221 .56893 .40792 Mtetra
.609 .471 .668 r
.56893 .40792 .56984 .41221 .57149 .41158 .57058 .40734 Mtetra
.609 .472 .67 r
.57058 .40734 .57149 .41158 .57314 .41096 .57223 .40676 Mtetra
.609 .473 .671 r
.57223 .40676 .57314 .41096 .57479 .41034 .57388 .40618 Mtetra
.609 .474 .672 r
.57388 .40618 .57479 .41034 .57644 .40972 .57553 .40561 Mtetra
.61 .476 .673 r
.57553 .40561 .57644 .40972 .57809 .40911 .57718 .40504 Mtetra
.61 .477 .675 r
.57718 .40504 .57809 .40911 .57975 .40849 .57884 .40447 Mtetra
.611 .479 .676 r
.57884 .40447 .57975 .40849 .5814 .40787 .58049 .40388 Mtetra
.612 .48 .677 r
.58049 .40388 .5814 .40787 .58306 .40725 .58215 .40331 Mtetra
.611 .481 .679 r
.58215 .40331 .58306 .40725 .58471 .40665 .5838 .40274 Mtetra
.637 .498 .676 r
.5838 .40274 .58471 .40665 .58636 .40549 .58545 .40181 Mtetra
.62 .494 .686 r
.58545 .40181 .58636 .40549 .58801 .40478 .58711 .40117 Mtetra
.571 .465 .694 r
.58711 .40117 .58801 .40478 .58969 .40493 .58878 .4011 Mtetra
.128 .162 .628 r
.58878 .4011 .58969 .40493 .59151 .41242 .59051 .40416 Mtetra
.976 .693 .421 r
.59051 .40416 .59151 .41242 .59733 .60836 .59629 .60104 Mtetra
0 0 .454 r
.59629 .60104 .59733 .60836 .59919 .61199 .59825 .60932 Mtetra
.481 .461 .759 r
.59825 .60932 .59919 .61199 .60098 .61219 .60004 .60987 Mtetra
.636 .574 .768 r
.60004 .60987 .60098 .61219 .60275 .61164 .60182 .60931 Mtetra
.688 .6 .752 r
.60182 .60931 .60275 .61164 .60452 .61077 .60358 .60825 Mtetra
.636 .561 .753 r
.60358 .60825 .60452 .61077 .6063 .61029 .60536 .60766 Mtetra
.63 .55 .746 r
.60536 .60766 .6063 .61029 .60808 .60985 .60713 .6071 Mtetra
.629 .543 .739 r
.60713 .6071 .60808 .60985 .60986 .60939 .60891 .60652 Mtetra
.635 .541 .731 r
.60891 .60652 .60986 .60939 .61164 .60887 .61069 .60586 Mtetra
.629 .531 .724 r
.61069 .60586 .61164 .60887 .61342 .60831 .61246 .60524 Mtetra
.618 .522 .723 r
.61246 .60524 .61342 .60831 .6152 .6077 .61425 .60473 Mtetra
.576 .501 .734 r
.61425 .60473 .6152 .6077 .61698 .60701 .61604 .60462 Mtetra
.566 .531 .775 r
.61604 .60462 .61698 .60701 .61875 .60627 .61784 .60458 Mtetra
.574 .603 .844 r
.61784 .60458 .61875 .60627 .62053 .6055 .61964 .60446 Mtetra
.643 .74 .919 r
.61964 .60446 .62053 .6055 .62231 .60473 .62142 .60396 Mtetra
.678 .816 .95 r
.62142 .60396 .62231 .60473 .62409 .60394 .62321 .6033 Mtetra
.695 .85 .957 r
.62321 .6033 .62409 .60394 .62587 .60318 .62499 .60255 Mtetra
.693 .854 .96 r
.62499 .60255 .62587 .60318 .62766 .60246 .62677 .6018 Mtetra
.694 .848 .957 r
.62677 .6018 .62766 .60246 .62944 .60178 .62856 .60106 Mtetra
.692 .831 .949 r
.62856 .60106 .62944 .60178 .63123 .60115 .63035 .60033 Mtetra
.676 .803 .943 r
.63035 .60033 .63123 .60115 .63302 .60056 .63214 .59967 Mtetra
.663 .782 .937 r
.63214 .59967 .63302 .60056 .63482 .60003 .63393 .59908 Mtetra
.651 .764 .932 r
.63393 .59908 .63482 .60003 .63661 .59956 .63572 .59854 Mtetra
.637 .747 .928 r
.63572 .59854 .63661 .59956 .63841 .59913 .63752 .59807 Mtetra
.625 .733 .924 r
.63752 .59807 .63841 .59913 .64021 .59875 .63932 .59765 Mtetra
.616 .72 .92 r
.63932 .59765 .64021 .59875 .64202 .59843 .64113 .59727 Mtetra
.604 .704 .914 r
.64113 .59727 .64202 .59843 .64384 .59834 .64294 .59694 Mtetra
.606 .661 .877 r
.64294 .59694 .64384 .59834 .64565 .59821 .64474 .59663 Mtetra
.61 .636 .852 r
.64474 .59663 .64565 .59821 .64746 .59783 .64655 .5963 Mtetra
.528 .604 .873 r
.64655 .5963 .64746 .59783 .64925 .597 .64838 .59635 Mtetra
.491 .78 .996 r
.64838 .59635 .64925 .597 .65102 .59555 .6502 .59617 Mtetra
0 0 0 r
.6502 .59617 .65102 .59555 .65275 .593 .65199 .5953 Mtetra
.65199 .5953 .65275 .593 .65412 .58095 .65366 .59118 Mtetra
.982 .7 .405 r
.65366 .59118 .65412 .58095 .64846 .38665 .64787 .392 Mtetra
0 0 .078 r
.64787 .392 .64846 .38665 .65002 .38268 .64926 .38331 Mtetra
.675 .922 .611 r
.64926 .38331 .65002 .38268 .65168 .38125 .6509 .38145 Mtetra
.24 .747 .708 r
.6509 .38145 .65168 .38125 .65338 .38069 .6526 .38092 Mtetra
.064 0 0 r
.6526 .38092 .65338 .38069 .65509 .38047 .65432 .38077 Mtetra
.263 .751 .659 r
.65432 .38077 .65509 .38047 .6568 .38015 .65601 .3801 Mtetra
.659 .965 .921 r
.65601 .3801 .6568 .38015 .65851 .37977 .6577 .37917 Mtetra
.739 .866 .939 r
.6577 .37917 .65851 .37977 .66021 .37935 .65939 .37827 Mtetra
.688 .739 .89 r
.65939 .37827 .66021 .37935 .66192 .37879 .66109 .3776 Mtetra
.659 .706 .882 r
.66109 .3776 .66192 .37879 .66362 .37815 .66279 .37706 Mtetra
.648 .723 .903 r
.66279 .37706 .66362 .37815 .66532 .37748 .6645 .37657 Mtetra
.646 .761 .933 r
.6645 .37657 .66532 .37748 .66701 .3768 .66621 .37608 Mtetra
.639 .809 .965 r
.66621 .37608 .66701 .3768 .66872 .37617 .66792 .37558 Mtetra
.629 .839 .981 r
.66792 .37558 .66872 .37617 .67043 .37571 .66963 .37506 Mtetra
.651 .832 .97 r
.66963 .37506 .67043 .37571 .67217 .37577 .67134 .3745 Mtetra
.668 .698 .869 r
.67134 .3745 .67217 .37577 .67392 .37627 .67304 .3739 Mtetra
.64 .565 .754 r
.67304 .3739 .67392 .37627 .6757 .37699 .67475 .3733 Mtetra
.616 .492 .688 r
.67475 .3733 .6757 .37699 .67744 .3771 .67646 .3727 Mtetra
.607 .469 .667 r
.67646 .3727 .67744 .3771 .67916 .37654 .67817 .3721 Mtetra
.606 .467 .666 r
.67817 .3721 .67916 .37654 .68086 .37576 .67989 .37152 Mtetra
.626 .484 .67 r
.67989 .37152 .68086 .37576 .68255 .37467 .68159 .37068 Mtetra
.625 .49 .677 r
.68159 .37068 .68255 .37467 .68425 .37377 .6833 .36991 Mtetra
.589 .47 .685 r
.6833 .36991 .68425 .37377 .68599 .37365 .68503 .36963 Mtetra
.367 .321 .675 r
.68503 .36963 .68599 .37365 .68795 .37776 .68687 .37149 Mtetra
.773 .526 0 r
.68687 .37149 .68795 .37776 .69997 .57713 .68946 .38784 Mtetra
.026 0 .429 r
.68946 .38784 .69997 .57713 .70208 .58186 .7011 .57866 Mtetra
.32 .332 .716 r
.7011 .57866 .70208 .58186 .704 .5829 .70306 .58041 Mtetra
.605 .549 .764 r
.70306 .58041 .704 .5829 .70585 .58261 .70491 .58007 Mtetra
.667 .58 .748 r
.70491 .58007 .70585 .58261 .70769 .58192 .70673 .57915 Mtetra
.648 .556 .737 r
.70673 .57915 .70769 .58192 .70952 .58128 .70856 .57836 Mtetra
.624 .535 .733 r
.70856 .57836 .70952 .58128 .71137 .58074 .71041 .57781 Mtetra
.625 .534 .732 r
.71041 .57781 .71137 .58074 .71321 .58018 .71225 .57723 Mtetra
.629 .536 .73 r
.71225 .57723 .71321 .58018 .71506 .57963 .71409 .57661 Mtetra
.628 .533 .727 r
.71409 .57661 .71506 .57963 .71691 .57907 .71593 .57598 Mtetra
.619 .524 .725 r
.71593 .57598 .71691 .57907 .71875 .57849 .71778 .57544 Mtetra
.592 .51 .731 r
.71778 .57544 .71875 .57849 .7206 .57785 .71965 .57518 Mtetra
.572 .518 .757 r
.71965 .57518 .7206 .57785 .72244 .57715 .72153 .57511 Mtetra
.574 .568 .809 r
.72153 .57511 .72244 .57715 .72428 .57644 .7234 .575 Mtetra
.611 .66 .873 r
.7234 .575 .72428 .57644 .72613 .5758 .72527 .57465 Mtetra
.654 .732 .907 r
.72527 .57465 .72613 .5758 .72798 .57521 .72713 .5741 Mtetra
.668 .744 .907 r
.72713 .5741 .72798 .57521 .72984 .57465 .72898 .57347 Mtetra
.663 .73 .899 r
.72898 .57347 .72984 .57465 .73169 .57409 .73083 .57287 Mtetra
.655 .717 .894 r
.73083 .57287 .73169 .57409 .73355 .57354 .73269 .5723 Mtetra
.654 .714 .892 r
.73269 .5723 .73355 .57354 .73541 .573 .73455 .57174 Mtetra
.657 .711 .888 r
.73455 .57174 .73541 .573 .73728 .57254 .73641 .57116 Mtetra
.656 .692 .871 r
.73641 .57116 .73728 .57254 .73914 .57211 .73827 .57058 Mtetra
.65 .667 .853 r
.73827 .57058 .73914 .57211 .74101 .57154 .74013 .57002 Mtetra
.639 .664 .858 r
.74013 .57002 .74101 .57154 .74284 .57048 .742 .56953 Mtetra
.617 .759 .947 r
.742 .56953 .74284 .57048 .74463 .56886 .74387 .5691 Mtetra
0 0 0 r
.74387 .5691 .74463 .56886 .74641 .56701 .74575 .56868 Mtetra
.438 .032 .17 r
.74575 .56868 .74641 .56701 .74825 .56598 .74764 .56852 Mtetra
.491 .136 .293 r
.74764 .56852 .74825 .56598 .75015 .56595 .74954 .56842 Mtetra
.41 .062 .262 r
.74954 .56842 .75015 .56595 .75202 .56544 .75141 .56776 Mtetra
0 0 .096 r
.75141 .56776 .75202 .56544 .75371 .56218 .75314 .56515 Mtetra
.889 .753 .25 r
.75314 .56515 .75371 .56218 .74203 .36282 .75432 .55436 Mtetra
.027 0 .429 r
.75432 .55436 .74203 .36282 .74325 .35447 .7425 .35403 Mtetra
.96 .867 .703 r
.7425 .35403 .74325 .35447 .74487 .35193 .74407 .35075 Mtetra
.713 .736 .869 r
.74407 .35075 .74487 .35193 .7466 .35114 .7458 .34991 Mtetra
.601 .679 .896 r
.7458 .34991 .7466 .35114 .74837 .35079 .74758 .34962 Mtetra
.652 .714 .893 r
.74758 .34962 .74837 .35079 .75013 .35019 .74934 .34909 Mtetra
.737 .76 .871 r
.74934 .34909 .75013 .35019 .75186 .34921 .75107 .34812 Mtetra
.639 .727 .912 r
.75107 .34812 .75186 .34921 .75362 .34873 .75284 .34766 Mtetra
0 .306 .798 r
.75284 .34766 .75362 .34873 .75552 .35004 .75473 .34897 Mtetra
.951 .602 .228 r
.75473 .34897 .75552 .35004 .7583 .36344 .75751 .36233 Mtetra
.975 .673 .363 r
.75751 .36233 .7583 .36344 .77456 .55909 .77373 .55808 Mtetra
0 0 .451 r
.77373 .55808 .77456 .55909 .77668 .56165 .77585 .56065 Mtetra
.452 .672 .958 r
.77585 .56065 .77668 .56165 .77861 .56175 .77779 .56075 Mtetra
.728 .791 .902 r
.77779 .56075 .77861 .56175 .78047 .56081 .77965 .55981 Mtetra
.9 .811 .751 r
.77965 .55981 .78047 .56081 .7822 .55806 .78137 .55704 Mtetra
.978 .746 .518 r
.78137 .55704 .7822 .55806 .78333 .54762 .78251 .54656 Mtetra
.977 .681 .376 r
.78251 .54656 .78333 .54762 .76972 .34653 .76894 .34545 Mtetra
.923 .786 .692 r
.76894 .34545 .76972 .34653 .77127 .34303 .77049 .34195 Mtetra
.72 .761 .884 r
.77049 .34195 .77127 .34303 .77301 .34215 .77223 .34108 Mtetra
.594 .711 .925 r
.77223 .34108 .77301 .34215 .77481 .34186 .77403 .34079 Mtetra
.622 .724 .92 r
.77403 .34079 .77481 .34186 .77659 .34145 .77582 .34039 Mtetra
.736 .768 .878 r
.77582 .34039 .77659 .34145 .77833 .34049 .77756 .33943 Mtetra
.643 .734 .915 r
.77756 .33943 .77833 .34049 .78011 .34 .77934 .33894 Mtetra
.059 .398 .855 r
.77934 .33894 .78011 .34 .78202 .34102 .78125 .34 Mtetra
.933 .567 .165 r
.78125 .34 .78202 .34102 .78462 .35042 .78392 .35031 Mtetra
.975 .669 .352 r
.78392 .35031 .78462 .35042 .80293 .55043 .80214 .54965 Mtetra
.661 .171 0 r
.80214 .54965 .80293 .55043 .80513 .55336 .80433 .55249 Mtetra
.413 .687 .975 r
.80433 .55249 .80513 .55336 .80709 .55352 .80629 .55261 Mtetra
.729 .813 .917 r
.80629 .55261 .80709 .55352 .80897 .55263 .80817 .55166 Mtetra
.9 .823 .762 r
.80817 .55166 .80897 .55263 .81071 .55004 .8099 .54901 Mtetra
.98 .748 .514 r
.8099 .54901 .81071 .55004 .81183 .54021 .81098 .53869 Mtetra
.977 .678 .363 r
.81098 .53869 .81183 .54021 .7964 .33789 .79562 .33662 Mtetra
.92 .767 .674 r
.79562 .33662 .7964 .33789 .7979 .33398 .79712 .33278 Mtetra
.767 .755 .842 r
.79712 .33278 .7979 .33398 .79963 .33271 .79885 .33155 Mtetra
.592 .693 .912 r
.79885 .33155 .79963 .33271 .80144 .33242 .80067 .33128 Mtetra
.051 .374 .84 r
.80067 .33128 .80144 .33242 .80339 .33365 .80261 .33247 Mtetra
.889 .505 .049 r
.80261 .33247 .80339 .33365 .80607 .34313 .80514 .34023 Mtetra
.975 .669 .33 r
.80514 .34023 .80607 .34313 .82589 .54414 .82504 .54259 Mtetra
0 0 .508 r
.82504 .54259 .82589 .54414 .82811 .54689 .82731 .54588 Mtetra
.39 .64 .955 r
.82731 .54588 .82811 .54689 .83002 .54624 .82931 .54614 Mtetra
.537 .922 .913 r
.82931 .54614 .83002 .54624 .83182 .54433 .83121 .54534 Mtetra
0 0 0 r
.83121 .54534 .83182 .54433 .83343 .5403 .83298 .54305 Mtetra
.71 .669 .121 r
.83298 .54305 .83343 .5403 .81701 .34113 .83423 .5352 Mtetra
.061 0 .45 r
.83423 .5352 .81701 .34113 .81787 .33038 .81723 .33057 Mtetra
.988 .888 .563 r
.81723 .33057 .81787 .33038 .81943 .32715 .81867 .32604 Mtetra
.799 .781 .836 r
.81867 .32604 .81943 .32715 .82115 .32581 .82039 .32461 Mtetra
.639 .707 .896 r
.82039 .32461 .82115 .32581 .82296 .3253 .8222 .32413 Mtetra
.252 .501 .898 r
.8222 .32413 .82296 .3253 .82488 .32598 .82413 .32488 Mtetra
.792 .375 0 r
.82413 .32488 .82488 .32598 .82723 .33102 .82647 .32992 Mtetra
.974 .665 .325 r
.82647 .32992 .82723 .33102 .84874 .53475 .84795 .5337 Mtetra
.734 .295 0 r
.84795 .5337 .84874 .53475 .85115 .53902 .85036 .53799 Mtetra
.52 .703 .953 r
.85036 .53799 .85115 .53902 .85313 .53893 .85234 .53789 Mtetra
.713 .786 .909 r
.85234 .53789 .85313 .53893 .85504 .53806 .85425 .53702 Mtetra
.762 .8 .884 r
.85425 .53702 .85504 .53806 .85692 .5369 .85613 .53584 Mtetra
.66 .762 .925 r
.85613 .53584 .85692 .5369 .85885 .5363 .85806 .53522 Mtetra
.652 .755 .925 r
.85806 .53522 .85885 .5363 .8608 .53575 .86 .53464 Mtetra
.639 .743 .924 r
.86 .53464 .8608 .53575 .86275 .53531 .86195 .53412 Mtetra
.618 .717 .916 r
.86195 .53412 .86275 .53531 .86474 .53516 .86391 .5337 Mtetra
.616 .669 .878 r
.86391 .5337 .86474 .53516 .86671 .53488 .86588 .53331 Mtetra
.6 .644 .866 r
.86588 .53331 .86671 .53488 .86866 .53434 .86785 .53301 Mtetra
.489 .625 .911 r
.86785 .53301 .86866 .53434 .87057 .53333 .86987 .53314 Mtetra
.351 .816 .918 r
.86987 .53314 .87057 .53333 .8724 .53168 .87184 .53277 Mtetra
0 0 0 r
.87184 .53277 .8724 .53168 .87409 .5286 .8737 .53132 Mtetra
.8737 .53132 .87409 .5286 .85558 .33279 .87498 .52426 Mtetra
.069 0 .457 r
.87498 .52426 .85558 .33279 .85598 .31859 .85538 .31888 Mtetra
.984 .874 .514 r
.85538 .31888 .85598 .31859 .8575 .31517 .85674 .3139 Mtetra
.734 .736 .853 r
.85674 .3139 .8575 .31517 .85929 .31423 .85852 .31288 Mtetra
.611 .669 .881 r
.85852 .31288 .85929 .31423 .86113 .31382 .86037 .31253 Mtetra
.535 .643 .903 r
.86037 .31253 .86113 .31382 .863 .31364 .86226 .3125 Mtetra
.658 .733 .905 r
.86226 .3125 .863 .31364 .86483 .31305 .86409 .31193 Mtetra
.664 .739 .906 r
.86409 .31193 .86483 .31305 .86666 .31242 .86592 .31133 Mtetra
.676 .749 .906 r
.86592 .31133 .86666 .31242 .86847 .31172 .86775 .31068 Mtetra
.764 .79 .874 r
.86775 .31068 .86847 .31172 .87023 .31048 .86952 .30954 Mtetra
.695 .79 .923 r
.86952 .30954 .87023 .31048 .87204 .30964 .87133 .3088 Mtetra
.443 .696 .973 r
.87133 .3088 .87204 .30964 .87393 .3096 .87324 .30885 Mtetra
.81 .372 0 r
.87324 .30885 .87393 .3096 .87634 .31412 .87569 .31376 Mtetra
.971 .656 .298 r
.87569 .31376 .87634 .31412 .90135 .51922 .90063 .51857 Mtetra
.805 .354 0 r
.90063 .51857 .90135 .51922 .90397 .52437 .9032 .52335 Mtetra
.288 .574 .938 r
.9032 .52335 .90397 .52437 .90607 .52495 .9053 .5239 Mtetra
.646 .761 .933 r
.9053 .5239 .90607 .52495 .90804 .52439 .90728 .52333 Mtetra
.826 .818 .841 r
.90728 .52333 .90804 .52439 .90989 .5227 .90913 .52163 Mtetra
.908 .736 .657 r
.27476 .70336 .27579 .7042 .27772 .69866 .27669 .69782 Mtetra
.936 .686 .535 r
.27669 .69782 .27772 .69866 .29288 .50338 .29192 .50248 Mtetra
.907 .727 .647 r
.29192 .50248 .29288 .50338 .29474 .49766 .29378 .49676 Mtetra
.772 .758 .84 r
.29378 .49676 .29474 .49766 .29627 .49654 .29531 .49564 Mtetra
.64 .735 .917 r
.29531 .49564 .29627 .49654 .29776 .49615 .29679 .49524 Mtetra
.511 .691 .949 r
.29679 .49524 .29776 .49615 .29922 .49611 .29826 .4952 Mtetra
.749 .757 .859 r
.29826 .4952 .29922 .49611 .30074 .49517 .29978 .49427 Mtetra
.696 .748 .892 r
.29978 .49427 .30074 .49517 .30224 .49454 .30128 .49364 Mtetra
.481 .678 .952 r
.30128 .49364 .30224 .49454 .3037 .49457 .30274 .49366 Mtetra
.928 .548 .253 r
.30274 .49366 .3037 .49457 .30489 .49863 .30394 .49769 Mtetra
.939 .683 .523 r
.30394 .49769 .30489 .49863 .29356 .69313 .29254 .69222 Mtetra
.937 .582 .321 r
.29254 .69222 .29356 .69313 .29477 .69839 .29375 .69752 Mtetra
.06 .473 .887 r
.29375 .69752 .29477 .69839 .29628 .69913 .29526 .69813 Mtetra
.647 .73 .909 r
.29526 .69813 .29628 .69913 .29786 .69871 .29685 .69768 Mtetra
.773 .748 .83 r
.29685 .69768 .29786 .69871 .29951 .69729 .29849 .69644 Mtetra
.861 .768 .758 r
.29849 .69644 .29951 .69729 .30136 .69285 .30021 .69401 Mtetra
.984 .9 .638 r
.30021 .69401 .30136 .69285 .31513 .49947 .30206 .68937 Mtetra
0 0 .245 r
.30206 .68937 .31513 .49947 .3171 .49156 .31555 .50007 Mtetra
0 0 .227 r
.31555 .50007 .3171 .49156 .31867 .48989 .31749 .49267 Mtetra
0 0 0 r
.31749 .49267 .31867 .48989 .32019 .48915 .31914 .4898 Mtetra
.809 .993 .754 r
.31914 .4898 .32019 .48915 .32169 .4888 .32072 .48806 Mtetra
.737 .791 .896 r
.32072 .48806 .32169 .4888 .32319 .48832 .32225 .48724 Mtetra
.654 .703 .883 r
.32225 .48724 .32319 .48832 .3247 .48787 .32375 .48678 Mtetra
.615 .689 .896 r
.32375 .48678 .3247 .48787 .3262 .48744 .32525 .48649 Mtetra
.742 .748 .857 r
.32525 .48649 .3262 .48744 .32773 .4865 .32678 .48557 Mtetra
.709 .748 .882 r
.32678 .48557 .32773 .4865 .32925 .48579 .3283 .48486 Mtetra
.532 .696 .944 r
.3283 .48486 .32925 .48579 .33074 .4857 .32979 .48478 Mtetra
.908 .499 .163 r
.32979 .48478 .33074 .4857 .33202 .48909 .33107 .48816 Mtetra
.942 .684 .517 r
.33107 .48816 .33202 .48909 .32226 .68368 .32125 .68277 Mtetra
.941 .597 .341 r
.32125 .68277 .32226 .68368 .32348 .6898 .32247 .68893 Mtetra
0 .316 .773 r
.32247 .68893 .32348 .6898 .325 .69081 .324 .68982 Mtetra
.627 .727 .919 r
.324 .68982 .325 .69081 .3266 .69048 .3256 .68944 Mtetra
.765 .749 .838 r
.3256 .68944 .3266 .69048 .32825 .68916 .32724 .68827 Mtetra
.854 .768 .766 r
.32724 .68827 .32825 .68916 .33006 .68519 .32895 .68598 Mtetra
.98 .893 .663 r
.32895 .68598 .33006 .68519 .34221 .49321 .33077 .6817 Mtetra
0 0 .263 r
.33077 .6817 .34221 .49321 .34426 .48308 .34267 .49392 Mtetra
0 0 .247 r
.34267 .49392 .34426 .48308 .34586 .48109 .3447 .48419 Mtetra
0 0 .021 r
.3447 .48419 .34586 .48109 .3474 .4803 .34636 .48113 Mtetra
.75 .964 .675 r
.34636 .48113 .3474 .4803 .34891 .47993 .34795 .47931 Mtetra
.751 .823 .908 r
.34795 .47931 .34891 .47993 .35043 .4795 .34949 .47843 Mtetra
.651 .706 .887 r
.34949 .47843 .35043 .4795 .35194 .47906 .35101 .47798 Mtetra
.606 .688 .901 r
.35101 .47798 .35194 .47906 .35346 .47866 .35252 .47771 Mtetra
.701 .744 .884 r
.35252 .47771 .35346 .47866 .355 .47782 .35405 .47703 Mtetra
.703 .779 .91 r
.35405 .47703 .355 .47782 .35654 .4771 .35559 .47637 Mtetra
.6 .769 .961 r
.35559 .47637 .35654 .4771 .35805 .47691 .3571 .47605 Mtetra
0 .257 .732 r
.3571 .47605 .35805 .47691 .35943 .47933 .35856 .47701 Mtetra
0 0 .402 r
.35856 .47701 .35943 .47933 .35146 .66999 .35991 .48001 Mtetra
0 0 .289 r
.35991 .48001 .35146 .66999 .35257 .67989 .35214 .66735 Mtetra
.125 .045 .487 r
.35214 .66735 .35257 .67989 .3541 .68127 .35331 .67599 Mtetra
.329 .259 .625 r
.35331 .67599 .3541 .68127 .3557 .68119 .35479 .67835 Mtetra
.381 .38 .734 r
.35479 .67835 .3557 .68119 .35733 .68065 .35634 .67939 Mtetra
.433 .595 .911 r
.35634 .67939 .35733 .68065 .35894 .68047 .35793 .67965 Mtetra
.598 .758 .955 r
.35793 .67965 .35894 .68047 .36055 .6802 .35955 .67933 Mtetra
.735 .78 .889 r
.35955 .67933 .36055 .6802 .3622 .67931 .3612 .67845 Mtetra
.859 .776 .768 r
.3612 .67845 .3622 .67931 .36397 .67578 .36291 .67614 Mtetra
.971 .849 .664 r
.36291 .67614 .36397 .67578 .37425 .48526 .36473 .67147 Mtetra
0 0 .275 r
.36473 .67147 .37425 .48526 .37633 .47282 .37488 .4833 Mtetra
.231 .032 .391 r
.37488 .4833 .37633 .47282 .37793 .47077 .37666 .47734 Mtetra
.548 .279 .46 r
.37666 .47734 .37793 .47077 .37947 .47027 .37818 .47748 Mtetra
.552 .288 .468 r
.37818 .47748 .37947 .47027 .38099 .4702 .37969 .4777 Mtetra
.194 0 .35 r
.37969 .4777 .38099 .4702 .38253 .46964 .38141 .47311 Mtetra
0 0 .021 r
.38141 .47311 .38253 .46964 .38409 .46876 .38309 .46937 Mtetra
.916 .979 .735 r
.38309 .46937 .38409 .46876 .38564 .46793 .38471 .467 Mtetra
.763 .762 .851 r
.38471 .467 .38564 .46793 .38719 .46733 .38628 .46594 Mtetra
.631 .646 .847 r
.38628 .46594 .38719 .46733 .38873 .4669 .38782 .46557 Mtetra
.581 .635 .869 r
.38782 .46557 .38873 .4669 .39027 .46651 .38934 .46541 Mtetra
.616 .692 .898 r
.38934 .46541 .39027 .46651 .39181 .46604 .39088 .4651 Mtetra
.66 .739 .908 r
.39088 .4651 .39181 .46604 .39336 .4655 .39243 .46461 Mtetra
.676 .753 .909 r
.39243 .46461 .39336 .4655 .39491 .46494 .39398 .46405 Mtetra
.699 .76 .899 r
.39398 .46405 .39491 .46494 .39646 .46434 .39553 .46339 Mtetra
.709 .748 .883 r
.39553 .46339 .39646 .46434 .39801 .46374 .39709 .46267 Mtetra
.703 .725 .867 r
.39709 .46267 .39801 .46374 .39956 .46314 .39864 .46196 Mtetra
.712 .708 .845 r
.39864 .46196 .39956 .46314 .40112 .4623 .4002 .46116 Mtetra
.7 .711 .857 r
.4002 .46116 .40112 .4623 .40268 .46151 .40176 .46045 Mtetra
.633 .704 .897 r
.40176 .46045 .40268 .46151 .40423 .4612 .40331 .46006 Mtetra
.135 .438 .875 r
.40331 .46006 .40423 .4612 .4057 .46277 .40482 .46082 Mtetra
0 0 .438 r
.40482 .46082 .4057 .46277 .40691 .47193 .40626 .46348 Mtetra
0 0 .21 r
.40626 .46348 .40691 .47193 .40165 .66441 .40739 .47473 Mtetra
0 0 .329 r
.40739 .47473 .40165 .66441 .40321 .66642 .40254 .65671 Mtetra
.59 .409 .604 r
.40254 .65671 .40321 .66642 .40486 .66609 .4042 .65587 Mtetra
.602 .416 .602 r
.4042 .65587 .40486 .66609 .40652 .66523 .40588 .6546 Mtetra
.391 .256 .574 r
.40588 .6546 .40652 .66523 .40818 .66479 .40738 .65841 Mtetra
.258 .192 .589 r
.40738 .65841 .40818 .66479 .40981 .66485 .4089 .66196 Mtetra
.192 .256 .701 r
.4089 .66196 .40981 .66485 .41145 .66484 .41048 .66379 Mtetra
.176 .501 .908 r
.41048 .66379 .41145 .66484 .4131 .66483 .4121 .66442 Mtetra
.446 .809 .995 r
.4121 .66442 .4131 .66483 .41475 .66462 .41375 .66421 Mtetra
.706 .89 .964 r
.41375 .66421 .41475 .66462 .41641 .66383 .41542 .66343 Mtetra
.88 .867 .821 r
.41542 .66343 .41641 .66383 .41815 .661 .41713 .66146 Mtetra
.977 .884 .67 r
.41713 .66146 .41815 .661 .42019 .64794 .4189 .6573 Mtetra
.869 .746 .233 r
.4189 .6573 .42019 .64794 .42751 .45672 .42112 .63818 Mtetra
0 0 .318 r
.42112 .63818 .42751 .45672 .42914 .45388 .42804 .45935 Mtetra
.454 .184 .414 r
.42804 .45935 .42914 .45388 .43072 .45313 .42962 .45824 Mtetra
.545 .261 .435 r
.42962 .45824 .43072 .45313 .43227 .4529 .43118 .45838 Mtetra
.542 .263 .441 r
.43118 .45838 .43227 .4529 .43384 .45263 .43273 .45847 Mtetra
.498 .228 .434 r
.43273 .45847 .43384 .45263 .43541 .4521 .43431 .45786 Mtetra
.498 .226 .433 r
.43431 .45786 .43541 .4521 .43698 .45158 .43589 .45727 Mtetra
.496 .224 .431 r
.43589 .45727 .43698 .45158 .43855 .45104 .43746 .45665 Mtetra
.494 .221 .429 r
.43746 .45665 .43855 .45104 .44012 .4505 .43904 .45602 Mtetra
.492 .218 .427 r
.43904 .45602 .44012 .4505 .4417 .44995 .44062 .45537 Mtetra
.491 .216 .425 r
.44062 .45537 .4417 .44995 .44327 .44939 .4422 .45473 Mtetra
.489 .214 .422 r
.4422 .45473 .44327 .44939 .44485 .44882 .44379 .45408 Mtetra
.481 .205 .418 r
.44379 .45408 .44485 .44882 .44643 .44825 .44537 .45334 Mtetra
.417 .146 .393 r
.44537 .45334 .44643 .44825 .44801 .44747 .44697 .45192 Mtetra
.361 .087 .356 r
.44697 .45192 .44801 .44747 .4496 .44657 .44858 .45024 Mtetra
.437 .137 .356 r
.44858 .45024 .4496 .44657 .45117 .44612 .45017 .44944 Mtetra
.674 .355 .426 r
.45017 .44944 .45117 .44612 .45272 .44718 .45169 .45141 Mtetra
.948 .677 .491 r
.45169 .45141 .45272 .44718 .45414 .45397 .44907 .64321 Mtetra
.564 .345 .541 r
.44907 .64321 .45414 .45397 .45159 .64914 .4506 .64956 Mtetra
.735 .266 .137 r
.4506 .64956 .45159 .64914 .45321 .65201 .45224 .65117 Mtetra
.556 .745 .964 r
.45224 .65117 .45321 .65201 .45488 .65193 .45392 .65095 Mtetra
.679 .755 .908 r
.45392 .65095 .45488 .65193 .45657 .65121 .4556 .65033 Mtetra
.667 .771 .928 r
.4556 .65033 .45657 .65121 .45826 .65047 .45729 .64976 Mtetra
.546 .776 .984 r
.45729 .64976 .45826 .65047 .45994 .65008 .45897 .64952 Mtetra
.516 .802 .998 r
.45897 .64952 .45994 .65008 .46163 .6497 .46066 .64927 Mtetra
.5 .831 .999 r
.46066 .64927 .46163 .6497 .46331 .64931 .46234 .64898 Mtetra
.509 .856 .993 r
.46234 .64898 .46331 .64931 .465 .64892 .46403 .6486 Mtetra
.518 .864 .992 r
.46403 .6486 .465 .64892 .46669 .64852 .46572 .6482 Mtetra
.473 .843 .99 r
.46572 .6482 .46669 .64852 .46838 .64816 .46741 .64788 Mtetra
.386 .81 .97 r
.46741 .64788 .46838 .64816 .47007 .64783 .4691 .64766 Mtetra
.497 .881 .968 r
.4691 .64766 .47007 .64783 .47176 .64744 .47079 .64718 Mtetra
.79 .936 .926 r
.47079 .64718 .47176 .64744 .47345 .64686 .4725 .64601 Mtetra
.88 .79 .756 r
.4725 .64601 .47345 .64686 .47515 .64601 .47422 .64341 Mtetra
.824 .648 .664 r
.47422 .64341 .47515 .64601 .47686 .64511 .47597 .63936 Mtetra
.769 .562 .618 r
.47597 .63936 .47686 .64511 .47856 .64436 .47774 .63366 Mtetra
.605 .416 .599 r
.47774 .63366 .47856 .64436 .48025 .64395 .47944 .6322 Mtetra
.527 .354 .59 r
.47944 .6322 .48025 .64395 .48195 .64361 .48112 .63323 Mtetra
.506 .344 .595 r
.48112 .63323 .48195 .64361 .48365 .64343 .48279 .63469 Mtetra
.524 .365 .608 r
.48279 .63469 .48365 .64343 .48534 .64343 .48447 .63555 Mtetra
.582 .413 .618 r
.48447 .63555 .48534 .64343 .48705 .6429 .48617 .63508 Mtetra
.723 .516 .609 r
.48617 .63508 .48705 .6429 .48877 .64082 .48793 .62985 Mtetra
.945 .677 .496 r
.48793 .62985 .48877 .64082 .49057 .63068 .49158 .43748 Mtetra
.563 .348 .546 r
.49158 .43748 .49057 .63068 .49411 .43544 .49323 .43278 Mtetra
.755 .606 .692 r
.49323 .43278 .49411 .43544 .49574 .43187 .49485 .43053 Mtetra
.697 .686 .836 r
.49485 .43053 .49574 .43187 .49735 .43098 .49646 .42978 Mtetra
.633 .685 .881 r
.49646 .42978 .49735 .43098 .49895 .43064 .49807 .42938 Mtetra
.611 .666 .878 r
.49807 .42938 .49895 .43064 .50056 .43046 .49967 .42909 Mtetra
.653 .664 .848 r
.49967 .42909 .50056 .43046 .50217 .42997 .50128 .42859 Mtetra
.651 .662 .847 r
.50128 .42859 .50217 .42997 .50378 .42949 .50289 .42809 Mtetra
.652 .66 .846 r
.50289 .42809 .50378 .42949 .50539 .429 .5045 .42759 Mtetra
.654 .66 .843 r
.5045 .42759 .50539 .429 .507 .4285 .50611 .42708 Mtetra
.654 .659 .842 r
.50611 .42708 .507 .4285 .50861 .42799 .50773 .42657 Mtetra
.654 .658 .842 r
.50773 .42657 .50861 .42799 .51022 .42747 .50934 .42605 Mtetra
.654 .658 .841 r
.50934 .42605 .51022 .42747 .51184 .42696 .51096 .42553 Mtetra
.654 .657 .841 r
.51096 .42553 .51184 .42696 .51345 .42645 .51257 .42501 Mtetra
.654 .657 .84 r
.51257 .42501 .51345 .42645 .51507 .42593 .51419 .4245 Mtetra
.51419 .4245 .51507 .42593 .51669 .42542 .5158 .42398 Mtetra
.654 .656 .84 r
.5158 .42398 .51669 .42542 .5183 .4249 .51742 .42346 Mtetra
.653 .655 .839 r
.51742 .42346 .5183 .4249 .51992 .42439 .51904 .42295 Mtetra
.653 .654 .839 r
.51904 .42295 .51992 .42439 .52154 .42389 .52066 .42243 Mtetra
.652 .653 .838 r
.52066 .42243 .52154 .42389 .52316 .42339 .52228 .42193 Mtetra
.651 .651 .837 r
.52228 .42193 .52316 .42339 .52479 .42291 .52391 .42142 Mtetra
.65 .648 .835 r
.52391 .42142 .52479 .42291 .52641 .42244 .52553 .42092 Mtetra
.646 .641 .831 r
.52553 .42092 .52641 .42244 .52803 .42198 .52715 .42043 Mtetra
.639 .635 .83 r
.52715 .42043 .52803 .42198 .52966 .42151 .52878 .41998 Mtetra
.623 .63 .837 r
.52878 .41998 .52966 .42151 .53128 .42102 .53041 .41962 Mtetra
.625 .651 .855 r
.53041 .41962 .53128 .42102 .53291 .42051 .53203 .41925 Mtetra
.641 .681 .872 r
.53203 .41925 .53291 .42051 .53454 .41999 .53366 .41882 Mtetra
.683 .711 .869 r
.53366 .41882 .53454 .41999 .53617 .41945 .53529 .41817 Mtetra
.687 .695 .852 r
.53529 .41817 .53617 .41945 .5378 .4189 .53692 .41749 Mtetra
.679 .671 .836 r
.53692 .41749 .5378 .4189 .53943 .41836 .53855 .41682 Mtetra
.658 .646 .826 r
.53855 .41682 .53943 .41836 .54106 .41784 .54018 .41626 Mtetra
.649 .637 .824 r
.54018 .41626 .54106 .41784 .54269 .41734 .54182 .41575 Mtetra
.64 .632 .826 r
.54182 .41575 .54269 .41734 .54433 .41684 .54345 .41529 Mtetra
.624 .629 .836 r
.54345 .41529 .54433 .41684 .54596 .41637 .54509 .41493 Mtetra
.622 .644 .851 r
.54509 .41493 .54596 .41637 .5476 .41589 .54672 .41458 Mtetra
.629 .667 .868 r
.54672 .41458 .5476 .41589 .54923 .41538 .54836 .4142 Mtetra
.656 .7 .879 r
.54836 .4142 .54923 .41538 .55087 .4148 .55 .41369 Mtetra
.672 .719 .884 r
.55 .41369 .55087 .4148 .55251 .41419 .55164 .41311 Mtetra
.686 .729 .883 r
.55164 .41311 .55251 .41419 .55415 .41356 .55328 .41246 Mtetra
.704 .73 .871 r
.55328 .41246 .55415 .41356 .55579 .41294 .55492 .41171 Mtetra
.702 .708 .852 r
.55492 .41171 .55579 .41294 .55743 .41231 .55656 .41094 Mtetra
.693 .684 .837 r
.55656 .41094 .55743 .41231 .55907 .41167 .5582 .41019 Mtetra
.674 .661 .83 r
.5582 .41019 .55907 .41167 .56071 .41101 .55984 .40954 Mtetra
.669 .66 .832 r
.55984 .40954 .56071 .41101 .56235 .41036 .56148 .40892 Mtetra
.667 .664 .838 r
.56148 .40892 .56235 .41036 .564 .40972 .56313 .40833 Mtetra
.667 .67 .843 r
.56313 .40833 .564 .40972 .56564 .40911 .56477 .40773 Mtetra
.666 .672 .846 r
.56477 .40773 .56564 .40911 .56729 .40851 .56642 .40714 Mtetra
.665 .674 .849 r
.56642 .40714 .56729 .40851 .56893 .40792 .56807 .40657 Mtetra
.665 .676 .851 r
.56807 .40657 .56893 .40792 .57058 .40734 .56972 .40599 Mtetra
.664 .677 .853 r
.56972 .40599 .57058 .40734 .57223 .40676 .57137 .40542 Mtetra
.664 .679 .854 r
.57137 .40542 .57223 .40676 .57388 .40618 .57302 .40486 Mtetra
.664 .68 .855 r
.57302 .40486 .57388 .40618 .57553 .40561 .57467 .40429 Mtetra
.664 .681 .857 r
.57467 .40429 .57553 .40561 .57718 .40504 .57632 .40373 Mtetra
.664 .683 .858 r
.57632 .40373 .57718 .40504 .57884 .40447 .57797 .40316 Mtetra
.665 .684 .858 r
.57797 .40316 .57884 .40447 .58049 .40388 .57963 .40259 Mtetra
.665 .686 .86 r
.57963 .40259 .58049 .40388 .58215 .40331 .58128 .40202 Mtetra
.664 .687 .862 r
.58128 .40202 .58215 .40331 .5838 .40274 .58294 .40146 Mtetra
.704 .703 .846 r
.58294 .40146 .5838 .40274 .58545 .40181 .58459 .40066 Mtetra
.677 .716 .878 r
.58459 .40066 .58545 .40181 .58711 .40117 .58625 .40005 Mtetra
.587 .687 .91 r
.58625 .40005 .58711 .40117 .58878 .4011 .58792 .39982 Mtetra
0 .217 .739 r
.58792 .39982 .58878 .4011 .59051 .40416 .58962 .40131 Mtetra
0 0 .506 r
.58962 .40131 .59051 .40416 .59629 .60104 .59137 .40508 Mtetra
0 0 .401 r
.59137 .40508 .59629 .60104 .59825 .60932 .59712 .59802 Mtetra
.452 .303 .587 r
.59712 .59802 .59825 .60932 .60004 .60987 .59897 .60106 Mtetra
.588 .412 .611 r
.59897 .60106 .60004 .60987 .60182 .60931 .60074 .60034 Mtetra
.639 .448 .608 r
.60074 .60034 .60182 .60931 .60358 .60825 .60247 .598 Mtetra
.59 .407 .602 r
.60247 .598 .60358 .60825 .60536 .60766 .60423 .59708 Mtetra
.584 .401 .6 r
.60423 .59708 .60536 .60766 .60713 .6071 .606 .59632 Mtetra
.585 .401 .599 r
.606 .59632 .60713 .6071 .60891 .60652 .60777 .59551 Mtetra
.645 .444 .597 r
.60777 .59551 .60891 .60652 .61069 .60586 .60947 .59229 Mtetra
.618 .417 .588 r
.60947 .59229 .61069 .60586 .61246 .60524 .6112 .58971 Mtetra
.491 .32 .576 r
.6112 .58971 .61246 .60524 .61425 .60473 .61306 .59247 Mtetra
.3 .19 .557 r
.61306 .59247 .61425 .60473 .61604 .60462 .61503 .59927 Mtetra
.291 .242 .629 r
.61503 .59927 .61604 .60462 .61784 .60458 .61691 .60234 Mtetra
.214 .329 .766 r
.61691 .60234 .61784 .60458 .61964 .60446 .61875 .60386 Mtetra
.417 .756 .995 r
.61875 .60386 .61964 .60446 .62142 .60396 .62055 .6038 Mtetra
.545 .91 .959 r
.62055 .6038 .62142 .60396 .62321 .6033 .62234 .60317 Mtetra
.659 .955 .946 r
.62234 .60317 .62321 .6033 .62499 .60255 .62412 .60226 Mtetra
.684 .934 .967 r
.62412 .60226 .62499 .60255 .62677 .6018 .6259 .6014 Mtetra
.707 .914 .966 r
.6259 .6014 .62677 .6018 .62856 .60106 .62768 .60053 Mtetra
.719 .886 .957 r
.62768 .60053 .62856 .60106 .63035 .60033 .62946 .59966 Mtetra
.689 .844 .957 r
.62946 .59966 .63035 .60033 .63214 .59967 .63125 .59893 Mtetra
.668 .82 .956 r
.63125 .59893 .63214 .59967 .63393 .59908 .63304 .5983 Mtetra
.653 .805 .956 r
.63304 .5983 .63393 .59908 .63572 .59854 .63484 .59772 Mtetra
.648 .794 .953 r
.63484 .59772 .63572 .59854 .63752 .59807 .63664 .59718 Mtetra
.64 .775 .945 r
.63664 .59718 .63752 .59807 .63932 .59765 .63844 .59667 Mtetra
.631 .753 .935 r
.63844 .59667 .63932 .59765 .64113 .59727 .64024 .59622 Mtetra
.621 .733 .927 r
.64024 .59622 .64113 .59727 .64294 .59694 .64204 .59581 Mtetra
.612 .713 .917 r
.64204 .59581 .64294 .59694 .64474 .59663 .64385 .59545 Mtetra
.602 .699 .912 r
.64385 .59545 .64474 .59663 .64655 .5963 .64566 .59513 Mtetra
.487 .648 .929 r
.64566 .59513 .64655 .5963 .64838 .59635 .64749 .59521 Mtetra
.527 .674 .931 r
.64749 .59521 .64838 .59635 .6502 .59617 .64931 .59516 Mtetra
.652 .754 .924 r
.64931 .59516 .6502 .59617 .65199 .5953 .65112 .59461 Mtetra
.902 .845 .779 r
.65112 .59461 .65199 .5953 .65366 .59118 .65286 .59214 Mtetra
.98 .884 .524 r
.65286 .59214 .65366 .59118 .64787 .392 .65448 .58667 Mtetra
.001 0 .407 r
.65448 .58667 .64787 .392 .64926 .38331 .64875 .39061 Mtetra
.33 .106 .415 r
.64875 .39061 .64926 .38331 .6509 .38145 .65033 .38699 Mtetra
.534 .254 .436 r
.65033 .38699 .6509 .38145 .6526 .38092 .65205 .38695 Mtetra
.535 .26 .444 r
.65205 .38695 .6526 .38092 .65432 .38077 .65378 .38691 Mtetra
.239 .024 .372 r
.65378 .38691 .65432 .38077 .65601 .3801 .65534 .38289 Mtetra
0 0 .091 r
.65534 .38289 .65601 .3801 .6577 .37917 .65693 .37947 Mtetra
.899 .985 .727 r
.65693 .37947 .6577 .37917 .65939 .37827 .65856 .37715 Mtetra
.761 .753 .846 r
.65856 .37715 .65939 .37827 .66109 .3776 .66024 .37601 Mtetra
.656 .645 .827 r
.66024 .37601 .66109 .3776 .66279 .37706 .66194 .37544 Mtetra
.619 .623 .833 r
.66194 .37544 .66279 .37706 .6645 .37657 .66365 .37508 Mtetra
.617 .64 .851 r
.66365 .37508 .6645 .37657 .66621 .37608 .66537 .37474 Mtetra
.621 .665 .871 r
.66537 .37474 .66621 .37608 .66792 .37558 .66709 .37438 Mtetra
.627 .693 .891 r
.66709 .37438 .66792 .37558 .66963 .37506 .6688 .37398 Mtetra
.67 .733 .897 r
.6688 .37398 .66963 .37506 .67134 .3745 .67051 .37339 Mtetra
.694 .737 .884 r
.67051 .37339 .67134 .3745 .67304 .3739 .67221 .37268 Mtetra
.693 .715 .865 r
.67221 .37268 .67304 .3739 .67475 .3733 .67392 .37195 Mtetra
.674 .687 .854 r
.67392 .37195 .67475 .3733 .67646 .3727 .67563 .3713 Mtetra
.661 .675 .852 r
.67563 .3713 .67646 .3727 .67817 .3721 .67734 .37072 Mtetra
.657 .676 .856 r
.67734 .37072 .67817 .3721 .67989 .37152 .67906 .37017 Mtetra
.689 .693 .848 r
.67906 .37017 .67989 .37152 .68159 .37068 .68076 .36943 Mtetra
.689 .71 .864 r
.68076 .36943 .68159 .37068 .6833 .36991 .68247 .36873 Mtetra
.623 .696 .897 r
.68247 .36873 .6833 .36991 .68503 .36963 .6842 .36835 Mtetra
.206 .448 .871 r
.6842 .36835 .68503 .36963 .68687 .37149 .68599 .36923 Mtetra
0 .025 .593 r
.68599 .36923 .68687 .37149 .68946 .38784 .6879 .37228 Mtetra
.982 .692 .347 r
.6879 .37228 .68946 .38784 .7011 .57866 .69944 .56204 Mtetra
.288 .173 .544 r
.69944 .56204 .7011 .57866 .70306 .58041 .70182 .57206 Mtetra
.566 .4 .616 r
.70182 .57206 .70306 .58041 .70491 .58007 .70368 .57195 Mtetra
.62 .439 .616 r
.70368 .57195 .70491 .58007 .70673 .57915 .70546 .5704 Mtetra
.608 .427 .611 r
.70546 .5704 .70673 .57915 .70856 .57836 .70726 .56908 Mtetra
.585 .408 .608 r
.70726 .56908 .70856 .57836 .71041 .57781 .70909 .56839 Mtetra
.586 .408 .608 r
.70909 .56839 .71041 .57781 .71225 .57723 .71092 .56767 Mtetra
.613 .427 .606 r
.71092 .56767 .71225 .57723 .71409 .57661 .7127 .56603 Mtetra
.616 .424 .6 r
.7127 .56603 .71409 .57661 .71593 .57598 .71447 .56411 Mtetra
.549 .372 .594 r
.71447 .56411 .71593 .57598 .71778 .57544 .71637 .5645 Mtetra
.401 .271 .587 r
.71637 .5645 .71778 .57544 .71965 .57518 .71849 .5688 Mtetra
.34 .263 .622 r
.71849 .5688 .71965 .57518 .72153 .57511 .72056 .57211 Mtetra
.302 .332 .726 r
.72056 .57211 .72153 .57511 .7234 .575 .72255 .57385 Mtetra
.373 .595 .932 r
.72255 .57385 .7234 .575 .72527 .57465 .72445 .57424 Mtetra
.544 .866 .995 r
.72445 .57424 .72527 .57465 .72713 .5741 .72632 .57376 Mtetra
.629 .918 .979 r
.72632 .57376 .72713 .5741 .72898 .57347 .72816 .57303 Mtetra
.638 .896 .985 r
.72816 .57303 .72898 .57347 .73083 .57287 .73001 .57234 Mtetra
.612 .866 .991 r
.73001 .57234 .73083 .57287 .73269 .5723 .73187 .57177 Mtetra
.621 .868 .989 r
.73187 .57177 .73269 .5723 .73455 .57174 .73373 .57118 Mtetra
.654 .872 .98 r
.73373 .57118 .73455 .57174 .73641 .57116 .73558 .5705 Mtetra
.684 .854 .964 r
.73558 .5705 .73641 .57116 .73827 .57058 .73743 .56976 Mtetra
.681 .813 .946 r
.73743 .56976 .73827 .57058 .74013 .57002 .73929 .56906 Mtetra
.636 .765 .941 r
.73929 .56906 .74013 .57002 .742 .56953 .74116 .56856 Mtetra
.582 .741 .952 r
.74116 .56856 .742 .56953 .74387 .5691 .74304 .56825 Mtetra
.558 .762 .974 r
.74304 .56825 .74387 .5691 .74575 .56868 .74493 .56798 Mtetra
.455 .752 .993 r
.74493 .56798 .74575 .56868 .74764 .56852 .74683 .56789 Mtetra
.439 .764 .996 r
.74683 .56789 .74764 .56852 .74954 .56842 .74873 .56779 Mtetra
.657 .856 .976 r
.74873 .56779 .74954 .56842 .75141 .56776 .75059 .56712 Mtetra
.918 .867 .774 r
.75059 .56712 .75141 .56776 .75314 .56515 .75233 .56453 Mtetra
.984 .76 .518 r
.75233 .56453 .75314 .56515 .75432 .55436 .75356 .55444 Mtetra
.978 .684 .386 r
.75356 .55444 .75432 .55436 .7425 .35403 .74171 .35297 Mtetra
.917 .786 .7 r
.74171 .35297 .7425 .35403 .74407 .35075 .74327 .34961 Mtetra
.714 .744 .875 r
.74327 .34961 .74407 .35075 .7458 .34991 .74501 .34877 Mtetra
.591 .695 .915 r
.74501 .34877 .7458 .34991 .74758 .34962 .74679 .3485 Mtetra
.647 .724 .905 r
.74679 .3485 .74758 .34962 .74934 .34909 .74855 .348 Mtetra
.736 .761 .873 r
.74855 .348 .74934 .34909 .75107 .34812 .75028 .34704 Mtetra
.637 .727 .913 r
.75028 .34704 .75107 .34812 .75284 .34766 .75205 .34659 Mtetra
0 .305 .797 r
.75205 .34659 .75284 .34766 .75473 .34897 .75395 .3479 Mtetra
.951 .602 .228 r
.75395 .3479 .75473 .34897 .75751 .36233 .75672 .36121 Mtetra
.975 .673 .363 r
.75672 .36121 .75751 .36233 .77373 .55808 .77291 .55707 Mtetra
0 0 .452 r
.77291 .55707 .77373 .55808 .77585 .56065 .77502 .55964 Mtetra
.452 .672 .958 r
.77502 .55964 .77585 .56065 .77779 .56075 .77696 .55974 Mtetra
.728 .79 .902 r
.77696 .55974 .77779 .56075 .77965 .55981 .77882 .5588 Mtetra
.9 .811 .751 r
.77882 .5588 .77965 .55981 .78137 .55704 .78055 .55603 Mtetra
.978 .745 .517 r
.78055 .55603 .78137 .55704 .78251 .54656 .78168 .54544 Mtetra
.977 .681 .376 r
.78168 .54544 .78251 .54656 .76894 .34545 .76816 .34435 Mtetra
.921 .784 .693 r
.76816 .34435 .76894 .34545 .77049 .34195 .76971 .34086 Mtetra
.719 .758 .883 r
.76971 .34086 .77049 .34195 .77223 .34108 .77146 .34 Mtetra
.592 .708 .924 r
.77146 .34 .77223 .34108 .77403 .34079 .77325 .33972 Mtetra
.621 .723 .919 r
.77325 .33972 .77403 .34079 .77582 .34039 .77504 .33932 Mtetra
.736 .767 .878 r
.77504 .33932 .77582 .34039 .77756 .33943 .77678 .33836 Mtetra
.639 .731 .915 r
.77678 .33836 .77756 .33943 .77934 .33894 .77857 .33788 Mtetra
.018 .369 .838 r
.77857 .33788 .77934 .33894 .78125 .34 .78049 .33903 Mtetra
.949 .598 .22 r
.78049 .33903 .78125 .34 .78392 .35031 .78343 .35279 Mtetra
.973 .667 .361 r
.78343 .35279 .78392 .35031 .80214 .54965 .80137 .54918 Mtetra
.712 .196 0 r
.80137 .54918 .80214 .54965 .80433 .55249 .80354 .55183 Mtetra
.402 .736 .992 r
.80354 .55183 .80433 .55249 .80629 .55261 .8055 .55182 Mtetra
.753 .85 .923 r
.8055 .55182 .80629 .55261 .80817 .55166 .80736 .55076 Mtetra
.914 .831 .751 r
.80736 .55076 .80817 .55166 .8099 .54901 .80908 .54794 Mtetra
.981 .739 .496 r
.80908 .54794 .8099 .54901 .81098 .53869 .81003 .53597 Mtetra
.977 .677 .367 r
.81003 .53597 .81098 .53869 .79562 .33662 .7948 .33504 Mtetra
.893 .736 .679 r
.7948 .33504 .79562 .33662 .79712 .33278 .79633 .33139 Mtetra
.742 .716 .827 r
.79633 .33139 .79712 .33278 .79885 .33155 .79807 .33026 Mtetra
.575 .658 .894 r
.79807 .33026 .79885 .33155 .80067 .33128 .79989 .33007 Mtetra
.034 .346 .823 r
.79989 .33007 .80067 .33128 .80261 .33247 .80185 .33138 Mtetra
.909 .53 .095 r
.80185 .33138 .80261 .33247 .80514 .34023 .80445 .34 Mtetra
.975 .667 .34 r
.80445 .34 .80514 .34023 .82504 .54259 .82428 .54202 Mtetra
.743 .25 0 r
.82428 .54202 .82504 .54259 .82731 .54588 .82654 .5452 Mtetra
.273 .655 .968 r
.82654 .5452 .82731 .54588 .82931 .54614 .82854 .54547 Mtetra
.683 .861 .967 r
.82854 .54547 .82931 .54614 .83121 .54534 .83044 .5447 Mtetra
.901 .89 .81 r
.83044 .5447 .83121 .54534 .83298 .54305 .83222 .54247 Mtetra
.99 .792 .542 r
.83222 .54247 .83298 .54305 .83423 .5352 .83352 .53512 Mtetra
.977 .676 .347 r
.83352 .53512 .83423 .5352 .81723 .33057 .81649 .32967 Mtetra
.964 .798 .628 r
.81649 .32967 .81723 .33057 .81867 .32604 .81791 .32493 Mtetra
.8 .782 .836 r
.81791 .32493 .81867 .32604 .82039 .32461 .81963 .32348 Mtetra
.637 .722 .909 r
.81963 .32348 .82039 .32461 .8222 .32413 .82144 .32301 Mtetra
.229 .498 .901 r
.82144 .32301 .8222 .32413 .82413 .32488 .82337 .32378 Mtetra
.789 .372 0 r
.82337 .32378 .82413 .32488 .82647 .32992 .82571 .3288 Mtetra
.974 .665 .325 r
.82571 .3288 .82647 .32992 .84795 .5337 .84716 .53266 Mtetra
.737 .297 0 r
.84716 .53266 .84795 .5337 .85036 .53799 .84956 .53696 Mtetra
.516 .704 .955 r
.84956 .53696 .85036 .53799 .85234 .53789 .85155 .53688 Mtetra
.712 .79 .913 r
.85155 .53688 .85234 .53789 .85425 .53702 .85346 .536 Mtetra
.763 .808 .888 r
.85346 .536 .85425 .53702 .85613 .53584 .85534 .53483 Mtetra
.662 .774 .932 r
.85534 .53483 .85613 .53584 .85806 .53522 .85728 .5342 Mtetra
.655 .768 .932 r
.85728 .5342 .85806 .53522 .86 .53464 .85922 .5336 Mtetra
.644 .759 .932 r
.85922 .5336 .86 .53464 .86195 .53412 .86116 .53305 Mtetra
.625 .745 .933 r
.86116 .53305 .86195 .53412 .86391 .5337 .86312 .53258 Mtetra
.613 .73 .929 r
.86312 .53258 .86391 .5337 .86588 .53331 .86508 .53217 Mtetra
.576 .708 .932 r
.86508 .53217 .86588 .53331 .86785 .53301 .86706 .53191 Mtetra
.396 .621 .943 r
.86706 .53191 .86785 .53301 .86987 .53314 .8691 .53222 Mtetra
.545 .744 .969 r
.8691 .53222 .86987 .53314 .87184 .53277 .87109 .532 Mtetra
.801 .869 .898 r
.87109 .532 .87184 .53277 .8737 .53132 .87296 .53064 Mtetra
.991 .792 .541 r
.87296 .53064 .8737 .53132 .87498 .52426 .87422 .52345 Mtetra
.976 .671 .328 r
.87422 .52345 .87498 .52426 .85538 .31888 .85459 .31732 Mtetra
.932 .745 .628 r
.85459 .31732 .85538 .31888 .85674 .3139 .85596 .3124 Mtetra
.708 .691 .831 r
.85596 .3124 .85674 .3139 .85852 .31288 .85775 .31147 Mtetra
.587 .648 .878 r
.85775 .31147 .85852 .31288 .86037 .31253 .85962 .31125 Mtetra
.498 .622 .905 r
.85962 .31125 .86037 .31253 .86226 .3125 .86152 .31135 Mtetra
.649 .725 .904 r
.86152 .31135 .86226 .3125 .86409 .31193 .86335 .31082 Mtetra
.661 .739 .908 r
.86335 .31082 .86409 .31193 .86592 .31133 .86519 .31024 Mtetra
.675 .749 .906 r
.86519 .31024 .86592 .31133 .86775 .31068 .86701 .30958 Mtetra
.76 .78 .869 r
.86701 .30958 .86775 .31068 .86952 .30954 .86878 .30845 Mtetra
.693 .757 .901 r
.86878 .30845 .86952 .30954 .87133 .3088 .8706 .30771 Mtetra
.488 .66 .937 r
.8706 .30771 .87133 .3088 .87324 .30885 .87251 .30777 Mtetra
.754 .335 0 r
.87251 .30777 .87324 .30885 .87569 .31376 .87496 .31271 Mtetra
.971 .656 .295 r
.87496 .31271 .87569 .31376 .90063 .51857 .89987 .51756 Mtetra
.744 .309 0 r
.89987 .51756 .90063 .51857 .9032 .52335 .90244 .52231 Mtetra
.294 .575 .937 r
.90244 .52231 .9032 .52335 .9053 .5239 .90454 .52285 Mtetra
.647 .764 .934 r
.90454 .52285 .9053 .5239 .90728 .52333 .90652 .52228 Mtetra
.828 .821 .843 r
.90652 .52228 .90728 .52333 .90913 .52163 .90836 .52058 Mtetra
.908 .736 .657 r
.27372 .70252 .27476 .70336 .27669 .69782 .27566 .69697 Mtetra
.936 .686 .535 r
.27566 .69697 .27669 .69782 .29192 .50248 .29095 .50158 Mtetra
.907 .727 .648 r
.29095 .50158 .29192 .50248 .29378 .49676 .29281 .49586 Mtetra
.772 .759 .841 r
.29281 .49586 .29378 .49676 .29531 .49564 .29435 .49474 Mtetra
.64 .735 .917 r
.29435 .49474 .29531 .49564 .29679 .49524 .29583 .49434 Mtetra
.511 .691 .949 r
.29583 .49434 .29679 .49524 .29826 .4952 .29729 .4943 Mtetra
.749 .757 .859 r
.29729 .4943 .29826 .4952 .29978 .49427 .29882 .49337 Mtetra
.696 .748 .892 r
.29882 .49337 .29978 .49427 .30128 .49364 .30032 .49273 Mtetra
.483 .679 .952 r
.30032 .49273 .30128 .49364 .30274 .49366 .30178 .49275 Mtetra
.927 .547 .25 r
.30178 .49275 .30274 .49366 .30394 .49769 .30298 .49676 Mtetra
.939 .683 .523 r
.30298 .49676 .30394 .49769 .29254 .69222 .29152 .69131 Mtetra
.937 .583 .322 r
.29152 .69131 .29254 .69222 .29375 .69752 .29272 .69665 Mtetra
.17 .542 .926 r
.29272 .69665 .29375 .69752 .29526 .69813 .29425 .69713 Mtetra
.656 .73 .904 r
.29425 .69713 .29526 .69813 .29685 .69768 .29584 .69664 Mtetra
.751 .743 .845 r
.29584 .69664 .29685 .69768 .29849 .69644 .29747 .69559 Mtetra
.736 .777 .886 r
.29747 .69559 .29849 .69644 .30021 .69401 .29908 .69471 Mtetra
.576 .915 .694 r
.29908 .69471 .30021 .69401 .30206 .68937 .30073 .69341 Mtetra
.215 0 .26 r
.30073 .69341 .30206 .68937 .31555 .50007 .30243 .69118 Mtetra
.535 .321 .536 r
.30243 .69118 .31555 .50007 .31749 .49267 .30459 .68179 Mtetra
0 0 .239 r
.30459 .68179 .31749 .49267 .31914 .4898 .31804 .49131 Mtetra
.954 .931 .592 r
.31804 .49131 .31914 .4898 .32072 .48806 .31976 .48733 Mtetra
.79 .795 .857 r
.31976 .48733 .32072 .48806 .32225 .48724 .32131 .48615 Mtetra
.655 .703 .882 r
.32131 .48615 .32225 .48724 .32375 .48678 .32281 .48569 Mtetra
.576 .675 .907 r
.32281 .48569 .32375 .48678 .32525 .48649 .3243 .48553 Mtetra
.738 .747 .86 r
.3243 .48553 .32525 .48649 .32678 .48557 .32583 .48464 Mtetra
.708 .747 .883 r
.32583 .48464 .32678 .48557 .3283 .48486 .32735 .48394 Mtetra
.53 .695 .944 r
.32735 .48394 .3283 .48486 .32979 .48478 .32884 .48386 Mtetra
.907 .498 .161 r
.32884 .48386 .32979 .48478 .33107 .48816 .33012 .48723 Mtetra
.942 .684 .517 r
.33012 .48723 .33107 .48816 .32125 .68277 .32024 .68186 Mtetra
.941 .597 .342 r
.32024 .68186 .32125 .68277 .32247 .68893 .32146 .68806 Mtetra
0 .392 .833 r
.32146 .68806 .32247 .68893 .324 .68982 .32299 .68882 Mtetra
.641 .73 .913 r
.32299 .68882 .324 .68982 .3256 .68944 .32459 .68839 Mtetra
.745 .744 .85 r
.32459 .68839 .3256 .68944 .32724 .68827 .32623 .68737 Mtetra
.739 .772 .879 r
.32623 .68737 .32724 .68827 .32895 .68598 .32787 .68646 Mtetra
.657 .966 .795 r
.32787 .68646 .32895 .68598 .33077 .6817 .32952 .68521 Mtetra
.183 0 .222 r
.32952 .68521 .33077 .6817 .34267 .49392 .33122 .68311 Mtetra
.539 .324 .536 r
.33122 .68311 .34267 .49392 .3447 .48419 .33321 .67563 Mtetra
0 0 .258 r
.33321 .67563 .3447 .48419 .34636 .48113 .34525 .48309 Mtetra
.913 .908 .507 r
.34525 .48309 .34636 .48113 .34795 .47931 .34699 .4787 Mtetra
.82 .824 .853 r
.34699 .4787 .34795 .47931 .34949 .47843 .34855 .47735 Mtetra
.655 .706 .885 r
.34855 .47735 .34949 .47843 .35101 .47798 .35008 .47688 Mtetra
.567 .672 .91 r
.35008 .47688 .35101 .47798 .35252 .47771 .35158 .47675 Mtetra
.665 .733 .9 r
.35158 .47675 .35252 .47771 .35405 .47703 .3531 .47624 Mtetra
.687 .776 .919 r
.3531 .47624 .35405 .47703 .35559 .47637 .35463 .47565 Mtetra
.648 .785 .947 r
.35463 .47565 .35559 .47637 .3571 .47605 .35616 .47519 Mtetra
.584 .731 .944 r
.35616 .47519 .3571 .47605 .35856 .47701 .35767 .47495 Mtetra
.528 .517 .787 r
.35767 .47495 .35856 .47701 .35991 .48001 .35917 .47511 Mtetra
.481 .368 .648 r
.35917 .47511 .35991 .48001 .35214 .66735 .36062 .47605 Mtetra
.542 .33 .543 r
.36062 .47605 .35214 .66735 .35331 .67599 .36183 .48204 Mtetra
0 0 .287 r
.36183 .48204 .35331 .67599 .35479 .67835 .35395 .67425 Mtetra
0 0 .513 r
.35395 .67425 .35479 .67835 .35634 .67939 .35536 .6781 Mtetra
.206 .462 .881 r
.35536 .6781 .35634 .67939 .35793 .67965 .35693 .67883 Mtetra
.614 .764 .951 r
.35693 .67883 .35793 .67965 .35955 .67933 .35855 .67846 Mtetra
.734 .779 .889 r
.35855 .67846 .35955 .67933 .3612 .67845 .3602 .67758 Mtetra
.786 .784 .851 r
.3602 .67758 .3612 .67845 .36291 .67614 .36186 .67632 Mtetra
.839 .987 .864 r
.36186 .67632 .36291 .67614 .36473 .67147 .36354 .67476 Mtetra
.239 0 .238 r
.36354 .67476 .36473 .67147 .37488 .4833 .36523 .67301 Mtetra
.552 .335 .539 r
.36523 .67301 .37488 .4833 .37666 .47734 .36686 .67247 Mtetra
.553 .336 .539 r
.36686 .67247 .37666 .47734 .37818 .47748 .36847 .67241 Mtetra
.552 .335 .539 r
.36847 .67241 .37818 .47748 .37969 .4777 .37012 .67168 Mtetra
.543 .328 .537 r
.37012 .67168 .37969 .4777 .38141 .47311 .37197 .66616 Mtetra
0 0 .28 r
.37197 .66616 .38141 .47311 .38309 .46937 .38202 .47157 Mtetra
.913 .887 .467 r
.38202 .47157 .38309 .46937 .38471 .467 .38376 .46654 Mtetra
.856 .852 .837 r
.38376 .46654 .38471 .467 .38628 .46594 .38535 .46491 Mtetra
.652 .718 .896 r
.38535 .46491 .38628 .46594 .38782 .46557 .38689 .46445 Mtetra
.55 .663 .911 r
.38689 .46445 .38782 .46557 .38934 .46541 .38842 .46437 Mtetra
.6 .697 .911 r
.38842 .46437 .38934 .46541 .39088 .4651 .38995 .46411 Mtetra
.654 .726 .902 r
.38995 .46411 .39088 .4651 .39243 .46461 .3915 .46364 Mtetra
.664 .735 .902 r
.3915 .46364 .39243 .46461 .39398 .46405 .39305 .46313 Mtetra
.682 .75 .903 r
.39305 .46313 .39398 .46405 .39553 .46339 .3946 .46255 Mtetra
.694 .77 .91 r
.3946 .46255 .39553 .46339 .39709 .46267 .39615 .46191 Mtetra
.696 .79 .923 r
.39615 .46191 .39709 .46267 .39864 .46196 .39771 .46127 Mtetra
.704 .81 .931 r
.39771 .46127 .39864 .46196 .4002 .46116 .39926 .4606 Mtetra
.689 .84 .955 r
.39926 .4606 .4002 .46116 .40176 .46045 .40082 .45997 Mtetra
.627 .849 .984 r
.40082 .45997 .40176 .46045 .40331 .46006 .40237 .45949 Mtetra
.396 .736 .992 r
.40237 .45949 .40331 .46006 .40482 .46082 .40391 .45949 Mtetra
.362 .528 .887 r
.40391 .45949 .40482 .46082 .40626 .46348 .40542 .45996 Mtetra
.481 .405 .694 r
.40542 .45996 .40626 .46348 .40739 .47473 .40694 .46066 Mtetra
.563 .373 .582 r
.40694 .46066 .40739 .47473 .40254 .65671 .40848 .46048 Mtetra
.556 .342 .545 r
.40848 .46048 .40254 .65671 .4042 .65587 .41005 .4596 Mtetra
.555 .341 .545 r
.41005 .4596 .4042 .65587 .40588 .6546 .41161 .45924 Mtetra
.548 .336 .544 r
.41161 .45924 .40588 .6546 .40738 .65841 .41305 .46228 Mtetra
0 0 .316 r
.41305 .46228 .40738 .65841 .4089 .66196 .40806 .65686 Mtetra
0 0 .447 r
.40806 .65686 .4089 .66196 .41048 .66379 .40952 .66219 Mtetra
.042 .3 .79 r
.40952 .66219 .41048 .66379 .4121 .66442 .41112 .66347 Mtetra
.582 .726 .942 r
.41112 .66347 .4121 .66442 .41375 .66421 .41277 .66321 Mtetra
.717 .756 .883 r
.41277 .66321 .41375 .66421 .41542 .66343 .41444 .6624 Mtetra
.777 .76 .838 r
.41444 .6624 .41542 .66343 .41713 .66146 .41613 .66113 Mtetra
.861 .894 .857 r
.41613 .66113 .41713 .66146 .4189 .6573 .41783 .65946 Mtetra
0 0 0 r
.41783 .65946 .4189 .6573 .42112 .63818 .41954 .65748 Mtetra
.519 .288 .505 r
.41954 .65748 .42112 .63818 .42804 .45935 .42123 .65592 Mtetra
.552 .335 .539 r
.42123 .65592 .42804 .45935 .42962 .45824 .4229 .65526 Mtetra
.553 .336 .539 r
.4229 .65526 .42962 .45824 .43118 .45838 .42456 .65492 Mtetra
.553 .335 .539 r
.42456 .65492 .43118 .45838 .43273 .45847 .42623 .65455 Mtetra
.552 .335 .539 r
.42623 .65455 .43273 .45847 .43431 .45786 .42789 .65401 Mtetra
.42789 .65401 .43431 .45786 .43589 .45727 .42956 .65347 Mtetra
.42956 .65347 .43589 .45727 .43746 .45665 .43123 .65293 Mtetra
.43123 .65293 .43746 .45665 .43904 .45602 .43291 .65237 Mtetra
.43291 .65237 .43904 .45602 .44062 .45537 .43458 .65181 Mtetra
.43458 .65181 .44062 .45537 .4422 .45473 .43625 .65124 Mtetra
.43625 .65124 .4422 .45473 .44379 .45408 .43793 .65067 Mtetra
.43793 .65067 .44379 .45408 .44537 .45334 .43961 .65004 Mtetra
.43961 .65004 .44537 .45334 .44697 .45192 .44129 .64912 Mtetra
.551 .334 .539 r
.44129 .64912 .44697 .45192 .44858 .45024 .44298 .64788 Mtetra
.552 .335 .539 r
.44298 .64788 .44858 .45024 .45017 .44944 .44467 .647 Mtetra
.554 .337 .539 r
.44467 .647 .45017 .44944 .45169 .45141 .44632 .64751 Mtetra
.556 .338 .539 r
.44632 .64751 .45169 .45141 .44907 .64321 .44796 .64899 Mtetra
.594 .309 .454 r
.44796 .64899 .44907 .64321 .4506 .64956 .44961 .65004 Mtetra
.437 0 0 r
.44961 .65004 .4506 .64956 .45224 .65117 .45127 .65036 Mtetra
.604 .771 .96 r
.45127 .65036 .45224 .65117 .45392 .65095 .45295 .65 Mtetra
.656 .753 .921 r
.45295 .65 .45392 .65095 .4556 .65033 .45464 .64948 Mtetra
.639 .771 .943 r
.45464 .64948 .4556 .65033 .45729 .64976 .45632 .64901 Mtetra
.575 .775 .974 r
.45632 .64901 .45729 .64976 .45897 .64952 .45801 .64871 Mtetra
.579 .763 .966 r
.45801 .64871 .45897 .64952 .46066 .64927 .45969 .64842 Mtetra
.594 .757 .956 r
.45969 .64842 .46066 .64927 .46234 .64898 .46138 .6481 Mtetra
.611 .758 .949 r
.46138 .6481 .46234 .64898 .46403 .6486 .46307 .64773 Mtetra
.619 .761 .947 r
.46307 .64773 .46403 .6486 .46572 .6482 .46476 .64734 Mtetra
.575 .748 .959 r
.46476 .64734 .46572 .6482 .46741 .64788 .46645 .64707 Mtetra
.511 .738 .976 r
.46645 .64707 .46741 .64788 .4691 .64766 .46813 .64695 Mtetra
.648 .811 .961 r
.46813 .64695 .4691 .64766 .47079 .64718 .46983 .64642 Mtetra
.843 .815 .822 r
.46983 .64642 .47079 .64718 .4725 .64601 .47155 .64465 Mtetra
.906 .726 .648 r
.47155 .64465 .4725 .64601 .47422 .64341 .47332 .63922 Mtetra
.953 .686 .492 r
.47332 .63922 .47422 .64341 .47597 .63936 .47784 .44269 Mtetra
.564 .349 .546 r
.47784 .44269 .47597 .63936 .47774 .63366 .47951 .43718 Mtetra
.556 .342 .545 r
.47951 .43718 .47774 .63366 .47944 .6322 .48111 .43625 Mtetra
.554 .341 .545 r
.48111 .43625 .47944 .6322 .48112 .63323 .48271 .43611 Mtetra
.554 .34 .545 r
.48271 .43611 .48112 .63323 .48279 .63469 .4843 .43624 Mtetra
.554 .341 .545 r
.4843 .43624 .48279 .63469 .48447 .63555 .4859 .43604 Mtetra
.555 .341 .545 r
.4859 .43604 .48447 .63555 .48617 .63508 .4875 .43562 Mtetra
.556 .342 .545 r
.4875 .43562 .48617 .63508 .48793 .62985 .48911 .43452 Mtetra
.558 .344 .546 r
.48911 .43452 .48793 .62985 .49158 .43748 .49073 .43264 Mtetra
.663 .497 .649 r
.49073 .43264 .49158 .43748 .49323 .43278 .49235 .431 Mtetra
.727 .646 .768 r
.49235 .431 .49323 .43278 .49485 .43053 .49396 .42979 Mtetra
.683 .8 .937 r
.49396 .42979 .49485 .43053 .49646 .42978 .49557 .42918 Mtetra
.624 .822 .977 r
.49557 .42918 .49646 .42978 .49807 .42938 .49718 .42873 Mtetra
.616 .805 .972 r
.49718 .42873 .49807 .42938 .49967 .42909 .49878 .42832 Mtetra
.655 .786 .944 r
.49878 .42832 .49967 .42909 .50128 .42859 .50039 .42781 Mtetra
.655 .785 .943 r
.50039 .42781 .50128 .42859 .50289 .42809 .502 .4273 Mtetra
.656 .782 .941 r
.502 .4273 .50289 .42809 .5045 .42759 .50361 .42679 Mtetra
.658 .78 .939 r
.50361 .42679 .5045 .42759 .50611 .42708 .50523 .42628 Mtetra
.659 .779 .937 r
.50523 .42628 .50611 .42708 .50773 .42657 .50684 .42576 Mtetra
.659 .778 .937 r
.50684 .42576 .50773 .42657 .50934 .42605 .50845 .42524 Mtetra
.66 .778 .936 r
.50845 .42524 .50934 .42605 .51096 .42553 .51007 .42472 Mtetra
.66 .777 .936 r
.51007 .42472 .51096 .42553 .51257 .42501 .51169 .4242 Mtetra
.66 .777 .935 r
.51169 .4242 .51257 .42501 .51419 .4245 .5133 .42367 Mtetra
.66 .776 .935 r
.5133 .42367 .51419 .4245 .5158 .42398 .51492 .42315 Mtetra
.66 .775 .935 r
.51492 .42315 .5158 .42398 .51742 .42346 .51654 .42263 Mtetra
.659 .775 .934 r
.51654 .42263 .51742 .42346 .51904 .42295 .51816 .42211 Mtetra
.659 .773 .934 r
.51816 .42211 .51904 .42295 .52066 .42243 .51978 .42159 Mtetra
.659 .772 .933 r
.51978 .42159 .52066 .42243 .52228 .42193 .5214 .42108 Mtetra
.659 .77 .931 r
.5214 .42108 .52228 .42193 .52391 .42142 .52303 .42056 Mtetra
.66 .767 .929 r
.52303 .42056 .52391 .42142 .52553 .42092 .52465 .42004 Mtetra
.657 .763 .928 r
.52465 .42004 .52553 .42092 .52715 .42043 .52627 .41953 Mtetra
.652 .756 .926 r
.52627 .41953 .52715 .42043 .52878 .41998 .5279 .41904 Mtetra
.636 .743 .925 r
.5279 .41904 .52878 .41998 .53041 .41962 .52953 .41862 Mtetra
.64 .729 .913 r
.52953 .41862 .53041 .41962 .53203 .41925 .53116 .41818 Mtetra
.652 .719 .897 r
.53116 .41818 .53203 .41925 .53366 .41882 .53278 .4177 Mtetra
.68 .72 .879 r
.53278 .4177 .53366 .41882 .53529 .41817 .53441 .41708 Mtetra
.685 .726 .881 r
.53441 .41708 .53529 .41817 .53692 .41749 .53604 .41643 Mtetra
.684 .733 .888 r
.53604 .41643 .53692 .41749 .53855 .41682 .53768 .4158 Mtetra
.668 .735 .9 r
.53768 .4158 .53855 .41682 .54018 .41626 .53931 .41525 Mtetra
.66 .734 .904 r
.53931 .41525 .54018 .41626 .54182 .41575 .54094 .41473 Mtetra
.651 .73 .907 r
.54094 .41473 .54182 .41575 .54345 .41529 .54258 .41425 Mtetra
.634 .719 .909 r
.54258 .41425 .54345 .41529 .54509 .41493 .54421 .41384 Mtetra
.632 .709 .901 r
.54421 .41384 .54509 .41493 .54672 .41458 .54585 .41343 Mtetra
.637 .7 .892 r
.54585 .41343 .54672 .41458 .54836 .4142 .54749 .41301 Mtetra
.654 .7 .88 r
.54749 .41301 .54836 .4142 .55 .41369 .54913 .41251 Mtetra
.664 .705 .878 r
.54913 .41251 .55 .41369 .55164 .41311 .55077 .41197 Mtetra
.674 .715 .879 r
.55077 .41197 .55164 .41311 .55328 .41246 .55241 .41137 Mtetra
.691 .731 .881 r
.55241 .41137 .55328 .41246 .55492 .41171 .55405 .4107 Mtetra
.696 .748 .892 r
.55405 .4107 .55492 .41171 .55656 .41094 .55569 .41001 Mtetra
.696 .764 .905 r
.55569 .41001 .55656 .41094 .5582 .41019 .55733 .40933 Mtetra
.681 .776 .922 r
.55733 .40933 .5582 .41019 .55984 .40954 .55897 .40871 Mtetra
.676 .783 .93 r
.55897 .40871 .55984 .40954 .56148 .40892 .56062 .40812 Mtetra
.673 .787 .935 r
.56062 .40812 .56148 .40892 .56313 .40833 .56226 .40754 Mtetra
.672 .791 .938 r
.56226 .40754 .56313 .40833 .56477 .40773 .56391 .40695 Mtetra
.67 .794 .941 r
.56391 .40695 .56477 .40773 .56642 .40714 .56556 .40638 Mtetra
.668 .796 .943 r
.56556 .40638 .56642 .40714 .56807 .40657 .56721 .40581 Mtetra
.667 .798 .945 r
.56721 .40581 .56807 .40657 .56972 .40599 .56886 .40524 Mtetra
.666 .799 .946 r
.56886 .40524 .56972 .40599 .57137 .40542 .57051 .40467 Mtetra
.665 .8 .947 r
.57051 .40467 .57137 .40542 .57302 .40486 .57216 .40411 Mtetra
.665 .801 .948 r
.57216 .40411 .57302 .40486 .57467 .40429 .57381 .40355 Mtetra
.664 .802 .949 r
.57381 .40355 .57467 .40429 .57632 .40373 .57547 .40299 Mtetra
.663 .803 .95 r
.57547 .40299 .57632 .40373 .57797 .40316 .57712 .40243 Mtetra
.664 .805 .951 r
.57712 .40243 .57797 .40316 .57963 .40259 .57878 .40187 Mtetra
.663 .807 .952 r
.57878 .40187 .57963 .40259 .58128 .40202 .58043 .4013 Mtetra
.662 .809 .954 r
.58043 .4013 .58128 .40202 .58294 .40146 .58209 .40074 Mtetra
.692 .817 .943 r
.58209 .40074 .58294 .40146 .58459 .40066 .58375 .40008 Mtetra
.66 .844 .97 r
.58375 .40008 .58459 .40066 .58625 .40005 .5854 .39949 Mtetra
.593 .831 .989 r
.5854 .39949 .58625 .40005 .58792 .39982 .58707 .39908 Mtetra
.304 .643 .967 r
.58707 .39908 .58792 .39982 .58962 .40131 .58875 .39933 Mtetra
.432 .478 .807 r
.58875 .39933 .58962 .40131 .59137 .40508 .59043 .39991 Mtetra
.509 .388 .65 r
.59043 .39991 .59137 .40508 .59712 .59802 .59212 .40066 Mtetra
.554 .341 .545 r
.59212 .40066 .59712 .59802 .59897 .60106 .5938 .40047 Mtetra
.555 .342 .545 r
.5938 .40047 .59897 .60106 .60074 .60034 .59546 .39986 Mtetra
.59546 .39986 .60074 .60034 .60247 .598 .59713 .39905 Mtetra
.59713 .39905 .60247 .598 .60423 .59708 .59879 .39843 Mtetra
.59879 .39843 .60423 .59708 .606 .59632 .60046 .39783 Mtetra
.60046 .39783 .606 .59632 .60777 .59551 .60213 .39723 Mtetra
.556 .342 .545 r
.60213 .39723 .60777 .59551 .60947 .59229 .60379 .3961 Mtetra
.555 .342 .545 r
.60379 .3961 .60947 .59229 .6112 .58971 .60546 .39534 Mtetra
.554 .341 .545 r
.60546 .39534 .6112 .58971 .61306 .59247 .60715 .3954 Mtetra
.542 .332 .544 r
.60715 .3954 .61306 .59247 .61503 .59927 .609 .40173 Mtetra
0 0 .403 r
.609 .40173 .61503 .59927 .61691 .60234 .61594 .59884 Mtetra
0 .029 .573 r
.61594 .59884 .61691 .60234 .61875 .60386 .61785 .60271 Mtetra
.395 .603 .931 r
.61785 .60271 .61875 .60386 .62055 .6038 .61966 .60303 Mtetra
.662 .811 .955 r
.61966 .60303 .62055 .6038 .62234 .60317 .62145 .60242 Mtetra
.754 .838 .915 r
.62145 .60242 .62234 .60317 .62412 .60226 .62322 .6014 Mtetra
.715 .804 .92 r
.62322 .6014 .62412 .60226 .6259 .6014 .62501 .60058 Mtetra
.71 .811 .928 r
.62501 .60058 .6259 .6014 .62768 .60053 .62679 .59978 Mtetra
.711 .829 .938 r
.62679 .59978 .62768 .60053 .62946 .59966 .62858 .59897 Mtetra
.687 .839 .956 r
.62858 .59897 .62946 .59966 .63125 .59893 .63037 .59826 Mtetra
.671 .838 .963 r
.63037 .59826 .63125 .59893 .63304 .5983 .63216 .59759 Mtetra
.662 .829 .963 r
.63216 .59759 .63304 .5983 .63484 .59772 .63396 .59697 Mtetra
.661 .816 .958 r
.63396 .59697 .63484 .59772 .63664 .59718 .63575 .59636 Mtetra
.656 .799 .951 r
.63575 .59636 .63664 .59718 .63844 .59667 .63755 .59578 Mtetra
.647 .779 .944 r
.63755 .59578 .63844 .59667 .64024 .59622 .63935 .59525 Mtetra
.635 .757 .936 r
.63935 .59525 .64024 .59622 .64204 .59581 .64115 .59477 Mtetra
.624 .737 .928 r
.64115 .59477 .64204 .59581 .64385 .59545 .64296 .59435 Mtetra
.613 .72 .922 r
.64296 .59435 .64385 .59545 .64566 .59513 .64477 .59398 Mtetra
.552 .683 .926 r
.64477 .59398 .64566 .59513 .64749 .59521 .64659 .59384 Mtetra
.574 .652 .889 r
.64659 .59384 .64749 .59521 .64931 .59516 .64841 .59367 Mtetra
.625 .657 .861 r
.64841 .59367 .64931 .59516 .65112 .59461 .65022 .59327 Mtetra
.753 .726 .828 r
.65022 .59327 .65112 .59461 .65286 .59214 .65201 .59204 Mtetra
.87 .973 .851 r
.65201 .59204 .65286 .59214 .65448 .58667 .65377 .59024 Mtetra
.263 0 .288 r
.65377 .59024 .65448 .58667 .64875 .39061 .65552 .58812 Mtetra
.552 .335 .539 r
.65552 .58812 .64875 .39061 .65033 .38699 .65733 .58763 Mtetra
.553 .336 .539 r
.65733 .58763 .65033 .38699 .65205 .38695 .65916 .58759 Mtetra
.552 .335 .539 r
.65916 .58759 .65205 .38695 .65378 .38691 .66096 .58673 Mtetra
.54 .326 .538 r
.66096 .58673 .65378 .38691 .65534 .38289 .66247 .57862 Mtetra
.002 0 .408 r
.66247 .57862 .65534 .38289 .65693 .37947 .6562 .3809 Mtetra
.859 .86 .407 r
.6562 .3809 .65693 .37947 .65856 .37715 .65774 .37645 Mtetra
.843 .847 .848 r
.65774 .37645 .65856 .37715 .66024 .37601 .65941 .37487 Mtetra
.67 .721 .887 r
.65941 .37487 .66024 .37601 .66194 .37544 .66111 .37428 Mtetra
.589 .684 .907 r
.66111 .37428 .66194 .37544 .66365 .37508 .66283 .37403 Mtetra
.603 .713 .922 r
.66283 .37403 .66365 .37508 .66537 .37474 .66455 .37372 Mtetra
.621 .728 .923 r
.66455 .37372 .66537 .37474 .66709 .37438 .66626 .37333 Mtetra
.626 .725 .917 r
.66626 .37333 .66709 .37438 .6688 .37398 .66798 .37293 Mtetra
.659 .736 .906 r
.66798 .37293 .6688 .37398 .67051 .37339 .66969 .37239 Mtetra
.68 .753 .907 r
.66969 .37239 .67051 .37339 .67221 .37268 .6714 .37175 Mtetra
.685 .773 .918 r
.6714 .37175 .67221 .37268 .67392 .37195 .67311 .3711 Mtetra
.67 .787 .936 r
.67311 .3711 .67392 .37195 .67563 .3713 .67482 .3705 Mtetra
.658 .795 .948 r
.67482 .3705 .67563 .3713 .67734 .37072 .67653 .36995 Mtetra
.653 .8 .953 r
.67653 .36995 .67734 .37072 .67906 .37017 .67825 .36941 Mtetra
.679 .81 .946 r
.67825 .36941 .67906 .37017 .68076 .36943 .67996 .36877 Mtetra
.673 .835 .961 r
.67996 .36877 .68076 .36943 .68247 .36873 .68168 .36813 Mtetra
.617 .837 .984 r
.68168 .36813 .68247 .36873 .6842 .36835 .6834 .36764 Mtetra
.412 .715 .986 r
.6834 .36764 .6842 .36835 .68599 .36923 .68515 .36768 Mtetra
.4 .517 .861 r
.68515 .36768 .68599 .36923 .6879 .37228 .68693 .36822 Mtetra
.491 .402 .682 r
.68693 .36822 .6879 .37228 .69944 .56204 .68872 .36902 Mtetra
.554 .34 .545 r
.68872 .36902 .69944 .56204 .70182 .57206 .69049 .36926 Mtetra
.555 .341 .545 r
.69049 .36926 .70182 .57206 .70368 .57195 .69222 .36875 Mtetra
.555 .342 .545 r
.69222 .36875 .70368 .57195 .70546 .5704 .69393 .36796 Mtetra
.69393 .36796 .70546 .5704 .70726 .56908 .69565 .36723 Mtetra
.69565 .36723 .70726 .56908 .70909 .56839 .69738 .3666 Mtetra
.555 .341 .545 r
.69738 .3666 .70909 .56839 .71092 .56767 .6991 .36599 Mtetra
.556 .342 .545 r
.6991 .36599 .71092 .56767 .7127 .56603 .70081 .36498 Mtetra
.70081 .36498 .7127 .56603 .71447 .56411 .70252 .36401 Mtetra
.554 .341 .545 r
.70252 .36401 .71447 .56411 .71637 .5645 .70427 .36378 Mtetra
.548 .336 .545 r
.70427 .36378 .71637 .5645 .71849 .5688 .70623 .36725 Mtetra
.045 0 .438 r
.70623 .36725 .71849 .5688 .72056 .57211 .71947 .56705 Mtetra
.03 .073 .572 r
.71947 .56705 .72056 .57211 .72255 .57385 .72165 .57218 Mtetra
.229 .412 .836 r
.72165 .57218 .72255 .57385 .72445 .57424 .72361 .57332 Mtetra
.605 .763 .955 r
.72361 .57332 .72445 .57424 .72632 .57376 .72547 .57292 Mtetra
.712 .817 .93 r
.72547 .57292 .72632 .57376 .72816 .57303 .72732 .57209 Mtetra
.7 .791 .921 r
.72732 .57209 .72816 .57303 .73001 .57234 .72916 .57131 Mtetra
.659 .757 .922 r
.72916 .57131 .73001 .57234 .73187 .57177 .73102 .57072 Mtetra
.664 .755 .918 r
.73102 .57072 .73187 .57177 .73373 .57118 .73288 .5701 Mtetra
.677 .755 .91 r
.73288 .5701 .73373 .57118 .73558 .5705 .73473 .56943 Mtetra
.685 .76 .908 r
.73473 .56943 .73558 .5705 .73743 .56976 .73659 .56871 Mtetra
.679 .763 .915 r
.73659 .56871 .73743 .56976 .73929 .56906 .73844 .56803 Mtetra
.647 .755 .928 r
.73844 .56803 .73929 .56906 .74116 .56856 .74031 .56749 Mtetra
.612 .733 .932 r
.74031 .56749 .74116 .56856 .74304 .56825 .74219 .5671 Mtetra
.607 .713 .92 r
.74219 .5671 .74304 .56825 .74493 .56798 .74407 .56674 Mtetra
.553 .672 .917 r
.74407 .56674 .74493 .56798 .74683 .56789 .74597 .56661 Mtetra
.549 .662 .911 r
.74597 .56661 .74683 .56789 .74873 .56779 .74787 .56651 Mtetra
.672 .718 .883 r
.74787 .56651 .74873 .56779 .75059 .56712 .74973 .56585 Mtetra
.871 .77 .748 r
.74973 .56585 .75059 .56712 .75233 .56453 .75147 .5632 Mtetra
.968 .731 .525 r
.75147 .5632 .75233 .56453 .75356 .55444 .75262 .55197 Mtetra
.976 .682 .392 r
.75262 .55197 .75356 .55444 .74171 .35297 .7409 .35173 Mtetra
.899 .765 .704 r
.7409 .35173 .74171 .35297 .74327 .34961 .74248 .34849 Mtetra
.711 .746 .88 r
.74248 .34849 .74327 .34961 .74501 .34877 .74422 .34767 Mtetra
.588 .701 .921 r
.74422 .34767 .74501 .34877 .74679 .3485 .74599 .34741 Mtetra
.645 .727 .909 r
.74599 .34741 .74679 .3485 .74855 .348 .74776 .34692 Mtetra
.734 .761 .875 r
.74776 .34692 .74855 .348 .75028 .34704 .74949 .34597 Mtetra
.636 .727 .914 r
.74949 .34597 .75028 .34704 .75205 .34659 .75126 .34551 Mtetra
0 .304 .796 r
.75126 .34551 .75205 .34659 .75395 .3479 .75316 .34683 Mtetra
.951 .602 .227 r
.75316 .34683 .75395 .3479 .75672 .36121 .75593 .3601 Mtetra
.975 .673 .363 r
.75593 .3601 .75672 .36121 .77291 .55707 .77208 .55607 Mtetra
0 0 .452 r
.77208 .55607 .77291 .55707 .77502 .55964 .7742 .55863 Mtetra
.453 .673 .958 r
.7742 .55863 .77502 .55964 .77696 .55974 .77614 .55873 Mtetra
.728 .79 .901 r
.77614 .55873 .77696 .55974 .77882 .5588 .778 .55778 Mtetra
.9 .81 .75 r
.778 .55778 .77882 .5588 .78055 .55603 .77972 .555 Mtetra
.978 .745 .516 r
.77972 .555 .78055 .55603 .78168 .54544 .78085 .54431 Mtetra
.977 .681 .376 r
.78085 .54431 .78168 .54544 .76816 .34435 .76738 .34326 Mtetra
.921 .785 .693 r
.76738 .34326 .76816 .34435 .76971 .34086 .76893 .33978 Mtetra
.718 .758 .884 r
.76893 .33978 .76971 .34086 .77146 .34 .77068 .33892 Mtetra
.591 .708 .925 r
.77068 .33892 .77146 .34 .77325 .33972 .77247 .33864 Mtetra
.618 .721 .92 r
.77247 .33864 .77325 .33972 .77504 .33932 .77426 .33825 Mtetra
.734 .768 .88 r
.77426 .33825 .77504 .33932 .77678 .33836 .77601 .3373 Mtetra
.637 .734 .919 r
.77601 .3373 .77678 .33836 .77857 .33788 .77779 .33684 Mtetra
.013 .368 .837 r
.77779 .33684 .77857 .33788 .78049 .33903 .77971 .33798 Mtetra
.946 .594 .208 r
.77971 .33798 .78049 .33903 .78343 .35279 .78261 .35113 Mtetra
.976 .671 .347 r
.78261 .35113 .78343 .35279 .80137 .54918 .80055 .54806 Mtetra
0 0 .491 r
.80055 .54806 .80137 .54918 .80354 .55183 .80272 .55073 Mtetra
.492 .674 .945 r
.80272 .55073 .80354 .55183 .8055 .55182 .80468 .55076 Mtetra
.74 .785 .889 r
.80468 .55076 .8055 .55182 .80736 .55076 .80655 .54972 Mtetra
.901 .811 .751 r
.80655 .54972 .80736 .55076 .80908 .54794 .80828 .54695 Mtetra
.982 .743 .499 r
.80828 .54695 .80908 .54794 .81003 .53597 .80927 .53551 Mtetra
.978 .679 .36 r
.80927 .53551 .81003 .53597 .7948 .33504 .79405 .33409 Mtetra
.941 .804 .68 r
.79405 .33409 .7948 .33504 .79633 .33139 .79557 .33038 Mtetra
.771 .793 .871 r
.79557 .33038 .79633 .33139 .79807 .33026 .79731 .32922 Mtetra
.57 .709 .936 r
.79731 .32922 .79807 .33026 .79989 .33007 .79913 .329 Mtetra
0 .346 .824 r
.79913 .329 .79989 .33007 .80185 .33138 .80108 .33024 Mtetra
.898 .515 .069 r
.80108 .33024 .80185 .33138 .80445 .34 .80363 .3383 Mtetra
.975 .668 .335 r
.80363 .3383 .80445 .34 .82428 .54202 .82346 .54076 Mtetra
0 0 .432 r
.82346 .54076 .82428 .54202 .82654 .5452 .82572 .54401 Mtetra
.429 .621 .932 r
.82572 .54401 .82654 .5452 .82854 .54547 .82772 .54428 Mtetra
.695 .747 .891 r
.82772 .54428 .82854 .54547 .83044 .5447 .82962 .54348 Mtetra
.86 .787 .779 r
.82962 .54348 .83044 .5447 .83222 .54247 .83139 .5412 Mtetra
.969 .755 .56 r
.83139 .5412 .83222 .54247 .83352 .53512 .83267 .53351 Mtetra
.977 .675 .352 r
.83267 .53351 .83352 .53512 .81649 .32967 .81571 .32841 Mtetra
.94 .768 .64 r
.81571 .32841 .81649 .32967 .81791 .32493 .81715 .32381 Mtetra
.799 .781 .837 r
.81715 .32381 .81791 .32493 .81963 .32348 .81887 .32238 Mtetra
.636 .727 .914 r
.81887 .32238 .81963 .32348 .82144 .32301 .82068 .32191 Mtetra
.222 .498 .902 r
.82068 .32191 .82144 .32301 .82337 .32378 .82262 .32268 Mtetra
.791 .373 0 r
.82262 .32268 .82337 .32378 .82571 .3288 .82496 .3277 Mtetra
.974 .665 .325 r
.82496 .3277 .82571 .3288 .84716 .53266 .84637 .53165 Mtetra
.742 .301 0 r
.84637 .53165 .84716 .53266 .84956 .53696 .84877 .53595 Mtetra
.512 .704 .957 r
.84877 .53595 .84956 .53696 .85155 .53688 .85076 .53587 Mtetra
.71 .792 .915 r
.85076 .53587 .85155 .53688 .85346 .536 .85267 .53501 Mtetra
.763 .81 .891 r
.85267 .53501 .85346 .536 .85534 .53483 .85456 .53384 Mtetra
.664 .779 .935 r
.85456 .53384 .85534 .53483 .85728 .5342 .85649 .5332 Mtetra
.658 .775 .935 r
.85649 .5332 .85728 .5342 .85922 .5336 .85843 .53258 Mtetra
.648 .767 .936 r
.85843 .53258 .85922 .5336 .86116 .53305 .86038 .53201 Mtetra
.629 .755 .938 r
.86038 .53201 .86116 .53305 .86312 .53258 .86233 .53152 Mtetra
.618 .745 .937 r
.86233 .53152 .86312 .53258 .86508 .53217 .86429 .53108 Mtetra
.586 .723 .938 r
.86429 .53108 .86508 .53217 .86706 .53191 .86627 .53077 Mtetra
.43 .632 .939 r
.86627 .53077 .86706 .53191 .8691 .53222 .8683 .531 Mtetra
.588 .699 .919 r
.8683 .531 .8691 .53222 .87109 .532 .87028 .53071 Mtetra
.781 .764 .838 r
.87028 .53071 .87109 .532 .87296 .53064 .87215 .52928 Mtetra
.969 .755 .558 r
.87215 .52928 .87296 .53064 .87422 .52345 .87338 .52177 Mtetra
.976 .671 .331 r
.87338 .52177 .87422 .52345 .85459 .31732 .85383 .3161 Mtetra
.95 .775 .629 r
.85383 .3161 .85459 .31732 .85596 .3124 .85522 .31133 Mtetra
.731 .774 .888 r
.85522 .31133 .85596 .3124 .85775 .31147 .85701 .31039 Mtetra
.58 .708 .93 r
.85701 .31039 .85775 .31147 .85962 .31125 .85887 .31013 Mtetra
.488 .654 .933 r
.85887 .31013 .85962 .31125 .86152 .31135 .86077 .3102 Mtetra
.647 .724 .905 r
.86077 .3102 .86152 .31135 .86335 .31082 .86261 .30968 Mtetra
.657 .73 .903 r
.86261 .30968 .86335 .31082 .86519 .31024 .86445 .30911 Mtetra
.671 .74 .902 r
.86445 .30911 .86519 .31024 .86701 .30958 .86627 .30848 Mtetra
.758 .777 .869 r
.86627 .30848 .86701 .30958 .86878 .30845 .86805 .30736 Mtetra
.692 .755 .9 r
.86805 .30736 .86878 .30845 .8706 .30771 .86987 .30662 Mtetra
.486 .659 .937 r
.86987 .30662 .8706 .30771 .87251 .30777 .87178 .30668 Mtetra
.758 .339 0 r
.87178 .30668 .87251 .30777 .87496 .31271 .87424 .31167 Mtetra
.971 .656 .295 r
.87424 .31167 .87496 .31271 .89987 .51756 .89911 .51655 Mtetra
.742 .306 0 r
.89911 .51655 .89987 .51756 .90244 .52231 .90167 .52127 Mtetra
.297 .576 .937 r
.90167 .52127 .90244 .52231 .90454 .52285 .90377 .5218 Mtetra
.647 .764 .934 r
.90377 .5218 .90454 .52285 .90652 .52228 .90575 .52123 Mtetra
.828 .821 .842 r
.90575 .52123 .90652 .52228 .90836 .52058 .9076 .51953 Mtetra
.908 .736 .657 r
.27269 .70168 .27372 .70252 .27566 .69697 .27463 .69613 Mtetra
.936 .686 .535 r
.27463 .69613 .27566 .69697 .29095 .50158 .28999 .50068 Mtetra
.907 .727 .648 r
.28999 .50068 .29095 .50158 .29281 .49586 .29185 .49496 Mtetra
.772 .759 .841 r
.29185 .49496 .29281 .49586 .29435 .49474 .29338 .49384 Mtetra
.64 .735 .918 r
.29338 .49384 .29435 .49474 .29583 .49434 .29487 .49344 Mtetra
.511 .692 .95 r
.29487 .49344 .29583 .49434 .29729 .4943 .29633 .4934 Mtetra
.749 .757 .859 r
.29633 .4934 .29729 .4943 .29882 .49337 .29786 .49246 Mtetra
.696 .749 .892 r
.29786 .49246 .29882 .49337 .30032 .49273 .29936 .49183 Mtetra
.484 .68 .952 r
.29936 .49183 .30032 .49273 .30178 .49275 .30082 .49185 Mtetra
.927 .546 .249 r
.30082 .49185 .30178 .49275 .30298 .49676 .30202 .49583 Mtetra
.939 .683 .523 r
.30202 .49583 .30298 .49676 .29152 .69131 .2905 .69041 Mtetra
.937 .584 .325 r
.2905 .69041 .29152 .69131 .29272 .69665 .2917 .69578 Mtetra
.246 .586 .946 r
.2917 .69578 .29272 .69665 .29425 .69713 .29323 .69616 Mtetra
.663 .74 .907 r
.29323 .69616 .29425 .69713 .29584 .69664 .29482 .69564 Mtetra
.735 .749 .863 r
.29482 .69564 .29584 .69664 .29747 .69559 .29644 .69472 Mtetra
.465 .696 .968 r
.29644 .69472 .29747 .69559 .29908 .69471 .298 .69474 Mtetra
.208 .734 .815 r
.298 .69474 .29908 .69471 .30073 .69341 .29958 .6945 Mtetra
0 0 0 r
.29958 .6945 .30073 .69341 .30243 .69118 .3012 .69358 Mtetra
.881 .892 .469 r
.3012 .69358 .30243 .69118 .30459 .68179 .30307 .68885 Mtetra
.949 .698 .522 r
.30307 .68885 .30459 .68179 .31804 .49131 .31689 .49334 Mtetra
.995 .867 .556 r
.31689 .49334 .31804 .49131 .31976 .48733 .3188 .48653 Mtetra
.811 .781 .826 r
.3188 .48653 .31976 .48733 .32131 .48615 .32036 .48511 Mtetra
.655 .711 .889 r
.32036 .48511 .32131 .48615 .32281 .48569 .32187 .48465 Mtetra
.54 .671 .922 r
.32187 .48465 .32281 .48569 .3243 .48553 .32335 .48458 Mtetra
.735 .748 .863 r
.32335 .48458 .3243 .48553 .32583 .48464 .32488 .48371 Mtetra
.707 .748 .884 r
.32488 .48371 .32583 .48464 .32735 .48394 .3264 .48302 Mtetra
.527 .694 .945 r
.3264 .48302 .32735 .48394 .32884 .48386 .32789 .48294 Mtetra
.907 .497 .16 r
.32789 .48294 .32884 .48386 .33012 .48723 .32917 .48631 Mtetra
.942 .683 .517 r
.32917 .48631 .33012 .48723 .32024 .68186 .31923 .68098 Mtetra
.941 .597 .345 r
.31923 .68098 .32024 .68186 .32146 .68806 .32044 .68719 Mtetra
.017 .446 .869 r
.32044 .68719 .32146 .68806 .32299 .68882 .32198 .68786 Mtetra
.651 .741 .915 r
.32198 .68786 .32299 .68882 .32459 .68839 .32359 .68738 Mtetra
.733 .75 .866 r
.32359 .68738 .32459 .68839 .32623 .68737 .32522 .68648 Mtetra
.522 .713 .959 r
.32522 .68648 .32623 .68737 .32787 .68646 .32681 .68638 Mtetra
.249 .756 .874 r
.32681 .68638 .32787 .68646 .32952 .68521 .3284 .68619 Mtetra
0 0 0 r
.3284 .68619 .32952 .68521 .33122 .68311 .33003 .68535 Mtetra
.815 .875 .438 r
.33003 .68535 .33122 .68311 .33321 .67563 .33185 .68122 Mtetra
.951 .697 .517 r
.33185 .68122 .33321 .67563 .34525 .48309 .34409 .48624 Mtetra
.978 .858 .47 r
.34409 .48624 .34525 .48309 .34699 .4787 .34603 .478 Mtetra
.84 .797 .81 r
.34603 .478 .34699 .4787 .34855 .47735 .34762 .4763 Mtetra
.656 .712 .889 r
.34762 .4763 .34855 .47735 .35008 .47688 .34914 .47583 Mtetra
.53 .665 .923 r
.34914 .47583 .35008 .47688 .35158 .47675 .35064 .47579 Mtetra
.631 .724 .914 r
.35064 .47579 .35158 .47675 .3531 .47624 .35216 .47541 Mtetra
.672 .765 .92 r
.35216 .47541 .3531 .47624 .35463 .47565 .35368 .47488 Mtetra
.677 .781 .928 r
.35368 .47488 .35463 .47565 .35616 .47519 .35521 .47433 Mtetra
.754 .771 .867 r
.35521 .47433 .35616 .47519 .35767 .47495 .35676 .47336 Mtetra
.695 .646 .796 r
.35676 .47336 .35767 .47495 .35917 .47511 .35831 .47255 Mtetra
.593 .518 .739 r
.35831 .47255 .35917 .47511 .36062 .47605 .35982 .47233 Mtetra
.091 .129 .608 r
.35982 .47233 .36062 .47605 .36183 .48204 .36119 .47502 Mtetra
.954 .693 .502 r
.36119 .47502 .36183 .48204 .35395 .67425 .35314 .66936 Mtetra
.728 .499 0 r
.35314 .66936 .35395 .67425 .35536 .6781 .35436 .6771 Mtetra
0 .262 .748 r
.35436 .6771 .35536 .6781 .35693 .67883 .35592 .67816 Mtetra
.614 .802 .972 r
.35592 .67816 .35693 .67883 .35855 .67846 .35754 .67775 Mtetra
.74 .816 .911 r
.35754 .67775 .35855 .67846 .3602 .67758 .35919 .67687 Mtetra
.687 .808 .94 r
.35919 .67687 .3602 .67758 .36186 .67632 .36082 .67623 Mtetra
.481 .882 .953 r
.36082 .67623 .36186 .67632 .36354 .67476 .36245 .67576 Mtetra
.202 0 0 r
.36245 .67576 .36354 .67476 .36523 .67301 .36409 .67529 Mtetra
.478 .117 .275 r
.36409 .67529 .36523 .67301 .36686 .67247 .3657 .67516 Mtetra
.48 .138 .309 r
.3657 .67516 .36686 .67247 .36847 .67241 .36732 .67495 Mtetra
.375 .03 .246 r
.36732 .67495 .36847 .67241 .37012 .67168 .36897 .6742 Mtetra
0 0 0 r
.36897 .6742 .37012 .67168 .37197 .66616 .37072 .6711 Mtetra
.984 .821 .426 r
.37072 .6711 .37197 .66616 .38202 .47157 .37294 .65719 Mtetra
0 0 .272 r
.37294 .65719 .38202 .47157 .38376 .46654 .38274 .46759 Mtetra
.875 .963 .632 r
.38274 .46759 .38376 .46654 .38535 .46491 .38438 .4649 Mtetra
.741 .97 .93 r
.38438 .4649 .38535 .46491 .38689 .46445 .38594 .46391 Mtetra
.653 .835 .97 r
.38594 .46391 .38689 .46445 .38842 .46437 .38749 .46339 Mtetra
.656 .73 .904 r
.38749 .46339 .38842 .46437 .38995 .46411 .38903 .46291 Mtetra
.654 .688 .869 r
.38903 .46291 .38995 .46411 .3915 .46364 .39058 .46244 Mtetra
.641 .681 .872 r
.39058 .46244 .3915 .46364 .39305 .46313 .39212 .46202 Mtetra
.645 .699 .885 r
.39212 .46202 .39305 .46313 .3946 .46255 .39367 .46159 Mtetra
.652 .733 .909 r
.39367 .46159 .3946 .46255 .39615 .46191 .39522 .46113 Mtetra
.652 .774 .938 r
.39522 .46113 .39615 .46191 .39771 .46127 .39677 .46066 Mtetra
.655 .817 .962 r
.39677 .46066 .39771 .46127 .39926 .4606 .39832 .46015 Mtetra
.65 .86 .98 r
.39832 .46015 .39926 .4606 .40082 .45997 .39987 .4596 Mtetra
.643 .882 .985 r
.39987 .4596 .40082 .45997 .40237 .45949 .40143 .45904 Mtetra
.665 .864 .975 r
.40143 .45904 .40237 .45949 .40391 .45949 .40298 .45846 Mtetra
.681 .727 .884 r
.40298 .45846 .40391 .45949 .40542 .45996 .40454 .45786 Mtetra
.648 .58 .764 r
.40454 .45786 .40542 .45996 .40694 .46066 .4061 .45727 Mtetra
.64 .512 .691 r
.4061 .45727 .40694 .46066 .40848 .46048 .40767 .45646 Mtetra
.628 .488 .672 r
.40767 .45646 .40848 .46048 .41005 .4596 .40923 .45566 Mtetra
.593 .467 .677 r
.40923 .45566 .41005 .4596 .41161 .45924 .41079 .45534 Mtetra
.384 .327 .67 r
.41079 .45534 .41161 .45924 .41305 .46228 .41228 .4568 Mtetra
0 0 .145 r
.41228 .4568 .41305 .46228 .40806 .65686 .41354 .46519 Mtetra
0 0 .307 r
.41354 .46519 .40806 .65686 .40952 .66219 .40862 .65884 Mtetra
.097 .164 .644 r
.40862 .65884 .40952 .66219 .41112 .66347 .41018 .66133 Mtetra
.524 .521 .795 r
.41018 .66133 .41112 .66347 .41277 .66321 .41182 .66151 Mtetra
.625 .618 .823 r
.41182 .66151 .41277 .66321 .41444 .6624 .41348 .66113 Mtetra
.649 .688 .873 r
.41348 .66113 .41444 .6624 .41613 .66113 .41514 .66064 Mtetra
.598 .847 .992 r
.41514 .66064 .41613 .66113 .41783 .65946 .4168 .66019 Mtetra
.06 0 0 r
.4168 .66019 .41783 .65946 .41954 .65748 .41847 .65966 Mtetra
.39 .025 .219 r
.41847 .65966 .41954 .65748 .42123 .65592 .42013 .65911 Mtetra
.449 .127 .326 r
.42013 .65911 .42123 .65592 .4229 .65526 .4218 .65856 Mtetra
.452 .133 .334 r
.4218 .65856 .4229 .65526 .42456 .65492 .42347 .658 Mtetra
.446 .12 .319 r
.42347 .658 .42456 .65492 .42623 .65455 .42514 .65746 Mtetra
.442 .111 .307 r
.42514 .65746 .42623 .65455 .42789 .65401 .42681 .65694 Mtetra
.444 .113 .309 r
.42681 .65694 .42789 .65401 .42956 .65347 .42848 .65643 Mtetra
.445 .114 .311 r
.42848 .65643 .42956 .65347 .43123 .65293 .43015 .65591 Mtetra
.445 .116 .313 r
.43015 .65591 .43123 .65293 .43291 .65237 .43183 .65539 Mtetra
.446 .118 .315 r
.43183 .65539 .43291 .65237 .43458 .65181 .4335 .65487 Mtetra
.447 .121 .318 r
.4335 .65487 .43458 .65181 .43625 .65124 .43518 .65434 Mtetra
.448 .123 .321 r
.43518 .65434 .43625 .65124 .43793 .65067 .43685 .6538 Mtetra
.449 .125 .323 r
.43685 .6538 .43793 .65067 .43961 .65004 .43853 .65326 Mtetra
.45 .129 .329 r
.43853 .65326 .43961 .65004 .44129 .64912 .44021 .65271 Mtetra
.46 .15 .351 r
.44021 .65271 .44129 .64912 .44298 .64788 .44189 .65214 Mtetra
.478 .182 .384 r
.44189 .65214 .44298 .64788 .44467 .647 .44357 .65159 Mtetra
.488 .197 .397 r
.44357 .65159 .44467 .647 .44632 .64751 .44525 .65108 Mtetra
.473 .161 .356 r
.44525 .65108 .44632 .64751 .44796 .64899 .44693 .65063 Mtetra
.364 0 .131 r
.44693 .65063 .44796 .64899 .44961 .65004 .44862 .65019 Mtetra
.239 .754 .766 r
.44862 .65019 .44961 .65004 .45127 .65036 .4503 .64978 Mtetra
.594 .824 .987 r
.4503 .64978 .45127 .65036 .45295 .65 .45198 .64937 Mtetra
.626 .821 .975 r
.45198 .64937 .45295 .65 .45464 .64948 .45367 .64889 Mtetra
.683 .846 .961 r
.45367 .64889 .45464 .64948 .45632 .64901 .45536 .64822 Mtetra
.742 .807 .904 r
.45536 .64822 .45632 .64901 .45801 .64871 .45705 .6473 Mtetra
.718 .692 .824 r
.45705 .6473 .45801 .64871 .45969 .64842 .45875 .64633 Mtetra
.668 .602 .773 r
.45875 .64633 .45969 .64842 .46138 .6481 .46045 .64557 Mtetra
.616 .545 .751 r
.46045 .64557 .46138 .6481 .46307 .64773 .46213 .64516 Mtetra
.605 .536 .75 r
.46213 .64516 .46307 .64773 .46476 .64734 .46382 .64484 Mtetra
.578 .526 .76 r
.46382 .64484 .46476 .64734 .46645 .64707 .46551 .64472 Mtetra
.558 .525 .774 r
.46551 .64472 .46645 .64707 .46813 .64695 .46719 .64474 Mtetra
.641 .58 .77 r
.46719 .64474 .46813 .64695 .46983 .64642 .46889 .64417 Mtetra
.784 .645 .709 r
.46889 .64417 .46983 .64642 .47155 .64465 .47062 .64171 Mtetra
.934 .683 .535 r
.47062 .64171 .47155 .64465 .47332 .63922 .47272 .61455 Mtetra
.923 .656 .514 r
.47272 .61455 .47332 .63922 .47784 .44269 .47701 .43631 Mtetra
.691 .499 .623 r
.47701 .43631 .47784 .44269 .47951 .43718 .47865 .43323 Mtetra
.629 .491 .675 r
.47865 .43323 .47951 .43718 .48111 .43625 .48025 .43242 Mtetra
.591 .469 .682 r
.48025 .43242 .48111 .43625 .48271 .43611 .48185 .43212 Mtetra
.581 .458 .678 r
.48185 .43212 .48271 .43611 .4843 .43624 .48345 .43194 Mtetra
.6 .464 .667 r
.48345 .43194 .4843 .43624 .4859 .43604 .48505 .43148 Mtetra
.597 .457 .661 r
.48505 .43148 .4859 .43604 .4875 .43562 .48665 .43102 Mtetra
.597 .456 .66 r
.48665 .43102 .4875 .43562 .48911 .43452 .48825 .43058 Mtetra
.603 .474 .678 r
.48825 .43058 .48911 .43452 .49073 .43264 .48985 .43012 Mtetra
.623 .541 .741 r
.48985 .43012 .49073 .43264 .49235 .431 .49146 .42965 Mtetra
.652 .669 .853 r
.49146 .42965 .49235 .431 .49396 .42979 .49307 .42916 Mtetra
.657 .822 .963 r
.49307 .42916 .49396 .42979 .49557 .42918 .49467 .42862 Mtetra
.654 .842 .972 r
.49467 .42862 .49557 .42918 .49718 .42873 .49628 .42807 Mtetra
.66 .817 .959 r
.49628 .42807 .49718 .42873 .49878 .42832 .49789 .42753 Mtetra
.66 .783 .94 r
.49789 .42753 .49878 .42832 .50039 .42781 .4995 .427 Mtetra
.659 .779 .937 r
.4995 .427 .50039 .42781 .502 .4273 .50111 .42649 Mtetra
.659 .776 .936 r
.50111 .42649 .502 .4273 .50361 .42679 .50272 .42597 Mtetra
.661 .775 .934 r
.50272 .42597 .50361 .42679 .50523 .42628 .50434 .42544 Mtetra
.661 .773 .933 r
.50434 .42544 .50523 .42628 .50684 .42576 .50595 .42492 Mtetra
.661 .772 .932 r
.50595 .42492 .50684 .42576 .50845 .42524 .50757 .4244 Mtetra
.50757 .4244 .50845 .42524 .51007 .42472 .50918 .42388 Mtetra
.661 .771 .931 r
.50918 .42388 .51007 .42472 .51169 .4242 .5108 .42335 Mtetra
.5108 .42335 .51169 .4242 .5133 .42367 .51242 .42283 Mtetra
.661 .77 .931 r
.51242 .42283 .5133 .42367 .51492 .42315 .51404 .4223 Mtetra
.661 .77 .93 r
.51404 .4223 .51492 .42315 .51654 .42263 .51566 .42178 Mtetra
.661 .769 .93 r
.51566 .42178 .51654 .42263 .51816 .42211 .51728 .42126 Mtetra
.661 .768 .929 r
.51728 .42126 .51816 .42211 .51978 .42159 .5189 .42073 Mtetra
.661 .767 .928 r
.5189 .42073 .51978 .42159 .5214 .42108 .52052 .4202 Mtetra
.662 .765 .927 r
.52052 .4202 .5214 .42108 .52303 .42056 .52214 .41968 Mtetra
.662 .763 .925 r
.52214 .41968 .52303 .42056 .52465 .42004 .52377 .41915 Mtetra
.663 .761 .923 r
.52377 .41915 .52465 .42004 .52627 .41953 .52539 .41862 Mtetra
.666 .757 .919 r
.52539 .41862 .52627 .41953 .5279 .41904 .52702 .41807 Mtetra
.677 .748 .905 r
.52702 .41807 .5279 .41904 .52953 .41862 .52865 .41748 Mtetra
.664 .711 .883 r
.52865 .41748 .52953 .41862 .53116 .41818 .53028 .41694 Mtetra
.638 .682 .875 r
.53028 .41694 .53116 .41818 .53278 .4177 .53191 .41652 Mtetra
.559 .661 .905 r
.53191 .41652 .53278 .4177 .53441 .41708 .53354 .4164 Mtetra
.449 .736 .989 r
.53354 .4164 .53441 .41708 .53604 .41643 .53517 .41636 Mtetra
.122 .67 .808 r
.53517 .41636 .53604 .41643 .53768 .4158 .53681 .41629 Mtetra
.059 0 0 r
.53681 .41629 .53768 .4158 .53931 .41525 .53844 .41592 Mtetra
.053 0 0 r
.53844 .41592 .53931 .41525 .54094 .41473 .54008 .41538 Mtetra
0 0 0 r
.54008 .41538 .54094 .41473 .54258 .41425 .54171 .41464 Mtetra
.483 .88 .716 r
.54171 .41464 .54258 .41425 .54421 .41384 .54334 .41363 Mtetra
.753 .951 .942 r
.54334 .41363 .54421 .41384 .54585 .41343 .54498 .41262 Mtetra
.743 .8 .898 r
.54498 .41262 .54585 .41343 .54749 .41301 .54662 .41171 Mtetra
.669 .685 .856 r
.54662 .41171 .54749 .41301 .54913 .41251 .54825 .41112 Mtetra
.652 .664 .848 r
.54825 .41112 .54913 .41251 .55077 .41197 .54989 .41061 Mtetra
.648 .667 .855 r
.54989 .41061 .55077 .41197 .55241 .41137 .55154 .41013 Mtetra
.664 .693 .867 r
.55154 .41013 .55241 .41137 .55405 .4107 .55318 .40957 Mtetra
.668 .715 .884 r
.55318 .40957 .55405 .4107 .55569 .41001 .55482 .40901 Mtetra
.671 .742 .904 r
.55482 .40901 .55569 .41001 .55733 .40933 .55646 .40844 Mtetra
.671 .767 .922 r
.55646 .40844 .55733 .40933 .55897 .40871 .55811 .40786 Mtetra
.671 .777 .929 r
.55811 .40786 .55897 .40871 .56062 .40812 .55975 .40729 Mtetra
.67 .782 .933 r
.55975 .40729 .56062 .40812 .56226 .40754 .5614 .40672 Mtetra
.669 .784 .935 r
.5614 .40672 .56226 .40754 .56391 .40695 .56305 .40615 Mtetra
.668 .787 .937 r
.56305 .40615 .56391 .40695 .56556 .40638 .5647 .40558 Mtetra
.667 .789 .939 r
.5647 .40558 .56556 .40638 .56721 .40581 .56635 .40502 Mtetra
.667 .791 .941 r
.56635 .40502 .56721 .40581 .56886 .40524 .568 .40445 Mtetra
.666 .792 .942 r
.568 .40445 .56886 .40524 .57051 .40467 .56965 .40389 Mtetra
.665 .793 .943 r
.56965 .40389 .57051 .40467 .57216 .40411 .5713 .40333 Mtetra
.664 .794 .944 r
.5713 .40333 .57216 .40411 .57381 .40355 .57295 .40278 Mtetra
.664 .795 .945 r
.57295 .40278 .57381 .40355 .57547 .40299 .57461 .40222 Mtetra
.663 .796 .946 r
.57461 .40222 .57547 .40299 .57712 .40243 .57626 .40167 Mtetra
.663 .797 .946 r
.57626 .40167 .57712 .40243 .57878 .40187 .57792 .40111 Mtetra
.662 .798 .948 r
.57792 .40111 .57878 .40187 .58043 .4013 .57958 .40055 Mtetra
.659 .8 .95 r
.57958 .40055 .58043 .4013 .58209 .40074 .58124 .40001 Mtetra
.65 .801 .955 r
.58124 .40001 .58209 .40074 .58375 .40008 .5829 .39949 Mtetra
.636 .838 .978 r
.5829 .39949 .58375 .40008 .5854 .39949 .58456 .39898 Mtetra
.63 .855 .985 r
.58456 .39898 .5854 .39949 .58707 .39908 .58622 .39845 Mtetra
.661 .833 .966 r
.58622 .39845 .58707 .39908 .58875 .39933 .58788 .39787 Mtetra
.664 .661 .837 r
.58788 .39787 .58875 .39933 .59043 .39991 .58954 .39727 Mtetra
.634 .543 .734 r
.58954 .39727 .59043 .39991 .59212 .40066 .59121 .39667 Mtetra
.611 .48 .678 r
.59121 .39667 .59212 .40066 .5938 .40047 .59287 .39609 Mtetra
.607 .468 .667 r
.59287 .39609 .5938 .40047 .59546 .39986 .59454 .39552 Mtetra
.607 .469 .668 r
.59454 .39552 .59546 .39986 .59713 .39905 .5962 .39494 Mtetra
.61 .476 .674 r
.5962 .39494 .59713 .39905 .59879 .39843 .59787 .39436 Mtetra
.61 .477 .675 r
.59787 .39436 .59879 .39843 .60046 .39783 .59954 .39379 Mtetra
.61 .478 .676 r
.59954 .39379 .60046 .39783 .60213 .39723 .60121 .39322 Mtetra
.634 .494 .674 r
.60121 .39322 .60213 .39723 .60379 .3961 .60287 .39231 Mtetra
.621 .491 .683 r
.60287 .39231 .60379 .3961 .60546 .39534 .60454 .39162 Mtetra
.577 .465 .69 r
.60454 .39162 .60546 .39534 .60715 .3954 .60623 .39149 Mtetra
.209 .216 .647 r
.60623 .39149 .60715 .3954 .609 .40173 .60798 .39421 Mtetra
.977 .691 .414 r
.60798 .39421 .609 .40173 .61594 .59884 .61483 .58978 Mtetra
0 0 .446 r
.61483 .58978 .61594 .59884 .61785 .60271 .6169 .59992 Mtetra
.463 .444 .751 r
.6169 .59992 .61785 .60271 .61966 .60303 .61872 .60061 Mtetra
.642 .571 .76 r
.61872 .60061 .61966 .60303 .62145 .60242 .62051 .59998 Mtetra
.687 .593 .745 r
.62051 .59998 .62145 .60242 .62322 .6014 .62228 .59888 Mtetra
.599 .541 .76 r
.62228 .59888 .62322 .6014 .62501 .60058 .62408 .59859 Mtetra
.572 .569 .812 r
.62408 .59859 .62501 .60058 .62679 .59978 .62589 .59849 Mtetra
.57 .665 .902 r
.62589 .59849 .62679 .59978 .62858 .59897 .6277 .59832 Mtetra
.618 .828 .981 r
.6277 .59832 .62858 .59897 .63037 .59826 .62949 .59783 Mtetra
.638 .891 .986 r
.62949 .59783 .63037 .59826 .63216 .59759 .63129 .59717 Mtetra
.662 .899 .98 r
.63129 .59717 .63216 .59759 .63396 .59697 .63308 .59645 Mtetra
.669 .876 .976 r
.63308 .59645 .63396 .59697 .63575 .59636 .63487 .59574 Mtetra
.673 .853 .969 r
.63487 .59574 .63575 .59636 .63755 .59578 .63667 .59506 Mtetra
.671 .826 .958 r
.63667 .59506 .63755 .59578 .63935 .59525 .63847 .59441 Mtetra
.652 .792 .949 r
.63847 .59441 .63935 .59525 .64115 .59477 .64027 .59385 Mtetra
.638 .768 .942 r
.64027 .59385 .64115 .59477 .64296 .59435 .64207 .59336 Mtetra
.628 .749 .934 r
.64207 .59336 .64296 .59435 .64477 .59398 .64388 .59291 Mtetra
.621 .73 .924 r
.64388 .59291 .64477 .59398 .64659 .59384 .64569 .5925 Mtetra
.621 .678 .883 r
.64569 .5925 .64659 .59384 .64841 .59367 .6475 .59212 Mtetra
.618 .645 .854 r
.6475 .59212 .64841 .59367 .65022 .59327 .64932 .59174 Mtetra
.617 .649 .859 r
.64932 .59174 .65022 .59327 .65201 .59204 .65113 .59138 Mtetra
.572 .81 .989 r
.65113 .59138 .65201 .59204 .65377 .59024 .65295 .59101 Mtetra
.195 0 0 r
.65295 .59101 .65377 .59024 .65552 .58812 .65477 .59062 Mtetra
.499 .143 .294 r
.65477 .59062 .65552 .58812 .65733 .58763 .6566 .59059 Mtetra
.488 .153 .325 r
.6566 .59059 .65733 .58763 .65916 .58759 .65843 .59038 Mtetra
.392 .061 .28 r
.65843 .59038 .65916 .58759 .66096 .58673 .66023 .58951 Mtetra
0 0 .023 r
.66023 .58951 .66096 .58673 .66247 .57862 .66192 .58563 Mtetra
.98 .697 .408 r
.66192 .58563 .66247 .57862 .6562 .3809 .65567 .38711 Mtetra
0 0 .102 r
.65567 .38711 .6562 .3809 .65774 .37645 .65698 .37704 Mtetra
.738 .946 .63 r
.65698 .37704 .65774 .37645 .65941 .37487 .65863 .37503 Mtetra
.307 .796 .763 r
.65863 .37503 .65941 .37487 .66111 .37428 .66034 .37446 Mtetra
.013 0 0 r
.66034 .37446 .66111 .37428 .66283 .37403 .66206 .37429 Mtetra
.27 .762 .689 r
.66206 .37429 .66283 .37403 .66455 .37372 .66376 .37366 Mtetra
.651 .962 .924 r
.66376 .37366 .66455 .37372 .66626 .37333 .66546 .37274 Mtetra
.734 .868 .944 r
.66546 .37274 .66626 .37333 .66798 .37293 .66715 .37187 Mtetra
.687 .744 .894 r
.66715 .37187 .66798 .37293 .66969 .37239 .66886 .37119 Mtetra
.656 .707 .884 r
.66886 .37119 .66969 .37239 .6714 .37175 .67057 .37066 Mtetra
.645 .722 .905 r
.67057 .37066 .6714 .37175 .67311 .3711 .67229 .37018 Mtetra
.641 .76 .935 r
.67229 .37018 .67311 .3711 .67482 .3705 .67401 .36971 Mtetra
.638 .789 .954 r
.67401 .36971 .67482 .3705 .67653 .36995 .67573 .36922 Mtetra
.635 .806 .965 r
.67573 .36922 .67653 .36995 .67825 .36941 .67745 .36873 Mtetra
.642 .822 .97 r
.67745 .36873 .67825 .36941 .67996 .36877 .67917 .3682 Mtetra
.64 .851 .981 r
.67917 .3682 .67996 .36877 .68168 .36813 .68089 .36764 Mtetra
.634 .87 .986 r
.68089 .36764 .68168 .36813 .6834 .36764 .68261 .36706 Mtetra
.653 .851 .976 r
.68261 .36706 .6834 .36764 .68515 .36768 .68432 .36646 Mtetra
.67 .708 .877 r
.68432 .36646 .68515 .36768 .68693 .36822 .68604 .36586 Mtetra
.64 .566 .755 r
.68604 .36586 .68693 .36822 .68872 .36902 .68777 .36525 Mtetra
.615 .489 .686 r
.68777 .36525 .68872 .36902 .69049 .36926 .68949 .36465 Mtetra
.605 .463 .662 r
.68949 .36465 .69049 .36926 .69222 .36875 .69121 .36406 Mtetra
.604 .461 .661 r
.69121 .36406 .69222 .36875 .69393 .36796 .69294 .36347 Mtetra
.606 .467 .665 r
.69294 .36347 .69393 .36796 .69565 .36723 .69466 .36287 Mtetra
.607 .47 .669 r
.69466 .36287 .69565 .36723 .69738 .3666 .69639 .36228 Mtetra
.607 .471 .67 r
.69639 .36228 .69738 .3666 .6991 .36599 .69811 .36169 Mtetra
.624 .482 .669 r
.69811 .36169 .6991 .36599 .70081 .36498 .69983 .36086 Mtetra
.626 .487 .674 r
.69983 .36086 .70081 .36498 .70252 .36401 .70155 .36004 Mtetra
.592 .47 .682 r
.70155 .36004 .70252 .36401 .70427 .36378 .70329 .3597 Mtetra
.404 .345 .677 r
.70329 .3597 .70427 .36378 .70623 .36725 .70515 .36129 Mtetra
0 0 .304 r
.70515 .36129 .70623 .36725 .71947 .56705 .70752 .37192 Mtetra
.033 0 .434 r
.70752 .37192 .71947 .56705 .72165 .57218 .72067 .56886 Mtetra
.281 .301 .704 r
.72067 .56886 .72165 .57218 .72361 .57332 .72267 .57092 Mtetra
.605 .556 .773 r
.72267 .57092 .72361 .57332 .72547 .57292 .72454 .57059 Mtetra
.677 .599 .761 r
.72454 .57059 .72547 .57292 .72732 .57209 .72638 .56962 Mtetra
.672 .587 .753 r
.72638 .56962 .72732 .57209 .72916 .57131 .72821 .56868 Mtetra
.641 .561 .749 r
.72821 .56868 .72916 .57131 .73102 .57072 .73007 .568 Mtetra
.631 .55 .745 r
.73007 .568 .73102 .57072 .73288 .5701 .73192 .56739 Mtetra
.599 .533 .751 r
.73192 .56739 .73288 .5701 .73473 .56943 .7338 .56709 Mtetra
.57 .54 .783 r
.7338 .56709 .73473 .56943 .73659 .56871 .7357 .56701 Mtetra
.565 .603 .85 r
.7357 .56701 .73659 .56871 .73844 .56803 .73759 .56692 Mtetra
.594 .716 .929 r
.73759 .56692 .73844 .56803 .74031 .56749 .73947 .56661 Mtetra
.642 .785 .951 r
.73947 .56661 .74031 .56749 .74219 .5671 .74134 .56607 Mtetra
.66 .759 .923 r
.74134 .56607 .74219 .5671 .74407 .56674 .74321 .56547 Mtetra
.59 .682 .905 r
.74321 .56547 .74407 .56674 .74597 .56661 .7451 .5652 Mtetra
.557 .642 .89 r
.7451 .5652 .74597 .56661 .74787 .56651 .747 .56509 Mtetra
.669 .693 .863 r
.747 .56509 .74787 .56651 .74973 .56585 .74887 .56443 Mtetra
.864 .753 .738 r
.74887 .56443 .74973 .56585 .75147 .5632 .7506 .5617 Mtetra
.968 .721 .508 r
.7506 .5617 .75147 .5632 .75262 .55197 .7516 .54818 Mtetra
.975 .68 .396 r
.7516 .54818 .75262 .55197 .7409 .35173 .7401 .35048 Mtetra
.893 .764 .712 r
.7401 .35048 .7409 .35173 .74248 .34849 .74168 .34739 Mtetra
.708 .748 .884 r
.74168 .34739 .74248 .34849 .74422 .34767 .74342 .34659 Mtetra
.586 .704 .924 r
.74342 .34659 .74422 .34767 .74599 .34741 .7452 .34633 Mtetra
.645 .729 .91 r
.7452 .34633 .74599 .34741 .74776 .34692 .74697 .34584 Mtetra
.733 .762 .876 r
.74697 .34584 .74776 .34692 .74949 .34597 .7487 .34489 Mtetra
.634 .727 .915 r
.7487 .34489 .74949 .34597 .75126 .34551 .75047 .34444 Mtetra
0 .302 .795 r
.75047 .34444 .75126 .34551 .75316 .34683 .75237 .34577 Mtetra
.951 .602 .228 r
.75237 .34577 .75316 .34683 .75593 .3601 .75514 .35906 Mtetra
.975 .673 .363 r
.75514 .35906 .75593 .3601 .77208 .55607 .77125 .55506 Mtetra
.546 .078 0 r
.77125 .55506 .77208 .55607 .7742 .55863 .77337 .55763 Mtetra
.453 .674 .958 r
.77337 .55763 .7742 .55863 .77614 .55873 .77531 .55772 Mtetra
.73 .792 .901 r
.77531 .55772 .77614 .55873 .778 .55778 .77717 .55677 Mtetra
.902 .81 .747 r
.77717 .55677 .778 .55778 .77972 .555 .77889 .55394 Mtetra
.978 .74 .509 r
.77889 .55394 .77972 .555 .78085 .54431 .77997 .54255 Mtetra
.977 .68 .378 r
.77997 .54255 .78085 .54431 .76738 .34326 .76658 .34198 Mtetra
.905 .764 .695 r
.76658 .34198 .76738 .34326 .76893 .33978 .76814 .33858 Mtetra
.706 .732 .871 r
.76814 .33858 .76893 .33978 .77068 .33892 .76989 .33776 Mtetra
.583 .689 .914 r
.76989 .33776 .77068 .33892 .77247 .33864 .77169 .33753 Mtetra
.604 .708 .917 r
.77169 .33753 .77247 .33864 .77426 .33825 .77349 .3372 Mtetra
.725 .768 .887 r
.77349 .3372 .77426 .33825 .77601 .3373 .77524 .33631 Mtetra
.638 .748 .928 r
.77524 .33631 .77601 .3373 .77779 .33684 .77702 .33583 Mtetra
.119 .453 .884 r
.77702 .33583 .77779 .33684 .77971 .33798 .77892 .33671 Mtetra
.867 .476 .002 r
.77892 .33671 .77971 .33798 .78261 .35113 .78129 .34341 Mtetra
.977 .674 .325 r
.78129 .34341 .78261 .35113 .80055 .54806 .79955 .54486 Mtetra
.022 .135 .644 r
.79955 .54486 .80055 .54806 .80272 .55073 .80179 .54835 Mtetra
.478 .486 .788 r
.80179 .54835 .80272 .55073 .80468 .55076 .80379 .54887 Mtetra
.642 .624 .816 r
.80379 .54887 .80468 .55076 .80655 .54972 .8057 .54831 Mtetra
.833 .753 .775 r
.8057 .54831 .80655 .54972 .80828 .54695 .80748 .54617 Mtetra
.982 .782 .559 r
.80748 .54617 .80828 .54695 .80927 .53551 .80883 .53894 Mtetra
.979 .681 .348 r
.80883 .53894 .80927 .53551 .79405 .33409 .79347 .33526 Mtetra
.859 .839 .372 r
.79347 .33526 .79405 .33409 .79557 .33038 .7949 .33053 Mtetra
.777 .993 .779 r
.7949 .33053 .79557 .33038 .79731 .32922 .7966 .32886 Mtetra
.624 .912 .982 r
.7966 .32886 .79731 .32922 .79913 .329 .79838 .32818 Mtetra
.154 .525 .919 r
.79838 .32818 .79913 .329 .80108 .33024 .80028 .32882 Mtetra
.72 .323 0 r
.80028 .32882 .80108 .33024 .80363 .3383 .80255 .33358 Mtetra
.975 .67 .324 r
.80255 .33358 .80363 .3383 .82346 .54076 .8224 .53686 Mtetra
0 .076 .597 r
.8224 .53686 .82346 .54076 .82572 .54401 .82478 .54148 Mtetra
.439 .452 .776 r
.82478 .54148 .82572 .54401 .82772 .54428 .82683 .54229 Mtetra
.615 .6 .812 r
.82683 .54229 .82772 .54428 .82962 .54348 .82877 .5419 Mtetra
.81 .729 .775 r
.82877 .5419 .82962 .54348 .83139 .5412 .83057 .53992 Mtetra
.969 .753 .558 r
.83057 .53992 .83139 .5412 .83267 .53351 .83184 .53212 Mtetra
.977 .676 .351 r
.83184 .53212 .83267 .53351 .81571 .32841 .81495 .32725 Mtetra
.946 .777 .64 r
.81495 .32725 .81571 .32841 .81715 .32381 .81638 .32269 Mtetra
.8 .78 .835 r
.81638 .32269 .81715 .32381 .81887 .32238 .81811 .32123 Mtetra
.644 .722 .904 r
.81811 .32123 .81887 .32238 .82068 .32191 .81992 .32073 Mtetra
.269 .51 .901 r
.81992 .32073 .82068 .32191 .82262 .32268 .82185 .32145 Mtetra
.758 .347 0 r
.82185 .32145 .82262 .32268 .82496 .3277 .82417 .32634 Mtetra
.974 .665 .324 r
.82417 .32634 .82496 .3277 .84637 .53165 .84557 .53052 Mtetra
.731 .299 0 r
.84557 .53052 .84637 .53165 .84877 .53595 .84798 .53495 Mtetra
.487 .697 .962 r
.84798 .53495 .84877 .53595 .85076 .53587 .84998 .53494 Mtetra
.697 .805 .932 r
.84998 .53494 .85076 .53587 .85267 .53501 .8519 .53414 Mtetra
.757 .839 .914 r
.8519 .53414 .85267 .53501 .85456 .53384 .85379 .53304 Mtetra
.651 .82 .965 r
.85379 .53304 .85456 .53384 .85649 .5332 .85573 .53241 Mtetra
.65 .824 .967 r
.85573 .53241 .85649 .5332 .85843 .53258 .85767 .53178 Mtetra
.646 .82 .967 r
.85767 .53178 .85843 .53258 .86038 .53201 .85961 .53117 Mtetra
.634 .806 .965 r
.85961 .53117 .86038 .53201 .86233 .53152 .86156 .53062 Mtetra
.632 .788 .957 r
.86156 .53062 .86233 .53152 .86429 .53108 .86351 .53009 Mtetra
.611 .758 .949 r
.86351 .53009 .86429 .53108 .86627 .53077 .86547 .52965 Mtetra
.493 .672 .944 r
.86547 .52965 .86627 .53077 .8683 .531 .86749 .52968 Mtetra
.619 .694 .897 r
.86749 .52968 .8683 .531 .87028 .53071 .86946 .52926 Mtetra
.768 .736 .824 r
.86946 .52926 .87028 .53071 .87215 .52928 .87133 .52786 Mtetra
.956 .759 .597 r
.87133 .52786 .87215 .52928 .87338 .52177 .8727 .52172 Mtetra
.976 .671 .325 r
.8727 .52172 .87338 .52177 .85383 .3161 .85333 .31725 Mtetra
.884 .816 .338 r
.85333 .31725 .85383 .3161 .85522 .31133 .85462 .31157 Mtetra
.601 .929 .712 r
.85462 .31157 .85522 .31133 .85701 .31039 .85636 .31018 Mtetra
.571 .924 .951 r
.85636 .31018 .85701 .31039 .85887 .31013 .85818 .30946 Mtetra
.578 .813 .988 r
.85818 .30946 .85887 .31013 .86077 .3102 .86003 .30906 Mtetra
.663 .735 .903 r
.86003 .30906 .86077 .3102 .86261 .30968 .86186 .30846 Mtetra
.652 .714 .894 r
.86186 .30846 .86261 .30968 .86445 .30911 .8637 .30792 Mtetra
.655 .721 .897 r
.8637 .30792 .86445 .30911 .86627 .30848 .86554 .30736 Mtetra
.755 .774 .868 r
.86554 .30736 .86627 .30848 .86805 .30736 .86731 .30625 Mtetra
.689 .752 .899 r
.86731 .30625 .86805 .30736 .86987 .30662 .86913 .30552 Mtetra
.484 .656 .936 r
.86913 .30552 .86987 .30662 .87178 .30668 .87104 .30559 Mtetra
.759 .341 0 r
.87104 .30559 .87178 .30668 .87424 .31167 .87351 .31061 Mtetra
.971 .656 .295 r
.87351 .31061 .87424 .31167 .89911 .51655 .89834 .51553 Mtetra
.738 .303 0 r
.89834 .51553 .89911 .51655 .90167 .52127 .90091 .52022 Mtetra
.299 .577 .937 r
.90091 .52022 .90167 .52127 .90377 .5218 .90301 .52075 Mtetra
.648 .764 .934 r
.90301 .52075 .90377 .5218 .90575 .52123 .90499 .52017 Mtetra
.828 .821 .842 r
.90499 .52017 .90575 .52123 .9076 .51953 .90684 .51847 Mtetra
.908 .736 .657 r
.27166 .70084 .27269 .70168 .27463 .69613 .2736 .69529 Mtetra
.936 .686 .535 r
.2736 .69529 .27463 .69613 .28999 .50068 .28902 .49978 Mtetra
.907 .728 .648 r
.28902 .49978 .28999 .50068 .29185 .49496 .29088 .49406 Mtetra
.772 .759 .841 r
.29088 .49406 .29185 .49496 .29338 .49384 .29242 .49294 Mtetra
.64 .735 .918 r
.29242 .49294 .29338 .49384 .29487 .49344 .2939 .49254 Mtetra
.511 .692 .95 r
.2939 .49254 .29487 .49344 .29633 .4934 .29537 .4925 Mtetra
.749 .757 .859 r
.29537 .4925 .29633 .4934 .29786 .49246 .29689 .49156 Mtetra
.697 .749 .892 r
.29689 .49156 .29786 .49246 .29936 .49183 .2984 .49092 Mtetra
.484 .68 .952 r
.2984 .49092 .29936 .49183 .30082 .49185 .29986 .49094 Mtetra
.926 .545 .248 r
.29986 .49094 .30082 .49185 .30202 .49583 .30105 .49491 Mtetra
.939 .683 .523 r
.30105 .49491 .30202 .49583 .2905 .69041 .28948 .68953 Mtetra
.936 .584 .327 r
.28948 .68953 .2905 .69041 .2917 .69578 .29067 .69492 Mtetra
.26 .596 .95 r
.29067 .69492 .2917 .69578 .29323 .69616 .29221 .69527 Mtetra
.666 .758 .919 r
.29221 .69527 .29323 .69616 .29482 .69564 .2938 .69474 Mtetra
.738 .768 .877 r
.2938 .69474 .29482 .69564 .29644 .69472 .29542 .69384 Mtetra
.391 .658 .965 r
.29542 .69384 .29644 .69472 .298 .69474 .29697 .694 Mtetra
.495 .74 .982 r
.29697 .694 .298 .69474 .29958 .6945 .29854 .69391 Mtetra
.726 .834 .932 r
.29854 .69391 .29958 .6945 .3012 .69358 .30015 .69311 Mtetra
.923 .776 .68 r
.30015 .69311 .3012 .69358 .30307 .68885 .30201 .68861 Mtetra
.94 .688 .528 r
.30201 .68861 .30307 .68885 .31689 .49334 .3159 .49302 Mtetra
.938 .748 .619 r
.3159 .49302 .31689 .49334 .3188 .48653 .31784 .4856 Mtetra
.803 .757 .811 r
.31784 .4856 .3188 .48653 .32036 .48511 .31941 .48415 Mtetra
.654 .728 .903 r
.31941 .48415 .32036 .48511 .32187 .48465 .32091 .48369 Mtetra
.521 .684 .94 r
.32091 .48369 .32187 .48465 .32335 .48458 .32239 .48365 Mtetra
.734 .752 .867 r
.32239 .48365 .32335 .48458 .32488 .48371 .32393 .48279 Mtetra
.706 .749 .885 r
.32393 .48279 .32488 .48371 .3264 .48302 .32545 .4821 Mtetra
.524 .695 .946 r
.32545 .4821 .3264 .48302 .32789 .48294 .32693 .48203 Mtetra
.907 .498 .162 r
.32693 .48203 .32789 .48294 .32917 .48631 .32822 .4854 Mtetra
.942 .683 .517 r
.32822 .4854 .32917 .48631 .31923 .68098 .31821 .68014 Mtetra
.939 .596 .348 r
.31821 .68014 .31923 .68098 .32044 .68719 .31942 .68634 Mtetra
.029 .458 .876 r
.31942 .68634 .32044 .68719 .32198 .68786 .32096 .68698 Mtetra
.655 .76 .927 r
.32096 .68698 .32198 .68786 .32359 .68738 .32257 .68648 Mtetra
.737 .771 .88 r
.32257 .68648 .32359 .68738 .32522 .68648 .32421 .68558 Mtetra
.463 .689 .964 r
.32421 .68558 .32522 .68648 .32681 .68638 .32579 .68562 Mtetra
.479 .729 .98 r
.32579 .68562 .32681 .68638 .3284 .68619 .32737 .68556 Mtetra
.706 .829 .941 r
.32737 .68556 .3284 .68619 .33003 .68535 .329 .68485 Mtetra
.919 .786 .697 r
.329 .68485 .33003 .68535 .33185 .68122 .3308 .6809 Mtetra
.943 .689 .522 r
.3308 .6809 .33185 .68122 .34409 .48624 .34309 .48617 Mtetra
.951 .75 .596 r
.34309 .48617 .34409 .48624 .34603 .478 .34508 .47704 Mtetra
.823 .756 .789 r
.34508 .47704 .34603 .478 .34762 .4763 .34667 .47531 Mtetra
.653 .723 .9 r
.34667 .47531 .34762 .4763 .34914 .47583 .3482 .47485 Mtetra
.506 .674 .94 r
.3482 .47485 .34914 .47583 .35064 .47579 .34969 .47484 Mtetra
.618 .723 .921 r
.34969 .47484 .35064 .47579 .35216 .47541 .35121 .47452 Mtetra
.664 .747 .912 r
.35121 .47452 .35216 .47541 .35368 .47488 .35274 .47401 Mtetra
.676 .757 .912 r
.35274 .47401 .35368 .47488 .35521 .47433 .35427 .47346 Mtetra
.771 .773 .854 r
.35427 .47346 .35521 .47433 .35676 .47336 .35582 .47237 Mtetra
.745 .746 .853 r
.35582 .47237 .35676 .47336 .35831 .47255 .35738 .47143 Mtetra
.619 .687 .892 r
.35738 .47143 .35831 .47255 .35982 .47233 .3589 .47111 Mtetra
.808 .366 0 r
.3589 .47111 .35982 .47233 .36119 .47502 .36027 .47379 Mtetra
.946 .685 .508 r
.36027 .47379 .36119 .47502 .35314 .66936 .35212 .66901 Mtetra
.931 .603 .395 r
.35212 .66901 .35314 .66936 .35436 .6771 .35334 .67669 Mtetra
.539 0 0 r
.35334 .67669 .35436 .6771 .35592 .67816 .35489 .67774 Mtetra
.577 .854 .996 r
.35489 .67774 .35592 .67816 .35754 .67775 .35651 .67732 Mtetra
.743 .882 .943 r
.35651 .67732 .35754 .67775 .35919 .67687 .35816 .67642 Mtetra
.672 .871 .974 r
.35816 .67642 .35919 .67687 .36082 .67623 .3598 .67578 Mtetra
.601 .855 .992 r
.3598 .67578 .36082 .67623 .36245 .67576 .36143 .67532 Mtetra
.599 .857 .993 r
.36143 .67532 .36245 .67576 .36409 .67529 .36306 .67486 Mtetra
.481 .818 .999 r
.36306 .67486 .36409 .67529 .3657 .67516 .36469 .67462 Mtetra
.543 .813 .996 r
.36469 .67462 .3657 .67516 .36732 .67495 .36631 .67432 Mtetra
.689 .829 .95 r
.36631 .67432 .36732 .67495 .36897 .6742 .36795 .67366 Mtetra
.863 .839 .82 r
.36795 .67366 .36897 .6742 .37072 .6711 .36965 .67178 Mtetra
.975 .912 .679 r
.36965 .67178 .37072 .6711 .37294 .65719 .37144 .66797 Mtetra
0 0 0 r
.37144 .66797 .37294 .65719 .38274 .46759 .37369 .65322 Mtetra
0 0 .286 r
.37369 .65322 .38274 .46759 .38438 .4649 .38327 .46806 Mtetra
0 0 0 r
.38327 .46806 .38438 .4649 .38594 .46391 .38495 .46454 Mtetra
.86 .992 .74 r
.38495 .46454 .38594 .46391 .38749 .46339 .38656 .46251 Mtetra
.768 .772 .857 r
.38656 .46251 .38749 .46339 .38903 .46291 .38813 .46144 Mtetra
.658 .646 .827 r
.38813 .46144 .38903 .46291 .39058 .46244 .38967 .4609 Mtetra
.614 .62 .833 r
.38967 .4609 .39058 .46244 .39212 .46202 .39121 .4606 Mtetra
.613 .636 .85 r
.39121 .4606 .39212 .46202 .39367 .46159 .39275 .46031 Mtetra
.622 .662 .868 r
.39275 .46031 .39367 .46159 .39522 .46113 .3943 .45998 Mtetra
.622 .685 .888 r
.3943 .45998 .39522 .46113 .39677 .46066 .39584 .45965 Mtetra
.64 .719 .905 r
.39584 .45965 .39677 .46066 .39832 .46015 .39739 .45923 Mtetra
.661 .746 .914 r
.39739 .45923 .39832 .46015 .39987 .4596 .39894 .45874 Mtetra
.676 .761 .914 r
.39894 .45874 .39987 .4596 .40143 .45904 .4005 .45817 Mtetra
.699 .766 .904 r
.4005 .45817 .40143 .45904 .40298 .45846 .40206 .45751 Mtetra
.708 .752 .886 r
.40206 .45751 .40298 .45846 .40454 .45786 .40362 .45679 Mtetra
.702 .726 .869 r
.40362 .45679 .40454 .45786 .4061 .45727 .40518 .45608 Mtetra
.711 .707 .845 r
.40518 .45608 .4061 .45727 .40767 .45646 .40675 .45529 Mtetra
.701 .708 .853 r
.40675 .45529 .40767 .45646 .40923 .45566 .40832 .45456 Mtetra
.636 .699 .892 r
.40832 .45456 .40923 .45566 .41079 .45534 .40987 .45417 Mtetra
.26 .505 .899 r
.40987 .45417 .41079 .45534 .41228 .4568 .41139 .45475 Mtetra
0 0 .576 r
.41139 .45475 .41228 .4568 .41354 .46519 .41286 .45704 Mtetra
0 0 .313 r
.41286 .45704 .41354 .46519 .40862 .65884 .41408 .46657 Mtetra
0 0 .32 r
.41408 .46657 .40862 .65884 .41018 .66133 .40936 .65553 Mtetra
.273 .212 .604 r
.40936 .65553 .41018 .66133 .41182 .66151 .4109 .65864 Mtetra
.316 .339 .726 r
.4109 .65864 .41182 .66151 .41348 .66113 .4125 .66 Mtetra
.352 .581 .929 r
.4125 .66 .41348 .66113 .41514 .66064 .41414 .66037 Mtetra
.394 .815 .971 r
.41414 .66037 .41514 .66064 .4168 .66019 .41579 .66014 Mtetra
.467 .882 .934 r
.41579 .66014 .4168 .66019 .41847 .65966 .41746 .65963 Mtetra
.53 .912 .938 r
.41746 .65963 .41847 .65966 .42013 .65911 .41913 .65901 Mtetra
.583 .924 .96 r
.41913 .65901 .42013 .65911 .4218 .65856 .4208 .65835 Mtetra
.638 .923 .976 r
.4208 .65835 .4218 .65856 .42347 .658 .42248 .65766 Mtetra
.644 .895 .984 r
.42248 .65766 .42347 .658 .42514 .65746 .42415 .65702 Mtetra
.623 .868 .988 r
.42415 .65702 .42514 .65746 .42681 .65694 .42582 .65649 Mtetra
.615 .862 .99 r
.42582 .65649 .42681 .65694 .42848 .65643 .42749 .65598 Mtetra
.614 .862 .99 r
.42749 .65598 .42848 .65643 .43015 .65591 .42917 .65547 Mtetra
.616 .865 .99 r
.42917 .65547 .43015 .65591 .43183 .65539 .43084 .65495 Mtetra
.615 .865 .99 r
.43084 .65495 .43183 .65539 .4335 .65487 .43252 .65443 Mtetra
.614 .866 .99 r
.43252 .65443 .4335 .65487 .43518 .65434 .43419 .65391 Mtetra
.612 .868 .991 r
.43419 .65391 .43518 .65434 .43685 .6538 .43587 .65339 Mtetra
.609 .871 .991 r
.43587 .65339 .43685 .6538 .43853 .65326 .43755 .65287 Mtetra
.606 .875 .992 r
.43755 .65287 .43853 .65326 .44021 .65271 .43923 .65235 Mtetra
.601 .881 .992 r
.43923 .65235 .44021 .65271 .44189 .65214 .44091 .65182 Mtetra
.586 .885 .991 r
.44091 .65182 .44189 .65214 .44357 .65159 .44259 .6513 Mtetra
.564 .885 .99 r
.44259 .6513 .44357 .65159 .44525 .65108 .44427 .6508 Mtetra
.544 .88 .989 r
.44427 .6508 .44525 .65108 .44693 .65063 .44595 .65033 Mtetra
.545 .878 .99 r
.44595 .65033 .44693 .65063 .44862 .65019 .44763 .64987 Mtetra
.494 .853 .991 r
.44763 .64987 .44862 .65019 .4503 .64978 .44932 .64952 Mtetra
.42 .83 .974 r
.44932 .64952 .4503 .64978 .45198 .64937 .451 .64923 Mtetra
.519 .896 .962 r
.451 .64923 .45198 .64937 .45367 .64889 .45269 .6487 Mtetra
.815 .944 .909 r
.45269 .6487 .45367 .64889 .45536 .64822 .45439 .64738 Mtetra
.887 .786 .745 r
.45439 .64738 .45536 .64822 .45705 .6473 .45612 .64458 Mtetra
.831 .647 .654 r
.45612 .64458 .45705 .6473 .45875 .64633 .45789 .64001 Mtetra
.784 .568 .608 r
.45789 .64001 .45875 .64633 .46045 .64557 .45971 .63273 Mtetra
.608 .412 .591 r
.45971 .63273 .46045 .64557 .46213 .64516 .46142 .63079 Mtetra
.5 .327 .577 r
.46142 .63079 .46213 .64516 .46382 .64484 .46306 .63291 Mtetra
.485 .322 .584 r
.46306 .63291 .46382 .64484 .46551 .64472 .4647 .63509 Mtetra
.516 .354 .6 r
.4647 .63509 .46551 .64472 .46719 .64474 .46636 .6362 Mtetra
.585 .411 .612 r
.46636 .6362 .46719 .64474 .46889 .64417 .46806 .63559 Mtetra
.786 .559 .592 r
.46806 .63559 .46889 .64417 .47062 .64171 .4699 .62542 Mtetra
.936 .669 .506 r
.4699 .62542 .47062 .64171 .47272 .61455 .47448 .43815 Mtetra
.562 .347 .546 r
.47448 .43815 .47272 .61455 .47701 .43631 .47613 .43404 Mtetra
.762 .628 .711 r
.47613 .43404 .47701 .43631 .47865 .43323 .47776 .432 Mtetra
.694 .701 .852 r
.47776 .432 .47865 .43323 .48025 .43242 .47936 .43129 Mtetra
.627 .696 .894 r
.47936 .43129 .48025 .43242 .48185 .43212 .48095 .43092 Mtetra
.612 .676 .887 r
.48095 .43092 .48185 .43212 .48345 .43194 .48255 .43062 Mtetra
.653 .672 .856 r
.48255 .43062 .48345 .43194 .48505 .43148 .48415 .43012 Mtetra
.648 .665 .853 r
.48415 .43012 .48505 .43148 .48665 .43102 .48576 .42965 Mtetra
.636 .657 .854 r
.48576 .42965 .48665 .43102 .48825 .43058 .48736 .42924 Mtetra
.618 .655 .864 r
.48736 .42924 .48825 .43058 .48985 .43012 .48896 .42891 Mtetra
.62 .678 .883 r
.48896 .42891 .48985 .43012 .49146 .42965 .49057 .42857 Mtetra
.645 .712 .896 r
.49057 .42857 .49146 .42965 .49307 .42916 .49217 .42812 Mtetra
.689 .736 .887 r
.49217 .42812 .49307 .42916 .49467 .42862 .49378 .42747 Mtetra
.693 .716 .867 r
.49378 .42747 .49467 .42862 .49628 .42807 .49539 .42679 Mtetra
.682 .689 .85 r
.49539 .42679 .49628 .42807 .49789 .42753 .497 .42613 Mtetra
.661 .664 .843 r
.497 .42613 .49789 .42753 .4995 .427 .49861 .42558 Mtetra
.656 .658 .841 r
.49861 .42558 .4995 .427 .50111 .42649 .50023 .42505 Mtetra
.654 .657 .84 r
.50023 .42505 .50111 .42649 .50272 .42597 .50184 .42453 Mtetra
.656 .658 .84 r
.50184 .42453 .50272 .42597 .50434 .42544 .50345 .42401 Mtetra
.655 .657 .839 r
.50345 .42401 .50434 .42544 .50595 .42492 .50507 .42348 Mtetra
.655 .656 .839 r
.50507 .42348 .50595 .42492 .50757 .4244 .50668 .42295 Mtetra
.50668 .42295 .50757 .4244 .50918 .42388 .5083 .42243 Mtetra
.655 .655 .838 r
.5083 .42243 .50918 .42388 .5108 .42335 .50992 .4219 Mtetra
.50992 .4219 .5108 .42335 .51242 .42283 .51153 .42138 Mtetra
.51153 .42138 .51242 .42283 .51404 .4223 .51315 .42085 Mtetra
.51315 .42085 .51404 .4223 .51566 .42178 .51477 .42032 Mtetra
.51477 .42032 .51566 .42178 .51728 .42126 .51639 .4198 Mtetra
.655 .654 .837 r
.51639 .4198 .51728 .42126 .5189 .42073 .51802 .41927 Mtetra
.51802 .41927 .5189 .42073 .52052 .4202 .51964 .41874 Mtetra
.656 .653 .836 r
.51964 .41874 .52052 .4202 .52214 .41968 .52126 .4182 Mtetra
.657 .653 .835 r
.52126 .4182 .52214 .41968 .52377 .41915 .52289 .41766 Mtetra
.656 .651 .833 r
.52289 .41766 .52377 .41915 .52539 .41862 .52451 .41712 Mtetra
.661 .651 .83 r
.52451 .41712 .52539 .41862 .52702 .41807 .52614 .41655 Mtetra
.683 .657 .819 r
.52614 .41655 .52702 .41807 .52865 .41748 .52777 .41583 Mtetra
.65 .628 .814 r
.52777 .41583 .52865 .41748 .53028 .41694 .5294 .41529 Mtetra
.569 .59 .835 r
.5294 .41529 .53028 .41694 .53191 .41652 .53103 .41521 Mtetra
0 .268 .775 r
.53103 .41521 .53191 .41652 .53354 .4164 .53266 .41652 Mtetra
.838 .395 .175 r
.53266 .41652 .53354 .4164 .53517 .41636 .53431 .41925 Mtetra
.84 .519 .446 r
.53431 .41925 .53517 .41636 .53681 .41629 .53597 .42659 Mtetra
.947 .667 .475 r
.53597 .42659 .53681 .41629 .53844 .41592 .53831 .6063 Mtetra
.549 .333 .538 r
.53831 .6063 .53844 .41592 .54008 .41538 .54004 .60427 Mtetra
0 0 .38 r
.54004 .60427 .54008 .41538 .54171 .41464 .54088 .42281 Mtetra
.055 0 .323 r
.54088 .42281 .54171 .41464 .54334 .41363 .54249 .41579 Mtetra
0 0 0 r
.54249 .41579 .54334 .41363 .54498 .41262 .54411 .41235 Mtetra
.912 .902 .803 r
.54411 .41235 .54498 .41262 .54662 .41171 .54574 .41022 Mtetra
.694 .668 .82 r
.54574 .41022 .54662 .41171 .54825 .41112 .54738 .40943 Mtetra
.641 .621 .814 r
.54738 .40943 .54825 .41112 .54989 .41061 .54902 .40895 Mtetra
.618 .613 .824 r
.54902 .40895 .54989 .41061 .55154 .41013 .55066 .40861 Mtetra
.656 .648 .83 r
.55066 .40861 .55154 .41013 .55318 .40957 .5523 .40806 Mtetra
.656 .649 .831 r
.5523 .40806 .55318 .40957 .55482 .40901 .55395 .4075 Mtetra
.657 .651 .833 r
.55395 .4075 .55482 .40901 .55646 .40844 .55559 .40695 Mtetra
.658 .654 .835 r
.55559 .40695 .55646 .40844 .55811 .40786 .55724 .40639 Mtetra
.659 .657 .837 r
.55724 .40639 .55811 .40786 .55975 .40729 .55888 .40584 Mtetra
.659 .659 .839 r
.55888 .40584 .55975 .40729 .5614 .40672 .56053 .40528 Mtetra
.66 .661 .84 r
.56053 .40528 .5614 .40672 .56305 .40615 .56218 .40472 Mtetra
.66 .663 .842 r
.56218 .40472 .56305 .40615 .5647 .40558 .56383 .40416 Mtetra
.66 .664 .843 r
.56383 .40416 .5647 .40558 .56635 .40502 .56548 .4036 Mtetra
.66 .665 .844 r
.56548 .4036 .56635 .40502 .568 .40445 .56713 .40304 Mtetra
.66 .666 .845 r
.56713 .40304 .568 .40445 .56965 .40389 .56878 .40248 Mtetra
.659 .666 .846 r
.56878 .40248 .56965 .40389 .5713 .40333 .57043 .40193 Mtetra
.659 .667 .846 r
.57043 .40193 .5713 .40333 .57295 .40278 .57209 .40138 Mtetra
.659 .668 .847 r
.57209 .40138 .57295 .40278 .57461 .40222 .57374 .40083 Mtetra
.658 .668 .848 r
.57374 .40083 .57461 .40222 .57626 .40167 .5754 .40028 Mtetra
.661 .671 .849 r
.5754 .40028 .57626 .40167 .57792 .40111 .57705 .39972 Mtetra
.658 .669 .849 r
.57705 .39972 .57792 .40111 .57958 .40055 .57871 .39918 Mtetra
.653 .668 .853 r
.57871 .39918 .57958 .40055 .58124 .40001 .58037 .39866 Mtetra
.629 .664 .865 r
.58037 .39866 .58124 .40001 .5829 .39949 .58203 .39827 Mtetra
.627 .685 .885 r
.58203 .39827 .5829 .39949 .58456 .39898 .5837 .39789 Mtetra
.637 .715 .903 r
.5837 .39789 .58456 .39898 .58622 .39845 .58536 .39746 Mtetra
.69 .753 .9 r
.58536 .39746 .58622 .39845 .58788 .39787 .58702 .39679 Mtetra
.7 .738 .881 r
.58702 .39679 .58788 .39787 .58954 .39727 .58868 .39607 Mtetra
.695 .713 .862 r
.58868 .39607 .58954 .39727 .59121 .39667 .59035 .39534 Mtetra
.669 .683 .854 r
.59035 .39534 .59121 .39667 .59287 .39609 .59201 .39474 Mtetra
.662 .677 .853 r
.59201 .39474 .59287 .39609 .59454 .39552 .59368 .39417 Mtetra
.659 .677 .856 r
.59368 .39417 .59454 .39552 .5962 .39494 .59534 .39362 Mtetra
.662 .683 .859 r
.59534 .39362 .5962 .39494 .59787 .39436 .59701 .39306 Mtetra
.663 .686 .862 r
.59701 .39306 .59787 .39436 .59954 .39379 .59868 .3925 Mtetra
.662 .688 .864 r
.59868 .3925 .59954 .39379 .60121 .39322 .60035 .39194 Mtetra
.704 .705 .848 r
.60035 .39194 .60121 .39322 .60287 .39231 .60202 .39114 Mtetra
.682 .717 .876 r
.60202 .39114 .60287 .39231 .60454 .39162 .60369 .39049 Mtetra
.601 .692 .907 r
.60369 .39049 .60454 .39162 .60623 .39149 .60537 .39021 Mtetra
0 .288 .788 r
.60537 .39021 .60623 .39149 .60798 .39421 .60709 .39153 Mtetra
0 0 .542 r
.60709 .39153 .60798 .39421 .61483 .58978 .60887 .39498 Mtetra
0 0 .406 r
.60887 .39498 .61483 .58978 .6169 .59992 .61568 .58685 Mtetra
.456 .3 .58 r
.61568 .58685 .6169 .59992 .61872 .60061 .61757 .59023 Mtetra
.609 .42 .601 r
.61757 .59023 .61872 .60061 .62051 .59998 .61932 .58863 Mtetra
.599 .41 .596 r
.61932 .58863 .62051 .59998 .62228 .59888 .62108 .58721 Mtetra
.331 .214 .567 r
.62108 .58721 .62228 .59888 .62408 .59859 .62306 .59309 Mtetra
.298 .244 .627 r
.62306 .59309 .62408 .59859 .62589 .59849 .62495 .59618 Mtetra
.222 .329 .762 r
.62495 .59618 .62589 .59849 .6277 .59832 .62681 .59773 Mtetra
.388 .743 .992 r
.62681 .59773 .6277 .59832 .62949 .59783 .62862 .59771 Mtetra
.506 .9 .941 r
.62862 .59771 .62949 .59783 .63129 .59717 .63042 .5971 Mtetra
.623 .951 .932 r
.63042 .5971 .63129 .59717 .63308 .59645 .63221 .59622 Mtetra
.66 .94 .964 r
.63221 .59622 .63308 .59645 .63487 .59574 .634 .59538 Mtetra
.689 .92 .971 r
.634 .59538 .63487 .59574 .63667 .59506 .63579 .59454 Mtetra
.704 .887 .964 r
.63579 .59454 .63667 .59506 .63847 .59441 .63758 .59372 Mtetra
.673 .835 .961 r
.63758 .59372 .63847 .59441 .64027 .59385 .63938 .59305 Mtetra
.65 .802 .955 r
.63938 .59305 .64027 .59385 .64207 .59336 .64119 .59248 Mtetra
.637 .78 .95 r
.64119 .59248 .64207 .59336 .64388 .59291 .64299 .59198 Mtetra
.639 .768 .941 r
.64299 .59198 .64388 .59291 .64569 .5925 .6448 .59148 Mtetra
.632 .746 .93 r
.6448 .59148 .64569 .5925 .6475 .59212 .64661 .59102 Mtetra
.619 .725 .922 r
.64661 .59102 .6475 .59212 .64932 .59174 .64843 .59062 Mtetra
.582 .704 .926 r
.64843 .59062 .64932 .59174 .65113 .59138 .65025 .59037 Mtetra
.559 .719 .947 r
.65025 .59037 .65113 .59138 .65295 .59101 .65207 .59016 Mtetra
.548 .754 .973 r
.65207 .59016 .65295 .59101 .65477 .59062 .6539 .58993 Mtetra
.458 .755 .993 r
.6539 .58993 .65477 .59062 .6566 .59059 .65573 .58984 Mtetra
.55 .778 .983 r
.65573 .58984 .6566 .59059 .65843 .59038 .65756 .58956 Mtetra
.693 .812 .939 r
.65756 .58956 .65843 .59038 .66023 .58951 .65936 .58883 Mtetra
.903 .847 .779 r
.65936 .58883 .66023 .58951 .66192 .58563 .66111 .58636 Mtetra
.989 .883 .552 r
.66111 .58636 .66192 .58563 .65567 .38711 .66273 .581 Mtetra
0 0 .407 r
.66273 .581 .65567 .38711 .65698 .37704 .65651 .38465 Mtetra
.3 .085 .411 r
.65651 .38465 .65698 .37704 .65863 .37503 .65807 .38046 Mtetra
.526 .245 .431 r
.65807 .38046 .65863 .37503 .66034 .37446 .6598 .38032 Mtetra
.534 .257 .44 r
.6598 .38032 .66034 .37446 .66206 .37429 .66153 .38027 Mtetra
.254 .033 .373 r
.66153 .38027 .66206 .37429 .66376 .37366 .66311 .37651 Mtetra
0 0 .108 r
.66311 .37651 .66376 .37366 .66546 .37274 .66469 .37309 Mtetra
.887 .984 .711 r
.66469 .37309 .66546 .37274 .66715 .37187 .66633 .37077 Mtetra
.767 .761 .848 r
.66633 .37077 .66715 .37187 .66886 .37119 .66801 .3696 Mtetra
.656 .645 .827 r
.66801 .3696 .66886 .37119 .67057 .37066 .66972 .36902 Mtetra
.618 .621 .831 r
.66972 .36902 .67057 .37066 .67229 .37018 .67145 .36866 Mtetra
.616 .637 .848 r
.67145 .36866 .67229 .37018 .67401 .36971 .67317 .36832 Mtetra
.62 .659 .866 r
.67317 .36832 .67401 .36971 .67573 .36922 .6749 .36796 Mtetra
.619 .68 .886 r
.6749 .36796 .67573 .36922 .67745 .36873 .67662 .3676 Mtetra
.636 .713 .903 r
.67662 .3676 .67745 .36873 .67917 .3682 .67835 .36716 Mtetra
.655 .739 .911 r
.67835 .36716 .67917 .3682 .68089 .36764 .68007 .36664 Mtetra
.67 .752 .912 r
.68007 .36664 .68089 .36764 .68261 .36706 .68179 .36604 Mtetra
.69 .757 .902 r
.68179 .36604 .68261 .36706 .68432 .36646 .6835 .36536 Mtetra
.699 .741 .884 r
.6835 .36536 .68432 .36646 .68604 .36586 .68522 .36461 Mtetra
.693 .713 .864 r
.68522 .36461 .68604 .36586 .68777 .36525 .68693 .36387 Mtetra
.675 .685 .851 r
.68693 .36387 .68777 .36525 .68949 .36465 .68865 .36322 Mtetra
.662 .67 .848 r
.68865 .36322 .68949 .36465 .69121 .36406 .69038 .36263 Mtetra
.658 .669 .85 r
.69038 .36263 .69121 .36406 .69294 .36347 .6921 .36206 Mtetra
.659 .674 .853 r
.6921 .36206 .69294 .36347 .69466 .36287 .69383 .36149 Mtetra
.661 .678 .855 r
.69383 .36149 .69466 .36287 .69639 .36228 .69556 .36091 Mtetra
.661 .68 .858 r
.69556 .36091 .69639 .36228 .69811 .36169 .69729 .36033 Mtetra
.689 .694 .849 r
.69729 .36033 .69811 .36169 .69983 .36086 .69901 .35959 Mtetra
.693 .71 .861 r
.69901 .35959 .69983 .36086 .70155 .36004 .70073 .35885 Mtetra
.632 .699 .894 r
.70073 .35885 .70155 .36004 .70329 .3597 .70247 .35842 Mtetra
.268 .489 .886 r
.70247 .35842 .70329 .3597 .70515 .36129 .70428 .35917 Mtetra
0 .052 .616 r
.70428 .35917 .70515 .36129 .70752 .37192 .70621 .36203 Mtetra
.98 .686 .353 r
.70621 .36203 .70752 .37192 .72067 .56886 .71797 .53582 Mtetra
.168 .072 .494 r
.71797 .53582 .72067 .56886 .72267 .57092 .72138 .5624 Mtetra
.567 .4 .614 r
.72138 .5624 .72267 .57092 .72454 .57059 .72326 .56225 Mtetra
.625 .442 .614 r
.72326 .56225 .72454 .57059 .72638 .56962 .72504 .56047 Mtetra
.646 .451 .606 r
.72504 .56047 .72638 .56962 .72821 .56868 .72677 .55777 Mtetra
.628 .432 .597 r
.72677 .55777 .72821 .56868 .73007 .568 .72851 .55525 Mtetra
.558 .376 .591 r
.72851 .55525 .73007 .568 .73192 .56739 .7304 .55529 Mtetra
.399 .265 .581 r
.7304 .55529 .73192 .56739 .7338 .56709 .73259 .56011 Mtetra
.334 .253 .613 r
.73259 .56011 .7338 .56709 .7357 .56701 .73471 .56381 Mtetra
.303 .322 .715 r
.73471 .56381 .7357 .56701 .73759 .56692 .73673 .56568 Mtetra
.381 .581 .92 r
.73673 .56568 .73759 .56692 .73947 .56661 .73866 .5661 Mtetra
.608 .87 .992 r
.73866 .5661 .73947 .56661 .74134 .56607 .74053 .56552 Mtetra
.702 .891 .966 r
.74053 .56552 .74134 .56607 .74321 .56547 .74238 .56467 Mtetra
.615 .798 .969 r
.74238 .56467 .74321 .56547 .7451 .5652 .74426 .5642 Mtetra
.53 .713 .956 r
.74426 .5642 .7451 .5652 .747 .56509 .74616 .56407 Mtetra
.675 .768 .92 r
.74616 .56407 .747 .56509 .74887 .56443 .74802 .5634 Mtetra
.895 .804 .751 r
.74802 .5634 .74887 .56443 .7506 .5617 .74975 .56065 Mtetra
.977 .73 .494 r
.74975 .56065 .7506 .5617 .7516 .54818 .75072 .54659 Mtetra
.976 .683 .39 r
.75072 .54659 .7516 .54818 .7401 .35048 .7393 .34936 Mtetra
.903 .781 .716 r
.7393 .34936 .7401 .35048 .74168 .34739 .74089 .34629 Mtetra
.707 .75 .886 r
.74089 .34629 .74168 .34739 .74342 .34659 .74263 .3455 Mtetra
.585 .703 .924 r
.74263 .3455 .74342 .34659 .7452 .34633 .74441 .34524 Mtetra
.643 .729 .911 r
.74441 .34524 .7452 .34633 .74697 .34584 .74618 .34476 Mtetra
.732 .763 .877 r
.74618 .34476 .74697 .34584 .7487 .34489 .74791 .34382 Mtetra
.633 .728 .916 r
.74791 .34382 .7487 .34489 .75047 .34444 .74968 .34338 Mtetra
0 .299 .793 r
.74968 .34338 .75047 .34444 .75237 .34577 .75158 .3447 Mtetra
.951 .603 .23 r
.75158 .3447 .75237 .34577 .75514 .35906 .75436 .35818 Mtetra
.975 .673 .364 r
.75436 .35818 .75514 .35906 .77125 .55506 .77042 .55407 Mtetra
.55 .08 0 r
.77042 .55407 .77125 .55506 .77337 .55763 .77254 .55663 Mtetra
.451 .675 .96 r
.77254 .55663 .77337 .55763 .77531 .55772 .77448 .55673 Mtetra
.733 .795 .902 r
.77448 .55673 .77531 .55772 .77717 .55677 .77634 .55575 Mtetra
.907 .81 .741 r
.77634 .55575 .77717 .55677 .77889 .55394 .77806 .55283 Mtetra
.979 .73 .489 r
.77806 .55283 .77889 .55394 .77997 .54255 .77895 .53901 Mtetra
.976 .679 .383 r
.77895 .53901 .77997 .54255 .76658 .34198 .76576 .3404 Mtetra
.876 .731 .698 r
.76576 .3404 .76658 .34198 .76814 .33858 .76733 .33718 Mtetra
.681 .69 .852 r
.76733 .33718 .76814 .33858 .76989 .33776 .76909 .33648 Mtetra
.561 .653 .897 r
.76909 .33648 .76989 .33776 .77169 .33753 .7709 .33635 Mtetra
.569 .678 .914 r
.7709 .33635 .77169 .33753 .77349 .3372 .77271 .33617 Mtetra
.702 .765 .901 r
.77271 .33617 .77349 .3372 .77524 .33631 .77447 .33541 Mtetra
.645 .774 .942 r
.77447 .33541 .77524 .33631 .77702 .33583 .77626 .33489 Mtetra
.388 .638 .955 r
.77626 .33489 .77702 .33583 .77892 .33671 .7781 .33513 Mtetra
0 .179 .713 r
.7781 .33513 .77892 .33671 .78129 .34341 .7801 .33721 Mtetra
0 0 .516 r
.7801 .33721 .78129 .34341 .79955 .54486 .78254 .34472 Mtetra
.087 .007 .46 r
.78254 .34472 .79955 .54486 .80179 .54835 .80049 .54136 Mtetra
.35 .266 .618 r
.80049 .54136 .80179 .54835 .80379 .54887 .80274 .54498 Mtetra
.447 .389 .7 r
.80274 .54498 .80379 .54887 .8057 .54831 .8048 .54618 Mtetra
.626 .592 .796 r
.8048 .54618 .8057 .54831 .80748 .54617 .80672 .5457 Mtetra
.949 .894 .74 r
.80672 .5457 .80748 .54617 .80883 .53894 .80843 .54272 Mtetra
0 0 .051 r
.80843 .54272 .80883 .53894 .79347 .33526 .80976 .53526 Mtetra
.081 0 .452 r
.80976 .53526 .79347 .33526 .7949 .33053 .7946 .33492 Mtetra
.025 0 .278 r
.7946 .33492 .7949 .33053 .7966 .32886 .79603 .33011 Mtetra
0 0 0 r
.79603 .33011 .7966 .32886 .79838 .32818 .79767 .32779 Mtetra
.678 .923 .973 r
.79767 .32779 .79838 .32818 .80028 .32882 .79945 .32698 Mtetra
.209 .36 .797 r
.79945 .32698 .80028 .32882 .80255 .33358 .80142 .32839 Mtetra
.134 .141 .6 r
.80142 .32839 .80255 .33358 .8224 .53686 .80369 .33316 Mtetra
.096 .015 .465 r
.80369 .33316 .8224 .53686 .82478 .54148 .82339 .5339 Mtetra
.293 .222 .603 r
.82339 .5339 .82478 .54148 .82683 .54229 .8258 .53872 Mtetra
.411 .379 .712 r
.8258 .53872 .82683 .54229 .82877 .5419 .8279 .54012 Mtetra
.683 .657 .818 r
.8279 .54012 .82877 .5419 .83057 .53992 .8298 .53927 Mtetra
.987 .797 .562 r
.8298 .53927 .83057 .53992 .83184 .53212 .83117 .53257 Mtetra
.978 .677 .346 r
.83117 .53257 .83184 .53212 .81495 .32725 .81423 .3266 Mtetra
.98 .815 .606 r
.81423 .3266 .81495 .32725 .81638 .32269 .81562 .32154 Mtetra
.81 .779 .824 r
.81562 .32154 .81638 .32269 .81811 .32123 .81733 .31999 Mtetra
.663 .71 .883 r
.81733 .31999 .81811 .32123 .81992 .32073 .81914 .31939 Mtetra
.349 .527 .89 r
.81914 .31939 .81992 .32073 .82185 .32145 .82105 .32 Mtetra
.671 .279 0 r
.82105 .32 .82185 .32145 .82417 .32634 .82335 .32453 Mtetra
.974 .665 .322 r
.82335 .32453 .82417 .32634 .84557 .53052 .84474 .52918 Mtetra
.716 .305 0 r
.84474 .52918 .84557 .53052 .84798 .53495 .8472 .534 Mtetra
.424 .672 .965 r
.8472 .534 .84798 .53495 .84998 .53494 .84921 .53414 Mtetra
.656 .821 .963 r
.84921 .53414 .84998 .53494 .8519 .53414 .85114 .53349 Mtetra
.725 .882 .953 r
.85114 .53349 .8519 .53414 .85379 .53304 .85305 .53254 Mtetra
.592 .875 .993 r
.85305 .53254 .85379 .53304 .85573 .53241 .85499 .53196 Mtetra
.6 .889 .99 r
.85499 .53196 .85573 .53241 .85767 .53178 .85693 .53132 Mtetra
.615 .894 .988 r
.85693 .53132 .85767 .53178 .85961 .53117 .85887 .53065 Mtetra
.642 .889 .985 r
.85887 .53065 .85961 .53117 .86156 .53062 .86081 .52994 Mtetra
.661 .856 .974 r
.86081 .52994 .86156 .53062 .86351 .53009 .86274 .52923 Mtetra
.647 .807 .96 r
.86274 .52923 .86351 .53009 .86547 .52965 .86469 .52863 Mtetra
.542 .719 .955 r
.86469 .52863 .86547 .52965 .86749 .52968 .86668 .52845 Mtetra
.619 .712 .912 r
.86668 .52845 .86749 .52968 .86946 .52926 .86865 .52803 Mtetra
.73 .756 .873 r
.86865 .52803 .86946 .52926 .87133 .52786 .87056 .527 Mtetra
.931 .847 .739 r
.87056 .527 .87133 .52786 .8727 .52172 .87226 .52399 Mtetra
0 0 0 r
.87226 .52399 .8727 .52172 .85333 .31725 .87362 .51768 Mtetra
.11 .024 .468 r
.87362 .51768 .85333 .31725 .85462 .31157 .85463 .31763 Mtetra
.172 0 .375 r
.85463 .31763 .85462 .31157 .85636 .31018 .85597 .31232 Mtetra
0 0 .119 r
.85597 .31232 .85636 .31018 .85818 .30946 .85758 .30965 Mtetra
.732 .976 .735 r
.85758 .30965 .85818 .30946 .86003 .30906 .85929 .30796 Mtetra
.704 .758 .894 r
.85929 .30796 .86003 .30906 .86186 .30846 .8611 .30716 Mtetra
.645 .694 .882 r
.8611 .30716 .86186 .30846 .8637 .30792 .86294 .30665 Mtetra
.625 .691 .892 r
.86294 .30665 .8637 .30792 .86554 .30736 .8648 .30623 Mtetra
.754 .772 .868 r
.8648 .30623 .86554 .30736 .86731 .30625 .86657 .30512 Mtetra
.688 .748 .898 r
.86657 .30512 .86731 .30625 .86913 .30552 .8684 .30441 Mtetra
.483 .652 .934 r
.8684 .30441 .86913 .30552 .87104 .30559 .87031 .30449 Mtetra
.757 .34 0 r
.87031 .30449 .87104 .30559 .87351 .31061 .87277 .30952 Mtetra
.971 .656 .295 r
.87277 .30952 .87351 .31061 .89834 .51553 .89757 .51448 Mtetra
.733 .299 0 r
.89757 .51448 .89834 .51553 .90091 .52022 .90014 .51917 Mtetra
.301 .577 .937 r
.90014 .51917 .90091 .52022 .90301 .52075 .90224 .5197 Mtetra
.648 .764 .933 r
.90224 .5197 .90301 .52075 .90499 .52017 .90422 .51912 Mtetra
.828 .821 .842 r
.90422 .51912 .90499 .52017 .90684 .51847 .90607 .51742 Mtetra
.908 .736 .657 r
.27062 .7 .27166 .70084 .2736 .69529 .27256 .69445 Mtetra
.936 .686 .535 r
.27256 .69445 .2736 .69529 .28902 .49978 .28805 .49888 Mtetra
.907 .728 .648 r
.28805 .49888 .28902 .49978 .29088 .49406 .28992 .49316 Mtetra
.772 .759 .841 r
.28992 .49316 .29088 .49406 .29242 .49294 .29145 .49204 Mtetra
.64 .736 .918 r
.29145 .49204 .29242 .49294 .2939 .49254 .29294 .49164 Mtetra
.511 .692 .95 r
.29294 .49164 .2939 .49254 .29537 .4925 .2944 .4916 Mtetra
.749 .758 .86 r
.2944 .4916 .29537 .4925 .29689 .49156 .29593 .49066 Mtetra
.697 .749 .892 r
.29593 .49066 .29689 .49156 .2984 .49092 .29743 .49002 Mtetra
.484 .681 .953 r
.29743 .49002 .2984 .49092 .29986 .49094 .29889 .49004 Mtetra
.926 .545 .248 r
.29889 .49004 .29986 .49094 .30105 .49491 .30009 .494 Mtetra
.939 .683 .523 r
.30009 .494 .30105 .49491 .28948 .68953 .28845 .68866 Mtetra
.936 .583 .329 r
.28845 .68866 .28948 .68953 .29067 .69492 .28964 .69406 Mtetra
.256 .595 .95 r
.28964 .69406 .29067 .69492 .29221 .69527 .29118 .69442 Mtetra
.668 .765 .923 r
.29118 .69442 .29221 .69527 .2938 .69474 .29277 .69387 Mtetra
.743 .776 .88 r
.29277 .69387 .2938 .69474 .29542 .69384 .29439 .69295 Mtetra
.426 .674 .966 r
.29439 .69295 .29542 .69384 .29697 .694 .29595 .69305 Mtetra
.554 .711 .945 r
.29595 .69305 .29697 .694 .29854 .69391 .29752 .6929 Mtetra
.725 .746 .869 r
.29752 .6929 .29854 .69391 .30015 .69311 .29914 .69204 Mtetra
.893 .73 .673 r
.29914 .69204 .30015 .69311 .30201 .68861 .30101 .68737 Mtetra
.939 .687 .529 r
.30101 .68737 .30201 .68861 .3159 .49302 .31497 .49159 Mtetra
.898 .701 .628 r
.31497 .49159 .3159 .49302 .31784 .4856 .31689 .48463 Mtetra
.797 .751 .811 r
.31689 .48463 .31784 .4856 .31941 .48415 .31845 .48321 Mtetra
.651 .733 .909 r
.31845 .48321 .31941 .48415 .32091 .48369 .31996 .48277 Mtetra
.516 .689 .946 r
.31996 .48277 .32091 .48369 .32239 .48365 .32144 .48272 Mtetra
.733 .754 .869 r
.32144 .48272 .32239 .48365 .32393 .48279 .32297 .48187 Mtetra
.705 .75 .887 r
.32297 .48187 .32393 .48279 .32545 .4821 .32449 .48119 Mtetra
.522 .695 .948 r
.32449 .48119 .32545 .4821 .32693 .48203 .32598 .48112 Mtetra
.908 .499 .165 r
.32598 .48112 .32693 .48203 .32822 .4854 .32726 .4845 Mtetra
.942 .683 .517 r
.32726 .4845 .32822 .4854 .31821 .68014 .31719 .67931 Mtetra
.939 .595 .347 r
.31719 .67931 .31821 .68014 .31942 .68634 .3184 .68549 Mtetra
.033 .46 .877 r
.3184 .68549 .31942 .68634 .32096 .68698 .31995 .68612 Mtetra
.657 .765 .929 r
.31995 .68612 .32096 .68698 .32257 .68648 .32156 .68562 Mtetra
.742 .779 .882 r
.32156 .68562 .32257 .68648 .32421 .68558 .32319 .6847 Mtetra
.492 .703 .963 r
.32319 .6847 .32421 .68558 .32579 .68562 .32477 .68466 Mtetra
.54 .706 .947 r
.32477 .68466 .32579 .68562 .32737 .68556 .32637 .68454 Mtetra
.712 .744 .877 r
.32637 .68454 .32737 .68556 .329 .68485 .328 .68376 Mtetra
.888 .735 .686 r
.328 .68376 .329 .68485 .3308 .6809 .32981 .67966 Mtetra
.942 .687 .523 r
.32981 .67966 .3308 .6809 .34309 .48617 .34219 .4843 Mtetra
.895 .686 .614 r
.34219 .4843 .34309 .48617 .34508 .47704 .34414 .47602 Mtetra
.815 .747 .788 r
.34414 .47602 .34508 .47704 .34667 .47531 .34573 .47434 Mtetra
.649 .727 .906 r
.34573 .47434 .34667 .47531 .3482 .47485 .34725 .4739 Mtetra
.498 .676 .944 r
.34725 .4739 .3482 .47485 .34969 .47484 .34875 .4739 Mtetra
.613 .721 .923 r
.34875 .4739 .34969 .47484 .35121 .47452 .35026 .47359 Mtetra
.658 .739 .909 r
.35026 .47359 .35121 .47452 .35274 .47401 .35179 .47311 Mtetra
.668 .746 .909 r
.35179 .47311 .35274 .47401 .35427 .47346 .35332 .47259 Mtetra
.761 .771 .86 r
.35332 .47259 .35427 .47346 .35582 .47237 .35487 .47157 Mtetra
.744 .783 .884 r
.35487 .47157 .35582 .47237 .35738 .47143 .35642 .47069 Mtetra
.578 .761 .965 r
.35642 .47069 .35738 .47143 .3589 .47111 .35794 .47043 Mtetra
.878 .44 .114 r
.35794 .47043 .3589 .47111 .36027 .47379 .3593 .47326 Mtetra
.945 .684 .509 r
.3593 .47326 .36027 .47379 .35212 .66901 .35108 .66877 Mtetra
.925 .592 .39 r
.35108 .66877 .35212 .66901 .35334 .67669 .35233 .67585 Mtetra
0 .244 .706 r
.35233 .67585 .35334 .67669 .35489 .67774 .35388 .67685 Mtetra
.637 .755 .934 r
.35388 .67685 .35489 .67774 .35651 .67732 .35551 .67642 Mtetra
.737 .774 .882 r
.35551 .67642 .35651 .67732 .35816 .67642 .35716 .67551 Mtetra
.696 .764 .904 r
.35716 .67551 .35816 .67642 .3598 .67578 .3588 .67483 Mtetra
.658 .747 .915 r
.3588 .67483 .3598 .67578 .36143 .67532 .36044 .67431 Mtetra
.657 .736 .908 r
.36044 .67431 .36143 .67532 .36306 .67486 .36207 .6738 Mtetra
.626 .717 .912 r
.36207 .6738 .36306 .67486 .36469 .67462 .3637 .67342 Mtetra
.628 .692 .89 r
.3637 .67342 .36469 .67462 .36631 .67432 .36533 .67304 Mtetra
.662 .688 .864 r
.36533 .67304 .36631 .67432 .36795 .67366 .36697 .6725 Mtetra
.716 .722 .855 r
.36697 .6725 .36795 .67366 .36965 .67178 .36862 .67165 Mtetra
.82 .944 .906 r
.36862 .67165 .36965 .67178 .37144 .66797 .37029 .67033 Mtetra
0 0 0 r
.37029 .67033 .37144 .66797 .37369 .65322 .37201 .66814 Mtetra
.315 .112 .437 r
.37201 .66814 .37369 .65322 .38327 .46806 .37392 .66134 Mtetra
0 0 .281 r
.37392 .66134 .38327 .46806 .38495 .46454 .38388 .46675 Mtetra
.873 .878 .441 r
.38388 .46675 .38495 .46454 .38656 .46251 .3856 .46209 Mtetra
.863 .861 .836 r
.3856 .46209 .38656 .46251 .38813 .46144 .3872 .46042 Mtetra
.679 .728 .887 r
.3872 .46042 .38813 .46144 .38967 .4609 .38875 .45984 Mtetra
.583 .688 .913 r
.38875 .45984 .38967 .4609 .39121 .4606 .39028 .45963 Mtetra
.592 .712 .927 r
.39028 .45963 .39121 .4606 .39275 .46031 .39182 .45939 Mtetra
.621 .731 .925 r
.39182 .45939 .39275 .46031 .3943 .45998 .39337 .45903 Mtetra
.622 .727 .922 r
.39337 .45903 .3943 .45998 .39584 .45965 .39491 .45868 Mtetra
.639 .729 .914 r
.39491 .45868 .39584 .45965 .39739 .45923 .39646 .45827 Mtetra
.656 .735 .908 r
.39646 .45827 .39739 .45923 .39894 .45874 .39801 .4578 Mtetra
.668 .743 .906 r
.39801 .4578 .39894 .45874 .4005 .45817 .39957 .45727 Mtetra
.684 .755 .905 r
.39957 .45727 .4005 .45817 .40206 .45751 .40113 .45667 Mtetra
.695 .772 .911 r
.40113 .45667 .40206 .45751 .40362 .45679 .40269 .45603 Mtetra
.697 .79 .923 r
.40269 .45603 .40362 .45679 .40518 .45608 .40425 .45538 Mtetra
.705 .808 .929 r
.40425 .45538 .40518 .45608 .40675 .45529 .40581 .4547 Mtetra
.694 .835 .951 r
.40581 .4547 .40675 .45529 .40832 .45456 .40738 .45406 Mtetra
.632 .844 .981 r
.40738 .45406 .40832 .45456 .40987 .45417 .40893 .45357 Mtetra
.529 .787 .992 r
.40893 .45357 .40987 .45417 .41139 .45475 .41048 .45335 Mtetra
.479 .579 .877 r
.41048 .45335 .41139 .45475 .41286 .45704 .41202 .45355 Mtetra
.443 .382 .694 r
.41202 .45355 .41286 .45704 .41408 .46657 .41353 .45449 Mtetra
.386 .243 .562 r
.41353 .45449 .41408 .46657 .40936 .65553 .41493 .4589 Mtetra
0 0 .316 r
.41493 .4589 .40936 .65553 .4109 .65864 .41005 .65373 Mtetra
0 0 .505 r
.41005 .65373 .4109 .65864 .4125 .66 .41154 .65833 Mtetra
.124 .344 .808 r
.41154 .65833 .4125 .66 .41414 .66037 .41315 .6595 Mtetra
.565 .74 .958 r
.41315 .6595 .41414 .66037 .41579 .66014 .41481 .65927 Mtetra
.689 .778 .919 r
.41481 .65927 .41579 .66014 .41746 .65963 .41648 .65861 Mtetra
.7 .749 .89 r
.41648 .65861 .41746 .65963 .41913 .65901 .41815 .65789 Mtetra
.683 .725 .882 r
.41815 .65789 .41913 .65901 .4208 .65835 .41983 .65724 Mtetra
.688 .729 .881 r
.41983 .65724 .4208 .65835 .42248 .65766 .4215 .65656 Mtetra
.679 .73 .889 r
.4215 .65656 .42248 .65766 .42415 .65702 .42318 .65594 Mtetra
.663 .726 .897 r
.42318 .65594 .42415 .65702 .42582 .65649 .42485 .65539 Mtetra
.657 .723 .897 r
.42485 .65539 .42582 .65649 .42749 .65598 .42652 .65487 Mtetra
.656 .721 .896 r
.42652 .65487 .42749 .65598 .42917 .65547 .4282 .65435 Mtetra
.657 .72 .895 r
.4282 .65435 .42917 .65547 .43084 .65495 .42987 .65383 Mtetra
.656 .719 .895 r
.42987 .65383 .43084 .65495 .43252 .65443 .43155 .65332 Mtetra
.655 .719 .896 r
.43155 .65332 .43252 .65443 .43419 .65391 .43322 .6528 Mtetra
.654 .72 .897 r
.43322 .6528 .43419 .65391 .43587 .65339 .4349 .6523 Mtetra
.653 .722 .899 r
.4349 .6523 .43587 .65339 .43755 .65287 .43658 .65179 Mtetra
.652 .725 .902 r
.43658 .65179 .43755 .65287 .43923 .65235 .43826 .65129 Mtetra
.651 .73 .906 r
.43826 .65129 .43923 .65235 .44091 .65182 .43994 .65079 Mtetra
.648 .735 .913 r
.43994 .65079 .44091 .65182 .44259 .6513 .44162 .65031 Mtetra
.642 .74 .921 r
.44162 .65031 .44259 .6513 .44427 .6508 .4433 .64985 Mtetra
.634 .746 .929 r
.4433 .64985 .44427 .6508 .44595 .65033 .44498 .64941 Mtetra
.632 .753 .935 r
.44498 .64941 .44595 .65033 .44763 .64987 .44666 .64898 Mtetra
.58 .743 .953 r
.44666 .64898 .44763 .64987 .44932 .64952 .44834 .64871 Mtetra
.529 .745 .974 r
.44834 .64871 .44932 .64952 .451 .64923 .45002 .64855 Mtetra
.664 .818 .958 r
.45002 .64855 .451 .64923 .45269 .6487 .45171 .64796 Mtetra
.857 .815 .807 r
.45171 .64796 .45269 .6487 .45439 .64738 .45343 .646 Mtetra
.909 .722 .637 r
.45343 .646 .45439 .64738 .45612 .64458 .45523 .63997 Mtetra
.951 .685 .496 r
.45523 .63997 .45612 .64458 .45789 .64001 .46077 .44334 Mtetra
.562 .347 .546 r
.46077 .44334 .45789 .64001 .45971 .63273 .46244 .4387 Mtetra
.555 .341 .545 r
.46244 .4387 .45971 .63273 .46142 .63079 .46404 .43783 Mtetra
.554 .34 .545 r
.46404 .43783 .46142 .63079 .46306 .63291 .46563 .43769 Mtetra
.553 .34 .544 r
.46563 .43769 .46306 .63291 .4647 .63509 .46721 .43776 Mtetra
.554 .34 .545 r
.46721 .43776 .4647 .63509 .46636 .6362 .4688 .43752 Mtetra
.554 .341 .545 r
.4688 .43752 .46636 .6362 .46806 .63559 .4704 .43705 Mtetra
.556 .342 .545 r
.4704 .43705 .46806 .63559 .4699 .62542 .47201 .4359 Mtetra
.557 .343 .545 r
.47201 .4359 .4699 .62542 .47448 .43815 .47363 .43408 Mtetra
.676 .518 .665 r
.47363 .43408 .47448 .43815 .47613 .43404 .47524 .43249 Mtetra
.734 .671 .789 r
.47524 .43249 .47613 .43404 .47776 .432 .47685 .43134 Mtetra
.676 .819 .952 r
.47685 .43134 .47776 .432 .47936 .43129 .47845 .43075 Mtetra
.613 .833 .984 r
.47845 .43075 .47936 .43129 .48095 .43092 .48005 .43031 Mtetra
.612 .814 .978 r
.48005 .43031 .48095 .43092 .48255 .43062 .48165 .42989 Mtetra
.653 .797 .951 r
.48165 .42989 .48255 .43062 .48415 .43012 .48325 .42939 Mtetra
.65 .793 .951 r
.48325 .42939 .48415 .43012 .48576 .42965 .48486 .42889 Mtetra
.64 .785 .951 r
.48486 .42889 .48576 .42965 .48736 .42924 .48646 .42843 Mtetra
.625 .769 .949 r
.48646 .42843 .48736 .42924 .48896 .42891 .48807 .42803 Mtetra
.633 .753 .935 r
.48807 .42803 .48896 .42891 .49057 .42857 .48967 .42762 Mtetra
.655 .743 .915 r
.48967 .42762 .49057 .42857 .49217 .42812 .49128 .42712 Mtetra
.687 .743 .894 r
.49128 .42712 .49217 .42812 .49378 .42747 .49289 .42649 Mtetra
.693 .748 .894 r
.49289 .42649 .49378 .42747 .49539 .42679 .4945 .42583 Mtetra
.688 .752 .9 r
.4945 .42583 .49539 .42679 .497 .42613 .49611 .42519 Mtetra
.671 .751 .911 r
.49611 .42519 .497 .42613 .49861 .42558 .49772 .42463 Mtetra
.666 .748 .912 r
.49772 .42463 .49861 .42558 .50023 .42505 .49933 .42409 Mtetra
.664 .745 .911 r
.49933 .42409 .50023 .42505 .50184 .42453 .50095 .42356 Mtetra
.664 .743 .909 r
.50095 .42356 .50184 .42453 .50345 .42401 .50256 .42303 Mtetra
.663 .742 .908 r
.50256 .42303 .50345 .42401 .50507 .42348 .50418 .4225 Mtetra
.663 .741 .908 r
.50418 .4225 .50507 .42348 .50668 .42295 .50579 .42197 Mtetra
.50579 .42197 .50668 .42295 .5083 .42243 .50741 .42145 Mtetra
.662 .741 .908 r
.50741 .42145 .5083 .42243 .50992 .4219 .50903 .42092 Mtetra
.50903 .42092 .50992 .4219 .51153 .42138 .51065 .4204 Mtetra
.663 .741 .908 r
.51065 .4204 .51153 .42138 .51315 .42085 .51227 .41987 Mtetra
.51227 .41987 .51315 .42085 .51477 .42032 .51389 .41934 Mtetra
.51389 .41934 .51477 .42032 .51639 .4198 .51551 .41881 Mtetra
.663 .74 .907 r
.51551 .41881 .51639 .4198 .51802 .41927 .51713 .41828 Mtetra
.664 .74 .907 r
.51713 .41828 .51802 .41927 .51964 .41874 .51876 .41774 Mtetra
.665 .74 .906 r
.51876 .41774 .51964 .41874 .52126 .4182 .52038 .4172 Mtetra
.668 .74 .904 r
.52038 .4172 .52126 .4182 .52289 .41766 .52201 .41665 Mtetra
.667 .738 .903 r
.52201 .41665 .52289 .41766 .52451 .41712 .52363 .4161 Mtetra
.677 .74 .898 r
.52363 .4161 .52451 .41712 .52614 .41655 .52526 .41551 Mtetra
.722 .748 .872 r
.52526 .41551 .52614 .41655 .52777 .41583 .52689 .41467 Mtetra
.661 .706 .881 r
.52689 .41467 .52777 .41583 .5294 .41529 .52852 .41414 Mtetra
.439 .609 .92 r
.52852 .41414 .5294 .41529 .53103 .41521 .53015 .41436 Mtetra
.855 .41 .004 r
.53015 .41436 .53103 .41521 .53266 .41652 .53179 .41768 Mtetra
.961 .682 .461 r
.53179 .41768 .53266 .41652 .53431 .41925 .53394 .61306 Mtetra
.565 .345 .54 r
.53394 .61306 .53431 .41925 .53597 .42659 .5357 .62048 Mtetra
.554 .336 .539 r
.5357 .62048 .53597 .42659 .53831 .6063 .53744 .62124 Mtetra
.532 .293 .498 r
.53744 .62124 .53831 .6063 .54004 .60427 .53918 .62061 Mtetra
.495 .265 .495 r
.53918 .62061 .54004 .60427 .54088 .42281 .54092 .61832 Mtetra
.525 .313 .535 r
.54092 .61832 .54088 .42281 .54249 .41579 .54258 .60247 Mtetra
0 0 .36 r
.54258 .60247 .54249 .41579 .54411 .41235 .54324 .41285 Mtetra
.977 .921 .652 r
.54324 .41285 .54411 .41235 .54574 .41022 .54487 .40921 Mtetra
.745 .761 .865 r
.54487 .40921 .54574 .41022 .54738 .40943 .5465 .40824 Mtetra
.645 .695 .882 r
.5465 .40824 .54738 .40943 .54902 .40895 .54814 .40778 Mtetra
.586 .676 .902 r
.54814 .40778 .54902 .40895 .55066 .40861 .54979 .40756 Mtetra
.664 .731 .899 r
.54979 .40756 .55066 .40861 .5523 .40806 .55143 .40702 Mtetra
.663 .732 .901 r
.55143 .40702 .5523 .40806 .55395 .4075 .55308 .40648 Mtetra
.663 .735 .904 r
.55308 .40648 .55395 .4075 .55559 .40695 .55472 .40595 Mtetra
.666 .74 .905 r
.55472 .40595 .55559 .40695 .55724 .40639 .55637 .4054 Mtetra
.666 .742 .907 r
.55637 .4054 .55724 .40639 .55888 .40584 .55801 .40485 Mtetra
.667 .744 .908 r
.55801 .40485 .55888 .40584 .56053 .40528 .55966 .40429 Mtetra
.667 .745 .909 r
.55966 .40429 .56053 .40528 .56218 .40472 .56131 .40374 Mtetra
.667 .746 .91 r
.56131 .40374 .56218 .40472 .56383 .40416 .56296 .40318 Mtetra
.667 .747 .911 r
.56296 .40318 .56383 .40416 .56548 .4036 .56461 .40263 Mtetra
.667 .748 .911 r
.56461 .40263 .56548 .4036 .56713 .40304 .56626 .40207 Mtetra
.666 .749 .912 r
.56626 .40207 .56713 .40304 .56878 .40248 .56791 .40152 Mtetra
.666 .749 .913 r
.56791 .40152 .56878 .40248 .57043 .40193 .56957 .40096 Mtetra
.665 .75 .913 r
.56957 .40096 .57043 .40193 .57209 .40138 .57122 .40041 Mtetra
.665 .75 .914 r
.57122 .40041 .57209 .40138 .57374 .40083 .57288 .39987 Mtetra
.663 .751 .915 r
.57288 .39987 .57374 .40083 .5754 .40028 .57454 .39932 Mtetra
.664 .752 .916 r
.57454 .39932 .5754 .40028 .57705 .39972 .57619 .39878 Mtetra
.661 .754 .919 r
.57619 .39878 .57705 .39972 .57871 .39918 .57785 .39824 Mtetra
.654 .754 .923 r
.57785 .39824 .57871 .39918 .58037 .39866 .57951 .39774 Mtetra
.629 .747 .932 r
.57951 .39774 .58037 .39866 .58203 .39827 .58118 .39732 Mtetra
.628 .741 .929 r
.58118 .39732 .58203 .39827 .5837 .39789 .58284 .39691 Mtetra
.638 .739 .922 r
.58284 .39691 .5837 .39789 .58536 .39746 .5845 .39647 Mtetra
.677 .751 .906 r
.5845 .39647 .58536 .39746 .58702 .39679 .58617 .39587 Mtetra
.688 .767 .912 r
.58617 .39587 .58702 .39679 .58868 .39607 .58783 .39521 Mtetra
.69 .784 .923 r
.58783 .39521 .58868 .39607 .59035 .39534 .58949 .39455 Mtetra
.668 .795 .942 r
.58949 .39455 .59035 .39534 .59201 .39474 .59116 .39398 Mtetra
.66 .799 .949 r
.59116 .39398 .59201 .39474 .59368 .39417 .59283 .39343 Mtetra
.656 .802 .953 r
.59283 .39343 .59368 .39417 .59534 .39362 .5945 .39288 Mtetra
.659 .804 .953 r
.5945 .39288 .59534 .39362 .59701 .39306 .59617 .39233 Mtetra
.659 .807 .955 r
.59617 .39233 .59701 .39306 .59868 .3925 .59784 .39178 Mtetra
.659 .81 .956 r
.59784 .39178 .59868 .3925 .60035 .39194 .59951 .39122 Mtetra
.692 .82 .944 r
.59951 .39122 .60035 .39194 .60202 .39114 .60118 .39055 Mtetra
.668 .846 .968 r
.60118 .39055 .60202 .39114 .60369 .39049 .60285 .38993 Mtetra
.605 .837 .987 r
.60285 .38993 .60369 .39049 .60537 .39021 .60453 .38948 Mtetra
.341 .669 .975 r
.60453 .38948 .60537 .39021 .60709 .39153 .60622 .38966 Mtetra
.434 .493 .821 r
.60622 .38966 .60709 .39153 .60887 .39498 .60793 .3902 Mtetra
.508 .395 .66 r
.60793 .3902 .60887 .39498 .61568 .58685 .60964 .3909 Mtetra
.555 .341 .545 r
.60964 .3909 .61568 .58685 .61757 .59023 .61131 .39018 Mtetra
.61131 .39018 .61757 .59023 .61932 .58863 .61299 .38933 Mtetra
.554 .34 .545 r
.61299 .38933 .61932 .58863 .62108 .58721 .61468 .38915 Mtetra
.543 .332 .544 r
.61468 .38915 .62108 .58721 .62306 .59309 .61654 .39494 Mtetra
0 0 .405 r
.61654 .39494 .62306 .59309 .62495 .59618 .62398 .59256 Mtetra
0 .025 .569 r
.62398 .59256 .62495 .59618 .62681 .59773 .62591 .59658 Mtetra
.357 .585 .93 r
.62591 .59658 .62681 .59773 .62862 .59771 .62774 .59698 Mtetra
.652 .82 .964 r
.62774 .59698 .62862 .59771 .63042 .5971 .62953 .5964 Mtetra
.751 .85 .924 r
.62953 .5964 .63042 .5971 .63221 .59622 .63132 .5954 Mtetra
.715 .815 .927 r
.63132 .5954 .63221 .59622 .634 .59538 .63311 .59457 Mtetra
.705 .816 .934 r
.63311 .59457 .634 .59538 .63579 .59454 .63491 .59379 Mtetra
.705 .828 .941 r
.63491 .59379 .63579 .59454 .63758 .59372 .6367 .593 Mtetra
.679 .832 .957 r
.6367 .593 .63758 .59372 .63938 .59305 .6385 .59232 Mtetra
.661 .822 .961 r
.6385 .59232 .63938 .59305 .64119 .59248 .6403 .5917 Mtetra
.653 .806 .957 r
.6403 .5917 .64119 .59248 .64299 .59198 .64211 .59112 Mtetra
.654 .789 .946 r
.64211 .59112 .64299 .59198 .6448 .59148 .64392 .59055 Mtetra
.648 .771 .938 r
.64392 .59055 .6448 .59148 .64661 .59102 .64573 .59002 Mtetra
.636 .75 .931 r
.64573 .59002 .64661 .59102 .64843 .59062 .64754 .58954 Mtetra
.609 .722 .926 r
.64754 .58954 .64843 .59062 .65025 .59037 .64936 .58918 Mtetra
.599 .697 .912 r
.64936 .58918 .65025 .59037 .65207 .59016 .65118 .58887 Mtetra
.602 .68 .896 r
.65118 .58887 .65207 .59016 .6539 .58993 .653 .58857 Mtetra
.591 .663 .888 r
.653 .58857 .6539 .58993 .65573 .58984 .65482 .58832 Mtetra
.613 .648 .861 r
.65482 .58832 .65573 .58984 .65756 .58956 .65665 .58798 Mtetra
.651 .656 .842 r
.65665 .58798 .65756 .58956 .65936 .58883 .65847 .58741 Mtetra
.755 .719 .818 r
.65847 .58741 .65936 .58883 .66111 .58636 .66025 .58612 Mtetra
.88 .951 .85 r
.66025 .58612 .66111 .58636 .66273 .581 .66202 .58427 Mtetra
.219 0 .254 r
.66202 .58427 .66273 .581 .65651 .38465 .66377 .58209 Mtetra
.552 .334 .538 r
.66377 .58209 .65651 .38465 .65807 .38046 .66559 .58146 Mtetra
.553 .335 .538 r
.66559 .58146 .65807 .38046 .6598 .38032 .66743 .58142 Mtetra
.551 .334 .538 r
.66743 .58142 .6598 .38032 .66153 .38027 .66924 .58059 Mtetra
.541 .326 .537 r
.66924 .58059 .66153 .38027 .66311 .37651 .67076 .57298 Mtetra
.006 0 .41 r
.67076 .57298 .66311 .37651 .66469 .37309 .66398 .37463 Mtetra
.833 .841 .374 r
.66398 .37463 .66469 .37309 .66633 .37077 .66552 .37009 Mtetra
.852 .854 .843 r
.66552 .37009 .66633 .37077 .66801 .3696 .66718 .36844 Mtetra
.672 .72 .885 r
.66718 .36844 .66801 .3696 .66972 .36902 .66889 .36783 Mtetra
.59 .681 .904 r
.66889 .36783 .66972 .36902 .67145 .36866 .67062 .36758 Mtetra
.601 .707 .919 r
.67062 .36758 .67145 .36866 .67317 .36832 .67235 .36728 Mtetra
.62 .723 .92 r
.67235 .36728 .67317 .36832 .6749 .36796 .67408 .3669 Mtetra
.62 .719 .917 r
.67408 .3669 .6749 .36796 .67662 .3676 .6758 .36652 Mtetra
.637 .721 .909 r
.6758 .36652 .67662 .3676 .67835 .36716 .67753 .36607 Mtetra
.652 .727 .904 r
.67753 .36607 .67835 .36716 .68007 .36664 .67925 .36556 Mtetra
.663 .733 .902 r
.67925 .36556 .68007 .36664 .68179 .36604 .68097 .365 Mtetra
.678 .745 .901 r
.68097 .365 .68179 .36604 .6835 .36536 .68269 .36436 Mtetra
.688 .76 .907 r
.68269 .36436 .6835 .36536 .68522 .36461 .68441 .36369 Mtetra
.688 .776 .918 r
.68441 .36369 .68522 .36461 .68693 .36387 .68613 .36302 Mtetra
.675 .788 .934 r
.68613 .36302 .68693 .36387 .68865 .36322 .68785 .3624 Mtetra
.662 .793 .944 r
.68785 .3624 .68865 .36322 .69038 .36263 .68957 .36182 Mtetra
.657 .795 .948 r
.68957 .36182 .69038 .36263 .6921 .36206 .6913 .36126 Mtetra
.657 .797 .95 r
.6913 .36126 .6921 .36206 .69383 .36149 .69303 .3607 Mtetra
.658 .801 .951 r
.69303 .3607 .69383 .36149 .69556 .36091 .69476 .36014 Mtetra
.658 .804 .953 r
.69476 .36014 .69556 .36091 .69729 .36033 .69649 .35957 Mtetra
.68 .814 .947 r
.69649 .35957 .69729 .36033 .69901 .35959 .69822 .35892 Mtetra
.678 .837 .96 r
.69822 .35892 .69901 .35959 .70073 .35885 .69994 .35826 Mtetra
.624 .842 .983 r
.69994 .35826 .70073 .35885 .70247 .35842 .70168 .35774 Mtetra
.432 .732 .989 r
.70168 .35774 .70247 .35842 .70428 .35917 .70345 .35772 Mtetra
.389 .529 .876 r
.70345 .35772 .70428 .35917 .70621 .36203 .70524 .35825 Mtetra
.486 .407 .693 r
.70524 .35825 .70621 .36203 .71797 .53582 .70706 .35903 Mtetra
.553 .34 .545 r
.70706 .35903 .71797 .53582 .72138 .5624 .70885 .3593 Mtetra
.554 .341 .545 r
.70885 .3593 .72138 .5624 .72326 .56225 .71059 .35872 Mtetra
.555 .341 .545 r
.71059 .35872 .72326 .56225 .72504 .56047 .71231 .35786 Mtetra
.71231 .35786 .72504 .56047 .72677 .55777 .71402 .3567 Mtetra
.71402 .3567 .72677 .55777 .72851 .55525 .71574 .35565 Mtetra
.554 .34 .545 r
.71574 .35565 .72851 .55525 .7304 .55529 .71749 .3553 Mtetra
.549 .336 .544 r
.71749 .3553 .7304 .55529 .73259 .56011 .71944 .35806 Mtetra
.052 0 .441 r
.71944 .35806 .73259 .56011 .73471 .56381 .73357 .55794 Mtetra
.039 .064 .558 r
.73357 .55794 .73471 .56381 .73673 .56568 .73583 .56386 Mtetra
.216 .383 .816 r
.73583 .56386 .73673 .56568 .73866 .5661 .73782 .56516 Mtetra
.622 .766 .949 r
.73782 .56516 .73866 .5661 .74053 .56552 .73969 .5647 Mtetra
.729 .829 .927 r
.73969 .5647 .74053 .56552 .74238 .56467 .74154 .56378 Mtetra
.646 .787 .949 r
.74154 .56378 .74238 .56467 .74426 .5642 .74341 .56322 Mtetra
.532 .718 .959 r
.74341 .56322 .74426 .5642 .74616 .56407 .74532 .56308 Mtetra
.68 .776 .923 r
.74532 .56308 .74616 .56407 .74802 .5634 .74718 .56239 Mtetra
.898 .807 .75 r
.74718 .56239 .74802 .5634 .74975 .56065 .74891 .5596 Mtetra
.978 .729 .49 r
.74891 .5596 .74975 .56065 .75072 .54659 .74985 .54505 Mtetra
.976 .683 .39 r
.74985 .54505 .75072 .54659 .7393 .34936 .7385 .34825 Mtetra
.904 .783 .717 r
.7385 .34825 .7393 .34936 .74089 .34629 .74009 .34521 Mtetra
.706 .752 .888 r
.74009 .34521 .74089 .34629 .74263 .3455 .74184 .34442 Mtetra
.583 .703 .925 r
.74184 .34442 .74263 .3455 .74441 .34524 .74362 .34416 Mtetra
.642 .729 .912 r
.74362 .34416 .74441 .34524 .74618 .34476 .74538 .34368 Mtetra
.731 .763 .878 r
.74538 .34368 .74618 .34476 .74791 .34382 .74712 .34275 Mtetra
.632 .728 .917 r
.74712 .34275 .74791 .34382 .74968 .34338 .74889 .34231 Mtetra
0 .297 .791 r
.74889 .34231 .74968 .34338 .75158 .3447 .75079 .34365 Mtetra
.952 .604 .232 r
.75079 .34365 .75158 .3447 .75436 .35818 .75358 .35727 Mtetra
.975 .673 .364 r
.75358 .35727 .75436 .35818 .77042 .55407 .76959 .55307 Mtetra
0 0 .451 r
.76959 .55307 .77042 .55407 .77254 .55663 .77171 .55562 Mtetra
.457 .675 .958 r
.77171 .55562 .77254 .55663 .77448 .55673 .77365 .5557 Mtetra
.733 .79 .898 r
.77365 .5557 .77448 .55673 .77634 .55575 .77551 .55473 Mtetra
.905 .808 .741 r
.77551 .55473 .77634 .55575 .77806 .55283 .77723 .55181 Mtetra
.98 .734 .49 r
.77723 .55181 .77806 .55283 .77895 .53901 .77816 .53844 Mtetra
.978 .681 .374 r
.77816 .53844 .77895 .53901 .76576 .3404 .76498 .33943 Mtetra
.924 .802 .708 r
.76498 .33943 .76576 .3404 .76733 .33718 .76655 .33618 Mtetra
.697 .768 .906 r
.76655 .33618 .76733 .33718 .76909 .33648 .76831 .33544 Mtetra
.552 .701 .939 r
.76831 .33544 .76909 .33648 .7709 .33635 .77012 .33528 Mtetra
.552 .693 .933 r
.77012 .33528 .7709 .33635 .77271 .33617 .77193 .33513 Mtetra
.677 .754 .909 r
.77193 .33513 .77271 .33617 .77447 .33541 .77371 .33449 Mtetra
.655 .773 .936 r
.77371 .33449 .77447 .33541 .77626 .33489 .77549 .33393 Mtetra
.605 .745 .943 r
.77549 .33393 .77626 .33489 .7781 .33513 .77729 .33357 Mtetra
.551 .603 .858 r
.77729 .33357 .7781 .33513 .7801 .33721 .77911 .33354 Mtetra
.508 .427 .699 r
.77911 .33354 .7801 .33721 .78254 .34472 .78099 .33411 Mtetra
.462 .314 .594 r
.78099 .33411 .78254 .34472 .80049 .54136 .78305 .33693 Mtetra
.088 .007 .46 r
.78305 .33693 .80049 .54136 .80274 .54498 .8014 .53761 Mtetra
.18 .146 .58 r
.8014 .53761 .80274 .54498 .8048 .54618 .80386 .54373 Mtetra
.302 .372 .768 r
.80386 .54373 .8048 .54618 .80672 .5457 .80595 .5452 Mtetra
.679 .901 .975 r
.80595 .5452 .80672 .5457 .80843 .54272 .80784 .54438 Mtetra
0 0 0 r
.80784 .54438 .80843 .54272 .80976 .53526 .80963 .54236 Mtetra
.264 .057 .4 r
.80963 .54236 .80976 .53526 .7946 .33492 .81119 .53763 Mtetra
.081 0 .453 r
.81119 .53763 .7946 .33492 .79603 .33011 .79575 .33466 Mtetra
0 0 .207 r
.79575 .33466 .79603 .33011 .79767 .32779 .79702 .32803 Mtetra
.884 .979 .688 r
.79702 .32803 .79767 .32779 .79945 .32698 .79865 .3256 Mtetra
.609 .663 .877 r
.79865 .3256 .79945 .32698 .80142 .32839 .80047 .32527 Mtetra
.48 .432 .726 r
.80047 .32527 .80142 .32839 .80369 .33316 .80238 .32598 Mtetra
.393 .289 .616 r
.80238 .32598 .80369 .33316 .82339 .5339 .80451 .32907 Mtetra
.093 .013 .464 r
.80451 .32907 .82339 .5339 .8258 .53872 .82447 .53191 Mtetra
.181 .153 .589 r
.82447 .53191 .8258 .53872 .8279 .54012 .82696 .53765 Mtetra
.494 .49 .781 r
.82696 .53765 .8279 .54012 .8298 .53927 .82898 .5381 Mtetra
.965 .77 .591 r
.82898 .5381 .8298 .53927 .83117 .53257 .83039 .53177 Mtetra
.977 .676 .35 r
.83039 .53177 .83117 .53257 .81423 .3266 .81348 .32565 Mtetra
.967 .788 .611 r
.81348 .32565 .81423 .3266 .81562 .32154 .81486 .32044 Mtetra
.81 .787 .832 r
.81486 .32044 .81562 .32154 .81733 .31999 .81657 .31892 Mtetra
.658 .746 .915 r
.81657 .31892 .81733 .31999 .81914 .31939 .81838 .31836 Mtetra
.248 .532 .919 r
.81838 .31836 .81914 .31939 .82105 .32 .8203 .319 Mtetra
.786 .358 0 r
.8203 .319 .82105 .32 .82335 .32453 .82261 .32367 Mtetra
.974 .664 .326 r
.82261 .32367 .82335 .32453 .84474 .52918 .84397 .52835 Mtetra
.801 .357 0 r
.84397 .52835 .84474 .52918 .8472 .534 .84641 .53301 Mtetra
.441 .676 .963 r
.84641 .53301 .8472 .534 .84921 .53414 .84841 .53312 Mtetra
.67 .777 .93 r
.84841 .53312 .84921 .53414 .85114 .53349 .85035 .53245 Mtetra
.73 .793 .902 r
.85035 .53245 .85114 .53349 .85305 .53254 .85225 .53148 Mtetra
.652 .76 .928 r
.85225 .53148 .85305 .53254 .85499 .53196 .8542 .53089 Mtetra
.662 .762 .925 r
.8542 .53089 .85499 .53196 .85693 .53132 .85614 .53026 Mtetra
.668 .766 .923 r
.85614 .53026 .85693 .53132 .85887 .53065 .85808 .5296 Mtetra
.674 .771 .923 r
.85808 .5296 .85887 .53065 .86081 .52994 .86002 .52891 Mtetra
.671 .775 .928 r
.86002 .52891 .86081 .52994 .86274 .52923 .86196 .52823 Mtetra
.655 .775 .937 r
.86196 .52823 .86274 .52923 .86469 .52863 .86391 .52762 Mtetra
.595 .748 .95 r
.86391 .52762 .86469 .52863 .86668 .52845 .86588 .52726 Mtetra
.624 .72 .916 r
.86588 .52726 .86668 .52845 .86865 .52803 .86785 .5268 Mtetra
.666 .734 .901 r
.86785 .5268 .86865 .52803 .87056 .527 .8698 .52615 Mtetra
.736 .84 .928 r
.8698 .52615 .87056 .527 .87226 .52399 .87171 .52516 Mtetra
0 0 0 r
.87171 .52516 .87226 .52399 .87362 .51768 .87357 .52358 Mtetra
.352 .112 .404 r
.87357 .52358 .87362 .51768 .85463 .31763 .87528 .52065 Mtetra
.136 .042 .475 r
.87528 .52065 .85463 .31763 .85597 .31232 .85689 .32701 Mtetra
.036 0 .404 r
.85689 .32701 .85597 .31232 .85758 .30965 .85703 .31038 Mtetra
.831 .881 .447 r
.85703 .31038 .85758 .30965 .85929 .30796 .85855 .30686 Mtetra
.74 .772 .879 r
.85855 .30686 .85929 .30796 .8611 .30716 .86034 .30585 Mtetra
.639 .692 .883 r
.86034 .30585 .8611 .30716 .86294 .30665 .86218 .30537 Mtetra
.592 .675 .898 r
.86218 .30537 .86294 .30665 .8648 .30623 .86405 .3051 Mtetra
.753 .771 .867 r
.86405 .3051 .8648 .30623 .86657 .30512 .86583 .304 Mtetra
.686 .747 .898 r
.86583 .304 .86657 .30512 .8684 .30441 .86766 .30328 Mtetra
.481 .65 .933 r
.86766 .30328 .8684 .30441 .87031 .30449 .86957 .30337 Mtetra
.756 .34 0 r
.86957 .30337 .87031 .30449 .87277 .30952 .87204 .30841 Mtetra
.971 .656 .295 r
.87204 .30841 .87277 .30952 .89757 .51448 .8968 .51343 Mtetra
.731 .298 0 r
.8968 .51343 .89757 .51448 .90014 .51917 .89937 .51811 Mtetra
.302 .577 .937 r
.89937 .51811 .90014 .51917 .90224 .5197 .90147 .51865 Mtetra
.648 .764 .933 r
.90147 .51865 .90224 .5197 .90422 .51912 .90345 .51806 Mtetra
.828 .821 .842 r
.90345 .51806 .90422 .51912 .90607 .51742 .9053 .51636 Mtetra
.908 .736 .657 r
.26958 .69915 .27062 .7 .27256 .69445 .27153 .6936 Mtetra
.936 .686 .535 r
.27153 .6936 .27256 .69445 .28805 .49888 .28708 .49798 Mtetra
.907 .728 .647 r
.28708 .49798 .28805 .49888 .28992 .49316 .28895 .49226 Mtetra
.772 .759 .841 r
.28895 .49226 .28992 .49316 .29145 .49204 .29049 .49114 Mtetra
.64 .736 .918 r
.29049 .49114 .29145 .49204 .29294 .49164 .29197 .49074 Mtetra
.51 .692 .95 r
.29197 .49074 .29294 .49164 .2944 .4916 .29344 .4907 Mtetra
.749 .758 .86 r
.29344 .4907 .2944 .4916 .29593 .49066 .29496 .48976 Mtetra
.697 .75 .893 r
.29496 .48976 .29593 .49066 .29743 .49002 .29647 .48912 Mtetra
.483 .681 .953 r
.29647 .48912 .29743 .49002 .29889 .49004 .29793 .48914 Mtetra
.926 .545 .25 r
.29793 .48914 .29889 .49004 .30009 .494 .29912 .49311 Mtetra
.939 .683 .523 r
.29912 .49311 .30009 .494 .28845 .68866 .28742 .68783 Mtetra
.934 .582 .331 r
.28742 .68783 .28845 .68866 .28964 .69406 .28861 .69322 Mtetra
.246 .593 .949 r
.28861 .69322 .28964 .69406 .29118 .69442 .29015 .69357 Mtetra
.669 .769 .925 r
.29015 .69357 .29118 .69442 .29277 .69387 .29174 .69303 Mtetra
.748 .78 .879 r
.29174 .69303 .29277 .69387 .29439 .69295 .29337 .69207 Mtetra
.483 .701 .965 r
.29337 .69207 .29439 .69295 .29595 .69305 .29493 .69206 Mtetra
.595 .716 .928 r
.29493 .69206 .29595 .69305 .29752 .6929 .29651 .69179 Mtetra
.737 .732 .846 r
.29651 .69179 .29752 .6929 .29914 .69204 .29814 .69082 Mtetra
.889 .72 .665 r
.29814 .69082 .29914 .69204 .30101 .68737 .30002 .68587 Mtetra
.939 .686 .529 r
.30002 .68587 .30101 .68737 .31497 .49159 .31405 .49002 Mtetra
.888 .695 .636 r
.31405 .49002 .31497 .49159 .31689 .48463 .31593 .48366 Mtetra
.793 .751 .814 r
.31593 .48366 .31689 .48463 .31845 .48321 .3175 .48229 Mtetra
.649 .735 .912 r
.3175 .48229 .31845 .48321 .31996 .48277 .319 .48185 Mtetra
.516 .692 .948 r
.319 .48185 .31996 .48277 .32144 .48272 .32048 .4818 Mtetra
.733 .755 .87 r
.32048 .4818 .32144 .48272 .32297 .48187 .32202 .48096 Mtetra
.704 .75 .888 r
.32202 .48096 .32297 .48187 .32449 .48119 .32354 .48028 Mtetra
.516 .694 .949 r
.32354 .48028 .32449 .48119 .32598 .48112 .32502 .48022 Mtetra
.911 .507 .181 r
.32502 .48022 .32598 .48112 .32726 .4845 .3263 .48371 Mtetra
.942 .683 .517 r
.3263 .48371 .32726 .4845 .31719 .67931 .31615 .67882 Mtetra
.927 .583 .364 r
.31615 .67882 .31719 .67931 .3184 .68549 .31738 .68478 Mtetra
0 .451 .85 r
.31738 .68478 .3184 .68549 .31995 .68612 .31892 .68537 Mtetra
.666 .792 .942 r
.31892 .68537 .31995 .68612 .32156 .68562 .32053 .68482 Mtetra
.756 .794 .884 r
.32053 .68482 .32156 .68562 .32319 .6847 .32217 .68383 Mtetra
.543 .728 .96 r
.32217 .68383 .32319 .6847 .32477 .68466 .32376 .68367 Mtetra
.586 .714 .931 r
.32376 .68367 .32477 .68466 .32637 .68454 .32536 .68343 Mtetra
.727 .73 .853 r
.32536 .68343 .32637 .68454 .328 .68376 .327 .68252 Mtetra
.885 .723 .675 r
.327 .68252 .328 .68376 .32981 .67966 .32884 .67806 Mtetra
.942 .687 .523 r
.32884 .67806 .32981 .67966 .34219 .4843 .34132 .48193 Mtetra
.87 .667 .625 r
.34132 .48193 .34219 .4843 .34414 .47602 .34321 .47487 Mtetra
.797 .726 .786 r
.34321 .47487 .34414 .47602 .34573 .47434 .34479 .47329 Mtetra
.638 .707 .896 r
.34479 .47329 .34573 .47434 .34725 .4739 .34631 .47289 Mtetra
.489 .66 .937 r
.34631 .47289 .34725 .4739 .34875 .4739 .3478 .47293 Mtetra
.606 .714 .921 r
.3478 .47293 .34875 .4739 .35026 .47359 .34932 .47264 Mtetra
.652 .734 .91 r
.34932 .47264 .35026 .47359 .35179 .47311 .35084 .47219 Mtetra
.658 .741 .911 r
.35084 .47219 .35179 .47311 .35332 .47259 .35237 .47171 Mtetra
.738 .766 .875 r
.35237 .47171 .35332 .47259 .35487 .47157 .35392 .47084 Mtetra
.721 .798 .912 r
.35392 .47084 .35487 .47157 .35642 .47069 .35546 .47009 Mtetra
.521 .782 .992 r
.35546 .47009 .35642 .47069 .35794 .47043 .35698 .4699 Mtetra
.859 .407 .102 r
.35698 .4699 .35794 .47043 .3593 .47326 .35836 .47242 Mtetra
.946 .684 .509 r
.35836 .47242 .3593 .47326 .35108 .66877 .35023 .66477 Mtetra
.917 .626 .139 r
.35023 .66477 .35108 .66877 .35233 .67585 .35139 .67355 Mtetra
.314 .381 .772 r
.35139 .67355 .35233 .67585 .35388 .67685 .35295 .6746 Mtetra
.631 .568 .765 r
.35295 .6746 .35388 .67685 .35551 .67642 .35457 .67411 Mtetra
.678 .589 .749 r
.35457 .67411 .35551 .67642 .35716 .67551 .35623 .67319 Mtetra
.618 .557 .764 r
.35623 .67319 .35716 .67551 .3588 .67483 .35785 .6728 Mtetra
.572 .556 .798 r
.35785 .6728 .3588 .67483 .36044 .67431 .35946 .67272 Mtetra
.572 .605 .848 r
.35946 .67272 .36044 .67431 .36207 .6738 .36108 .67261 Mtetra
.611 .684 .894 r
.36108 .67261 .36207 .6738 .3637 .67342 .36271 .6723 Mtetra
.643 .708 .894 r
.36271 .6723 .3637 .67342 .36533 .67304 .36434 .67185 Mtetra
.654 .7 .88 r
.36434 .67185 .36533 .67304 .36697 .6725 .36598 .67135 Mtetra
.574 .68 .912 r
.36598 .67135 .36697 .6725 .36862 .67165 .3676 .67117 Mtetra
.5 .813 1 r
.3676 .67117 .36862 .67165 .37029 .67033 .36923 .67092 Mtetra
0 0 0 r
.36923 .67092 .37029 .67033 .37201 .66814 .37088 .67013 Mtetra
.645 .804 .365 r
.37088 .67013 .37201 .66814 .37392 .66134 .37264 .66694 Mtetra
.992 .809 .433 r
.37264 .66694 .37392 .66134 .38388 .46675 .37501 .64963 Mtetra
0 0 .273 r
.37501 .64963 .38388 .46675 .3856 .46209 .38458 .46308 Mtetra
.824 .962 .633 r
.38458 .46308 .3856 .46209 .3872 .46042 .38621 .46072 Mtetra
.307 .791 .726 r
.38621 .46072 .3872 .46042 .38875 .45984 .38776 .46013 Mtetra
.098 0 0 r
.38776 .46013 .38875 .45984 .39028 .45963 .3893 .46 Mtetra
0 0 0 r
.3893 .46 .39028 .45963 .39182 .45939 .39085 .45948 Mtetra
.653 .965 .915 r
.39085 .45948 .39182 .45939 .39337 .45903 .39241 .4586 Mtetra
.74 .879 .944 r
.39241 .4586 .39337 .45903 .39491 .45868 .39398 .45776 Mtetra
.695 .753 .896 r
.39398 .45776 .39491 .45868 .39646 .45827 .39554 .45711 Mtetra
.659 .696 .874 r
.39554 .45711 .39646 .45827 .39801 .4578 .39709 .45662 Mtetra
.647 .689 .875 r
.39709 .45662 .39801 .4578 .39957 .45727 .39864 .45617 Mtetra
.649 .704 .887 r
.39864 .45617 .39957 .45727 .40113 .45667 .4002 .45572 Mtetra
.654 .736 .91 r
.4002 .45572 .40113 .45667 .40269 .45603 .40175 .45525 Mtetra
.654 .776 .938 r
.40175 .45525 .40269 .45603 .40425 .45538 .40331 .45476 Mtetra
.659 .819 .96 r
.40331 .45476 .40425 .45538 .40581 .4547 .40487 .45424 Mtetra
.655 .861 .978 r
.40487 .45424 .40581 .4547 .40738 .45406 .40643 .45368 Mtetra
.645 .881 .984 r
.40643 .45368 .40738 .45406 .40893 .45357 .40799 .45311 Mtetra
.733 .873 .946 r
.40799 .45311 .40893 .45357 .41048 .45335 .40956 .4523 Mtetra
.72 .735 .863 r
.40956 .4523 .41048 .45335 .41202 .45355 .41114 .45149 Mtetra
.614 .566 .776 r
.41114 .45149 .41202 .45355 .41353 .45449 .41269 .45115 Mtetra
.327 .311 .688 r
.41269 .45115 .41353 .45449 .41493 .4589 .41419 .45268 Mtetra
.73 .525 0 r
.41419 .45268 .41493 .4589 .41005 .65373 .41539 .46309 Mtetra
0 0 .309 r
.41539 .46309 .41005 .65373 .41154 .65833 .41063 .6551 Mtetra
.186 .232 .677 r
.41063 .6551 .41154 .65833 .41315 .6595 .41221 .65717 Mtetra
.606 .552 .767 r
.41221 .65717 .41315 .6595 .41481 .65927 .41387 .65686 Mtetra
.667 .579 .747 r
.41387 .65686 .41481 .65927 .41648 .65861 .41555 .65601 Mtetra
.634 .55 .742 r
.41555 .65601 .41648 .65861 .41815 .65789 .41722 .65544 Mtetra
.576 .526 .763 r
.41722 .65544 .41815 .65789 .41983 .65724 .41888 .65534 Mtetra
.579 .574 .812 r
.41888 .65534 .41983 .65724 .4215 .65656 .42053 .65521 Mtetra
.612 .661 .874 r
.42053 .65521 .4215 .65656 .42318 .65594 .4222 .65489 Mtetra
.655 .733 .907 r
.4222 .65489 .42318 .65594 .42485 .65539 .42387 .65438 Mtetra
.668 .744 .907 r
.42387 .65438 .42485 .65539 .42652 .65487 .42555 .65381 Mtetra
.666 .734 .901 r
.42555 .65381 .42652 .65487 .4282 .65435 .42722 .65325 Mtetra
.657 .723 .897 r
.42722 .65325 .4282 .65435 .42987 .65383 .4289 .65273 Mtetra
.655 .722 .898 r
.4289 .65273 .42987 .65383 .43155 .65332 .43057 .65222 Mtetra
.654 .722 .899 r
.43057 .65222 .43155 .65332 .43322 .6528 .43225 .65171 Mtetra
.652 .723 .901 r
.43225 .65171 .43322 .6528 .4349 .6523 .43393 .65121 Mtetra
.65 .724 .903 r
.43393 .65121 .4349 .6523 .43658 .65179 .43561 .65072 Mtetra
.641 .724 .909 r
.43561 .65072 .43658 .65179 .43826 .65129 .43729 .65027 Mtetra
.634 .732 .918 r
.43729 .65027 .43826 .65129 .43994 .65079 .43896 .64984 Mtetra
.647 .75 .925 r
.43896 .64984 .43994 .65079 .44162 .65031 .44065 .64936 Mtetra
.688 .762 .908 r
.44065 .64936 .44162 .65031 .4433 .64985 .44233 .64869 Mtetra
.721 .732 .859 r
.44233 .64869 .4433 .64985 .44498 .64941 .44403 .6478 Mtetra
.705 .664 .806 r
.44403 .6478 .44498 .64941 .44666 .64898 .44572 .64687 Mtetra
.637 .585 .78 r
.44572 .64687 .44666 .64898 .44834 .64871 .44741 .64635 Mtetra
.57 .531 .772 r
.44741 .64635 .44834 .64871 .45002 .64855 .44908 .64629 Mtetra
.643 .577 .766 r
.44908 .64629 .45002 .64855 .45171 .64796 .45077 .6457 Mtetra
.794 .649 .701 r
.45077 .6457 .45171 .64796 .45343 .646 .45251 .64299 Mtetra
.953 .687 .495 r
.45251 .64299 .45343 .646 .45523 .63997 .45812 .45008 Mtetra
.577 .359 .547 r
.45812 .45008 .45523 .63997 .46077 .44334 .45996 .43773 Mtetra
.696 .51 .631 r
.45996 .43773 .46077 .44334 .46244 .4387 .46159 .4349 Mtetra
.629 .494 .679 r
.46159 .4349 .46244 .4387 .46404 .43783 .46319 .43413 Mtetra
.591 .472 .686 r
.46319 .43413 .46404 .43783 .46563 .43769 .46478 .43384 Mtetra
.584 .463 .682 r
.46478 .43384 .46563 .43769 .46721 .43776 .46637 .43362 Mtetra
.603 .469 .672 r
.46637 .43362 .46721 .43776 .4688 .43752 .46796 .43315 Mtetra
.6 .462 .665 r
.46796 .43315 .4688 .43752 .4704 .43705 .46955 .43268 Mtetra
.599 .462 .665 r
.46955 .43268 .4704 .43705 .47201 .4359 .47115 .43222 Mtetra
.606 .483 .686 r
.47115 .43222 .47201 .4359 .47363 .43408 .47275 .43176 Mtetra
.627 .555 .754 r
.47275 .43176 .47363 .43408 .47524 .43249 .47435 .43129 Mtetra
.655 .694 .874 r
.47435 .43129 .47524 .43249 .47685 .43134 .47594 .43079 Mtetra
.649 .842 .975 r
.47594 .43079 .47685 .43134 .47845 .43075 .47755 .43026 Mtetra
.645 .858 .98 r
.47755 .43026 .47845 .43075 .48005 .43031 .47915 .42971 Mtetra
.655 .831 .968 r
.47915 .42971 .48005 .43031 .48165 .42989 .48075 .42917 Mtetra
.658 .799 .95 r
.48075 .42917 .48165 .42989 .48325 .42939 .48235 .42865 Mtetra
.657 .795 .948 r
.48235 .42865 .48325 .42939 .48486 .42889 .48396 .42813 Mtetra
.663 .79 .942 r
.48396 .42813 .48486 .42889 .48646 .42843 .48556 .42759 Mtetra
.674 .774 .926 r
.48556 .42759 .48646 .42843 .48807 .42803 .48717 .42702 Mtetra
.663 .733 .902 r
.48717 .42702 .48807 .42803 .48967 .42762 .48878 .4265 Mtetra
.632 .701 .895 r
.48878 .4265 .48967 .42762 .49128 .42712 .49038 .4261 Mtetra
.563 .694 .929 r
.49038 .4261 .49128 .42712 .49289 .42649 .49199 .42594 Mtetra
.453 .772 .997 r
.49199 .42594 .49289 .42649 .4945 .42583 .4936 .42582 Mtetra
.194 .724 .816 r
.4936 .42582 .4945 .42583 .49611 .42519 .4952 .42561 Mtetra
0 0 0 r
.4952 .42561 .49611 .42519 .49772 .42463 .49682 .42511 Mtetra
.49682 .42511 .49772 .42463 .49933 .42409 .49843 .42453 Mtetra
.49843 .42453 .49933 .42409 .50095 .42356 .50005 .42394 Mtetra
.50005 .42394 .50095 .42356 .50256 .42303 .50166 .4234 Mtetra
.50166 .4234 .50256 .42303 .50418 .4225 .50328 .42287 Mtetra
.50328 .42287 .50418 .4225 .50579 .42197 .5049 .42234 Mtetra
.5049 .42234 .50579 .42197 .50741 .42145 .50651 .42182 Mtetra
.50651 .42182 .50741 .42145 .50903 .42092 .50813 .42129 Mtetra
.50813 .42129 .50903 .42092 .51065 .4204 .50975 .42077 Mtetra
.50975 .42077 .51065 .4204 .51227 .41987 .51137 .42024 Mtetra
.51137 .42024 .51227 .41987 .51389 .41934 .513 .41971 Mtetra
.513 .41971 .51389 .41934 .51551 .41881 .51462 .41918 Mtetra
.51462 .41918 .51551 .41881 .51713 .41828 .51624 .41865 Mtetra
.51624 .41865 .51713 .41828 .51876 .41774 .51787 .41811 Mtetra
.51787 .41811 .51876 .41774 .52038 .4172 .51949 .41757 Mtetra
.51949 .41757 .52038 .4172 .52201 .41665 .52112 .417 Mtetra
.52112 .417 .52201 .41665 .52363 .4161 .52275 .41645 Mtetra
.52275 .41645 .52363 .4161 .52526 .41551 .52438 .41582 Mtetra
.53 .914 .777 r
.52438 .41582 .52526 .41551 .52689 .41467 .52601 .41484 Mtetra
.314 .801 .777 r
.52601 .41484 .52689 .41467 .52852 .41414 .52764 .41431 Mtetra
.472 0 0 r
.52764 .41431 .52852 .41414 .53015 .41436 .52927 .41489 Mtetra
.92 .582 .383 r
.52927 .41489 .53015 .41436 .53179 .41768 .53092 .42332 Mtetra
.955 .675 .468 r
.53092 .42332 .53179 .41768 .53394 .61306 .53302 .61945 Mtetra
.673 .383 .473 r
.53302 .61945 .53394 .61306 .5357 .62048 .53477 .62277 Mtetra
.547 .182 .3 r
.53477 .62277 .5357 .62048 .53744 .62124 .53652 .62313 Mtetra
.357 0 .166 r
.53652 .62313 .53744 .62124 .53918 .62061 .53826 .62254 Mtetra
.028 0 .014 r
.53826 .62254 .53918 .62061 .54092 .61832 .54 .62084 Mtetra
.765 .79 .297 r
.54 .62084 .54092 .61832 .54258 .60247 .54172 .6155 Mtetra
.979 .708 .442 r
.54172 .6155 .54258 .60247 .54324 .41285 .54239 .41592 Mtetra
.759 .751 .236 r
.54239 .41592 .54324 .41285 .54487 .40921 .544 .40955 Mtetra
.612 .947 .775 r
.544 .40955 .54487 .40921 .5465 .40824 .54564 .40838 Mtetra
.247 .759 .763 r
.54564 .40838 .5465 .40824 .54814 .40778 .54728 .40795 Mtetra
.068 0 0 r
.54728 .40795 .54814 .40778 .54979 .40756 .54893 .40788 Mtetra
0 0 0 r
.54893 .40788 .54979 .40756 .55143 .40702 .55057 .40734 Mtetra
.55057 .40734 .55143 .40702 .55308 .40648 .55222 .40682 Mtetra
.55222 .40682 .55308 .40648 .55472 .40595 .55386 .4063 Mtetra
.55386 .4063 .55472 .40595 .55637 .4054 .55551 .40576 Mtetra
.55551 .40576 .55637 .4054 .55801 .40485 .55716 .40521 Mtetra
.55716 .40521 .55801 .40485 .55966 .40429 .55881 .40465 Mtetra
.55881 .40465 .55966 .40429 .56131 .40374 .56046 .4041 Mtetra
.56046 .4041 .56131 .40374 .56296 .40318 .56211 .40354 Mtetra
.56211 .40354 .56296 .40318 .56461 .40263 .56376 .40299 Mtetra
.56376 .40299 .56461 .40263 .56626 .40207 .56541 .40243 Mtetra
.56541 .40243 .56626 .40207 .56791 .40152 .56707 .40187 Mtetra
.56707 .40187 .56791 .40152 .56957 .40096 .56872 .40132 Mtetra
.56872 .40132 .56957 .40096 .57122 .40041 .57038 .40077 Mtetra
.57038 .40077 .57122 .40041 .57288 .39987 .57204 .40022 Mtetra
.57204 .40022 .57288 .39987 .57454 .39932 .57369 .39968 Mtetra
.57369 .39968 .57454 .39932 .57619 .39878 .57535 .39921 Mtetra
.57535 .39921 .57619 .39878 .57785 .39824 .57701 .39871 Mtetra
.57701 .39871 .57785 .39824 .57951 .39774 .57867 .39811 Mtetra
.411 .84 .695 r
.57867 .39811 .57951 .39774 .58118 .39732 .58033 .3972 Mtetra
.703 .963 .942 r
.58033 .3972 .58118 .39732 .58284 .39691 .58199 .39626 Mtetra
.74 .843 .928 r
.58199 .39626 .58284 .39691 .5845 .39647 .58364 .39538 Mtetra
.677 .728 .888 r
.58364 .39538 .5845 .39647 .58617 .39587 .58531 .39476 Mtetra
.659 .72 .894 r
.58531 .39476 .58617 .39587 .58783 .39521 .58697 .39423 Mtetra
.649 .743 .918 r
.58697 .39423 .58783 .39521 .58949 .39455 .58864 .39375 Mtetra
.657 .786 .943 r
.58864 .39375 .58949 .39455 .59116 .39398 .59031 .39321 Mtetra
.656 .797 .95 r
.59031 .39321 .59116 .39398 .59283 .39343 .59198 .39267 Mtetra
.653 .8 .953 r
.59198 .39267 .59283 .39343 .5945 .39288 .59365 .39214 Mtetra
.645 .8 .957 r
.59365 .39214 .5945 .39288 .59617 .39233 .59532 .39164 Mtetra
.641 .811 .965 r
.59532 .39164 .59617 .39233 .59784 .39178 .59699 .39114 Mtetra
.64 .825 .971 r
.59699 .39114 .59784 .39178 .59951 .39122 .59866 .39062 Mtetra
.649 .839 .974 r
.59866 .39062 .59951 .39122 .60118 .39055 .60034 .39007 Mtetra
.641 .87 .984 r
.60034 .39007 .60118 .39055 .60285 .38993 .60201 .38949 Mtetra
.642 .88 .985 r
.60201 .38949 .60285 .38993 .60453 .38948 .60369 .38889 Mtetra
.67 .849 .968 r
.60369 .38889 .60453 .38948 .60622 .38966 .60536 .38826 Mtetra
.672 .676 .845 r
.60536 .38826 .60622 .38966 .60793 .3902 .60704 .38763 Mtetra
.638 .55 .739 r
.60704 .38763 .60793 .3902 .60964 .3909 .60871 .387 Mtetra
.639 .5 .677 r
.60871 .387 .60964 .3909 .61131 .39018 .61038 .38605 Mtetra
.62 .482 .673 r
.61038 .38605 .61131 .39018 .61299 .38933 .61206 .38532 Mtetra
.579 .459 .68 r
.61206 .38532 .61299 .38933 .61468 .38915 .61375 .38515 Mtetra
.245 .237 .652 r
.61375 .38515 .61468 .38915 .61654 .39494 .61552 .38771 Mtetra
.977 .69 .41 r
.61552 .38771 .61654 .39494 .62398 .59256 .62283 .58265 Mtetra
0 0 .439 r
.62283 .58265 .62398 .59256 .62591 .59658 .62496 .59382 Mtetra
.438 .431 .754 r
.62496 .59382 .62591 .59658 .62774 .59698 .6268 .59464 Mtetra
.64 .576 .767 r
.6268 .59464 .62774 .59698 .62953 .5964 .6286 .59403 Mtetra
.689 .6 .751 r
.6286 .59403 .62953 .5964 .63132 .5954 .63038 .59295 Mtetra
.606 .55 .765 r
.63038 .59295 .63132 .5954 .63311 .59457 .63219 .5926 Mtetra
.574 .573 .814 r
.63219 .5926 .63311 .59457 .63491 .59379 .634 .59249 Mtetra
.572 .664 .9 r
.634 .59249 .63491 .59379 .6367 .593 .63582 .59231 Mtetra
.615 .817 .978 r
.63582 .59231 .6367 .593 .6385 .59232 .63763 .59183 Mtetra
.639 .877 .985 r
.63763 .59183 .6385 .59232 .6403 .5917 .63943 .5912 Mtetra
.662 .881 .979 r
.63943 .5912 .6403 .5917 .64211 .59112 .64123 .5905 Mtetra
.667 .852 .97 r
.64123 .5905 .64211 .59112 .64392 .59055 .64304 .58983 Mtetra
.668 .827 .96 r
.64304 .58983 .64392 .59055 .64573 .59002 .64484 .58918 Mtetra
.666 .799 .946 r
.64484 .58918 .64573 .59002 .64754 .58954 .64665 .58856 Mtetra
.653 .763 .93 r
.64665 .58856 .64754 .58954 .64936 .58918 .64846 .58801 Mtetra
.644 .72 .904 r
.64846 .58801 .64936 .58918 .65118 .58887 .65028 .58751 Mtetra
.637 .682 .876 r
.65028 .58751 .65118 .58887 .653 .58857 .65209 .58704 Mtetra
.631 .655 .856 r
.65209 .58704 .653 .58857 .65482 .58832 .65391 .5866 Mtetra
.626 .628 .833 r
.65391 .5866 .65482 .58832 .65665 .58798 .65573 .58618 Mtetra
.623 .618 .825 r
.65573 .58618 .65665 .58798 .65847 .58741 .65756 .58577 Mtetra
.622 .636 .843 r
.65756 .58577 .65847 .58741 .66025 .58612 .65938 .58537 Mtetra
.593 .796 .977 r
.65938 .58537 .66025 .58612 .66202 .58427 .66121 .58497 Mtetra
.159 0 0 r
.66121 .58497 .66202 .58427 .66377 .58209 .66303 .58456 Mtetra
.493 .136 .288 r
.66303 .58456 .66377 .58209 .66559 .58146 .66488 .58451 Mtetra
.49 .157 .329 r
.66488 .58451 .66559 .58146 .66743 .58142 .66672 .5843 Mtetra
.4 .072 .289 r
.66672 .5843 .66743 .58142 .66924 .58059 .66853 .58345 Mtetra
0 0 .06 r
.66853 .58345 .66924 .58059 .67076 .57298 .67022 .57972 Mtetra
.98 .696 .404 r
.67022 .57972 .67076 .57298 .66398 .37463 .6635 .38158 Mtetra
0 0 .136 r
.6635 .38158 .66398 .37463 .66552 .37009 .66476 .37067 Mtetra
.768 .953 .632 r
.66476 .37067 .66552 .37009 .66718 .36844 .66641 .36854 Mtetra
.359 .831 .808 r
.66641 .36854 .66718 .36844 .66889 .36783 .66812 .36795 Mtetra
0 0 0 r
.66812 .36795 .66889 .36783 .67062 .36758 .66986 .36778 Mtetra
.28 .774 .726 r
.66986 .36778 .67062 .36758 .67235 .36728 .67157 .36719 Mtetra
.645 .959 .929 r
.67157 .36719 .67235 .36728 .67408 .3669 .67327 .3663 Mtetra
.729 .868 .947 r
.67327 .3663 .67408 .3669 .6758 .36652 .67498 .36544 Mtetra
.686 .742 .894 r
.67498 .36544 .6758 .36652 .67753 .36607 .67669 .36477 Mtetra
.655 .689 .87 r
.67669 .36477 .67753 .36607 .67925 .36556 .67842 .36424 Mtetra
.646 .682 .87 r
.67842 .36424 .67925 .36556 .68097 .365 .68014 .36375 Mtetra
.653 .697 .879 r
.68014 .36375 .68097 .365 .68269 .36436 .68187 .36323 Mtetra
.66 .721 .894 r
.68187 .36323 .68269 .36436 .68441 .36369 .68359 .36268 Mtetra
.661 .747 .914 r
.68359 .36268 .68441 .36369 .68613 .36302 .68532 .36212 Mtetra
.66 .775 .934 r
.68532 .36212 .68613 .36302 .68785 .3624 .68704 .36157 Mtetra
.657 .789 .945 r
.68704 .36157 .68785 .3624 .68957 .36182 .68877 .36101 Mtetra
.655 .793 .949 r
.68877 .36101 .68957 .36182 .6913 .36126 .6905 .36046 Mtetra
.647 .793 .953 r
.6905 .36046 .6913 .36126 .69303 .3607 .69223 .35994 Mtetra
.64 .8 .96 r
.69223 .35994 .69303 .3607 .69476 .36014 .69396 .35943 Mtetra
.637 .815 .968 r
.69396 .35943 .69476 .36014 .69649 .35957 .6957 .35891 Mtetra
.642 .83 .973 r
.6957 .35891 .69649 .35957 .69822 .35892 .69743 .35837 Mtetra
.64 .859 .983 r
.69743 .35837 .69822 .35892 .69994 .35826 .69916 .35779 Mtetra
.632 .879 .987 r
.69916 .35779 .69994 .35826 .70168 .35774 .7009 .35719 Mtetra
.649 .863 .98 r
.7009 .35719 .70168 .35774 .70345 .35772 .70263 .35658 Mtetra
.673 .727 .891 r
.70263 .35658 .70345 .35772 .70524 .35825 .70436 .35597 Mtetra
.644 .575 .762 r
.70436 .35597 .70524 .35825 .70706 .35903 .7061 .35534 Mtetra
.618 .494 .689 r
.7061 .35534 .70706 .35903 .70885 .3593 .70783 .3547 Mtetra
.608 .466 .663 r
.70783 .3547 .70885 .3593 .71059 .35872 .70957 .35406 Mtetra
.607 .464 .661 r
.70957 .35406 .71059 .35872 .71231 .35786 .71131 .35343 Mtetra
.623 .479 .665 r
.71131 .35343 .71231 .35786 .71402 .3567 .71303 .35257 Mtetra
.629 .489 .673 r
.71303 .35257 .71402 .3567 .71574 .35565 .71476 .3517 Mtetra
.598 .474 .683 r
.71476 .3517 .71574 .35565 .71749 .3553 .71651 .35128 Mtetra
.438 .369 .683 r
.71651 .35128 .71749 .3553 .71944 .35806 .71837 .35256 Mtetra
0 0 .471 r
.71837 .35256 .71944 .35806 .73357 .55794 .7206 .35988 Mtetra
.038 0 .437 r
.7206 .35988 .73357 .55794 .73583 .56386 .73482 .56018 Mtetra
.205 .235 .671 r
.73482 .56018 .73583 .56386 .73782 .56516 .73689 .56295 Mtetra
.536 .534 .799 r
.73689 .56295 .73782 .56516 .73969 .5647 .73881 .56308 Mtetra
.635 .649 .847 r
.73881 .56308 .73969 .5647 .74154 .56378 .74068 .5626 Mtetra
.596 .703 .918 r
.74068 .5626 .74154 .56378 .74341 .56322 .74257 .56228 Mtetra
.52 .723 .966 r
.74257 .56228 .74341 .56322 .74532 .56308 .74448 .56216 Mtetra
.691 .796 .93 r
.74448 .56216 .74532 .56308 .74718 .56239 .74634 .56141 Mtetra
.904 .812 .747 r
.74634 .56141 .74718 .56239 .74891 .5596 .74807 .55858 Mtetra
.978 .728 .487 r
.74807 .55858 .74891 .5596 .74985 .54505 .74899 .54362 Mtetra
.977 .683 .39 r
.74899 .54362 .74985 .54505 .7385 .34825 .7377 .34715 Mtetra
.904 .784 .718 r
.7377 .34715 .7385 .34825 .74009 .34521 .7393 .34412 Mtetra
.706 .752 .888 r
.7393 .34412 .74009 .34521 .74184 .34442 .74104 .34333 Mtetra
.582 .703 .926 r
.74104 .34333 .74184 .34442 .74362 .34416 .74282 .34309 Mtetra
.641 .73 .913 r
.74282 .34309 .74362 .34416 .74538 .34368 .74459 .34261 Mtetra
.731 .763 .879 r
.74459 .34261 .74538 .34368 .74712 .34275 .74633 .34168 Mtetra
.63 .727 .917 r
.74633 .34168 .74712 .34275 .74889 .34231 .7481 .34125 Mtetra
0 .283 .781 r
.7481 .34125 .74889 .34231 .75079 .34365 .75001 .34262 Mtetra
.958 .617 .257 r
.75001 .34262 .75079 .34365 .75358 .35727 .75297 .3587 Mtetra
.974 .671 .371 r
.75297 .3587 .75358 .35727 .76959 .55307 .76877 .55224 Mtetra
.592 .097 0 r
.76877 .55224 .76959 .55307 .77171 .55562 .77088 .5547 Mtetra
.472 .704 .97 r
.77088 .5547 .77171 .55562 .77365 .5557 .77282 .55469 Mtetra
.739 .794 .897 r
.77282 .55469 .77365 .5557 .77551 .55473 .77468 .55369 Mtetra
.892 .808 .759 r
.77468 .55369 .77551 .55473 .77723 .55181 .77642 .55104 Mtetra
.981 .77 .545 r
.77642 .55104 .77723 .55181 .77816 .53844 .77774 .54283 Mtetra
.98 .685 .36 r
.77774 .54283 .77816 .53844 .76498 .33943 .76435 .34034 Mtetra
.884 .886 .458 r
.76435 .34034 .76498 .33943 .76655 .33618 .76586 .33631 Mtetra
.632 .96 .812 r
.76586 .33631 .76655 .33618 .76831 .33544 .76759 .33512 Mtetra
.587 .905 .982 r
.76759 .33512 .76831 .33544 .77012 .33528 .76936 .3345 Mtetra
.618 .796 .967 r
.76936 .3345 .77012 .33528 .77193 .33513 .77115 .33405 Mtetra
.667 .742 .906 r
.77115 .33405 .77193 .33513 .77371 .33449 .77293 .33345 Mtetra
.656 .747 .917 r
.77293 .33345 .77371 .33449 .77549 .33393 .77471 .3329 Mtetra
.696 .764 .904 r
.77471 .3329 .77549 .33393 .77729 .33357 .77648 .33216 Mtetra
.726 .708 .833 r
.77648 .33216 .77729 .33357 .77911 .33354 .77823 .33115 Mtetra
.631 .563 .759 r
.77823 .33115 .77911 .33354 .78099 .33411 .78001 .3306 Mtetra
.465 .405 .706 r
.78001 .3306 .78099 .33411 .78305 .33693 .78192 .33153 Mtetra
0 0 .427 r
.78192 .33153 .78305 .33693 .8014 .53761 .78447 .34018 Mtetra
.066 0 .454 r
.78447 .34018 .8014 .53761 .80386 .54373 .80295 .54159 Mtetra
0 .079 .637 r
.80295 .54159 .80386 .54373 .80595 .5452 .80517 .54463 Mtetra
.28 .691 .971 r
.80517 .54463 .80595 .5452 .80784 .54438 .80714 .54478 Mtetra
0 0 0 r
.80714 .54478 .80784 .54438 .80963 .54236 .80903 .54389 Mtetra
.80903 .54389 .80963 .54236 .81119 .53763 .8108 .54151 Mtetra
0 0 .072 r
.8108 .54151 .81119 .53763 .79575 .33466 .81214 .53415 Mtetra
.068 0 .448 r
.81214 .53415 .79575 .33466 .79702 .32803 .79653 .33018 Mtetra
0 0 0 r
.79653 .33018 .79702 .32803 .79865 .3256 .79797 .32545 Mtetra
.855 .987 .849 r
.79797 .32545 .79865 .3256 .80047 .32527 .79967 .32376 Mtetra
.677 .673 .839 r
.79967 .32376 .80047 .32527 .80238 .32598 .80145 .32305 Mtetra
.479 .44 .737 r
.80145 .32305 .80238 .32598 .80451 .32907 .80336 .32372 Mtetra
.03 .066 .565 r
.80336 .32372 .80451 .32907 .82447 .53191 .80573 .32958 Mtetra
.085 .008 .462 r
.80573 .32958 .82447 .53191 .82696 .53765 .82581 .53272 Mtetra
.372 .313 .661 r
.82581 .53272 .82696 .53765 .82898 .5381 .828 .53507 Mtetra
.914 .679 .569 r
.828 .53507 .82898 .5381 .83039 .53177 .82918 .52622 Mtetra
.975 .673 .364 r
.82918 .52622 .83039 .53177 .81348 .32565 .81262 .3235 Mtetra
.874 .694 .654 r
.81262 .3235 .81348 .32565 .81486 .32044 .81409 .31934 Mtetra
.744 .768 .872 r
.81409 .31934 .81486 .32044 .81657 .31892 .81586 .31831 Mtetra
.459 .769 .997 r
.81586 .31831 .81657 .31892 .81838 .31836 .81771 .31817 Mtetra
.481 0 0 r
.81771 .31817 .81838 .31836 .8203 .319 .81968 .31936 Mtetra
.913 .514 .213 r
.81968 .31936 .8203 .319 .82261 .32367 .82222 .32651 Mtetra
.973 .662 .339 r
.82222 .32651 .82261 .32367 .84397 .52835 .8433 .52866 Mtetra
.815 .338 .067 r
.8433 .52866 .84397 .52835 .84641 .53301 .84561 .53195 Mtetra
.617 .745 .937 r
.84561 .53195 .84641 .53301 .84841 .53312 .84756 .53151 Mtetra
.737 .702 .818 r
.84756 .53151 .84841 .53312 .85035 .53245 .84945 .53029 Mtetra
.738 .647 .759 r
.84945 .53029 .85035 .53245 .85225 .53148 .8513 .52875 Mtetra
.647 .562 .745 r
.8513 .52875 .85225 .53148 .8542 .53089 .85322 .52796 Mtetra
.626 .54 .737 r
.85322 .52796 .8542 .53089 .85614 .53026 .85516 .52735 Mtetra
.604 .528 .742 r
.85516 .52735 .85614 .53026 .85808 .5296 .85713 .52697 Mtetra
.565 .522 .766 r
.85713 .52697 .85808 .5296 .86002 .52891 .85914 .52693 Mtetra
.556 .571 .825 r
.85914 .52693 .86002 .52891 .86196 .52823 .86114 .52691 Mtetra
.557 .664 .909 r
.86114 .52691 .86196 .52823 .86391 .52762 .86314 .52677 Mtetra
.61 .793 .969 r
.86314 .52677 .86391 .52762 .86588 .52726 .8651 .5263 Mtetra
.638 .779 .949 r
.8651 .5263 .86588 .52726 .86785 .5268 .86706 .52575 Mtetra
.629 .754 .937 r
.86706 .52575 .86785 .5268 .8698 .52615 .86903 .52526 Mtetra
.435 .696 .975 r
.86903 .52526 .8698 .52615 .87171 .52516 .87105 .52533 Mtetra
0 0 0 r
.87105 .52533 .87171 .52516 .87357 .52358 .87303 .52494 Mtetra
.077 0 0 r
.87303 .52494 .87357 .52358 .87528 .52065 .87491 .52355 Mtetra
0 0 .01 r
.87491 .52355 .87528 .52065 .85689 .32701 .87625 .51707 Mtetra
.06 0 .454 r
.87625 .51707 .85689 .32701 .85703 .31038 .85649 .31118 Mtetra
.936 .849 .412 r
.85649 .31118 .85703 .31038 .85855 .30686 .85781 .30574 Mtetra
.762 .777 .865 r
.85781 .30574 .85855 .30686 .86034 .30585 .85958 .30459 Mtetra
.634 .699 .892 r
.85958 .30459 .86034 .30585 .86218 .30537 .86143 .30413 Mtetra
.565 .669 .908 r
.86143 .30413 .86218 .30537 .86405 .3051 .86331 .30396 Mtetra
.752 .77 .868 r
.86331 .30396 .86405 .3051 .86583 .304 .86509 .30287 Mtetra
.684 .746 .898 r
.86509 .30287 .86583 .304 .86766 .30328 .86692 .30216 Mtetra
.479 .649 .933 r
.86692 .30216 .86766 .30328 .86957 .30337 .86883 .30226 Mtetra
.755 .339 0 r
.86883 .30226 .86957 .30337 .87204 .30841 .8713 .30729 Mtetra
.971 .656 .295 r
.8713 .30729 .87204 .30841 .8968 .51343 .89603 .51237 Mtetra
.73 .298 0 r
.89603 .51237 .8968 .51343 .89937 .51811 .8986 .51706 Mtetra
.302 .577 .937 r
.8986 .51706 .89937 .51811 .90147 .51865 .9007 .51759 Mtetra
.648 .763 .933 r
.9007 .51759 .90147 .51865 .90345 .51806 .90268 .51701 Mtetra
.828 .821 .842 r
.90268 .51701 .90345 .51806 .9053 .51636 .90454 .5153 Mtetra
.908 .736 .657 r
.26854 .69831 .26958 .69915 .27153 .6936 .27049 .69276 Mtetra
.936 .686 .535 r
.27049 .69276 .27153 .6936 .28708 .49798 .28611 .49709 Mtetra
.907 .728 .647 r
.28611 .49709 .28708 .49798 .28895 .49226 .28798 .49136 Mtetra
.772 .76 .841 r
.28798 .49136 .28895 .49226 .29049 .49114 .28952 .49024 Mtetra
.639 .736 .919 r
.28952 .49024 .29049 .49114 .29197 .49074 .291 .48984 Mtetra
.509 .692 .951 r
.291 .48984 .29197 .49074 .29344 .4907 .29247 .4898 Mtetra
.749 .759 .86 r
.29247 .4898 .29344 .4907 .29496 .48976 .29399 .48886 Mtetra
.697 .751 .893 r
.29399 .48886 .29496 .48976 .29647 .48912 .2955 .48822 Mtetra
.481 .682 .954 r
.2955 .48822 .29647 .48912 .29793 .48914 .29696 .48824 Mtetra
.927 .546 .253 r
.29696 .48824 .29793 .48914 .29912 .49311 .29815 .49224 Mtetra
.939 .683 .523 r
.29815 .49224 .29912 .49311 .28742 .68783 .28638 .68704 Mtetra
.933 .581 .333 r
.28638 .68704 .28742 .68783 .28861 .69322 .28758 .69239 Mtetra
.245 .597 .951 r
.28758 .69239 .28861 .69322 .29015 .69357 .28911 .69274 Mtetra
.671 .77 .925 r
.28911 .69274 .29015 .69357 .29174 .69303 .29071 .69218 Mtetra
.75 .78 .878 r
.29071 .69218 .29174 .69303 .29337 .69207 .29234 .69121 Mtetra
.48 .704 .968 r
.29234 .69121 .29337 .69207 .29493 .69206 .2939 .69119 Mtetra
.587 .743 .951 r
.2939 .69119 .29493 .69206 .29651 .69179 .29548 .69092 Mtetra
.75 .777 .875 r
.29548 .69092 .29651 .69179 .29814 .69082 .29711 .68995 Mtetra
.906 .742 .667 r
.29711 .68995 .29814 .69082 .30002 .68587 .299 .68497 Mtetra
.939 .687 .529 r
.299 .68497 .30002 .68587 .31405 .49002 .31309 .48904 Mtetra
.911 .724 .637 r
.31309 .48904 .31405 .49002 .31593 .48366 .31497 .48273 Mtetra
.796 .758 .818 r
.31497 .48273 .31593 .48366 .3175 .48229 .31654 .48137 Mtetra
.647 .734 .913 r
.31654 .48137 .3175 .48229 .319 .48185 .31804 .48093 Mtetra
.513 .69 .948 r
.31804 .48093 .319 .48185 .32048 .4818 .31953 .48089 Mtetra
.734 .757 .871 r
.31953 .48089 .32048 .4818 .32202 .48096 .32106 .48004 Mtetra
.703 .75 .889 r
.32106 .48004 .32202 .48096 .32354 .48028 .32258 .47937 Mtetra
.504 .689 .95 r
.32258 .47937 .32354 .48028 .32502 .48022 .32407 .47934 Mtetra
.92 .528 .217 r
.32407 .47934 .32502 .48022 .3263 .48371 .32532 .48313 Mtetra
.942 .683 .517 r
.32532 .48313 .3263 .48371 .31615 .67882 .31508 .6789 Mtetra
.901 .557 .383 r
.31508 .6789 .31615 .67882 .31738 .68478 .31633 .68434 Mtetra
0 .445 .773 r
.31633 .68434 .31738 .68478 .31892 .68537 .31788 .6848 Mtetra
.693 .841 .954 r
.31788 .6848 .31892 .68537 .32053 .68482 .3195 .68413 Mtetra
.781 .817 .881 r
.3195 .68413 .32053 .68482 .32217 .68383 .32115 .683 Mtetra
.558 .743 .963 r
.32115 .683 .32217 .68383 .32376 .68367 .32275 .68279 Mtetra
.581 .739 .951 r
.32275 .68279 .32376 .68367 .32536 .68343 .32435 .68253 Mtetra
.742 .774 .879 r
.32435 .68253 .32536 .68343 .327 .68252 .32599 .6816 Mtetra
.905 .743 .67 r
.32599 .6816 .327 .68252 .32884 .67806 .32784 .67683 Mtetra
.942 .687 .523 r
.32784 .67683 .32884 .67806 .34132 .48193 .34043 .47988 Mtetra
.874 .677 .633 r
.34043 .47988 .34132 .48193 .34321 .47487 .34228 .47351 Mtetra
.774 .698 .779 r
.34228 .47351 .34321 .47487 .34479 .47329 .34386 .47206 Mtetra
.614 .665 .876 r
.34386 .47206 .34479 .47329 .34631 .47289 .34537 .47177 Mtetra
.457 .619 .92 r
.34537 .47177 .34631 .47289 .3478 .47293 .34686 .47192 Mtetra
.585 .698 .92 r
.34686 .47192 .3478 .47293 .34932 .47264 .34837 .47171 Mtetra
.644 .733 .914 r
.34837 .47171 .34932 .47264 .35084 .47219 .3499 .47128 Mtetra
.655 .744 .915 r
.3499 .47128 .35084 .47219 .35237 .47171 .35142 .47082 Mtetra
.716 .76 .888 r
.35142 .47082 .35237 .47171 .35392 .47084 .35296 .47007 Mtetra
.706 .787 .914 r
.35296 .47007 .35392 .47084 .35546 .47009 .3545 .4694 Mtetra
.597 .778 .967 r
.3545 .4694 .35546 .47009 .35698 .4699 .35603 .46908 Mtetra
0 .071 .548 r
.35603 .46908 .35698 .4699 .35836 .47242 .35747 .47031 Mtetra
.803 .445 0 r
.35747 .47031 .35836 .47242 .35023 .66477 .35878 .47422 Mtetra
0 0 .281 r
.35878 .47422 .35023 .66477 .35139 .67355 .35083 .66371 Mtetra
.429 .286 .584 r
.35083 .66371 .35139 .67355 .35295 .6746 .3523 .66649 Mtetra
.604 .426 .615 r
.3523 .66649 .35295 .6746 .35457 .67411 .35395 .66545 Mtetra
.6 .421 .611 r
.35395 .66545 .35457 .67411 .35623 .67319 .3556 .66444 Mtetra
.383 .258 .584 r
.3556 .66444 .35623 .67319 .35785 .6728 .35705 .6676 Mtetra
.274 .222 .616 r
.35705 .6676 .35785 .6728 .35946 .67272 .35853 .67029 Mtetra
.189 .29 .737 r
.35853 .67029 .35946 .67272 .36108 .67261 .36007 .67178 Mtetra
.342 .652 .969 r
.36007 .67178 .36108 .67261 .36271 .6723 .36168 .67199 Mtetra
.54 .87 .993 r
.36168 .67199 .36271 .6723 .36434 .67185 .36331 .67157 Mtetra
.64 .905 .983 r
.36331 .67157 .36434 .67185 .36598 .67135 .36495 .67093 Mtetra
.53 .841 .999 r
.36495 .67093 .36598 .67135 .3676 .67117 .36658 .67059 Mtetra
.554 .81 .993 r
.36658 .67059 .3676 .67117 .36923 .67092 .36822 .67029 Mtetra
.69 .83 .95 r
.36822 .67029 .36923 .67092 .37088 .67013 .36986 .66962 Mtetra
.877 .839 .805 r
.36986 .66962 .37088 .67013 .37264 .66694 .37157 .66755 Mtetra
.979 .885 .665 r
.37157 .66755 .37264 .66694 .37501 .64963 .37338 .66325 Mtetra
.967 .711 .495 r
.37338 .66325 .37501 .64963 .38458 .46308 .38272 .48385 Mtetra
.029 0 .348 r
.38272 .48385 .38458 .46308 .38621 .46072 .38495 .46735 Mtetra
.527 .26 .452 r
.38495 .46735 .38621 .46072 .38776 .46013 .38649 .46714 Mtetra
.545 .279 .462 r
.38649 .46714 .38776 .46013 .3893 .46 .38802 .46725 Mtetra
.221 .003 .356 r
.38802 .46725 .3893 .46 .39085 .45948 .38973 .46307 Mtetra
0 0 .046 r
.38973 .46307 .39085 .45948 .39241 .4586 .39142 .4593 Mtetra
.907 .981 .714 r
.39142 .4593 .39241 .4586 .39398 .45776 .39305 .45687 Mtetra
.787 .773 .84 r
.39305 .45687 .39398 .45776 .39554 .45711 .39463 .45563 Mtetra
.662 .648 .825 r
.39463 .45563 .39554 .45711 .39709 .45662 .39619 .45507 Mtetra
.619 .621 .831 r
.39619 .45507 .39709 .45662 .39864 .45617 .39773 .45474 Mtetra
.616 .636 .848 r
.39773 .45474 .39864 .45617 .4002 .45572 .39928 .45443 Mtetra
.624 .662 .867 r
.39928 .45443 .4002 .45572 .40175 .45525 .40083 .45409 Mtetra
.624 .685 .887 r
.40083 .45409 .40175 .45525 .40331 .45476 .40238 .45374 Mtetra
.642 .719 .904 r
.40238 .45374 .40331 .45476 .40487 .45424 .40394 .45332 Mtetra
.664 .747 .912 r
.40394 .45332 .40487 .45424 .40643 .45368 .4055 .45281 Mtetra
.677 .761 .914 r
.4055 .45281 .40643 .45368 .40799 .45311 .40706 .45224 Mtetra
.729 .772 .887 r
.40706 .45224 .40799 .45311 .40956 .4523 .40863 .45142 Mtetra
.738 .77 .879 r
.40863 .45142 .40956 .4523 .41114 .45149 .41021 .45054 Mtetra
.67 .743 .904 r
.41021 .45054 .41114 .45149 .41269 .45115 .41177 .45 Mtetra
.217 .485 .894 r
.41177 .45 .41269 .45115 .41419 .45268 .4133 .45064 Mtetra
0 0 .437 r
.4133 .45064 .41419 .45268 .41539 .46309 .41475 .45341 Mtetra
.919 .684 .189 r
.41475 .45341 .41539 .46309 .41063 .6551 .41557 .47562 Mtetra
0 0 .329 r
.41557 .47562 .41063 .6551 .41221 .65717 .41148 .64861 Mtetra
.586 .411 .611 r
.41148 .64861 .41221 .65717 .41387 .65686 .41315 .64797 Mtetra
.603 .422 .609 r
.41315 .64797 .41387 .65686 .41555 .65601 .41483 .64683 Mtetra
.442 .301 .593 r
.41483 .64683 .41555 .65601 .41722 .65544 .4164 .64929 Mtetra
.293 .221 .602 r
.4164 .64929 .41722 .65544 .41888 .65534 .41796 .65241 Mtetra
.233 .282 .709 r
.41796 .65241 .41888 .65534 .42053 .65521 .41956 .65412 Mtetra
.289 .559 .929 r
.41956 .65412 .42053 .65521 .4222 .65489 .4212 .65459 Mtetra
.519 .865 .991 r
.4212 .65459 .4222 .65489 .42387 .65438 .42287 .65419 Mtetra
.617 .92 .976 r
.42287 .65419 .42387 .65438 .42555 .65381 .42455 .65353 Mtetra
.635 .907 .983 r
.42455 .65353 .42555 .65381 .42722 .65325 .42623 .65288 Mtetra
.598 .878 .992 r
.42623 .65288 .42722 .65325 .4289 .65273 .4279 .65237 Mtetra
.595 .878 .993 r
.4279 .65237 .4289 .65273 .43057 .65222 .42958 .65185 Mtetra
.589 .876 .993 r
.42958 .65185 .43057 .65222 .43225 .65171 .43126 .65135 Mtetra
.581 .875 .994 r
.43126 .65135 .43225 .65171 .43393 .65121 .43294 .65086 Mtetra
.576 .876 .994 r
.43294 .65086 .43393 .65121 .43561 .65072 .43462 .65038 Mtetra
.516 .856 .995 r
.43462 .65038 .43561 .65072 .43729 .65027 .43629 .65 Mtetra
.443 .84 .978 r
.43629 .65 .43729 .65027 .43896 .64984 .43797 .64969 Mtetra
.541 .902 .967 r
.43797 .64969 .43896 .64984 .44065 .64936 .43966 .64913 Mtetra
.82 .936 .906 r
.43966 .64913 .44065 .64936 .44233 .64869 .44136 .6478 Mtetra
.879 .78 .748 r
.44136 .6478 .44233 .64869 .44403 .6478 .4431 .64509 Mtetra
.824 .644 .659 r
.4431 .64509 .44403 .6478 .44572 .64687 .44487 .64081 Mtetra
.742 .541 .622 r
.44487 .64081 .44572 .64687 .44741 .64635 .44665 .63605 Mtetra
.55 .376 .598 r
.44665 .63605 .44741 .64635 .44908 .64629 .44831 .63632 Mtetra
.563 .387 .601 r
.44831 .63632 .44908 .64629 .45077 .6457 .44999 .63621 Mtetra
.943 .677 .504 r
.44999 .63621 .45077 .6457 .45251 .64299 .45537 .46138 Mtetra
.595 .373 .55 r
.45537 .46138 .45251 .64299 .45812 .45008 .45741 .43953 Mtetra
.665 .459 .597 r
.45741 .43953 .45812 .45008 .45996 .43773 .45907 .43563 Mtetra
.764 .638 .722 r
.45907 .43563 .45996 .43773 .46159 .4349 .46069 .43371 Mtetra
.691 .707 .86 r
.46069 .43371 .46159 .4349 .46319 .43413 .46229 .43303 Mtetra
.624 .702 .901 r
.46229 .43303 .46319 .43413 .46478 .43384 .46388 .43268 Mtetra
.616 .685 .892 r
.46388 .43268 .46478 .43384 .46637 .43362 .46547 .43236 Mtetra
.656 .682 .862 r
.46547 .43236 .46637 .43362 .46796 .43315 .46706 .43185 Mtetra
.651 .675 .859 r
.46706 .43185 .46796 .43315 .46955 .43268 .46866 .43136 Mtetra
.638 .667 .861 r
.46866 .43136 .46955 .43268 .47115 .43222 .47025 .43094 Mtetra
.619 .666 .873 r
.47025 .43094 .47115 .43222 .47275 .43176 .47185 .43061 Mtetra
.621 .69 .893 r
.47185 .43061 .47275 .43176 .47435 .43129 .47344 .43026 Mtetra
.648 .725 .904 r
.47344 .43026 .47435 .43129 .47594 .43079 .47504 .4298 Mtetra
.691 .745 .893 r
.47504 .4298 .47594 .43079 .47755 .43026 .47665 .42915 Mtetra
.695 .724 .872 r
.47665 .42915 .47755 .43026 .47915 .42971 .47825 .42846 Mtetra
.683 .695 .855 r
.47825 .42846 .47915 .42971 .48075 .42917 .47986 .42781 Mtetra
.663 .67 .846 r
.47986 .42781 .48075 .42917 .48235 .42865 .48146 .42725 Mtetra
.658 .662 .843 r
.48146 .42725 .48235 .42865 .48396 .42813 .48307 .42672 Mtetra
.666 .664 .838 r
.48307 .42672 .48396 .42813 .48556 .42759 .48467 .42613 Mtetra
.682 .664 .826 r
.48467 .42613 .48556 .42759 .48717 .42702 .48628 .42544 Mtetra
.647 .634 .823 r
.48628 .42544 .48717 .42702 .48878 .4265 .48789 .42494 Mtetra
.534 .585 .852 r
.48789 .42494 .48878 .4265 .49038 .4261 .48949 .42499 Mtetra
0 .206 .722 r
.48949 .42499 .49038 .4261 .49199 .42594 .49108 .42629 Mtetra
.822 .395 .225 r
.49108 .42629 .49199 .42594 .4936 .42582 .49266 .42888 Mtetra
.781 .459 .442 r
.49266 .42888 .4936 .42582 .4952 .42561 .49423 .43348 Mtetra
.592 .324 .479 r
.49423 .43348 .4952 .42561 .49682 .42511 .49583 .43474 Mtetra
.479 .236 .467 r
.49583 .43474 .49682 .42511 .49843 .42453 .49746 .43316 Mtetra
.453 .209 .453 r
.49746 .43316 .49843 .42453 .50005 .42394 .49909 .43124 Mtetra
.514 .253 .456 r
.49909 .43124 .50005 .42394 .50166 .4234 .50071 .43073 Mtetra
.50071 .43073 .50166 .4234 .50328 .42287 .50233 .43021 Mtetra
.515 .253 .456 r
.50233 .43021 .50328 .42287 .5049 .42234 .50395 .4297 Mtetra
.516 .254 .457 r
.50395 .4297 .5049 .42234 .50651 .42182 .50557 .42921 Mtetra
.516 .255 .457 r
.50557 .42921 .50651 .42182 .50813 .42129 .5072 .42872 Mtetra
.516 .255 .458 r
.5072 .42872 .50813 .42129 .50975 .42077 .50882 .42822 Mtetra
.50882 .42822 .50975 .42077 .51137 .42024 .51045 .42772 Mtetra
.51045 .42772 .51137 .42024 .513 .41971 .51207 .42721 Mtetra
.515 .255 .458 r
.51207 .42721 .513 .41971 .51462 .41918 .5137 .42669 Mtetra
.514 .254 .458 r
.5137 .42669 .51462 .41918 .51624 .41865 .51533 .42615 Mtetra
.513 .253 .458 r
.51533 .42615 .51624 .41865 .51787 .41811 .51696 .42559 Mtetra
.511 .251 .457 r
.51696 .42559 .51787 .41811 .51949 .41757 .51859 .42499 Mtetra
.507 .247 .455 r
.51859 .42499 .51949 .41757 .52112 .417 .52022 .42432 Mtetra
.507 .247 .454 r
.52022 .42432 .52112 .417 .52275 .41645 .52186 .42367 Mtetra
.493 .234 .45 r
.52186 .42367 .52275 .41645 .52438 .41582 .52349 .42276 Mtetra
.423 .173 .428 r
.52349 .42276 .52438 .41582 .52601 .41484 .52513 .4208 Mtetra
.501 .23 .435 r
.52513 .4208 .52601 .41484 .52764 .41431 .52676 .42022 Mtetra
.687 .395 .474 r
.52676 .42022 .52764 .41431 .52927 .41489 .5284 .42375 Mtetra
.95 .67 .474 r
.5284 .42375 .52927 .41489 .53092 .42332 .53034 .61633 Mtetra
.559 .34 .539 r
.53034 .61633 .53092 .42332 .53302 .61945 .53209 .62046 Mtetra
.717 .289 .23 r
.53209 .62046 .53302 .61945 .53477 .62277 .53384 .62217 Mtetra
.337 .711 .984 r
.53384 .62217 .53477 .62277 .53652 .62313 .53558 .62224 Mtetra
.66 .776 .935 r
.53558 .62224 .53652 .62313 .53826 .62254 .53733 .62168 Mtetra
.791 .808 .866 r
.53733 .62168 .53826 .62254 .54 .62084 .53907 .62038 Mtetra
.931 .844 .736 r
.53907 .62038 .54 .62084 .54172 .6155 .5408 .61728 Mtetra
.957 .874 .472 r
.5408 .61728 .54172 .6155 .54239 .41592 .54252 .61117 Mtetra
0 0 .367 r
.54252 .61117 .54239 .41592 .544 .40955 .54317 .41672 Mtetra
.393 .151 .423 r
.54317 .41672 .544 .40955 .54564 .40838 .5448 .41424 Mtetra
.526 .25 .439 r
.5448 .41424 .54564 .40838 .54728 .40795 .54645 .41406 Mtetra
.589 .308 .457 r
.54645 .41406 .54728 .40795 .54893 .40788 .54811 .41508 Mtetra
.516 .253 .455 r
.54811 .41508 .54893 .40788 .55057 .40734 .54976 .4146 Mtetra
.518 .255 .456 r
.54976 .4146 .55057 .40734 .55222 .40682 .55141 .41415 Mtetra
.518 .256 .457 r
.55141 .41415 .55222 .40682 .55386 .4063 .55306 .41371 Mtetra
.514 .253 .457 r
.55306 .41371 .55386 .4063 .55551 .40576 .55472 .41317 Mtetra
.513 .252 .457 r
.55472 .41317 .55551 .40576 .55716 .40521 .55637 .41261 Mtetra
.512 .251 .456 r
.55637 .41261 .55716 .40521 .55881 .40465 .55802 .41202 Mtetra
.511 .25 .456 r
.55802 .41202 .55881 .40465 .56046 .4041 .55968 .41143 Mtetra
.51 .249 .455 r
.55968 .41143 .56046 .4041 .56211 .40354 .56133 .41082 Mtetra
.51 .249 .454 r
.56133 .41082 .56211 .40354 .56376 .40299 .56299 .41021 Mtetra
.509 .248 .454 r
.56299 .41021 .56376 .40299 .56541 .40243 .56465 .4096 Mtetra
.509 .247 .453 r
.56465 .4096 .56541 .40243 .56707 .40187 .5663 .40899 Mtetra
.509 .247 .452 r
.5663 .40899 .56707 .40187 .56872 .40132 .56796 .40839 Mtetra
.51 .247 .452 r
.56796 .40839 .56872 .40132 .57038 .40077 .56962 .40782 Mtetra
.56962 .40782 .57038 .40077 .57204 .40022 .57129 .40725 Mtetra
.57129 .40725 .57204 .40022 .57369 .39968 .57295 .40667 Mtetra
.584 .309 .466 r
.57295 .40667 .57369 .39968 .57535 .39921 .57464 .40766 Mtetra
.54 .281 .472 r
.57464 .40766 .57535 .39921 .57701 .39871 .57631 .40763 Mtetra
.425 .189 .45 r
.57631 .40763 .57701 .39871 .57867 .39811 .57794 .40503 Mtetra
.118 0 .334 r
.57794 .40503 .57867 .39811 .58033 .3972 .57953 .39951 Mtetra
0 0 0 r
.57953 .39951 .58033 .3972 .58199 .39626 .58114 .39624 Mtetra
.922 .952 .794 r
.58114 .39624 .58199 .39626 .58364 .39538 .58278 .39406 Mtetra
.714 .703 .838 r
.58278 .39406 .58364 .39538 .58531 .39476 .58444 .39318 Mtetra
.649 .64 .828 r
.58444 .39318 .58531 .39476 .58697 .39423 .5861 .39266 Mtetra
.619 .627 .837 r
.5861 .39266 .58697 .39423 .58864 .39375 .58777 .39231 Mtetra
.653 .662 .846 r
.58777 .39231 .58864 .39375 .59031 .39321 .58944 .39178 Mtetra
.653 .663 .847 r
.58944 .39178 .59031 .39321 .59198 .39267 .59111 .39126 Mtetra
.648 .662 .85 r
.59111 .39126 .59198 .39267 .59365 .39214 .59278 .39076 Mtetra
.629 .66 .861 r
.59278 .39076 .59365 .39214 .59532 .39164 .59446 .39036 Mtetra
.624 .675 .878 r
.59446 .39036 .59532 .39164 .59699 .39114 .59613 .38999 Mtetra
.627 .7 .898 r
.59613 .38999 .59699 .39114 .59866 .39062 .59781 .3896 Mtetra
.649 .734 .912 r
.59781 .3896 .59866 .39062 .60034 .39007 .59949 .38912 Mtetra
.665 .755 .917 r
.59949 .38912 .60034 .39007 .60201 .38949 .60116 .38856 Mtetra
.68 .765 .915 r
.60116 .38856 .60201 .38949 .60369 .38889 .60284 .38794 Mtetra
.705 .768 .901 r
.60284 .38794 .60369 .38889 .60536 .38826 .60451 .3872 Mtetra
.707 .745 .882 r
.60451 .3872 .60536 .38826 .60704 .38763 .60618 .38643 Mtetra
.698 .717 .864 r
.60618 .38643 .60704 .38763 .60871 .387 .60786 .38568 Mtetra
.711 .703 .84 r
.60786 .38568 .60871 .387 .61038 .38605 .60953 .38482 Mtetra
.685 .707 .865 r
.60953 .38482 .61038 .38605 .61206 .38532 .6112 .38414 Mtetra
.604 .685 .899 r
.6112 .38414 .61206 .38532 .61375 .38515 .61289 .38384 Mtetra
.008 .315 .804 r
.61289 .38384 .61375 .38515 .61552 .38771 .61463 .3851 Mtetra
0 0 .547 r
.61463 .3851 .61552 .38771 .62283 .58265 .61642 .3885 Mtetra
0 0 .407 r
.61642 .3885 .62283 .58265 .62496 .59382 .6237 .58053 Mtetra
.435 .284 .576 r
.6237 .58053 .62496 .59382 .6268 .59464 .62563 .58456 Mtetra
.606 .419 .602 r
.62563 .58456 .6268 .59464 .6286 .59403 .6274 .58309 Mtetra
.601 .412 .598 r
.6274 .58309 .6286 .59403 .63038 .59295 .62917 .58167 Mtetra
.347 .228 .572 r
.62917 .58167 .63038 .59295 .63219 .5926 .63115 .58703 Mtetra
.304 .247 .627 r
.63115 .58703 .63219 .5926 .634 .59249 .63306 .59011 Mtetra
.234 .331 .759 r
.63306 .59011 .634 .59249 .63582 .59231 .63494 .59166 Mtetra
.382 .727 .99 r
.63494 .59166 .63582 .59231 .63763 .59183 .63676 .59169 Mtetra
.506 .897 .947 r
.63676 .59169 .63763 .59183 .63943 .5912 .63857 .5911 Mtetra
.624 .949 .939 r
.63857 .5911 .63943 .5912 .64123 .5905 .64036 .59023 Mtetra
.664 .935 .968 r
.64036 .59023 .64123 .5905 .64304 .58983 .64216 .5894 Mtetra
.691 .907 .972 r
.64216 .5894 .64304 .58983 .64484 .58918 .64397 .58858 Mtetra
.705 .867 .959 r
.64397 .58858 .64484 .58918 .64665 .58856 .64577 .58777 Mtetra
.678 .813 .948 r
.64577 .58777 .64665 .58856 .64846 .58801 .64758 .5871 Mtetra
.657 .778 .938 r
.64758 .5871 .64846 .58801 .65028 .58751 .64939 .58652 Mtetra
.645 .757 .931 r
.64939 .58652 .65028 .58751 .65209 .58704 .6512 .586 Mtetra
.646 .746 .922 r
.6512 .586 .65209 .58704 .65391 .5866 .65302 .58548 Mtetra
.64 .728 .912 r
.65302 .58548 .65391 .5866 .65573 .58618 .65484 .58499 Mtetra
.626 .71 .906 r
.65484 .58499 .65573 .58618 .65756 .58577 .65666 .58457 Mtetra
.59 .692 .913 r
.65666 .58457 .65756 .58577 .65938 .58537 .65849 .5843 Mtetra
.566 .708 .937 r
.65849 .5843 .65938 .58537 .66121 .58497 .66033 .58409 Mtetra
.554 .746 .966 r
.66033 .58409 .66121 .58497 .66303 .58456 .66216 .58385 Mtetra
.466 .753 .992 r
.66216 .58385 .66303 .58456 .66488 .58451 .66401 .58375 Mtetra
.545 .777 .984 r
.66401 .58375 .66488 .58451 .66672 .5843 .66584 .58348 Mtetra
.688 .813 .942 r
.66584 .58348 .66672 .5843 .66853 .58345 .66766 .58276 Mtetra
.9 .85 .785 r
.66766 .58276 .66853 .58345 .67022 .57972 .66941 .58036 Mtetra
.99 .883 .559 r
.66941 .58036 .67022 .57972 .6635 .38158 .67103 .57506 Mtetra
0 0 .408 r
.67103 .57506 .6635 .38158 .66476 .37067 .66432 .37839 Mtetra
.278 .069 .406 r
.66432 .37839 .66476 .37067 .66641 .36854 .66586 .37383 Mtetra
.523 .24 .427 r
.66586 .37383 .66641 .36854 .66812 .36795 .6676 .37366 Mtetra
.535 .255 .437 r
.6676 .37366 .66812 .36795 .66986 .36778 .66934 .37366 Mtetra
.27 .044 .376 r
.66934 .37366 .66986 .36778 .67157 .36719 .67093 .37012 Mtetra
0 0 .124 r
.67093 .37012 .67157 .36719 .67327 .3663 .67252 .3667 Mtetra
.876 .982 .696 r
.67252 .3667 .67327 .3663 .67498 .36544 .67415 .36435 Mtetra
.771 .765 .847 r
.67415 .36435 .67498 .36544 .67669 .36477 .67584 .36315 Mtetra
.656 .643 .825 r
.67584 .36315 .67669 .36477 .67842 .36424 .67756 .36256 Mtetra
.622 .62 .827 r
.67756 .36256 .67842 .36424 .68014 .36375 .67929 .36218 Mtetra
.637 .64 .837 r
.67929 .36218 .68014 .36375 .68187 .36323 .68102 .36172 Mtetra
.652 .656 .841 r
.68102 .36172 .68187 .36323 .68359 .36268 .68275 .36117 Mtetra
.652 .657 .841 r
.68275 .36117 .68359 .36268 .68532 .36212 .68447 .36063 Mtetra
.654 .659 .842 r
.68447 .36063 .68532 .36212 .68704 .36157 .6862 .36007 Mtetra
.653 .659 .843 r
.6862 .36007 .68704 .36157 .68877 .36101 .68793 .35952 Mtetra
.649 .658 .845 r
.68793 .35952 .68877 .36101 .6905 .36046 .68966 .359 Mtetra
.635 .655 .853 r
.68966 .359 .6905 .36046 .69223 .35994 .6914 .35856 Mtetra
.623 .662 .868 r
.6914 .35856 .69223 .35994 .69396 .35943 .69314 .35817 Mtetra
.623 .684 .887 r
.69314 .35817 .69396 .35943 .6957 .35891 .69488 .35779 Mtetra
.637 .716 .905 r
.69488 .35779 .6957 .35891 .69743 .35837 .69662 .35734 Mtetra
.656 .744 .915 r
.69662 .35734 .69743 .35837 .69916 .35779 .69836 .35681 Mtetra
.67 .758 .917 r
.69836 .35681 .69916 .35779 .7009 .35719 .70009 .35621 Mtetra
.69 .765 .909 r
.70009 .35621 .7009 .35719 .70263 .35658 .70182 .35551 Mtetra
.701 .751 .89 r
.70182 .35551 .70263 .35658 .70436 .35597 .70355 .35476 Mtetra
.697 .724 .87 r
.70355 .35476 .70436 .35597 .7061 .35534 .70527 .354 Mtetra
.682 .696 .856 r
.70527 .354 .7061 .35534 .70783 .3547 .70701 .35331 Mtetra
.67 .682 .852 r
.70701 .35331 .70783 .3547 .70957 .35406 .70874 .35267 Mtetra
.666 .681 .855 r
.70874 .35267 .70957 .35406 .71131 .35343 .71048 .35206 Mtetra
.693 .696 .849 r
.71048 .35206 .71131 .35343 .71303 .35257 .71221 .35129 Mtetra
.701 .713 .858 r
.71221 .35129 .71303 .35257 .71476 .3517 .71394 .35049 Mtetra
.645 .705 .89 r
.71394 .35049 .71476 .3517 .71651 .35128 .71569 .35 Mtetra
.38 .556 .901 r
.71569 .35 .71651 .35128 .71837 .35256 .7175 .35046 Mtetra
.021 .204 .712 r
.7175 .35046 .71837 .35256 .7206 .35988 .71941 .35263 Mtetra
0 .013 .516 r
.71941 .35263 .7206 .35988 .73482 .56018 .72168 .36035 Mtetra
.057 0 .443 r
.72168 .36035 .73482 .56018 .73689 .56295 .73569 .55623 Mtetra
.354 .269 .62 r
.73569 .55623 .73689 .56295 .73881 .56308 .7378 .55952 Mtetra
.411 .376 .71 r
.7378 .55952 .73881 .56308 .74068 .5626 .73979 .56086 Mtetra
.419 .52 .854 r
.73979 .56086 .74068 .5626 .74257 .56228 .74174 .56141 Mtetra
.482 .72 .976 r
.74174 .56141 .74257 .56228 .74448 .56216 .74364 .56135 Mtetra
.711 .829 .938 r
.74364 .56135 .74448 .56216 .74634 .56141 .7455 .56051 Mtetra
.913 .821 .742 r
.7455 .56051 .74634 .56141 .74807 .55858 .74722 .55757 Mtetra
.979 .728 .485 r
.74722 .55757 .74807 .55858 .74899 .54362 .74813 .54237 Mtetra
.977 .683 .389 r
.74813 .54237 .74899 .54362 .7377 .34715 .7369 .34606 Mtetra
.904 .784 .719 r
.7369 .34606 .7377 .34715 .7393 .34412 .7385 .34303 Mtetra
.704 .751 .888 r
.7385 .34303 .7393 .34412 .74104 .34333 .74024 .34225 Mtetra
.58 .702 .926 r
.74024 .34225 .74104 .34333 .74282 .34309 .74203 .34201 Mtetra
.64 .729 .913 r
.74203 .34201 .74282 .34309 .74459 .34261 .7438 .34153 Mtetra
.731 .763 .879 r
.7438 .34153 .74459 .34261 .74633 .34168 .74554 .3406 Mtetra
.626 .724 .917 r
.74554 .3406 .74633 .34168 .7481 .34125 .74731 .34018 Mtetra
0 .245 .754 r
.74731 .34018 .7481 .34125 .75001 .34262 .74922 .34166 Mtetra
.975 .673 .364 r
.74922 .34166 .75001 .34262 .75297 .3587 .76481 .53451 Mtetra
.581 .356 .539 r
.76481 .53451 .75297 .3587 .76877 .55224 .76798 .55174 Mtetra
.652 .121 0 r
.76798 .55174 .76877 .55224 .77088 .5547 .77007 .55396 Mtetra
.518 .776 .99 r
.77007 .55396 .77088 .5547 .77282 .55469 .77199 .55373 Mtetra
.754 .809 .896 r
.77199 .55373 .77282 .55469 .77468 .55369 .77385 .55265 Mtetra
.853 .81 .807 r
.77385 .55265 .77468 .55369 .77642 .55104 .77564 .55063 Mtetra
.965 .88 .699 r
.77564 .55063 .77642 .55104 .77774 .54283 .77731 .54712 Mtetra
0 0 .037 r
.77731 .54712 .77774 .54283 .76435 .34034 .7786 .53852 Mtetra
.069 0 .445 r
.7786 .53852 .76435 .34034 .76586 .33631 .76551 .34091 Mtetra
.108 0 .306 r
.76551 .34091 .76586 .33631 .76759 .33512 .76701 .33665 Mtetra
0 0 0 r
.76701 .33665 .76759 .33512 .76936 .3345 .76865 .3343 Mtetra
.812 .979 .894 r
.76865 .3343 .76936 .3345 .77115 .33405 .77036 .3329 Mtetra
.686 .735 .888 r
.77036 .3329 .77115 .33405 .77293 .33345 .77214 .3322 Mtetra
.639 .697 .888 r
.77214 .3322 .77293 .33345 .77471 .3329 .77393 .33173 Mtetra
.686 .732 .886 r
.77393 .33173 .77471 .3329 .77648 .33216 .7757 .33103 Mtetra
.763 .766 .855 r
.7757 .33103 .77648 .33216 .77823 .33115 .77743 .32987 Mtetra
.678 .709 .871 r
.77743 .32987 .77823 .33115 .78001 .3306 .77921 .3292 Mtetra
.279 .473 .87 r
.77921 .3292 .78001 .3306 .78192 .33153 .78111 .33003 Mtetra
.888 .516 .046 r
.78111 .33003 .78192 .33153 .78447 .34018 .78363 .33839 Mtetra
.976 .67 .344 r
.78363 .33839 .78447 .34018 .80295 .54159 .80217 .54092 Mtetra
.717 .226 0 r
.80217 .54092 .80295 .54159 .80517 .54463 .80438 .54398 Mtetra
.355 .716 .986 r
.80438 .54398 .80517 .54463 .80714 .54478 .80635 .54406 Mtetra
.703 .854 .955 r
.80635 .54406 .80714 .54478 .80903 .54389 .80825 .54322 Mtetra
.859 .889 .857 r
.80825 .54322 .80903 .54389 .8108 .54151 .81007 .54145 Mtetra
.967 .933 .687 r
.81007 .54145 .8108 .54151 .81214 .53415 .81175 .53813 Mtetra
0 0 .063 r
.81175 .53813 .81214 .53415 .79653 .33018 .81305 .53032 Mtetra
.08 0 .452 r
.81305 .53032 .79653 .33018 .79797 .32545 .79765 .3296 Mtetra
0 0 .252 r
.79765 .3296 .79797 .32545 .79967 .32376 .79907 .3247 Mtetra
0 0 0 r
.79907 .3247 .79967 .32376 .80145 .32305 .80071 .32231 Mtetra
.713 .842 .943 r
.80071 .32231 .80145 .32305 .80336 .32372 .80249 .32149 Mtetra
.214 .322 .759 r
.80249 .32149 .80336 .32372 .80573 .32958 .8045 .3232 Mtetra
.27 .214 .609 r
.8045 .3232 .80573 .32958 .82581 .53272 .80674 .32753 Mtetra
.539 .329 .544 r
.80674 .32753 .82581 .53272 .828 .53507 .80932 .33563 Mtetra
.572 .353 .545 r
.80932 .33563 .828 .53507 .82918 .52622 .81016 .32431 Mtetra
.56 .344 .544 r
.81016 .32431 .82918 .52622 .81262 .3235 .81165 .32015 Mtetra
.717 .566 .683 r
.81165 .32015 .81262 .3235 .81409 .31934 .81332 .31817 Mtetra
.374 .577 .919 r
.81332 .31817 .81409 .31934 .81586 .31831 .81522 .31859 Mtetra
.71 .184 0 r
.81522 .31859 .81586 .31831 .81771 .31817 .81726 .32042 Mtetra
.856 .485 .347 r
.81726 .32042 .81771 .31817 .81968 .31936 .81974 .32701 Mtetra
.97 .658 .357 r
.81974 .32701 .81968 .31936 .82222 .32651 .84038 .52628 Mtetra
.558 .338 .538 r
.84038 .52628 .82222 .32651 .8433 .52866 .84273 .52998 Mtetra
.574 .125 .146 r
.84273 .52998 .8433 .52866 .84561 .53195 .8448 .53075 Mtetra
.855 .793 .79 r
.8448 .53075 .84561 .53195 .84756 .53151 .84659 .52859 Mtetra
.83 .648 .657 r
.84659 .52859 .84756 .53151 .84945 .53029 .8482 .52454 Mtetra
.839 .6 .577 r
.8482 .52454 .84945 .53029 .8513 .52875 .84932 .51553 Mtetra
.97 .664 .379 r
.84932 .51553 .8513 .52875 .85322 .52796 .8334 .33231 Mtetra
.549 .337 .544 r
.8334 .33231 .85322 .52796 .85516 .52735 .83552 .33465 Mtetra
.131 .042 .478 r
.83552 .33465 .85516 .52735 .85713 .52697 .85536 .51602 Mtetra
.326 .224 .582 r
.85536 .51602 .85713 .52697 .85914 .52693 .85799 .52235 Mtetra
.324 .291 .666 r
.85799 .52235 .85914 .52693 .86114 .52691 .86027 .52503 Mtetra
.291 .424 .824 r
.86027 .52503 .86114 .52691 .86314 .52677 .8624 .52619 Mtetra
.546 .836 .998 r
.8624 .52619 .86314 .52677 .8651 .5263 .86437 .52578 Mtetra
.654 .894 .982 r
.86437 .52578 .8651 .5263 .86706 .52575 .86631 .52502 Mtetra
.677 .85 .965 r
.86631 .52502 .86706 .52575 .86903 .52526 .86825 .52427 Mtetra
.409 .657 .961 r
.86825 .52427 .86903 .52526 .87105 .52533 .87029 .52446 Mtetra
.541 .76 .978 r
.87029 .52446 .87105 .52533 .87303 .52494 .87228 .52422 Mtetra
.782 .882 .919 r
.87228 .52422 .87303 .52494 .87491 .52355 .87418 .52298 Mtetra
.992 .816 .566 r
.87418 .52298 .87491 .52355 .87625 .51707 .87556 .51688 Mtetra
.976 .67 .323 r
.87556 .51688 .87625 .51707 .85649 .31118 .85578 .31041 Mtetra
.984 .799 .574 r
.85578 .31041 .85649 .31118 .85781 .30574 .85706 .3046 Mtetra
.763 .772 .86 r
.85706 .3046 .85781 .30574 .85958 .30459 .85883 .30343 Mtetra
.631 .716 .908 r
.85883 .30343 .85958 .30459 .86143 .30413 .86068 .30297 Mtetra
.553 .681 .924 r
.86068 .30297 .86143 .30413 .86331 .30396 .86257 .30283 Mtetra
.751 .771 .869 r
.86257 .30283 .86331 .30396 .86509 .30287 .86435 .30174 Mtetra
.684 .747 .899 r
.86435 .30174 .86509 .30287 .86692 .30216 .86618 .30104 Mtetra
.478 .649 .933 r
.86618 .30104 .86692 .30216 .86883 .30226 .8681 .30114 Mtetra
.755 .339 0 r
.8681 .30114 .86883 .30226 .8713 .30729 .87056 .30617 Mtetra
.971 .656 .295 r
.87056 .30617 .8713 .30729 .89603 .51237 .89526 .51131 Mtetra
.73 .298 0 r
.89526 .51131 .89603 .51237 .8986 .51706 .89783 .516 Mtetra
.302 .577 .937 r
.89783 .516 .8986 .51706 .9007 .51759 .89993 .51653 Mtetra
.648 .763 .933 r
.89993 .51653 .9007 .51759 .90268 .51701 .90191 .51595 Mtetra
.828 .821 .842 r
.90191 .51595 .90268 .51701 .90454 .5153 .90377 .51424 Mtetra
.908 .736 .657 r
.2675 .69747 .26854 .69831 .27049 .69276 .26945 .69192 Mtetra
.936 .686 .535 r
.26945 .69192 .27049 .69276 .28611 .49709 .28514 .49619 Mtetra
.908 .728 .647 r
.28514 .49619 .28611 .49709 .28798 .49136 .28701 .49046 Mtetra
.772 .76 .842 r
.28701 .49046 .28798 .49136 .28952 .49024 .28855 .48934 Mtetra
.639 .736 .919 r
.28855 .48934 .28952 .49024 .291 .48984 .29004 .48894 Mtetra
.507 .692 .951 r
.29004 .48894 .291 .48984 .29247 .4898 .2915 .4889 Mtetra
.749 .759 .861 r
.2915 .4889 .29247 .4898 .29399 .48886 .29303 .48796 Mtetra
.696 .751 .894 r
.29303 .48796 .29399 .48886 .2955 .48822 .29453 .48733 Mtetra
.478 .682 .955 r
.29453 .48733 .2955 .48822 .29696 .48824 .296 .48735 Mtetra
.927 .548 .256 r
.296 .48735 .29696 .48824 .29815 .49224 .29718 .49139 Mtetra
.939 .683 .523 r
.29718 .49139 .29815 .49224 .28638 .68704 .28535 .68625 Mtetra
.933 .579 .331 r
.28535 .68625 .28638 .68704 .28758 .69239 .28654 .69156 Mtetra
.25 .6 .952 r
.28654 .69156 .28758 .69239 .28911 .69274 .28808 .6919 Mtetra
.673 .771 .924 r
.28808 .6919 .28911 .69274 .29071 .69218 .28968 .69133 Mtetra
.751 .782 .878 r
.28968 .69133 .29071 .69218 .29234 .69121 .29131 .69036 Mtetra
.482 .708 .969 r
.29131 .69036 .29234 .69121 .2939 .69119 .29287 .69033 Mtetra
.589 .745 .951 r
.29287 .69033 .2939 .69119 .29548 .69092 .29445 .69006 Mtetra
.751 .777 .875 r
.29445 .69006 .29548 .69092 .29711 .68995 .29608 .68908 Mtetra
.906 .741 .666 r
.29608 .68908 .29711 .68995 .299 .68497 .29797 .68407 Mtetra
.939 .687 .529 r
.29797 .68407 .299 .68497 .31309 .48904 .31213 .48808 Mtetra
.911 .724 .637 r
.31213 .48808 .31309 .48904 .31497 .48273 .31401 .4818 Mtetra
.795 .759 .82 r
.31401 .4818 .31497 .48273 .31654 .48137 .31558 .48045 Mtetra
.646 .736 .915 r
.31558 .48045 .31654 .48137 .31804 .48093 .31708 .48002 Mtetra
.508 .69 .949 r
.31708 .48002 .31804 .48093 .31953 .48089 .31857 .47998 Mtetra
.732 .757 .873 r
.31857 .47998 .31953 .48089 .32106 .48004 .3201 .47915 Mtetra
.702 .755 .893 r
.3201 .47915 .32106 .48004 .32258 .47937 .32162 .47848 Mtetra
.498 .692 .955 r
.32162 .47848 .32258 .47937 .32407 .47934 .32311 .47846 Mtetra
.919 .526 .216 r
.32311 .47846 .32407 .47934 .32532 .48313 .32436 .48223 Mtetra
.942 .683 .517 r
.32436 .48223 .32532 .48313 .31508 .6789 .31406 .67794 Mtetra
.939 .582 .309 r
.31406 .67794 .31508 .6789 .31633 .68434 .31531 .68341 Mtetra
.193 .542 .928 r
.31531 .68341 .31633 .68434 .31788 .6848 .31686 .6839 Mtetra
.691 .762 .906 r
.31686 .6839 .31788 .6848 .3195 .68413 .31848 .68324 Mtetra
.767 .777 .861 r
.31848 .68324 .3195 .68413 .32115 .683 .32013 .68213 Mtetra
.566 .738 .957 r
.32013 .68213 .32115 .683 .32275 .68279 .32173 .68192 Mtetra
.588 .743 .95 r
.32173 .68192 .32275 .68279 .32435 .68253 .32333 .68164 Mtetra
.745 .774 .876 r
.32333 .68164 .32435 .68253 .32599 .6816 .32497 .68068 Mtetra
.905 .743 .67 r
.32497 .68068 .32599 .6816 .32784 .67683 .32683 .67589 Mtetra
.942 .688 .523 r
.32683 .67589 .32784 .67683 .34043 .47988 .33947 .47896 Mtetra
.917 .729 .634 r
.33947 .47896 .34043 .47988 .34228 .47351 .34133 .47262 Mtetra
.809 .768 .815 r
.34133 .47262 .34228 .47351 .34386 .47206 .34291 .47115 Mtetra
.614 .73 .929 r
.34291 .47115 .34386 .47206 .34537 .47177 .34442 .47083 Mtetra
.436 .653 .951 r
.34442 .47083 .34537 .47177 .34686 .47192 .34591 .47095 Mtetra
.582 .705 .927 r
.34591 .47095 .34686 .47192 .34837 .47171 .34743 .47074 Mtetra
.638 .724 .911 r
.34743 .47074 .34837 .47171 .3499 .47128 .34895 .47034 Mtetra
.648 .733 .911 r
.34895 .47034 .3499 .47128 .35142 .47082 .35047 .4699 Mtetra
.685 .748 .9 r
.35047 .4699 .35142 .47082 .35296 .47007 .35201 .4693 Mtetra
.686 .783 .924 r
.35201 .4693 .35296 .47007 .3545 .4694 .35355 .46871 Mtetra
.644 .795 .955 r
.35355 .46871 .3545 .4694 .35603 .46908 .35507 .46825 Mtetra
.409 .672 .968 r
.35507 .46825 .35603 .46908 .35747 .47031 .35658 .46837 Mtetra
.422 .471 .806 r
.35658 .46837 .35747 .47031 .35878 .47422 .35806 .46891 Mtetra
.504 .377 .641 r
.35806 .46891 .35878 .47422 .35083 .66371 .35953 .46966 Mtetra
.554 .34 .544 r
.35953 .46966 .35083 .66371 .3523 .66649 .36107 .46914 Mtetra
.555 .341 .544 r
.36107 .46914 .3523 .66649 .35395 .66545 .36263 .46822 Mtetra
.553 .339 .544 r
.36263 .46822 .35395 .66545 .3556 .66444 .36415 .46799 Mtetra
.542 .33 .542 r
.36415 .46799 .3556 .66444 .35705 .6676 .3654 .4734 Mtetra
0 0 .285 r
.3654 .4734 .35705 .6676 .35853 .67029 .35767 .66648 Mtetra
0 0 .467 r
.35767 .66648 .35853 .67029 .36007 .67178 .35909 .67048 Mtetra
.202 .46 .88 r
.35909 .67048 .36007 .67178 .36168 .67199 .36067 .67122 Mtetra
.618 .778 .958 r
.36067 .67122 .36168 .67199 .36331 .67157 .3623 .67082 Mtetra
.715 .805 .921 r
.3623 .67082 .36331 .67157 .36495 .67093 .36395 .67005 Mtetra
.661 .765 .927 r
.36395 .67005 .36495 .67093 .36658 .67059 .36559 .66952 Mtetra
.637 .717 .906 r
.36559 .66952 .36658 .67059 .36822 .67029 .36723 .66909 Mtetra
.671 .706 .874 r
.36723 .66909 .36822 .67029 .36986 .66962 .36887 .66851 Mtetra
.758 .741 .837 r
.36887 .66851 .36986 .66962 .37157 .66755 .37054 .66736 Mtetra
.865 .916 .862 r
.37054 .66736 .37157 .66755 .37338 .66325 .37224 .6657 Mtetra
.032 0 .061 r
.37224 .6657 .37338 .66325 .38272 .48385 .37394 .66378 Mtetra
.551 .333 .537 r
.37394 .66378 .38272 .48385 .38495 .46735 .3756 .66297 Mtetra
.552 .334 .538 r
.3756 .66297 .38495 .46735 .38649 .46714 .37723 .66284 Mtetra
.551 .333 .538 r
.37723 .66284 .38649 .46714 .38802 .46725 .37888 .66211 Mtetra
.543 .327 .536 r
.37888 .66211 .38802 .46725 .38973 .46307 .38072 .65698 Mtetra
0 0 .283 r
.38072 .65698 .38973 .46307 .39142 .4593 .39035 .46168 Mtetra
.896 .873 .436 r
.39035 .46168 .39142 .4593 .39305 .45687 .39209 .45643 Mtetra
.873 .853 .819 r
.39209 .45643 .39305 .45687 .39463 .45563 .3937 .45459 Mtetra
.685 .728 .883 r
.3937 .45459 .39463 .45563 .39619 .45507 .39526 .45398 Mtetra
.592 .687 .908 r
.39526 .45398 .39619 .45507 .39773 .45474 .3968 .45375 Mtetra
.594 .709 .923 r
.3968 .45375 .39773 .45474 .39928 .45443 .39835 .45349 Mtetra
.623 .73 .924 r
.39835 .45349 .39928 .45443 .40083 .45409 .3999 .45313 Mtetra
.623 .727 .921 r
.3999 .45313 .40083 .45409 .40238 .45374 .40145 .45278 Mtetra
.64 .729 .913 r
.40145 .45278 .40238 .45374 .40394 .45332 .40301 .45236 Mtetra
.658 .736 .907 r
.40301 .45236 .40394 .45332 .4055 .45281 .40457 .45187 Mtetra
.669 .744 .907 r
.40457 .45187 .4055 .45281 .40706 .45224 .40613 .45133 Mtetra
.701 .759 .897 r
.40613 .45133 .40706 .45224 .40863 .45142 .4077 .45065 Mtetra
.714 .794 .914 r
.4077 .45065 .40863 .45142 .41021 .45054 .40927 .44992 Mtetra
.675 .824 .955 r
.40927 .44992 .41021 .45054 .41177 .45 .41084 .44934 Mtetra
.459 .742 .989 r
.41084 .44934 .41177 .45 .4133 .45064 .41239 .44928 Mtetra
.338 .512 .882 r
.41239 .44928 .4133 .45064 .41475 .45341 .41392 .44981 Mtetra
.462 .391 .69 r
.41392 .44981 .41475 .45341 .41557 .47562 .41544 .45065 Mtetra
.555 .355 .564 r
.41544 .45065 .41557 .47562 .41148 .64861 .41699 .45065 Mtetra
.555 .34 .544 r
.41699 .45065 .41148 .64861 .41315 .64797 .41857 .44975 Mtetra
.554 .34 .544 r
.41857 .44975 .41315 .64797 .41483 .64683 .42014 .44935 Mtetra
.547 .334 .543 r
.42014 .44935 .41483 .64683 .4164 .64929 .4216 .45233 Mtetra
0 0 .319 r
.4216 .45233 .4164 .64929 .41796 .65241 .4171 .64729 Mtetra
0 0 .463 r
.4171 .64729 .41796 .65241 .41956 .65412 .4186 .65252 Mtetra
.043 .301 .791 r
.4186 .65252 .41956 .65412 .4212 .65459 .42022 .6538 Mtetra
.586 .768 .966 r
.42022 .6538 .4212 .65459 .42287 .65419 .42188 .65349 Mtetra
.707 .822 .936 r
.42188 .65349 .42287 .65419 .42455 .65353 .42356 .65275 Mtetra
.703 .802 .926 r
.42356 .65275 .42455 .65353 .42623 .65288 .42525 .65202 Mtetra
.652 .772 .936 r
.42525 .65202 .42623 .65288 .4279 .65237 .42692 .65151 Mtetra
.652 .772 .937 r
.42692 .65151 .4279 .65237 .42958 .65185 .4286 .65099 Mtetra
.648 .771 .938 r
.4286 .65099 .42958 .65185 .43126 .65135 .43028 .65049 Mtetra
.643 .77 .94 r
.43028 .65049 .43126 .65135 .43294 .65086 .43196 .65001 Mtetra
.643 .772 .942 r
.43196 .65001 .43294 .65086 .43462 .65038 .43364 .64953 Mtetra
.589 .756 .958 r
.43364 .64953 .43462 .65038 .43629 .65 .43531 .64922 Mtetra
.546 .757 .975 r
.43531 .64922 .43629 .65 .43797 .64969 .43699 .64901 Mtetra
.675 .821 .954 r
.43699 .64901 .43797 .64969 .43966 .64913 .43868 .64839 Mtetra
.859 .811 .801 r
.43868 .64839 .43966 .64913 .44136 .6478 .4404 .64637 Mtetra
.905 .719 .641 r
.4404 .64637 .44136 .6478 .4431 .64509 .44221 .64051 Mtetra
.95 .685 .499 r
.44221 .64051 .4431 .64509 .44487 .64081 .44848 .44393 Mtetra
.562 .346 .545 r
.44848 .44393 .44487 .64081 .44665 .63605 .45017 .43927 Mtetra
.554 .34 .544 r
.45017 .43927 .44665 .63605 .44831 .63632 .45176 .43855 Mtetra
.553 .339 .544 r
.45176 .43855 .44831 .63632 .44999 .63621 .45334 .43837 Mtetra
.554 .34 .544 r
.45334 .43837 .44999 .63621 .45537 .46138 .45494 .43757 Mtetra
.582 .376 .567 r
.45494 .43757 .45537 .46138 .45741 .43953 .45656 .43576 Mtetra
.681 .528 .672 r
.45656 .43576 .45741 .43953 .45907 .43563 .45817 .43419 Mtetra
.735 .684 .801 r
.45817 .43419 .45907 .43563 .46069 .43371 .45978 .43309 Mtetra
.67 .826 .959 r
.45978 .43309 .46069 .43371 .46229 .43303 .46137 .43251 Mtetra
.604 .837 .988 r
.46137 .43251 .46229 .43303 .46388 .43268 .46296 .43209 Mtetra
.612 .82 .98 r
.46296 .43209 .46388 .43268 .46547 .43236 .46455 .43167 Mtetra
.655 .806 .956 r
.46455 .43167 .46547 .43236 .46706 .43185 .46615 .43115 Mtetra
.652 .803 .955 r
.46615 .43115 .46706 .43185 .46866 .43136 .46775 .43064 Mtetra
.64 .794 .956 r
.46775 .43064 .46866 .43136 .47025 .43094 .46934 .43018 Mtetra
.624 .778 .955 r
.46934 .43018 .47025 .43094 .47185 .43061 .47094 .42977 Mtetra
.633 .762 .941 r
.47094 .42977 .47185 .43061 .47344 .43026 .47254 .42935 Mtetra
.659 .753 .919 r
.47254 .42935 .47344 .43026 .47504 .4298 .47414 .42884 Mtetra
.69 .751 .898 r
.47414 .42884 .47504 .4298 .47665 .42915 .47574 .4282 Mtetra
.696 .754 .897 r
.47574 .4282 .47665 .42915 .47825 .42846 .47735 .42753 Mtetra
.691 .757 .902 r
.47735 .42753 .47825 .42846 .47986 .42781 .47895 .42688 Mtetra
.675 .754 .91 r
.47895 .42688 .47986 .42781 .48146 .42725 .48056 .4263 Mtetra
.669 .749 .91 r
.48056 .4263 .48146 .42725 .48307 .42672 .48217 .42575 Mtetra
.688 .751 .899 r
.48217 .42575 .48307 .42672 .48467 .42613 .48377 .42512 Mtetra
.718 .748 .875 r
.48377 .42512 .48467 .42613 .48628 .42544 .48538 .42431 Mtetra
.65 .705 .887 r
.48538 .42431 .48628 .42544 .48789 .42494 .48699 .42384 Mtetra
.305 .548 .918 r
.48699 .42384 .48789 .42494 .48949 .42499 .48859 .42431 Mtetra
.888 .46 .114 r
.48859 .42431 .48949 .42499 .49108 .42629 .49016 .42786 Mtetra
.956 .681 .474 r
.49016 .42786 .49108 .42629 .49266 .42888 .48977 .62322 Mtetra
.562 .343 .539 r
.48977 .62322 .49266 .42888 .49423 .43348 .49142 .62938 Mtetra
.552 .334 .538 r
.49142 .62938 .49423 .43348 .49583 .43474 .49313 .62951 Mtetra
.551 .333 .538 r
.49313 .62951 .49583 .43474 .49746 .43316 .49485 .62873 Mtetra
.55 .333 .538 r
.49485 .62873 .49746 .43316 .49909 .43124 .49657 .62769 Mtetra
.551 .334 .538 r
.49657 .62769 .49909 .43124 .50071 .43073 .49829 .6272 Mtetra
.49829 .6272 .50071 .43073 .50233 .43021 .50001 .62671 Mtetra
.50001 .62671 .50233 .43021 .50395 .4297 .50173 .62621 Mtetra
.50173 .62621 .50395 .4297 .50557 .42921 .50345 .62573 Mtetra
.50345 .62573 .50557 .42921 .5072 .42872 .50518 .62524 Mtetra
.50518 .62524 .5072 .42872 .50882 .42822 .5069 .62476 Mtetra
.5069 .62476 .50882 .42822 .51045 .42772 .50862 .62427 Mtetra
.50862 .62427 .51045 .42772 .51207 .42721 .51035 .62377 Mtetra
.51035 .62377 .51207 .42721 .5137 .42669 .51208 .62327 Mtetra
.51208 .62327 .5137 .42669 .51533 .42615 .51381 .62277 Mtetra
.51381 .62277 .51533 .42615 .51696 .42559 .51554 .62226 Mtetra
.51554 .62226 .51696 .42559 .51859 .42499 .51727 .62174 Mtetra
.51727 .62174 .51859 .42499 .52022 .42432 .519 .62121 Mtetra
.519 .62121 .52022 .42432 .52186 .42367 .52073 .62068 Mtetra
.52073 .62068 .52186 .42367 .52349 .42276 .52246 .6201 Mtetra
.551 .333 .538 r
.52246 .6201 .52349 .42276 .52513 .4208 .5242 .61932 Mtetra
.551 .334 .538 r
.5242 .61932 .52513 .4208 .52676 .42022 .52594 .61877 Mtetra
.552 .334 .538 r
.52594 .61877 .52676 .42022 .5284 .42375 .52767 .61877 Mtetra
.554 .336 .538 r
.52767 .61877 .5284 .42375 .53034 .61633 .52941 .61977 Mtetra
.588 .263 .386 r
.52941 .61977 .53034 .61633 .53209 .62046 .53116 .62055 Mtetra
.328 0 0 r
.53116 .62055 .53209 .62046 .53384 .62217 .5329 .62095 Mtetra
.586 .68 .906 r
.5329 .62095 .53384 .62217 .53558 .62224 .53464 .62071 Mtetra
.65 .657 .844 r
.53464 .62071 .53558 .62224 .53733 .62168 .53639 .62018 Mtetra
.701 .682 .828 r
.53639 .62018 .53733 .62168 .53907 .62038 .53813 .61931 Mtetra
.8 .771 .826 r
.53813 .61931 .53907 .62038 .5408 .61728 .53988 .61779 Mtetra
.77 .983 .733 r
.53988 .61779 .5408 .61728 .54252 .61117 .54162 .61594 Mtetra
.352 .082 .357 r
.54162 .61594 .54252 .61117 .54317 .41672 .54336 .61399 Mtetra
.551 .333 .538 r
.54336 .61399 .54317 .41672 .5448 .41424 .5451 .61319 Mtetra
.551 .334 .538 r
.5451 .61319 .5448 .41424 .54645 .41406 .54685 .61279 Mtetra
.552 .334 .538 r
.54685 .61279 .54645 .41406 .54811 .41508 .5486 .61256 Mtetra
.551 .334 .538 r
.5486 .61256 .54811 .41508 .54976 .4146 .55036 .61208 Mtetra
.55036 .61208 .54976 .4146 .55141 .41415 .55211 .61159 Mtetra
.55211 .61159 .55141 .41415 .55306 .41371 .55386 .6111 Mtetra
.55386 .6111 .55306 .41371 .55472 .41317 .55562 .61059 Mtetra
.55562 .61059 .55472 .41317 .55637 .41261 .55737 .61008 Mtetra
.55737 .61008 .55637 .41261 .55802 .41202 .55913 .60956 Mtetra
.55913 .60956 .55802 .41202 .55968 .41143 .56089 .60904 Mtetra
.56089 .60904 .55968 .41143 .56133 .41082 .56265 .60851 Mtetra
.56265 .60851 .56133 .41082 .56299 .41021 .56441 .60798 Mtetra
.56441 .60798 .56299 .41021 .56465 .4096 .56617 .60744 Mtetra
.56617 .60744 .56465 .4096 .5663 .40899 .56793 .60691 Mtetra
.56793 .60691 .5663 .40899 .56796 .40839 .5697 .60638 Mtetra
.5697 .60638 .56796 .40839 .56962 .40782 .57146 .60586 Mtetra
.57146 .60586 .56962 .40782 .57129 .40725 .57323 .60533 Mtetra
.57323 .60533 .57129 .40725 .57295 .40667 .57499 .6048 Mtetra
.552 .335 .538 r
.57499 .6048 .57295 .40667 .57464 .40766 .57677 .60495 Mtetra
.552 .334 .538 r
.57677 .60495 .57464 .40766 .57631 .40763 .57854 .60458 Mtetra
.55 .332 .538 r
.57854 .60458 .57631 .40763 .57794 .40503 .5803 .60314 Mtetra
.529 .316 .535 r
.5803 .60314 .57794 .40503 .57953 .39951 .58186 .58974 Mtetra
0 0 .376 r
.58186 .58974 .57953 .39951 .58114 .39624 .58031 .39706 Mtetra
.96 .925 .586 r
.58031 .39706 .58114 .39624 .58278 .39406 .58192 .39317 Mtetra
.773 .793 .87 r
.58192 .39317 .58278 .39406 .58444 .39318 .58358 .39204 Mtetra
.655 .712 .89 r
.58358 .39204 .58444 .39318 .5861 .39266 .58524 .39153 Mtetra
.583 .685 .911 r
.58524 .39153 .5861 .39266 .58777 .39231 .58692 .39131 Mtetra
.654 .74 .913 r
.58692 .39131 .58777 .39231 .58944 .39178 .58859 .3908 Mtetra
.655 .745 .916 r
.58859 .3908 .58944 .39178 .59111 .39126 .59026 .39029 Mtetra
.648 .746 .921 r
.59026 .39029 .59111 .39126 .59278 .39076 .59193 .3898 Mtetra
.629 .742 .929 r
.59193 .3898 .59278 .39076 .59446 .39036 .5936 .38939 Mtetra
.625 .736 .927 r
.5936 .38939 .59446 .39036 .59613 .38999 .59528 .38899 Mtetra
.629 .733 .922 r
.59528 .38899 .59613 .38999 .59781 .3896 .59696 .38858 Mtetra
.649 .735 .913 r
.59696 .38858 .59781 .3896 .59949 .38912 .59863 .3881 Mtetra
.661 .74 .908 r
.59863 .3881 .59949 .38912 .60116 .38856 .60031 .38756 Mtetra
.672 .747 .907 r
.60031 .38756 .60116 .38856 .60284 .38794 .60198 .38697 Mtetra
.69 .76 .905 r
.60198 .38697 .60284 .38794 .60451 .3872 .60366 .38629 Mtetra
.697 .777 .913 r
.60366 .38629 .60451 .3872 .60618 .38643 .60533 .3856 Mtetra
.695 .793 .926 r
.60533 .3856 .60618 .38643 .60786 .38568 .60701 .38491 Mtetra
.703 .81 .931 r
.60701 .38491 .60786 .38568 .60953 .38482 .60869 .38418 Mtetra
.674 .839 .962 r
.60869 .38418 .60953 .38482 .6112 .38414 .61037 .38355 Mtetra
.607 .832 .985 r
.61037 .38355 .6112 .38414 .61289 .38384 .61205 .3831 Mtetra
.351 .671 .976 r
.61205 .3831 .61289 .38384 .61463 .3851 .61376 .38327 Mtetra
.425 .493 .826 r
.61376 .38327 .61463 .3851 .61642 .3885 .61547 .38382 Mtetra
.503 .393 .662 r
.61547 .38382 .61642 .3885 .6237 .58053 .6172 .38457 Mtetra
.554 .34 .544 r
.6172 .38457 .6237 .58053 .62563 .58456 .61888 .38392 Mtetra
.61888 .38392 .62563 .58456 .6274 .58309 .62056 .38305 Mtetra
.553 .339 .544 r
.62056 .38305 .6274 .58309 .62917 .58167 .62226 .38284 Mtetra
.543 .331 .543 r
.62226 .38284 .62917 .58167 .63115 .58703 .62414 .38829 Mtetra
0 0 .407 r
.62414 .38829 .63115 .58703 .63306 .59011 .63208 .58635 Mtetra
0 .029 .569 r
.63208 .58635 .63306 .59011 .63494 .59166 .63403 .59047 Mtetra
.335 .564 .921 r
.63403 .59047 .63494 .59166 .63676 .59169 .63587 .59095 Mtetra
.647 .818 .965 r
.63587 .59095 .63676 .59169 .63857 .5911 .63768 .59039 Mtetra
.748 .849 .926 r
.63768 .59039 .63857 .5911 .64036 .59023 .63948 .58939 Mtetra
.717 .813 .924 r
.63948 .58939 .64036 .59023 .64216 .5894 .64128 .58855 Mtetra
.706 .807 .928 r
.64128 .58855 .64216 .5894 .64397 .58858 .64308 .58776 Mtetra
.707 .814 .932 r
.64308 .58776 .64397 .58858 .64577 .58777 .64488 .58696 Mtetra
.686 .812 .943 r
.64488 .58696 .64577 .58777 .64758 .5871 .64669 .58625 Mtetra
.671 .8 .944 r
.64669 .58625 .64758 .5871 .64939 .58652 .6485 .58561 Mtetra
.662 .782 .938 r
.6485 .58561 .64939 .58652 .6512 .586 .65032 .58501 Mtetra
.66 .764 .927 r
.65032 .58501 .6512 .586 .65302 .58548 .65213 .58443 Mtetra
.652 .748 .92 r
.65213 .58443 .65302 .58548 .65484 .58499 .65395 .58388 Mtetra
.639 .731 .915 r
.65395 .58388 .65484 .58499 .65666 .58457 .65577 .5834 Mtetra
.61 .707 .913 r
.65577 .5834 .65666 .58457 .65849 .5843 .6576 .58304 Mtetra
.597 .685 .903 r
.6576 .58304 .65849 .5843 .66033 .58409 .65943 .58275 Mtetra
.599 .671 .891 r
.65943 .58275 .66033 .58409 .66216 .58385 .66126 .58245 Mtetra
.589 .657 .884 r
.66126 .58245 .66216 .58385 .66401 .58375 .6631 .58221 Mtetra
.61 .645 .86 r
.6631 .58221 .66401 .58375 .66584 .58348 .66494 .58188 Mtetra
.649 .654 .842 r
.66494 .58188 .66584 .58348 .66766 .58276 .66676 .58132 Mtetra
.752 .717 .819 r
.66676 .58132 .66766 .58276 .66941 .58036 .66856 .58005 Mtetra
.882 .938 .849 r
.66856 .58005 .66941 .58036 .67103 .57506 .67033 .57817 Mtetra
.189 0 .232 r
.67033 .57817 .67103 .57506 .66432 .37839 .67209 .57595 Mtetra
.551 .333 .538 r
.67209 .57595 .66432 .37839 .66586 .37383 .67391 .57522 Mtetra
.552 .334 .538 r
.67391 .57522 .66586 .37383 .6676 .37366 .67577 .57521 Mtetra
.551 .333 .538 r
.67577 .57521 .6676 .37366 .66934 .37366 .67759 .57443 Mtetra
.541 .326 .537 r
.67759 .57443 .66934 .37366 .67093 .37012 .67912 .56737 Mtetra
.009 0 .412 r
.67912 .56737 .67093 .37012 .67252 .3667 .67182 .36837 Mtetra
.805 .819 .338 r
.67182 .36837 .67252 .3667 .67415 .36435 .67335 .36369 Mtetra
.86 .859 .838 r
.67335 .36369 .67415 .36435 .67584 .36315 .67501 .36196 Mtetra
.675 .717 .88 r
.67501 .36196 .67584 .36315 .67756 .36256 .67673 .36133 Mtetra
.601 .678 .895 r
.67673 .36133 .67756 .36256 .67929 .36218 .67847 .36104 Mtetra
.626 .707 .904 r
.67847 .36104 .67929 .36218 .68102 .36172 .6802 .36064 Mtetra
.657 .732 .905 r
.6802 .36064 .68102 .36172 .68275 .36117 .68193 .3601 Mtetra
.655 .733 .907 r
.68193 .3601 .68275 .36117 .68447 .36063 .68366 .35957 Mtetra
.657 .736 .908 r
.68366 .35957 .68447 .36063 .6862 .36007 .68538 .35903 Mtetra
.656 .74 .911 r
.68538 .35903 .6862 .36007 .68793 .35952 .68711 .35849 Mtetra
.651 .741 .915 r
.68711 .35849 .68793 .35952 .68966 .359 .68885 .35798 Mtetra
.635 .737 .922 r
.68885 .35798 .68966 .359 .6914 .35856 .69058 .35753 Mtetra
.623 .73 .924 r
.69058 .35753 .6914 .35856 .69314 .35817 .69232 .35712 Mtetra
.624 .726 .92 r
.69232 .35712 .69314 .35817 .69488 .35779 .69406 .35672 Mtetra
.637 .727 .913 r
.69406 .35672 .69488 .35779 .69662 .35734 .6958 .35626 Mtetra
.652 .732 .908 r
.6958 .35626 .69662 .35734 .69836 .35681 .69754 .35575 Mtetra
.662 .739 .907 r
.69754 .35575 .69836 .35681 .70009 .35621 .69928 .35518 Mtetra
.677 .752 .908 r
.69928 .35518 .70009 .35621 .70182 .35551 .70101 .35455 Mtetra
.688 .769 .913 r
.70101 .35455 .70182 .35551 .70355 .35476 .70274 .35387 Mtetra
.69 .787 .925 r
.70274 .35387 .70355 .35476 .70527 .354 .70448 .35318 Mtetra
.68 .801 .94 r
.70448 .35318 .70527 .354 .70701 .35331 .70621 .35253 Mtetra
.669 .809 .95 r
.70621 .35253 .70701 .35331 .70874 .35267 .70795 .35192 Mtetra
.666 .814 .954 r
.70795 .35192 .70874 .35267 .71048 .35206 .70969 .35131 Mtetra
.689 .823 .947 r
.70969 .35131 .71048 .35206 .71221 .35129 .71143 .35062 Mtetra
.694 .843 .954 r
.71143 .35062 .71221 .35129 .71394 .35049 .71316 .34989 Mtetra
.645 .849 .978 r
.71316 .34989 .71394 .35049 .71569 .35 .71491 .34931 Mtetra
.56 .792 .986 r
.71491 .34931 .71569 .35 .7175 .35046 .71667 .349 Mtetra
.512 .596 .875 r
.71667 .349 .7175 .35046 .71941 .35263 .71846 .34911 Mtetra
.478 .412 .704 r
.71846 .34911 .71941 .35263 .72168 .36035 .72029 .3499 Mtetra
.425 .288 .589 r
.72029 .3499 .72168 .36035 .73569 .55623 .7223 .35345 Mtetra
.054 0 .442 r
.7223 .35345 .73569 .55623 .7378 .55952 .73663 .55336 Mtetra
.107 .107 .574 r
.73663 .55336 .7378 .55952 .73979 .56086 .73889 .55896 Mtetra
.148 .328 .788 r
.73889 .55896 .73979 .56086 .74174 .56141 .7409 .56054 Mtetra
.453 .707 .976 r
.7409 .56054 .74174 .56141 .74364 .56135 .74281 .56055 Mtetra
.732 .836 .929 r
.74281 .56055 .74364 .56135 .7455 .56051 .74466 .55961 Mtetra
.917 .821 .736 r
.74466 .55961 .7455 .56051 .74722 .55757 .74638 .55657 Mtetra
.979 .728 .484 r
.74638 .55657 .74722 .55757 .74813 .54237 .74729 .5413 Mtetra
.977 .683 .389 r
.74729 .5413 .74813 .54237 .7369 .34606 .73611 .34497 Mtetra
.905 .786 .719 r
.73611 .34497 .7369 .34606 .7385 .34303 .7377 .34195 Mtetra
.704 .753 .89 r
.7377 .34195 .7385 .34303 .74024 .34225 .73945 .34117 Mtetra
.579 .703 .927 r
.73945 .34117 .74024 .34225 .74203 .34201 .74123 .34093 Mtetra
.638 .729 .914 r
.74123 .34093 .74203 .34201 .7438 .34153 .743 .34046 Mtetra
.729 .764 .881 r
.743 .34046 .7438 .34153 .74554 .3406 .74474 .33955 Mtetra
.623 .728 .922 r
.74474 .33955 .74554 .3406 .74731 .34018 .74652 .33914 Mtetra
0 .245 .753 r
.74652 .33914 .74731 .34018 .74922 .34166 .74843 .3406 Mtetra
.975 .673 .364 r
.74843 .3406 .74922 .34166 .76481 .53451 .76389 .53215 Mtetra
.949 .619 .204 r
.76389 .53215 .76481 .53451 .76798 .55174 .76714 .55063 Mtetra
0 .048 .586 r
.76714 .55063 .76798 .55174 .77007 .55396 .76923 .55282 Mtetra
.591 .711 .927 r
.76923 .55282 .77007 .55396 .77199 .55373 .77114 .55251 Mtetra
.732 .752 .869 r
.77114 .55251 .77199 .55373 .77385 .55265 .773 .55149 Mtetra
.771 .776 .857 r
.773 .55149 .77385 .55265 .77564 .55063 .77485 .55021 Mtetra
.779 .939 .932 r
.77485 .55021 .77564 .55063 .77731 .54712 .7767 .54898 Mtetra
.047 0 .054 r
.7767 .54898 .77731 .54712 .7786 .53852 .7785 .54709 Mtetra
.346 .128 .433 r
.7785 .54709 .7786 .53852 .76551 .34091 .78012 .54287 Mtetra
.069 0 .445 r
.78012 .54287 .76551 .34091 .76701 .33665 .76669 .34175 Mtetra
0 0 .206 r
.76669 .34175 .76701 .33665 .76865 .3343 .76795 .33433 Mtetra
.939 .965 .726 r
.76795 .33433 .76865 .3343 .77036 .3329 .76958 .33174 Mtetra
.708 .742 .878 r
.76958 .33174 .77036 .3329 .77214 .3322 .77134 .33092 Mtetra
.621 .683 .887 r
.77134 .33092 .77214 .3322 .77393 .33173 .77313 .33053 Mtetra
.655 .714 .891 r
.77313 .33053 .77393 .33173 .7757 .33103 .77492 .32998 Mtetra
.758 .78 .871 r
.77492 .32998 .7757 .33103 .77743 .32987 .77666 .32889 Mtetra
.668 .765 .923 r
.77666 .32889 .77743 .32987 .77921 .3292 .77845 .32828 Mtetra
.062 .436 .874 r
.77845 .32828 .77921 .3292 .78111 .33003 .78035 .32918 Mtetra
.925 .548 .148 r
.78035 .32918 .78111 .33003 .78363 .33839 .78292 .33817 Mtetra
.975 .669 .349 r
.78292 .33817 .78363 .33839 .80217 .54092 .80135 .53992 Mtetra
.599 .135 0 r
.80135 .53992 .80217 .54092 .80438 .54398 .80355 .54284 Mtetra
.526 .682 .937 r
.80355 .54284 .80438 .54398 .80635 .54406 .80551 .54276 Mtetra
.7 .732 .875 r
.80551 .54276 .80635 .54406 .80825 .54322 .80741 .54192 Mtetra
.759 .752 .846 r
.80741 .54192 .80825 .54322 .81007 .54145 .80927 .54067 Mtetra
.795 .861 .899 r
.80927 .54067 .81007 .54145 .81175 .53813 .81113 .53935 Mtetra
0 0 0 r
.81113 .53935 .81175 .53813 .81305 .53032 .81293 .53728 Mtetra
.264 .055 .397 r
.81293 .53728 .81305 .53032 .79765 .3296 .8145 .53265 Mtetra
.08 0 .452 r
.8145 .53265 .79765 .3296 .79907 .3247 .79876 .32887 Mtetra
0 0 .186 r
.79876 .32887 .79907 .3247 .80071 .32231 .80007 .32262 Mtetra
.848 .976 .673 r
.80007 .32262 .80071 .32231 .80249 .32149 .80171 .3203 Mtetra
.521 .654 .918 r
.80171 .3203 .80249 .32149 .8045 .3232 .80357 .32028 Mtetra
.484 .445 .738 r
.80357 .32028 .8045 .3232 .80674 .32753 .80547 .32091 Mtetra
.547 .398 .631 r
.80547 .32091 .80674 .32753 .80932 .33563 .80736 .3212 Mtetra
.597 .397 .582 r
.80736 .3212 .80932 .33563 .81016 .32431 .80905 .31934 Mtetra
.649 .487 .65 r
.80905 .31934 .81016 .32431 .81165 .32015 .81077 .31786 Mtetra
.619 .564 .771 r
.81077 .31786 .81165 .32015 .81332 .31817 .81259 .31742 Mtetra
.618 .128 0 r
.81259 .31742 .81332 .31817 .81522 .31859 .81469 .32001 Mtetra
.974 .664 .337 r
.81469 .32001 .81522 .31859 .81726 .32042 .83454 .51373 Mtetra
.574 .35 .538 r
.83454 .51373 .81726 .32042 .81974 .32701 .8379 .52848 Mtetra
.555 .336 .538 r
.8379 .52848 .81974 .32701 .84038 .52628 .84007 .53038 Mtetra
.546 .231 .386 r
.84007 .53038 .84038 .52628 .84273 .52998 .84209 .53069 Mtetra
0 0 0 r
.84209 .53069 .84273 .52998 .8448 .53075 .84398 .52954 Mtetra
.95 .781 .636 r
.84398 .52954 .8448 .53075 .84659 .52859 .84551 .5246 Mtetra
.976 .672 .351 r
.84551 .5246 .84659 .52859 .8482 .52454 .828 .32222 Mtetra
.565 .348 .544 r
.828 .32222 .8482 .52454 .84932 .51553 .82915 .31469 Mtetra
.556 .341 .544 r
.82915 .31469 .84932 .51553 .8334 .33231 .83086 .31301 Mtetra
.564 .367 .572 r
.83086 .31301 .8334 .33231 .83552 .33465 .83269 .31254 Mtetra
.539 .347 .568 r
.83269 .31254 .83552 .33465 .85536 .51602 .83468 .31366 Mtetra
.522 .317 .543 r
.83468 .31366 .85536 .51602 .85799 .52235 .83837 .33181 Mtetra
.101 .021 .47 r
.83837 .33181 .85799 .52235 .86027 .52503 .85931 .52226 Mtetra
.082 .205 .694 r
.85931 .52226 .86027 .52503 .8624 .52619 .8616 .52511 Mtetra
.549 .71 .946 r
.8616 .52511 .8624 .52619 .86437 .52578 .8636 .52493 Mtetra
.688 .824 .948 r
.8636 .52493 .86437 .52578 .86631 .52502 .86554 .52415 Mtetra
.718 .83 .934 r
.86554 .52415 .86631 .52502 .86825 .52427 .86746 .52325 Mtetra
.444 .67 .959 r
.86746 .52325 .86825 .52427 .87029 .52446 .8695 .52336 Mtetra
.589 .726 .938 r
.8695 .52336 .87029 .52446 .87228 .52422 .87148 .52304 Mtetra
.774 .783 .86 r
.87148 .52304 .87228 .52422 .87418 .52298 .87337 .52172 Mtetra
.967 .769 .586 r
.87337 .52172 .87418 .52298 .87556 .51688 .87473 .5154 Mtetra
.976 .67 .327 r
.87473 .5154 .87556 .51688 .85578 .31041 .855 .30904 Mtetra
.954 .759 .602 r
.855 .30904 .85578 .31041 .85706 .3046 .85631 .30345 Mtetra
.76 .77 .861 r
.85631 .30345 .85706 .3046 .85883 .30343 .85809 .3023 Mtetra
.629 .722 .914 r
.85809 .3023 .85883 .30343 .86068 .30297 .85994 .30185 Mtetra
.551 .686 .928 r
.85994 .30185 .86068 .30297 .86257 .30283 .86182 .3017 Mtetra
.751 .771 .87 r
.86182 .3017 .86257 .30283 .86435 .30174 .86361 .30062 Mtetra
.683 .747 .9 r
.86361 .30062 .86435 .30174 .86618 .30104 .86544 .29992 Mtetra
.477 .648 .933 r
.86544 .29992 .86618 .30104 .8681 .30114 .86736 .30002 Mtetra
.755 .338 0 r
.86736 .30002 .8681 .30114 .87056 .30617 .86982 .30505 Mtetra
.971 .656 .295 r
.86982 .30505 .87056 .30617 .89526 .51131 .89449 .51025 Mtetra
.73 .298 0 r
.89449 .51025 .89526 .51131 .89783 .516 .89705 .51494 Mtetra
.302 .577 .937 r
.89705 .51494 .89783 .516 .89993 .51653 .89916 .51547 Mtetra
.648 .763 .933 r
.89916 .51547 .89993 .51653 .90191 .51595 .90114 .51489 Mtetra
.828 .821 .842 r
.90114 .51489 .90191 .51595 .90377 .51424 .903 .51318 Mtetra
.908 .736 .657 r
.26646 .69662 .2675 .69747 .26945 .69192 .26841 .69107 Mtetra
.936 .686 .535 r
.26841 .69107 .26945 .69192 .28514 .49619 .28416 .4953 Mtetra
.908 .728 .647 r
.28416 .4953 .28514 .49619 .28701 .49046 .28604 .48956 Mtetra
.772 .76 .842 r
.28604 .48956 .28701 .49046 .28855 .48934 .28758 .48844 Mtetra
.638 .736 .92 r
.28758 .48844 .28855 .48934 .29004 .48894 .28907 .48804 Mtetra
.505 .691 .952 r
.28907 .48804 .29004 .48894 .2915 .4889 .29053 .48801 Mtetra
.749 .76 .861 r
.29053 .48801 .2915 .4889 .29303 .48796 .29206 .48707 Mtetra
.696 .751 .895 r
.29206 .48707 .29303 .48796 .29453 .48733 .29356 .48644 Mtetra
.472 .679 .956 r
.29356 .48644 .29453 .48733 .296 .48735 .29503 .48647 Mtetra
.929 .554 .269 r
.29503 .48647 .296 .48735 .29718 .49139 .2962 .49065 Mtetra
.939 .683 .523 r
.2962 .49065 .29718 .49139 .28535 .68625 .28429 .68573 Mtetra
.922 .568 .346 r
.28429 .68573 .28535 .68625 .28654 .69156 .2855 .69086 Mtetra
.218 .616 .953 r
.2855 .69086 .28654 .69156 .28808 .6919 .28704 .69115 Mtetra
.682 .794 .934 r
.28704 .69115 .28808 .6919 .28968 .69133 .28864 .69055 Mtetra
.76 .793 .88 r
.28864 .69055 .28968 .69133 .29131 .69036 .29027 .68953 Mtetra
.489 .715 .971 r
.29027 .68953 .29131 .69036 .29287 .69033 .29184 .68948 Mtetra
.592 .747 .951 r
.29184 .68948 .29287 .69033 .29445 .69006 .29342 .68919 Mtetra
.752 .778 .874 r
.29342 .68919 .29445 .69006 .29608 .68908 .29505 .68821 Mtetra
.907 .741 .666 r
.29505 .68821 .29608 .68908 .29797 .68407 .29695 .68318 Mtetra
.939 .687 .529 r
.29695 .68318 .29797 .68407 .31213 .48808 .31117 .48713 Mtetra
.911 .725 .638 r
.31117 .48713 .31213 .48808 .31401 .4818 .31305 .48088 Mtetra
.795 .76 .821 r
.31305 .48088 .31401 .4818 .31558 .48045 .31462 .47953 Mtetra
.644 .736 .916 r
.31462 .47953 .31558 .48045 .31708 .48002 .31612 .47911 Mtetra
.504 .69 .951 r
.31612 .47911 .31708 .48002 .31857 .47998 .31761 .47908 Mtetra
.724 .757 .879 r
.31761 .47908 .31857 .47998 .3201 .47915 .31914 .4783 Mtetra
.699 .764 .902 r
.31914 .4783 .3201 .47915 .32162 .47848 .32066 .47765 Mtetra
.513 .713 .962 r
.32066 .47765 .32162 .47848 .32311 .47846 .32215 .47757 Mtetra
.885 .455 .101 r
.32215 .47757 .32311 .47846 .32436 .48223 .32345 .4805 Mtetra
.943 .685 .516 r
.32345 .4805 .32436 .48223 .31406 .67794 .31326 .67336 Mtetra
.808 .555 0 r
.31326 .67336 .31406 .67794 .31531 .68341 .31438 .68103 Mtetra
.337 .388 .767 r
.31438 .68103 .31531 .68341 .31686 .6839 .3159 .68202 Mtetra
.593 .58 .808 r
.3159 .68202 .31686 .6839 .31848 .68324 .31749 .68182 Mtetra
.676 .669 .836 r
.31749 .68182 .31848 .68324 .32013 .68213 .31912 .68117 Mtetra
.539 .704 .947 r
.31912 .68117 .32013 .68213 .32173 .68192 .32071 .68105 Mtetra
.599 .749 .949 r
.32071 .68105 .32173 .68192 .32333 .68164 .32231 .68074 Mtetra
.746 .774 .876 r
.32231 .68074 .32333 .68164 .32497 .68068 .32395 .67978 Mtetra
.897 .75 .691 r
.32395 .67978 .32497 .68068 .32683 .67589 .32577 .67576 Mtetra
.943 .689 .522 r
.32577 .67576 .32683 .67589 .33947 .47896 .3383 .48199 Mtetra
.992 .851 .494 r
.3383 .48199 .33947 .47896 .34133 .47262 .3403 .47306 Mtetra
.889 .988 .795 r
.3403 .47306 .34133 .47262 .34291 .47115 .3419 .47112 Mtetra
.639 .947 .95 r
.3419 .47112 .34291 .47115 .34442 .47083 .34344 .47039 Mtetra
.541 .832 .999 r
.34344 .47039 .34442 .47083 .34591 .47095 .34496 .47008 Mtetra
.63 .746 .931 r
.34496 .47008 .34591 .47095 .34743 .47074 .34648 .4697 Mtetra
.637 .711 .9 r
.34648 .4697 .34743 .47074 .34895 .47034 .348 .4693 Mtetra
.631 .71 .903 r
.348 .4693 .34895 .47034 .35047 .4699 .34953 .46893 Mtetra
.652 .73 .907 r
.34953 .46893 .35047 .4699 .35201 .4693 .35106 .46848 Mtetra
.666 .765 .924 r
.35106 .46848 .35201 .4693 .35355 .46871 .35259 .46796 Mtetra
.673 .786 .934 r
.35259 .46796 .35355 .46871 .35507 .46825 .35412 .46741 Mtetra
.683 .766 .914 r
.35412 .46741 .35507 .46825 .35658 .46837 .35566 .46683 Mtetra
.667 .641 .814 r
.35566 .46683 .35658 .46837 .35806 .46891 .3572 .46622 Mtetra
.635 .536 .725 r
.3572 .46622 .35806 .46891 .35953 .46966 .35874 .46562 Mtetra
.635 .491 .67 r
.35874 .46562 .35953 .46966 .36107 .46914 .3603 .46472 Mtetra
.62 .474 .661 r
.3603 .46472 .36107 .46914 .36263 .46822 .36184 .46396 Mtetra
.582 .451 .667 r
.36184 .46396 .36263 .46822 .36415 .46799 .36337 .46373 Mtetra
.272 .237 .635 r
.36337 .46373 .36415 .46799 .3654 .4734 .36477 .46594 Mtetra
.956 .694 .498 r
.36477 .46594 .3654 .4734 .35767 .66648 .35714 .65571 Mtetra
0 0 .288 r
.35714 .65571 .35767 .66648 .35909 .67048 .35817 .66777 Mtetra
.299 .338 .735 r
.35817 .66777 .35909 .67048 .36067 .67122 .35972 .66907 Mtetra
.622 .572 .778 r
.35972 .66907 .36067 .67122 .3623 .67082 .36135 .66866 Mtetra
.677 .599 .762 r
.36135 .66866 .3623 .67082 .36395 .67005 .36301 .6678 Mtetra
.619 .563 .77 r
.36301 .6678 .36395 .67005 .36559 .66952 .36464 .66741 Mtetra
.57 .549 .791 r
.36464 .66741 .36559 .66952 .36723 .66909 .36626 .66733 Mtetra
.573 .586 .828 r
.36626 .66733 .36723 .66909 .36887 .66851 .36789 .66723 Mtetra
.605 .669 .884 r
.36789 .66723 .36887 .66851 .37054 .66736 .36952 .66694 Mtetra
.569 .856 .997 r
.36952 .66694 .37054 .66736 .37224 .6657 .37116 .66652 Mtetra
.13 0 0 r
.37116 .66652 .37224 .6657 .37394 .66378 .3728 .66604 Mtetra
.461 .098 .262 r
.3728 .66604 .37394 .66378 .3756 .66297 .37444 .66583 Mtetra
.475 .139 .316 r
.37444 .66583 .3756 .66297 .37723 .66284 .37607 .66557 Mtetra
.379 .041 .261 r
.37607 .66557 .37723 .66284 .37888 .66211 .37773 .66477 Mtetra
0 0 0 r
.37773 .66477 .37888 .66211 .38072 .65698 .37949 .66173 Mtetra
.983 .822 .425 r
.37949 .66173 .38072 .65698 .39035 .46168 .38168 .64816 Mtetra
0 0 .274 r
.38168 .64816 .39035 .46168 .39209 .45643 .39108 .45739 Mtetra
.868 .969 .649 r
.39108 .45739 .39209 .45643 .3937 .45459 .39272 .45484 Mtetra
.386 .844 .786 r
.39272 .45484 .3937 .45459 .39526 .45398 .39428 .45421 Mtetra
.029 0 0 r
.39428 .45421 .39526 .45398 .3968 .45375 .39582 .45405 Mtetra
.225 .733 .684 r
.39582 .45405 .3968 .45375 .39835 .45349 .39738 .45355 Mtetra
.656 .964 .923 r
.39738 .45355 .39835 .45349 .3999 .45313 .39895 .45269 Mtetra
.737 .878 .945 r
.39895 .45269 .3999 .45313 .40145 .45278 .40052 .45186 Mtetra
.696 .757 .898 r
.40052 .45186 .40145 .45278 .40301 .45236 .40209 .4512 Mtetra
.66 .7 .875 r
.40209 .4512 .40301 .45236 .40457 .45187 .40365 .45069 Mtetra
.65 .693 .877 r
.40365 .45069 .40457 .45187 .40613 .45133 .40521 .45023 Mtetra
.652 .708 .888 r
.40521 .45023 .40613 .45133 .4077 .45065 .40677 .44977 Mtetra
.657 .754 .922 r
.40677 .44977 .4077 .45065 .40927 .44992 .40833 .44928 Mtetra
.652 .812 .96 r
.40833 .44928 .40927 .44992 .41084 .44934 .4099 .44877 Mtetra
.658 .834 .968 r
.4099 .44877 .41084 .44934 .41239 .44928 .41146 .44823 Mtetra
.675 .724 .887 r
.41146 .44823 .41239 .44928 .41392 .44981 .41303 .44766 Mtetra
.644 .575 .762 r
.41303 .44766 .41392 .44981 .41544 .45065 .4146 .44709 Mtetra
.635 .504 .686 r
.4146 .44709 .41544 .45065 .41699 .45065 .41618 .4463 Mtetra
.624 .478 .663 r
.41618 .4463 .41699 .45065 .41857 .44975 .41776 .44549 Mtetra
.592 .458 .668 r
.41776 .44549 .41857 .44975 .42014 .44935 .41932 .44514 Mtetra
.405 .333 .662 r
.41932 .44514 .42014 .44935 .4216 .45233 .42083 .44656 Mtetra
0 0 .11 r
.42083 .44656 .4216 .45233 .4171 .64729 .4221 .4558 Mtetra
0 0 .31 r
.4221 .4558 .4171 .64729 .4186 .65252 .41768 .64937 Mtetra
.112 .187 .663 r
.41768 .64937 .4186 .65252 .42022 .6538 .41927 .65166 Mtetra
.595 .561 .786 r
.41927 .65166 .42022 .6538 .42188 .65349 .42093 .65143 Mtetra
.677 .609 .772 r
.42093 .65143 .42188 .65349 .42356 .65275 .42262 .65059 Mtetra
.672 .599 .766 r
.42262 .65059 .42356 .65275 .42525 .65202 .4243 .64977 Mtetra
.634 .573 .768 r
.4243 .64977 .42525 .65202 .42692 .65151 .42598 .64925 Mtetra
.42598 .64925 .42692 .65151 .4286 .65099 .42766 .64873 Mtetra
.631 .571 .768 r
.42766 .64873 .4286 .65099 .43028 .65049 .42934 .64823 Mtetra
.628 .569 .769 r
.42934 .64823 .43028 .65049 .43196 .65001 .43102 .64775 Mtetra
.629 .569 .769 r
.43102 .64775 .43196 .65001 .43364 .64953 .4327 .64727 Mtetra
.595 .552 .776 r
.4327 .64727 .43364 .64953 .43531 .64922 .43437 .64704 Mtetra
.575 .548 .786 r
.43437 .64704 .43531 .64922 .43699 .64901 .43604 .64694 Mtetra
.659 .6 .777 r
.43604 .64694 .43699 .64901 .43868 .64839 .43773 .64625 Mtetra
.806 .66 .702 r
.43773 .64625 .43868 .64839 .4404 .64637 .43947 .64342 Mtetra
.952 .687 .498 r
.43947 .64342 .4404 .64637 .44221 .64051 .44579 .45133 Mtetra
.578 .36 .547 r
.44579 .45133 .44221 .64051 .44848 .44393 .44768 .438 Mtetra
.69 .502 .628 r
.44768 .438 .44848 .44393 .45017 .43927 .44932 .43521 Mtetra
.624 .485 .672 r
.44932 .43521 .45017 .43927 .45176 .43855 .45092 .43445 Mtetra
.586 .459 .674 r
.45092 .43445 .45176 .43855 .45334 .43837 .4525 .43418 Mtetra
.581 .453 .671 r
.4525 .43418 .45334 .43837 .45494 .43757 .45408 .43398 Mtetra
.607 .486 .689 r
.45408 .43398 .45494 .43757 .45656 .43576 .45567 .43352 Mtetra
.626 .56 .761 r
.45567 .43352 .45656 .43576 .45817 .43419 .45726 .43307 Mtetra
.648 .705 .888 r
.45726 .43307 .45817 .43419 .45978 .43309 .45886 .43261 Mtetra
.62 .851 .987 r
.45886 .43261 .45978 .43309 .46137 .43251 .46045 .43212 Mtetra
.608 .873 .991 r
.46045 .43212 .46137 .43251 .46296 .43209 .46204 .43163 Mtetra
.634 .862 .985 r
.46204 .43163 .46296 .43209 .46455 .43167 .46364 .4311 Mtetra
.66 .84 .969 r
.46364 .4311 .46455 .43167 .46615 .43115 .46524 .43054 Mtetra
.666 .83 .962 r
.46524 .43054 .46615 .43115 .46775 .43064 .46684 .42997 Mtetra
.672 .815 .952 r
.46684 .42997 .46775 .43064 .46934 .43018 .46844 .42939 Mtetra
.676 .787 .933 r
.46844 .42939 .46934 .43018 .47094 .42977 .47004 .42881 Mtetra
.665 .743 .909 r
.47004 .42881 .47094 .42977 .47254 .42935 .47164 .42828 Mtetra
.633 .71 .902 r
.47164 .42828 .47254 .42935 .47414 .42884 .47324 .42788 Mtetra
.57 .71 .936 r
.47324 .42788 .47414 .42884 .47574 .4282 .47483 .42768 Mtetra
.47 .788 .999 r
.47483 .42768 .47574 .4282 .47735 .42753 .47643 .42751 Mtetra
.259 .768 .848 r
.47643 .42751 .47735 .42753 .47895 .42688 .47803 .42724 Mtetra
0 0 0 r
.47803 .42724 .47895 .42688 .48056 .4263 .47964 .4267 Mtetra
.47964 .4267 .48056 .4263 .48217 .42575 .48125 .4261 Mtetra
.365 .821 .714 r
.48125 .4261 .48217 .42575 .48377 .42512 .48286 .42535 Mtetra
.572 .939 .834 r
.48286 .42535 .48377 .42512 .48538 .42431 .48447 .42442 Mtetra
.316 .805 .816 r
.48447 .42442 .48538 .42431 .48699 .42384 .48608 .42396 Mtetra
.616 .068 0 r
.48608 .42396 .48699 .42384 .48859 .42431 .48767 .42494 Mtetra
.926 .606 .418 r
.48767 .42494 .48859 .42431 .49016 .42786 .48916 .43594 Mtetra
.947 .672 .484 r
.48916 .43594 .49016 .42786 .48977 .62322 .48875 .62917 Mtetra
.661 .37 .468 r
.48875 .62917 .48977 .62322 .49142 .62938 .49043 .63192 Mtetra
.492 .14 .298 r
.49043 .63192 .49142 .62938 .49313 .62951 .49214 .63184 Mtetra
.38 .023 .229 r
.49214 .63184 .49313 .62951 .49485 .62873 .49387 .63117 Mtetra
.358 .009 .229 r
.49387 .63117 .49485 .62873 .49657 .62769 .49559 .63034 Mtetra
.441 .097 .285 r
.49559 .63034 .49657 .62769 .49829 .6272 .49731 .62989 Mtetra
.442 .1 .288 r
.49731 .62989 .49829 .6272 .50001 .62671 .49903 .62944 Mtetra
.442 .102 .291 r
.49903 .62944 .50001 .62671 .50173 .62621 .50075 .62898 Mtetra
.441 .102 .293 r
.50075 .62898 .50173 .62621 .50345 .62573 .50248 .6285 Mtetra
.44 .101 .293 r
.50248 .6285 .50345 .62573 .50518 .62524 .5042 .62801 Mtetra
.439 .1 .292 r
.5042 .62801 .50518 .62524 .5069 .62476 .50593 .62751 Mtetra
.439 .099 .292 r
.50593 .62751 .5069 .62476 .50862 .62427 .50766 .62702 Mtetra
.438 .099 .291 r
.50766 .62702 .50862 .62427 .51035 .62377 .50939 .62652 Mtetra
.438 .098 .291 r
.50939 .62652 .51035 .62377 .51208 .62327 .51112 .62602 Mtetra
.51112 .62602 .51208 .62327 .51381 .62277 .51285 .62552 Mtetra
.437 .098 .291 r
.51285 .62552 .51381 .62277 .51554 .62226 .51458 .62502 Mtetra
.51458 .62502 .51554 .62226 .51727 .62174 .51631 .62451 Mtetra
.51631 .62451 .51727 .62174 .519 .62121 .51805 .624 Mtetra
.437 .099 .293 r
.51805 .624 .519 .62121 .52073 .62068 .51978 .62348 Mtetra
.437 .1 .294 r
.51978 .62348 .52073 .62068 .52246 .6201 .52152 .62296 Mtetra
.439 .103 .299 r
.52152 .62296 .52246 .6201 .5242 .61932 .52326 .62243 Mtetra
.448 .122 .319 r
.52326 .62243 .5242 .61932 .52594 .61877 .525 .62189 Mtetra
.448 .122 .32 r
.525 .62189 .52594 .61877 .52767 .61877 .52674 .62135 Mtetra
.421 .075 .27 r
.52674 .62135 .52767 .61877 .52941 .61977 .52848 .6208 Mtetra
.196 0 0 r
.52848 .6208 .52941 .61977 .53116 .62055 .53022 .62025 Mtetra
.571 .891 .988 r
.53022 .62025 .53116 .62055 .5329 .62095 .53196 .6197 Mtetra
.651 .703 .884 r
.53196 .6197 .5329 .62095 .53464 .62071 .5337 .61918 Mtetra
.645 .656 .846 r
.5337 .61918 .53464 .62071 .53639 .62018 .53545 .61868 Mtetra
.642 .659 .851 r
.53545 .61868 .53639 .62018 .53813 .61931 .5372 .61819 Mtetra
.64 .722 .908 r
.5372 .61819 .53813 .61931 .53988 .61779 .53894 .61773 Mtetra
.406 .852 .913 r
.53894 .61773 .53988 .61779 .54162 .61594 .54069 .61727 Mtetra
.309 0 .034 r
.54069 .61727 .54162 .61594 .54336 .61399 .54244 .61681 Mtetra
.446 .108 .298 r
.54244 .61681 .54336 .61399 .5451 .61319 .54419 .61633 Mtetra
.457 .131 .324 r
.54419 .61633 .5451 .61319 .54685 .61279 .54595 .61585 Mtetra
.454 .125 .318 r
.54595 .61585 .54685 .61279 .5486 .61256 .5477 .61537 Mtetra
.442 .105 .297 r
.5477 .61537 .5486 .61256 .55036 .61208 .54945 .61487 Mtetra
.441 .103 .295 r
.54945 .61487 .55036 .61208 .55211 .61159 .55121 .61437 Mtetra
.44 .101 .294 r
.55121 .61437 .55211 .61159 .55386 .6111 .55296 .61387 Mtetra
.439 .1 .293 r
.55296 .61387 .55386 .6111 .55562 .61059 .55472 .61336 Mtetra
.438 .099 .292 r
.55472 .61336 .55562 .61059 .55737 .61008 .55648 .61285 Mtetra
.55648 .61285 .55737 .61008 .55913 .60956 .55824 .61234 Mtetra
.438 .099 .293 r
.55824 .61234 .55913 .60956 .56089 .60904 .56 .61182 Mtetra
.56 .61182 .56089 .60904 .56265 .60851 .56176 .6113 Mtetra
.438 .1 .294 r
.56176 .6113 .56265 .60851 .56441 .60798 .56353 .61078 Mtetra
.438 .101 .294 r
.56353 .61078 .56441 .60798 .56617 .60744 .56529 .61026 Mtetra
.438 .101 .295 r
.56529 .61026 .56617 .60744 .56793 .60691 .56706 .60973 Mtetra
.437 .101 .296 r
.56706 .60973 .56793 .60691 .5697 .60638 .56882 .60919 Mtetra
.435 .098 .294 r
.56882 .60919 .5697 .60638 .57146 .60586 .57059 .60864 Mtetra
.432 .094 .291 r
.57059 .60864 .57146 .60586 .57323 .60533 .57236 .60808 Mtetra
.429 .09 .287 r
.57236 .60808 .57323 .60533 .57499 .6048 .57413 .60751 Mtetra
.493 .147 .309 r
.57413 .60751 .57499 .6048 .57677 .60495 .5759 .60741 Mtetra
.436 .082 .265 r
.5759 .60741 .57677 .60495 .57854 .60458 .57768 .60698 Mtetra
.304 0 .205 r
.57768 .60698 .57854 .60458 .5803 .60314 .57944 .60587 Mtetra
0 0 0 r
.57944 .60587 .5803 .60314 .58186 .58974 .58114 .60094 Mtetra
.98 .704 .43 r
.58114 .60094 .58186 .58974 .58031 .39706 .57953 .40084 Mtetra
0 0 0 r
.57953 .40084 .58031 .39706 .58192 .39317 .58108 .39353 Mtetra
.678 .967 .761 r
.58108 .39353 .58192 .39317 .58358 .39204 .58273 .39214 Mtetra
.32 .808 .81 r
.58273 .39214 .58358 .39204 .58524 .39153 .5844 .39165 Mtetra
.03 0 0 r
.5844 .39165 .58524 .39153 .58692 .39131 .58608 .39157 Mtetra
0 0 0 r
.58608 .39157 .58692 .39131 .58859 .3908 .58775 .39116 Mtetra
.58775 .39116 .58859 .3908 .59026 .39029 .58943 .39068 Mtetra
.58943 .39068 .59026 .39029 .59193 .3898 .5911 .39012 Mtetra
.413 .848 .723 r
.5911 .39012 .59193 .3898 .5936 .38939 .59276 .38926 Mtetra
.691 .96 .945 r
.59276 .38926 .5936 .38939 .59528 .38899 .59443 .38834 Mtetra
.736 .847 .933 r
.59443 .38834 .59528 .38899 .59696 .38858 .5961 .38748 Mtetra
.678 .728 .888 r
.5961 .38748 .59696 .38858 .59863 .3881 .59777 .38686 Mtetra
.657 .696 .874 r
.59777 .38686 .59863 .3881 .60031 .38756 .59945 .38632 Mtetra
.65 .695 .878 r
.59945 .38632 .60031 .38756 .60198 .38697 .60113 .38583 Mtetra
.663 .717 .888 r
.60113 .38583 .60198 .38697 .60366 .38629 .60281 .38527 Mtetra
.666 .742 .907 r
.60281 .38527 .60366 .38629 .60533 .3856 .60449 .38471 Mtetra
.666 .772 .929 r
.60449 .38471 .60533 .3856 .60701 .38491 .60617 .38414 Mtetra
.656 .8 .952 r
.60617 .38414 .60701 .38491 .60869 .38418 .60785 .3836 Mtetra
.641 .843 .978 r
.60785 .3836 .60869 .38418 .61037 .38355 .60953 .38306 Mtetra
.633 .865 .985 r
.60953 .38306 .61037 .38355 .61205 .3831 .61121 .3825 Mtetra
.663 .844 .969 r
.61121 .3825 .61205 .3831 .61376 .38327 .6129 .38189 Mtetra
.67 .679 .849 r
.6129 .38189 .61376 .38327 .61547 .38382 .61458 .38127 Mtetra
.638 .551 .74 r
.61458 .38127 .61547 .38382 .6172 .38457 .61627 .38065 Mtetra
.637 .499 .677 r
.61627 .38065 .6172 .38457 .61888 .38392 .61794 .3797 Mtetra
.619 .48 .67 r
.61794 .3797 .61888 .38392 .62056 .38305 .61962 .37895 Mtetra
.58 .458 .678 r
.61962 .37895 .62056 .38305 .62226 .38284 .62132 .37875 Mtetra
.273 .254 .655 r
.62132 .37875 .62226 .38284 .62414 .38829 .62311 .3812 Mtetra
.977 .689 .406 r
.62311 .3812 .62414 .38829 .63208 .58635 .63088 .57551 Mtetra
0 0 .436 r
.63088 .57551 .63208 .58635 .63403 .59047 .63308 .58771 Mtetra
.415 .417 .753 r
.63308 .58771 .63403 .59047 .63587 .59095 .63494 .58866 Mtetra
.639 .58 .772 r
.63494 .58866 .63587 .59095 .63768 .59039 .63674 .58807 Mtetra
.691 .605 .755 r
.63674 .58807 .63768 .59039 .63948 .58939 .63854 .58697 Mtetra
.615 .558 .767 r
.63854 .58697 .63948 .58939 .64128 .58855 .64035 .58656 Mtetra
.582 .576 .812 r
.64035 .58656 .64128 .58855 .64308 .58776 .64218 .58639 Mtetra
.585 .66 .89 r
.64218 .58639 .64308 .58776 .64488 .58696 .644 .58617 Mtetra
.642 .802 .96 r
.644 .58617 .64488 .58696 .64669 .58625 .64581 .58563 Mtetra
.678 .855 .967 r
.64581 .58563 .64669 .58625 .6485 .58561 .64762 .58492 Mtetra
.696 .842 .953 r
.64762 .58492 .6485 .58561 .65032 .58501 .64943 .58415 Mtetra
.678 .798 .939 r
.64943 .58415 .65032 .58501 .65213 .58443 .65125 .58348 Mtetra
.664 .774 .932 r
.65125 .58348 .65213 .58443 .65395 .58388 .65306 .58288 Mtetra
.655 .759 .926 r
.65306 .58288 .65395 .58388 .65577 .5834 .65488 .58232 Mtetra
.646 .74 .917 r
.65488 .58232 .65577 .5834 .6576 .58304 .6567 .5818 Mtetra
.639 .706 .895 r
.6567 .5818 .6576 .58304 .65943 .58275 .65853 .58131 Mtetra
.633 .671 .869 r
.65853 .58131 .65943 .58275 .66126 .58245 .66036 .58086 Mtetra
.627 .646 .849 r
.66036 .58086 .66126 .58245 .6631 .58221 .66219 .58043 Mtetra
.622 .621 .828 r
.66219 .58043 .6631 .58221 .66494 .58188 .66402 .58003 Mtetra
.62 .611 .82 r
.66402 .58003 .66494 .58188 .66676 .58132 .66585 .57963 Mtetra
.62 .629 .838 r
.66585 .57963 .66676 .58132 .66856 .58005 .66769 .57924 Mtetra
.597 .784 .97 r
.66769 .57924 .66856 .58005 .67033 .57817 .66952 .57884 Mtetra
.146 0 0 r
.66952 .57884 .67033 .57817 .67209 .57595 .67136 .57843 Mtetra
.492 .134 .287 r
.67136 .57843 .67209 .57595 .67391 .57522 .67321 .57837 Mtetra
.494 .163 .335 r
.67321 .57837 .67391 .57522 .67577 .57521 .67506 .57819 Mtetra
.409 .083 .298 r
.67506 .57819 .67577 .57521 .67759 .57443 .67689 .57737 Mtetra
0 0 .096 r
.67689 .57737 .67759 .57443 .67912 .56737 .67859 .5738 Mtetra
.98 .695 .4 r
.67859 .5738 .67912 .56737 .67182 .36837 .67141 .37656 Mtetra
0 0 .179 r
.67141 .37656 .67182 .36837 .67335 .36369 .6726 .36428 Mtetra
.803 .957 .627 r
.6726 .36428 .67335 .36369 .67501 .36196 .67424 .36197 Mtetra
.473 .894 .883 r
.67424 .36197 .67501 .36196 .67673 .36133 .67596 .3613 Mtetra
.152 .694 .796 r
.67596 .3613 .67673 .36133 .67847 .36104 .6777 .36113 Mtetra
.174 .709 .746 r
.6777 .36113 .67847 .36104 .6802 .36064 .67944 .3608 Mtetra
.254 .76 .736 r
.67944 .3608 .6802 .36064 .68193 .3601 .68117 .36028 Mtetra
.234 .745 .716 r
.68117 .36028 .68193 .3601 .68366 .35957 .6829 .35977 Mtetra
.19 .712 .686 r
.6829 .35977 .68366 .35957 .68538 .35903 .68463 .3593 Mtetra
0 0 0 r
.68463 .3593 .68538 .35903 .68711 .35849 .68636 .35882 Mtetra
.68636 .35882 .68711 .35849 .68885 .35798 .6881 .35828 Mtetra
.322 .79 .68 r
.6881 .35828 .68885 .35798 .69058 .35753 .68982 .3575 Mtetra
.624 .957 .907 r
.68982 .3575 .69058 .35753 .69232 .35712 .69153 .35658 Mtetra
.732 .886 .951 r
.69153 .35658 .69232 .35712 .69406 .35672 .69325 .35569 Mtetra
.692 .756 .901 r
.69325 .35569 .69406 .35672 .6958 .35626 .69498 .35499 Mtetra
.656 .695 .875 r
.69498 .35499 .6958 .35626 .69754 .35575 .69671 .35444 Mtetra
.644 .686 .874 r
.69671 .35444 .69754 .35575 .69928 .35518 .69846 .35396 Mtetra
.644 .7 .887 r
.69846 .35396 .69928 .35518 .70101 .35455 .7002 .35347 Mtetra
.648 .73 .909 r
.7002 .35347 .70101 .35455 .70274 .35387 .70194 .35297 Mtetra
.647 .77 .938 r
.70194 .35297 .70274 .35387 .70448 .35318 .70368 .35245 Mtetra
.646 .814 .964 r
.70368 .35245 .70448 .35318 .70621 .35253 .70543 .35191 Mtetra
.647 .843 .976 r
.70543 .35191 .70621 .35253 .70795 .35192 .70717 .35133 Mtetra
.651 .854 .978 r
.70717 .35133 .70795 .35192 .70969 .35131 .70891 .35073 Mtetra
.66 .858 .975 r
.70891 .35073 .70969 .35131 .71143 .35062 .71065 .3501 Mtetra
.659 .875 .979 r
.71065 .3501 .71143 .35062 .71316 .34989 .71239 .34944 Mtetra
.65 .891 .983 r
.71239 .34944 .71316 .34989 .71491 .34931 .71413 .34878 Mtetra
.738 .892 .949 r
.71413 .34878 .71491 .34931 .71667 .349 .71586 .34785 Mtetra
.734 .749 .864 r
.71586 .34785 .71667 .349 .71846 .34911 .71758 .34688 Mtetra
.623 .569 .773 r
.71758 .34688 .71846 .34911 .72029 .3499 .71934 .34643 Mtetra
.385 .354 .701 r
.71934 .34643 .72029 .3499 .7223 .35345 .72122 .34791 Mtetra
0 0 .156 r
.72122 .34791 .7223 .35345 .73663 .55336 .72382 .36093 Mtetra
.032 0 .435 r
.72382 .36093 .73663 .55336 .73889 .55896 .73799 .55721 Mtetra
0 .107 .662 r
.73799 .55721 .73889 .55896 .7409 .56054 .74006 .55965 Mtetra
.438 .696 .974 r
.74006 .55965 .7409 .56054 .74281 .56055 .74197 .55971 Mtetra
.746 .83 .916 r
.74197 .55971 .74281 .56055 .74466 .55961 .74382 .55869 Mtetra
.919 .816 .728 r
.74382 .55869 .74466 .55961 .74638 .55657 .74554 .55554 Mtetra
.979 .723 .476 r
.74554 .55554 .74638 .55657 .74729 .5413 .74634 .5386 Mtetra
.976 .682 .393 r
.74634 .5386 .74729 .5413 .73611 .34497 .7353 .34375 Mtetra
.891 .768 .719 r
.7353 .34375 .73611 .34497 .7377 .34195 .7369 .34077 Mtetra
.695 .732 .879 r
.7369 .34077 .7377 .34195 .73945 .34117 .73865 .34003 Mtetra
.572 .687 .918 r
.73865 .34003 .73945 .34117 .74123 .34093 .74043 .33982 Mtetra
.624 .718 .914 r
.74043 .33982 .74123 .34093 .743 .34046 .74221 .33941 Mtetra
.721 .766 .888 r
.74221 .33941 .743 .34046 .74474 .33955 .74395 .33855 Mtetra
.625 .742 .931 r
.74395 .33855 .74474 .33955 .74652 .33914 .74573 .33812 Mtetra
0 .351 .825 r
.74573 .33812 .74652 .33914 .74843 .3406 .74762 .33928 Mtetra
.908 .534 .093 r
.74762 .33928 .74843 .3406 .76389 .53215 .75001 .34749 Mtetra
.008 0 .43 r
.75001 .34749 .76389 .53215 .76714 .55063 .76616 .54767 Mtetra
.085 .192 .68 r
.76616 .54767 .76714 .55063 .76923 .55282 .7683 .5505 Mtetra
.544 .531 .791 r
.7683 .5505 .76923 .55282 .77114 .55251 .77024 .55059 Mtetra
.635 .616 .814 r
.77024 .55059 .77114 .55251 .773 .55149 .77214 .55008 Mtetra
.628 .678 .878 r
.77214 .55008 .773 .55149 .77485 .55021 .77405 .54963 Mtetra
.422 .77 .996 r
.77405 .54963 .77485 .55021 .7767 .54898 .77598 .54952 Mtetra
0 0 0 r
.77598 .54952 .7767 .54898 .7785 .54709 .77788 .54884 Mtetra
.77788 .54884 .7785 .54709 .78012 .54287 .77964 .54643 Mtetra
.764 .68 .132 r
.77964 .54643 .78012 .54287 .76669 .34175 .78081 .53625 Mtetra
.04 0 .435 r
.78081 .53625 .76669 .34175 .76795 .33433 .76723 .33407 Mtetra
.977 .885 .672 r
.76723 .33407 .76795 .33433 .76958 .33174 .76878 .33048 Mtetra
.713 .726 .861 r
.76878 .33048 .76958 .33174 .77134 .33092 .77054 .3296 Mtetra
.6 .668 .887 r
.77054 .3296 .77134 .33092 .77313 .33053 .77234 .32931 Mtetra
.613 .692 .9 r
.77234 .32931 .77313 .33053 .77492 .32998 .77414 .32896 Mtetra
.732 .778 .889 r
.77414 .32896 .77492 .32998 .77666 .32889 .7759 .32803 Mtetra
.638 .784 .952 r
.7759 .32803 .77666 .32889 .77845 .32828 .77769 .32752 Mtetra
.012 .445 .867 r
.77769 .32752 .77845 .32828 .78035 .32918 .77959 .32834 Mtetra
.891 .487 .06 r
.77959 .32834 .78035 .32918 .78292 .33817 .78195 .33479 Mtetra
.976 .671 .338 r
.78195 .33479 .78292 .33817 .80135 .53992 .80038 .53701 Mtetra
0 .109 .638 r
.80038 .53701 .80135 .53992 .80355 .54284 .80263 .54048 Mtetra
.524 .516 .789 r
.80263 .54048 .80355 .54284 .80551 .54276 .80461 .5407 Mtetra
.62 .596 .804 r
.80461 .5407 .80551 .54276 .80741 .54192 .80654 .54027 Mtetra
.641 .652 .845 r
.80654 .54027 .80741 .54192 .80927 .54067 .80847 .53974 Mtetra
.527 .733 .969 r
.80847 .53974 .80927 .54067 .81113 .53935 .81042 .53957 Mtetra
.262 .759 .696 r
.81042 .53957 .81113 .53935 .81293 .53728 .81234 .53889 Mtetra
0 0 0 r
.81234 .53889 .81293 .53728 .8145 .53265 .81414 .53686 Mtetra
0 0 .115 r
.81414 .53686 .8145 .53265 .79876 .32887 .81547 .5294 Mtetra
.07 0 .449 r
.81547 .5294 .79876 .32887 .80007 .32262 .7996 .32503 Mtetra
0 0 .001 r
.7996 .32503 .80007 .32262 .80171 .3203 .80106 .32053 Mtetra
.495 .889 .73 r
.80106 .32053 .80171 .3203 .80357 .32028 .80282 .31944 Mtetra
.616 .782 .961 r
.80282 .31944 .80357 .32028 .80547 .32091 .80463 .319 Mtetra
.61 .594 .81 r
.80463 .319 .80547 .32091 .80736 .3212 .80646 .31867 Mtetra
.67 .576 .741 r
.80646 .31867 .80736 .3212 .80905 .31934 .80823 .31771 Mtetra
.639 .641 .836 r
.80823 .31771 .80905 .31934 .81077 .31786 .81005 .31721 Mtetra
0 .46 .863 r
.81005 .31721 .81077 .31786 .81259 .31742 .81198 .31796 Mtetra
.92 .533 .246 r
.81198 .31796 .81259 .31742 .81469 .32001 .81459 .3261 Mtetra
.971 .66 .353 r
.81459 .3261 .81469 .32001 .83454 .51373 .83515 .52793 Mtetra
.612 .351 .498 r
.83515 .52793 .83454 .51373 .8379 .52848 .83745 .53123 Mtetra
.536 .182 .314 r
.83745 .53123 .8379 .52848 .84007 .53038 .83947 .53154 Mtetra
.203 0 0 r
.83947 .53154 .84007 .53038 .84209 .53069 .8414 .53077 Mtetra
.869 .993 .755 r
.8414 .53077 .84209 .53069 .84398 .52954 .84319 .52854 Mtetra
.982 .765 .534 r
.84319 .52854 .84398 .52954 .84551 .5246 .84439 .52021 Mtetra
.976 .672 .352 r
.84439 .52021 .84551 .5246 .828 .32222 .82666 .31508 Mtetra
.718 .507 .604 r
.82666 .31508 .828 .32222 .82915 .31469 .8281 .31062 Mtetra
.661 .512 .671 r
.8281 .31062 .82915 .31469 .83086 .31301 .82984 .30922 Mtetra
.603 .484 .69 r
.82984 .30922 .83086 .31301 .83269 .31254 .83167 .30874 Mtetra
.51 .426 .696 r
.83167 .30874 .83269 .31254 .83468 .31366 .83361 .30932 Mtetra
.175 .189 .635 r
.83361 .30932 .83468 .31366 .83837 .33181 .83586 .31307 Mtetra
.958 .66 .234 r
.83586 .31307 .83837 .33181 .85931 .52226 .85803 .51637 Mtetra
.07 .093 .577 r
.85803 .51637 .85931 .52226 .8616 .52511 .86066 .52257 Mtetra
.483 .48 .778 r
.86066 .52257 .8616 .52511 .8636 .52493 .86273 .52311 Mtetra
.599 .613 .837 r
.86273 .52311 .8636 .52493 .86554 .52415 .86472 .52281 Mtetra
.654 .708 .887 r
.86472 .52281 .86554 .52415 .86746 .52325 .86668 .52222 Mtetra
.47 .682 .958 r
.86668 .52222 .86746 .52325 .8695 .52336 .8687 .52226 Mtetra
.626 .743 .931 r
.8687 .52226 .8695 .52336 .87148 .52304 .87068 .52179 Mtetra
.792 .775 .838 r
.87068 .52179 .87148 .52304 .87337 .52172 .87254 .52028 Mtetra
.962 .756 .579 r
.87254 .52028 .87337 .52172 .87473 .5154 .87387 .51353 Mtetra
.976 .67 .328 r
.87387 .51353 .87473 .5154 .855 .30904 .85422 .30756 Mtetra
.944 .753 .615 r
.85422 .30756 .855 .30904 .85631 .30345 .85556 .30231 Mtetra
.757 .771 .864 r
.85556 .30231 .85631 .30345 .85809 .3023 .85734 .30118 Mtetra
.629 .725 .917 r
.85734 .30118 .85809 .3023 .85994 .30185 .85919 .30073 Mtetra
.553 .689 .93 r
.85919 .30073 .85994 .30185 .86182 .3017 .86108 .30057 Mtetra
.75 .772 .871 r
.86108 .30057 .86182 .3017 .86361 .30062 .86287 .29949 Mtetra
.682 .748 .901 r
.86287 .29949 .86361 .30062 .86544 .29992 .8647 .2988 Mtetra
.477 .648 .934 r
.8647 .2988 .86544 .29992 .86736 .30002 .86662 .2989 Mtetra
.754 .338 0 r
.86662 .2989 .86736 .30002 .86982 .30505 .86908 .30392 Mtetra
.971 .656 .295 r
.86908 .30392 .86982 .30505 .89449 .51025 .89371 .50918 Mtetra
.73 .298 0 r
.89371 .50918 .89449 .51025 .89705 .51494 .89628 .51388 Mtetra
.302 .576 .937 r
.89628 .51388 .89705 .51494 .89916 .51547 .89839 .51441 Mtetra
.648 .763 .933 r
.89839 .51441 .89916 .51547 .90114 .51489 .90037 .51382 Mtetra
.828 .821 .842 r
.90037 .51382 .90114 .51489 .903 .51318 .90223 .51212 Mtetra
.908 .736 .657 r
.26542 .69578 .26646 .69662 .26841 .69107 .26737 .69023 Mtetra
.936 .686 .535 r
.26737 .69023 .26841 .69107 .28416 .4953 .28319 .4944 Mtetra
.908 .728 .647 r
.28319 .4944 .28416 .4953 .28604 .48956 .28507 .48866 Mtetra
.772 .76 .842 r
.28507 .48866 .28604 .48956 .28758 .48844 .28661 .48754 Mtetra
.637 .736 .92 r
.28661 .48754 .28758 .48844 .28907 .48804 .28809 .48715 Mtetra
.501 .691 .953 r
.28809 .48715 .28907 .48804 .29053 .48801 .28956 .48712 Mtetra
.751 .761 .861 r
.28956 .48712 .29053 .48801 .29206 .48707 .29109 .48617 Mtetra
.695 .751 .895 r
.29109 .48617 .29206 .48707 .29356 .48644 .29259 .48554 Mtetra
.456 .672 .957 r
.29259 .48554 .29356 .48644 .29503 .48647 .29405 .48561 Mtetra
.933 .57 .3 r
.29405 .48561 .29503 .48647 .2962 .49065 .2952 .4902 Mtetra
.938 .682 .523 r
.2952 .4902 .2962 .49065 .28429 .68573 .2832 .68572 Mtetra
.896 .543 .367 r
.2832 .68572 .28429 .68573 .2855 .69086 .28444 .69043 Mtetra
.157 .645 .92 r
.28444 .69043 .2855 .69086 .28704 .69115 .28599 .6906 Mtetra
.708 .844 .947 r
.28599 .6906 .28704 .69115 .28864 .69055 .2876 .68987 Mtetra
.784 .817 .879 r
.2876 .68987 .28864 .69055 .29027 .68953 .28924 .68872 Mtetra
.506 .729 .973 r
.28924 .68872 .29027 .68953 .29184 .68948 .29081 .68863 Mtetra
.594 .749 .951 r
.29081 .68863 .29184 .68948 .29342 .68919 .29239 .68833 Mtetra
.751 .779 .876 r
.29239 .68833 .29342 .68919 .29505 .68821 .29402 .68735 Mtetra
.907 .743 .666 r
.29402 .68735 .29505 .68821 .29695 .68318 .29592 .68232 Mtetra
.939 .687 .529 r
.29592 .68232 .29695 .68318 .31117 .48713 .31021 .48621 Mtetra
.913 .727 .638 r
.31021 .48621 .31117 .48713 .31305 .48088 .31209 .47997 Mtetra
.795 .761 .822 r
.31209 .47997 .31305 .48088 .31462 .47953 .31366 .47862 Mtetra
.642 .737 .918 r
.31366 .47862 .31462 .47953 .31612 .47911 .31516 .47821 Mtetra
.5 .69 .953 r
.31516 .47821 .31612 .47911 .31761 .47908 .31664 .47819 Mtetra
.701 .754 .893 r
.31664 .47819 .31761 .47908 .31914 .4783 .31817 .47752 Mtetra
.691 .78 .919 r
.31817 .47752 .31914 .4783 .32066 .47765 .31969 .47691 Mtetra
.57 .758 .967 r
.31969 .47691 .32066 .47765 .32215 .47757 .32119 .47667 Mtetra
0 .097 .588 r
.32119 .47667 .32215 .47757 .32345 .4805 .3226 .47787 Mtetra
0 0 .319 r
.3226 .47787 .32345 .4805 .31326 .67336 .32387 .48134 Mtetra
0 0 .262 r
.32387 .48134 .31326 .67336 .31438 .68103 .31392 .67078 Mtetra
.177 .092 .515 r
.31392 .67078 .31438 .68103 .3159 .68202 .31512 .67708 Mtetra
.343 .275 .635 r
.31512 .67708 .3159 .68202 .31749 .68182 .31658 .67913 Mtetra
.397 .4 .746 r
.31658 .67913 .31749 .68182 .31912 .68117 .31811 .68001 Mtetra
.439 .619 .927 r
.31811 .68001 .31912 .68117 .32071 .68105 .31968 .6802 Mtetra
.612 .757 .948 r
.31968 .6802 .32071 .68105 .32231 .68074 .32129 .67985 Mtetra
.742 .775 .879 r
.32129 .67985 .32231 .68074 .32395 .67978 .32293 .67891 Mtetra
.858 .773 .766 r
.32293 .67891 .32395 .67978 .32577 .67576 .32465 .67659 Mtetra
.982 .881 .651 r
.32465 .67659 .32577 .67576 .3383 .48199 .32651 .6719 Mtetra
0 0 .252 r
.32651 .6719 .3383 .48199 .3403 .47306 .33883 .48129 Mtetra
0 0 .219 r
.33883 .48129 .3403 .47306 .3419 .47112 .34074 .47394 Mtetra
0 0 0 r
.34074 .47394 .3419 .47112 .34344 .47039 .3424 .47113 Mtetra
.753 .974 .71 r
.3424 .47113 .34344 .47039 .34496 .47008 .34399 .46941 Mtetra
.742 .813 .908 r
.34399 .46941 .34496 .47008 .34648 .4697 .34554 .46856 Mtetra
.644 .694 .882 r
.34554 .46856 .34648 .4697 .348 .4693 .34707 .46814 Mtetra
.598 .673 .892 r
.34707 .46814 .348 .4693 .34953 .46893 .34858 .4679 Mtetra
.631 .71 .904 r
.34858 .4679 .34953 .46893 .35106 .46848 .35011 .46753 Mtetra
.655 .735 .909 r
.35011 .46753 .35106 .46848 .35259 .46796 .35164 .46706 Mtetra
.67 .749 .91 r
.35164 .46706 .35259 .46796 .35412 .46741 .35317 .46653 Mtetra
.703 .761 .897 r
.35317 .46653 .35412 .46741 .35566 .46683 .35472 .46585 Mtetra
.713 .743 .876 r
.35472 .46585 .35566 .46683 .3572 .46622 .35626 .4651 Mtetra
.705 .715 .857 r
.35626 .4651 .3572 .46622 .35874 .46562 .35781 .46437 Mtetra
.715 .697 .832 r
.35781 .46437 .35874 .46562 .3603 .46472 .35936 .46352 Mtetra
.696 .7 .85 r
.35936 .46352 .3603 .46472 .36184 .46396 .36091 .46282 Mtetra
.619 .686 .891 r
.36091 .46282 .36184 .46396 .36337 .46373 .36244 .4625 Mtetra
0 .285 .786 r
.36244 .4625 .36337 .46373 .36477 .46594 .3639 .46359 Mtetra
0 0 .294 r
.3639 .46359 .36477 .46594 .35714 .65571 .36525 .46701 Mtetra
0 0 .28 r
.36525 .46701 .35714 .65571 .35817 .66777 .35767 .65632 Mtetra
.354 .222 .558 r
.35767 .65632 .35817 .66777 .35972 .66907 .35906 .66094 Mtetra
.593 .418 .614 r
.35906 .66094 .35972 .66907 .36135 .66866 .3607 .66016 Mtetra
.597 .419 .612 r
.3607 .66016 .36135 .66866 .36301 .6678 .36236 .65924 Mtetra
.398 .27 .588 r
.36236 .65924 .36301 .6678 .36464 .66741 .36384 .66213 Mtetra
.283 .227 .616 r
.36384 .66213 .36464 .66741 .36626 .66733 .36533 .6648 Mtetra
.2 .289 .731 r
.36533 .6648 .36626 .66733 .36789 .66723 .36688 .66633 Mtetra
.264 .592 .948 r
.36688 .66633 .36789 .66723 .36952 .66694 .36849 .6667 Mtetra
.384 .814 .963 r
.36849 .6667 .36952 .66694 .37116 .66652 .37012 .66647 Mtetra
.461 .878 .937 r
.37012 .66647 .37116 .66652 .3728 .66604 .37176 .66598 Mtetra
.396 .845 .921 r
.37176 .66598 .3728 .66604 .37444 .66583 .37341 .66559 Mtetra
.537 .882 .986 r
.37341 .66559 .37444 .66583 .37607 .66557 .37505 .66513 Mtetra
.723 .882 .954 r
.37505 .66513 .37607 .66557 .37773 .66477 .37671 .6643 Mtetra
.881 .846 .805 r
.37671 .6643 .37773 .66477 .37949 .66173 .37843 .6622 Mtetra
.975 .876 .671 r
.37843 .6622 .37949 .66173 .38168 .64816 .38024 .65793 Mtetra
.906 .769 .278 r
.38024 .65793 .38168 .64816 .39108 .45739 .38271 .63742 Mtetra
0 0 .299 r
.38271 .63742 .39108 .45739 .39272 .45484 .39148 .46132 Mtetra
.517 .249 .447 r
.39148 .46132 .39272 .45484 .39428 .45421 .39304 .46097 Mtetra
.541 .272 .457 r
.39304 .46097 .39428 .45421 .39582 .45405 .39458 .46101 Mtetra
.24 .016 .359 r
.39458 .46101 .39582 .45405 .39738 .45355 .39627 .45717 Mtetra
0 0 .057 r
.39627 .45717 .39738 .45355 .39895 .45269 .39795 .45342 Mtetra
.899 .981 .704 r
.39795 .45342 .39895 .45269 .40052 .45186 .39959 .45099 Mtetra
.793 .779 .841 r
.39959 .45099 .40052 .45186 .40209 .4512 .40118 .44971 Mtetra
.664 .649 .825 r
.40118 .44971 .40209 .4512 .40365 .45069 .40274 .44914 Mtetra
.622 .622 .83 r
.40274 .44914 .40365 .45069 .40521 .45023 .4043 .44879 Mtetra
.615 .635 .848 r
.4043 .44879 .40521 .45023 .40677 .44977 .40585 .44849 Mtetra
.623 .665 .869 r
.40585 .44849 .40677 .44977 .40833 .44928 .40741 .44814 Mtetra
.629 .693 .89 r
.40741 .44814 .40833 .44928 .4099 .44877 .40897 .44777 Mtetra
.668 .732 .898 r
.40897 .44777 .4099 .44877 .41146 .44823 .41054 .44724 Mtetra
.699 .741 .884 r
.41054 .44724 .41146 .44823 .41303 .44766 .41211 .44655 Mtetra
.699 .719 .865 r
.41211 .44655 .41303 .44766 .4146 .44709 .41369 .44584 Mtetra
.706 .699 .841 r
.41369 .44584 .4146 .44709 .41618 .4463 .41526 .44506 Mtetra
.697 .697 .846 r
.41526 .44506 .41618 .4463 .41776 .44549 .41684 .44433 Mtetra
.636 .691 .885 r
.41684 .44433 .41776 .44549 .41932 .44514 .41841 .44393 Mtetra
.211 .469 .885 r
.41841 .44393 .41932 .44514 .42083 .44656 .41994 .44462 Mtetra
0 0 .403 r
.41994 .44462 .42083 .44656 .4221 .4558 .42141 .44743 Mtetra
.964 .697 .478 r
.42141 .44743 .4221 .4558 .41768 .64937 .41756 .62086 Mtetra
.034 0 .422 r
.41756 .62086 .41768 .64937 .41927 .65166 .41849 .64392 Mtetra
.558 .395 .617 r
.41849 .64392 .41927 .65166 .42093 .65143 .42015 .64397 Mtetra
.62 .443 .621 r
.42015 .64397 .42093 .65143 .42262 .65059 .42185 .6426 Mtetra
.618 .438 .616 r
.42185 .6426 .42262 .65059 .4243 .64977 .42355 .64118 Mtetra
.584 .41 .611 r
.42355 .64118 .4243 .64977 .42598 .64925 .42522 .64057 Mtetra
.584 .409 .61 r
.42522 .64057 .42598 .64925 .42766 .64873 .4269 .63997 Mtetra
.581 .406 .609 r
.4269 .63997 .42766 .64873 .42934 .64823 .42858 .63943 Mtetra
.578 .404 .609 r
.42858 .63943 .42934 .64823 .43102 .64775 .43025 .63897 Mtetra
.43025 .63897 .43102 .64775 .4327 .64727 .43193 .63851 Mtetra
.549 .383 .608 r
.43193 .63851 .4327 .64727 .43437 .64704 .43359 .63875 Mtetra
.538 .377 .611 r
.43359 .63875 .43437 .64704 .43604 .64694 .43524 .63924 Mtetra
.601 .427 .619 r
.43524 .63924 .43604 .64694 .43773 .64625 .43693 .63832 Mtetra
.809 .579 .589 r
.43693 .63832 .43773 .64625 .43947 .64342 .43889 .62668 Mtetra
.933 .668 .512 r
.43889 .62668 .43947 .64342 .44579 .45133 .44512 .43994 Mtetra
.661 .454 .593 r
.44512 .43994 .44579 .45133 .44768 .438 .4468 .43591 Mtetra
.764 .638 .722 r
.4468 .43591 .44768 .438 .44932 .43521 .44842 .43399 Mtetra
.691 .701 .855 r
.44842 .43399 .44932 .43521 .45092 .43445 .45001 .4333 Mtetra
.62 .689 .892 r
.45001 .4333 .45092 .43445 .4525 .43418 .45159 .43296 Mtetra
.597 .666 .887 r
.45159 .43296 .4525 .43418 .45408 .43398 .45318 .43272 Mtetra
.618 .668 .876 r
.45318 .43272 .45408 .43398 .45567 .43352 .45477 .43239 Mtetra
.613 .691 .898 r
.45477 .43239 .45567 .43352 .45726 .43307 .45635 .43207 Mtetra
.624 .723 .918 r
.45635 .43207 .45726 .43307 .45886 .43261 .45795 .4317 Mtetra
.649 .752 .925 r
.45795 .4317 .45886 .43261 .46045 .43212 .45954 .43123 Mtetra
.666 .759 .92 r
.45954 .43123 .46045 .43212 .46204 .43163 .46113 .4307 Mtetra
.685 .756 .906 r
.46113 .4307 .46204 .43163 .46364 .4311 .46273 .43008 Mtetra
.699 .741 .884 r
.46273 .43008 .46364 .4311 .46524 .43054 .46433 .42938 Mtetra
.695 .714 .863 r
.46433 .42938 .46524 .43054 .46684 .42997 .46594 .42868 Mtetra
.693 .692 .844 r
.46594 .42868 .46684 .42997 .46844 .42939 .46754 .42796 Mtetra
.686 .669 .828 r
.46754 .42796 .46844 .42939 .47004 .42881 .46914 .42725 Mtetra
.646 .636 .825 r
.46914 .42725 .47004 .42881 .47164 .42828 .47074 .42675 Mtetra
.52 .582 .858 r
.47074 .42675 .47164 .42828 .47324 .42788 .47233 .42685 Mtetra
0 .185 .696 r
.47233 .42685 .47324 .42788 .47483 .42768 .47391 .42813 Mtetra
.812 .389 .238 r
.47391 .42813 .47483 .42768 .47643 .42751 .47547 .43061 Mtetra
.756 .433 .438 r
.47547 .43061 .47643 .42751 .47803 .42724 .47701 .4344 Mtetra
.563 .294 .466 r
.47701 .4344 .47803 .42724 .47964 .4267 .47861 .43491 Mtetra
.469 .219 .452 r
.47861 .43491 .47964 .4267 .48125 .4261 .48023 .43342 Mtetra
.423 .175 .431 r
.48023 .43342 .48125 .4261 .48286 .42535 .48186 .4314 Mtetra
.424 .163 .413 r
.48186 .4314 .48286 .42535 .48447 .42442 .48349 .42977 Mtetra
.508 .228 .425 r
.48349 .42977 .48447 .42442 .48608 .42396 .4851 .42939 Mtetra
.734 .438 .479 r
.4851 .42939 .48608 .42396 .48767 .42494 .48665 .43434 Mtetra
.945 .67 .486 r
.48665 .43434 .48767 .42494 .48916 .43594 .48611 .62602 Mtetra
.559 .339 .538 r
.48611 .62602 .48916 .43594 .48875 .62917 .48777 .62994 Mtetra
.697 .244 .173 r
.48777 .62994 .48875 .62917 .49043 .63192 .48947 .63136 Mtetra
.503 .8 .999 r
.48947 .63136 .49043 .63192 .49214 .63184 .49119 .63112 Mtetra
.668 .817 .955 r
.49119 .63112 .49214 .63184 .49387 .63117 .49291 .63051 Mtetra
.679 .835 .958 r
.49291 .63051 .49387 .63117 .49559 .63034 .49463 .62985 Mtetra
.529 .83 .999 r
.49463 .62985 .49559 .63034 .49731 .62989 .49635 .62952 Mtetra
.489 .842 .995 r
.49635 .62952 .49731 .62989 .49903 .62944 .49807 .62919 Mtetra
.46 .854 .976 r
.49807 .62919 .49903 .62944 .50075 .62898 .4998 .62882 Mtetra
.469 .873 .957 r
.4998 .62882 .50075 .62898 .50248 .6285 .50152 .62836 Mtetra
.476 .879 .953 r
.50152 .62836 .50248 .6285 .5042 .62801 .50325 .62787 Mtetra
.483 .883 .954 r
.50325 .62787 .5042 .62801 .50593 .62751 .50498 .62737 Mtetra
.481 .88 .955 r
.50498 .62737 .50593 .62751 .50766 .62702 .5067 .62688 Mtetra
.482 .881 .955 r
.5067 .62688 .50766 .62702 .50939 .62652 .50843 .62638 Mtetra
.483 .882 .954 r
.50843 .62638 .50939 .62652 .51112 .62602 .51017 .62588 Mtetra
.484 .883 .954 r
.51017 .62588 .51112 .62602 .51285 .62552 .5119 .62538 Mtetra
.486 .883 .954 r
.5119 .62538 .51285 .62552 .51458 .62502 .51363 .62488 Mtetra
.487 .884 .954 r
.51363 .62488 .51458 .62502 .51631 .62451 .51536 .62437 Mtetra
.51536 .62437 .51631 .62451 .51805 .624 .5171 .62386 Mtetra
.488 .885 .953 r
.5171 .62386 .51805 .624 .51978 .62348 .51884 .62334 Mtetra
.487 .885 .952 r
.51884 .62334 .51978 .62348 .52152 .62296 .52057 .62283 Mtetra
.478 .882 .949 r
.52057 .62283 .52152 .62296 .52326 .62243 .52231 .62232 Mtetra
.479 .885 .943 r
.52231 .62232 .52326 .62243 .525 .62189 .52405 .62179 Mtetra
.503 .897 .944 r
.52405 .62179 .525 .62189 .52674 .62135 .52579 .62122 Mtetra
.579 .924 .959 r
.52579 .62122 .52674 .62135 .52848 .6208 .52754 .62054 Mtetra
.63 .919 .978 r
.52754 .62054 .52848 .6208 .53022 .62025 .52928 .61984 Mtetra
.652 .892 .983 r
.52928 .61984 .53022 .62025 .53196 .6197 .53102 .61917 Mtetra
.633 .856 .984 r
.53102 .61917 .53196 .6197 .5337 .61918 .53277 .6186 Mtetra
.617 .84 .985 r
.53277 .6186 .5337 .61918 .53545 .61868 .53451 .6181 Mtetra
.59 .832 .99 r
.53451 .6181 .53545 .61868 .5372 .61819 .53626 .61767 Mtetra
.532 .826 .999 r
.53626 .61767 .5372 .61819 .53894 .61773 .53801 .61734 Mtetra
.478 .837 .994 r
.53801 .61734 .53894 .61773 .54069 .61727 .53976 .61703 Mtetra
.428 .842 .966 r
.53976 .61703 .54069 .61727 .54244 .61681 .54151 .61668 Mtetra
.437 .863 .938 r
.54151 .61668 .54244 .61681 .54419 .61633 .54326 .61623 Mtetra
.449 .871 .936 r
.54326 .61623 .54419 .61633 .54595 .61585 .54502 .61574 Mtetra
.466 .878 .942 r
.54502 .61574 .54595 .61585 .5477 .61537 .54677 .61523 Mtetra
.471 .878 .949 r
.54677 .61523 .5477 .61537 .54945 .61487 .54853 .61473 Mtetra
.476 .88 .951 r
.54853 .61473 .54945 .61487 .55121 .61437 .55028 .61423 Mtetra
.479 .881 .952 r
.55028 .61423 .55121 .61437 .55296 .61387 .55204 .61372 Mtetra
.481 .882 .953 r
.55204 .61372 .55296 .61387 .55472 .61336 .5538 .61321 Mtetra
.483 .883 .953 r
.5538 .61321 .55472 .61336 .55648 .61285 .55556 .6127 Mtetra
.485 .883 .953 r
.55556 .6127 .55648 .61285 .55824 .61234 .55732 .61219 Mtetra
.486 .884 .953 r
.55732 .61219 .55824 .61234 .56 .61182 .55908 .61167 Mtetra
.487 .885 .953 r
.55908 .61167 .56 .61182 .56176 .6113 .56084 .61115 Mtetra
.489 .886 .954 r
.56084 .61115 .56176 .6113 .56353 .61078 .56261 .61063 Mtetra
.482 .882 .953 r
.56261 .61063 .56353 .61078 .56529 .61026 .56437 .61011 Mtetra
.488 .886 .951 r
.56437 .61011 .56529 .61026 .56706 .60973 .56614 .60958 Mtetra
.507 .895 .954 r
.56614 .60958 .56706 .60973 .56882 .60919 .56791 .60902 Mtetra
.574 .918 .964 r
.56791 .60902 .56882 .60919 .57059 .60864 .56967 .60836 Mtetra
.622 .915 .98 r
.56967 .60836 .57059 .60864 .57236 .60808 .57144 .60767 Mtetra
.648 .896 .983 r
.57144 .60767 .57236 .60808 .57413 .60751 .57321 .60699 Mtetra
.501 .816 1 r
.57321 .60699 .57413 .60751 .5759 .60741 .57498 .60672 Mtetra
.612 .814 .978 r
.57498 .60672 .5759 .60741 .57768 .60698 .57676 .60626 Mtetra
.729 .838 .932 r
.57676 .60626 .57768 .60698 .57944 .60587 .57853 .60537 Mtetra
.928 .85 .745 r
.57853 .60537 .57944 .60587 .58114 .60094 .58026 .60241 Mtetra
.966 .879 .49 r
.58026 .60241 .58114 .60094 .57953 .40084 .58195 .59654 Mtetra
0 0 .38 r
.58195 .59654 .57953 .40084 .58108 .39353 .58036 .40052 Mtetra
.356 .119 .411 r
.58036 .40052 .58108 .39353 .58273 .39214 .58199 .39757 Mtetra
.511 .232 .427 r
.58199 .39757 .58273 .39214 .5844 .39165 .58366 .39722 Mtetra
.582 .295 .445 r
.58366 .39722 .5844 .39165 .58608 .39157 .58536 .39806 Mtetra
.584 .305 .459 r
.58536 .39806 .58608 .39157 .58775 .39116 .58706 .39903 Mtetra
.546 .282 .467 r
.58706 .39903 .58775 .39116 .58943 .39068 .58875 .39916 Mtetra
.44 .199 .45 r
.58875 .39916 .58943 .39068 .5911 .39012 .5904 .39698 Mtetra
.141 0 .342 r
.5904 .39698 .5911 .39012 .59276 .38926 .59198 .3917 Mtetra
0 0 0 r
.59198 .3917 .59276 .38926 .59443 .38834 .5936 .38839 Mtetra
.922 .963 .785 r
.5936 .38839 .59443 .38834 .5961 .38748 .59524 .38618 Mtetra
.722 .71 .838 r
.59524 .38618 .5961 .38748 .59777 .38686 .5969 .38525 Mtetra
.65 .638 .825 r
.5969 .38525 .59777 .38686 .59945 .38632 .59858 .38472 Mtetra
.62 .624 .833 r
.59858 .38472 .59945 .38632 .60113 .38583 .60026 .38436 Mtetra
.653 .658 .842 r
.60026 .38436 .60113 .38583 .60281 .38527 .60194 .38382 Mtetra
.656 .662 .844 r
.60194 .38382 .60281 .38527 .60449 .38471 .60362 .38327 Mtetra
.652 .662 .847 r
.60362 .38327 .60449 .38471 .60617 .38414 .6053 .38275 Mtetra
.632 .66 .859 r
.6053 .38275 .60617 .38414 .60785 .3836 .60699 .38233 Mtetra
.629 .68 .88 r
.60699 .38233 .60785 .3836 .60953 .38306 .60868 .38193 Mtetra
.638 .712 .9 r
.60868 .38193 .60953 .38306 .61121 .3825 .61036 .38149 Mtetra
.688 .753 .901 r
.61036 .38149 .61121 .3825 .6129 .38189 .61205 .38082 Mtetra
.703 .745 .885 r
.61205 .38082 .6129 .38189 .61458 .38127 .61373 .38007 Mtetra
.699 .721 .866 r
.61373 .38007 .61458 .38127 .61627 .38065 .61541 .37932 Mtetra
.711 .704 .841 r
.61541 .37932 .61627 .38065 .61794 .3797 .61709 .37845 Mtetra
.687 .708 .864 r
.61709 .37845 .61794 .3797 .61962 .37895 .61877 .37776 Mtetra
.609 .686 .897 r
.61877 .37776 .61962 .37895 .62132 .37875 .62047 .37744 Mtetra
.04 .337 .817 r
.62047 .37744 .62132 .37875 .62311 .3812 .62221 .37865 Mtetra
0 0 .548 r
.62221 .37865 .62311 .3812 .63088 .57551 .62403 .38201 Mtetra
0 0 .407 r
.62403 .38201 .63088 .57551 .63308 .58771 .6318 .57432 Mtetra
.418 .271 .574 r
.6318 .57432 .63308 .58771 .63494 .58866 .63376 .57886 Mtetra
.605 .419 .604 r
.63376 .57886 .63494 .58866 .63674 .58807 .63554 .57744 Mtetra
.606 .416 .599 r
.63554 .57744 .63674 .58807 .63854 .58697 .63731 .57587 Mtetra
.363 .24 .576 r
.63731 .57587 .63854 .58697 .64035 .58656 .6393 .58082 Mtetra
.314 .252 .626 r
.6393 .58082 .64035 .58656 .64218 .58639 .64123 .58389 Mtetra
.261 .339 .755 r
.64123 .58389 .64218 .58639 .644 .58617 .64312 .58543 Mtetra
.468 .746 .989 r
.64312 .58543 .644 .58617 .64581 .58563 .64495 .58534 Mtetra
.653 .929 .972 r
.64495 .58534 .64581 .58563 .64762 .58492 .64676 .58454 Mtetra
.751 .931 .947 r
.64676 .58454 .64762 .58492 .64943 .58415 .64856 .58348 Mtetra
.708 .851 .951 r
.64856 .58348 .64943 .58415 .65125 .58348 .65036 .58266 Mtetra
.673 .807 .947 r
.65036 .58266 .65125 .58348 .65306 .58288 .65218 .58201 Mtetra
.663 .791 .943 r
.65218 .58201 .65306 .58288 .65488 .58232 .654 .5814 Mtetra
.658 .779 .938 r
.654 .5814 .65488 .58232 .6567 .5818 .65582 .58081 Mtetra
.652 .763 .931 r
.65582 .58081 .6567 .5818 .65853 .58131 .65764 .58026 Mtetra
.645 .746 .923 r
.65764 .58026 .65853 .58131 .66036 .58086 .65947 .57974 Mtetra
.643 .732 .913 r
.65947 .57974 .66036 .58086 .66219 .58043 .66129 .57924 Mtetra
.635 .714 .904 r
.66129 .57924 .66219 .58043 .66402 .58003 .66312 .57877 Mtetra
.621 .697 .899 r
.66312 .57877 .66402 .58003 .66585 .57963 .66496 .57837 Mtetra
.586 .682 .907 r
.66496 .57837 .66585 .57963 .66769 .57924 .6668 .57812 Mtetra
.561 .698 .933 r
.6668 .57812 .66769 .57924 .66952 .57884 .66865 .57793 Mtetra
.547 .74 .965 r
.66865 .57793 .66952 .57884 .67136 .57843 .67049 .57772 Mtetra
.46 .75 .992 r
.67049 .57772 .67136 .57843 .67321 .57837 .67235 .57763 Mtetra
.533 .776 .987 r
.67235 .57763 .67321 .57837 .67506 .57819 .67419 .57739 Mtetra
.681 .815 .947 r
.67419 .57739 .67506 .57819 .67689 .57737 .67602 .57669 Mtetra
.896 .855 .793 r
.67602 .57669 .67689 .57737 .67859 .5738 .67778 .57436 Mtetra
.99 .885 .567 r
.67778 .57436 .67859 .5738 .67141 .37656 .67941 .56919 Mtetra
0 0 .408 r
.67941 .56919 .67141 .37656 .6726 .36428 .6722 .3724 Mtetra
.218 .026 .393 r
.6722 .3724 .6726 .36428 .67424 .36197 .67369 .36676 Mtetra
.48 .196 .405 r
.67369 .36676 .67424 .36197 .67596 .3613 .67541 .36607 Mtetra
.559 .262 .421 r
.67541 .36607 .67596 .3613 .6777 .36113 .67718 .3665 Mtetra
.542 .256 .431 r
.67718 .3665 .6777 .36113 .67944 .3608 .67895 .36665 Mtetra
.514 .239 .434 r
.67895 .36665 .67944 .3608 .68117 .36028 .68069 .36629 Mtetra
.515 .241 .437 r
.68069 .36629 .68117 .36028 .6829 .35977 .68243 .36593 Mtetra
.557 .277 .447 r
.68243 .36593 .6829 .35977 .68463 .3593 .68421 .36633 Mtetra
.563 .29 .459 r
.68421 .36633 .68463 .3593 .68636 .35882 .68601 .36689 Mtetra
.483 .232 .457 r
.68601 .36689 .68636 .35882 .6881 .35828 .68771 .3656 Mtetra
.259 .052 .397 r
.68771 .3656 .6881 .35828 .68982 .3575 .68923 .36098 Mtetra
0 0 .191 r
.68923 .36098 .68982 .3575 .69153 .35658 .6908 .35719 Mtetra
.827 .954 .611 r
.6908 .35719 .69153 .35658 .69325 .35569 .69243 .35468 Mtetra
.792 .788 .848 r
.69243 .35468 .69325 .35569 .69498 .35499 .69413 .35336 Mtetra
.66 .645 .824 r
.69413 .35336 .69498 .35499 .69671 .35444 .69586 .35274 Mtetra
.618 .617 .827 r
.69586 .35274 .69671 .35444 .69846 .35396 .69761 .35237 Mtetra
.613 .629 .843 r
.69761 .35237 .69846 .35396 .7002 .35347 .69936 .35204 Mtetra
.62 .654 .862 r
.69936 .35204 .7002 .35347 .70194 .35297 .70111 .35167 Mtetra
.619 .676 .882 r
.70111 .35167 .70194 .35297 .70368 .35245 .70287 .3513 Mtetra
.635 .71 .901 r
.70287 .3513 .70368 .35245 .70543 .35191 .70461 .35085 Mtetra
.655 .738 .911 r
.70461 .35085 .70543 .35191 .70717 .35133 .70636 .35031 Mtetra
.666 .751 .914 r
.70636 .35031 .70717 .35133 .70891 .35073 .7081 .34973 Mtetra
.671 .757 .915 r
.7081 .34973 .70891 .35073 .71065 .3501 .70985 .34912 Mtetra
.676 .765 .918 r
.70985 .34912 .71065 .3501 .71239 .34944 .71159 .34849 Mtetra
.685 .774 .918 r
.71159 .34849 .71239 .34944 .71413 .34878 .71333 .34782 Mtetra
.753 .792 .885 r
.71333 .34782 .71413 .34878 .71586 .34785 .71505 .34679 Mtetra
.762 .774 .863 r
.71505 .34679 .71586 .34785 .71758 .34688 .71677 .34567 Mtetra
.665 .712 .883 r
.71677 .34567 .71758 .34688 .71934 .34643 .71852 .34508 Mtetra
.041 .327 .81 r
.71852 .34508 .71934 .34643 .72122 .34791 .72038 .34642 Mtetra
.936 .58 .167 r
.72038 .34642 .72122 .34791 .72382 .36093 .72283 .35688 Mtetra
.977 .678 .367 r
.72283 .35688 .72382 .36093 .73799 .55721 .73714 .55617 Mtetra
.55 .085 0 r
.73714 .55617 .73799 .55721 .74006 .55965 .73921 .55872 Mtetra
.45 .691 .969 r
.73921 .55872 .74006 .55965 .74197 .55971 .74113 .55877 Mtetra
.75 .81 .901 r
.74113 .55877 .74197 .55971 .74382 .55869 .74298 .55771 Mtetra
.92 .808 .719 r
.74298 .55771 .74382 .55869 .74554 .55554 .74468 .55442 Mtetra
.977 .683 .39 r
.74468 .55442 .74554 .55554 .74634 .5386 .73391 .36117 Mtetra
.588 .365 .545 r
.73391 .36117 .74634 .5386 .7353 .34375 .73447 .3422 Mtetra
.86 .73 .718 r
.73447 .3422 .7353 .34375 .7369 .34077 .73608 .33938 Mtetra
.669 .686 .856 r
.73608 .33938 .7369 .34077 .73865 .34003 .73784 .33875 Mtetra
.55 .649 .9 r
.73784 .33875 .73865 .34003 .74043 .33982 .73963 .33866 Mtetra
.588 .69 .912 r
.73963 .33866 .74043 .33982 .74221 .33941 .74142 .3384 Mtetra
.7 .767 .904 r
.74142 .3384 .74221 .33941 .74395 .33855 .74317 .33765 Mtetra
.637 .771 .944 r
.74317 .33765 .74395 .33855 .74573 .33812 .74494 .33716 Mtetra
.323 .599 .946 r
.74494 .33716 .74573 .33812 .74762 .33928 .74678 .33756 Mtetra
0 .129 .677 r
.74678 .33756 .74762 .33928 .75001 .34749 .74875 .33986 Mtetra
0 0 .446 r
.74875 .33986 .75001 .34749 .76616 .54767 .7513 .35019 Mtetra
.07 0 .45 r
.7513 .35019 .76616 .54767 .7683 .5505 .76706 .54388 Mtetra
.378 .288 .626 r
.76706 .54388 .7683 .5505 .77024 .55059 .76921 .54685 Mtetra
.427 .381 .704 r
.76921 .54685 .77024 .55059 .77214 .55008 .77124 .54814 Mtetra
.425 .499 .832 r
.77124 .54814 .77214 .55008 .77405 .54963 .77323 .54875 Mtetra
.398 .678 .973 r
.77323 .54875 .77405 .54963 .77598 .54952 .77518 .5489 Mtetra
.635 .857 .983 r
.77518 .5489 .77598 .54952 .77788 .54884 .77708 .54828 Mtetra
.917 .894 .791 r
.77708 .54828 .77788 .54884 .77964 .54643 .77884 .54585 Mtetra
.988 .762 .506 r
.77884 .54585 .77964 .54643 .78081 .53625 .78001 .53561 Mtetra
.978 .681 .372 r
.78001 .53561 .78081 .53625 .76723 .33407 .76641 .33258 Mtetra
.895 .744 .685 r
.76641 .33258 .76723 .33407 .76878 .33048 .76797 .32902 Mtetra
.688 .685 .842 r
.76797 .32902 .76878 .33048 .77054 .3296 .76973 .32825 Mtetra
.571 .648 .887 r
.76973 .32825 .77054 .3296 .77234 .32931 .77155 .32809 Mtetra
.572 .672 .907 r
.77155 .32809 .77234 .32931 .77414 .32896 .77336 .3279 Mtetra
.705 .762 .896 r
.77336 .3279 .77414 .32896 .7759 .32803 .77513 .32711 Mtetra
.648 .772 .939 r
.77513 .32711 .7759 .32803 .77769 .32752 .77692 .32657 Mtetra
.396 .643 .956 r
.77692 .32657 .77769 .32752 .77959 .32834 .77878 .3268 Mtetra
0 .167 .706 r
.77878 .3268 .77959 .32834 .78195 .33479 .78078 .3289 Mtetra
0 0 .484 r
.78078 .3289 .78195 .33479 .80038 .53701 .78328 .33689 Mtetra
.084 .004 .459 r
.78328 .33689 .80038 .53701 .80263 .54048 .80134 .53374 Mtetra
.356 .272 .623 r
.80134 .53374 .80263 .54048 .80461 .5407 .80358 .53712 Mtetra
.399 .37 .71 r
.80358 .53712 .80461 .5407 .80654 .54027 .80567 .53859 Mtetra
.402 .519 .862 r
.80567 .53859 .80654 .54027 .80847 .53974 .80769 .53918 Mtetra
.35 .738 .986 r
.80769 .53918 .80847 .53974 .81042 .53957 .80966 .53918 Mtetra
.558 .886 .988 r
.80966 .53918 .81042 .53957 .81234 .53889 .81159 .53861 Mtetra
.815 .974 .898 r
.81159 .53861 .81234 .53889 .81414 .53686 .81343 .53712 Mtetra
.959 .937 .621 r
.81343 .53712 .81414 .53686 .81547 .5294 .8151 .53348 Mtetra
0 0 .044 r
.8151 .53348 .81547 .5294 .7996 .32503 .81633 .52495 Mtetra
.085 .001 .454 r
.81633 .52495 .7996 .32503 .80106 .32053 .80087 .32599 Mtetra
.374 .124 .402 r
.80087 .32599 .80106 .32053 .80282 .31944 .80252 .32365 Mtetra
.468 .176 .385 r
.80252 .32365 .80282 .31944 .80463 .319 .80431 .32292 Mtetra
.501 .196 .381 r
.80431 .32292 .80463 .319 .80646 .31867 .80615 .32264 Mtetra
.445 .152 .373 r
.80615 .32264 .80646 .31867 .80823 .31771 .80793 .32172 Mtetra
.534 .225 .39 r
.80793 .32172 .80823 .31771 .81005 .31721 .8098 .32185 Mtetra
.734 .405 .425 r
.8098 .32185 .81005 .31721 .81198 .31796 .81207 .32629 Mtetra
.97 .658 .362 r
.81207 .32629 .81198 .31796 .81459 .3261 .83221 .52532 Mtetra
.558 .338 .538 r
.83221 .52532 .81459 .3261 .83515 .52793 .83459 .52949 Mtetra
.668 .241 .223 r
.83459 .52949 .83515 .52793 .83745 .53123 .83673 .53107 Mtetra
.116 .659 .836 r
.83673 .53107 .83745 .53123 .83947 .53154 .83872 .53107 Mtetra
.674 .913 .975 r
.83872 .53107 .83947 .53154 .8414 .53077 .84064 .53023 Mtetra
.905 .914 .816 r
.84064 .53023 .8414 .53077 .84319 .52854 .84244 .52802 Mtetra
.994 .786 .517 r
.84244 .52802 .84319 .52854 .84439 .52021 .84366 .51984 Mtetra
.977 .674 .339 r
.84366 .51984 .84439 .52021 .82666 .31508 .82588 .31376 Mtetra
.938 .766 .643 r
.82588 .31376 .82666 .31508 .8281 .31062 .82732 .30925 Mtetra
.765 .733 .823 r
.82732 .30925 .8281 .31062 .82984 .30922 .82907 .30794 Mtetra
.639 .696 .886 r
.82907 .30794 .82984 .30922 .83167 .30874 .8309 .30746 Mtetra
.445 .596 .907 r
.8309 .30746 .83167 .30874 .83361 .30932 .83281 .30773 Mtetra
.12 .338 .805 r
.83281 .30773 .83361 .30932 .83586 .31307 .83484 .30923 Mtetra
.071 .134 .624 r
.83484 .30923 .83586 .31307 .85803 .51637 .83712 .31327 Mtetra
.109 .026 .472 r
.83712 .31327 .85803 .51637 .86066 .52257 .85902 .51304 Mtetra
.327 .232 .592 r
.85902 .51304 .86066 .52257 .86273 .52311 .86159 .51853 Mtetra
.403 .342 .676 r
.86159 .51853 .86273 .52311 .86472 .52281 .86379 .52043 Mtetra
.436 .464 .79 r
.86379 .52043 .86472 .52281 .86668 .52222 .86589 .5212 Mtetra
.405 .648 .956 r
.86589 .5212 .86668 .52222 .8687 .52226 .86794 .52142 Mtetra
.624 .802 .968 r
.86794 .52142 .8687 .52226 .87068 .52179 .86991 .52089 Mtetra
.833 .851 .86 r
.86991 .52089 .87068 .52179 .87254 .52028 .87176 .51924 Mtetra
.979 .78 .567 r
.87176 .51924 .87254 .52028 .87387 .51353 .87308 .5125 Mtetra
.976 .67 .325 r
.87308 .5125 .87387 .51353 .85422 .30756 .85347 .30645 Mtetra
.964 .781 .607 r
.85347 .30645 .85422 .30756 .85556 .30231 .85482 .30118 Mtetra
.758 .775 .867 r
.85482 .30118 .85556 .30231 .85734 .30118 .8566 .30005 Mtetra
.629 .724 .916 r
.8566 .30005 .85734 .30118 .85919 .30073 .85845 .2996 Mtetra
.553 .688 .929 r
.85845 .2996 .85919 .30073 .86108 .30057 .86034 .29945 Mtetra
.75 .773 .872 r
.86034 .29945 .86108 .30057 .86287 .29949 .86212 .29837 Mtetra
.682 .748 .901 r
.86212 .29837 .86287 .29949 .8647 .2988 .86396 .29767 Mtetra
.476 .648 .934 r
.86396 .29767 .8647 .2988 .86662 .2989 .86587 .29777 Mtetra
.754 .338 0 r
.86587 .29777 .86662 .2989 .86908 .30392 .86834 .3028 Mtetra
.971 .656 .295 r
.86834 .3028 .86908 .30392 .89371 .50918 .89294 .50811 Mtetra
.73 .298 0 r
.89294 .50811 .89371 .50918 .89628 .51388 .8955 .51281 Mtetra
.302 .576 .937 r
.8955 .51281 .89628 .51388 .89839 .51441 .89761 .51335 Mtetra
.648 .763 .933 r
.89761 .51335 .89839 .51441 .90037 .51382 .8996 .51276 Mtetra
.828 .821 .842 r
.8996 .51276 .90037 .51382 .90223 .51212 .90146 .51105 Mtetra
.908 .736 .657 r
.26438 .69493 .26542 .69578 .26737 .69023 .26633 .68938 Mtetra
.936 .686 .535 r
.26633 .68938 .26737 .69023 .28319 .4944 .28221 .4935 Mtetra
.908 .728 .647 r
.28221 .4935 .28319 .4944 .28507 .48866 .28409 .48775 Mtetra
.772 .76 .842 r
.28409 .48775 .28507 .48866 .28661 .48754 .28563 .48664 Mtetra
.635 .736 .921 r
.28563 .48664 .28661 .48754 .28809 .48715 .28712 .48625 Mtetra
.498 .69 .953 r
.28712 .48625 .28809 .48715 .28956 .48712 .28858 .48623 Mtetra
.749 .761 .862 r
.28858 .48623 .28956 .48712 .29109 .48617 .29011 .48529 Mtetra
.693 .755 .899 r
.29011 .48529 .29109 .48617 .29259 .48554 .29162 .48467 Mtetra
.447 .675 .961 r
.29162 .48467 .29259 .48554 .29405 .48561 .29308 .48474 Mtetra
.933 .57 .3 r
.29308 .48474 .29405 .48561 .2952 .4902 .29423 .48934 Mtetra
.939 .683 .523 r
.29423 .48934 .2952 .4902 .2832 .68572 .28217 .68482 Mtetra
.931 .564 .29 r
.28217 .68482 .2832 .68572 .28444 .69043 .2834 .68953 Mtetra
.376 .649 .963 r
.2834 .68953 .28444 .69043 .28599 .6906 .28495 .68972 Mtetra
.702 .769 .904 r
.28495 .68972 .28599 .6906 .2876 .68987 .28656 .68902 Mtetra
.77 .781 .862 r
.28656 .68902 .2876 .68987 .28924 .68872 .2882 .6879 Mtetra
.51 .726 .971 r
.2882 .6879 .28924 .68872 .29081 .68863 .28977 .6878 Mtetra
.596 .755 .955 r
.28977 .6878 .29081 .68863 .29239 .68833 .29136 .6875 Mtetra
.754 .784 .878 r
.29136 .6875 .29239 .68833 .29402 .68735 .29299 .6865 Mtetra
.908 .743 .666 r
.29299 .6865 .29402 .68735 .29592 .68232 .29489 .68147 Mtetra
.939 .687 .529 r
.29489 .68147 .29592 .68232 .31021 .48621 .30924 .48529 Mtetra
.913 .727 .638 r
.30924 .48529 .31021 .48621 .31209 .47997 .31113 .47905 Mtetra
.794 .761 .823 r
.31113 .47905 .31209 .47997 .31366 .47862 .31269 .47771 Mtetra
.64 .737 .919 r
.31269 .47771 .31366 .47862 .31516 .47821 .3142 .47731 Mtetra
.498 .689 .953 r
.3142 .47731 .31516 .47821 .31664 .47819 .31568 .47729 Mtetra
.671 .748 .908 r
.31568 .47729 .31664 .47819 .31817 .47752 .3172 .47676 Mtetra
.68 .781 .926 r
.3172 .47676 .31817 .47752 .31969 .47691 .31871 .47619 Mtetra
.634 .781 .952 r
.31871 .47619 .31969 .47691 .32119 .47667 .32022 .47578 Mtetra
.557 .713 .945 r
.32022 .47578 .32119 .47667 .3226 .47787 .32172 .47562 Mtetra
.508 .489 .771 r
.32172 .47562 .3226 .47787 .32387 .48134 .32319 .47589 Mtetra
.47 .35 .634 r
.32319 .47589 .32387 .48134 .31392 .67078 .32461 .47701 Mtetra
.536 .325 .54 r
.32461 .47701 .31392 .67078 .31512 .67708 .32564 .48469 Mtetra
0 0 .261 r
.32564 .48469 .31512 .67708 .31658 .67913 .31573 .67537 Mtetra
0 0 .521 r
.31573 .67537 .31658 .67913 .31811 .68001 .3171 .67883 Mtetra
.269 .525 .911 r
.3171 .67883 .31811 .68001 .31968 .6802 .31866 .67936 Mtetra
.626 .762 .944 r
.31866 .67936 .31968 .6802 .32129 .67985 .32027 .67896 Mtetra
.738 .775 .883 r
.32027 .67896 .32129 .67985 .32293 .67891 .32191 .67805 Mtetra
.747 .782 .882 r
.32191 .67805 .32293 .67891 .32465 .67659 .32355 .6771 Mtetra
.687 .975 .79 r
.32355 .6771 .32465 .67659 .32651 .6719 .32522 .67575 Mtetra
.184 0 .236 r
.32522 .67575 .32651 .6719 .33883 .48129 .32694 .67347 Mtetra
.535 .32 .534 r
.32694 .67347 .33883 .48129 .34074 .47394 .32902 .66483 Mtetra
0 0 .252 r
.32902 .66483 .34074 .47394 .3424 .47113 .3413 .4729 Mtetra
.921 .919 .535 r
.3413 .4729 .3424 .47113 .34399 .46941 .34303 .46877 Mtetra
.815 .818 .852 r
.34303 .46877 .34399 .46941 .34554 .46856 .3446 .46743 Mtetra
.65 .695 .879 r
.3446 .46743 .34554 .46856 .34707 .46814 .34613 .46697 Mtetra
.562 .657 .9 r
.34613 .46697 .34707 .46814 .34858 .4679 .34764 .46686 Mtetra
.616 .703 .906 r
.34764 .46686 .34858 .4679 .35011 .46753 .34916 .46654 Mtetra
.648 .724 .904 r
.34916 .46654 .35011 .46753 .35164 .46706 .35069 .4661 Mtetra
.659 .733 .905 r
.35069 .4661 .35164 .46706 .35317 .46653 .35222 .46561 Mtetra
.687 .75 .9 r
.35222 .46561 .35317 .46653 .35472 .46585 .35376 .46501 Mtetra
.701 .77 .905 r
.35376 .46501 .35472 .46585 .35626 .4651 .35531 .46434 Mtetra
.704 .789 .917 r
.35531 .46434 .35626 .4651 .35781 .46437 .35685 .46367 Mtetra
.713 .806 .923 r
.35685 .46367 .35781 .46437 .35936 .46352 .3584 .46296 Mtetra
.692 .837 .953 r
.3584 .46296 .35936 .46352 .36091 .46282 .35994 .46232 Mtetra
.622 .841 .983 r
.35994 .46232 .36091 .46282 .36244 .4625 .36148 .46187 Mtetra
.314 .679 .977 r
.36148 .46187 .36244 .4625 .3639 .46359 .36299 .46201 Mtetra
.332 .469 .848 r
.36299 .46201 .3639 .46359 .36525 .46701 .36447 .46265 Mtetra
.469 .371 .662 r
.36447 .46265 .36525 .46701 .35767 .65632 .36594 .46358 Mtetra
.553 .339 .543 r
.36594 .46358 .35767 .65632 .35906 .66094 .36748 .46329 Mtetra
.554 .34 .544 r
.36748 .46329 .35906 .66094 .3607 .66016 .36904 .46243 Mtetra
.553 .339 .543 r
.36904 .46243 .3607 .66016 .36236 .65924 .37057 .4622 Mtetra
.542 .33 .542 r
.37057 .4622 .36236 .65924 .36384 .66213 .37185 .46733 Mtetra
0 0 .288 r
.37185 .46733 .36384 .66213 .36533 .6648 .36447 .66087 Mtetra
0 0 .468 r
.36447 .66087 .36533 .6648 .36688 .66633 .3659 .66497 Mtetra
.132 .406 .854 r
.3659 .66497 .36688 .66633 .36849 .6667 .36748 .66587 Mtetra
.576 .751 .96 r
.36748 .66587 .36849 .6667 .37012 .66647 .36911 .6656 Mtetra
.688 .776 .919 r
.36911 .6656 .37012 .66647 .37176 .66598 .37077 .66495 Mtetra
.669 .737 .901 r
.37077 .66495 .37176 .66598 .37341 .66559 .37242 .66439 Mtetra
.66 .702 .878 r
.37242 .66439 .37341 .66559 .37505 .66513 .37407 .66385 Mtetra
.69 .7 .854 r
.37407 .66385 .37505 .66513 .37671 .6643 .37572 .66314 Mtetra
.762 .735 .828 r
.37572 .66314 .37671 .6643 .37843 .6622 .3774 .66192 Mtetra
.866 .9 .855 r
.3774 .66192 .37843 .6622 .38024 .65793 .37911 .66022 Mtetra
0 0 .009 r
.37911 .66022 .38024 .65793 .38271 .63742 .38082 .65826 Mtetra
.531 .299 .508 r
.38082 .65826 .38271 .63742 .39148 .46132 .38249 .65735 Mtetra
.551 .333 .537 r
.38249 .65735 .39148 .46132 .39304 .46097 .38412 .6572 Mtetra
.55 .332 .537 r
.38412 .6572 .39304 .46097 .39458 .46101 .38579 .65648 Mtetra
.543 .326 .536 r
.38579 .65648 .39458 .46101 .39627 .45717 .38762 .65154 Mtetra
0 0 .287 r
.38762 .65154 .39627 .45717 .39795 .45342 .39689 .45592 Mtetra
.881 .862 .414 r
.39689 .45592 .39795 .45342 .39959 .45099 .39864 .45057 Mtetra
.88 .856 .814 r
.39864 .45057 .39959 .45099 .40118 .44971 .40025 .44867 Mtetra
.688 .728 .881 r
.40025 .44867 .40118 .44971 .40274 .44914 .40182 .44803 Mtetra
.596 .687 .905 r
.40182 .44803 .40274 .44914 .4043 .44879 .40337 .44779 Mtetra
.59 .705 .923 r
.40337 .44779 .4043 .44879 .40585 .44849 .40492 .44754 Mtetra
.621 .729 .924 r
.40492 .44754 .40585 .44849 .40741 .44814 .40648 .44719 Mtetra
.625 .729 .921 r
.40648 .44719 .40741 .44814 .40897 .44777 .40804 .44682 Mtetra
.657 .739 .91 r
.40804 .44682 .40897 .44777 .41054 .44724 .40961 .44633 Mtetra
.685 .757 .906 r
.40961 .44633 .41054 .44724 .41211 .44655 .41118 .44572 Mtetra
.692 .777 .916 r
.41118 .44572 .41211 .44655 .41369 .44584 .41275 .44509 Mtetra
.699 .796 .925 r
.41275 .44509 .41369 .44584 .41526 .44506 .41433 .44443 Mtetra
.689 .824 .948 r
.41433 .44443 .41526 .44506 .41684 .44433 .4159 .4438 Mtetra
.628 .837 .98 r
.4159 .4438 .41684 .44433 .41841 .44393 .41747 .44333 Mtetra
.399 .73 .991 r
.41747 .44333 .41841 .44393 .41994 .44462 .41902 .44333 Mtetra
.287 .498 .887 r
.41902 .44333 .41994 .44462 .42141 .44743 .42056 .44393 Mtetra
.446 .384 .694 r
.42056 .44393 .42141 .44743 .41756 .62086 .42209 .44485 Mtetra
.551 .338 .543 r
.42209 .44485 .41756 .62086 .41849 .64392 .42364 .44535 Mtetra
.553 .339 .543 r
.42364 .44535 .41849 .64392 .42015 .64397 .42521 .44492 Mtetra
.554 .339 .543 r
.42521 .44492 .42015 .64397 .42185 .6426 .4268 .44415 Mtetra
.4268 .44415 .42185 .6426 .42355 .64118 .42838 .44342 Mtetra
.553 .339 .543 r
.42838 .44342 .42355 .64118 .42522 .64057 .42996 .44286 Mtetra
.42996 .44286 .42522 .64057 .4269 .63997 .43154 .44231 Mtetra
.43154 .44231 .4269 .63997 .42858 .63943 .43313 .44177 Mtetra
.43313 .44177 .42858 .63943 .43025 .63897 .43471 .44125 Mtetra
.43471 .44125 .43025 .63897 .43193 .63851 .43629 .44074 Mtetra
.43629 .44074 .43193 .63851 .43359 .63875 .43787 .44036 Mtetra
.43787 .44036 .43359 .63875 .43524 .63924 .43945 .44007 Mtetra
.554 .339 .543 r
.43945 .44007 .43524 .63924 .43693 .63832 .44104 .43948 Mtetra
.555 .34 .544 r
.44104 .43948 .43693 .63832 .43889 .62668 .44265 .43808 Mtetra
.556 .342 .544 r
.44265 .43808 .43889 .62668 .44512 .43994 .44428 .43613 Mtetra
.685 .53 .67 r
.44428 .43613 .44512 .43994 .4468 .43591 .44589 .43448 Mtetra
.739 .687 .8 r
.44589 .43448 .4468 .43591 .44842 .43399 .44749 .43335 Mtetra
.676 .823 .954 r
.44749 .43335 .44842 .43399 .45001 .4333 .44909 .43276 Mtetra
.607 .831 .985 r
.44909 .43276 .45001 .4333 .45159 .43296 .45067 .43233 Mtetra
.596 .805 .98 r
.45067 .43233 .45159 .43296 .45318 .43272 .45226 .43197 Mtetra
.618 .78 .959 r
.45226 .43197 .45318 .43272 .45477 .43239 .45385 .43158 Mtetra
.621 .766 .949 r
.45385 .43158 .45477 .43239 .45635 .43207 .45544 .43119 Mtetra
.637 .754 .933 r
.45544 .43119 .45635 .43207 .45795 .4317 .45703 .43077 Mtetra
.658 .747 .916 r
.45703 .43077 .45795 .4317 .45954 .43123 .45863 .43027 Mtetra
.669 .744 .906 r
.45863 .43027 .45954 .43123 .46113 .4307 .46023 .42972 Mtetra
.684 .745 .897 r
.46023 .42972 .46113 .4307 .46273 .43008 .46182 .4291 Mtetra
.698 .748 .89 r
.46182 .4291 .46273 .43008 .46433 .42938 .46343 .42841 Mtetra
.698 .751 .892 r
.46343 .42841 .46433 .42938 .46594 .42868 .46503 .42772 Mtetra
.713 .758 .887 r
.46503 .42772 .46594 .42868 .46754 .42796 .46663 .42696 Mtetra
.722 .752 .876 r
.46663 .42696 .46754 .42796 .46914 .42725 .46824 .42614 Mtetra
.649 .709 .891 r
.46824 .42614 .46914 .42725 .47074 .42675 .46984 .42567 Mtetra
.239 .516 .911 r
.46984 .42567 .47074 .42675 .47233 .42685 .47142 .42625 Mtetra
.895 .474 .151 r
.47142 .42625 .47233 .42685 .47391 .42813 .47296 .4299 Mtetra
.955 .681 .479 r
.47296 .4299 .47391 .42813 .47547 .43061 .47154 .6252 Mtetra
.561 .341 .539 r
.47154 .6252 .47547 .43061 .47701 .4344 .47315 .63093 Mtetra
.552 .334 .537 r
.47315 .63093 .47701 .4344 .47861 .43491 .47485 .63098 Mtetra
.55 .332 .537 r
.47485 .63098 .47861 .43491 .48023 .43342 .47656 .63013 Mtetra
.47656 .63013 .48023 .43342 .48186 .4314 .47828 .62896 Mtetra
.47828 .62896 .48186 .4314 .48349 .42977 .47999 .62818 Mtetra
.551 .333 .537 r
.47999 .62818 .48349 .42977 .4851 .42939 .48171 .62769 Mtetra
.552 .334 .537 r
.48171 .62769 .4851 .42939 .48665 .43434 .48341 .62793 Mtetra
.553 .335 .537 r
.48341 .62793 .48665 .43434 .48611 .62602 .4851 .62903 Mtetra
.595 .258 .369 r
.4851 .62903 .48611 .62602 .48777 .62994 .48681 .62985 Mtetra
.181 0 0 r
.48681 .62985 .48777 .62994 .48947 .63136 .48852 .63016 Mtetra
.622 .697 .898 r
.48852 .63016 .48947 .63136 .49119 .63112 .49023 .62978 Mtetra
.656 .685 .866 r
.49023 .62978 .49119 .63112 .49291 .63051 .49195 .62923 Mtetra
.656 .696 .875 r
.49195 .62923 .49291 .63051 .49463 .62985 .49368 .62869 Mtetra
.613 .701 .907 r
.49368 .62869 .49463 .62985 .49635 .62952 .4954 .62834 Mtetra
.612 .698 .905 r
.4954 .62834 .49635 .62952 .49807 .62919 .49712 .628 Mtetra
.621 .699 .901 r
.49712 .628 .49807 .62919 .4998 .62882 .49884 .62763 Mtetra
.639 .705 .894 r
.49884 .62763 .4998 .62882 .50152 .62836 .50057 .62717 Mtetra
.644 .708 .893 r
.50057 .62717 .50152 .62836 .50325 .62787 .5023 .62669 Mtetra
.647 .711 .894 r
.5023 .62669 .50325 .62787 .50498 .62737 .50403 .62619 Mtetra
.646 .712 .896 r
.50403 .62619 .50498 .62737 .5067 .62688 .50575 .62571 Mtetra
.647 .713 .896 r
.50575 .62571 .5067 .62688 .50843 .62638 .50749 .62521 Mtetra
.648 .714 .896 r
.50749 .62521 .50843 .62638 .51017 .62588 .50922 .62471 Mtetra
.50922 .62471 .51017 .62588 .5119 .62538 .51095 .62421 Mtetra
.649 .715 .896 r
.51095 .62421 .5119 .62538 .51363 .62488 .51268 .62371 Mtetra
.65 .715 .896 r
.51268 .62371 .51363 .62488 .51536 .62437 .51442 .6232 Mtetra
.51442 .6232 .51536 .62437 .5171 .62386 .51615 .62269 Mtetra
.651 .715 .895 r
.51615 .62269 .5171 .62386 .51884 .62334 .51789 .62218 Mtetra
.651 .716 .896 r
.51789 .62218 .51884 .62334 .52057 .62283 .51963 .62166 Mtetra
.65 .715 .896 r
.51963 .62166 .52057 .62283 .52231 .62232 .52137 .62115 Mtetra
.653 .716 .895 r
.52137 .62115 .52231 .62232 .52405 .62179 .52311 .62063 Mtetra
.66 .719 .893 r
.52311 .62063 .52405 .62179 .52579 .62122 .52485 .62007 Mtetra
.675 .728 .89 r
.52485 .62007 .52579 .62122 .52754 .62054 .52659 .61944 Mtetra
.677 .738 .896 r
.52659 .61944 .52754 .62054 .52928 .61984 .52834 .6188 Mtetra
.674 .748 .907 r
.52834 .6188 .52928 .61984 .53102 .61917 .53008 .61817 Mtetra
.657 .753 .921 r
.53008 .61817 .53102 .61917 .53277 .6186 .53183 .61763 Mtetra
.646 .753 .927 r
.53183 .61763 .53277 .6186 .53451 .6181 .53357 .61712 Mtetra
.634 .749 .931 r
.53357 .61712 .53451 .6181 .53626 .61767 .53532 .61667 Mtetra
.615 .737 .933 r
.53532 .61667 .53626 .61767 .53801 .61734 .53707 .61629 Mtetra
.614 .726 .925 r
.53707 .61629 .53801 .61734 .53976 .61703 .53882 .61591 Mtetra
.621 .716 .914 r
.53882 .61591 .53976 .61703 .54151 .61668 .54057 .61552 Mtetra
.64 .715 .901 r
.54057 .61552 .54151 .61668 .54326 .61623 .54233 .61505 Mtetra
.645 .714 .898 r
.54233 .61505 .54326 .61623 .54502 .61574 .54408 .61456 Mtetra
.648 .715 .896 r
.54408 .61456 .54502 .61574 .54677 .61523 .54583 .61405 Mtetra
.646 .714 .897 r
.54583 .61405 .54677 .61523 .54853 .61473 .54759 .61355 Mtetra
.647 .714 .897 r
.54759 .61355 .54853 .61473 .55028 .61423 .54935 .61305 Mtetra
.648 .714 .896 r
.54935 .61305 .55028 .61423 .55204 .61372 .55111 .61254 Mtetra
.648 .715 .896 r
.55111 .61254 .55204 .61372 .5538 .61321 .55286 .61203 Mtetra
.649 .715 .896 r
.55286 .61203 .5538 .61321 .55556 .6127 .55463 .61152 Mtetra
.65 .715 .896 r
.55463 .61152 .55556 .6127 .55732 .61219 .55639 .61101 Mtetra
.55639 .61101 .55732 .61219 .55908 .61167 .55815 .61049 Mtetra
.651 .715 .895 r
.55815 .61049 .55908 .61167 .56084 .61115 .55991 .60996 Mtetra
.652 .715 .894 r
.55991 .60996 .56084 .61115 .56261 .61063 .56168 .60943 Mtetra
.651 .714 .894 r
.56168 .60943 .56261 .61063 .56437 .61011 .56344 .60891 Mtetra
.654 .714 .892 r
.56344 .60891 .56437 .61011 .56614 .60958 .56521 .60837 Mtetra
.659 .714 .889 r
.56521 .60837 .56614 .60958 .56791 .60902 .56698 .60781 Mtetra
.677 .72 .881 r
.56698 .60781 .56791 .60902 .56967 .60836 .56875 .60715 Mtetra
.68 .722 .881 r
.56875 .60715 .56967 .60836 .57144 .60767 .57051 .60648 Mtetra
.678 .724 .884 r
.57051 .60648 .57144 .60767 .57321 .60699 .57228 .60582 Mtetra
.629 .709 .904 r
.57228 .60582 .57321 .60699 .57498 .60672 .57406 .60539 Mtetra
.643 .688 .877 r
.57406 .60539 .57498 .60672 .57676 .60626 .57583 .6049 Mtetra
.677 .696 .861 r
.57583 .6049 .57676 .60626 .57853 .60537 .5776 .60422 Mtetra
.795 .762 .823 r
.5776 .60422 .57853 .60537 .58026 .60241 .57936 .60272 Mtetra
.832 .999 .786 r
.57936 .60272 .58026 .60241 .58195 .59654 .58112 .60082 Mtetra
.304 .032 .325 r
.58112 .60082 .58195 .59654 .58036 .40052 .58287 .59869 Mtetra
.55 .332 .537 r
.58287 .59869 .58036 .40052 .58199 .39757 .58464 .59775 Mtetra
.551 .333 .537 r
.58464 .59775 .58199 .39757 .58366 .39722 .58642 .59733 Mtetra
.58642 .59733 .58366 .39722 .58536 .39806 .5882 .59713 Mtetra
.552 .334 .537 r
.5882 .59713 .58536 .39806 .58706 .39903 .59 .59732 Mtetra
.551 .333 .537 r
.59 .59732 .58706 .39903 .58875 .39916 .59178 .597 Mtetra
.549 .332 .537 r
.59178 .597 .58875 .39916 .5904 .39698 .59355 .59564 Mtetra
.533 .319 .535 r
.59355 .59564 .5904 .39698 .59198 .3917 .59511 .58439 Mtetra
0 0 .381 r
.59511 .58439 .59198 .3917 .5936 .38839 .59278 .38936 Mtetra
.947 .918 .551 r
.59278 .38936 .5936 .38839 .59524 .38618 .59438 .38531 Mtetra
.789 .803 .864 r
.59438 .38531 .59524 .38618 .5969 .38525 .59604 .38408 Mtetra
.659 .71 .885 r
.59604 .38408 .5969 .38525 .59858 .38472 .59772 .38355 Mtetra
.588 .681 .905 r
.59772 .38355 .59858 .38472 .60026 .38436 .59941 .38331 Mtetra
.651 .731 .908 r
.59941 .38331 .60026 .38436 .60194 .38382 .60109 .38281 Mtetra
.658 .741 .911 r
.60109 .38281 .60194 .38382 .60362 .38327 .60277 .38228 Mtetra
.652 .743 .917 r
.60277 .38228 .60362 .38327 .6053 .38275 .60445 .38177 Mtetra
.63 .74 .927 r
.60445 .38177 .6053 .38275 .60699 .38233 .60614 .38135 Mtetra
.626 .737 .927 r
.60614 .38135 .60699 .38233 .60868 .38193 .60783 .38094 Mtetra
.636 .738 .922 r
.60783 .38094 .60868 .38193 .61036 .38149 .60951 .3805 Mtetra
.675 .753 .909 r
.60951 .3805 .61036 .38149 .61205 .38082 .6112 .3799 Mtetra
.69 .771 .913 r
.6112 .3799 .61205 .38082 .61373 .38007 .61288 .37922 Mtetra
.694 .79 .925 r
.61288 .37922 .61373 .38007 .61541 .37932 .61457 .37854 Mtetra
.703 .809 .931 r
.61457 .37854 .61541 .37932 .61709 .37845 .61625 .37781 Mtetra
.676 .839 .961 r
.61625 .37781 .61709 .37845 .61877 .37776 .61794 .37717 Mtetra
.611 .833 .985 r
.61794 .37717 .61877 .37776 .62047 .37744 .61963 .37671 Mtetra
.356 .676 .977 r
.61963 .37671 .62047 .37744 .62221 .37865 .62134 .37686 Mtetra
.415 .494 .832 r
.62134 .37686 .62221 .37865 .62403 .38201 .62307 .37743 Mtetra
.498 .392 .665 r
.62307 .37743 .62403 .38201 .6318 .57432 .62481 .37821 Mtetra
.553 .339 .544 r
.62481 .37821 .6318 .57432 .63376 .57886 .6265 .37761 Mtetra
.554 .34 .543 r
.6265 .37761 .63376 .57886 .63554 .57744 .62819 .3767 Mtetra
.553 .339 .543 r
.62819 .3767 .63554 .57744 .63731 .57587 .6299 .37642 Mtetra
.543 .331 .543 r
.6299 .37642 .63731 .57587 .6393 .58082 .63178 .38133 Mtetra
0 0 .409 r
.63178 .38133 .6393 .58082 .64123 .58389 .64023 .57983 Mtetra
0 .04 .569 r
.64023 .57983 .64123 .58389 .64312 .58543 .64221 .58414 Mtetra
.363 .562 .912 r
.64221 .58414 .64312 .58543 .64495 .58534 .64406 .58461 Mtetra
.681 .831 .956 r
.64406 .58461 .64495 .58534 .64676 .58454 .64588 .58391 Mtetra
.776 .873 .919 r
.64588 .58391 .64676 .58454 .64856 .58348 .64767 .58276 Mtetra
.719 .845 .941 r
.64767 .58276 .64856 .58348 .65036 .58266 .64948 .5819 Mtetra
.679 .824 .953 r
.64948 .5819 .65036 .58266 .65218 .58201 .6513 .58122 Mtetra
.675 .815 .951 r
.6513 .58122 .65218 .58201 .654 .5814 .65312 .58055 Mtetra
.672 .8 .944 r
.65312 .58055 .654 .5814 .65582 .58081 .65493 .5799 Mtetra
.668 .784 .936 r
.65493 .5799 .65582 .58081 .65764 .58026 .65676 .57927 Mtetra
.661 .766 .927 r
.65676 .57927 .65764 .58026 .65947 .57974 .65858 .57868 Mtetra
.656 .748 .918 r
.65858 .57868 .65947 .57974 .66129 .57924 .6604 .57811 Mtetra
.646 .732 .911 r
.6604 .57811 .66129 .57924 .66312 .57877 .66223 .57759 Mtetra
.632 .715 .907 r
.66223 .57759 .66312 .57877 .66496 .57837 .66407 .57714 Mtetra
.602 .693 .907 r
.66407 .57714 .66496 .57837 .6668 .57812 .66591 .57682 Mtetra
.587 .674 .9 r
.66591 .57682 .6668 .57812 .66865 .57793 .66775 .57657 Mtetra
.59 .664 .89 r
.66775 .57657 .66865 .57793 .67049 .57772 .66959 .57631 Mtetra
.582 .654 .886 r
.66959 .57631 .67049 .57772 .67235 .57763 .67144 .5761 Mtetra
.604 .645 .864 r
.67144 .5761 .67235 .57763 .67419 .57739 .67329 .57579 Mtetra
.645 .655 .846 r
.67329 .57579 .67419 .57739 .67602 .57669 .67513 .57526 Mtetra
.75 .719 .823 r
.67513 .57526 .67602 .57669 .67778 .57436 .67693 .57401 Mtetra
.882 .932 .849 r
.67693 .57401 .67778 .57436 .67941 .56919 .67871 .57213 Mtetra
.162 0 .208 r
.67871 .57213 .67941 .56919 .6722 .3724 .68047 .56989 Mtetra
.549 .332 .537 r
.68047 .56989 .6722 .3724 .67369 .36676 .68227 .56846 Mtetra
.551 .333 .537 r
.68227 .56846 .67369 .36676 .67541 .36607 .68411 .56801 Mtetra
.68411 .56801 .67541 .36607 .67718 .3665 .68598 .56789 Mtetra
.68598 .56789 .67718 .3665 .67895 .36665 .68783 .56762 Mtetra
.68783 .56762 .67895 .36665 .68069 .36629 .68968 .56719 Mtetra
.68968 .56719 .68069 .36629 .68243 .36593 .69153 .56674 Mtetra
.552 .333 .537 r
.69153 .56674 .68243 .36593 .68421 .36633 .69341 .56676 Mtetra
.551 .333 .537 r
.69341 .56676 .68421 .36633 .68601 .36689 .69528 .56669 Mtetra
.55 .332 .537 r
.69528 .56669 .68601 .36689 .68771 .3656 .69711 .56574 Mtetra
.543 .327 .537 r
.69711 .56574 .68771 .3656 .68923 .36098 .6987 .56022 Mtetra
.019 0 .418 r
.6987 .56022 .68923 .36098 .6908 .35719 .69015 .35945 Mtetra
.694 .72 .201 r
.69015 .35945 .6908 .35719 .69243 .35468 .69164 .35412 Mtetra
.888 .882 .822 r
.69164 .35412 .69243 .35468 .69413 .35336 .69331 .35218 Mtetra
.682 .723 .881 r
.69331 .35218 .69413 .35336 .69586 .35274 .69504 .35151 Mtetra
.596 .678 .898 r
.69504 .35151 .69586 .35274 .69761 .35237 .69679 .35124 Mtetra
.593 .695 .914 r
.69679 .35124 .69761 .35237 .69936 .35204 .69855 .35096 Mtetra
.619 .719 .918 r
.69855 .35096 .69936 .35204 .70111 .35167 .7003 .35058 Mtetra
.617 .716 .916 r
.7003 .35058 .70111 .35167 .70287 .3513 .70205 .3502 Mtetra
.632 .721 .911 r
.70205 .3502 .70287 .3513 .70461 .35085 .7038 .34976 Mtetra
.649 .73 .908 r
.7038 .34976 .70461 .35085 .70636 .35031 .70555 .34925 Mtetra
.659 .739 .909 r
.70555 .34925 .70636 .35031 .7081 .34973 .70729 .3487 Mtetra
.666 .748 .912 r
.70729 .3487 .7081 .34973 .70985 .34912 .70904 .34811 Mtetra
.673 .755 .913 r
.70904 .34811 .70985 .34912 .71159 .34849 .71078 .34749 Mtetra
.681 .761 .912 r
.71078 .34749 .71159 .34849 .71333 .34782 .71253 .34684 Mtetra
.746 .785 .885 r
.71253 .34684 .71333 .34782 .71505 .34679 .71425 .34585 Mtetra
.762 .797 .881 r
.71425 .34585 .71505 .34679 .71677 .34567 .71597 .34477 Mtetra
.654 .774 .937 r
.71597 .34477 .71677 .34567 .71852 .34508 .71772 .34422 Mtetra
0 .198 .695 r
.71772 .34422 .71852 .34508 .72038 .34642 .7196 .34565 Mtetra
.953 .604 .258 r
.7196 .34565 .72038 .34642 .72283 .35688 .72217 .35834 Mtetra
.973 .673 .384 r
.72217 .35834 .72283 .35688 .73714 .55617 .7363 .55532 Mtetra
.6 .105 0 r
.7363 .55532 .73714 .55617 .73921 .55872 .73837 .55775 Mtetra
.468 .692 .965 r
.73837 .55775 .73921 .55872 .74113 .55877 .74028 .55778 Mtetra
.749 .798 .892 r
.74028 .55778 .74113 .55877 .74298 .55771 .74213 .55671 Mtetra
.917 .804 .719 r
.74213 .55671 .74298 .55771 .74468 .55442 .74384 .55343 Mtetra
.977 .684 .39 r
.74384 .55343 .74468 .55442 .73391 .36117 .7333 .36298 Mtetra
.991 .739 .38 r
.7333 .36298 .73391 .36117 .73447 .3422 .73367 .3412 Mtetra
.905 .8 .733 r
.73367 .3412 .73447 .3422 .73608 .33938 .73528 .33836 Mtetra
.681 .758 .91 r
.73528 .33836 .73608 .33938 .73784 .33875 .73704 .3377 Mtetra
.538 .693 .939 r
.73704 .3377 .73784 .33875 .73963 .33866 .73883 .33758 Mtetra
.568 .7 .931 r
.73883 .33758 .73963 .33866 .74142 .3384 .74062 .33738 Mtetra
.677 .757 .912 r
.74062 .33738 .74142 .3384 .74317 .33765 .74239 .33674 Mtetra
.652 .774 .938 r
.74239 .33674 .74317 .33765 .74494 .33716 .74416 .3362 Mtetra
.595 .738 .943 r
.74416 .3362 .74494 .33716 .74678 .33756 .74594 .33587 Mtetra
.538 .579 .844 r
.74594 .33587 .74678 .33756 .74875 .33986 .74776 .33591 Mtetra
.498 .411 .688 r
.74776 .33591 .74875 .33986 .7513 .35019 .74962 .33662 Mtetra
.468 .308 .58 r
.74962 .33662 .7513 .35019 .76706 .54388 .75167 .33989 Mtetra
.069 0 .45 r
.75167 .33989 .76706 .54388 .76921 .54685 .76797 .54024 Mtetra
.141 .126 .578 r
.76797 .54024 .76921 .54685 .77124 .54814 .77032 .546 Mtetra
.16 .309 .768 r
.77032 .546 .77124 .54814 .77323 .54875 .7724 .54777 Mtetra
.41 .659 .961 r
.7724 .54777 .77323 .54875 .77518 .5489 .77435 .54795 Mtetra
.692 .795 .929 r
.77435 .54795 .77518 .5489 .77708 .54828 .77624 .54719 Mtetra
.887 .803 .761 r
.77624 .54719 .77708 .54828 .77884 .54585 .77799 .54459 Mtetra
.973 .737 .52 r
.77799 .54459 .77884 .54585 .78001 .53561 .77912 .53377 Mtetra
.977 .68 .375 r
.77912 .53377 .78001 .53561 .76641 .33258 .76562 .33146 Mtetra
.921 .784 .693 r
.76562 .33146 .76641 .33258 .76797 .32902 .76718 .32796 Mtetra
.704 .761 .896 r
.76718 .32796 .76797 .32902 .76973 .32825 .76895 .32718 Mtetra
.561 .699 .933 r
.76895 .32718 .76973 .32825 .77155 .32809 .77076 .32699 Mtetra
.554 .69 .93 r
.77076 .32699 .77155 .32809 .77336 .3279 .77258 .32684 Mtetra
.679 .752 .906 r
.77258 .32684 .77336 .3279 .77513 .32711 .77436 .32618 Mtetra
.654 .773 .936 r
.77436 .32618 .77513 .32711 .77692 .32657 .77615 .32562 Mtetra
.597 .744 .947 r
.77615 .32562 .77692 .32657 .77878 .3268 .77796 .32528 Mtetra
.535 .602 .867 r
.77796 .32528 .77878 .3268 .78078 .3289 .7798 .3253 Mtetra
.493 .42 .703 r
.7798 .3253 .78078 .3289 .78328 .33689 .78169 .32599 Mtetra
.454 .307 .591 r
.78169 .32599 .78328 .33689 .80134 .53374 .78379 .32904 Mtetra
.084 .004 .458 r
.78379 .32904 .80134 .53374 .80358 .53712 .80229 .53036 Mtetra
.15 .132 .581 r
.80229 .53036 .80358 .53712 .80567 .53859 .80474 .53629 Mtetra
.2 .321 .764 r
.80474 .53629 .80567 .53859 .80769 .53918 .80687 .53808 Mtetra
.509 .684 .945 r
.80687 .53808 .80769 .53918 .80966 .53918 .80883 .53804 Mtetra
.667 .748 .911 r
.80883 .53804 .80966 .53918 .81159 .53861 .81075 .53739 Mtetra
.754 .764 .861 r
.81075 .53739 .81159 .53861 .81343 .53712 .81263 .53621 Mtetra
.845 .841 .84 r
.81263 .53621 .81343 .53712 .8151 .53348 .81445 .53442 Mtetra
0 0 0 r
.81445 .53442 .8151 .53348 .81633 .52495 .81623 .53215 Mtetra
.418 .172 .432 r
.81623 .53215 .81633 .52495 .80087 .32599 .81801 .52977 Mtetra
.55 .332 .537 r
.81801 .52977 .80087 .32599 .80252 .32365 .81988 .52851 Mtetra
.55 .333 .537 r
.81988 .52851 .80252 .32365 .80431 .32292 .82179 .52779 Mtetra
.551 .333 .537 r
.82179 .52779 .80431 .32292 .80615 .32264 .82373 .52733 Mtetra
.82373 .52733 .80615 .32264 .80793 .32172 .82566 .52671 Mtetra
.82566 .52671 .80793 .32172 .8098 .32185 .82764 .52655 Mtetra
.552 .334 .537 r
.82764 .52655 .8098 .32185 .81207 .32629 .82968 .52712 Mtetra
.554 .335 .537 r
.82968 .52712 .81207 .32629 .83221 .52532 .83179 .52849 Mtetra
.591 .245 .351 r
.83179 .52849 .83221 .52532 .83459 .52949 .83387 .52941 Mtetra
.195 0 0 r
.83387 .52941 .83459 .52949 .83673 .53107 .83591 .52985 Mtetra
.537 .674 .926 r
.83591 .52985 .83673 .53107 .83872 .53107 .8379 .52975 Mtetra
.68 .722 .881 r
.8379 .52975 .83872 .53107 .84064 .53023 .83983 .52901 Mtetra
.841 .79 .803 r
.83983 .52901 .84064 .53023 .84244 .52802 .84164 .52702 Mtetra
.98 .771 .549 r
.84164 .52702 .84244 .52802 .84366 .51984 .84292 .5194 Mtetra
.977 .674 .339 r
.84292 .5194 .84366 .51984 .82588 .31376 .82517 .31315 Mtetra
.981 .828 .618 r
.82517 .31315 .82588 .31376 .82732 .30925 .82659 .30846 Mtetra
.79 .854 .898 r
.82659 .30846 .82732 .30925 .82907 .30794 .82835 .30724 Mtetra
.614 .821 .98 r
.82835 .30724 .82907 .30794 .8309 .30746 .83018 .30675 Mtetra
.44 .736 .99 r
.83018 .30675 .8309 .30746 .83281 .30773 .83206 .30671 Mtetra
.511 .689 .948 r
.83206 .30671 .83281 .30773 .83484 .30923 .83394 .30666 Mtetra
.49 .471 .763 r
.83394 .30666 .83484 .30923 .83712 .31327 .83587 .30716 Mtetra
.452 .342 .638 r
.83587 .30716 .83712 .31327 .85902 .51304 .83794 .30897 Mtetra
.123 .036 .476 r
.83794 .30897 .85902 .51304 .86159 .51853 .85944 .50399 Mtetra
.141 .084 .527 r
.85944 .50399 .86159 .51853 .86379 .52043 .86281 .5175 Mtetra
.148 .239 .703 r
.86281 .5175 .86379 .52043 .86589 .5212 .86511 .52017 Mtetra
.337 .609 .949 r
.86511 .52017 .86589 .5212 .86794 .52142 .86717 .52057 Mtetra
.638 .808 .965 r
.86717 .52057 .86794 .52142 .86991 .52089 .86913 .52 Mtetra
.849 .852 .845 r
.86913 .52 .86991 .52089 .87176 .51924 .87097 .5182 Mtetra
.978 .779 .567 r
.87097 .5182 .87176 .51924 .87308 .5125 .8723 .51147 Mtetra
.976 .67 .325 r
.8723 .51147 .87308 .5125 .85347 .30645 .85272 .30534 Mtetra
.965 .781 .607 r
.85272 .30534 .85347 .30645 .85482 .30118 .85407 .30007 Mtetra
.759 .776 .868 r
.85407 .30007 .85482 .30118 .8566 .30005 .85585 .29893 Mtetra
.629 .725 .917 r
.85585 .29893 .8566 .30005 .85845 .2996 .8577 .29848 Mtetra
.552 .689 .93 r
.8577 .29848 .85845 .2996 .86034 .29945 .85959 .29833 Mtetra
.75 .773 .872 r
.85959 .29833 .86034 .29945 .86212 .29837 .86138 .29725 Mtetra
.682 .748 .901 r
.86138 .29725 .86212 .29837 .86396 .29767 .86321 .29655 Mtetra
.476 .648 .934 r
.86321 .29655 .86396 .29767 .86587 .29777 .86513 .29665 Mtetra
.754 .337 0 r
.86513 .29665 .86587 .29777 .86834 .3028 .86759 .30167 Mtetra
.971 .656 .295 r
.86759 .30167 .86834 .3028 .89294 .50811 .89216 .50704 Mtetra
.73 .299 0 r
.89216 .50704 .89294 .50811 .8955 .51281 .89473 .51175 Mtetra
.302 .576 .936 r
.89473 .51175 .8955 .51281 .89761 .51335 .89684 .51228 Mtetra
.648 .763 .933 r
.89684 .51228 .89761 .51335 .8996 .51276 .89882 .51169 Mtetra
.828 .821 .842 r
.89882 .51169 .8996 .51276 .90146 .51105 .90068 .50999 Mtetra
.908 .736 .657 r
.26333 .69408 .26438 .69493 .26633 .68938 .26529 .68853 Mtetra
.936 .686 .535 r
.26529 .68853 .26633 .68938 .28221 .4935 .28124 .4926 Mtetra
.907 .728 .647 r
.28124 .4926 .28221 .4935 .28409 .48775 .28312 .48685 Mtetra
.771 .76 .843 r
.28312 .48685 .28409 .48775 .28563 .48664 .28466 .48574 Mtetra
.633 .736 .922 r
.28466 .48574 .28563 .48664 .28712 .48625 .28615 .48536 Mtetra
.494 .689 .954 r
.28615 .48536 .28712 .48625 .28858 .48623 .28761 .48534 Mtetra
.742 .761 .868 r
.28761 .48534 .28858 .48623 .29011 .48529 .28914 .48446 Mtetra
.691 .764 .908 r
.28914 .48446 .29011 .48529 .29162 .48467 .29064 .48385 Mtetra
.469 .697 .967 r
.29064 .48385 .29162 .48467 .29308 .48474 .29211 .48386 Mtetra
.916 .52 .21 r
.29211 .48386 .29308 .48474 .29423 .48934 .29333 .48741 Mtetra
.94 .684 .522 r
.29333 .48741 .29423 .48934 .28217 .68482 .28133 .68113 Mtetra
.824 .542 0 r
.28133 .68113 .28217 .68482 .2834 .68953 .28246 .6873 Mtetra
.412 .446 .786 r
.28246 .6873 .2834 .68953 .28495 .68972 .28398 .68795 Mtetra
.604 .597 .817 r
.28398 .68795 .28495 .68972 .28656 .68902 .28556 .68769 Mtetra
.683 .684 .845 r
.28556 .68769 .28656 .68902 .2882 .6879 .28717 .68702 Mtetra
.468 .696 .967 r
.28717 .68702 .2882 .6879 .28977 .6878 .28873 .68703 Mtetra
.595 .768 .963 r
.28873 .68703 .28977 .6878 .29136 .6875 .29032 .68671 Mtetra
.765 .796 .878 r
.29032 .68671 .29136 .6875 .29299 .6865 .29195 .68567 Mtetra
.908 .744 .666 r
.29195 .68567 .29299 .6865 .29489 .68147 .29385 .68062 Mtetra
.939 .687 .529 r
.29385 .68062 .29489 .68147 .30924 .48529 .30828 .48438 Mtetra
.913 .727 .638 r
.30828 .48438 .30924 .48529 .31113 .47905 .31016 .47813 Mtetra
.794 .76 .823 r
.31016 .47813 .31113 .47905 .31269 .47771 .31173 .4768 Mtetra
.638 .735 .919 r
.31173 .4768 .31269 .47771 .3142 .47731 .31323 .4764 Mtetra
.496 .687 .952 r
.31323 .4764 .3142 .47731 .31568 .47729 .31472 .47638 Mtetra
.644 .74 .919 r
.31472 .47638 .31568 .47729 .3172 .47676 .31623 .47596 Mtetra
.67 .771 .926 r
.31623 .47596 .3172 .47676 .31871 .47619 .31774 .47543 Mtetra
.675 .782 .93 r
.31774 .47543 .31871 .47619 .32022 .47578 .31926 .47488 Mtetra
.756 .764 .86 r
.31926 .47488 .32022 .47578 .32172 .47562 .32081 .4739 Mtetra
.683 .627 .787 r
.32081 .4739 .32172 .47562 .32319 .47589 .32234 .47314 Mtetra
.583 .501 .728 r
.32234 .47314 .32319 .47589 .32461 .47701 .32384 .47298 Mtetra
.038 .078 .575 r
.32384 .47298 .32461 .47701 .32564 .48469 .32514 .47601 Mtetra
.953 .695 .507 r
.32514 .47601 .32564 .48469 .31573 .67537 .31494 .67059 Mtetra
.713 .488 0 r
.31494 .67059 .31573 .67537 .3171 .67883 .31609 .67774 Mtetra
.053 .415 .863 r
.31609 .67774 .3171 .67883 .31866 .67936 .31763 .67853 Mtetra
.638 .767 .941 r
.31763 .67853 .31866 .67936 .32027 .67896 .31924 .67808 Mtetra
.737 .777 .886 r
.31924 .67808 .32027 .67896 .32191 .67805 .32089 .67719 Mtetra
.521 .722 .965 r
.32089 .67719 .32191 .67805 .32355 .6771 .32248 .67708 Mtetra
.212 .735 .837 r
.32248 .67708 .32355 .6771 .32522 .67575 .32408 .67687 Mtetra
.011 0 0 r
.32408 .67687 .32522 .67575 .32694 .67347 .32572 .676 Mtetra
.762 .836 .378 r
.32572 .676 .32694 .67347 .32902 .66483 .32756 .67172 Mtetra
.953 .699 .514 r
.32756 .67172 .32902 .66483 .3413 .4729 .34015 .47545 Mtetra
.989 .865 .511 r
.34015 .47545 .3413 .4729 .34303 .46877 .34207 .46791 Mtetra
.829 .775 .8 r
.34207 .46791 .34303 .46877 .3446 .46743 .34366 .46621 Mtetra
.655 .684 .865 r
.34366 .46621 .3446 .46743 .34613 .46697 .34519 .46573 Mtetra
.54 .634 .893 r
.34519 .46573 .34613 .46697 .34764 .46686 .3467 .4657 Mtetra
.604 .676 .892 r
.3467 .4657 .34764 .46686 .34916 .46654 .34822 .46543 Mtetra
.636 .698 .89 r
.34822 .46543 .34916 .46654 .35069 .4661 .34975 .46504 Mtetra
.639 .709 .897 r
.34975 .46504 .35069 .4661 .35222 .46561 .35127 .46464 Mtetra
.654 .73 .905 r
.35127 .46464 .35222 .46561 .35376 .46501 .35281 .46417 Mtetra
.665 .763 .923 r
.35281 .46417 .35376 .46501 .35531 .46434 .35434 .46365 Mtetra
.669 .802 .946 r
.35434 .46365 .35531 .46434 .35685 .46367 .35588 .46311 Mtetra
.666 .835 .964 r
.35588 .46311 .35685 .46367 .3584 .46296 .35742 .46256 Mtetra
.653 .873 .981 r
.35742 .46256 .3584 .46296 .35994 .46232 .35896 .46199 Mtetra
.644 .889 .984 r
.35896 .46199 .35994 .46232 .36148 .46187 .36051 .46142 Mtetra
.666 .863 .974 r
.36051 .46142 .36148 .46187 .36299 .46201 .36205 .46084 Mtetra
.675 .698 .864 r
.36205 .46084 .36299 .46201 .36447 .46265 .3636 .46026 Mtetra
.638 .554 .743 r
.3636 .46026 .36447 .46265 .36594 .46358 .36514 .45969 Mtetra
.634 .494 .674 r
.36514 .45969 .36594 .46358 .36748 .46329 .3667 .45883 Mtetra
.619 .472 .66 r
.3667 .45883 .36748 .46329 .36904 .46243 .36826 .45808 Mtetra
.581 .449 .665 r
.36826 .45808 .36904 .46243 .37057 .4622 .36979 .45785 Mtetra
.298 .253 .638 r
.36979 .45785 .37057 .4622 .37185 .46733 .37121 .45996 Mtetra
.957 .694 .496 r
.37121 .45996 .37185 .46733 .36447 .66087 .36396 .64921 Mtetra
0 0 .287 r
.36396 .64921 .36447 .66087 .3659 .66497 .36498 .66225 Mtetra
.264 .316 .729 r
.36498 .66225 .3659 .66497 .36748 .66587 .36653 .66368 Mtetra
.616 .567 .776 r
.36653 .66368 .36748 .66587 .36911 .6656 .36817 .66331 Mtetra
.67 .587 .754 r
.36817 .66331 .36911 .6656 .37077 .66495 .36983 .66246 Mtetra
.621 .549 .751 r
.36983 .66246 .37077 .66495 .37242 .66439 .37148 .66202 Mtetra
.578 .533 .768 r
.37148 .66202 .37242 .66439 .37407 .66385 .37311 .6619 Mtetra
.582 .57 .806 r
.37311 .6619 .37407 .66385 .37572 .66314 .37474 .66175 Mtetra
.611 .655 .869 r
.37474 .66175 .37572 .66314 .3774 .66192 .37639 .66144 Mtetra
.591 .847 .993 r
.37639 .66144 .3774 .66192 .37911 .66022 .37803 .66101 Mtetra
.1 0 0 r
.37803 .66101 .37911 .66022 .38082 .65826 .37969 .66051 Mtetra
.455 .09 .256 r
.37969 .66051 .38082 .65826 .38249 .65735 .38133 .66028 Mtetra
.477 .142 .32 r
.38133 .66028 .38249 .65735 .38412 .6572 .38297 .66002 Mtetra
.387 .052 .27 r
.38297 .66002 .38412 .6572 .38579 .65648 .38464 .65923 Mtetra
0 0 0 r
.38464 .65923 .38579 .65648 .38762 .65154 .3864 .65628 Mtetra
.975 .823 .411 r
.3864 .65628 .38762 .65154 .39689 .45592 .38854 .64337 Mtetra
0 0 .277 r
.38854 .64337 .39689 .45592 .39864 .45057 .39763 .45151 Mtetra
.89 .97 .655 r
.39763 .45151 .39864 .45057 .40025 .44867 .39927 .44885 Mtetra
.452 .884 .841 r
.39927 .44885 .40025 .44867 .40182 .44803 .40084 .44819 Mtetra
0 0 0 r
.40084 .44819 .40182 .44803 .40337 .44779 .40239 .44803 Mtetra
.236 .747 .723 r
.40239 .44803 .40337 .44779 .40492 .44754 .40396 .44757 Mtetra
.651 .96 .931 r
.40396 .44757 .40492 .44754 .40648 .44719 .40553 .44674 Mtetra
.729 .876 .949 r
.40553 .44674 .40648 .44719 .40804 .44682 .40711 .44594 Mtetra
.69 .763 .907 r
.40711 .44594 .40804 .44682 .40961 .44633 .40868 .44531 Mtetra
.652 .723 .901 r
.40868 .44531 .40961 .44633 .41118 .44572 .41025 .44484 Mtetra
.639 .75 .929 r
.41025 .44484 .41118 .44572 .41275 .44509 .41181 .44441 Mtetra
.641 .801 .96 r
.41181 .44441 .41275 .44509 .41433 .44443 .41338 .44394 Mtetra
.641 .854 .981 r
.41338 .44394 .41433 .44443 .4159 .4438 .41495 .44342 Mtetra
.629 .879 .988 r
.41495 .44342 .4159 .4438 .41747 .44333 .41653 .44288 Mtetra
.643 .866 .983 r
.41653 .44288 .41747 .44333 .41902 .44333 .4181 .44234 Mtetra
.67 .735 .899 r
.4181 .44234 .41902 .44333 .42056 .44393 .41967 .44179 Mtetra
.642 .575 .765 r
.41967 .44179 .42056 .44393 .42209 .44485 .42125 .44124 Mtetra
.615 .49 .687 r
.42125 .44124 .42209 .44485 .42364 .44535 .42283 .44068 Mtetra
.603 .458 .657 r
.42283 .44068 .42364 .44535 .42521 .44492 .4244 .44013 Mtetra
.602 .455 .655 r
.4244 .44013 .42521 .44492 .4268 .44415 .42598 .43957 Mtetra
.603 .46 .659 r
.42598 .43957 .4268 .44415 .42838 .44342 .42756 .43902 Mtetra
.604 .464 .664 r
.42756 .43902 .42838 .44342 .42996 .44286 .42914 .43848 Mtetra
.42914 .43848 .42996 .44286 .43154 .44231 .43072 .43795 Mtetra
.604 .465 .665 r
.43072 .43795 .43154 .44231 .43313 .44177 .4323 .43742 Mtetra
.4323 .43742 .43313 .44177 .43471 .44125 .43388 .4369 Mtetra
.603 .464 .665 r
.43388 .4369 .43471 .44125 .43629 .44074 .43547 .43637 Mtetra
.43547 .43637 .43629 .44074 .43787 .44036 .43705 .43586 Mtetra
.601 .46 .662 r
.43705 .43586 .43787 .44036 .43945 .44007 .43863 .43535 Mtetra
.599 .455 .657 r
.43863 .43535 .43945 .44007 .44104 .43948 .44022 .43485 Mtetra
.599 .456 .659 r
.44022 .43485 .44104 .43948 .44265 .43808 .44181 .43435 Mtetra
.608 .483 .684 r
.44181 .43435 .44265 .43808 .44428 .43613 .44339 .43386 Mtetra
.631 .561 .757 r
.44339 .43386 .44428 .43613 .44589 .43448 .44498 .43336 Mtetra
.66 .71 .885 r
.44498 .43336 .44589 .43448 .44749 .43335 .44657 .43285 Mtetra
.646 .852 .979 r
.44657 .43285 .44749 .43335 .44909 .43276 .44816 .43231 Mtetra
.639 .866 .984 r
.44816 .43231 .44909 .43276 .45067 .43233 .44975 .43177 Mtetra
.651 .837 .972 r
.44975 .43177 .45067 .43233 .45226 .43197 .45134 .43124 Mtetra
.657 .795 .948 r
.45134 .43124 .45226 .43197 .45385 .43158 .45294 .43072 Mtetra
.661 .765 .927 r
.45294 .43072 .45385 .43158 .45544 .43119 .45453 .4302 Mtetra
.668 .737 .902 r
.45453 .4302 .45544 .43119 .45703 .43077 .45612 .42966 Mtetra
.673 .716 .881 r
.45612 .42966 .45703 .43077 .45863 .43027 .45772 .42908 Mtetra
.663 .699 .873 r
.45772 .42908 .45863 .43027 .46023 .42972 .45932 .42854 Mtetra
.637 .692 .885 r
.45932 .42854 .46023 .42972 .46182 .4291 .46091 .42813 Mtetra
.584 .715 .933 r
.46091 .42813 .46182 .4291 .46343 .42841 .46251 .42789 Mtetra
.495 .798 .999 r
.46251 .42789 .46343 .42841 .46503 .42772 .4641 .42768 Mtetra
.451 .876 .923 r
.4641 .42768 .46503 .42772 .46663 .42696 .4657 .4272 Mtetra
.559 .934 .835 r
.4657 .4272 .46663 .42696 .46824 .42614 .46731 .42629 Mtetra
.293 .789 .784 r
.46731 .42629 .46824 .42614 .46984 .42567 .46891 .42583 Mtetra
.653 .12 0 r
.46891 .42583 .46984 .42567 .47142 .42625 .47049 .42693 Mtetra
.93 .62 .434 r
.47049 .42693 .47142 .42625 .47296 .4299 .47187 .44034 Mtetra
.942 .668 .491 r
.47187 .44034 .47296 .4299 .47154 .6252 .47047 .63108 Mtetra
.654 .363 .466 r
.47047 .63108 .47154 .6252 .47315 .63093 .47213 .63363 Mtetra
.488 .143 .307 r
.47213 .63363 .47315 .63093 .47485 .63098 .47383 .63349 Mtetra
.384 .036 .246 r
.47383 .63349 .47485 .63098 .47656 .63013 .47555 .63278 Mtetra
.372 .032 .253 r
.47555 .63278 .47656 .63013 .47828 .62896 .47726 .63195 Mtetra
.449 .117 .31 r
.47726 .63195 .47828 .62896 .47999 .62818 .47898 .63146 Mtetra
.458 .136 .331 r
.47898 .63146 .47999 .62818 .48171 .62769 .48069 .63098 Mtetra
.457 .135 .331 r
.48069 .63098 .48171 .62769 .48341 .62793 .48241 .63047 Mtetra
.422 .073 .266 r
.48241 .63047 .48341 .62793 .4851 .62903 .48412 .62995 Mtetra
.164 0 0 r
.48412 .62995 .4851 .62903 .48681 .62985 .48584 .62943 Mtetra
.591 .87 .994 r
.48584 .62943 .48681 .62985 .48852 .63016 .48756 .62893 Mtetra
.639 .698 .888 r
.48756 .62893 .48852 .63016 .49023 .62978 .48928 .62847 Mtetra
.647 .688 .875 r
.48928 .62847 .49023 .62978 .49195 .62923 .491 .62798 Mtetra
.668 .704 .874 r
.491 .62798 .49195 .62923 .49368 .62869 .49272 .62737 Mtetra
.702 .706 .85 r
.49272 .62737 .49368 .62869 .4954 .62834 .49445 .62655 Mtetra
.688 .642 .798 r
.49445 .62655 .4954 .62834 .49712 .628 .49618 .6257 Mtetra
.661 .586 .76 r
.49618 .6257 .49712 .628 .49884 .62763 .4979 .62492 Mtetra
.624 .542 .741 r
.4979 .62492 .49884 .62763 .50057 .62717 .49963 .62441 Mtetra
.615 .533 .739 r
.49963 .62441 .50057 .62717 .5023 .62669 .50136 .62397 Mtetra
.614 .535 .742 r
.50136 .62397 .5023 .62669 .50403 .62619 .50308 .62354 Mtetra
.621 .543 .745 r
.50308 .62354 .50403 .62619 .50575 .62571 .50481 .62306 Mtetra
.622 .544 .745 r
.50481 .62306 .50575 .62571 .50749 .62521 .50654 .62257 Mtetra
.622 .544 .746 r
.50654 .62257 .50749 .62521 .50922 .62471 .50827 .62208 Mtetra
.623 .545 .746 r
.50827 .62208 .50922 .62471 .51095 .62421 .51001 .62158 Mtetra
.624 .546 .746 r
.51001 .62158 .51095 .62421 .51268 .62371 .51174 .62107 Mtetra
.51174 .62107 .51268 .62371 .51442 .6232 .51348 .62056 Mtetra
.51348 .62056 .51442 .6232 .51615 .62269 .51521 .62005 Mtetra
.625 .546 .746 r
.51521 .62005 .51615 .62269 .51789 .62218 .51695 .61953 Mtetra
.625 .546 .745 r
.51695 .61953 .51789 .62218 .51963 .62166 .51869 .61901 Mtetra
.51869 .61901 .51963 .62166 .52137 .62115 .52043 .61849 Mtetra
.625 .545 .744 r
.52043 .61849 .52137 .62115 .52311 .62063 .52217 .61797 Mtetra
.626 .545 .744 r
.52217 .61797 .52311 .62063 .52485 .62007 .52391 .61744 Mtetra
.626 .548 .746 r
.52391 .61744 .52485 .62007 .52659 .61944 .52565 .61691 Mtetra
.628 .555 .753 r
.52565 .61691 .52659 .61944 .52834 .6188 .52739 .61638 Mtetra
.63 .563 .761 r
.52739 .61638 .52834 .6188 .53008 .61817 .52914 .61585 Mtetra
.63 .57 .768 r
.52914 .61585 .53008 .61817 .53183 .61763 .53088 .61534 Mtetra
.63 .572 .771 r
.53088 .61534 .53183 .61763 .53357 .61712 .53263 .61483 Mtetra
.629 .572 .771 r
.53263 .61483 .53357 .61712 .53532 .61667 .53438 .61433 Mtetra
.627 .567 .768 r
.53438 .61433 .53532 .61667 .53707 .61629 .53613 .61384 Mtetra
.625 .559 .76 r
.53613 .61384 .53707 .61629 .53882 .61591 .53788 .61336 Mtetra
.623 .55 .752 r
.53788 .61336 .53882 .61591 .54057 .61552 .53963 .61287 Mtetra
.621 .544 .746 r
.53963 .61287 .54057 .61552 .54233 .61505 .54138 .61238 Mtetra
.621 .543 .745 r
.54138 .61238 .54233 .61505 .54408 .61456 .54313 .61189 Mtetra
.622 .543 .745 r
.54313 .61189 .54408 .61456 .54583 .61405 .54489 .61139 Mtetra
.622 .544 .746 r
.54489 .61139 .54583 .61405 .54759 .61355 .54664 .61089 Mtetra
.623 .545 .746 r
.54664 .61089 .54759 .61355 .54935 .61305 .5484 .61039 Mtetra
.5484 .61039 .54935 .61305 .55111 .61254 .55016 .60989 Mtetra
.55016 .60989 .55111 .61254 .55286 .61203 .55192 .60938 Mtetra
.624 .546 .746 r
.55192 .60938 .55286 .61203 .55463 .61152 .55368 .60886 Mtetra
.55368 .60886 .55463 .61152 .55639 .61101 .55544 .60835 Mtetra
.625 .546 .746 r
.55544 .60835 .55639 .61101 .55815 .61049 .5572 .60782 Mtetra
.625 .546 .745 r
.5572 .60782 .55815 .61049 .55991 .60996 .55897 .60729 Mtetra
.626 .546 .744 r
.55897 .60729 .55991 .60996 .56168 .60943 .56073 .60675 Mtetra
.633 .549 .743 r
.56073 .60675 .56168 .60943 .56344 .60891 .5625 .60615 Mtetra
.627 .542 .739 r
.5625 .60615 .56344 .60891 .56521 .60837 .56426 .60558 Mtetra
.618 .535 .739 r
.56426 .60558 .56521 .60837 .56698 .60781 .56603 .60511 Mtetra
.585 .521 .75 r
.56603 .60511 .56698 .60781 .56875 .60715 .5678 .60492 Mtetra
.582 .552 .787 r
.5678 .60492 .56875 .60715 .57051 .60648 .56958 .60476 Mtetra
.588 .608 .84 r
.56958 .60476 .57051 .60648 .57228 .60582 .57135 .60456 Mtetra
.636 .697 .89 r
.57135 .60456 .57228 .60582 .57406 .60539 .57313 .6041 Mtetra
.65 .697 .88 r
.57313 .6041 .57406 .60539 .57583 .6049 .5749 .60357 Mtetra
.655 .693 .873 r
.5749 .60357 .57583 .6049 .5776 .60422 .57668 .60302 Mtetra
.643 .71 .896 r
.57668 .60302 .5776 .60422 .57936 .60272 .57845 .60253 Mtetra
.478 .876 .961 r
.57845 .60253 .57936 .60272 .58112 .60082 .58023 .60205 Mtetra
.284 0 0 r
.58023 .60205 .58112 .60082 .58287 .59869 .58201 .60157 Mtetra
.448 .112 .302 r
.58201 .60157 .58287 .59869 .58464 .59775 .58379 .6011 Mtetra
.463 .142 .336 r
.58379 .6011 .58464 .59775 .58642 .59733 .58557 .60061 Mtetra
.459 .136 .331 r
.58557 .60061 .58642 .59733 .5882 .59713 .58736 .60011 Mtetra
.494 .158 .326 r
.58736 .60011 .5882 .59713 .59 .59732 .58915 .59997 Mtetra
.443 .098 .284 r
.58915 .59997 .59 .59732 .59178 .597 .59093 .59953 Mtetra
.32 0 .224 r
.59093 .59953 .59178 .597 .59355 .59564 .59271 .59843 Mtetra
0 0 0 r
.59271 .59843 .59355 .59564 .59511 .58439 .59441 .59377 Mtetra
.979 .702 .427 r
.59441 .59377 .59511 .58439 .59278 .38936 .59203 .39364 Mtetra
0 0 0 r
.59203 .39364 .59278 .38936 .59438 .38531 .59355 .38567 Mtetra
.735 .982 .761 r
.59355 .38567 .59438 .38531 .59604 .38408 .59521 .38411 Mtetra
.395 .852 .864 r
.59521 .38411 .59604 .38408 .59772 .38355 .59689 .38358 Mtetra
.053 .62 .72 r
.59689 .38358 .59772 .38355 .59941 .38331 .59858 .38348 Mtetra
.187 .714 .712 r
.59858 .38348 .59941 .38331 .60109 .38281 .60026 .38308 Mtetra
0 0 0 r
.60026 .38308 .60109 .38281 .60277 .38228 .60195 .38259 Mtetra
.60195 .38259 .60277 .38228 .60445 .38177 .60363 .38203 Mtetra
.428 .861 .755 r
.60363 .38203 .60445 .38177 .60614 .38135 .60531 .3812 Mtetra
.684 .957 .948 r
.60531 .3812 .60614 .38135 .60783 .38094 .60698 .38031 Mtetra
.73 .852 .938 r
.60698 .38031 .60783 .38094 .60951 .3805 .60866 .37946 Mtetra
.674 .741 .901 r
.60866 .37946 .60951 .3805 .6112 .3799 .61035 .37885 Mtetra
.652 .733 .909 r
.61035 .37885 .6112 .3799 .61288 .37922 .61203 .37835 Mtetra
.641 .768 .94 r
.61203 .37835 .61288 .37922 .61457 .37854 .61373 .37787 Mtetra
.65 .825 .967 r
.61373 .37787 .61457 .37854 .61625 .37781 .61542 .37732 Mtetra
.641 .87 .984 r
.61542 .37732 .61625 .37781 .61794 .37717 .61711 .37674 Mtetra
.637 .884 .986 r
.61711 .37674 .61794 .37717 .61963 .37671 .6188 .37613 Mtetra
.665 .855 .972 r
.6188 .37613 .61963 .37671 .62134 .37686 .62049 .37551 Mtetra
.672 .685 .854 r
.62049 .37551 .62134 .37686 .62307 .37743 .62218 .37488 Mtetra
.638 .552 .741 r
.62218 .37488 .62307 .37743 .62481 .37821 .62387 .37424 Mtetra
.637 .498 .676 r
.62387 .37424 .62481 .37821 .6265 .37761 .62556 .37329 Mtetra
.62 .479 .668 r
.62556 .37329 .6265 .37761 .62819 .3767 .62724 .37251 Mtetra
.583 .457 .675 r
.62724 .37251 .62819 .3767 .6299 .37642 .62895 .37227 Mtetra
.318 .283 .661 r
.62895 .37227 .6299 .37642 .63178 .38133 .63074 .37446 Mtetra
.977 .689 .401 r
.63074 .37446 .63178 .38133 .64023 .57983 .63872 .56053 Mtetra
0 0 .423 r
.63872 .56053 .64023 .57983 .64221 .58414 .64125 .58128 Mtetra
.314 .347 .736 r
.64125 .58128 .64221 .58414 .64406 .58461 .64314 .58279 Mtetra
.571 .59 .833 r
.64314 .58279 .64406 .58461 .64588 .58391 .64498 .58267 Mtetra
.676 .721 .883 r
.64498 .58267 .64588 .58391 .64767 .58276 .64679 .582 Mtetra
.669 .82 .956 r
.64679 .582 .64767 .58276 .64948 .5819 .64861 .58135 Mtetra
.66 .87 .978 r
.64861 .58135 .64948 .5819 .6513 .58122 .65042 .58067 Mtetra
.684 .879 .971 r
.65042 .58067 .6513 .58122 .65312 .58055 .65224 .57991 Mtetra
.687 .856 .963 r
.65224 .57991 .65312 .58055 .65493 .5799 .65406 .57917 Mtetra
.686 .833 .954 r
.65406 .57917 .65493 .5799 .65676 .57927 .65587 .57844 Mtetra
.684 .809 .942 r
.65587 .57844 .65676 .57927 .65858 .57868 .65769 .57774 Mtetra
.671 .78 .931 r
.65769 .57774 .65858 .57868 .6604 .57811 .65952 .5771 Mtetra
.659 .759 .924 r
.65952 .5771 .6604 .57811 .66223 .57759 .66134 .57652 Mtetra
.648 .742 .918 r
.66134 .57652 .66223 .57759 .66407 .57714 .66317 .57599 Mtetra
.635 .723 .911 r
.66317 .57599 .66407 .57714 .66591 .57682 .66501 .57551 Mtetra
.627 .691 .89 r
.66501 .57551 .66591 .57682 .66775 .57657 .66685 .57509 Mtetra
.621 .66 .867 r
.66685 .57509 .66775 .57657 .66959 .57631 .66869 .57469 Mtetra
.617 .638 .849 r
.66869 .57469 .66959 .57631 .67144 .5761 .67053 .57431 Mtetra
.614 .617 .83 r
.67053 .57431 .67144 .5761 .67329 .57579 .67237 .57395 Mtetra
.613 .61 .824 r
.67237 .57395 .67329 .57579 .67513 .57526 .67422 .57359 Mtetra
.614 .631 .844 r
.67422 .57359 .67513 .57526 .67693 .57401 .67606 .57323 Mtetra
.581 .788 .977 r
.67606 .57323 .67693 .57401 .67871 .57213 .67791 .57287 Mtetra
.19 0 0 r
.67791 .57287 .67871 .57213 .68047 .56989 .67976 .57249 Mtetra
.448 .1 .281 r
.67976 .57249 .68047 .56989 .68227 .56846 .68161 .57209 Mtetra
.478 .164 .354 r
.68161 .57209 .68227 .56846 .68411 .56801 .68346 .57167 Mtetra
.476 .163 .355 r
.68346 .57167 .68411 .56801 .68598 .56789 .68531 .57122 Mtetra
.464 .142 .335 r
.68531 .57122 .68598 .56789 .68783 .56762 .68716 .57073 Mtetra
.454 .126 .32 r
.68716 .57073 .68783 .56762 .68968 .56719 .68901 .57022 Mtetra
.449 .118 .312 r
.68901 .57022 .68968 .56719 .69153 .56674 .69085 .56968 Mtetra
.483 .146 .318 r
.69085 .56968 .69153 .56674 .69341 .56676 .69272 .56946 Mtetra
.473 .126 .297 r
.69272 .56946 .69341 .56676 .69528 .56669 .69459 .56921 Mtetra
.38 .035 .25 r
.69459 .56921 .69528 .56669 .69711 .56574 .69643 .56839 Mtetra
0 0 .085 r
.69643 .56839 .69711 .56574 .6987 .56022 .69815 .56524 Mtetra
.874 .721 .203 r
.69815 .56524 .6987 .56022 .69015 .35945 .69921 .54945 Mtetra
.007 0 .413 r
.69921 .54945 .69015 .35945 .69164 .35412 .69092 .3549 Mtetra
.79 .923 .545 r
.69092 .3549 .69164 .35412 .69331 .35218 .69255 .35224 Mtetra
.439 .877 .847 r
.69255 .35224 .69331 .35218 .69504 .35151 .69428 .35156 Mtetra
.102 .657 .734 r
.69428 .35156 .69504 .35151 .69679 .35124 .69604 .35137 Mtetra
.252 .761 .752 r
.69604 .35137 .69679 .35124 .69855 .35096 .69778 .35088 Mtetra
.621 .953 .925 r
.69778 .35088 .69855 .35096 .7003 .35058 .69951 .35001 Mtetra
.718 .879 .956 r
.69951 .35001 .7003 .35058 .70205 .3502 .70124 .34917 Mtetra
.682 .755 .907 r
.70124 .34917 .70205 .3502 .7038 .34976 .70298 .34852 Mtetra
.645 .698 .884 r
.70298 .34852 .7038 .34976 .70555 .34925 .70473 .34803 Mtetra
.637 .698 .89 r
.70473 .34803 .70555 .34925 .70729 .3487 .70648 .34757 Mtetra
.651 .723 .902 r
.70648 .34757 .70729 .3487 .70904 .34811 .70823 .34705 Mtetra
.669 .744 .907 r
.70823 .34705 .70904 .34811 .71078 .34749 .70997 .34645 Mtetra
.674 .75 .908 r
.70997 .34645 .71078 .34749 .71253 .34684 .71172 .34583 Mtetra
.731 .775 .888 r
.71172 .34583 .71253 .34684 .71425 .34585 .71345 .34491 Mtetra
.745 .796 .894 r
.71345 .34491 .71425 .34585 .71597 .34477 .71518 .34394 Mtetra
.62 .781 .958 r
.71518 .34394 .71597 .34477 .71772 .34422 .71694 .3435 Mtetra
0 .075 .559 r
.71694 .3435 .71772 .34422 .7196 .34565 .71882 .34513 Mtetra
.975 .675 .379 r
.71882 .34513 .7196 .34565 .72217 .35834 .73246 .53693 Mtetra
.581 .355 .538 r
.73246 .53693 .72217 .35834 .7363 .55532 .73547 .55465 Mtetra
.61 .089 0 r
.73547 .55465 .7363 .55532 .73837 .55775 .73752 .55684 Mtetra
.493 .718 .972 r
.73752 .55684 .73837 .55775 .74028 .55778 .73943 .55677 Mtetra
.751 .797 .889 r
.73943 .55677 .74028 .55778 .74213 .55671 .74128 .55568 Mtetra
.904 .805 .74 r
.74128 .55568 .74213 .55671 .74384 .55343 .74301 .55274 Mtetra
.983 .757 .52 r
.74301 .55274 .74384 .55343 .7333 .36298 .74427 .54257 Mtetra
0 0 .404 r
.74427 .54257 .7333 .36298 .73367 .3412 .73298 .34183 Mtetra
.919 .931 .561 r
.73298 .34183 .73367 .3412 .73528 .33836 .73455 .33837 Mtetra
.661 .972 .882 r
.73455 .33837 .73528 .33836 .73704 .3377 .73628 .33729 Mtetra
.585 .881 .992 r
.73628 .33729 .73704 .3377 .73883 .33758 .73805 .33675 Mtetra
.621 .782 .958 r
.73805 .33675 .73883 .33758 .74062 .33738 .73983 .33631 Mtetra
.665 .742 .908 r
.73983 .33631 .74062 .33738 .74239 .33674 .74159 .33572 Mtetra
.656 .75 .919 r
.74159 .33572 .74239 .33674 .74416 .3362 .74336 .33517 Mtetra
.707 .767 .899 r
.74336 .33517 .74416 .3362 .74594 .33587 .74512 .33438 Mtetra
.717 .692 .825 r
.74512 .33438 .74594 .33587 .74776 .33591 .74686 .3334 Mtetra
.622 .549 .751 r
.74686 .3334 .74776 .33591 .74962 .33662 .74864 .33291 Mtetra
.434 .378 .696 r
.74864 .33291 .74962 .33662 .75167 .33989 .75054 .33412 Mtetra
0 0 .305 r
.75054 .33412 .75167 .33989 .76797 .54024 .75315 .34513 Mtetra
.047 0 .443 r
.75315 .34513 .76797 .54024 .77032 .546 .76943 .54416 Mtetra
0 .086 .645 r
.76943 .54416 .77032 .546 .7724 .54777 .77157 .54683 Mtetra
.446 .689 .969 r
.77157 .54683 .7724 .54777 .77435 .54795 .77352 .54689 Mtetra
.728 .783 .896 r
.77352 .54689 .77435 .54795 .77624 .54719 .77539 .54593 Mtetra
.873 .779 .754 r
.77539 .54593 .77624 .54719 .77799 .54459 .77714 .54333 Mtetra
.966 .75 .559 r
.77714 .54333 .77799 .54459 .77912 .53377 .77847 .53515 Mtetra
.979 .682 .366 r
.77847 .53515 .77912 .53377 .76562 .33146 .76496 .33206 Mtetra
.949 .909 .533 r
.76496 .33206 .76562 .33146 .76718 .32796 .76648 .32796 Mtetra
.707 .985 .869 r
.76648 .32796 .76718 .32796 .76895 .32718 .76821 .32674 Mtetra
.629 .893 .987 r
.76821 .32674 .76895 .32718 .77076 .32699 .76999 .3261 Mtetra
.625 .77 .95 r
.76999 .3261 .77076 .32699 .77258 .32684 .77179 .32565 Mtetra
.659 .718 .892 r
.77179 .32565 .77258 .32684 .77436 .32618 .77358 .32508 Mtetra
.646 .731 .911 r
.77358 .32508 .77436 .32618 .77615 .32562 .77537 .32457 Mtetra
.68 .754 .908 r
.77537 .32457 .77615 .32562 .77796 .32528 .77715 .3239 Mtetra
.717 .71 .843 r
.77715 .3239 .77796 .32528 .7798 .3253 .77892 .32296 Mtetra
.629 .566 .764 r
.77892 .32296 .7798 .3253 .78169 .32599 .78071 .32244 Mtetra
.482 .415 .705 r
.78071 .32244 .78169 .32599 .78379 .32904 .78262 .32321 Mtetra
.012 .044 .547 r
.78262 .32321 .78379 .32904 .80229 .53036 .78499 .32963 Mtetra
.069 0 .454 r
.78499 .32963 .80229 .53036 .80474 .53629 .80368 .53225 Mtetra
.175 .205 .653 r
.80368 .53225 .80474 .53629 .80687 .53808 .80593 .53562 Mtetra
.579 .541 .776 r
.80593 .53562 .80687 .53808 .80883 .53804 .80789 .53546 Mtetra
.652 .574 .754 r
.80789 .53546 .80883 .53804 .81075 .53739 .80979 .53467 Mtetra
.652 .565 .744 r
.80979 .53467 .81075 .53739 .81263 .53621 .8117 .53383 Mtetra
.584 .55 .783 r
.8117 .53383 .81263 .53621 .81445 .53442 .81366 .53365 Mtetra
.507 .765 .989 r
.81366 .53365 .81445 .53442 .81623 .53215 .81562 .53345 Mtetra
.361 0 .055 r
.81562 .53345 .81623 .53215 .81801 .52977 .81758 .53314 Mtetra
.463 .142 .336 r
.81758 .53314 .81801 .52977 .81988 .52851 .81952 .53262 Mtetra
.475 .173 .372 r
.81952 .53262 .81988 .52851 .82179 .52779 .82145 .53203 Mtetra
.478 .178 .378 r
.82145 .53203 .82179 .52779 .82373 .52733 .82338 .53144 Mtetra
.482 .178 .374 r
.82338 .53144 .82373 .52733 .82566 .52671 .82533 .53093 Mtetra
.481 .18 .378 r
.82533 .53093 .82566 .52671 .82764 .52655 .82727 .53037 Mtetra
.462 .155 .358 r
.82727 .53037 .82764 .52655 .82968 .52712 .8292 .52971 Mtetra
.382 .043 .261 r
.8292 .52971 .82968 .52712 .83179 .52849 .83111 .52882 Mtetra
.314 .774 .636 r
.83111 .52882 .83179 .52849 .83387 .52941 .83302 .52788 Mtetra
.679 .688 .852 r
.83302 .52788 .83387 .52941 .83591 .52985 .83494 .52712 Mtetra
.577 .523 .758 r
.83494 .52712 .83591 .52985 .8379 .52975 .83693 .52698 Mtetra
.623 .547 .748 r
.83693 .52698 .8379 .52975 .83983 .52901 .83888 .52643 Mtetra
.737 .619 .728 r
.83888 .52643 .83983 .52901 .84164 .52702 .84071 .52463 Mtetra
.936 .704 .562 r
.84071 .52463 .84164 .52702 .84292 .5194 .8419 .51603 Mtetra
.976 .672 .349 r
.8419 .51603 .84292 .5194 .82517 .31315 .82442 .31218 Mtetra
.956 .8 .647 r
.82442 .31218 .82517 .31315 .82659 .30846 .82588 .30786 Mtetra
.771 .897 .932 r
.82588 .30786 .82659 .30846 .82835 .30724 .82765 .30676 Mtetra
.576 .867 .995 r
.82765 .30676 .82835 .30724 .83018 .30675 .82948 .30625 Mtetra
.515 .835 .999 r
.82948 .30625 .83018 .30675 .83206 .30671 .83133 .3059 Mtetra
.764 .843 .911 r
.83133 .3059 .83206 .30671 .83394 .30666 .83311 .30483 Mtetra
.659 .628 .808 r
.83311 .30483 .83394 .30666 .83587 .30716 .83492 .30416 Mtetra
.531 .47 .733 r
.83492 .30416 .83587 .30716 .83794 .30897 .83684 .30443 Mtetra
.046 .097 .593 r
.83684 .30443 .83794 .30897 .85944 .50399 .83922 .3094 Mtetra
.071 .001 .461 r
.83922 .3094 .85944 .50399 .86281 .5175 .86183 .51454 Mtetra
0 0 .562 r
.86183 .51454 .86281 .5175 .86511 .52017 .86432 .51916 Mtetra
.286 .58 .941 r
.86432 .51916 .86511 .52017 .86717 .52057 .8664 .51968 Mtetra
.652 .802 .955 r
.8664 .51968 .86717 .52057 .86913 .52 .86836 .51906 Mtetra
.857 .845 .832 r
.86836 .51906 .86913 .52 .87097 .5182 .87019 .51715 Mtetra
.978 .779 .568 r
.87019 .51715 .87097 .5182 .8723 .51147 .87152 .51043 Mtetra
.976 .67 .325 r
.87152 .51043 .8723 .51147 .85272 .30534 .85197 .30423 Mtetra
.965 .782 .606 r
.85197 .30423 .85272 .30534 .85407 .30007 .85332 .29895 Mtetra
.759 .777 .868 r
.85332 .29895 .85407 .30007 .85585 .29893 .8551 .29781 Mtetra
.629 .726 .917 r
.8551 .29781 .85585 .29893 .8577 .29848 .85696 .29736 Mtetra
.552 .689 .93 r
.85696 .29736 .8577 .29848 .85959 .29833 .85885 .29721 Mtetra
.75 .774 .872 r
.85885 .29721 .85959 .29833 .86138 .29725 .86064 .29613 Mtetra
.682 .748 .902 r
.86064 .29613 .86138 .29725 .86321 .29655 .86247 .29543 Mtetra
.476 .649 .934 r
.86247 .29543 .86321 .29655 .86513 .29665 .86439 .29553 Mtetra
.753 .337 0 r
.86439 .29553 .86513 .29665 .86759 .30167 .86685 .30054 Mtetra
.971 .656 .295 r
.86685 .30054 .86759 .30167 .89216 .50704 .89139 .50596 Mtetra
.731 .299 0 r
.89139 .50596 .89216 .50704 .89473 .51175 .89395 .51068 Mtetra
.302 .576 .936 r
.89395 .51068 .89473 .51175 .89684 .51228 .89606 .51121 Mtetra
.648 .763 .933 r
.89606 .51121 .89684 .51228 .89882 .51169 .89805 .51063 Mtetra
.828 .82 .842 r
.89805 .51063 .89882 .51169 .90068 .50999 .89991 .50892 Mtetra
.908 .736 .657 r
.26229 .69323 .26333 .69408 .26529 .68853 .26425 .68767 Mtetra
.936 .686 .535 r
.26425 .68767 .26529 .68853 .28124 .4926 .28026 .49169 Mtetra
.907 .727 .647 r
.28026 .49169 .28124 .4926 .28312 .48685 .28214 .48594 Mtetra
.77 .759 .844 r
.28214 .48594 .28312 .48685 .28466 .48574 .28368 .48484 Mtetra
.631 .735 .923 r
.28368 .48484 .28466 .48574 .28615 .48536 .28517 .48447 Mtetra
.49 .688 .955 r
.28517 .48447 .28615 .48536 .28761 .48534 .28664 .48446 Mtetra
.72 .758 .883 r
.28664 .48446 .28761 .48534 .28914 .48446 .28815 .4837 Mtetra
.686 .782 .924 r
.28815 .4837 .28914 .48446 .29064 .48385 .28966 .48312 Mtetra
.545 .751 .972 r
.28966 .48312 .29064 .48385 .29211 .48386 .29114 .48294 Mtetra
.57 .059 0 r
.29114 .48294 .29211 .48386 .29333 .48741 .2925 .48438 Mtetra
0 0 .23 r
.2925 .48438 .29333 .48741 .28133 .68113 .29369 .48848 Mtetra
0 0 .241 r
.29369 .48848 .28133 .68113 .28246 .6873 .28197 .67858 Mtetra
.218 .132 .539 r
.28197 .67858 .28246 .6873 .28398 .68795 .28319 .68344 Mtetra
.347 .287 .647 r
.28319 .68344 .28398 .68795 .28556 .68769 .28463 .68525 Mtetra
.397 .419 .766 r
.28463 .68525 .28556 .68769 .28717 .68702 .28614 .68603 Mtetra
.328 .603 .947 r
.28614 .68603 .28717 .68702 .28873 .68703 .28768 .68635 Mtetra
.589 .789 .975 r
.28768 .68635 .28873 .68703 .29032 .68671 .28927 .68602 Mtetra
.787 .814 .874 r
.28927 .68602 .29032 .68671 .29195 .68567 .29092 .68484 Mtetra
.909 .744 .665 r
.29092 .68484 .29195 .68567 .29385 .68062 .29282 .67977 Mtetra
.939 .687 .529 r
.29282 .67977 .29385 .68062 .30828 .48438 .30731 .48344 Mtetra
.912 .726 .638 r
.30731 .48344 .30828 .48438 .31016 .47813 .3092 .4772 Mtetra
.792 .758 .822 r
.3092 .4772 .31016 .47813 .31173 .4768 .31076 .47587 Mtetra
.636 .732 .918 r
.31076 .47587 .31173 .4768 .31323 .4764 .31227 .47547 Mtetra
.493 .682 .951 r
.31227 .47547 .31323 .4764 .31472 .47638 .31375 .47547 Mtetra
.635 .736 .921 r
.31375 .47547 .31472 .47638 .31623 .47596 .31526 .47508 Mtetra
.666 .751 .914 r
.31526 .47508 .31623 .47596 .31774 .47543 .31678 .47457 Mtetra
.68 .758 .911 r
.31678 .47457 .31774 .47543 .31926 .47488 .3183 .474 Mtetra
.775 .769 .847 r
.3183 .474 .31926 .47488 .32081 .4739 .31985 .47288 Mtetra
.736 .738 .853 r
.31985 .47288 .32081 .4739 .32234 .47314 .32139 .47197 Mtetra
.611 .676 .888 r
.32139 .47197 .32234 .47314 .32384 .47298 .3229 .47169 Mtetra
.832 .4 0 r
.3229 .47169 .32384 .47298 .32514 .47601 .32422 .4745 Mtetra
.943 .684 .515 r
.32422 .4745 .32514 .47601 .31494 .67059 .31397 .66883 Mtetra
.963 .638 .34 r
.31397 .66883 .31494 .67059 .31609 .67774 .31507 .67688 Mtetra
0 .353 .798 r
.31507 .67688 .31609 .67774 .31763 .67853 .3166 .6777 Mtetra
.646 .771 .939 r
.3166 .6777 .31763 .67853 .31924 .67808 .31822 .67722 Mtetra
.741 .781 .885 r
.31822 .67722 .31924 .67808 .32089 .67719 .31986 .6763 Mtetra
.462 .693 .967 r
.31986 .6763 .32089 .67719 .32248 .67708 .32145 .67633 Mtetra
.47 .732 .984 r
.32145 .67633 .32248 .67708 .32408 .67687 .32304 .67627 Mtetra
.714 .838 .941 r
.32304 .67627 .32408 .67687 .32572 .676 .32468 .67552 Mtetra
.924 .783 .687 r
.32468 .67552 .32572 .676 .32756 .67172 .32652 .67124 Mtetra
.944 .688 .521 r
.32652 .67124 .32756 .67172 .34015 .47545 .33922 .47402 Mtetra
.905 .704 .62 r
.33922 .47402 .34015 .47545 .34207 .46791 .34114 .46653 Mtetra
.791 .7 .763 r
.34114 .46653 .34207 .46791 .34366 .46621 .34274 .46481 Mtetra
.653 .655 .839 r
.34274 .46481 .34366 .46621 .34519 .46573 .34427 .46432 Mtetra
.548 .609 .865 r
.34427 .46432 .34519 .46573 .3467 .4657 .34577 .46429 Mtetra
.588 .627 .858 r
.34577 .46429 .3467 .4657 .34822 .46543 .34729 .46411 Mtetra
.606 .648 .865 r
.34729 .46411 .34822 .46543 .34975 .46504 .34881 .46385 Mtetra
.606 .67 .885 r
.34881 .46385 .34975 .46504 .35127 .46464 .35033 .46357 Mtetra
.637 .707 .897 r
.35033 .46357 .35127 .46464 .35281 .46417 .35186 .46318 Mtetra
.659 .728 .901 r
.35186 .46318 .35281 .46417 .35434 .46365 .3534 .46269 Mtetra
.669 .737 .901 r
.3534 .46269 .35434 .46365 .35588 .46311 .35493 .46216 Mtetra
.666 .739 .904 r
.35493 .46216 .35588 .46311 .35742 .46256 .35647 .46164 Mtetra
.669 .748 .909 r
.35647 .46164 .35742 .46256 .35896 .46199 .35801 .46111 Mtetra
.679 .758 .911 r
.35801 .46111 .35896 .46199 .36051 .46142 .35956 .46054 Mtetra
.703 .764 .899 r
.35956 .46054 .36051 .46142 .36205 .46084 .36111 .45986 Mtetra
.709 .745 .88 r
.36111 .45986 .36205 .46084 .3636 .46026 .36266 .45914 Mtetra
.7 .716 .861 r
.36266 .45914 .3636 .46026 .36514 .45969 .36421 .45843 Mtetra
.71 .696 .835 r
.36421 .45843 .36514 .45969 .3667 .45883 .36577 .45762 Mtetra
.693 .698 .85 r
.36577 .45762 .3667 .45883 .36826 .45808 .36732 .45692 Mtetra
.618 .683 .889 r
.36732 .45692 .36826 .45808 .36979 .45785 .36886 .4566 Mtetra
0 .31 .802 r
.36886 .4566 .36979 .45785 .37121 .45996 .37033 .45765 Mtetra
0 0 .291 r
.37033 .45765 .37121 .45996 .36396 .64921 .37169 .46107 Mtetra
0 0 .279 r
.37169 .46107 .36396 .64921 .36498 .66225 .36445 .65092 Mtetra
.333 .207 .554 r
.36445 .65092 .36498 .66225 .36653 .66368 .36584 .65583 Mtetra
.589 .417 .617 r
.36584 .65583 .36653 .66368 .36817 .66331 .36749 .65518 Mtetra
.597 .421 .614 r
.36749 .65518 .36817 .66331 .36983 .66246 .36915 .65429 Mtetra
.419 .289 .596 r
.36915 .65429 .36983 .66246 .37148 .66202 .37067 .65675 Mtetra
.298 .239 .62 r
.37067 .65675 .37148 .66202 .37311 .6619 .37218 .65931 Mtetra
.225 .301 .733 r
.37218 .65931 .37311 .6619 .37474 .66175 .37374 .66079 Mtetra
.28 .587 .945 r
.37374 .66079 .37474 .66175 .37639 .66144 .37535 .66118 Mtetra
.397 .817 .97 r
.37535 .66118 .37639 .66144 .37803 .66101 .377 .66094 Mtetra
.465 .879 .94 r
.377 .66094 .37803 .66101 .37969 .66051 .37865 .66046 Mtetra
.403 .849 .921 r
.37865 .66046 .37969 .66051 .38133 .66028 .3803 .66005 Mtetra
.528 .882 .983 r
.3803 .66005 .38133 .66028 .38297 .66002 .38195 .65959 Mtetra
.721 .886 .957 r
.38195 .65959 .38297 .66002 .38464 .65923 .38362 .65876 Mtetra
.88 .849 .809 r
.38362 .65876 .38464 .65923 .3864 .65628 .38534 .65668 Mtetra
.974 .871 .671 r
.38534 .65668 .3864 .65628 .38854 .64337 .38715 .65237 Mtetra
.963 .705 .496 r
.38715 .65237 .38854 .64337 .39763 .45151 .39566 .47689 Mtetra
0 0 .326 r
.39566 .47689 .39763 .45151 .39927 .44885 .39807 .45489 Mtetra
.512 .239 .438 r
.39807 .45489 .39927 .44885 .40084 .44819 .39963 .4545 Mtetra
.542 .269 .451 r
.39963 .4545 .40084 .44819 .40239 .44803 .40118 .4546 Mtetra
.265 .032 .362 r
.40118 .4546 .40239 .44803 .40396 .44757 .40285 .45119 Mtetra
0 0 .07 r
.40285 .45119 .40396 .44757 .40553 .44674 .40454 .44751 Mtetra
.882 .981 .692 r
.40454 .44751 .40553 .44674 .40711 .44594 .40617 .44512 Mtetra
.789 .791 .854 r
.40617 .44512 .40711 .44594 .40868 .44531 .40777 .4439 Mtetra
.64 .652 .846 r
.40777 .4439 .40868 .44531 .41025 .44484 .40933 .44347 Mtetra
.59 .637 .866 r
.40933 .44347 .41025 .44484 .41181 .44441 .41089 .44327 Mtetra
.607 .684 .897 r
.41089 .44327 .41181 .44441 .41338 .44394 .41245 .44298 Mtetra
.653 .737 .911 r
.41245 .44298 .41338 .44394 .41495 .44342 .41402 .44251 Mtetra
.667 .752 .914 r
.41402 .44251 .41495 .44342 .41653 .44288 .4156 .44198 Mtetra
.687 .759 .906 r
.4156 .44198 .41653 .44288 .4181 .44234 .41717 .44136 Mtetra
.7 .746 .887 r
.41717 .44136 .4181 .44234 .41967 .44179 .41875 .44067 Mtetra
.695 .718 .867 r
.41875 .44067 .41967 .44179 .42125 .44124 .42033 .43998 Mtetra
.679 .689 .853 r
.42033 .43998 .42125 .44124 .42283 .44068 .42191 .43935 Mtetra
.664 .673 .848 r
.42191 .43935 .42283 .44068 .4244 .44013 .42349 .43879 Mtetra
.66 .672 .85 r
.42349 .43879 .4244 .44013 .42598 .43957 .42507 .43826 Mtetra
.66 .676 .854 r
.42507 .43826 .42598 .43957 .42756 .43902 .42665 .43774 Mtetra
.662 .679 .856 r
.42665 .43774 .42756 .43902 .42914 .43848 .42823 .4372 Mtetra
.661 .68 .857 r
.42823 .4372 .42914 .43848 .43072 .43795 .42981 .43667 Mtetra
.661 .68 .858 r
.42981 .43667 .43072 .43795 .4323 .43742 .43139 .43614 Mtetra
.43139 .43614 .4323 .43742 .43388 .4369 .43297 .43561 Mtetra
.66 .679 .857 r
.43297 .43561 .43388 .4369 .43547 .43637 .43456 .43508 Mtetra
.661 .679 .856 r
.43456 .43508 .43547 .43637 .43705 .43586 .43614 .43454 Mtetra
.661 .675 .853 r
.43614 .43454 .43705 .43586 .43863 .43535 .43773 .43401 Mtetra
.656 .669 .851 r
.43773 .43401 .43863 .43535 .44022 .43485 .43931 .43349 Mtetra
.641 .661 .854 r
.43931 .43349 .44022 .43485 .44181 .43435 .4409 .43306 Mtetra
.623 .664 .869 r
.4409 .43306 .44181 .43435 .44339 .43386 .44248 .43271 Mtetra
.625 .691 .891 r
.44248 .43271 .44339 .43386 .44498 .43336 .44406 .43234 Mtetra
.655 .728 .903 r
.44406 .43234 .44498 .43336 .44657 .43285 .44565 .43185 Mtetra
.693 .744 .891 r
.44565 .43185 .44657 .43285 .44816 .43231 .44725 .43119 Mtetra
.695 .721 .87 r
.44725 .43119 .44816 .43231 .44975 .43177 .44884 .4305 Mtetra
.681 .692 .854 r
.44884 .4305 .44975 .43177 .45134 .43124 .45044 .42987 Mtetra
.661 .668 .846 r
.45044 .42987 .45134 .43124 .45294 .43072 .45203 .42932 Mtetra
.656 .662 .843 r
.45203 .42932 .45294 .43072 .45453 .4302 .45363 .42879 Mtetra
.669 .666 .838 r
.45363 .42879 .45453 .4302 .45612 .42966 .45522 .42819 Mtetra
.681 .663 .825 r
.45522 .42819 .45612 .42966 .45772 .42908 .45682 .4275 Mtetra
.646 .634 .824 r
.45682 .4275 .45772 .42908 .45932 .42854 .45842 .42701 Mtetra
.516 .579 .857 r
.45842 .42701 .45932 .42854 .46091 .42813 .46 .42712 Mtetra
0 .184 .692 r
.46 .42712 .46091 .42813 .46251 .42789 .46157 .42838 Mtetra
.806 .383 .241 r
.46157 .42838 .46251 .42789 .4641 .42768 .46311 .43078 Mtetra
.719 .393 .427 r
.46311 .43078 .4641 .42768 .4657 .4272 .46466 .43358 Mtetra
.476 .211 .432 r
.46466 .43358 .4657 .4272 .46731 .42629 .46627 .43259 Mtetra
.489 .221 .435 r
.46627 .43259 .46731 .42629 .46891 .42583 .46788 .43181 Mtetra
.734 .442 .486 r
.46788 .43181 .46891 .42583 .47049 .42693 .46939 .4372 Mtetra
.942 .668 .491 r
.46939 .4372 .47049 .42693 .47187 .44034 .46784 .62802 Mtetra
.558 .338 .538 r
.46784 .62802 .47187 .44034 .47047 .63108 .46947 .63178 Mtetra
.684 .22 .145 r
.46947 .63178 .47047 .63108 .47213 .63363 .47115 .63308 Mtetra
.516 .81 .999 r
.47115 .63308 .47213 .63363 .47383 .63349 .47286 .63281 Mtetra
.675 .826 .956 r
.47286 .63281 .47383 .63349 .47555 .63278 .47458 .63217 Mtetra
.676 .844 .964 r
.47458 .63217 .47555 .63278 .47726 .63195 .47629 .63151 Mtetra
.516 .839 .999 r
.47629 .63151 .47726 .63195 .47898 .63146 .478 .63118 Mtetra
.472 .852 .984 r
.478 .63118 .47898 .63146 .48069 .63098 .47972 .63082 Mtetra
.471 .873 .958 r
.47972 .63082 .48069 .63098 .48241 .63047 .48143 .63036 Mtetra
.554 .915 .956 r
.48143 .63036 .48241 .63047 .48412 .62995 .48315 .62973 Mtetra
.616 .918 .977 r
.48315 .62973 .48412 .62995 .48584 .62943 .48487 .62906 Mtetra
.616 .887 .989 r
.48487 .62906 .48584 .62943 .48756 .62893 .4866 .62847 Mtetra
.522 .836 .999 r
.4866 .62847 .48756 .62893 .48928 .62847 .48831 .62814 Mtetra
.57 .882 .992 r
.48831 .62814 .48928 .62847 .491 .62798 .49004 .62763 Mtetra
.759 .92 .943 r
.49004 .62763 .491 .62798 .49272 .62737 .49176 .62659 Mtetra
.878 .81 .778 r
.49176 .62659 .49272 .62737 .49445 .62655 .49351 .62424 Mtetra
.821 .66 .683 r
.49351 .62424 .49445 .62655 .49618 .6257 .49525 .62081 Mtetra
.764 .567 .631 r
.49525 .62081 .49618 .6257 .4979 .62492 .49701 .61625 Mtetra
.617 .433 .611 r
.49701 .61625 .4979 .62492 .49963 .62441 .49874 .61469 Mtetra
.554 .382 .602 r
.49874 .61469 .49963 .62441 .50136 .62397 .50046 .61481 Mtetra
.54 .374 .605 r
.50046 .61481 .50136 .62397 .50308 .62354 .50218 .61527 Mtetra
.577 .407 .614 r
.50218 .61527 .50308 .62354 .50481 .62306 .5039 .61485 Mtetra
.578 .407 .614 r
.5039 .61485 .50481 .62306 .50654 .62257 .50563 .61442 Mtetra
.579 .408 .615 r
.50563 .61442 .50654 .62257 .50827 .62208 .50736 .61398 Mtetra
.581 .41 .615 r
.50736 .61398 .50827 .62208 .51001 .62158 .50909 .61349 Mtetra
.581 .411 .615 r
.50909 .61349 .51001 .62158 .51174 .62107 .51082 .61297 Mtetra
.582 .411 .615 r
.51082 .61297 .51174 .62107 .51348 .62056 .51255 .61245 Mtetra
.51255 .61245 .51348 .62056 .51521 .62005 .51429 .61191 Mtetra
.583 .411 .615 r
.51429 .61191 .51521 .62005 .51695 .61953 .51602 .61136 Mtetra
.51602 .61136 .51695 .61953 .51869 .61901 .51775 .61081 Mtetra
.51775 .61081 .51869 .61901 .52043 .61849 .51949 .61025 Mtetra
.583 .411 .614 r
.51949 .61025 .52043 .61849 .52217 .61797 .52123 .60968 Mtetra
.52123 .60968 .52217 .61797 .52391 .61744 .52297 .6091 Mtetra
.584 .411 .613 r
.52297 .6091 .52391 .61744 .52565 .61691 .52471 .60851 Mtetra
.583 .41 .613 r
.52471 .60851 .52565 .61691 .52739 .61638 .52645 .60792 Mtetra
.583 .409 .612 r
.52645 .60792 .52739 .61638 .52914 .61585 .52819 .60734 Mtetra
.581 .408 .612 r
.52819 .60734 .52914 .61585 .53088 .61534 .52993 .60681 Mtetra
.58 .407 .612 r
.52993 .60681 .53088 .61534 .53263 .61483 .53167 .6063 Mtetra
.579 .406 .612 r
.53167 .6063 .53263 .61483 .53438 .61433 .53342 .60583 Mtetra
.577 .405 .612 r
.53342 .60583 .53438 .61433 .53613 .61384 .53516 .60538 Mtetra
.53516 .60538 .53613 .61384 .53788 .61336 .53691 .60496 Mtetra
.577 .406 .613 r
.53691 .60496 .53788 .61336 .53963 .61287 .53866 .60453 Mtetra
.578 .407 .613 r
.53866 .60453 .53963 .61287 .54138 .61238 .54041 .60408 Mtetra
.578 .407 .614 r
.54041 .60408 .54138 .61238 .54313 .61189 .54216 .60363 Mtetra
.579 .408 .614 r
.54216 .60363 .54313 .61189 .54489 .61139 .54391 .60317 Mtetra
.579 .408 .615 r
.54391 .60317 .54489 .61139 .54664 .61089 .54567 .6027 Mtetra
.58 .409 .615 r
.54567 .6027 .54664 .61089 .5484 .61039 .54742 .60222 Mtetra
.58 .41 .615 r
.54742 .60222 .5484 .61039 .55016 .60989 .54917 .60173 Mtetra
.54917 .60173 .55016 .60989 .55192 .60938 .55093 .60123 Mtetra
.581 .411 .615 r
.55093 .60123 .55192 .60938 .55368 .60886 .55269 .60072 Mtetra
.582 .411 .615 r
.55269 .60072 .55368 .60886 .55544 .60835 .55445 .60018 Mtetra
.584 .412 .615 r
.55445 .60018 .55544 .60835 .5572 .60782 .55621 .59959 Mtetra
.55621 .59959 .5572 .60782 .55897 .60729 .55797 .599 Mtetra
.584 .412 .614 r
.55797 .599 .55897 .60729 .56073 .60675 .55973 .59839 Mtetra
.623 .439 .613 r
.55973 .59839 .56073 .60675 .5625 .60615 .56148 .59672 Mtetra
.589 .409 .606 r
.56148 .59672 .5625 .60615 .56426 .60558 .56324 .59585 Mtetra
.523 .36 .601 r
.56324 .59585 .56426 .60558 .56603 .60511 .56502 .59678 Mtetra
.344 .24 .59 r
.56502 .59678 .56603 .60511 .5678 .60492 .56684 .60063 Mtetra
.318 .284 .663 r
.56684 .60063 .5678 .60492 .56958 .60476 .56864 .60281 Mtetra
.246 .384 .805 r
.56864 .60281 .56958 .60476 .57135 .60456 .57043 .60398 Mtetra
.491 .796 .999 r
.57043 .60398 .57135 .60456 .57313 .6041 .57221 .60376 Mtetra
.578 .888 .99 r
.57221 .60376 .57313 .6041 .5749 .60357 .57399 .60321 Mtetra
.641 .903 .983 r
.57399 .60321 .5749 .60357 .57668 .60302 .57576 .60252 Mtetra
.535 .836 .999 r
.57576 .60252 .57668 .60302 .57845 .60253 .57754 .60216 Mtetra
.477 .842 .992 r
.57754 .60216 .57845 .60253 .58023 .60205 .57932 .60182 Mtetra
.42 .842 .96 r
.57932 .60182 .58023 .60205 .58201 .60157 .58111 .60146 Mtetra
.406 .85 .922 r
.58111 .60146 .58201 .60157 .58379 .6011 .58289 .60102 Mtetra
.426 .863 .918 r
.58289 .60102 .58379 .6011 .58557 .60061 .58467 .60052 Mtetra
.471 .885 .933 r
.58467 .60052 .58557 .60061 .58736 .60011 .58645 .59996 Mtetra
.396 .84 .933 r
.58645 .59996 .58736 .60011 .58915 .59997 .58824 .59957 Mtetra
.612 .888 .99 r
.58824 .59957 .58915 .59997 .59093 .59953 .59002 .59897 Mtetra
.755 .882 .936 r
.59002 .59897 .59093 .59953 .59271 .59843 .5918 .59795 Mtetra
.929 .858 .749 r
.5918 .59795 .59271 .59843 .59441 .59377 .59354 .59504 Mtetra
.974 .882 .509 r
.59354 .59504 .59441 .59377 .59203 .39364 .59522 .58929 Mtetra
0 0 .383 r
.59522 .58929 .59203 .39364 .59355 .38567 .59287 .39284 Mtetra
.323 .094 .404 r
.59287 .39284 .59355 .38567 .59521 .38411 .59449 .38937 Mtetra
.5 .219 .419 r
.59449 .38937 .59521 .38411 .59689 .38358 .59617 .38889 Mtetra
.573 .283 .437 r
.59617 .38889 .59689 .38358 .59858 .38348 .59788 .38956 Mtetra
.578 .296 .451 r
.59788 .38956 .59858 .38348 .60026 .38308 .5996 .39039 Mtetra
.546 .278 .46 r
.5996 .39039 .60026 .38308 .60195 .38259 .6013 .39055 Mtetra
.451 .204 .447 r
.6013 .39055 .60195 .38259 .60363 .38203 .60296 .38872 Mtetra
.161 0 .347 r
.60296 .38872 .60363 .38203 .60531 .3812 .60454 .38374 Mtetra
0 0 .006 r
.60454 .38374 .60531 .3812 .60698 .38031 .60616 .38044 Mtetra
.914 .976 .776 r
.60616 .38044 .60698 .38031 .60866 .37946 .6078 .37824 Mtetra
.717 .723 .855 r
.6078 .37824 .60866 .37946 .61035 .37885 .60948 .37738 Mtetra
.627 .646 .85 r
.60948 .37738 .61035 .37885 .61203 .37835 .61117 .37698 Mtetra
.587 .646 .876 r
.61117 .37698 .61203 .37835 .61373 .37787 .61287 .37677 Mtetra
.636 .716 .905 r
.61287 .37677 .61373 .37787 .61542 .37732 .61457 .37633 Mtetra
.661 .749 .915 r
.61457 .37633 .61542 .37732 .61711 .37674 .61626 .37578 Mtetra
.676 .761 .915 r
.61626 .37578 .61711 .37674 .6188 .37613 .61795 .37517 Mtetra
.701 .767 .903 r
.61795 .37517 .6188 .37613 .62049 .37551 .61964 .37444 Mtetra
.706 .747 .884 r
.61964 .37444 .62049 .37551 .62218 .37488 .62133 .37367 Mtetra
.699 .719 .865 r
.62133 .37367 .62218 .37488 .62387 .37424 .62302 .37291 Mtetra
.713 .704 .84 r
.62302 .37291 .62387 .37424 .62556 .37329 .6247 .37202 Mtetra
.691 .706 .859 r
.6247 .37202 .62556 .37329 .62724 .37251 .62639 .37129 Mtetra
.617 .686 .892 r
.62639 .37129 .62724 .37251 .62895 .37227 .6281 .37094 Mtetra
.19 .433 .863 r
.6281 .37094 .62895 .37227 .63074 .37446 .62985 .37185 Mtetra
0 .104 .638 r
.62985 .37185 .63074 .37446 .63872 .56053 .63166 .37462 Mtetra
0 0 .403 r
.63166 .37462 .63872 .56053 .64125 .58128 .6398 .56383 Mtetra
.148 .068 .501 r
.6398 .56383 .64125 .58128 .64314 .58279 .6421 .57756 Mtetra
.336 .276 .641 r
.6421 .57756 .64314 .58279 .64498 .58267 .64403 .58016 Mtetra
.371 .408 .77 r
.64403 .58016 .64498 .58267 .64679 .582 .64591 .58122 Mtetra
.459 .732 .986 r
.64591 .58122 .64679 .582 .64861 .58135 .64774 .58118 Mtetra
.531 .904 .958 r
.64774 .58118 .64861 .58135 .65042 .58067 .64957 .58056 Mtetra
.639 .953 .94 r
.64957 .58056 .65042 .58067 .65224 .57991 .65138 .57966 Mtetra
.677 .943 .962 r
.65138 .57966 .65224 .57991 .65406 .57917 .65319 .57877 Mtetra
.701 .918 .968 r
.65319 .57877 .65406 .57917 .65587 .57844 .655 .57789 Mtetra
.717 .884 .958 r
.655 .57789 .65587 .57844 .65769 .57774 .65682 .577 Mtetra
.696 .835 .949 r
.65682 .577 .65769 .57774 .65952 .5771 .65864 .57624 Mtetra
.674 .799 .942 r
.65864 .57624 .65952 .5771 .66134 .57652 .66046 .57558 Mtetra
.659 .776 .936 r
.66046 .57558 .66134 .57652 .66317 .57599 .66229 .57499 Mtetra
.646 .759 .931 r
.66229 .57499 .66317 .57599 .66501 .57551 .66412 .57445 Mtetra
.635 .742 .926 r
.66412 .57445 .66501 .57551 .66685 .57509 .66596 .57397 Mtetra
.625 .727 .92 r
.66596 .57397 .66685 .57509 .66869 .57469 .6678 .57354 Mtetra
.624 .719 .915 r
.6678 .57354 .66869 .57469 .67053 .57431 .66964 .57312 Mtetra
.616 .706 .91 r
.66964 .57312 .67053 .57431 .67237 .57395 .67148 .57273 Mtetra
.597 .694 .911 r
.67148 .57273 .67237 .57395 .67422 .57359 .67333 .57242 Mtetra
.542 .68 .928 r
.67333 .57242 .67422 .57359 .67606 .57323 .67519 .57231 Mtetra
.483 .708 .969 r
.67519 .57231 .67606 .57323 .67791 .57287 .67705 .57228 Mtetra
.418 .762 .996 r
.67705 .57228 .67791 .57287 .67976 .57249 .67891 .57219 Mtetra
.388 .814 .967 r
.67891 .57219 .67976 .57249 .68161 .57209 .68077 .57192 Mtetra
.399 .841 .935 r
.68077 .57192 .68161 .57209 .68346 .57167 .68262 .57151 Mtetra
.439 .865 .937 r
.68262 .57151 .68346 .57167 .68531 .57122 .68447 .57102 Mtetra
.51 .894 .958 r
.68447 .57102 .68531 .57122 .68716 .57073 .68632 .57044 Mtetra
.577 .907 .979 r
.68632 .57044 .68716 .57073 .68901 .57022 .68816 .56981 Mtetra
.62 .896 .987 r
.68816 .56981 .68901 .57022 .69085 .56968 .69 .56915 Mtetra
.54 .836 .999 r
.69 .56915 .69085 .56968 .69272 .56946 .69186 .56877 Mtetra
.559 .802 .99 r
.69186 .56877 .69272 .56946 .69459 .56921 .69373 .56842 Mtetra
.68 .822 .951 r
.69373 .56842 .69459 .56921 .69643 .56839 .69557 .56771 Mtetra
.885 .865 .814 r
.69557 .56771 .69643 .56839 .69815 .56524 .69735 .56559 Mtetra
.988 .896 .599 r
.69735 .56559 .69815 .56524 .69921 .54945 .69899 .56097 Mtetra
.983 .698 .374 r
.69899 .56097 .69921 .54945 .69092 .3549 .69083 .3679 Mtetra
.182 .023 .417 r
.69083 .3679 .69092 .3549 .69255 .35224 .69209 .35798 Mtetra
.515 .237 .431 r
.69209 .35798 .69255 .35224 .69428 .35156 .69384 .35766 Mtetra
.542 .264 .442 r
.69384 .35766 .69428 .35156 .69604 .35137 .69562 .3578 Mtetra
.314 .085 .398 r
.69562 .3578 .69604 .35137 .69778 .35088 .69722 .3544 Mtetra
0 0 .203 r
.69722 .3544 .69778 .35088 .69951 .35001 .69879 .35068 Mtetra
.79 .938 .582 r
.69879 .35068 .69951 .35001 .70124 .34917 .70043 .34821 Mtetra
.786 .797 .862 r
.70043 .34821 .70124 .34917 .70298 .34852 .70213 .34696 Mtetra
.635 .644 .842 r
.70213 .34696 .70298 .34852 .70473 .34803 .70389 .3465 Mtetra
.589 .627 .857 r
.70389 .3465 .70473 .34803 .70648 .34757 .70565 .34628 Mtetra
.612 .676 .887 r
.70565 .34628 .70648 .34757 .70823 .34705 .70741 .34594 Mtetra
.66 .73 .902 r
.70741 .34594 .70823 .34705 .70997 .34645 .70916 .34538 Mtetra
.669 .742 .905 r
.70916 .34538 .70997 .34645 .71172 .34583 .71091 .34478 Mtetra
.729 .767 .884 r
.71091 .34478 .71172 .34583 .71345 .34491 .71264 .34387 Mtetra
.74 .772 .879 r
.71264 .34387 .71345 .34491 .71518 .34394 .71437 .3429 Mtetra
.626 .732 .924 r
.71437 .3429 .71518 .34394 .71694 .3435 .71613 .34248 Mtetra
0 .115 .642 r
.71613 .34248 .71694 .3435 .71882 .34513 .71803 .34425 Mtetra
.975 .676 .378 r
.71803 .34425 .71882 .34513 .73246 .53693 .73199 .54203 Mtetra
.852 .528 .438 r
.73199 .54203 .73246 .53693 .73547 .55465 .73465 .5542 Mtetra
.618 .072 0 r
.73465 .5542 .73547 .55465 .73752 .55684 .73669 .55612 Mtetra
.541 .79 .99 r
.73669 .55612 .73752 .55684 .73943 .55677 .73859 .55583 Mtetra
.765 .813 .891 r
.73859 .55583 .73943 .55677 .74128 .55568 .74043 .55467 Mtetra
.863 .811 .797 r
.74043 .55467 .74128 .55568 .74301 .55274 .74221 .55253 Mtetra
.976 .886 .673 r
.74221 .55253 .74301 .55274 .74427 .54257 .74388 .54868 Mtetra
0 0 .07 r
.74388 .54868 .74427 .54257 .73298 .34183 .74503 .53689 Mtetra
.049 0 .434 r
.74503 .53689 .73298 .34183 .73455 .33837 .73408 .34231 Mtetra
.08 0 .264 r
.73408 .34231 .73455 .33837 .73628 .33729 .73564 .33858 Mtetra
0 0 0 r
.73564 .33858 .73628 .33729 .73805 .33675 .7373 .33642 Mtetra
.803 .952 .916 r
.7373 .33642 .73805 .33675 .73983 .33631 .73902 .33514 Mtetra
.68 .729 .888 r
.73902 .33514 .73983 .33631 .74159 .33572 .74078 .33448 Mtetra
.637 .698 .889 r
.74078 .33448 .74159 .33572 .74336 .33517 .74256 .33401 Mtetra
.701 .74 .881 r
.74256 .33401 .74336 .33517 .74512 .33438 .74432 .33323 Mtetra
.758 .761 .855 r
.74432 .33323 .74512 .33438 .74686 .3334 .74605 .3321 Mtetra
.668 .701 .871 r
.74605 .3321 .74686 .3334 .74864 .33291 .74782 .33148 Mtetra
.165 .397 .841 r
.74782 .33148 .74864 .33291 .75054 .33412 .74971 .33261 Mtetra
.929 .572 .145 r
.74971 .33261 .75054 .33412 .75315 .34513 .7523 .34331 Mtetra
.976 .673 .358 r
.7523 .34331 .75315 .34513 .76943 .54416 .76862 .54354 Mtetra
.681 .171 0 r
.76862 .54354 .76943 .54416 .77157 .54683 .77075 .54613 Mtetra
.477 .768 .995 r
.77075 .54613 .77157 .54683 .77352 .54689 .77269 .54597 Mtetra
.75 .819 .906 r
.77269 .54597 .77352 .54689 .77539 .54593 .77456 .54491 Mtetra
.855 .816 .81 r
.77456 .54491 .77539 .54593 .77714 .54333 .77635 .5429 Mtetra
.966 .878 .696 r
.77635 .5429 .77714 .54333 .77847 .53515 .77804 .53934 Mtetra
0 0 0 r
.77804 .53934 .77847 .53515 .76496 .33206 .77929 .53012 Mtetra
.064 0 .442 r
.77929 .53012 .76496 .33206 .76648 .32796 .76609 .33209 Mtetra
.048 0 .267 r
.76609 .33209 .76648 .32796 .76821 .32674 .7676 .32787 Mtetra
0 0 0 r
.7676 .32787 .76821 .32674 .76999 .3261 .76925 .32552 Mtetra
.821 .899 .896 r
.76925 .32552 .76999 .3261 .77179 .32565 .77097 .32416 Mtetra
.653 .666 .85 r
.77097 .32416 .77179 .32565 .77358 .32508 .77276 .32359 Mtetra
.607 .644 .862 r
.77276 .32359 .77358 .32508 .77537 .32457 .77457 .32327 Mtetra
.639 .691 .883 r
.77457 .32327 .77537 .32457 .77715 .3239 .77637 .3228 Mtetra
.734 .764 .876 r
.77637 .3228 .77715 .3239 .77892 .32296 .77813 .32183 Mtetra
.686 .741 .893 r
.77813 .32183 .77892 .32296 .78071 .32244 .77991 .32113 Mtetra
.484 .612 .903 r
.77991 .32113 .78071 .32244 .78262 .32321 .78177 .32128 Mtetra
0 .166 .697 r
.78177 .32128 .78262 .32321 .78499 .32963 .78381 .32365 Mtetra
0 0 .454 r
.78381 .32365 .78499 .32963 .80368 .53225 .78638 .33242 Mtetra
.089 .008 .46 r
.78638 .33242 .80368 .53225 .80593 .53562 .80449 .52722 Mtetra
.57 .403 .616 r
.80449 .52722 .80593 .53562 .80789 .53546 .80644 .52695 Mtetra
.597 .421 .613 r
.80644 .52695 .80789 .53546 .80979 .53467 .80832 .52592 Mtetra
.517 .365 .613 r
.80832 .52592 .80979 .53467 .8117 .53383 .81039 .52698 Mtetra
.358 .273 .622 r
.81039 .52698 .8117 .53383 .81366 .53365 .81265 .53039 Mtetra
.313 .329 .717 r
.81265 .53039 .81366 .53365 .81562 .53345 .8148 .53228 Mtetra
.226 .506 .906 r
.8148 .53228 .81562 .53345 .81758 .53314 .81685 .53306 Mtetra
.282 .782 .861 r
.81685 .53306 .81758 .53314 .81952 .53262 .8188 .5327 Mtetra
.338 .817 .792 r
.8188 .5327 .81952 .53262 .82145 .53203 .82073 .53205 Mtetra
.399 .855 .84 r
.82073 .53205 .82145 .53203 .82338 .53144 .82266 .53137 Mtetra
.28 .781 .855 r
.82266 .53137 .82338 .53144 .82533 .53093 .82461 .53099 Mtetra
.304 .797 .792 r
.82461 .53099 .82533 .53093 .82727 .53037 .82655 .53042 Mtetra
.591 .948 .848 r
.82655 .53042 .82727 .53037 .8292 .52971 .82845 .52932 Mtetra
.926 .933 .791 r
.82845 .52932 .8292 .52971 .83111 .52882 .83022 .52688 Mtetra
.867 .715 .69 r
.83022 .52688 .83111 .52882 .83302 .52788 .83189 .52336 Mtetra
.78 .58 .63 r
.83189 .52336 .83302 .52788 .83494 .52712 .83348 .5189 Mtetra
.578 .41 .617 r
.83348 .5189 .83494 .52712 .83693 .52698 .83543 .51843 Mtetra
.567 .4 .615 r
.83543 .51843 .83693 .52698 .83888 .52643 .83741 .51824 Mtetra
.651 .459 .611 r
.83741 .51824 .83888 .52643 .84071 .52463 .83916 .51561 Mtetra
.973 .669 .366 r
.83916 .51561 .84071 .52463 .8419 .51603 .82221 .31561 Mtetra
.562 .345 .543 r
.82221 .31561 .8419 .51603 .82442 .31218 .82352 .30964 Mtetra
.797 .642 .69 r
.82352 .30964 .82442 .31218 .82588 .30786 .82513 .30689 Mtetra
.731 .796 .904 r
.82513 .30689 .82588 .30786 .82765 .30676 .82692 .30596 Mtetra
.641 .807 .963 r
.82692 .30596 .82765 .30676 .82948 .30625 .82875 .30542 Mtetra
.638 .794 .958 r
.82875 .30542 .82948 .30625 .83133 .3059 .83058 .30489 Mtetra
.782 .803 .87 r
.83058 .30489 .83133 .3059 .83311 .30483 .83234 .30364 Mtetra
.705 .744 .882 r
.83234 .30364 .83311 .30483 .83492 .30416 .83415 .30282 Mtetra
.493 .614 .9 r
.83415 .30282 .83492 .30416 .83684 .30443 .83605 .30295 Mtetra
.659 .27 0 r
.83605 .30295 .83684 .30443 .83922 .3094 .8384 .30758 Mtetra
.973 .661 .309 r
.8384 .30758 .83922 .3094 .86183 .51454 .86101 .51324 Mtetra
.72 .307 0 r
.86101 .51324 .86183 .51454 .86432 .51916 .86353 .51817 Mtetra
.278 .58 .942 r
.86353 .51817 .86432 .51916 .8664 .51968 .86561 .51869 Mtetra
.66 .782 .939 r
.86561 .51869 .8664 .51968 .86836 .51906 .86757 .51805 Mtetra
.853 .831 .824 r
.86757 .51805 .86836 .51906 .87019 .51715 .8694 .51612 Mtetra
.979 .78 .568 r
.8694 .51612 .87019 .51715 .87152 .51043 .87073 .50941 Mtetra
.976 .67 .325 r
.87073 .50941 .87152 .51043 .85197 .30423 .85123 .30313 Mtetra
.966 .782 .605 r
.85123 .30313 .85197 .30423 .85332 .29895 .85257 .29784 Mtetra
.76 .778 .868 r
.85257 .29784 .85332 .29895 .8551 .29781 .85436 .2967 Mtetra
.629 .727 .917 r
.85436 .2967 .8551 .29781 .85696 .29736 .85621 .29624 Mtetra
.553 .69 .93 r
.85621 .29624 .85696 .29736 .85885 .29721 .8581 .29608 Mtetra
.75 .774 .872 r
.8581 .29608 .85885 .29721 .86064 .29613 .85989 .295 Mtetra
.682 .749 .902 r
.85989 .295 .86064 .29613 .86247 .29543 .86172 .29431 Mtetra
.476 .649 .934 r
.86172 .29431 .86247 .29543 .86439 .29553 .86365 .2944 Mtetra
.753 .336 0 r
.86365 .2944 .86439 .29553 .86685 .30054 .8661 .29941 Mtetra
.971 .656 .295 r
.8661 .29941 .86685 .30054 .89139 .50596 .89061 .50489 Mtetra
.731 .299 0 r
.89061 .50489 .89139 .50596 .89395 .51068 .89317 .50961 Mtetra
.302 .576 .936 r
.89317 .50961 .89395 .51068 .89606 .51121 .89528 .51014 Mtetra
.648 .762 .933 r
.89528 .51014 .89606 .51121 .89805 .51063 .89727 .50956 Mtetra
.828 .82 .842 r
.89727 .50956 .89805 .51063 .89991 .50892 .89913 .50785 Mtetra
.908 .736 .657 r
.26124 .69237 .26229 .69323 .26425 .68767 .2632 .68681 Mtetra
.936 .686 .535 r
.2632 .68681 .26425 .68767 .28026 .49169 .27928 .49077 Mtetra
.907 .727 .647 r
.27928 .49077 .28026 .49169 .28214 .48594 .28117 .48503 Mtetra
.768 .759 .844 r
.28117 .48503 .28214 .48594 .28368 .48484 .28271 .48394 Mtetra
.629 .734 .923 r
.28271 .48394 .28368 .48484 .28517 .48447 .2842 .48357 Mtetra
.488 .687 .955 r
.2842 .48357 .28517 .48447 .28664 .48446 .28566 .48357 Mtetra
.691 .753 .899 r
.28566 .48357 .28664 .48446 .28815 .4837 .28717 .48296 Mtetra
.679 .784 .929 r
.28717 .48296 .28815 .4837 .28966 .48312 .28867 .4824 Mtetra
.627 .779 .954 r
.28867 .4824 .28966 .48312 .29114 .48294 .29017 .48201 Mtetra
.537 .698 .944 r
.29017 .48201 .29114 .48294 .2925 .48438 .29164 .48191 Mtetra
.493 .463 .753 r
.29164 .48191 .2925 .48438 .29369 .48848 .29308 .48229 Mtetra
.461 .333 .619 r
.29308 .48229 .29369 .48848 .28197 .67858 .29446 .48364 Mtetra
.52 .311 .536 r
.29446 .48364 .28197 .67858 .28319 .68344 .29492 .49818 Mtetra
0 0 .239 r
.29492 .49818 .28319 .68344 .28463 .68525 .28375 .68203 Mtetra
0 0 .533 r
.28375 .68203 .28463 .68525 .28614 .68603 .28511 .68503 Mtetra
.108 .473 .894 r
.28511 .68503 .28614 .68603 .28768 .68635 .28663 .68567 Mtetra
.594 .791 .974 r
.28663 .68567 .28768 .68635 .28927 .68602 .28822 .68532 Mtetra
.803 .812 .859 r
.28822 .68532 .28927 .68602 .29092 .68484 .28988 .684 Mtetra
.909 .744 .665 r
.28988 .684 .29092 .68484 .29282 .67977 .29179 .67892 Mtetra
.939 .687 .529 r
.29179 .67892 .29282 .67977 .30731 .48344 .30634 .48251 Mtetra
.912 .727 .638 r
.30634 .48251 .30731 .48344 .3092 .4772 .30823 .47626 Mtetra
.792 .759 .823 r
.30823 .47626 .3092 .4772 .31076 .47587 .3098 .47494 Mtetra
.635 .731 .918 r
.3098 .47494 .31076 .47587 .31227 .47547 .31131 .47455 Mtetra
.49 .68 .95 r
.31131 .47455 .31227 .47547 .31375 .47547 .31279 .47455 Mtetra
.633 .734 .92 r
.31279 .47455 .31375 .47547 .31526 .47508 .31429 .47417 Mtetra
.663 .743 .91 r
.31429 .47417 .31526 .47508 .31678 .47457 .31581 .47367 Mtetra
.674 .749 .907 r
.31581 .47367 .31678 .47457 .3183 .474 .31733 .47312 Mtetra
.769 .768 .852 r
.31733 .47312 .3183 .474 .31985 .47288 .31888 .47204 Mtetra
.739 .776 .882 r
.31888 .47204 .31985 .47288 .32139 .47197 .32042 .47119 Mtetra
.575 .749 .959 r
.32042 .47119 .32139 .47197 .3229 .47169 .32193 .47095 Mtetra
.888 .461 .139 r
.32193 .47095 .3229 .47169 .32422 .4745 .32324 .47389 Mtetra
.942 .683 .516 r
.32324 .47389 .32422 .4745 .31397 .66883 .3129 .66868 Mtetra
.922 .597 .409 r
.3129 .66868 .31397 .66883 .31507 .67688 .31403 .6761 Mtetra
0 .362 .794 r
.31403 .6761 .31507 .67688 .3166 .6777 .31557 .67686 Mtetra
.652 .772 .937 r
.31557 .67686 .3166 .6777 .31822 .67722 .31719 .67637 Mtetra
.746 .783 .884 r
.31719 .67637 .31822 .67722 .31986 .6763 .31884 .67542 Mtetra
.496 .708 .965 r
.31884 .67542 .31986 .6763 .32145 .67633 .32043 .67537 Mtetra
.539 .708 .949 r
.32043 .67537 .32145 .67633 .32304 .67627 .32203 .67525 Mtetra
.719 .746 .874 r
.32203 .67525 .32304 .67627 .32468 .67552 .32367 .67442 Mtetra
.893 .734 .677 r
.32367 .67442 .32468 .67552 .32652 .67124 .32552 .66997 Mtetra
.943 .687 .522 r
.32552 .66997 .32652 .67124 .33922 .47402 .33829 .47255 Mtetra
.9 .702 .626 r
.33829 .47255 .33922 .47402 .34114 .46653 .34019 .46554 Mtetra
.817 .752 .792 r
.34019 .46554 .34114 .46653 .34274 .46481 .34178 .46386 Mtetra
.659 .735 .905 r
.34178 .46386 .34274 .46481 .34427 .46432 .34331 .46337 Mtetra
.514 .685 .944 r
.34331 .46337 .34427 .46432 .34577 .46429 .34482 .46332 Mtetra
.577 .706 .931 r
.34482 .46332 .34577 .46429 .34729 .46411 .34634 .46312 Mtetra
.606 .712 .919 r
.34634 .46312 .34729 .46411 .34881 .46385 .34786 .46283 Mtetra
.608 .707 .915 r
.34786 .46283 .34881 .46385 .35033 .46357 .34938 .46254 Mtetra
.635 .712 .902 r
.34938 .46254 .35033 .46357 .35186 .46318 .35091 .46215 Mtetra
.653 .718 .896 r
.35091 .46215 .35186 .46318 .3534 .46269 .35245 .46168 Mtetra
.661 .726 .897 r
.35245 .46168 .3534 .46269 .35493 .46216 .35399 .46118 Mtetra
.66 .732 .903 r
.35399 .46118 .35493 .46216 .35647 .46164 .35552 .46069 Mtetra
.663 .738 .906 r
.35552 .46069 .35647 .46164 .35801 .46111 .35706 .46018 Mtetra
.671 .746 .906 r
.35706 .46018 .35801 .46111 .35956 .46054 .35861 .45964 Mtetra
.689 .757 .903 r
.35861 .45964 .35956 .46054 .36111 .45986 .36015 .45903 Mtetra
.699 .773 .909 r
.36015 .45903 .36111 .45986 .36266 .45914 .3617 .45837 Mtetra
.699 .788 .92 r
.3617 .45837 .36266 .45914 .36421 .45843 .36325 .45772 Mtetra
.707 .803 .925 r
.36325 .45772 .36421 .45843 .36577 .45762 .3648 .45703 Mtetra
.688 .832 .952 r
.3648 .45703 .36577 .45762 .36732 .45692 .36635 .4564 Mtetra
.619 .836 .983 r
.36635 .4564 .36732 .45692 .36886 .4566 .3679 .45596 Mtetra
.317 .679 .977 r
.3679 .45596 .36886 .4566 .37033 .45765 .36941 .45611 Mtetra
.31 .463 .851 r
.36941 .45611 .37033 .45765 .37169 .46107 .3709 .45678 Mtetra
.458 .366 .663 r
.3709 .45678 .37169 .46107 .36445 .65092 .37238 .45778 Mtetra
.552 .338 .543 r
.37238 .45778 .36445 .65092 .36584 .65583 .37392 .4576 Mtetra
.554 .339 .543 r
.37392 .4576 .36584 .65583 .36749 .65518 .37549 .45674 Mtetra
.552 .338 .543 r
.37549 .45674 .36749 .65518 .36915 .65429 .37703 .45649 Mtetra
.542 .329 .541 r
.37703 .45649 .36915 .65429 .37067 .65675 .37834 .46144 Mtetra
0 0 .292 r
.37834 .46144 .37067 .65675 .37218 .65931 .37131 .65525 Mtetra
0 0 .479 r
.37131 .65525 .37218 .65931 .37374 .66079 .37276 .65938 Mtetra
.122 .39 .844 r
.37276 .65938 .37374 .66079 .37535 .66118 .37435 .66033 Mtetra
.573 .749 .961 r
.37435 .66033 .37535 .66118 .377 .66094 .37599 .66008 Mtetra
.686 .778 .921 r
.37599 .66008 .377 .66094 .37865 .66046 .37765 .65943 Mtetra
.672 .741 .902 r
.37765 .65943 .37865 .66046 .3803 .66005 .37931 .65884 Mtetra
.661 .704 .879 r
.37931 .65884 .3803 .66005 .38195 .65959 .38097 .6583 Mtetra
.691 .701 .854 r
.38097 .6583 .38195 .65959 .38362 .65876 .38263 .65758 Mtetra
.762 .734 .827 r
.38263 .65758 .38362 .65876 .38534 .65668 .38432 .65635 Mtetra
.868 .888 .847 r
.38432 .65635 .38534 .65668 .38715 .65237 .38603 .6546 Mtetra
0 0 0 r
.38603 .6546 .38715 .65237 .39566 .47689 .38775 .65255 Mtetra
.549 .331 .536 r
.38775 .65255 .39566 .47689 .39807 .45489 .38943 .65153 Mtetra
.551 .333 .537 r
.38943 .65153 .39807 .45489 .39963 .4545 .39107 .65142 Mtetra
.55 .332 .537 r
.39107 .65142 .39963 .4545 .40118 .4546 .39274 .65076 Mtetra
.543 .326 .535 r
.39274 .65076 .40118 .4546 .40285 .45119 .39456 .64606 Mtetra
0 0 .29 r
.39456 .64606 .40285 .45119 .40454 .44751 .40347 .4502 Mtetra
.849 .842 .376 r
.40347 .4502 .40454 .44751 .40617 .44512 .40522 .44476 Mtetra
.885 .87 .818 r
.40522 .44476 .40617 .44512 .40777 .4439 .40684 .44285 Mtetra
.665 .722 .892 r
.40684 .44285 .40777 .4439 .40933 .44347 .40841 .44233 Mtetra
.562 .666 .907 r
.40841 .44233 .40933 .44347 .41089 .44327 .40996 .44219 Mtetra
.583 .689 .914 r
.40996 .44219 .41089 .44327 .41245 .44298 .41153 .44198 Mtetra
.648 .728 .907 r
.41153 .44198 .41245 .44298 .41402 .44251 .41309 .44153 Mtetra
.658 .734 .906 r
.41309 .44153 .41402 .44251 .4156 .44198 .41467 .44103 Mtetra
.674 .747 .905 r
.41467 .44103 .4156 .44198 .41717 .44136 .41624 .44047 Mtetra
.687 .763 .909 r
.41624 .44047 .41717 .44136 .41875 .44067 .41782 .43985 Mtetra
.69 .779 .919 r
.41782 .43985 .41875 .44067 .42033 .43998 .4194 .43922 Mtetra
.679 .792 .934 r
.4194 .43922 .42033 .43998 .42191 .43935 .42098 .43863 Mtetra
.664 .799 .947 r
.42098 .43863 .42191 .43935 .42349 .43879 .42256 .4381 Mtetra
.659 .802 .952 r
.42256 .4381 .42349 .43879 .42507 .43826 .42413 .43757 Mtetra
.659 .804 .953 r
.42413 .43757 .42507 .43826 .42665 .43774 .42571 .43705 Mtetra
.661 .806 .953 r
.42571 .43705 .42665 .43774 .42823 .4372 .42729 .43652 Mtetra
.661 .807 .953 r
.42729 .43652 .42823 .4372 .42981 .43667 .42888 .43598 Mtetra
.42888 .43598 .42981 .43667 .43139 .43614 .43046 .43545 Mtetra
.662 .807 .953 r
.43046 .43545 .43139 .43614 .43297 .43561 .43204 .43491 Mtetra
.662 .805 .952 r
.43204 .43491 .43297 .43561 .43456 .43508 .43363 .43438 Mtetra
.665 .804 .949 r
.43363 .43438 .43456 .43508 .43614 .43454 .43521 .43383 Mtetra
.667 .802 .947 r
.43521 .43383 .43614 .43454 .43773 .43401 .4368 .43328 Mtetra
.662 .798 .947 r
.4368 .43328 .43773 .43401 .43931 .43349 .43839 .43275 Mtetra
.646 .789 .95 r
.43839 .43275 .43931 .43349 .4409 .43306 .43997 .43227 Mtetra
.629 .774 .95 r
.43997 .43227 .4409 .43306 .44248 .43271 .44156 .43185 Mtetra
.637 .76 .937 r
.44156 .43185 .44248 .43271 .44406 .43234 .44314 .43142 Mtetra
.665 .752 .915 r
.44314 .43142 .44406 .43234 .44565 .43185 .44474 .43089 Mtetra
.693 .751 .896 r
.44474 .43089 .44565 .43185 .44725 .43119 .44633 .43023 Mtetra
.697 .753 .895 r
.44633 .43023 .44725 .43119 .44884 .4305 .44793 .42956 Mtetra
.689 .753 .9 r
.44793 .42956 .44884 .4305 .45044 .42987 .44952 .42892 Mtetra
.674 .749 .907 r
.44952 .42892 .45044 .42987 .45203 .42932 .45112 .42835 Mtetra
.668 .743 .907 r
.45112 .42835 .45203 .42932 .45363 .42879 .45271 .42781 Mtetra
.694 .747 .892 r
.45271 .42781 .45363 .42879 .45522 .42819 .45431 .42714 Mtetra
.714 .74 .871 r
.45431 .42714 .45522 .42819 .45682 .4275 .45591 .42635 Mtetra
.644 .699 .886 r
.45591 .42635 .45682 .4275 .45842 .42701 .45751 .42591 Mtetra
.209 .494 .901 r
.45751 .42591 .45842 .42701 .46 .42712 .45908 .42654 Mtetra
.898 .482 .168 r
.45908 .42654 .46 .42712 .46157 .42838 .4606 .43025 Mtetra
.954 .681 .482 r
.4606 .43025 .46157 .42838 .46311 .43078 .45843 .62556 Mtetra
.56 .34 .538 r
.45843 .62556 .46311 .43078 .46466 .43358 .46002 .63095 Mtetra
.551 .332 .537 r
.46002 .63095 .46466 .43358 .46627 .43259 .46171 .63079 Mtetra
.55 .332 .536 r
.46171 .63079 .46627 .43259 .46788 .43181 .46343 .62995 Mtetra
.551 .332 .537 r
.46343 .62995 .46788 .43181 .46939 .4372 .46513 .62973 Mtetra
.553 .334 .537 r
.46513 .62973 .46939 .4372 .46784 .62802 .46681 .63083 Mtetra
.594 .252 .358 r
.46681 .63083 .46784 .62802 .46947 .63178 .46849 .63163 Mtetra
0 .487 .703 r
.46849 .63163 .46947 .63178 .47115 .63308 .47019 .63189 Mtetra
.628 .7 .897 r
.47019 .63189 .47115 .63308 .47286 .63281 .4719 .63148 Mtetra
.66 .689 .866 r
.4719 .63148 .47286 .63281 .47458 .63217 .47362 .63092 Mtetra
.657 .7 .878 r
.47362 .63092 .47458 .63217 .47629 .63151 .47533 .63037 Mtetra
.613 .705 .91 r
.47533 .63037 .47629 .63151 .478 .63118 .47704 .63002 Mtetra
.616 .704 .907 r
.47704 .63002 .478 .63118 .47972 .63082 .47876 .62966 Mtetra
.634 .71 .902 r
.47876 .62966 .47972 .63082 .48143 .63036 .48047 .62923 Mtetra
.664 .725 .895 r
.48047 .62923 .48143 .63036 .48315 .62973 .48219 .62866 Mtetra
.671 .739 .901 r
.48219 .62866 .48315 .62973 .48487 .62906 .48391 .62805 Mtetra
.645 .745 .922 r
.48391 .62805 .48487 .62906 .4866 .62847 .48563 .62756 Mtetra
.552 .733 .959 r
.48563 .62756 .4866 .62847 .48831 .62814 .48735 .62737 Mtetra
.647 .799 .956 r
.48735 .62737 .48831 .62814 .49004 .62763 .48907 .62684 Mtetra
.816 .819 .852 r
.48907 .62684 .49004 .62763 .49176 .62659 .49081 .62536 Mtetra
.905 .741 .668 r
.49081 .62536 .49176 .62659 .49351 .62424 .49257 .62078 Mtetra
.957 .687 .483 r
.49257 .62078 .49351 .62424 .49525 .62081 .49602 .42571 Mtetra
.569 .351 .545 r
.49602 .42571 .49525 .62081 .49701 .61625 .49772 .41671 Mtetra
.554 .339 .543 r
.49772 .41671 .49701 .61625 .49874 .61469 .49935 .41554 Mtetra
.552 .338 .543 r
.49935 .41554 .49874 .61469 .50046 .61481 .50097 .41528 Mtetra
.552 .337 .543 r
.50097 .41528 .50046 .61481 .50218 .61527 .5026 .41535 Mtetra
.553 .338 .543 r
.5026 .41535 .50218 .61527 .5039 .61485 .50422 .41485 Mtetra
.50422 .41485 .5039 .61485 .50563 .61442 .50585 .41435 Mtetra
.50585 .41435 .50563 .61442 .50736 .61398 .50748 .41385 Mtetra
.50748 .41385 .50736 .61398 .50909 .61349 .50911 .41332 Mtetra
.50911 .41332 .50909 .61349 .51082 .61297 .51074 .41278 Mtetra
.51074 .41278 .51082 .61297 .51255 .61245 .51237 .41223 Mtetra
.51237 .41223 .51255 .61245 .51429 .61191 .51401 .41168 Mtetra
.51401 .41168 .51429 .61191 .51602 .61136 .51564 .41112 Mtetra
.51564 .41112 .51602 .61136 .51775 .61081 .51728 .41056 Mtetra
.51728 .41056 .51775 .61081 .51949 .61025 .51891 .41 Mtetra
.51891 .41 .51949 .61025 .52123 .60968 .52055 .40943 Mtetra
.52055 .40943 .52123 .60968 .52297 .6091 .52219 .40887 Mtetra
.52219 .40887 .52297 .6091 .52471 .60851 .52383 .4083 Mtetra
.52383 .4083 .52471 .60851 .52645 .60792 .52547 .40773 Mtetra
.52547 .40773 .52645 .60792 .52819 .60734 .52711 .40718 Mtetra
.52711 .40718 .52819 .60734 .52993 .60681 .52875 .40663 Mtetra
.52875 .40663 .52993 .60681 .53167 .6063 .53039 .40609 Mtetra
.53039 .40609 .53167 .6063 .53342 .60583 .53204 .40556 Mtetra
.53204 .40556 .53342 .60583 .53516 .60538 .53368 .40504 Mtetra
.53368 .40504 .53516 .60538 .53691 .60496 .53533 .40452 Mtetra
.53533 .40452 .53691 .60496 .53866 .60453 .53698 .40401 Mtetra
.53698 .40401 .53866 .60453 .54041 .60408 .53862 .40349 Mtetra
.53862 .40349 .54041 .60408 .54216 .60363 .54027 .40297 Mtetra
.54027 .40297 .54216 .60363 .54391 .60317 .54192 .40245 Mtetra
.54192 .40245 .54391 .60317 .54567 .6027 .54357 .40193 Mtetra
.54357 .40193 .54567 .6027 .54742 .60222 .54523 .40141 Mtetra
.54523 .40141 .54742 .60222 .54917 .60173 .54688 .40088 Mtetra
.54688 .40088 .54917 .60173 .55093 .60123 .54853 .40035 Mtetra
.54853 .40035 .55093 .60123 .55269 .60072 .55019 .3998 Mtetra
.55019 .3998 .55269 .60072 .55445 .60018 .55184 .39925 Mtetra
.55184 .39925 .55445 .60018 .55621 .59959 .5535 .39866 Mtetra
.5535 .39866 .55621 .59959 .55797 .599 .55516 .39808 Mtetra
.55516 .39808 .55797 .599 .55973 .59839 .55681 .39749 Mtetra
.554 .339 .543 r
.55681 .39749 .55973 .59839 .56148 .59672 .55847 .39625 Mtetra
.553 .338 .543 r
.55847 .39625 .56148 .59672 .56324 .59585 .56013 .39557 Mtetra
.551 .337 .543 r
.56013 .39557 .56324 .59585 .56502 .59678 .5618 .39596 Mtetra
0 0 .397 r
.5618 .39596 .56502 .59678 .56684 .60063 .56574 .58572 Mtetra
0 0 .445 r
.56574 .58572 .56684 .60063 .56864 .60281 .56769 .60002 Mtetra
0 .077 .62 r
.56769 .60002 .56864 .60281 .57043 .60398 .56951 .60294 Mtetra
.483 .677 .951 r
.56951 .60294 .57043 .60398 .57221 .60376 .57129 .60297 Mtetra
.653 .803 .955 r
.57129 .60297 .57221 .60376 .57399 .60321 .57306 .6024 Mtetra
.719 .816 .925 r
.57306 .6024 .57399 .60321 .57576 .60252 .57484 .60156 Mtetra
.622 .752 .939 r
.57484 .60156 .57576 .60252 .57754 .60216 .57662 .60113 Mtetra
.618 .737 .931 r
.57662 .60113 .57754 .60216 .57932 .60182 .5784 .60073 Mtetra
.625 .726 .919 r
.5784 .60073 .57932 .60182 .58111 .60146 .58018 .60031 Mtetra
.639 .719 .906 r
.58018 .60031 .58111 .60146 .58289 .60102 .58196 .59983 Mtetra
.648 .717 .898 r
.58196 .59983 .58289 .60102 .58467 .60052 .58375 .59932 Mtetra
.657 .717 .892 r
.58375 .59932 .58467 .60052 .58645 .59996 .58553 .59876 Mtetra
.649 .713 .895 r
.58553 .59876 .58645 .59996 .58824 .59957 .58731 .59824 Mtetra
.667 .698 .87 r
.58731 .59824 .58824 .59957 .59002 .59897 .5891 .59761 Mtetra
.699 .706 .853 r
.5891 .59761 .59002 .59897 .5918 .59795 .59088 .59679 Mtetra
.797 .764 .822 r
.59088 .59679 .5918 .59795 .59354 .59504 .59265 .59525 Mtetra
.858 .997 .801 r
.59265 .59525 .59354 .59504 .59522 .58929 .59441 .59331 Mtetra
.275 .001 .304 r
.59441 .59331 .59522 .58929 .59287 .39284 .59616 .59111 Mtetra
.549 .331 .536 r
.59616 .59111 .59287 .39284 .59449 .38937 .59794 .59003 Mtetra
.55 .332 .537 r
.59794 .59003 .59449 .38937 .59617 .38889 .59973 .58956 Mtetra
.551 .332 .537 r
.59973 .58956 .59617 .38889 .59788 .38956 .60153 .58934 Mtetra
.551 .333 .537 r
.60153 .58934 .59788 .38956 .5996 .39039 .60334 .58954 Mtetra
.551 .332 .537 r
.60334 .58954 .5996 .39039 .6013 .39055 .60514 .58928 Mtetra
.549 .331 .536 r
.60514 .58928 .6013 .39055 .60296 .38872 .60692 .58801 Mtetra
.534 .32 .535 r
.60692 .58801 .60296 .38872 .60454 .38374 .60848 .57806 Mtetra
0 0 .385 r
.60848 .57806 .60454 .38374 .60616 .38044 .60536 .38161 Mtetra
.917 .904 .501 r
.60536 .38161 .60616 .38044 .6078 .37824 .60695 .37744 Mtetra
.793 .821 .874 r
.60695 .37744 .6078 .37824 .60948 .37738 .60862 .37621 Mtetra
.633 .703 .896 r
.60862 .37621 .60948 .37738 .61117 .37698 .61032 .37579 Mtetra
.55 .661 .91 r
.61032 .37579 .61117 .37698 .61287 .37677 .61202 .37569 Mtetra
.628 .717 .911 r
.61202 .37569 .61287 .37677 .61457 .37633 .61371 .37528 Mtetra
.656 .735 .908 r
.61371 .37528 .61457 .37633 .61626 .37578 .61541 .37476 Mtetra
.666 .744 .908 r
.61541 .37476 .61626 .37578 .61795 .37517 .6171 .37419 Mtetra
.687 .759 .907 r
.6171 .37419 .61795 .37517 .61964 .37444 .61879 .37352 Mtetra
.696 .777 .914 r
.61879 .37352 .61964 .37444 .62133 .37367 .62048 .37282 Mtetra
.697 .794 .925 r
.62048 .37282 .62133 .37367 .62302 .37291 .62217 .37212 Mtetra
.709 .81 .928 r
.62217 .37212 .62302 .37291 .6247 .37202 .62387 .37136 Mtetra
.686 .838 .956 r
.62387 .37136 .6247 .37202 .62639 .37129 .62556 .37068 Mtetra
.622 .833 .981 r
.62556 .37068 .62639 .37129 .6281 .37094 .62726 .37019 Mtetra
.518 .754 .982 r
.62726 .37019 .6281 .37094 .62985 .37185 .62897 .37003 Mtetra
.485 .529 .827 r
.62897 .37003 .62985 .37185 .63166 .37462 .6307 .37033 Mtetra
.452 .369 .672 r
.6307 .37033 .63166 .37462 .6398 .56383 .63247 .3715 Mtetra
.539 .328 .542 r
.63247 .3715 .6398 .56383 .6421 .57756 .63442 .37827 Mtetra
0 0 .41 r
.63442 .37827 .6421 .57756 .64403 .58016 .64303 .57617 Mtetra
.04 .108 .607 r
.64303 .57617 .64403 .58016 .64591 .58122 .645 .57991 Mtetra
.351 .55 .907 r
.645 .57991 .64591 .58122 .64774 .58118 .64686 .58042 Mtetra
.646 .816 .965 r
.64686 .58042 .64774 .58118 .64957 .58056 .64868 .57985 Mtetra
.75 .853 .926 r
.64868 .57985 .64957 .58056 .65138 .57966 .65049 .57884 Mtetra
.728 .823 .924 r
.65049 .57884 .65138 .57966 .65319 .57877 .6523 .57793 Mtetra
.714 .816 .928 r
.6523 .57793 .65319 .57877 .655 .57789 .65412 .57709 Mtetra
.717 .827 .933 r
.65412 .57709 .655 .57789 .65682 .577 .65594 .57624 Mtetra
.701 .83 .944 r
.65594 .57624 .65682 .577 .65864 .57624 .65776 .57546 Mtetra
.684 .822 .949 r
.65776 .57546 .65864 .57624 .66046 .57558 .65958 .57475 Mtetra
.673 .806 .947 r
.65958 .57475 .66046 .57558 .66229 .57499 .66141 .57409 Mtetra
.661 .787 .941 r
.66141 .57409 .66229 .57499 .66412 .57445 .66324 .57348 Mtetra
.649 .766 .934 r
.66324 .57348 .66412 .57445 .66596 .57397 .66507 .57293 Mtetra
.637 .747 .928 r
.66507 .57293 .66596 .57397 .6678 .57354 .66691 .57244 Mtetra
.628 .731 .921 r
.66691 .57244 .6678 .57354 .66964 .57312 .66875 .57199 Mtetra
.615 .721 .921 r
.66875 .57199 .66964 .57312 .67148 .57273 .67059 .5716 Mtetra
.597 .713 .925 r
.67059 .5716 .67148 .57273 .67333 .57242 .67244 .57128 Mtetra
.559 .693 .93 r
.67244 .57128 .67333 .57242 .67519 .57231 .6743 .5711 Mtetra
.547 .674 .921 r
.6743 .5711 .67519 .57231 .67705 .57228 .67616 .57098 Mtetra
.562 .666 .907 r
.67616 .57098 .67705 .57228 .67891 .57219 .67802 .57082 Mtetra
.597 .67 .89 r
.67802 .57082 .67891 .57219 .68077 .57192 .67987 .57053 Mtetra
.621 .676 .881 r
.67987 .57053 .68077 .57192 .68262 .57151 .68172 .57013 Mtetra
.635 .683 .878 r
.68172 .57013 .68262 .57151 .68447 .57102 .68358 .56966 Mtetra
.652 .693 .876 r
.68358 .56966 .68447 .57102 .68632 .57044 .68542 .5691 Mtetra
.662 .701 .875 r
.68542 .5691 .68632 .57044 .68816 .56981 .68727 .56849 Mtetra
.665 .706 .878 r
.68727 .56849 .68816 .56981 .69 .56915 .68912 .56786 Mtetra
.636 .699 .891 r
.68912 .56786 .69 .56915 .69186 .56877 .69097 .56738 Mtetra
.627 .68 .881 r
.69097 .56738 .69186 .56877 .69373 .56842 .69283 .56695 Mtetra
.657 .679 .86 r
.69283 .56695 .69373 .56842 .69557 .56771 .69468 .56635 Mtetra
.75 .731 .834 r
.69468 .56635 .69557 .56771 .69735 .56559 .6965 .56514 Mtetra
.876 .916 .851 r
.6965 .56514 .69735 .56559 .69899 .56097 .69829 .56328 Mtetra
.051 0 .105 r
.69829 .56328 .69899 .56097 .69083 .3679 .70006 .56108 Mtetra
.549 .331 .536 r
.70006 .56108 .69083 .3679 .69209 .35798 .70189 .56003 Mtetra
.551 .333 .537 r
.70189 .56003 .69209 .35798 .69384 .35766 .70378 .55995 Mtetra
.55 .332 .537 r
.70378 .55995 .69384 .35766 .69562 .3578 .70563 .55927 Mtetra
.543 .327 .536 r
.70563 .55927 .69562 .3578 .69722 .3544 .70725 .55425 Mtetra
.024 0 .42 r
.70725 .55425 .69722 .3544 .69879 .35068 .69817 .35322 Mtetra
0 0 0 r
.69817 .35322 .69879 .35068 .70043 .34821 .69964 .34772 Mtetra
.893 .899 .825 r
.69964 .34772 .70043 .34821 .70213 .34696 .70131 .34577 Mtetra
.658 .714 .89 r
.70131 .34577 .70213 .34696 .70389 .3465 .70306 .34522 Mtetra
.567 .655 .896 r
.70306 .34522 .70389 .3465 .70565 .34628 .70483 .34507 Mtetra
.592 .68 .902 r
.70483 .34507 .70565 .34628 .70741 .34594 .70659 .3448 Mtetra
.654 .722 .899 r
.70659 .3448 .70741 .34594 .70916 .34538 .70835 .34426 Mtetra
.661 .73 .9 r
.70835 .34426 .70916 .34538 .71091 .34478 .7101 .3437 Mtetra
.721 .758 .882 r
.7101 .3437 .71091 .34478 .71264 .34387 .71183 .34282 Mtetra
.735 .769 .88 r
.71183 .34282 .71264 .34387 .71437 .3429 .71356 .34187 Mtetra
.621 .733 .927 r
.71356 .34187 .71437 .3429 .71613 .34248 .71532 .34147 Mtetra
0 .107 .634 r
.71532 .34147 .71613 .34248 .71803 .34425 .71722 .34325 Mtetra
.975 .676 .378 r
.71722 .34325 .71803 .34425 .73199 .54203 .73115 .54115 Mtetra
.949 .593 .236 r
.73115 .54115 .73199 .54203 .73465 .5542 .7338 .55316 Mtetra
0 .118 .641 r
.7338 .55316 .73465 .5542 .73669 .55612 .73583 .55501 Mtetra
.607 .724 .928 r
.73583 .55501 .73669 .55612 .73859 .55583 .73772 .55463 Mtetra
.741 .759 .867 r
.73772 .55463 .73859 .55583 .74043 .55467 .73957 .55356 Mtetra
.774 .782 .86 r
.73957 .55356 .74043 .55467 .74221 .55253 .74141 .55227 Mtetra
.786 .969 .917 r
.74141 .55227 .74221 .55253 .74388 .54868 .74325 .55094 Mtetra
.09 0 .121 r
.74325 .55094 .74388 .54868 .74503 .53689 .74504 .54888 Mtetra
.38 .167 .461 r
.74504 .54888 .74503 .53689 .73408 .34231 .74663 .54391 Mtetra
.048 0 .433 r
.74663 .54391 .73408 .34231 .73564 .33858 .73517 .34249 Mtetra
0 0 .108 r
.73517 .34249 .73564 .33858 .7373 .33642 .73656 .33627 Mtetra
.929 .954 .779 r
.73656 .33627 .7373 .33642 .73902 .33514 .73822 .33396 Mtetra
.698 .734 .878 r
.73822 .33396 .73902 .33514 .74078 .33448 .73997 .3332 Mtetra
.616 .682 .889 r
.73997 .3332 .74078 .33448 .74256 .33401 .74176 .33283 Mtetra
.674 .724 .887 r
.74176 .33283 .74256 .33401 .74432 .33323 .74352 .33219 Mtetra
.755 .779 .873 r
.74352 .33219 .74432 .33323 .74605 .3321 .74526 .33112 Mtetra
.658 .76 .926 r
.74526 .33112 .74605 .3321 .74782 .33148 .74703 .33056 Mtetra
0 .317 .796 r
.74703 .33056 .74782 .33148 .74971 .33261 .74893 .33176 Mtetra
.947 .59 .221 r
.74893 .33176 .74971 .33261 .7523 .34331 .7516 .34366 Mtetra
.975 .671 .365 r
.7516 .34366 .7523 .34331 .76862 .54354 .76779 .54254 Mtetra
0 0 .469 r
.76779 .54254 .76862 .54354 .77075 .54613 .76991 .54502 Mtetra
.574 .712 .936 r
.76991 .54502 .77075 .54613 .77269 .54597 .77184 .54476 Mtetra
.729 .755 .873 r
.77184 .54476 .77269 .54597 .77456 .54491 .77371 .54375 Mtetra
.774 .778 .855 r
.77371 .54375 .77456 .54491 .77635 .5429 .77556 .54244 Mtetra
.793 .933 .924 r
.77556 .54244 .77635 .5429 .77804 .53934 .77742 .54115 Mtetra
0 0 .023 r
.77742 .54115 .77804 .53934 .77929 .53012 .77922 .53914 Mtetra
.334 .121 .433 r
.77922 .53914 .77929 .53012 .76609 .33209 .78082 .53451 Mtetra
.064 0 .442 r
.78082 .53451 .76609 .33209 .7676 .32787 .76722 .33206 Mtetra
0 0 .149 r
.76722 .33206 .7676 .32787 .76925 .32552 .76855 .32552 Mtetra
.931 .97 .742 r
.76855 .32552 .76925 .32552 .77097 .32416 .77019 .32305 Mtetra
.688 .747 .896 r
.77019 .32305 .77097 .32416 .77276 .32359 .77196 .32234 Mtetra
.592 .678 .9 r
.77196 .32234 .77276 .32359 .77457 .32327 .77378 .32207 Mtetra
.599 .69 .906 r
.77378 .32207 .77457 .32327 .77637 .3228 .77559 .32176 Mtetra
.705 .769 .902 r
.77559 .32176 .77637 .3228 .77813 .32183 .77737 .32098 Mtetra
.681 .802 .94 r
.77737 .32098 .77813 .32183 .77991 .32113 .77915 .3203 Mtetra
.566 .763 .971 r
.77915 .3203 .77991 .32113 .78177 .32128 .78097 .32001 Mtetra
.374 .559 .906 r
.78097 .32001 .78177 .32128 .78381 .32365 .78285 .32048 Mtetra
.46 .417 .724 r
.78285 .32048 .78381 .32365 .78638 .33242 .78477 .32134 Mtetra
.541 .367 .594 r
.78477 .32134 .78638 .33242 .80449 .52722 .78666 .32188 Mtetra
.554 .339 .543 r
.78666 .32188 .80449 .52722 .80644 .52695 .78843 .32088 Mtetra
.553 .338 .543 r
.78843 .32088 .80644 .52695 .80832 .52592 .79023 .32027 Mtetra
.549 .335 .543 r
.79023 .32027 .80832 .52592 .81039 .52698 .79222 .32193 Mtetra
.087 .007 .46 r
.79222 .32193 .81039 .52698 .81265 .53039 .81134 .52352 Mtetra
.114 .107 .57 r
.81134 .52352 .81265 .53039 .8148 .53228 .81387 .52998 Mtetra
.175 .304 .757 r
.81387 .52998 .8148 .53228 .81685 .53306 .81602 .53188 Mtetra
.565 .697 .93 r
.81602 .53188 .81685 .53306 .8188 .5327 .81799 .53167 Mtetra
.677 .776 .925 r
.81799 .53167 .8188 .5327 .82073 .53205 .81991 .53097 Mtetra
.689 .77 .914 r
.81991 .53097 .82073 .53205 .82266 .53137 .82183 .53021 Mtetra
.574 .705 .931 r
.82183 .53021 .82266 .53137 .82461 .53099 .8238 .52995 Mtetra
.653 .765 .932 r
.8238 .52995 .82461 .53099 .82655 .53042 .82574 .52936 Mtetra
.803 .808 .855 r
.82574 .52936 .82655 .53042 .82845 .52932 .8276 .52786 Mtetra
.925 .762 .661 r
.8276 .52786 .82845 .52932 .83022 .52688 .8292 .52346 Mtetra
.976 .674 .356 r
.8292 .52346 .83022 .52688 .83189 .52336 .81353 .33051 Mtetra
.581 .359 .543 r
.81353 .33051 .83189 .52336 .83348 .5189 .81381 .31318 Mtetra
.554 .339 .543 r
.81381 .31318 .83348 .5189 .83543 .51843 .81558 .31203 Mtetra
.552 .338 .543 r
.81558 .31203 .83543 .51843 .83741 .51824 .81743 .31176 Mtetra
.553 .338 .543 r
.81743 .31176 .83741 .51824 .83916 .51561 .81926 .31131 Mtetra
.555 .34 .543 r
.81926 .31131 .83916 .51561 .82221 .31561 .82094 .3092 Mtetra
.644 .465 .626 r
.82094 .3092 .82221 .31561 .82352 .30964 .82264 .30735 Mtetra
.722 .621 .744 r
.82264 .30735 .82352 .30964 .82513 .30689 .82439 .30593 Mtetra
.697 .786 .92 r
.82439 .30593 .82513 .30689 .82692 .30596 .82619 .30517 Mtetra
.654 .814 .96 r
.82619 .30517 .82692 .30596 .82875 .30542 .82802 .30458 Mtetra
.671 .807 .948 r
.82802 .30458 .82875 .30542 .83058 .30489 .82984 .30392 Mtetra
.78 .812 .878 r
.82984 .30392 .83058 .30489 .83234 .30364 .8316 .30271 Mtetra
.706 .796 .921 r
.8316 .30271 .83234 .30364 .83415 .30282 .83341 .30191 Mtetra
.406 .661 .964 r
.83341 .30191 .83415 .30282 .83605 .30295 .83531 .30208 Mtetra
.81 .378 0 r
.83531 .30208 .83605 .30295 .8384 .30758 .83769 .307 Mtetra
.973 .661 .314 r
.83769 .307 .8384 .30758 .86101 .51324 .86025 .51252 Mtetra
.805 .355 0 r
.86025 .51252 .86101 .51324 .86353 .51817 .86275 .51718 Mtetra
.291 .588 .945 r
.86275 .51718 .86353 .51817 .86561 .51869 .86482 .51767 Mtetra
.663 .777 .934 r
.86482 .51767 .86561 .51869 .86757 .51805 .86678 .51702 Mtetra
.851 .826 .823 r
.86678 .51702 .86757 .51805 .8694 .51612 .86861 .51508 Mtetra
.978 .78 .569 r
.86861 .51508 .8694 .51612 .87073 .50941 .86995 .50839 Mtetra
.976 .67 .325 r
.86995 .50839 .87073 .50941 .85123 .30313 .85048 .30204 Mtetra
.966 .782 .605 r
.85048 .30204 .85123 .30313 .85257 .29784 .85182 .29672 Mtetra
.76 .779 .868 r
.85182 .29672 .85257 .29784 .85436 .2967 .85361 .29558 Mtetra
.63 .727 .918 r
.85361 .29558 .85436 .2967 .85621 .29624 .85546 .29512 Mtetra
.553 .69 .931 r
.85546 .29512 .85621 .29624 .8581 .29608 .85735 .29496 Mtetra
.751 .774 .872 r
.85735 .29496 .8581 .29608 .85989 .295 .85915 .29388 Mtetra
.682 .749 .902 r
.85915 .29388 .85989 .295 .86172 .29431 .86098 .29318 Mtetra
.476 .649 .934 r
.86098 .29318 .86172 .29431 .86365 .2944 .8629 .29328 Mtetra
.752 .336 0 r
.8629 .29328 .86365 .2944 .8661 .29941 .86536 .29827 Mtetra
.971 .656 .295 r
.86536 .29827 .8661 .29941 .89061 .50489 .88983 .50381 Mtetra
.731 .299 0 r
.88983 .50381 .89061 .50489 .89317 .50961 .89239 .50854 Mtetra
.302 .576 .936 r
.89239 .50854 .89317 .50961 .89528 .51014 .89451 .50907 Mtetra
.648 .762 .932 r
.89451 .50907 .89528 .51014 .89727 .50956 .89649 .50848 Mtetra
.828 .82 .842 r
.89649 .50848 .89727 .50956 .89913 .50785 .89836 .50677 Mtetra
.908 .736 .656 r
.26019 .69151 .26124 .69237 .2632 .68681 .26216 .68593 Mtetra
.936 .686 .535 r
.26216 .68593 .2632 .68681 .27928 .49077 .27831 .48983 Mtetra
.906 .726 .648 r
.27831 .48983 .27928 .49077 .28117 .48503 .28019 .48411 Mtetra
.767 .757 .844 r
.28019 .48411 .28117 .48503 .28271 .48394 .28173 .48303 Mtetra
.626 .732 .923 r
.28173 .48303 .28271 .48394 .2842 .48357 .28322 .48267 Mtetra
.485 .684 .954 r
.28322 .48267 .2842 .48357 .28566 .48357 .28468 .48268 Mtetra
.663 .745 .911 r
.28468 .48268 .28566 .48357 .28717 .48296 .28618 .48218 Mtetra
.673 .775 .927 r
.28618 .48218 .28717 .48296 .28867 .4824 .28769 .48165 Mtetra
.677 .781 .929 r
.28769 .48165 .28867 .4824 .29017 .48201 .28919 .4811 Mtetra
.759 .758 .852 r
.28919 .4811 .29017 .48201 .29164 .48191 .29073 .48008 Mtetra
.671 .611 .779 r
.29073 .48008 .29164 .48191 .29308 .48229 .29225 .47938 Mtetra
.569 .484 .72 r
.29225 .47938 .29308 .48229 .29446 .48364 .29372 .47933 Mtetra
0 0 .495 r
.29372 .47933 .29446 .48364 .29492 .49818 .29493 .48308 Mtetra
.959 .704 .507 r
.29493 .48308 .29492 .49818 .28375 .68203 .28291 .67834 Mtetra
.767 .495 0 r
.28291 .67834 .28375 .68203 .28511 .68503 .28408 .68407 Mtetra
0 .332 .797 r
.28408 .68407 .28511 .68503 .28663 .68567 .28558 .68495 Mtetra
.603 .784 .967 r
.28558 .68495 .28663 .68567 .28822 .68532 .28718 .68459 Mtetra
.811 .803 .844 r
.28718 .68459 .28822 .68532 .28988 .684 .28884 .68316 Mtetra
.909 .742 .663 r
.28884 .68316 .28988 .684 .29179 .67892 .29076 .67797 Mtetra
.939 .687 .529 r
.29076 .67797 .29179 .67892 .30634 .48251 .30539 .48134 Mtetra
.902 .715 .64 r
.30539 .48134 .30634 .48251 .30823 .47626 .30727 .47523 Mtetra
.782 .742 .816 r
.30727 .47523 .30823 .47626 .3098 .47494 .30884 .47393 Mtetra
.628 .714 .908 r
.30884 .47393 .3098 .47494 .31131 .47455 .31034 .47357 Mtetra
.482 .666 .944 r
.31034 .47357 .31131 .47455 .31279 .47455 .31182 .47361 Mtetra
.631 .729 .918 r
.31182 .47361 .31279 .47455 .31429 .47417 .31333 .47324 Mtetra
.66 .739 .908 r
.31333 .47324 .31429 .47417 .31581 .47367 .31484 .47275 Mtetra
.666 .743 .908 r
.31484 .47275 .31581 .47367 .31733 .47312 .31636 .47224 Mtetra
.754 .766 .863 r
.31636 .47224 .31733 .47312 .31888 .47204 .31791 .47126 Mtetra
.721 .785 .903 r
.31791 .47126 .31888 .47204 .32042 .47119 .31944 .47052 Mtetra
.502 .754 .986 r
.31944 .47052 .32042 .47119 .32193 .47095 .32094 .47039 Mtetra
.899 .493 .22 r
.32094 .47039 .32193 .47095 .32324 .47389 .32223 .47368 Mtetra
.942 .683 .516 r
.32223 .47368 .32324 .47389 .3129 .66868 .31179 .6691 Mtetra
.896 .566 .414 r
.31179 .6691 .3129 .66868 .31403 .6761 .31299 .67544 Mtetra
0 .384 .783 r
.31299 .67544 .31403 .6761 .31557 .67686 .31454 .67611 Mtetra
.662 .793 .944 r
.31454 .67611 .31557 .67686 .31719 .67637 .31616 .67557 Mtetra
.757 .796 .884 r
.31616 .67557 .31719 .67637 .31884 .67542 .31781 .67457 Mtetra
.569 .743 .958 r
.31781 .67457 .31884 .67542 .32043 .67537 .31941 .67433 Mtetra
.601 .711 .922 r
.31941 .67433 .32043 .67537 .32203 .67525 .32102 .67404 Mtetra
.723 .717 .844 r
.32102 .67404 .32203 .67525 .32367 .67442 .32267 .67313 Mtetra
.878 .721 .683 r
.32267 .67313 .32367 .67442 .32552 .66997 .3245 .669 Mtetra
.943 .688 .522 r
.3245 .669 .32552 .66997 .33829 .47255 .3372 .47394 Mtetra
.991 .819 .574 r
.3372 .47394 .33829 .47255 .34019 .46554 .33917 .46574 Mtetra
.878 .975 .841 r
.33917 .46574 .34019 .46554 .34178 .46386 .34077 .46403 Mtetra
.304 .797 .792 r
.34077 .46403 .34178 .46386 .34331 .46337 .3423 .46358 Mtetra
.108 0 0 r
.3423 .46358 .34331 .46337 .34482 .46332 .3438 .46353 Mtetra
.356 .829 .803 r
.3438 .46353 .34482 .46332 .34634 .46312 .34534 .46299 Mtetra
.678 .94 .964 r
.34534 .46299 .34634 .46312 .34786 .46283 .34689 .46224 Mtetra
.718 .833 .936 r
.34689 .46224 .34786 .46283 .34938 .46254 .34844 .46151 Mtetra
.675 .725 .887 r
.34844 .46151 .34938 .46254 .35091 .46215 .34997 .46094 Mtetra
.651 .686 .87 r
.34997 .46094 .35091 .46215 .35245 .46168 .35151 .46048 Mtetra
.644 .684 .873 r
.35151 .46048 .35245 .46168 .35399 .46118 .35304 .46005 Mtetra
.653 .699 .881 r
.35304 .46005 .35399 .46118 .35552 .46069 .35458 .45959 Mtetra
.658 .706 .883 r
.35458 .45959 .35552 .46069 .35706 .46018 .35612 .4591 Mtetra
.659 .71 .885 r
.35612 .4591 .35706 .46018 .35861 .45964 .35766 .4586 Mtetra
.657 .718 .893 r
.35766 .4586 .35861 .45964 .36015 .45903 .3592 .45812 Mtetra
.657 .746 .916 r
.3592 .45812 .36015 .45903 .3617 .45837 .36074 .45763 Mtetra
.656 .787 .944 r
.36074 .45763 .3617 .45837 .36325 .45772 .36229 .45714 Mtetra
.657 .829 .966 r
.36229 .45714 .36325 .45772 .3648 .45703 .36383 .45661 Mtetra
.645 .87 .983 r
.36383 .45661 .3648 .45703 .36635 .4564 .36538 .45607 Mtetra
.636 .887 .986 r
.36538 .45607 .36635 .4564 .3679 .45596 .36693 .45551 Mtetra
.658 .862 .977 r
.36693 .45551 .3679 .45596 .36941 .45611 .36848 .45495 Mtetra
.672 .701 .869 r
.36848 .45495 .36941 .45611 .3709 .45678 .37003 .45438 Mtetra
.636 .553 .744 r
.37003 .45438 .3709 .45678 .37238 .45778 .37158 .45382 Mtetra
.631 .491 .673 r
.37158 .45382 .37238 .45778 .37392 .4576 .37314 .45299 Mtetra
.617 .468 .657 r
.37314 .45299 .37392 .4576 .37549 .45674 .37471 .45222 Mtetra
.582 .446 .661 r
.37471 .45222 .37549 .45674 .37703 .45649 .37625 .45197 Mtetra
.328 .27 .639 r
.37625 .45197 .37703 .45649 .37834 .46144 .37768 .45398 Mtetra
.958 .695 .493 r
.37768 .45398 .37834 .46144 .37131 .65525 .37085 .64217 Mtetra
0 0 .29 r
.37085 .64217 .37131 .65525 .37276 .65938 .37183 .65664 Mtetra
.234 .295 .722 r
.37183 .65664 .37276 .65938 .37435 .66033 .3734 .65818 Mtetra
.615 .57 .781 r
.3734 .65818 .37435 .66033 .37599 .66008 .37504 .65782 Mtetra
.672 .591 .757 r
.37504 .65782 .37599 .66008 .37765 .65943 .37671 .65697 Mtetra
.628 .555 .753 r
.37671 .65697 .37765 .65943 .37931 .65884 .37837 .65647 Mtetra
.583 .536 .768 r
.37837 .65647 .37931 .65884 .38097 .6583 .38001 .65632 Mtetra
.588 .571 .802 r
.38001 .65632 .38097 .6583 .38263 .65758 .38165 .65613 Mtetra
.619 .65 .859 r
.38165 .65613 .38263 .65758 .38432 .65635 .38331 .65578 Mtetra
.625 .835 .981 r
.38331 .65578 .38432 .65635 .38603 .6546 .38496 .65529 Mtetra
.027 0 0 r
.38496 .65529 .38603 .6546 .38775 .65255 .38663 .65476 Mtetra
.452 .084 .249 r
.38663 .65476 .38775 .65255 .38943 .65153 .38828 .65452 Mtetra
.487 .153 .327 r
.38828 .65452 .38943 .65153 .39107 .65142 .38993 .65433 Mtetra
.404 .072 .284 r
.38993 .65433 .39107 .65142 .39274 .65076 .3916 .65361 Mtetra
0 0 .02 r
.3916 .65361 .39274 .65076 .39456 .64606 .39335 .65085 Mtetra
.932 .817 .36 r
.39335 .65085 .39456 .64606 .40347 .4502 .39541 .63975 Mtetra
0 0 .28 r
.39541 .63975 .40347 .4502 .40522 .44476 .40421 .44579 Mtetra
.916 .958 .631 r
.40421 .44579 .40522 .44476 .40684 .44285 .40588 .44274 Mtetra
.754 .957 .938 r
.40588 .44274 .40684 .44285 .40841 .44233 .40746 .44174 Mtetra
.642 .827 .971 r
.40746 .44174 .40841 .44233 .40996 .44219 .40903 .44125 Mtetra
.638 .736 .919 r
.40903 .44125 .40996 .44219 .41153 .44198 .4106 .44083 Mtetra
.654 .699 .879 r
.4106 .44083 .41153 .44198 .41309 .44153 .41217 .44034 Mtetra
.641 .689 .879 r
.41217 .44034 .41309 .44153 .41467 .44103 .41374 .43991 Mtetra
.642 .702 .89 r
.41374 .43991 .41467 .44103 .41624 .44047 .41531 .43948 Mtetra
.647 .731 .91 r
.41531 .43948 .41624 .44047 .41782 .43985 .41689 .43903 Mtetra
.646 .769 .938 r
.41689 .43903 .41782 .43985 .4194 .43922 .41846 .43857 Mtetra
.644 .811 .963 r
.41846 .43857 .4194 .43922 .42098 .43863 .42004 .43808 Mtetra
.642 .838 .976 r
.42004 .43808 .42098 .43863 .42256 .4381 .42162 .43757 Mtetra
.643 .846 .978 r
.42162 .43757 .42256 .4381 .42413 .43757 .4232 .43705 Mtetra
.645 .847 .978 r
.4232 .43705 .42413 .43757 .42571 .43705 .42478 .43653 Mtetra
.646 .847 .977 r
.42478 .43653 .42571 .43705 .42729 .43652 .42636 .436 Mtetra
.647 .848 .977 r
.42636 .436 .42729 .43652 .42888 .43598 .42794 .43547 Mtetra
.648 .848 .977 r
.42794 .43547 .42888 .43598 .43046 .43545 .42952 .43493 Mtetra
.65 .848 .976 r
.42952 .43493 .43046 .43545 .43204 .43491 .43111 .43439 Mtetra
.654 .848 .974 r
.43111 .43439 .43204 .43491 .43363 .43438 .43269 .43384 Mtetra
.662 .846 .971 r
.43269 .43384 .43363 .43438 .43521 .43383 .43428 .43327 Mtetra
.67 .841 .965 r
.43428 .43327 .43521 .43383 .4368 .43328 .43587 .43268 Mtetra
.673 .832 .96 r
.43587 .43268 .4368 .43328 .43839 .43275 .43746 .43209 Mtetra
.677 .818 .951 r
.43746 .43209 .43839 .43275 .43997 .43227 .43905 .43149 Mtetra
.679 .789 .933 r
.43905 .43149 .43997 .43227 .44156 .43185 .44064 .4309 Mtetra
.667 .746 .909 r
.44064 .4309 .44156 .43185 .44314 .43142 .44223 .43036 Mtetra
.634 .713 .904 r
.44223 .43036 .44314 .43142 .44474 .43089 .44382 .42996 Mtetra
.581 .722 .94 r
.44382 .42996 .44474 .43089 .44633 .43023 .4454 .42972 Mtetra
.497 .801 .999 r
.4454 .42972 .44633 .43023 .44793 .42956 .44699 .42951 Mtetra
.344 .817 .897 r
.44699 .42951 .44793 .42956 .44952 .42892 .44858 .42917 Mtetra
.287 .78 .735 r
.44858 .42917 .44952 .42892 .45112 .42835 .45017 .42862 Mtetra
.312 .794 .734 r
.45017 .42862 .45112 .42835 .45271 .42781 .45177 .42803 Mtetra
.49 .902 .826 r
.45177 .42803 .45271 .42781 .45431 .42714 .45337 .42725 Mtetra
.63 .961 .897 r
.45337 .42725 .45431 .42714 .45591 .42635 .45498 .42635 Mtetra
.362 .831 .883 r
.45498 .42635 .45591 .42635 .45751 .42591 .45657 .42595 Mtetra
.681 .149 0 r
.45657 .42595 .45751 .42591 .45908 .42654 .45814 .4272 Mtetra
.933 .629 .442 r
.45814 .4272 .45908 .42654 .4606 .43025 .45942 .4426 Mtetra
.938 .665 .495 r
.45942 .4426 .4606 .43025 .45843 .62556 .45733 .63144 Mtetra
.65 .359 .465 r
.45733 .63144 .45843 .62556 .46002 .63095 .45897 .63388 Mtetra
.494 .157 .324 r
.45897 .63388 .46002 .63095 .46171 .63079 .46067 .63375 Mtetra
.413 .083 .293 r
.46067 .63375 .46171 .63079 .46343 .62995 .46238 .63305 Mtetra
.402 .077 .297 r
.46238 .63305 .46343 .62995 .46513 .62973 .4641 .63223 Mtetra
.416 .065 .258 r
.4641 .63223 .46513 .62973 .46681 .63083 .46581 .6317 Mtetra
.128 0 0 r
.46581 .6317 .46681 .63083 .46849 .63163 .46752 .63116 Mtetra
.612 .863 .991 r
.46752 .63116 .46849 .63163 .47019 .63189 .46923 .63064 Mtetra
.643 .696 .884 r
.46923 .63064 .47019 .63189 .4719 .63148 .47094 .63016 Mtetra
.65 .687 .872 r
.47094 .63016 .4719 .63148 .47362 .63092 .47265 .62965 Mtetra
.672 .704 .871 r
.47265 .62965 .47362 .63092 .47533 .63037 .47437 .62903 Mtetra
.702 .701 .847 r
.47437 .62903 .47533 .63037 .47704 .63002 .47609 .62821 Mtetra
.686 .638 .796 r
.47609 .62821 .47704 .63002 .47876 .62966 .47781 .62736 Mtetra
.658 .585 .761 r
.47781 .62736 .47876 .62966 .48047 .62923 .47953 .62661 Mtetra
.624 .546 .746 r
.47953 .62661 .48047 .62923 .48219 .62866 .48125 .6261 Mtetra
.617 .546 .752 r
.48125 .6261 .48219 .62866 .48391 .62805 .48297 .62567 Mtetra
.6 .548 .768 r
.48297 .62567 .48391 .62805 .48563 .62756 .48469 .62538 Mtetra
.563 .543 .791 r
.48469 .62538 .48563 .62756 .48735 .62737 .4864 .62534 Mtetra
.64 .598 .79 r
.4864 .62534 .48735 .62737 .48907 .62684 .48813 .6248 Mtetra
.771 .655 .735 r
.48813 .6248 .48907 .62684 .49081 .62536 .48986 .62282 Mtetra
.903 .681 .592 r
.48986 .62282 .49081 .62536 .49257 .62078 .49168 .61309 Mtetra
.952 .681 .488 r
.49168 .61309 .49257 .62078 .49602 .42571 .4952 .41599 Mtetra
.669 .464 .599 r
.4952 .41599 .49602 .42571 .49772 .41671 .49685 .41222 Mtetra
.628 .479 .661 r
.49685 .41222 .49772 .41671 .49935 .41554 .49848 .41129 Mtetra
.592 .46 .67 r
.49848 .41129 .49935 .41554 .50097 .41528 .5001 .41092 Mtetra
.577 .448 .668 r
.5001 .41092 .50097 .41528 .5026 .41535 .50172 .41074 Mtetra
.6 .458 .66 r
.50172 .41074 .5026 .41535 .50422 .41485 .50335 .41022 Mtetra
.6 .457 .66 r
.50335 .41022 .50422 .41485 .50585 .41435 .50498 .4097 Mtetra
.6 .457 .659 r
.50498 .4097 .50585 .41435 .50748 .41385 .50661 .40918 Mtetra
.601 .457 .659 r
.50661 .40918 .50748 .41385 .50911 .41332 .50824 .40864 Mtetra
.601 .457 .658 r
.50824 .40864 .50911 .41332 .51074 .41278 .50987 .4081 Mtetra
.601 .458 .658 r
.50987 .4081 .51074 .41278 .51237 .41223 .5115 .40755 Mtetra
.5115 .40755 .51237 .41223 .51401 .41168 .51313 .407 Mtetra
.601 .458 .659 r
.51313 .407 .51401 .41168 .51564 .41112 .51476 .40645 Mtetra
.602 .458 .659 r
.51476 .40645 .51564 .41112 .51728 .41056 .5164 .4059 Mtetra
.5164 .4059 .51728 .41056 .51891 .41 .51803 .40534 Mtetra
.602 .459 .659 r
.51803 .40534 .51891 .41 .52055 .40943 .51967 .40479 Mtetra
.602 .459 .66 r
.51967 .40479 .52055 .40943 .52219 .40887 .5213 .40424 Mtetra
.5213 .40424 .52219 .40887 .52383 .4083 .52294 .40369 Mtetra
.602 .46 .66 r
.52294 .40369 .52383 .4083 .52547 .40773 .52458 .40314 Mtetra
.602 .46 .661 r
.52458 .40314 .52547 .40773 .52711 .40718 .52622 .4026 Mtetra
.52622 .4026 .52711 .40718 .52875 .40663 .52786 .40205 Mtetra
.52786 .40205 .52875 .40663 .53039 .40609 .5295 .40151 Mtetra
.601 .46 .661 r
.5295 .40151 .53039 .40609 .53204 .40556 .53114 .40097 Mtetra
.53114 .40097 .53204 .40556 .53368 .40504 .53279 .40044 Mtetra
.601 .459 .661 r
.53279 .40044 .53368 .40504 .53533 .40452 .53443 .3999 Mtetra
.601 .459 .66 r
.53443 .3999 .53533 .40452 .53698 .40401 .53608 .39937 Mtetra
.6 .458 .66 r
.53608 .39937 .53698 .40401 .53862 .40349 .53773 .39884 Mtetra
.53773 .39884 .53862 .40349 .54027 .40297 .53937 .39831 Mtetra
.6 .457 .659 r
.53937 .39831 .54027 .40297 .54192 .40245 .54102 .39777 Mtetra
.54102 .39777 .54192 .40245 .54357 .40193 .54267 .39724 Mtetra
.54267 .39724 .54357 .40193 .54523 .40141 .54432 .39671 Mtetra
.54432 .39671 .54523 .40141 .54688 .40088 .54597 .39617 Mtetra
.54597 .39617 .54688 .40088 .54853 .40035 .54763 .39564 Mtetra
.6 .457 .658 r
.54763 .39564 .54853 .40035 .55019 .3998 .54928 .3951 Mtetra
.601 .457 .658 r
.54928 .3951 .55019 .3998 .55184 .39925 .55093 .39455 Mtetra
.602 .458 .659 r
.55093 .39455 .55184 .39925 .5535 .39866 .55259 .39399 Mtetra
.602 .459 .659 r
.55259 .39399 .5535 .39866 .55516 .39808 .55425 .39342 Mtetra
.602 .459 .66 r
.55425 .39342 .55516 .39808 .55681 .39749 .5559 .39286 Mtetra
.627 .476 .658 r
.5559 .39286 .55681 .39749 .55847 .39625 .55756 .3919 Mtetra
.609 .47 .667 r
.55756 .3919 .55847 .39625 .56013 .39557 .55922 .39127 Mtetra
.561 .439 .671 r
.55922 .39127 .56013 .39557 .5618 .39596 .56088 .39129 Mtetra
.082 .103 .583 r
.56088 .39129 .5618 .39596 .56574 .58572 .5626 .39518 Mtetra
0 0 .365 r
.5626 .39518 .56574 .58572 .56769 .60002 .56671 .59477 Mtetra
0 0 .483 r
.56671 .59477 .56769 .60002 .56951 .60294 .56856 .60064 Mtetra
.508 .506 .789 r
.56856 .60064 .56951 .60294 .57129 .60297 .57035 .60093 Mtetra
.645 .602 .791 r
.57035 .60093 .57129 .60297 .57306 .6024 .57212 .60034 Mtetra
.695 .624 .773 r
.57212 .60034 .57306 .6024 .57484 .60156 .57389 .59931 Mtetra
.635 .58 .775 r
.57389 .59931 .57484 .60156 .57662 .60113 .57567 .59876 Mtetra
.631 .569 .766 r
.57567 .59876 .57662 .60113 .5784 .60073 .57745 .59822 Mtetra
.629 .559 .757 r
.57745 .59822 .5784 .60073 .58018 .60031 .57923 .59768 Mtetra
.632 .553 .747 r
.57923 .59768 .58018 .60031 .58196 .59983 .58101 .59709 Mtetra
.626 .543 .741 r
.58101 .59709 .58196 .59983 .58375 .59932 .58279 .59654 Mtetra
.617 .536 .741 r
.58279 .59654 .58375 .59932 .58553 .59876 .58458 .59607 Mtetra
.587 .524 .752 r
.58458 .59607 .58553 .59876 .58731 .59824 .58637 .59587 Mtetra
.582 .543 .776 r
.58637 .59587 .58731 .59824 .5891 .59761 .58816 .5957 Mtetra
.589 .587 .818 r
.58816 .5957 .5891 .59761 .59088 .59679 .58996 .59549 Mtetra
.63 .69 .887 r
.58996 .59549 .59088 .59679 .59265 .59525 .59175 .59506 Mtetra
.497 .885 .963 r
.59175 .59506 .59265 .59525 .59441 .59331 .59354 .59454 Mtetra
.257 0 0 r
.59354 .59454 .59441 .59331 .59616 .59111 .59533 .59398 Mtetra
.438 .102 .297 r
.59533 .59398 .59616 .59111 .59794 .59003 .59712 .59345 Mtetra
.458 .139 .336 r
.59712 .59345 .59794 .59003 .59973 .58956 .59891 .59291 Mtetra
.455 .135 .332 r
.59891 .59291 .59973 .58956 .60153 .58934 .60071 .59236 Mtetra
.496 .161 .327 r
.60071 .59236 .60153 .58934 .60334 .58954 .60251 .59224 Mtetra
.455 .11 .29 r
.60251 .59224 .60334 .58954 .60514 .58928 .60431 .59187 Mtetra
.343 .005 .238 r
.60431 .59187 .60514 .58928 .60692 .58801 .6061 .59086 Mtetra
0 0 0 r
.6061 .59086 .60692 .58801 .60848 .57806 .60781 .58658 Mtetra
.979 .7 .423 r
.60781 .58658 .60848 .57806 .60536 .38161 .60466 .38721 Mtetra
0 0 .026 r
.60466 .38721 .60536 .38161 .60695 .37744 .60613 .37786 Mtetra
.825 .99 .729 r
.60613 .37786 .60695 .37744 .60862 .37621 .60779 .37588 Mtetra
.71 .927 .963 r
.60779 .37588 .60862 .37621 .61032 .37579 .60947 .37502 Mtetra
.622 .79 .963 r
.60947 .37502 .61032 .37579 .61202 .37569 .61116 .37459 Mtetra
.659 .725 .898 r
.61116 .37459 .61202 .37569 .61371 .37528 .61286 .37405 Mtetra
.653 .698 .879 r
.61286 .37405 .61371 .37528 .61541 .37476 .61455 .37353 Mtetra
.644 .696 .883 r
.61455 .37353 .61541 .37476 .6171 .37419 .61625 .37305 Mtetra
.652 .717 .896 r
.61625 .37305 .6171 .37419 .61879 .37352 .61794 .37255 Mtetra
.656 .751 .92 r
.61794 .37255 .61879 .37352 .62048 .37282 .61964 .37202 Mtetra
.657 .792 .947 r
.61964 .37202 .62048 .37282 .62217 .37212 .62134 .37147 Mtetra
.661 .834 .966 r
.62134 .37147 .62217 .37212 .62387 .37136 .62303 .37087 Mtetra
.651 .875 .982 r
.62303 .37087 .62387 .37136 .62556 .37068 .62473 .37025 Mtetra
.643 .887 .985 r
.62473 .37025 .62556 .37068 .62726 .37019 .62643 .36963 Mtetra
.752 .876 .936 r
.62643 .36963 .62726 .37019 .62897 .37003 .62812 .36867 Mtetra
.698 .696 .844 r
.62812 .36867 .62897 .37003 .6307 .37033 .62981 .36788 Mtetra
.594 .534 .757 r
.62981 .36788 .6307 .37033 .63247 .3715 .63153 .36763 Mtetra
.269 .26 .664 r
.63153 .36763 .63247 .3715 .63442 .37827 .63333 .36997 Mtetra
.979 .69 .396 r
.63333 .36997 .63442 .37827 .64303 .57617 .64177 .56474 Mtetra
0 0 .448 r
.64177 .56474 .64303 .57617 .645 .57991 .64404 .57714 Mtetra
.388 .401 .752 r
.64404 .57714 .645 .57991 .64686 .58042 .64592 .57823 Mtetra
.64 .589 .782 r
.64592 .57823 .64686 .58042 .64868 .57985 .64775 .57764 Mtetra
.697 .617 .764 r
.64775 .57764 .64868 .57985 .65049 .57884 .64955 .57653 Mtetra
.632 .577 .774 r
.64955 .57653 .65049 .57884 .6523 .57793 .65138 .57599 Mtetra
.595 .59 .816 r
.65138 .57599 .6523 .57793 .65412 .57709 .65322 .57574 Mtetra
.6 .671 .89 r
.65322 .57574 .65412 .57709 .65594 .57624 .65505 .57544 Mtetra
.65 .806 .958 r
.65505 .57544 .65594 .57624 .65776 .57546 .65688 .57486 Mtetra
.684 .866 .968 r
.65688 .57486 .65776 .57546 .65958 .57475 .65871 .57411 Mtetra
.699 .861 .959 r
.65871 .57411 .65958 .57475 .66141 .57409 .66053 .57331 Mtetra
.682 .822 .951 r
.66053 .57331 .66141 .57409 .66324 .57348 .66236 .57261 Mtetra
.663 .793 .944 r
.66236 .57261 .66324 .57348 .66507 .57293 .66419 .57199 Mtetra
.65 .774 .939 r
.66419 .57199 .66507 .57293 .66691 .57244 .66602 .57143 Mtetra
.621 .748 .938 r
.66602 .57143 .66691 .57244 .66875 .57199 .66786 .571 Mtetra
.608 .747 .943 r
.66786 .571 .66875 .57199 .67059 .5716 .66971 .57061 Mtetra
.621 .753 .941 r
.66971 .57061 .67059 .5716 .67244 .57128 .67155 .57017 Mtetra
.682 .751 .903 r
.67155 .57017 .67244 .57128 .6743 .5711 .67339 .56947 Mtetra
.693 .672 .826 r
.67339 .56947 .6743 .5711 .67616 .57098 .67521 .56861 Mtetra
.665 .59 .761 r
.67521 .56861 .67616 .57098 .67802 .57082 .67704 .56775 Mtetra
.625 .529 .725 r
.67704 .56775 .67802 .57082 .67987 .57053 .67888 .56714 Mtetra
.6 .5 .713 r
.67888 .56714 .67987 .57053 .68172 .57013 .68074 .56675 Mtetra
.587 .494 .715 r
.68074 .56675 .68172 .57013 .68358 .56966 .6826 .5665 Mtetra
.572 .494 .728 r
.6826 .5665 .68358 .56966 .68542 .5691 .68447 .56641 Mtetra
.565 .514 .757 r
.68447 .56641 .68542 .5691 .68727 .56849 .68634 .56637 Mtetra
.571 .561 .804 r
.68634 .56637 .68727 .56849 .68912 .56786 .68821 .56627 Mtetra
.605 .639 .857 r
.68821 .56627 .68912 .56786 .69097 .56738 .69007 .56595 Mtetra
.637 .676 .871 r
.69007 .56595 .69097 .56738 .69283 .56695 .69193 .56547 Mtetra
.647 .673 .861 r
.69193 .56547 .69283 .56695 .69468 .56635 .69379 .56492 Mtetra
.646 .682 .869 r
.69379 .56492 .69468 .56635 .6965 .56514 .69564 .56439 Mtetra
.625 .815 .973 r
.69564 .56439 .6965 .56514 .69829 .56328 .6975 .56387 Mtetra
.046 0 0 r
.6975 .56387 .69829 .56328 .70006 .56108 .69936 .56335 Mtetra
.46 .091 .251 r
.69936 .56335 .70006 .56108 .70189 .56003 .70124 .56313 Mtetra
.488 .155 .327 r
.70124 .56313 .70189 .56003 .70378 .55995 .70312 .56292 Mtetra
.416 .087 .297 r
.70312 .56292 .70378 .55995 .70563 .55927 .70497 .56216 Mtetra
.015 0 .153 r
.70497 .56216 .70563 .55927 .70725 .55425 .7067 .55923 Mtetra
.734 .653 .097 r
.7067 .55923 .70725 .55425 .69817 .35322 .70794 .5471 Mtetra
.011 0 .415 r
.70794 .5471 .69817 .35322 .69964 .34772 .69893 .34864 Mtetra
.807 .901 .492 r
.69893 .34864 .69964 .34772 .70131 .34577 .70054 .34555 Mtetra
.732 .963 .94 r
.70054 .34555 .70131 .34577 .70306 .34522 .70226 .34451 Mtetra
.636 .817 .97 r
.70226 .34451 .70306 .34522 .70483 .34507 .70401 .34398 Mtetra
.634 .726 .914 r
.70401 .34398 .70483 .34507 .70659 .3448 .70577 .34353 Mtetra
.649 .697 .881 r
.70577 .34353 .70659 .3448 .70835 .34426 .70752 .34302 Mtetra
.639 .696 .887 r
.70752 .34302 .70835 .34426 .7101 .3437 .70928 .34255 Mtetra
.7 .738 .881 r
.70928 .34255 .7101 .3437 .71183 .34282 .71102 .34178 Mtetra
.726 .768 .886 r
.71102 .34178 .71183 .34282 .71356 .34187 .71275 .34089 Mtetra
.622 .743 .933 r
.71275 .34089 .71356 .34187 .71532 .34147 .71452 .34047 Mtetra
0 .225 .732 r
.71452 .34047 .71532 .34147 .71722 .34325 .7164 .34192 Mtetra
.945 .593 .201 r
.7164 .34192 .71722 .34325 .73115 .54115 .71889 .35335 Mtetra
.008 0 .425 r
.71889 .35335 .73115 .54115 .7338 .55316 .73284 .55047 Mtetra
.119 .234 .709 r
.73284 .55047 .7338 .55316 .73583 .55501 .7349 .55283 Mtetra
.558 .55 .801 r
.7349 .55283 .73583 .55501 .73772 .55463 .73682 .55281 Mtetra
.647 .632 .821 r
.73682 .55281 .73772 .55463 .73957 .55356 .7387 .55222 Mtetra
.62 .688 .892 r
.7387 .55222 .73957 .55356 .74141 .55227 .74059 .55181 Mtetra
.397 .787 .989 r
.74059 .55181 .74141 .55227 .74325 .55094 .74251 .55165 Mtetra
.004 0 0 r
.74251 .55165 .74325 .55094 .74504 .54888 .74438 .5509 Mtetra
0 0 0 r
.74438 .5509 .74504 .54888 .74663 .54391 .74613 .54814 Mtetra
.831 .703 .168 r
.74613 .54814 .74663 .54391 .73517 .34249 .74719 .53511 Mtetra
.024 0 .425 r
.74719 .53511 .73517 .34249 .73656 .33627 .73581 .33587 Mtetra
.96 .88 .711 r
.73581 .33587 .73656 .33627 .73822 .33396 .7374 .33271 Mtetra
.703 .722 .865 r
.7374 .33271 .73822 .33396 .73997 .3332 .73916 .33189 Mtetra
.593 .667 .89 r
.73916 .33189 .73997 .3332 .74176 .33283 .74095 .33163 Mtetra
.633 .704 .898 r
.74095 .33163 .74176 .33283 .74352 .33219 .74273 .33118 Mtetra
.729 .78 .893 r
.74273 .33118 .74352 .33219 .74526 .33112 .74448 .33028 Mtetra
.624 .782 .957 r
.74448 .33028 .74526 .33112 .74703 .33056 .74626 .32982 Mtetra
0 .318 .775 r
.74626 .32982 .74703 .33056 .74893 .33176 .74815 .3309 Mtetra
.92 .535 .136 r
.74815 .3309 .74893 .33176 .7516 .34366 .75053 .33871 Mtetra
.977 .676 .348 r
.75053 .33871 .7516 .34366 .76779 .54254 .76683 .53986 Mtetra
0 .149 .667 r
.76683 .53986 .76779 .54254 .76991 .54502 .76899 .54281 Mtetra
.537 .536 .802 r
.76899 .54281 .76991 .54502 .77184 .54476 .77094 .54292 Mtetra
.634 .626 .824 r
.77094 .54292 .77184 .54476 .77371 .54375 .77285 .54241 Mtetra
.639 .697 .888 r
.77285 .54241 .77371 .54375 .77556 .54244 .77476 .5419 Mtetra
.448 .796 .998 r
.77476 .5419 .77556 .54244 .77742 .54115 .7767 .5417 Mtetra
0 0 0 r
.7767 .5417 .77742 .54115 .77922 .53914 .7786 .54097 Mtetra
0 0 .002 r
.7786 .54097 .77922 .53914 .78082 .53451 .78038 .53873 Mtetra
0 0 .067 r
.78038 .53873 .78082 .53451 .76722 .33206 .78174 .53089 Mtetra
.048 0 .437 r
.78174 .53089 .76722 .33206 .76855 .32552 .76797 .32724 Mtetra
0 0 0 r
.76797 .32724 .76855 .32552 .77019 .32305 .76948 .32299 Mtetra
.736 .989 .885 r
.76948 .32299 .77019 .32305 .77196 .32234 .77122 .32174 Mtetra
.66 .861 .976 r
.77122 .32174 .77196 .32234 .77378 .32207 .773 .32108 Mtetra
.629 .751 .935 r
.773 .32108 .77378 .32207 .77559 .32176 .7748 .32063 Mtetra
.66 .731 .902 r
.7748 .32063 .77559 .32176 .77737 .32098 .7766 .32005 Mtetra
.643 .771 .941 r
.7766 .32005 .77737 .32098 .77915 .3203 .7784 .31953 Mtetra
.639 .809 .965 r
.7784 .31953 .77915 .3203 .78097 .32001 .7802 .319 Mtetra
.669 .76 .919 r
.7802 .319 .78097 .32001 .78285 .32048 .78199 .31838 Mtetra
.646 .594 .782 r
.78199 .31838 .78285 .32048 .78477 .32134 .78379 .31776 Mtetra
.627 .505 .694 r
.78379 .31776 .78477 .32134 .78666 .32188 .78557 .31701 Mtetra
.622 .471 .656 r
.78557 .31701 .78666 .32188 .78843 .32088 .78734 .31605 Mtetra
.597 .456 .66 r
.78734 .31605 .78843 .32088 .79023 .32027 .78914 .31552 Mtetra
.511 .401 .666 r
.78914 .31552 .79023 .32027 .79222 .32193 .79105 .3162 Mtetra
.037 .064 .559 r
.79105 .3162 .79222 .32193 .81134 .52352 .79343 .3223 Mtetra
.071 0 .455 r
.79343 .3223 .81134 .52352 .81387 .52998 .81277 .52565 Mtetra
.178 .199 .644 r
.81277 .52565 .81387 .52998 .81602 .53188 .81506 .52924 Mtetra
.566 .522 .765 r
.81506 .52924 .81602 .53188 .81799 .53167 .81705 .52919 Mtetra
.651 .58 .763 r
.81705 .52919 .81799 .53167 .81991 .53097 .81897 .52843 Mtetra
.658 .581 .757 r
.81897 .52843 .81991 .53097 .82183 .53021 .82088 .52758 Mtetra
.574 .528 .766 r
.82088 .52758 .82183 .53021 .8238 .52995 .82286 .52746 Mtetra
.634 .571 .766 r
.82286 .52746 .8238 .52995 .82574 .52936 .8248 .52685 Mtetra
.752 .631 .727 r
.8248 .52685 .82574 .52936 .8276 .52786 .82662 .5249 Mtetra
.917 .682 .569 r
.82662 .5249 .8276 .52786 .8292 .52346 .82782 .51616 Mtetra
.974 .671 .366 r
.82782 .51616 .8292 .52346 .81353 .33051 .8112 .31243 Mtetra
.624 .41 .571 r
.8112 .31243 .81353 .33051 .81381 .31318 .81269 .30823 Mtetra
.624 .471 .654 r
.81269 .30823 .81381 .31318 .81558 .31203 .81447 .30721 Mtetra
.589 .451 .661 r
.81447 .30721 .81558 .31203 .81743 .31176 .8163 .30681 Mtetra
.574 .439 .659 r
.8163 .30681 .81743 .31176 .81926 .31131 .81816 .30663 Mtetra
.599 .46 .664 r
.81816 .30663 .81926 .31131 .82094 .3092 .81999 .30608 Mtetra
.617 .517 .718 r
.81999 .30608 .82094 .3092 .82264 .30735 .82181 .30553 Mtetra
.645 .623 .814 r
.82181 .30553 .82264 .30735 .82439 .30593 .82364 .30496 Mtetra
.667 .776 .931 r
.82364 .30496 .82439 .30593 .82619 .30517 .82546 .30434 Mtetra
.669 .808 .95 r
.82546 .30434 .82619 .30517 .82802 .30458 .82728 .3037 Mtetra
.692 .806 .935 r
.82728 .3037 .82802 .30458 .82984 .30392 .82909 .30296 Mtetra
.766 .81 .887 r
.82909 .30296 .82984 .30392 .8316 .30271 .83087 .30184 Mtetra
.685 .806 .939 r
.83087 .30184 .8316 .30271 .83341 .30191 .83268 .30113 Mtetra
.315 .644 .967 r
.83268 .30113 .83341 .30191 .83531 .30208 .8346 .30141 Mtetra
.855 .428 0 r
.8346 .30141 .83531 .30208 .83769 .307 .83704 .30692 Mtetra
.973 .661 .316 r
.83704 .30692 .83769 .307 .86025 .51252 .85951 .51192 Mtetra
.798 .335 0 r
.85951 .51192 .86025 .51252 .86275 .51718 .86196 .51618 Mtetra
.309 .598 .947 r
.86196 .51618 .86275 .51718 .86482 .51767 .86403 .51663 Mtetra
.665 .774 .931 r
.86403 .51663 .86482 .51767 .86678 .51702 .86599 .51597 Mtetra
.85 .824 .823 r
.86599 .51597 .86678 .51702 .86861 .51508 .86783 .51404 Mtetra
.978 .781 .569 r
.86783 .51404 .86861 .51508 .86995 .50839 .86917 .50737 Mtetra
.976 .67 .325 r
.86917 .50737 .86995 .50839 .85048 .30204 .84973 .30094 Mtetra
.966 .782 .604 r
.84973 .30094 .85048 .30204 .85182 .29672 .85108 .29561 Mtetra
.761 .779 .868 r
.85108 .29561 .85182 .29672 .85361 .29558 .85286 .29446 Mtetra
.63 .728 .918 r
.85286 .29446 .85361 .29558 .85546 .29512 .85472 .294 Mtetra
.553 .691 .931 r
.85472 .294 .85546 .29512 .85735 .29496 .85661 .29384 Mtetra
.751 .775 .872 r
.85661 .29384 .85735 .29496 .85915 .29388 .8584 .29275 Mtetra
.683 .749 .902 r
.8584 .29275 .85915 .29388 .86098 .29318 .86023 .29205 Mtetra
.477 .649 .934 r
.86023 .29205 .86098 .29318 .8629 .29328 .86216 .29215 Mtetra
.751 .335 0 r
.86216 .29215 .8629 .29328 .86536 .29827 .86461 .29713 Mtetra
.971 .656 .295 r
.86461 .29713 .86536 .29827 .88983 .50381 .88905 .50272 Mtetra
.731 .3 0 r
.88905 .50272 .88983 .50381 .89239 .50854 .89161 .50746 Mtetra
.302 .576 .936 r
.89161 .50746 .89239 .50854 .89451 .50907 .89373 .50799 Mtetra
.648 .762 .932 r
.89373 .50799 .89451 .50907 .89649 .50848 .89572 .5074 Mtetra
.828 .819 .841 r
.89572 .5074 .89649 .50848 .89836 .50677 .89758 .50569 Mtetra
.908 .735 .656 r
.25915 .69064 .26019 .69151 .26216 .68593 .26112 .68502 Mtetra
.936 .686 .535 r
.26112 .68502 .26216 .68593 .27831 .48983 .27733 .48885 Mtetra
.904 .724 .648 r
.27733 .48885 .27831 .48983 .28019 .48411 .27922 .48317 Mtetra
.764 .754 .843 r
.27922 .48317 .28019 .48411 .28173 .48303 .28076 .4821 Mtetra
.623 .727 .921 r
.28076 .4821 .28173 .48303 .28322 .48267 .28224 .48175 Mtetra
.482 .679 .952 r
.28224 .48175 .28322 .48267 .28468 .48268 .28371 .48177 Mtetra
.654 .741 .913 r
.28371 .48177 .28468 .48268 .28618 .48218 .2852 .48131 Mtetra
.669 .752 .913 r
.2852 .48131 .28618 .48218 .28769 .48165 .28671 .48079 Mtetra
.682 .759 .909 r
.28671 .48079 .28769 .48165 .28919 .4811 .28822 .48022 Mtetra
.78 .766 .841 r
.28822 .48022 .28919 .4811 .29073 .48008 .28977 .47904 Mtetra
.728 .732 .854 r
.28977 .47904 .29073 .48008 .29225 .47938 .2913 .4782 Mtetra
.585 .662 .891 r
.2913 .4782 .29225 .47938 .29372 .47933 .29278 .47801 Mtetra
.904 .501 .1 r
.29278 .47801 .29372 .47933 .29493 .48308 .29401 .48146 Mtetra
.94 .684 .521 r
.29401 .48146 .29493 .48308 .28291 .67834 .28191 .67687 Mtetra
.954 .614 .316 r
.28191 .67687 .28291 .67834 .28408 .68407 .28304 .68322 Mtetra
0 .271 .728 r
.28304 .68322 .28408 .68407 .28558 .68495 .28454 .68414 Mtetra
.614 .766 .952 r
.28454 .68414 .28558 .68495 .28718 .68459 .28613 .68377 Mtetra
.81 .787 .831 r
.28613 .68377 .28718 .68459 .28884 .68316 .2878 .68229 Mtetra
.91 .738 .656 r
.2878 .68229 .28884 .68316 .29076 .67797 .28974 .67673 Mtetra
.939 .687 .529 r
.28974 .67673 .29076 .67797 .30539 .48134 .30447 .47957 Mtetra
.875 .686 .644 r
.30447 .47957 .30539 .48134 .30727 .47523 .30633 .47392 Mtetra
.752 .697 .799 r
.30633 .47392 .30727 .47523 .30884 .47393 .30789 .47273 Mtetra
.603 .666 .884 r
.30789 .47273 .30884 .47393 .31034 .47357 .30939 .47248 Mtetra
.447 .622 .926 r
.30939 .47248 .31034 .47357 .31182 .47361 .31086 .47264 Mtetra
.617 .717 .917 r
.31086 .47264 .31182 .47361 .31333 .47324 .31236 .47231 Mtetra
.655 .74 .912 r
.31236 .47231 .31333 .47324 .31484 .47275 .31388 .47185 Mtetra
.665 .746 .911 r
.31388 .47185 .31484 .47275 .31636 .47224 .3154 .47134 Mtetra
.754 .763 .861 r
.3154 .47134 .31636 .47224 .31791 .47126 .31694 .47036 Mtetra
.715 .757 .885 r
.31694 .47036 .31791 .47126 .31944 .47052 .31848 .46962 Mtetra
.529 .704 .951 r
.31848 .46962 .31944 .47052 .32094 .47039 .31997 .46952 Mtetra
.915 .515 .2 r
.31997 .46952 .32094 .47039 .32223 .47368 .32124 .47314 Mtetra
.942 .683 .516 r
.32124 .47314 .32223 .47368 .31179 .6691 .3107 .6694 Mtetra
.895 .555 .397 r
.3107 .6694 .31179 .6691 .31299 .67544 .31193 .67506 Mtetra
0 .376 .691 r
.31193 .67506 .31299 .67544 .31454 .67611 .31349 .67558 Mtetra
.689 .852 .961 r
.31349 .67558 .31454 .67611 .31616 .67557 .31512 .67491 Mtetra
.783 .826 .886 r
.31512 .67491 .31616 .67557 .31781 .67457 .31678 .67377 Mtetra
.631 .776 .95 r
.31678 .67377 .31781 .67457 .31941 .67433 .31839 .67334 Mtetra
.62 .729 .924 r
.31839 .67334 .31941 .67433 .32102 .67404 .32001 .67297 Mtetra
.706 .737 .876 r
.32001 .67297 .32102 .67404 .32267 .67313 .32164 .67222 Mtetra
.866 .766 .751 r
.32164 .67222 .32267 .67313 .3245 .669 .32339 .66963 Mtetra
.978 .836 .635 r
.32339 .66963 .3245 .669 .3372 .47394 .32531 .66394 Mtetra
0 0 .246 r
.32531 .66394 .3372 .47394 .33917 .46574 .33778 .47236 Mtetra
.303 .061 .371 r
.33778 .47236 .33917 .46574 .34077 .46403 .33945 .4694 Mtetra
.533 .251 .433 r
.33945 .4694 .34077 .46403 .3423 .46358 .34096 .4694 Mtetra
.537 .259 .442 r
.34096 .4694 .3423 .46358 .3438 .46353 .34247 .46943 Mtetra
.16 0 .301 r
.34247 .46943 .3438 .46353 .34534 .46299 .34418 .46573 Mtetra
0 0 0 r
.34418 .46573 .34534 .46299 .34689 .46224 .34586 .46257 Mtetra
.92 .963 .788 r
.34586 .46257 .34689 .46224 .34844 .46151 .34749 .4604 Mtetra
.747 .729 .835 r
.34749 .4604 .34844 .46151 .34997 .46094 .34905 .45938 Mtetra
.65 .633 .819 r
.34905 .45938 .34997 .46094 .35151 .46048 .35059 .45888 Mtetra
.616 .613 .825 r
.35059 .45888 .35151 .46048 .35304 .46005 .35212 .45857 Mtetra
.638 .638 .833 r
.35212 .45857 .35304 .46005 .35458 .45959 .35366 .45814 Mtetra
.649 .648 .836 r
.35366 .45814 .35458 .45959 .35612 .4591 .35519 .45766 Mtetra
.646 .648 .838 r
.35519 .45766 .35612 .4591 .35766 .4586 .35673 .4572 Mtetra
.632 .648 .848 r
.35673 .4572 .35766 .4586 .3592 .45812 .35827 .45682 Mtetra
.624 .661 .865 r
.35827 .45682 .3592 .45812 .36074 .45763 .3598 .45648 Mtetra
.626 .686 .886 r
.3598 .45648 .36074 .45763 .36229 .45714 .36134 .45612 Mtetra
.644 .72 .903 r
.36134 .45612 .36229 .45714 .36383 .45661 .36288 .45569 Mtetra
.662 .745 .912 r
.36288 .45569 .36383 .45661 .36538 .45607 .36443 .45519 Mtetra
.677 .758 .912 r
.36443 .45519 .36538 .45607 .36693 .45551 .36598 .45462 Mtetra
.699 .762 .901 r
.36598 .45462 .36693 .45551 .36848 .45495 .36753 .45396 Mtetra
.705 .742 .88 r
.36753 .45396 .36848 .45495 .37003 .45438 .36909 .45324 Mtetra
.697 .713 .861 r
.36909 .45324 .37003 .45438 .37158 .45382 .37065 .45254 Mtetra
.708 .693 .834 r
.37065 .45254 .37158 .45382 .37314 .45299 .37221 .45174 Mtetra
.693 .693 .846 r
.37221 .45174 .37314 .45299 .37471 .45222 .37377 .45103 Mtetra
.621 .68 .884 r
.37377 .45103 .37471 .45222 .37625 .45197 .37532 .4507 Mtetra
.03 .342 .821 r
.37532 .4507 .37625 .45197 .37768 .45398 .3768 .45169 Mtetra
0 0 .303 r
.3768 .45169 .37768 .45398 .37085 .64217 .37818 .45506 Mtetra
0 0 .279 r
.37818 .45506 .37085 .64217 .37183 .65664 .3713 .64512 Mtetra
.312 .19 .549 r
.3713 .64512 .37183 .65664 .3734 .65818 .37269 .65045 Mtetra
.589 .418 .617 r
.37269 .65045 .3734 .65818 .37504 .65782 .37435 .6498 Mtetra
.6 .424 .615 r
.37435 .6498 .37504 .65782 .37671 .65697 .37602 .64883 Mtetra
.432 .299 .599 r
.37602 .64883 .37671 .65697 .37837 .65647 .37755 .65108 Mtetra
.306 .242 .619 r
.37755 .65108 .37837 .65647 .38001 .65632 .37908 .65364 Mtetra
.246 .308 .731 r
.37908 .65364 .38001 .65632 .38165 .65613 .38065 .65511 Mtetra
.348 .608 .946 r
.38065 .65511 .38165 .65613 .38331 .65578 .38228 .65542 Mtetra
.538 .858 .997 r
.38228 .65542 .38331 .65578 .38496 .65529 .38394 .65502 Mtetra
.622 .905 .984 r
.38394 .65502 .38496 .65529 .38663 .65476 .3856 .65441 Mtetra
.529 .858 .996 r
.3856 .65441 .38663 .65476 .38828 .65452 .38726 .65402 Mtetra
.524 .819 .999 r
.38726 .65402 .38828 .65452 .38993 .65433 .38892 .65373 Mtetra
.678 .84 .961 r
.38892 .65373 .38993 .65433 .3916 .65361 .39059 .65308 Mtetra
.857 .85 .835 r
.39059 .65308 .3916 .65361 .39335 .65085 .3923 .65131 Mtetra
.972 .899 .688 r
.3923 .65131 .39335 .65085 .39541 .63975 .39409 .6475 Mtetra
.791 .721 .188 r
.39409 .6475 .39541 .63975 .40421 .44579 .39625 .63376 Mtetra
0 0 .293 r
.39625 .63376 .40421 .44579 .40588 .44274 .40479 .44598 Mtetra
0 0 .014 r
.40479 .44598 .40588 .44274 .40746 .44174 .40647 .44248 Mtetra
.81 .98 .694 r
.40647 .44248 .40746 .44174 .40903 .44125 .40809 .44046 Mtetra
.783 .799 .866 r
.40809 .44046 .40903 .44125 .4106 .44083 .40969 .43932 Mtetra
.662 .648 .825 r
.40969 .43932 .4106 .44083 .41217 .44034 .41126 .43875 Mtetra
.617 .618 .828 r
.41126 .43875 .41217 .44034 .41374 .43991 .41283 .43842 Mtetra
.609 .627 .844 r
.41283 .43842 .41374 .43991 .41531 .43948 .4144 .43813 Mtetra
.619 .653 .861 r
.4144 .43813 .41531 .43948 .41689 .43903 .41597 .4378 Mtetra
.618 .673 .881 r
.41597 .4378 .41689 .43903 .41846 .43857 .41754 .43748 Mtetra
.633 .705 .898 r
.41754 .43748 .41846 .43857 .42004 .43808 .41911 .43708 Mtetra
.654 .73 .905 r
.41911 .43708 .42004 .43808 .42162 .43757 .42069 .4366 Mtetra
.663 .738 .906 r
.42069 .4366 .42162 .43757 .4232 .43705 .42227 .43608 Mtetra
.664 .739 .906 r
.42227 .43608 .4232 .43705 .42478 .43653 .42385 .43555 Mtetra
.42385 .43555 .42478 .43653 .42636 .436 .42543 .43503 Mtetra
.666 .741 .906 r
.42543 .43503 .42636 .436 .42794 .43547 .42701 .43449 Mtetra
.42701 .43449 .42794 .43547 .42952 .43493 .4286 .43396 Mtetra
.667 .742 .906 r
.4286 .43396 .42952 .43493 .43111 .43439 .43018 .43342 Mtetra
.674 .745 .904 r
.43018 .43342 .43111 .43439 .43269 .43384 .43177 .43285 Mtetra
.691 .746 .893 r
.43177 .43285 .43269 .43384 .43428 .43327 .43336 .43221 Mtetra
.703 .733 .874 r
.43336 .43221 .43428 .43327 .43587 .43268 .43495 .43148 Mtetra
.697 .707 .856 r
.43495 .43148 .43587 .43268 .43746 .43209 .43654 .43076 Mtetra
.694 .686 .838 r
.43654 .43076 .43746 .43209 .43905 .43149 .43814 .43002 Mtetra
.684 .663 .823 r
.43814 .43002 .43905 .43149 .44064 .4309 .43973 .42932 Mtetra
.643 .631 .823 r
.43973 .42932 .44064 .4309 .44223 .43036 .44132 .42884 Mtetra
.496 .57 .86 r
.44132 .42884 .44223 .43036 .44382 .42996 .4429 .42901 Mtetra
0 .141 .644 r
.4429 .42901 .44382 .42996 .4454 .42972 .44444 .4303 Mtetra
.804 .388 .26 r
.44444 .4303 .4454 .42972 .44699 .42951 .44597 .43272 Mtetra
.728 .407 .435 r
.44597 .43272 .44699 .42951 .44858 .42917 .44748 .43583 Mtetra
.545 .274 .454 r
.44748 .43583 .44858 .42917 .45017 .42862 .44906 .43599 Mtetra
.463 .207 .44 r
.44906 .43599 .45017 .42862 .45177 .42803 .45068 .43461 Mtetra
.417 .162 .417 r
.45068 .43461 .45177 .42803 .45337 .42725 .45231 .43279 Mtetra
.422 .154 .4 r
.45231 .43279 .45337 .42725 .45498 .42635 .45393 .43134 Mtetra
.512 .226 .417 r
.45393 .43134 .45498 .42635 .45657 .42595 .45553 .43108 Mtetra
.762 .465 .482 r
.45553 .43108 .45657 .42595 .45814 .4272 .457 .43711 Mtetra
.941 .669 .493 r
.457 .43711 .45814 .4272 .45942 .4426 .4547 .62828 Mtetra
.557 .338 .537 r
.4547 .62828 .45942 .4426 .45733 .63144 .45632 .63208 Mtetra
.69 .224 .139 r
.45632 .63208 .45733 .63144 .45897 .63388 .45799 .63342 Mtetra
.396 .777 .991 r
.45799 .63342 .45897 .63388 .46067 .63375 .45969 .6333 Mtetra
.603 .865 .992 r
.45969 .6333 .46067 .63375 .46238 .63305 .4614 .63279 Mtetra
.627 .915 .98 r
.4614 .63279 .46238 .63305 .4641 .63223 .46311 .63212 Mtetra
.561 .918 .956 r
.46311 .63212 .4641 .63223 .46581 .6317 .46482 .63148 Mtetra
.626 .921 .976 r
.46482 .63148 .46581 .6317 .46752 .63116 .46654 .63079 Mtetra
.617 .887 .989 r
.46654 .63079 .46752 .63116 .46923 .63064 .46825 .6302 Mtetra
.526 .842 .999 r
.46825 .6302 .46923 .63064 .47094 .63016 .46996 .62985 Mtetra
.577 .888 .99 r
.46996 .62985 .47094 .63016 .47265 .62965 .47168 .62932 Mtetra
.775 .921 .934 r
.47168 .62932 .47265 .62965 .47437 .62903 .4734 .62821 Mtetra
.876 .801 .773 r
.4734 .62821 .47437 .62903 .47609 .62821 .47514 .62581 Mtetra
.819 .655 .679 r
.47514 .62581 .47609 .62821 .47781 .62736 .4769 .6223 Mtetra
.758 .561 .631 r
.4769 .6223 .47781 .62736 .47953 .62661 .47867 .61781 Mtetra
.612 .429 .61 r
.47867 .61781 .47953 .62661 .48125 .6261 .4804 .61636 Mtetra
.551 .379 .601 r
.4804 .61636 .48125 .6261 .48297 .62567 .48211 .61654 Mtetra
.525 .363 .604 r
.48211 .61654 .48297 .62567 .48469 .62538 .48381 .61734 Mtetra
.529 .373 .613 r
.48381 .61734 .48469 .62538 .4864 .62534 .48551 .61798 Mtetra
.584 .417 .622 r
.48551 .61798 .4864 .62534 .48813 .6248 .48723 .61747 Mtetra
.71 .508 .614 r
.48723 .61747 .48813 .6248 .48986 .62282 .489 .61318 Mtetra
.949 .679 .49 r
.489 .61318 .48986 .62282 .49168 .61309 .49265 .41837 Mtetra
.561 .345 .544 r
.49265 .41837 .49168 .61309 .4952 .41599 .49432 .4133 Mtetra
.763 .61 .689 r
.49432 .4133 .4952 .41599 .49685 .41222 .49596 .41088 Mtetra
.701 .691 .838 r
.49596 .41088 .49685 .41222 .49848 .41129 .49758 .41009 Mtetra
.635 .691 .885 r
.49758 .41009 .49848 .41129 .5001 .41092 .49921 .40968 Mtetra
.607 .672 .886 r
.49921 .40968 .5001 .41092 .50172 .41074 .50083 .40939 Mtetra
.656 .673 .855 r
.50083 .40939 .50172 .41074 .50335 .41022 .50246 .40886 Mtetra
.656 .673 .854 r
.50246 .40886 .50335 .41022 .50498 .4097 .50408 .40834 Mtetra
.657 .672 .853 r
.50408 .40834 .50498 .4097 .50661 .40918 .50571 .40781 Mtetra
.66 .671 .85 r
.50571 .40781 .50661 .40918 .50824 .40864 .50734 .40726 Mtetra
.66 .67 .849 r
.50734 .40726 .50824 .40864 .50987 .4081 .50897 .40671 Mtetra
.66 .669 .848 r
.50897 .40671 .50987 .4081 .5115 .40755 .5106 .40615 Mtetra
.66 .668 .847 r
.5106 .40615 .5115 .40755 .51313 .407 .51224 .4056 Mtetra
.659 .667 .846 r
.51224 .4056 .51313 .407 .51476 .40645 .51387 .40504 Mtetra
.51387 .40504 .51476 .40645 .5164 .4059 .5155 .40449 Mtetra
.5155 .40449 .5164 .4059 .51803 .40534 .51714 .40394 Mtetra
.51714 .40394 .51803 .40534 .51967 .40479 .51878 .40339 Mtetra
.51878 .40339 .51967 .40479 .5213 .40424 .52041 .40284 Mtetra
.658 .667 .847 r
.52041 .40284 .5213 .40424 .52294 .40369 .52205 .40229 Mtetra
.52205 .40229 .52294 .40369 .52458 .40314 .52369 .40174 Mtetra
.52369 .40174 .52458 .40314 .52622 .4026 .52533 .40119 Mtetra
.657 .667 .848 r
.52533 .40119 .52622 .4026 .52786 .40205 .52697 .40065 Mtetra
.52697 .40065 .52786 .40205 .5295 .40151 .52861 .40011 Mtetra
.52861 .40011 .5295 .40151 .53114 .40097 .53026 .39957 Mtetra
.656 .666 .848 r
.53026 .39957 .53114 .40097 .53279 .40044 .5319 .39903 Mtetra
.5319 .39903 .53279 .40044 .53443 .3999 .53355 .39849 Mtetra
.655 .666 .848 r
.53355 .39849 .53443 .3999 .53608 .39937 .53519 .39796 Mtetra
.655 .665 .848 r
.53519 .39796 .53608 .39937 .53773 .39884 .53684 .39743 Mtetra
.53684 .39743 .53773 .39884 .53937 .39831 .53849 .39689 Mtetra
.53849 .39689 .53937 .39831 .54102 .39777 .54014 .39636 Mtetra
.54014 .39636 .54102 .39777 .54267 .39724 .54179 .39583 Mtetra
.654 .665 .848 r
.54179 .39583 .54267 .39724 .54432 .39671 .54344 .3953 Mtetra
.54344 .3953 .54432 .39671 .54597 .39617 .54509 .39477 Mtetra
.654 .666 .849 r
.54509 .39477 .54597 .39617 .54763 .39564 .54674 .39424 Mtetra
.655 .667 .85 r
.54674 .39424 .54763 .39564 .54928 .3951 .5484 .39371 Mtetra
.656 .669 .851 r
.5484 .39371 .54928 .3951 .55093 .39455 .55005 .39317 Mtetra
.659 .672 .851 r
.55005 .39317 .55093 .39455 .55259 .39399 .55171 .39261 Mtetra
.66 .674 .852 r
.55171 .39261 .55259 .39399 .55425 .39342 .55337 .39205 Mtetra
.661 .675 .853 r
.55337 .39205 .55425 .39342 .5559 .39286 .55502 .39149 Mtetra
.705 .692 .836 r
.55502 .39149 .5559 .39286 .55756 .3919 .55668 .39066 Mtetra
.673 .701 .868 r
.55668 .39066 .55756 .3919 .55922 .39127 .55834 .39005 Mtetra
.576 .664 .898 r
.55834 .39005 .55922 .39127 .56088 .39129 .56 .38987 Mtetra
0 .095 .649 r
.56 .38987 .56088 .39129 .5626 .39518 .56169 .39173 Mtetra
0 0 .357 r
.56169 .39173 .5626 .39518 .56671 .59477 .56343 .397 Mtetra
0 0 .384 r
.56343 .397 .56671 .59477 .56856 .60064 .56754 .59246 Mtetra
.5 .353 .612 r
.56754 .59246 .56856 .60064 .57035 .60093 .56934 .59371 Mtetra
.594 .426 .624 r
.56934 .59371 .57035 .60093 .57212 .60034 .57111 .59298 Mtetra
.633 .453 .621 r
.57111 .59298 .57212 .60034 .57389 .59931 .57287 .59124 Mtetra
.587 .415 .616 r
.57287 .59124 .57389 .59931 .57567 .59876 .57464 .59058 Mtetra
.584 .413 .615 r
.57464 .59058 .57567 .59876 .57745 .59822 .57642 .58997 Mtetra
.584 .412 .614 r
.57642 .58997 .57745 .59822 .57923 .59768 .57819 .58937 Mtetra
.619 .436 .613 r
.57819 .58937 .57923 .59768 .58101 .59709 .57995 .5878 Mtetra
.59 .411 .606 r
.57995 .5878 .58101 .59709 .58279 .59654 .58173 .58691 Mtetra
.528 .364 .602 r
.58173 .58691 .58279 .59654 .58458 .59607 .58353 .58771 Mtetra
.362 .253 .594 r
.58353 .58771 .58458 .59607 .58637 .59587 .58538 .59134 Mtetra
.329 .286 .657 r
.58538 .59134 .58637 .59587 .58816 .5957 .58722 .59357 Mtetra
.262 .374 .789 r
.58722 .59357 .58816 .5957 .58996 .59549 .58904 .59481 Mtetra
.392 .723 .989 r
.58904 .59481 .58996 .59549 .59175 .59506 .59084 .59484 Mtetra
.422 .844 .958 r
.59084 .59484 .59175 .59506 .59354 .59454 .59264 .59447 Mtetra
.471 .887 .924 r
.59264 .59447 .59354 .59454 .59533 .59398 .59443 .59389 Mtetra
.509 .903 .937 r
.59443 .59389 .59533 .59398 .59712 .59345 .59622 .59326 Mtetra
.577 .919 .964 r
.59622 .59326 .59712 .59345 .59891 .59291 .59801 .59258 Mtetra
.63 .912 .982 r
.59801 .59258 .59891 .59291 .60071 .59236 .5998 .59189 Mtetra
.492 .825 .999 r
.5998 .59189 .60071 .59236 .60251 .59224 .60161 .59159 Mtetra
.588 .818 .987 r
.60161 .59159 .60251 .59224 .60431 .59187 .60341 .59117 Mtetra
.714 .843 .943 r
.60341 .59117 .60431 .59187 .6061 .59086 .6052 .59033 Mtetra
.911 .868 .783 r
.6052 .59033 .6061 .59086 .60781 .58658 .60695 .58786 Mtetra
.942 .896 .501 r
.60695 .58786 .60781 .58658 .60466 .38721 .60864 .58292 Mtetra
0 0 .385 r
.60864 .58292 .60466 .38721 .60613 .37786 .6055 .38565 Mtetra
.001 0 .305 r
.6055 .38565 .60613 .37786 .60779 .37588 .60702 .37814 Mtetra
0 0 0 r
.60702 .37814 .60779 .37588 .60947 .37502 .60865 .37519 Mtetra
.858 .997 .806 r
.60865 .37519 .60947 .37502 .61116 .37459 .6103 .37337 Mtetra
.727 .727 .85 r
.6103 .37337 .61116 .37459 .61286 .37405 .61199 .37243 Mtetra
.649 .638 .826 r
.61199 .37243 .61286 .37405 .61455 .37353 .61368 .3719 Mtetra
.613 .62 .834 r
.61368 .3719 .61455 .37353 .61625 .37305 .61538 .37157 Mtetra
.622 .644 .851 r
.61538 .37157 .61625 .37305 .61794 .37255 .61708 .37119 Mtetra
.625 .666 .869 r
.61708 .37119 .61794 .37255 .61964 .37202 .61878 .3708 Mtetra
.629 .692 .89 r
.61878 .3708 .61964 .37202 .62134 .37147 .62049 .3704 Mtetra
.651 .729 .906 r
.62049 .3704 .62134 .37147 .62303 .37087 .62219 .36989 Mtetra
.668 .754 .915 r
.62219 .36989 .62303 .37087 .62473 .37025 .62389 .36931 Mtetra
.682 .767 .916 r
.62389 .36931 .62473 .37025 .62643 .36963 .62558 .36866 Mtetra
.745 .781 .882 r
.62558 .36866 .62643 .36963 .62812 .36867 .62727 .36769 Mtetra
.73 .774 .888 r
.62727 .36769 .62812 .36867 .62981 .36788 .62896 .3668 Mtetra
.649 .729 .907 r
.62896 .3668 .62981 .36788 .63153 .36763 .63067 .3663 Mtetra
.111 .382 .84 r
.63067 .3663 .63153 .36763 .63333 .36997 .63243 .36738 Mtetra
0 0 .554 r
.63243 .36738 .63333 .36997 .64177 .56474 .63427 .37077 Mtetra
0 0 .408 r
.63427 .37077 .64177 .56474 .64404 .57714 .64274 .56445 Mtetra
.403 .262 .574 r
.64274 .56445 .64404 .57714 .64592 .57823 .64474 .5691 Mtetra
.603 .421 .608 r
.64474 .5691 .64592 .57823 .64775 .57764 .64653 .56783 Mtetra
.61 .422 .603 r
.64653 .56783 .64775 .57764 .64955 .57653 .64832 .56621 Mtetra
.395 .267 .586 r
.64832 .56621 .64955 .57653 .65138 .57599 .65031 .57017 Mtetra
.329 .261 .628 r
.65031 .57017 .65138 .57599 .65322 .57574 .65226 .57314 Mtetra
.282 .346 .751 r
.65226 .57314 .65322 .57574 .65505 .57544 .65417 .57464 Mtetra
.461 .731 .985 r
.65417 .57464 .65505 .57544 .65688 .57486 .65602 .57459 Mtetra
.647 .933 .969 r
.65602 .57459 .65688 .57486 .65871 .57411 .65784 .57378 Mtetra
.747 .944 .946 r
.65784 .57378 .65871 .57411 .66053 .57331 .65965 .5727 Mtetra
.713 .87 .956 r
.65965 .5727 .66053 .57331 .66236 .57261 .66148 .57184 Mtetra
.671 .822 .956 r
.66148 .57184 .66236 .57261 .66419 .57199 .66331 .57118 Mtetra
.658 .807 .954 r
.66331 .57118 .66419 .57199 .66602 .57143 .66514 .57057 Mtetra
.589 .77 .965 r
.66514 .57057 .66602 .57143 .66786 .571 .66699 .57021 Mtetra
.585 .787 .976 r
.66699 .57021 .66786 .571 .66971 .57061 .66883 .56983 Mtetra
.68 .823 .952 r
.66883 .56983 .66971 .57061 .67155 .57017 .67067 .56913 Mtetra
.854 .798 .795 r
.67067 .56913 .67155 .57017 .67339 .56947 .67244 .56704 Mtetra
.847 .671 .664 r
.67244 .56704 .67339 .56947 .67521 .56861 .67413 .56293 Mtetra
.853 .614 .575 r
.67413 .56293 .67521 .56861 .67704 .56775 .67551 .55207 Mtetra
.958 .669 .446 r
.67551 .55207 .67704 .56775 .67888 .56714 .66897 .36609 Mtetra
.551 .337 .542 r
.66897 .36609 .67888 .56714 .68074 .56675 .67073 .36626 Mtetra
.069 0 .44 r
.67073 .36626 .68074 .56675 .6826 .5665 .68099 .54977 Mtetra
.284 .169 .541 r
.68099 .54977 .6826 .5665 .68447 .56641 .68332 .55966 Mtetra
.317 .241 .611 r
.68332 .55966 .68447 .56641 .68634 .56637 .68536 .5633 Mtetra
.288 .319 .72 r
.68536 .5633 .68634 .56637 .68821 .56627 .68733 .56509 Mtetra
.381 .598 .931 r
.68733 .56509 .68821 .56627 .69007 .56595 .68922 .56545 Mtetra
.542 .846 .999 r
.68922 .56545 .69007 .56595 .69193 .56547 .69108 .56503 Mtetra
.625 .894 .987 r
.69108 .56503 .69193 .56547 .69379 .56492 .69294 .56438 Mtetra
.621 .864 .989 r
.69294 .56438 .69379 .56492 .69564 .56439 .69479 .56379 Mtetra
.593 .841 .991 r
.69479 .56379 .69564 .56439 .6975 .56387 .69665 .5633 Mtetra
.59 .848 .993 r
.69665 .5633 .6975 .56387 .69936 .56335 .69851 .56281 Mtetra
.502 .819 1 r
.69851 .56281 .69936 .56335 .70124 .56313 .70039 .5625 Mtetra
.529 .808 .997 r
.70039 .5625 .70124 .56313 .70312 .56292 .70226 .56219 Mtetra
.671 .835 .962 r
.70226 .56219 .70312 .56292 .70497 .56216 .70412 .56151 Mtetra
.868 .876 .84 r
.70412 .56151 .70497 .56216 .7067 .55923 .70591 .55962 Mtetra
.974 .922 .617 r
.70591 .55962 .7067 .55923 .70794 .5471 .70759 .55561 Mtetra
0 0 .09 r
.70759 .55561 .70794 .5471 .69893 .34864 .70862 .53988 Mtetra
.028 0 .421 r
.70862 .53988 .69893 .34864 .70054 .34555 .69996 .34871 Mtetra
0 0 .164 r
.69996 .34871 .70054 .34555 .70226 .34451 .70154 .34516 Mtetra
.688 .912 .574 r
.70154 .34516 .70226 .34451 .70401 .34398 .70321 .34309 Mtetra
.768 .81 .886 r
.70321 .34309 .70401 .34398 .70577 .34353 .70493 .34199 Mtetra
.637 .647 .844 r
.70493 .34199 .70577 .34353 .70752 .34302 .70668 .34152 Mtetra
.591 .632 .86 r
.70668 .34152 .70752 .34302 .70928 .34255 .70845 .34128 Mtetra
.648 .697 .881 r
.70845 .34128 .70928 .34255 .71102 .34178 .71021 .34077 Mtetra
.706 .768 .901 r
.71021 .34077 .71102 .34178 .71275 .34089 .71195 .33999 Mtetra
.636 .77 .944 r
.71195 .33999 .71275 .34089 .71452 .34047 .71371 .33951 Mtetra
.248 .552 .93 r
.71371 .33951 .71452 .34047 .7164 .34192 .71554 .34005 Mtetra
0 .065 .629 r
.71554 .34005 .7164 .34192 .71889 .35335 .71749 .34267 Mtetra
.979 .684 .342 r
.71749 .34267 .71889 .35335 .73284 .55047 .73079 .52994 Mtetra
.159 .076 .505 r
.73079 .52994 .73284 .55047 .7349 .55283 .73373 .54672 Mtetra
.386 .299 .634 r
.73373 .54672 .7349 .55283 .73682 .55281 .73581 .5493 Mtetra
.433 .393 .714 r
.73581 .5493 .73682 .55281 .7387 .55222 .7378 .55042 Mtetra
.42 .514 .849 r
.7378 .55042 .7387 .55222 .74059 .55181 .73975 .55098 Mtetra
.408 .697 .98 r
.73975 .55098 .74059 .55181 .74251 .55165 .74168 .55106 Mtetra
.655 .871 .98 r
.74168 .55106 .74251 .55165 .74438 .5509 .74356 .55037 Mtetra
.933 .885 .761 r
.74356 .55037 .74438 .5509 .74613 .54814 .74531 .54761 Mtetra
.986 .747 .486 r
.74531 .54761 .74613 .54814 .74719 .53511 .74638 .53461 Mtetra
.977 .683 .385 r
.74638 .53461 .74719 .53511 .73581 .33587 .73498 .33439 Mtetra
.879 .74 .705 r
.73498 .33439 .73581 .33587 .7374 .33271 .73658 .33125 Mtetra
.679 .681 .845 r
.73658 .33125 .7374 .33271 .73916 .33189 .73834 .33054 Mtetra
.562 .645 .889 r
.73834 .33054 .73916 .33189 .74095 .33163 .74014 .33041 Mtetra
.592 .684 .905 r
.74014 .33041 .74095 .33163 .74273 .33118 .74193 .33014 Mtetra
.705 .765 .899 r
.74193 .33014 .74273 .33118 .74448 .33028 .74369 .32936 Mtetra
.641 .77 .941 r
.74369 .32936 .74448 .33028 .74626 .32982 .74547 .32885 Mtetra
.333 .604 .947 r
.74547 .32885 .74626 .32982 .74815 .3309 .74732 .32922 Mtetra
0 .118 .669 r
.74732 .32922 .74815 .3309 .75053 .33871 .7493 .33155 Mtetra
0 0 .393 r
.7493 .33155 .75053 .33871 .76683 .53986 .75192 .34266 Mtetra
.066 0 .448 r
.75192 .34266 .76683 .53986 .76899 .54281 .76777 .53653 Mtetra
.36 .28 .629 r
.76777 .53653 .76899 .54281 .77094 .54292 .76993 .53955 Mtetra
.405 .382 .721 r
.76993 .53955 .77094 .54292 .77285 .54241 .77197 .54085 Mtetra
.42 .549 .88 r
.77197 .54085 .77285 .54241 .77476 .5419 .77396 .5413 Mtetra
.448 .781 .998 r
.77396 .5413 .77476 .5419 .7767 .5417 .7759 .54114 Mtetra
.658 .882 .981 r
.7759 .54114 .7767 .5417 .7786 .54097 .7778 .54041 Mtetra
.848 .914 .878 r
.7778 .54041 .7786 .54097 .78038 .53873 .77963 .53877 Mtetra
.97 .932 .67 r
.77963 .53877 .78038 .53873 .78174 .53089 .78132 .53529 Mtetra
0 0 .061 r
.78132 .53529 .78174 .53089 .76797 .32724 .78263 .52683 Mtetra
.064 0 .442 r
.78263 .52683 .76797 .32724 .76948 .32299 .7691 .32716 Mtetra
.042 0 .266 r
.7691 .32716 .76948 .32299 .77122 .32174 .7706 .32285 Mtetra
0 0 0 r
.7706 .32285 .77122 .32174 .773 .32108 .77226 .3205 Mtetra
.821 .899 .896 r
.77226 .3205 .773 .32108 .7748 .32063 .77399 .31913 Mtetra
.655 .666 .849 r
.77399 .31913 .7748 .32063 .7766 .32005 .77578 .31855 Mtetra
.609 .644 .86 r
.77578 .31855 .7766 .32005 .7784 .31953 .7776 .31822 Mtetra
.618 .68 .886 r
.7776 .31822 .7784 .31953 .7802 .319 .77941 .31784 Mtetra
.693 .74 .887 r
.77941 .31784 .7802 .319 .78199 .31838 .78119 .31709 Mtetra
.694 .717 .867 r
.78119 .31709 .78199 .31838 .78379 .31776 .78298 .31632 Mtetra
.694 .694 .845 r
.78298 .31632 .78379 .31776 .78557 .31701 .78476 .31551 Mtetra
.698 .686 .835 r
.78476 .31551 .78557 .31701 .78734 .31605 .78654 .31466 Mtetra
.651 .682 .866 r
.78654 .31466 .78734 .31605 .78914 .31552 .78834 .31411 Mtetra
.467 .587 .89 r
.78834 .31411 .78914 .31552 .79105 .3162 .79021 .31436 Mtetra
0 .144 .685 r
.79021 .31436 .79105 .3162 .79343 .3223 .79227 .31678 Mtetra
0 0 .4 r
.79227 .31678 .79343 .3223 .81277 .52565 .79494 .3262 Mtetra
.089 .008 .461 r
.79494 .3262 .81277 .52565 .81506 .52924 .81367 .52153 Mtetra
.538 .387 .623 r
.81367 .52153 .81506 .52924 .81705 .52919 .8157 .52201 Mtetra
.602 .434 .626 r
.8157 .52201 .81705 .52919 .81897 .52843 .8176 .52104 Mtetra
.608 .436 .623 r
.8176 .52104 .81897 .52843 .82088 .52758 .81948 .51988 Mtetra
.542 .389 .623 r
.81948 .51988 .82088 .52758 .82286 .52746 .8215 .52028 Mtetra
.587 .424 .627 r
.8215 .52028 .82286 .52746 .8248 .52685 .82344 .51967 Mtetra
.697 .497 .613 r
.82344 .51967 .8248 .52685 .82662 .5249 .82509 .51594 Mtetra
.973 .67 .371 r
.82509 .51594 .82662 .5249 .82782 .51616 .80891 .31513 Mtetra
.561 .344 .543 r
.80891 .31513 .82782 .51616 .8112 .31243 .81026 .30938 Mtetra
.766 .605 .678 r
.81026 .30938 .8112 .31243 .81269 .30823 .81189 .30674 Mtetra
.701 .69 .836 r
.81189 .30674 .81269 .30823 .81447 .30721 .81368 .30586 Mtetra
.63 .681 .879 r
.81368 .30586 .81447 .30721 .8163 .30681 .81551 .30542 Mtetra
.588 .654 .882 r
.81551 .30542 .8163 .30681 .81816 .30663 .81736 .30517 Mtetra
.617 .658 .867 r
.81736 .30517 .81816 .30663 .81999 .30608 .8192 .30479 Mtetra
.613 .684 .893 r
.8192 .30479 .81999 .30608 .82181 .30553 .82105 .30443 Mtetra
.622 .725 .92 r
.82105 .30443 .82181 .30553 .82364 .30496 .82289 .30401 Mtetra
.663 .775 .933 r
.82289 .30401 .82364 .30496 .82546 .30434 .82471 .3034 Mtetra
.677 .785 .931 r
.82471 .3034 .82546 .30434 .82728 .3037 .82653 .30273 Mtetra
.701 .788 .918 r
.82653 .30273 .82728 .3037 .82909 .30296 .82834 .30195 Mtetra
.768 .8 .879 r
.82834 .30195 .82909 .30296 .83087 .30184 .83011 .3008 Mtetra
.689 .769 .912 r
.83011 .3008 .83087 .30184 .83268 .30113 .83193 .30008 Mtetra
.397 .622 .943 r
.83193 .30008 .83268 .30113 .8346 .30141 .83385 .30036 Mtetra
.819 .405 0 r
.83385 .30036 .8346 .30141 .83704 .30692 .8363 .30598 Mtetra
.973 .661 .313 r
.8363 .30598 .83704 .30692 .85951 .51192 .85872 .51096 Mtetra
.733 .285 0 r
.85872 .51096 .85951 .51192 .86196 .51618 .86117 .51516 Mtetra
.32 .6 .947 r
.86117 .51516 .86196 .51618 .86403 .51663 .86324 .5156 Mtetra
.666 .776 .932 r
.86324 .5156 .86403 .51663 .86599 .51597 .8652 .51493 Mtetra
.85 .825 .823 r
.8652 .51493 .86599 .51597 .86783 .51404 .86703 .513 Mtetra
.978 .78 .57 r
.86703 .513 .86783 .51404 .86917 .50737 .86838 .50634 Mtetra
.976 .67 .325 r
.86838 .50634 .86917 .50737 .84973 .30094 .84898 .29984 Mtetra
.966 .782 .603 r
.84898 .29984 .84973 .30094 .85108 .29561 .85032 .29449 Mtetra
.761 .779 .868 r
.85032 .29449 .85108 .29561 .85286 .29446 .85211 .29334 Mtetra
.63 .728 .917 r
.85211 .29334 .85286 .29446 .85472 .294 .85397 .29288 Mtetra
.554 .691 .931 r
.85397 .29288 .85472 .294 .85661 .29384 .85586 .29272 Mtetra
.751 .775 .872 r
.85586 .29272 .85661 .29384 .8584 .29275 .85765 .29163 Mtetra
.683 .749 .901 r
.85765 .29163 .8584 .29275 .86023 .29205 .85949 .29093 Mtetra
.477 .649 .934 r
.85949 .29093 .86023 .29205 .86216 .29215 .86141 .29102 Mtetra
.75 .334 0 r
.86141 .29102 .86216 .29215 .86461 .29713 .86386 .29599 Mtetra
.971 .656 .295 r
.86386 .29599 .86461 .29713 .88905 .50272 .88826 .50163 Mtetra
.731 .3 0 r
.88826 .50163 .88905 .50272 .89161 .50746 .89083 .50638 Mtetra
.303 .575 .936 r
.89083 .50638 .89161 .50746 .89373 .50799 .89295 .50691 Mtetra
.648 .762 .932 r
.89295 .50691 .89373 .50799 .89572 .5074 .89494 .50632 Mtetra
.828 .819 .841 r
.89494 .50632 .89572 .5074 .89758 .50569 .8968 .5046 Mtetra
.908 .735 .655 r
.2581 .68977 .25915 .69064 .26112 .68502 .26007 .68411 Mtetra
.936 .686 .535 r
.26007 .68411 .26112 .68502 .27733 .48885 .27636 .48788 Mtetra
.904 .724 .649 r
.27636 .48788 .27733 .48885 .27922 .48317 .27824 .48224 Mtetra
.764 .754 .844 r
.27824 .48224 .27922 .48317 .28076 .4821 .27978 .48117 Mtetra
.622 .726 .922 r
.27978 .48117 .28076 .4821 .28224 .48175 .28127 .48083 Mtetra
.478 .676 .951 r
.28127 .48083 .28224 .48175 .28371 .48177 .28273 .48085 Mtetra
.652 .738 .913 r
.28273 .48085 .28371 .48177 .2852 .48131 .28423 .4804 Mtetra
.666 .744 .908 r
.28423 .4804 .2852 .48131 .28671 .48079 .28573 .4799 Mtetra
.677 .749 .905 r
.28573 .4799 .28671 .48079 .28822 .48022 .28724 .47934 Mtetra
.775 .767 .846 r
.28724 .47934 .28822 .48022 .28977 .47904 .28879 .47821 Mtetra
.731 .773 .887 r
.28879 .47821 .28977 .47904 .2913 .4782 .29031 .47741 Mtetra
.537 .734 .966 r
.29031 .47741 .2913 .4782 .29278 .47801 .29179 .47726 Mtetra
.914 .522 .237 r
.29179 .47726 .29278 .47801 .29401 .48146 .29301 .48086 Mtetra
.939 .682 .522 r
.29301 .48086 .29401 .48146 .28191 .67687 .28085 .67639 Mtetra
.925 .586 .375 r
.28085 .67639 .28191 .67687 .28304 .68322 .28199 .6824 Mtetra
0 .285 .734 r
.28199 .6824 .28304 .68322 .28454 .68414 .2835 .68328 Mtetra
.622 .757 .943 r
.2835 .68328 .28454 .68414 .28613 .68377 .28509 .68289 Mtetra
.807 .778 .826 r
.28509 .68289 .28613 .68377 .2878 .68229 .28676 .6814 Mtetra
.91 .738 .656 r
.28676 .6814 .2878 .68229 .28974 .67673 .28871 .67586 Mtetra
.939 .687 .529 r
.28871 .67586 .28974 .67673 .30447 .47957 .3035 .47869 Mtetra
.911 .732 .647 r
.3035 .47869 .30447 .47957 .30633 .47392 .30536 .47302 Mtetra
.782 .766 .838 r
.30536 .47302 .30633 .47392 .30789 .47273 .30692 .47182 Mtetra
.599 .725 .933 r
.30692 .47182 .30789 .47273 .30939 .47248 .30842 .47154 Mtetra
.424 .65 .953 r
.30842 .47154 .30939 .47248 .31086 .47264 .30989 .47168 Mtetra
.615 .72 .921 r
.30989 .47168 .31086 .47264 .31236 .47231 .3114 .47136 Mtetra
.651 .732 .909 r
.3114 .47136 .31236 .47231 .31388 .47185 .31291 .47091 Mtetra
.659 .738 .908 r
.31291 .47091 .31388 .47185 .3154 .47134 .31443 .47042 Mtetra
.75 .76 .862 r
.31443 .47042 .3154 .47134 .31694 .47036 .31598 .46947 Mtetra
.712 .759 .889 r
.31598 .46947 .31694 .47036 .31848 .46962 .31751 .46874 Mtetra
.518 .706 .956 r
.31751 .46874 .31848 .46962 .31997 .46952 .319 .46867 Mtetra
.916 .519 .208 r
.319 .46867 .31997 .46952 .32124 .47314 .32027 .47234 Mtetra
.942 .683 .516 r
.32027 .47234 .32124 .47314 .3107 .6694 .30966 .66863 Mtetra
.934 .58 .328 r
.30966 .66863 .3107 .6694 .31193 .67506 .3109 .6742 Mtetra
.123 .519 .913 r
.3109 .6742 .31193 .67506 .31349 .67558 .31246 .67472 Mtetra
.691 .775 .915 r
.31246 .67472 .31349 .67558 .31512 .67491 .31409 .67406 Mtetra
.77 .787 .867 r
.31409 .67406 .31512 .67491 .31678 .67377 .31574 .67294 Mtetra
.673 .779 .929 r
.31574 .67294 .31678 .67377 .31839 .67334 .31737 .67236 Mtetra
.642 .739 .919 r
.31737 .67236 .31839 .67334 .32001 .67297 .31899 .67192 Mtetra
.677 .732 .891 r
.31899 .67192 .32001 .67297 .32164 .67222 .32062 .67131 Mtetra
.786 .777 .844 r
.32062 .67131 .32164 .67222 .32339 .66963 .32229 .67002 Mtetra
.851 .996 .824 r
.32229 .67002 .32339 .66963 .32531 .66394 .32399 .66826 Mtetra
.277 0 .296 r
.32399 .66826 .32531 .66394 .33778 .47236 .3257 .66623 Mtetra
.55 .331 .536 r
.3257 .66623 .33778 .47236 .33945 .4694 .32732 .66579 Mtetra
.55 .332 .536 r
.32732 .66579 .33945 .4694 .34096 .4694 .32892 .66574 Mtetra
.549 .331 .536 r
.32892 .66574 .34096 .4694 .34247 .46943 .33057 .66491 Mtetra
.536 .32 .533 r
.33057 .66491 .34247 .46943 .34418 .46573 .3326 .65708 Mtetra
0 0 .25 r
.3326 .65708 .34418 .46573 .34586 .46257 .34478 .46405 Mtetra
.965 .922 .586 r
.34478 .46405 .34586 .46257 .34749 .4604 .34652 .45973 Mtetra
.825 .811 .837 r
.34652 .45973 .34749 .4604 .34905 .45938 .34811 .45826 Mtetra
.667 .706 .876 r
.34811 .45826 .34905 .45938 .35059 .45888 .34965 .45773 Mtetra
.588 .672 .898 r
.34965 .45773 .35059 .45888 .35212 .45857 .35117 .45752 Mtetra
.63 .707 .902 r
.35117 .45752 .35212 .45857 .35366 .45814 .35271 .45714 Mtetra
.653 .725 .902 r
.35271 .45714 .35366 .45814 .35519 .45766 .35424 .45667 Mtetra
.647 .726 .907 r
.35424 .45667 .35519 .45766 .35673 .4572 .35578 .45623 Mtetra
.631 .725 .915 r
.35578 .45623 .35673 .4572 .35827 .45682 .35732 .45585 Mtetra
.622 .723 .918 r
.35732 .45585 .35827 .45682 .3598 .45648 .35886 .4555 Mtetra
.624 .722 .916 r
.35886 .4555 .3598 .45648 .36134 .45612 .36039 .45514 Mtetra
.641 .726 .91 r
.36039 .45514 .36134 .45612 .36288 .45569 .36193 .45472 Mtetra
.656 .733 .906 r
.36193 .45472 .36288 .45569 .36443 .45519 .36348 .45423 Mtetra
.668 .741 .905 r
.36348 .45423 .36443 .45519 .36598 .45462 .36503 .4537 Mtetra
.685 .753 .903 r
.36503 .4537 .36598 .45462 .36753 .45396 .36658 .4531 Mtetra
.695 .769 .908 r
.36658 .4531 .36753 .45396 .36909 .45324 .36814 .45245 Mtetra
.696 .784 .919 r
.36814 .45245 .36909 .45324 .37065 .45254 .36969 .45181 Mtetra
.706 .799 .923 r
.36969 .45181 .37065 .45254 .37221 .45174 .37125 .45112 Mtetra
.689 .826 .949 r
.37125 .45112 .37221 .45174 .37377 .45103 .37281 .45049 Mtetra
.623 .832 .981 r
.37281 .45049 .37377 .45103 .37532 .4507 .37436 .45004 Mtetra
.335 .685 .98 r
.37436 .45004 .37532 .4507 .3768 .45169 .37588 .45017 Mtetra
.299 .461 .854 r
.37588 .45017 .3768 .45169 .37818 .45506 .37738 .45085 Mtetra
.452 .364 .666 r
.37738 .45085 .37818 .45506 .3713 .64512 .37887 .45188 Mtetra
.551 .337 .542 r
.37887 .45188 .3713 .64512 .37269 .65045 .38041 .45178 Mtetra
.553 .338 .542 r
.38041 .45178 .37269 .65045 .37435 .6498 .38199 .45087 Mtetra
.552 .337 .542 r
.38199 .45087 .37435 .6498 .37602 .64883 .38354 .45056 Mtetra
.542 .329 .541 r
.38354 .45056 .37602 .64883 .37755 .65108 .38489 .45498 Mtetra
0 0 .295 r
.38489 .45498 .37755 .65108 .37908 .65364 .37822 .64931 Mtetra
0 0 .483 r
.37822 .64931 .37908 .65364 .38065 .65511 .37967 .65362 Mtetra
.158 .397 .843 r
.37967 .65362 .38065 .65511 .38228 .65542 .38127 .65456 Mtetra
.612 .761 .95 r
.38127 .65456 .38228 .65542 .38394 .65502 .38293 .65419 Mtetra
.711 .79 .913 r
.38293 .65419 .38394 .65502 .3856 .65441 .3846 .65342 Mtetra
.67 .75 .911 r
.3846 .65342 .3856 .65441 .38726 .65402 .38627 .65284 Mtetra
.628 .7 .897 r
.38627 .65284 .38726 .65402 .38892 .65373 .38793 .65245 Mtetra
.663 .694 .869 r
.38793 .65245 .38892 .65373 .39059 .65308 .3896 .65189 Mtetra
.721 .724 .853 r
.3896 .65189 .39059 .65308 .3923 .65131 .39128 .65099 Mtetra
.831 .908 .891 r
.39128 .65099 .3923 .65131 .39409 .6475 .39298 .64958 Mtetra
0 0 0 r
.39298 .64958 .39409 .6475 .39625 .63376 .39471 .64731 Mtetra
.306 .1 .428 r
.39471 .64731 .39625 .63376 .40479 .44598 .39659 .641 Mtetra
0 0 .29 r
.39659 .641 .40479 .44598 .40647 .44248 .40541 .44505 Mtetra
.806 .831 .36 r
.40541 .44505 .40647 .44248 .40809 .44046 .40714 .44014 Mtetra
.887 .879 .821 r
.40714 .44014 .40809 .44046 .40969 .43932 .40876 .43825 Mtetra
.688 .725 .878 r
.40876 .43825 .40969 .43932 .41126 .43875 .41034 .4376 Mtetra
.596 .681 .9 r
.41034 .4376 .41126 .43875 .41283 .43842 .4119 .43735 Mtetra
.585 .693 .916 r
.4119 .43735 .41283 .43842 .4144 .43813 .41347 .43713 Mtetra
.619 .718 .917 r
.41347 .43713 .4144 .43813 .41597 .4378 .41504 .43678 Mtetra
.617 .714 .915 r
.41504 .43678 .41597 .4378 .41754 .43748 .41661 .43645 Mtetra
.633 .717 .908 r
.41661 .43645 .41754 .43748 .41911 .43708 .41818 .43605 Mtetra
.652 .723 .901 r
.41818 .43605 .41911 .43708 .42069 .4366 .41976 .43557 Mtetra
.66 .728 .9 r
.41976 .43557 .42069 .4366 .42227 .43608 .42134 .43507 Mtetra
.662 .731 .901 r
.42134 .43507 .42227 .43608 .42385 .43555 .42292 .43455 Mtetra
.663 .733 .902 r
.42292 .43455 .42385 .43555 .42543 .43503 .4245 .43403 Mtetra
.666 .735 .901 r
.4245 .43403 .42543 .43503 .42701 .43449 .42609 .43349 Mtetra
.667 .735 .901 r
.42609 .43349 .42701 .43449 .4286 .43396 .42767 .43296 Mtetra
.668 .735 .9 r
.42767 .43296 .4286 .43396 .43018 .43342 .42926 .43241 Mtetra
.675 .735 .896 r
.42926 .43241 .43018 .43342 .43177 .43285 .43085 .43183 Mtetra
.689 .738 .888 r
.43085 .43183 .43177 .43285 .43336 .43221 .43244 .43119 Mtetra
.702 .742 .882 r
.43244 .43119 .43336 .43221 .43495 .43148 .43403 .43047 Mtetra
.701 .744 .885 r
.43403 .43047 .43495 .43148 .43654 .43076 .43562 .42977 Mtetra
.718 .751 .879 r
.43562 .42977 .43654 .43076 .43814 .43002 .43722 .42898 Mtetra
.717 .741 .87 r
.43722 .42898 .43814 .43002 .43973 .42932 .43882 .42817 Mtetra
.641 .699 .888 r
.43882 .42817 .43973 .42932 .44132 .42884 .4404 .42774 Mtetra
.132 .449 .882 r
.4404 .42774 .44132 .42884 .4429 .42901 .44196 .42848 Mtetra
.904 .497 .202 r
.44196 .42848 .4429 .42901 .44444 .4303 .44345 .43236 Mtetra
.952 .681 .486 r
.44345 .43236 .44444 .4303 .44597 .43272 .44024 .62775 Mtetra
.559 .339 .537 r
.44024 .62775 .44597 .43272 .44748 .43583 .4418 .63272 Mtetra
.55 .332 .536 r
.4418 .63272 .44748 .43583 .44906 .43599 .44348 .63269 Mtetra
.549 .331 .536 r
.44348 .63269 .44906 .43599 .45068 .43461 .44519 .63178 Mtetra
.548 .33 .536 r
.44519 .63178 .45068 .43461 .45231 .43279 .4469 .63063 Mtetra
.549 .331 .536 r
.4469 .63063 .45231 .43279 .45393 .43134 .44861 .62986 Mtetra
.55 .331 .536 r
.44861 .62986 .45393 .43134 .45553 .43108 .45031 .62942 Mtetra
.551 .332 .536 r
.45031 .62942 .45553 .43108 .457 .43711 .45199 .62986 Mtetra
.553 .333 .536 r
.45199 .62986 .457 .43711 .4547 .62828 .45365 .63104 Mtetra
.601 .256 .357 r
.45365 .63104 .4547 .62828 .45632 .63208 .45533 .6319 Mtetra
.152 0 0 r
.45533 .6319 .45632 .63208 .45799 .63342 .45702 .63224 Mtetra
.588 .688 .911 r
.45702 .63224 .45799 .63342 .45969 .6333 .45872 .63199 Mtetra
.636 .683 .878 r
.45872 .63199 .45969 .6333 .4614 .63279 .46043 .63156 Mtetra
.658 .703 .88 r
.46043 .63156 .4614 .63279 .46311 .63212 .46214 .63101 Mtetra
.667 .729 .896 r
.46214 .63101 .46311 .63212 .46482 .63148 .46385 .63042 Mtetra
.675 .743 .902 r
.46385 .63042 .46482 .63148 .46654 .63079 .46557 .6298 Mtetra
.643 .747 .925 r
.46557 .6298 .46654 .63079 .46825 .6302 .46728 .62932 Mtetra
.557 .741 .962 r
.46728 .62932 .46825 .6302 .46996 .62985 .46899 .6291 Mtetra
.656 .805 .955 r
.46899 .6291 .46996 .62985 .47168 .62932 .4707 .62854 Mtetra
.829 .818 .839 r
.4707 .62854 .47168 .62932 .4734 .62821 .47244 .62693 Mtetra
.904 .735 .663 r
.47244 .62693 .4734 .62821 .47514 .62581 .47422 .62214 Mtetra
.955 .687 .487 r
.47422 .62214 .47514 .62581 .4769 .6223 .47871 .42613 Mtetra
.566 .348 .544 r
.47871 .42613 .4769 .6223 .47867 .61781 .48043 .41848 Mtetra
.553 .338 .542 r
.48043 .41848 .47867 .61781 .4804 .61636 .48205 .41737 Mtetra
.552 .337 .542 r
.48205 .41737 .4804 .61636 .48211 .61654 .48367 .41715 Mtetra
.551 .336 .542 r
.48367 .41715 .48211 .61654 .48381 .61734 .48528 .41729 Mtetra
.552 .337 .542 r
.48528 .41729 .48381 .61734 .48551 .61798 .4869 .4171 Mtetra
.4869 .4171 .48551 .61798 .48723 .61747 .48852 .41664 Mtetra
.554 .338 .542 r
.48852 .41664 .48723 .61747 .489 .61318 .49015 .41544 Mtetra
.555 .34 .543 r
.49015 .41544 .489 .61318 .49265 .41837 .49179 .41331 Mtetra
.666 .495 .644 r
.49179 .41331 .49265 .41837 .49432 .4133 .49342 .41149 Mtetra
.737 .651 .764 r
.49342 .41149 .49432 .4133 .49596 .41088 .49505 .41016 Mtetra
.686 .81 .941 r
.49505 .41016 .49596 .41088 .49758 .41009 .49668 .40952 Mtetra
.617 .832 .983 r
.49668 .40952 .49758 .41009 .49921 .40968 .4983 .40907 Mtetra
.603 .816 .982 r
.4983 .40907 .49921 .40968 .50083 .40939 .49993 .40866 Mtetra
.655 .802 .953 r
.49993 .40866 .50083 .40939 .50246 .40886 .50156 .40814 Mtetra
.657 .802 .952 r
.50156 .40814 .50246 .40886 .50408 .40834 .50319 .4076 Mtetra
.66 .8 .95 r
.50319 .4076 .50408 .40834 .50571 .40781 .50481 .40706 Mtetra
.664 .799 .947 r
.50481 .40706 .50571 .40781 .50734 .40726 .50644 .4065 Mtetra
.666 .797 .945 r
.50644 .4065 .50734 .40726 .50897 .40671 .50808 .40594 Mtetra
.667 .795 .943 r
.50808 .40594 .50897 .40671 .5106 .40615 .50971 .40538 Mtetra
.666 .793 .943 r
.50971 .40538 .5106 .40615 .51224 .4056 .51134 .40482 Mtetra
.665 .792 .942 r
.51134 .40482 .51224 .4056 .51387 .40504 .51298 .40426 Mtetra
.665 .79 .941 r
.51298 .40426 .51387 .40504 .5155 .40449 .51461 .4037 Mtetra
.665 .789 .941 r
.51461 .4037 .5155 .40449 .51714 .40394 .51625 .40315 Mtetra
.664 .789 .941 r
.51625 .40315 .51714 .40394 .51878 .40339 .51788 .40259 Mtetra
.664 .788 .941 r
.51788 .40259 .51878 .40339 .52041 .40284 .51952 .40204 Mtetra
.663 .788 .941 r
.51952 .40204 .52041 .40284 .52205 .40229 .52116 .40149 Mtetra
.52116 .40149 .52205 .40229 .52369 .40174 .5228 .40094 Mtetra
.662 .788 .941 r
.5228 .40094 .52369 .40174 .52533 .40119 .52444 .40039 Mtetra
.661 .787 .942 r
.52444 .40039 .52533 .40119 .52697 .40065 .52608 .39985 Mtetra
.52608 .39985 .52697 .40065 .52861 .40011 .52773 .39931 Mtetra
.66 .787 .942 r
.52773 .39931 .52861 .40011 .53026 .39957 .52937 .39877 Mtetra
.659 .787 .942 r
.52937 .39877 .53026 .39957 .5319 .39903 .53102 .39823 Mtetra
.53102 .39823 .5319 .39903 .53355 .39849 .53266 .39769 Mtetra
.658 .786 .943 r
.53266 .39769 .53355 .39849 .53519 .39796 .53431 .39716 Mtetra
.53431 .39716 .53519 .39796 .53684 .39743 .53596 .39662 Mtetra
.657 .786 .943 r
.53596 .39662 .53684 .39743 .53849 .39689 .53761 .39609 Mtetra
.657 .787 .944 r
.53761 .39609 .53849 .39689 .54014 .39636 .53926 .39556 Mtetra
.656 .787 .944 r
.53926 .39556 .54014 .39636 .54179 .39583 .54091 .39503 Mtetra
.655 .788 .945 r
.54091 .39503 .54179 .39583 .54344 .3953 .54256 .39451 Mtetra
.654 .789 .946 r
.54256 .39451 .54344 .3953 .54509 .39477 .54421 .39398 Mtetra
.653 .79 .948 r
.54421 .39398 .54509 .39477 .54674 .39424 .54586 .39346 Mtetra
.653 .792 .949 r
.54586 .39346 .54674 .39424 .5484 .39371 .54752 .39294 Mtetra
.654 .795 .95 r
.54752 .39294 .5484 .39371 .55005 .39317 .54918 .39241 Mtetra
.658 .798 .949 r
.54918 .39241 .55005 .39317 .55171 .39261 .55083 .39186 Mtetra
.66 .801 .951 r
.55083 .39186 .55171 .39261 .55337 .39205 .55249 .39131 Mtetra
.662 .804 .951 r
.55249 .39131 .55337 .39205 .55502 .39149 .55415 .39075 Mtetra
.699 .814 .937 r
.55415 .39075 .55502 .39149 .55668 .39066 .55581 .39005 Mtetra
.665 .84 .967 r
.55581 .39005 .55668 .39066 .55834 .39005 .55747 .38945 Mtetra
.59 .82 .987 r
.55747 .38945 .55834 .39005 .56 .38987 .55913 .38906 Mtetra
.215 .575 .941 r
.55913 .38906 .56 .38987 .56169 .39173 .5608 .38949 Mtetra
.387 .427 .781 r
.5608 .38949 .56169 .39173 .56343 .397 .56248 .39033 Mtetra
.493 .356 .623 r
.56248 .39033 .56343 .397 .56754 .59246 .56417 .39146 Mtetra
.552 .337 .542 r
.56417 .39146 .56754 .59246 .56934 .59371 .56584 .39132 Mtetra
.552 .338 .542 r
.56584 .39132 .56934 .59371 .57111 .59298 .56751 .39064 Mtetra
.553 .338 .542 r
.56751 .39064 .57111 .59298 .57287 .59124 .56918 .38973 Mtetra
.552 .338 .542 r
.56918 .38973 .57287 .59124 .57464 .59058 .57085 .3891 Mtetra
.57085 .3891 .57464 .59058 .57642 .58997 .57252 .38849 Mtetra
.552 .337 .542 r
.57252 .38849 .57642 .58997 .57819 .58937 .57419 .38791 Mtetra
.553 .338 .542 r
.57419 .38791 .57819 .58937 .57995 .5878 .57585 .38669 Mtetra
.57585 .38669 .57995 .5878 .58173 .58691 .57752 .38596 Mtetra
.551 .336 .542 r
.57752 .38596 .58173 .58691 .58353 .58771 .57921 .38625 Mtetra
.51 .305 .537 r
.57921 .38625 .58353 .58771 .58538 .59134 .58127 .40737 Mtetra
0 0 .388 r
.58127 .40737 .58538 .59134 .58722 .59357 .58626 .59053 Mtetra
0 .076 .613 r
.58626 .59053 .58722 .59357 .58904 .59481 .58812 .59368 Mtetra
.401 .614 .937 r
.58812 .59368 .58904 .59481 .59084 .59484 .58992 .59395 Mtetra
.619 .771 .953 r
.58992 .59395 .59084 .59484 .59264 .59447 .59172 .59352 Mtetra
.702 .782 .914 r
.59172 .59352 .59264 .59447 .59443 .59389 .59351 .59275 Mtetra
.677 .737 .895 r
.59351 .59275 .59443 .59389 .59622 .59326 .5953 .59208 Mtetra
.681 .732 .889 r
.5953 .59208 .59622 .59326 .59801 .59258 .59709 .5914 Mtetra
.682 .732 .888 r
.59709 .5914 .59801 .59258 .5998 .59189 .59888 .59071 Mtetra
.629 .713 .907 r
.59888 .59071 .5998 .59189 .60161 .59159 .60068 .59027 Mtetra
.637 .691 .884 r
.60068 .59027 .60161 .59159 .60341 .59117 .60248 .5898 Mtetra
.672 .697 .865 r
.60248 .5898 .60341 .59117 .6052 .59033 .60428 .58914 Mtetra
.745 .748 .855 r
.60428 .58914 .6052 .59033 .60695 .58786 .60607 .58805 Mtetra
.803 1 .824 r
.60607 .58805 .60695 .58786 .60864 .58292 .60784 .58637 Mtetra
.107 0 .212 r
.60784 .58637 .60864 .58292 .6055 .38565 .60959 .58357 Mtetra
.527 .314 .533 r
.60959 .58357 .6055 .38565 .60702 .37814 .61105 .56973 Mtetra
0 0 .386 r
.61105 .56973 .60702 .37814 .60865 .37519 .60785 .37642 Mtetra
.872 .897 .478 r
.60785 .37642 .60865 .37519 .6103 .37337 .60946 .37257 Mtetra
.805 .824 .866 r
.60946 .37257 .6103 .37337 .61199 .37243 .61113 .37126 Mtetra
.659 .711 .887 r
.61113 .37126 .61199 .37243 .61368 .3719 .61282 .37071 Mtetra
.581 .677 .906 r
.61282 .37071 .61368 .3719 .61538 .37157 .61453 .3705 Mtetra
.614 .715 .918 r
.61453 .3705 .61538 .37157 .61708 .37119 .61623 .37014 Mtetra
.623 .724 .919 r
.61623 .37014 .61708 .37119 .61878 .3708 .61793 .36975 Mtetra
.626 .723 .917 r
.61793 .36975 .61878 .3708 .62049 .3704 .61963 .36934 Mtetra
.647 .732 .911 r
.61963 .36934 .62049 .3704 .62219 .36989 .62134 .36885 Mtetra
.662 .741 .908 r
.62134 .36885 .62219 .36989 .62389 .36931 .62304 .36829 Mtetra
.674 .75 .908 r
.62304 .36829 .62389 .36931 .62558 .36866 .62474 .36768 Mtetra
.713 .77 .897 r
.62474 .36768 .62558 .36866 .62727 .36769 .62643 .36689 Mtetra
.713 .809 .925 r
.62643 .36689 .62727 .36769 .62896 .3668 .62813 .36611 Mtetra
.663 .824 .961 r
.62813 .36611 .62896 .3668 .63067 .3663 .62983 .36551 Mtetra
.402 .688 .977 r
.62983 .36551 .63067 .3663 .63243 .36738 .63156 .36561 Mtetra
.402 .489 .834 r
.63156 .36561 .63243 .36738 .63427 .37077 .63331 .36622 Mtetra
.487 .386 .666 r
.63331 .36622 .63427 .37077 .64274 .56445 .63506 .36709 Mtetra
.552 .337 .542 r
.63506 .36709 .64274 .56445 .64474 .5691 .63678 .36661 Mtetra
.553 .338 .542 r
.63678 .36661 .64474 .5691 .64653 .56783 .63847 .36566 Mtetra
.552 .337 .542 r
.63847 .36566 .64653 .56783 .64832 .56621 .64019 .3653 Mtetra
.543 .33 .541 r
.64019 .3653 .64832 .56621 .65031 .57017 .64209 .36981 Mtetra
0 0 .412 r
.64209 .36981 .65031 .57017 .65226 .57314 .65125 .56883 Mtetra
0 .047 .57 r
.65125 .56883 .65226 .57314 .65417 .57464 .65326 .5733 Mtetra
.334 .535 .901 r
.65326 .5733 .65417 .57464 .65602 .57459 .65514 .57387 Mtetra
.678 .836 .959 r
.65514 .57387 .65602 .57459 .65784 .57378 .65697 .57317 Mtetra
.777 .881 .922 r
.65697 .57317 .65784 .57378 .65965 .5727 .65878 .57201 Mtetra
.725 .856 .944 r
.65878 .57201 .65965 .5727 .66148 .57184 .6606 .57112 Mtetra
.673 .834 .961 r
.6606 .57112 .66148 .57184 .66331 .57118 .66243 .57043 Mtetra
.669 .828 .96 r
.66243 .57043 .66331 .57118 .66514 .57057 .66426 .56977 Mtetra
.562 .776 .979 r
.66426 .56977 .66514 .57057 .66699 .57021 .66611 .56947 Mtetra
.576 .796 .983 r
.66611 .56947 .66699 .57021 .66883 .56983 .66796 .5691 Mtetra
.736 .847 .932 r
.66796 .5691 .66883 .56983 .67067 .56913 .66978 .56815 Mtetra
.925 .793 .695 r
.66978 .56815 .67067 .56913 .67244 .56704 .67149 .56438 Mtetra
.973 .685 .421 r
.67149 .56438 .67244 .56704 .67413 .56293 .66469 .3668 Mtetra
.569 .35 .543 r
.66469 .3668 .67413 .56293 .67551 .55207 .666 .35673 Mtetra
.556 .34 .543 r
.666 .35673 .67551 .55207 .66897 .36609 .66765 .35434 Mtetra
.576 .389 .59 r
.66765 .35434 .66897 .36609 .67073 .36626 .66937 .35364 Mtetra
.546 .364 .586 r
.66937 .35364 .67073 .36626 .68099 .54977 .67115 .35402 Mtetra
.545 .332 .542 r
.67115 .35402 .68099 .54977 .68332 .55966 .67308 .35765 Mtetra
.019 0 .423 r
.67308 .35765 .68332 .55966 .68536 .5633 .68428 .55782 Mtetra
.006 .046 .552 r
.68428 .55782 .68536 .5633 .68733 .56509 .68641 .56336 Mtetra
.24 .413 .834 r
.68641 .56336 .68733 .56509 .68922 .56545 .68835 .56447 Mtetra
.593 .745 .949 r
.68835 .56447 .68922 .56545 .69108 .56503 .69021 .56412 Mtetra
.698 .798 .927 r
.69021 .56412 .69108 .56503 .69294 .56438 .69206 .56334 Mtetra
.679 .767 .918 r
.69206 .56334 .69294 .56438 .69479 .56379 .69391 .56266 Mtetra
.646 .735 .914 r
.69391 .56266 .69479 .56379 .69665 .5633 .69577 .56213 Mtetra
.648 .727 .907 r
.69577 .56213 .69665 .5633 .69851 .56281 .69763 .56159 Mtetra
.624 .709 .907 r
.69763 .56159 .69851 .56281 .70039 .5625 .6995 .56116 Mtetra
.622 .686 .889 r
.6995 .56116 .70039 .5625 .70226 .56219 .70137 .56075 Mtetra
.656 .684 .865 r
.70137 .56075 .70226 .56219 .70412 .56151 .70323 .56015 Mtetra
.715 .722 .855 r
.70323 .56015 .70412 .56151 .70591 .55962 .70507 .55921 Mtetra
.827 .934 .9 r
.70507 .55921 .70591 .55962 .70759 .55561 .70689 .55774 Mtetra
0 0 .041 r
.70689 .55774 .70759 .55561 .70862 .53988 .70866 .55537 Mtetra
.371 .168 .47 r
.70866 .55537 .70862 .53988 .69996 .34871 .71019 .54875 Mtetra
.024 0 .42 r
.71019 .54875 .69996 .34871 .70154 .34516 .70092 .3477 Mtetra
0 0 0 r
.70092 .3477 .70154 .34516 .70321 .34309 .70243 .3427 Mtetra
.891 .923 .836 r
.70243 .3427 .70321 .34309 .70493 .34199 .7041 .34081 Mtetra
.659 .718 .892 r
.7041 .34081 .70493 .34199 .70668 .34152 .70586 .34025 Mtetra
.567 .661 .9 r
.70586 .34025 .70668 .34152 .70845 .34128 .70763 .34009 Mtetra
.612 .695 .903 r
.70763 .34009 .70845 .34128 .71021 .34077 .7094 .33974 Mtetra
.682 .756 .908 r
.7094 .33974 .71021 .34077 .71195 .33999 .71115 .33907 Mtetra
.654 .772 .936 r
.71115 .33907 .71195 .33999 .71371 .33951 .71291 .33853 Mtetra
.587 .73 .943 r
.71291 .33853 .71371 .33951 .71554 .34005 .71468 .33823 Mtetra
.524 .555 .829 r
.71468 .33823 .71554 .34005 .71749 .34267 .71648 .33836 Mtetra
.487 .394 .676 r
.71648 .33836 .71749 .34267 .73079 .52994 .71833 .33922 Mtetra
.544 .331 .542 r
.71833 .33922 .73079 .52994 .73373 .54672 .72038 .34331 Mtetra
.049 0 .439 r
.72038 .34331 .73373 .54672 .73581 .5493 .73466 .54354 Mtetra
.135 .133 .59 r
.73466 .54354 .73581 .5493 .7378 .55042 .73688 .54847 Mtetra
.164 .335 .79 r
.73688 .54847 .7378 .55042 .73975 .55098 .7389 .55002 Mtetra
.433 .678 .966 r
.7389 .55002 .73975 .55098 .74168 .55106 .74084 .55013 Mtetra
.709 .801 .922 r
.74084 .55013 .74168 .55106 .74356 .55037 .74271 .54929 Mtetra
.9 .799 .74 r
.74271 .54929 .74356 .55037 .74531 .54761 .74444 .54636 Mtetra
.975 .726 .495 r
.74444 .54636 .74531 .54761 .74638 .53461 .74544 .53209 Mtetra
.976 .681 .39 r
.74544 .53209 .74638 .53461 .73498 .33439 .73417 .33326 Mtetra
.904 .782 .716 r
.73417 .33326 .73498 .33439 .73658 .33125 .73577 .33017 Mtetra
.691 .752 .898 r
.73577 .33017 .73658 .33125 .73834 .33054 .73754 .32946 Mtetra
.551 .691 .932 r
.73754 .32946 .73834 .33054 .74014 .33041 .73934 .32931 Mtetra
.572 .697 .926 r
.73934 .32931 .74014 .33041 .74193 .33014 .74114 .32909 Mtetra
.679 .755 .908 r
.74114 .32909 .74193 .33014 .74369 .32936 .7429 .32843 Mtetra
.652 .773 .937 r
.7429 .32843 .74369 .32936 .74547 .32885 .74468 .32789 Mtetra
.588 .737 .946 r
.74468 .32789 .74547 .32885 .74732 .32922 .74648 .32758 Mtetra
.523 .578 .852 r
.74648 .32758 .74732 .32922 .7493 .33155 .7483 .32767 Mtetra
.484 .405 .692 r
.7483 .32767 .7493 .33155 .75192 .34266 .75018 .32849 Mtetra
.458 .299 .577 r
.75018 .32849 .75192 .34266 .76777 .53653 .75227 .33217 Mtetra
.065 0 .448 r
.75227 .33217 .76777 .53653 .76993 .53955 .76873 .53349 Mtetra
.144 .136 .589 r
.76873 .53349 .76993 .53955 .77197 .54085 .77105 .53871 Mtetra
.23 .357 .786 r
.77105 .53871 .77197 .54085 .77396 .5413 .77312 .54021 Mtetra
.555 .709 .943 r
.77312 .54021 .77396 .5413 .7759 .54114 .77505 .54002 Mtetra
.696 .761 .902 r
.77505 .54002 .7759 .54114 .7778 .54041 .77695 .53922 Mtetra
.751 .767 .866 r
.77695 .53922 .7778 .54041 .77963 .53877 .77882 .53807 Mtetra
.808 .88 .898 r
.77882 .53807 .77963 .53877 .78132 .53529 .78067 .53669 Mtetra
0 0 0 r
.78067 .53669 .78132 .53529 .78263 .52683 .78247 .53454 Mtetra
.283 .072 .407 r
.78247 .53454 .78263 .52683 .7691 .32716 .78406 .52982 Mtetra
.064 0 .442 r
.78406 .52982 .7691 .32716 .7706 .32285 .77023 .3271 Mtetra
0 0 .155 r
.77023 .3271 .7706 .32285 .77226 .3205 .77156 .32051 Mtetra
.932 .97 .736 r
.77156 .32051 .77226 .3205 .77399 .31913 .7732 .31801 Mtetra
.69 .746 .894 r
.7732 .31801 .77399 .31913 .77578 .31855 .77498 .31728 Mtetra
.595 .677 .898 r
.77498 .31728 .77578 .31855 .7776 .31822 .7768 .317 Mtetra
.587 .683 .907 r
.7768 .317 .7776 .31822 .77941 .31784 .77863 .31675 Mtetra
.681 .749 .902 r
.77863 .31675 .77941 .31784 .78119 .31709 .78042 .31607 Mtetra
.687 .765 .911 r
.78042 .31607 .78119 .31709 .78298 .31632 .78221 .31537 Mtetra
.691 .783 .921 r
.78221 .31537 .78298 .31632 .78476 .31551 .784 .31465 Mtetra
.691 .805 .936 r
.784 .31465 .78476 .31551 .78654 .31466 .78579 .31393 Mtetra
.645 .823 .968 r
.78579 .31393 .78654 .31466 .78834 .31411 .78759 .31336 Mtetra
.522 .764 .985 r
.78759 .31336 .78834 .31411 .79021 .31436 .78942 .31315 Mtetra
.332 .548 .911 r
.78942 .31315 .79021 .31436 .79227 .31678 .79133 .3137 Mtetra
.442 .41 .728 r
.79133 .3137 .79227 .31678 .79494 .3262 .79326 .31465 Mtetra
.529 .357 .592 r
.79326 .31465 .79494 .3262 .81367 .52153 .79521 .31561 Mtetra
.552 .337 .542 r
.79521 .31561 .81367 .52153 .8157 .52201 .79704 .31532 Mtetra
.553 .338 .542 r
.79704 .31532 .8157 .52201 .8176 .52104 .79884 .31458 Mtetra
.79884 .31458 .8176 .52104 .81948 .51988 .80064 .31381 Mtetra
.552 .337 .542 r
.80064 .31381 .81948 .51988 .8215 .52028 .80248 .31356 Mtetra
.80248 .31356 .8215 .52028 .82344 .51967 .8043 .313 Mtetra
.553 .338 .542 r
.8043 .313 .82344 .51967 .82509 .51594 .80605 .31167 Mtetra
.555 .34 .542 r
.80605 .31167 .82509 .51594 .80891 .31513 .80771 .30932 Mtetra
.658 .481 .633 r
.80771 .30932 .80891 .31513 .81026 .30938 .8094 .30734 Mtetra
.737 .646 .759 r
.8094 .30734 .81026 .30938 .81189 .30674 .81114 .30589 Mtetra
.683 .81 .943 r
.81114 .30589 .81189 .30674 .81368 .30586 .81295 .3052 Mtetra
.605 .828 .985 r
.81295 .3052 .81368 .30586 .81551 .30542 .81478 .30472 Mtetra
.573 .804 .987 r
.81478 .30472 .81551 .30542 .81736 .30517 .81662 .30434 Mtetra
.604 .783 .966 r
.81662 .30434 .81736 .30517 .8192 .30479 .81846 .30393 Mtetra
.608 .775 .96 r
.81846 .30393 .8192 .30479 .82105 .30443 .8203 .30351 Mtetra
.628 .77 .948 r
.8203 .30351 .82105 .30443 .82289 .30401 .82214 .30303 Mtetra
.669 .775 .929 r
.82214 .30303 .82289 .30401 .82471 .3034 .82396 .3024 Mtetra
.681 .774 .921 r
.82396 .3024 .82471 .3034 .82653 .30273 .82578 .30172 Mtetra
.703 .779 .91 r
.82578 .30172 .82653 .30273 .82834 .30195 .82759 .30093 Mtetra
.769 .797 .876 r
.82759 .30093 .82834 .30195 .83011 .3008 .82936 .29976 Mtetra
.691 .768 .91 r
.82936 .29976 .83011 .3008 .83193 .30008 .83118 .29903 Mtetra
.396 .621 .942 r
.83118 .29903 .83193 .30008 .83385 .30036 .83309 .29931 Mtetra
.824 .412 0 r
.83309 .29931 .83385 .30036 .8363 .30598 .83556 .30505 Mtetra
.973 .661 .313 r
.83556 .30505 .8363 .30598 .85872 .51096 .85793 .50999 Mtetra
.725 .277 0 r
.85793 .50999 .85872 .51096 .86117 .51516 .86037 .51413 Mtetra
.327 .602 .947 r
.86037 .51413 .86117 .51516 .86324 .5156 .86245 .51455 Mtetra
.667 .775 .93 r
.86245 .51455 .86324 .5156 .8652 .51493 .86441 .51388 Mtetra
.85 .825 .823 r
.86441 .51388 .8652 .51493 .86703 .513 .86624 .51195 Mtetra
.978 .78 .57 r
.86624 .51195 .86703 .513 .86838 .50634 .86759 .50531 Mtetra
.976 .67 .325 r
.86759 .50531 .86838 .50634 .84898 .29984 .84823 .29874 Mtetra
.966 .782 .603 r
.84823 .29874 .84898 .29984 .85032 .29449 .84957 .29338 Mtetra
.762 .779 .867 r
.84957 .29338 .85032 .29449 .85211 .29334 .85136 .29222 Mtetra
.631 .728 .917 r
.85136 .29222 .85211 .29334 .85397 .29288 .85322 .29176 Mtetra
.554 .691 .93 r
.85322 .29176 .85397 .29288 .85586 .29272 .85511 .29159 Mtetra
.751 .775 .872 r
.85511 .29159 .85586 .29272 .85765 .29163 .8569 .2905 Mtetra
.683 .749 .901 r
.8569 .2905 .85765 .29163 .85949 .29093 .85874 .2898 Mtetra
.478 .65 .934 r
.85874 .2898 .85949 .29093 .86141 .29102 .86066 .28988 Mtetra
.749 .332 0 r
.86066 .28988 .86141 .29102 .86386 .29599 .86311 .29484 Mtetra
.971 .656 .295 r
.86311 .29484 .86386 .29599 .88826 .50163 .88748 .50054 Mtetra
.731 .3 0 r
.88748 .50054 .88826 .50163 .89083 .50638 .89005 .5053 Mtetra
.304 .575 .936 r
.89005 .5053 .89083 .50638 .89295 .50691 .89216 .50583 Mtetra
.649 .761 .931 r
.89216 .50583 .89295 .50691 .89494 .50632 .89415 .50524 Mtetra
.828 .818 .84 r
.89415 .50524 .89494 .50632 .8968 .5046 .89602 .50351 Mtetra
.908 .733 .653 r
.25705 .68889 .2581 .68977 .26007 .68411 .25904 .68309 Mtetra
.936 .686 .535 r
.25904 .68309 .26007 .68411 .27636 .48788 .27539 .48671 Mtetra
.895 .715 .651 r
.27539 .48671 .27636 .48788 .27824 .48224 .27727 .48121 Mtetra
.754 .737 .837 r
.27727 .48121 .27824 .48224 .27978 .48117 .27881 .48017 Mtetra
.615 .71 .913 r
.27881 .48017 .27978 .48117 .28127 .48083 .28029 .47986 Mtetra
.469 .662 .946 r
.28029 .47986 .28127 .48083 .28273 .48085 .28175 .47992 Mtetra
.651 .735 .911 r
.28175 .47992 .28273 .48085 .28423 .4804 .28325 .47948 Mtetra
.663 .739 .907 r
.28325 .47948 .28423 .4804 .28573 .4799 .28475 .47898 Mtetra
.669 .743 .906 r
.28475 .47898 .28573 .4799 .28724 .47934 .28626 .47846 Mtetra
.76 .765 .857 r
.28626 .47846 .28724 .47934 .28879 .47821 .2878 .47745 Mtetra
.712 .785 .909 r
.2878 .47745 .28879 .47821 .29031 .47741 .28932 .47675 Mtetra
.451 .735 .988 r
.28932 .47675 .29031 .47741 .29179 .47726 .29079 .47671 Mtetra
.914 .536 .29 r
.29079 .47671 .29179 .47726 .29301 .48086 .29199 .48063 Mtetra
.938 .682 .522 r
.29199 .48063 .29301 .48086 .28085 .67639 .27976 .67614 Mtetra
.913 .568 .373 r
.27976 .67614 .28085 .67639 .28199 .6824 .28095 .68159 Mtetra
0 .346 .784 r
.28095 .68159 .28199 .6824 .2835 .68328 .28246 .68237 Mtetra
.632 .748 .932 r
.28246 .68237 .2835 .68328 .28509 .68289 .28406 .68196 Mtetra
.798 .768 .826 r
.28406 .68196 .28509 .68289 .28676 .6814 .28572 .68053 Mtetra
.903 .745 .675 r
.28572 .68053 .28676 .6814 .28871 .67586 .28761 .67588 Mtetra
.94 .688 .528 r
.28761 .67588 .28871 .67586 .3035 .47869 .30234 .48058 Mtetra
.997 .852 .568 r
.30234 .48058 .3035 .47869 .30536 .47302 .30431 .47328 Mtetra
.861 .984 .848 r
.30431 .47328 .30536 .47302 .30692 .47182 .3059 .47167 Mtetra
.638 .926 .974 r
.3059 .47167 .30692 .47182 .30842 .47154 .30742 .47103 Mtetra
.53 .807 .997 r
.30742 .47103 .30842 .47154 .30989 .47168 .30892 .47078 Mtetra
.646 .743 .92 r
.30892 .47078 .30989 .47168 .3114 .47136 .31043 .47035 Mtetra
.647 .719 .9 r
.31043 .47035 .3114 .47136 .31291 .47091 .31195 .46991 Mtetra
.643 .72 .904 r
.31195 .46991 .31291 .47091 .31443 .47042 .31346 .46949 Mtetra
.738 .755 .866 r
.31346 .46949 .31443 .47042 .31598 .46947 .31501 .4686 Mtetra
.707 .765 .897 r
.31501 .4686 .31598 .46947 .31751 .46874 .31654 .46791 Mtetra
.525 .72 .962 r
.31654 .46791 .31751 .46874 .319 .46867 .31803 .4678 Mtetra
.888 .46 .114 r
.31803 .4678 .319 .46867 .32027 .47234 .31934 .47079 Mtetra
.943 .685 .515 r
.31934 .47079 .32027 .47234 .30966 .66863 .30882 .66474 Mtetra
.874 .588 .066 r
.30882 .66474 .30966 .66863 .3109 .6742 .30995 .67205 Mtetra
.302 .39 .787 r
.30995 .67205 .3109 .6742 .31246 .67472 .31148 .67302 Mtetra
.596 .604 .829 r
.31148 .67302 .31246 .67472 .31409 .67406 .31308 .67279 Mtetra
.684 .696 .856 r
.31308 .67279 .31409 .67406 .31574 .67294 .31471 .67212 Mtetra
.659 .777 .936 r
.31471 .67212 .31574 .67294 .31737 .67236 .31633 .67159 Mtetra
.653 .787 .946 r
.31633 .67159 .31737 .67236 .31899 .67192 .31796 .67108 Mtetra
.663 .775 .933 r
.31796 .67108 .31899 .67192 .32062 .67131 .31958 .67054 Mtetra
.647 .787 .949 r
.31958 .67054 .32062 .67131 .32229 .67002 .32121 .67005 Mtetra
.408 .857 .898 r
.32121 .67005 .32229 .67002 .32399 .66826 .32283 .66958 Mtetra
.287 0 .011 r
.32283 .66958 .32399 .66826 .3257 .66623 .32446 .66912 Mtetra
.5 .163 .327 r
.32446 .66912 .3257 .66623 .32732 .66579 .32606 .66905 Mtetra
.487 .162 .342 r
.32606 .66905 .32732 .66579 .32892 .66574 .32767 .66881 Mtetra
.388 .062 .286 r
.32767 .66881 .32892 .66574 .33057 .66491 .32932 .66797 Mtetra
0 0 0 r
.32932 .66797 .33057 .66491 .3326 .65708 .33113 .66423 Mtetra
.954 .699 .512 r
.33113 .66423 .3326 .65708 .34478 .46405 .3434 .47075 Mtetra
.741 .711 .177 r
.3434 .47075 .34478 .46405 .34652 .45973 .34549 .46022 Mtetra
.882 .992 .783 r
.34549 .46022 .34652 .45973 .34811 .45826 .3471 .45825 Mtetra
.52 .908 .936 r
.3471 .45825 .34811 .45826 .34965 .45773 .34865 .45769 Mtetra
.122 .672 .797 r
.34865 .45769 .34965 .45773 .35117 .45752 .35016 .4576 Mtetra
.204 .732 .788 r
.35016 .4576 .35117 .45752 .35271 .45714 .35169 .45733 Mtetra
.261 .768 .768 r
.35169 .45733 .35271 .45714 .35424 .45667 .35323 .45691 Mtetra
.272 .773 .749 r
.35323 .45691 .35424 .45667 .35578 .45623 .35477 .45644 Mtetra
.482 .899 .847 r
.35477 .45644 .35578 .45623 .35732 .45585 .35632 .45574 Mtetra
.687 .947 .959 r
.35632 .45574 .35732 .45585 .35886 .4555 .35788 .45495 Mtetra
.727 .847 .938 r
.35788 .45495 .35886 .4555 .36039 .45514 .35944 .45417 Mtetra
.684 .742 .895 r
.35944 .45417 .36039 .45514 .36193 .45472 .36099 .45357 Mtetra
.656 .699 .878 r
.36099 .45357 .36193 .45472 .36348 .45423 .36254 .45308 Mtetra
.647 .695 .881 r
.36254 .45308 .36348 .45423 .36503 .4537 .36408 .45264 Mtetra
.65 .712 .893 r
.36408 .45264 .36503 .4537 .36658 .4531 .36563 .45218 Mtetra
.654 .744 .916 r
.36563 .45218 .36658 .4531 .36814 .45245 .36718 .4517 Mtetra
.653 .785 .944 r
.36718 .4517 .36814 .45245 .36969 .45181 .36873 .45122 Mtetra
.654 .826 .966 r
.36873 .45122 .36969 .45181 .37125 .45112 .37028 .4507 Mtetra
.645 .868 .983 r
.37028 .4507 .37125 .45112 .37281 .45049 .37183 .45015 Mtetra
.635 .887 .986 r
.37183 .45015 .37281 .45049 .37436 .45004 .37339 .44959 Mtetra
.656 .864 .978 r
.37339 .44959 .37436 .45004 .37588 .45017 .37495 .44903 Mtetra
.672 .705 .872 r
.37495 .44903 .37588 .45017 .37738 .45085 .3765 .44846 Mtetra
.637 .555 .745 r
.3765 .44846 .37738 .45085 .37887 .45188 .37806 .4479 Mtetra
.631 .49 .673 r
.37806 .4479 .37887 .45188 .38041 .45178 .37963 .44706 Mtetra
.618 .467 .655 r
.37963 .44706 .38041 .45178 .38199 .45087 .3812 .44626 Mtetra
.584 .446 .659 r
.3812 .44626 .38199 .45087 .38354 .45056 .38275 .44597 Mtetra
.364 .294 .643 r
.38275 .44597 .38354 .45056 .38489 .45498 .38421 .44776 Mtetra
.94 .688 .216 r
.38421 .44776 .38489 .45498 .37822 .64931 .38502 .46492 Mtetra
0 0 .287 r
.38502 .46492 .37822 .64931 .37967 .65362 .37875 .65074 Mtetra
.129 .216 .687 r
.37875 .65074 .37967 .65362 .38127 .65456 .38031 .65271 Mtetra
.553 .568 .823 r
.38031 .65271 .38127 .65456 .38293 .65419 .38195 .6527 Mtetra
.654 .659 .842 r
.38195 .6527 .38293 .65419 .3846 .65342 .38361 .65216 Mtetra
.661 .695 .871 r
.38361 .65216 .3846 .65342 .38627 .65284 .38528 .65161 Mtetra
.645 .694 .882 r
.38528 .65161 .38627 .65284 .38793 .65245 .38694 .65114 Mtetra
.655 .686 .867 r
.38694 .65114 .38793 .65245 .3896 .65189 .38861 .65061 Mtetra
.597 .67 .891 r
.38861 .65061 .3896 .65189 .39128 .65099 .39026 .65035 Mtetra
.526 .787 .992 r
.39026 .65035 .39128 .65099 .39298 .64958 .39192 .65012 Mtetra
0 0 0 r
.39192 .65012 .39298 .64958 .39471 .64731 .3936 .64936 Mtetra
.3936 .64936 .39471 .64731 .39659 .641 .39536 .64651 Mtetra
.938 .808 .351 r
.39536 .64651 .39659 .641 .40541 .44505 .39749 .6335 Mtetra
0 0 .281 r
.39749 .6335 .40541 .44505 .40714 .44014 .40613 .44109 Mtetra
.9 .966 .648 r
.40613 .44109 .40714 .44014 .40876 .43825 .40779 .43831 Mtetra
.541 .924 .911 r
.40779 .43831 .40876 .43825 .41034 .4376 .40937 .43763 Mtetra
.153 .696 .785 r
.40937 .43763 .41034 .4376 .4119 .43735 .41093 .43744 Mtetra
.287 .788 .818 r
.41093 .43744 .4119 .43735 .41347 .43713 .41251 .43706 Mtetra
.657 .95 .953 r
.41251 .43706 .41347 .43713 .41504 .43678 .41409 .43628 Mtetra
.72 .863 .949 r
.41409 .43628 .41504 .43678 .41661 .43645 .41568 .43551 Mtetra
.69 .755 .901 r
.41568 .43551 .41661 .43645 .41818 .43605 .41726 .43487 Mtetra
.657 .697 .875 r
.41726 .43487 .41818 .43605 .41976 .43557 .41884 .43436 Mtetra
.649 .689 .874 r
.41884 .43436 .41976 .43557 .42134 .43507 .42042 .4339 Mtetra
.653 .697 .878 r
.42042 .4339 .42134 .43507 .42292 .43455 .422 .43341 Mtetra
.661 .706 .881 r
.422 .43341 .42292 .43455 .4245 .43403 .42358 .43289 Mtetra
.664 .707 .88 r
.42358 .43289 .4245 .43403 .42609 .43349 .42517 .43236 Mtetra
.67 .71 .878 r
.42517 .43236 .42609 .43349 .42767 .43296 .42675 .43179 Mtetra
.674 .706 .872 r
.42675 .43179 .42767 .43296 .42926 .43241 .42834 .43121 Mtetra
.666 .697 .869 r
.42834 .43121 .42926 .43241 .43085 .43183 .42993 .43065 Mtetra
.641 .692 .882 r
.42993 .43065 .43085 .43183 .43244 .43119 .43151 .43022 Mtetra
.599 .722 .93 r
.43151 .43022 .43244 .43119 .43403 .43047 .43309 .42993 Mtetra
.533 .808 .996 r
.43309 .42993 .43403 .43047 .43562 .42977 .43467 .42967 Mtetra
.56 .916 .959 r
.43467 .42967 .43562 .42977 .43722 .42898 .43627 .42908 Mtetra
.632 .961 .903 r
.43627 .42908 .43722 .42898 .43882 .42817 .43787 .42819 Mtetra
.361 .831 .875 r
.43787 .42819 .43882 .42817 .4404 .42774 .43946 .42778 Mtetra
.711 .191 0 r
.43946 .42778 .4404 .42774 .44196 .42848 .441 .42916 Mtetra
.953 .682 .485 r
.441 .42916 .44196 .42848 .44345 .43236 .43799 .6106 Mtetra
.591 .364 .541 r
.43799 .6106 .44345 .43236 .44024 .62775 .4391 .63334 Mtetra
.646 .353 .46 r
.4391 .63334 .44024 .62775 .4418 .63272 .44072 .63558 Mtetra
.484 .145 .315 r
.44072 .63558 .4418 .63272 .44348 .63269 .44242 .6354 Mtetra
.389 .048 .262 r
.44242 .6354 .44348 .63269 .44519 .63178 .44412 .63466 Mtetra
.391 .058 .276 r
.44412 .63466 .44519 .63178 .4469 .63063 .44583 .63386 Mtetra
.456 .131 .325 r
.44583 .63386 .4469 .63063 .44861 .62986 .44753 .63339 Mtetra
.464 .148 .344 r
.44753 .63339 .44861 .62986 .45031 .62942 .44923 .63291 Mtetra
.464 .146 .342 r
.44923 .63291 .45031 .62942 .45199 .62986 .45093 .63243 Mtetra
.43 .08 .269 r
.45093 .63243 .45199 .62986 .45365 .63104 .45264 .63197 Mtetra
.165 0 0 r
.45264 .63197 .45365 .63104 .45533 .6319 .45434 .63145 Mtetra
.652 .878 .982 r
.45434 .63145 .45533 .6319 .45702 .63224 .45605 .63082 Mtetra
.697 .689 .838 r
.45605 .63082 .45702 .63224 .45872 .63199 .45777 .63001 Mtetra
.678 .619 .782 r
.45777 .63001 .45872 .63199 .46043 .63156 .45948 .62918 Mtetra
.654 .577 .756 r
.45948 .62918 .46043 .63156 .46214 .63101 .4612 .62845 Mtetra
.626 .55 .75 r
.4612 .62845 .46214 .63101 .46385 .63042 .46291 .62793 Mtetra
.62 .552 .756 r
.46291 .62793 .46385 .63042 .46557 .6298 .46462 .62748 Mtetra
.6 .553 .773 r
.46462 .62748 .46557 .6298 .46728 .62932 .46633 .6272 Mtetra
.568 .552 .797 r
.46633 .6272 .46728 .62932 .46899 .6291 .46803 .62713 Mtetra
.648 .607 .794 r
.46803 .62713 .46899 .6291 .4707 .62854 .46975 .62654 Mtetra
.785 .664 .729 r
.46975 .62654 .4707 .62854 .47244 .62693 .47149 .62437 Mtetra
.908 .682 .583 r
.47149 .62437 .47244 .62693 .47422 .62214 .47337 .61322 Mtetra
.949 .68 .493 r
.47337 .61322 .47422 .62214 .47871 .42613 .47791 .4175 Mtetra
.674 .472 .605 r
.47791 .4175 .47871 .42613 .48043 .41848 .47957 .41398 Mtetra
.626 .477 .661 r
.47957 .41398 .48043 .41848 .48205 .41737 .48119 .41309 Mtetra
.59 .458 .669 r
.48119 .41309 .48205 .41737 .48367 .41715 .48281 .41274 Mtetra
.577 .446 .666 r
.48281 .41274 .48367 .41715 .48528 .41729 .48442 .41256 Mtetra
.597 .453 .657 r
.48442 .41256 .48528 .41729 .4869 .4171 .48604 .41207 Mtetra
.593 .446 .651 r
.48604 .41207 .4869 .4171 .48852 .41664 .48766 .4116 Mtetra
.48766 .4116 .48852 .41664 .49015 .41544 .48928 .41112 Mtetra
.6 .464 .667 r
.48928 .41112 .49015 .41544 .49179 .41331 .4909 .41063 Mtetra
.622 .533 .733 r
.4909 .41063 .49179 .41331 .49342 .41149 .49252 .41014 Mtetra
.65 .67 .856 r
.49252 .41014 .49342 .41149 .49505 .41016 .49415 .40964 Mtetra
.624 .847 .985 r
.49415 .40964 .49505 .41016 .49668 .40952 .49577 .40914 Mtetra
.598 .877 .993 r
.49577 .40914 .49668 .40952 .4983 .40907 .4974 .40864 Mtetra
.614 .87 .991 r
.4974 .40864 .4983 .40907 .49993 .40866 .49903 .40813 Mtetra
.639 .849 .98 r
.49903 .40813 .49993 .40866 .50156 .40814 .50065 .4076 Mtetra
.645 .85 .979 r
.50065 .4076 .50156 .40814 .50319 .4076 .50228 .40705 Mtetra
.653 .849 .975 r
.50228 .40705 .50319 .4076 .50481 .40706 .50391 .40649 Mtetra
.665 .846 .969 r
.50391 .40649 .50481 .40706 .50644 .4065 .50555 .40589 Mtetra
.67 .837 .963 r
.50555 .40589 .50644 .4065 .50808 .40594 .50718 .40529 Mtetra
.671 .827 .958 r
.50718 .40529 .50808 .40594 .50971 .40538 .50881 .40469 Mtetra
.665 .817 .956 r
.50881 .40469 .50971 .40538 .51134 .40482 .51045 .40412 Mtetra
.664 .813 .955 r
.51045 .40412 .51134 .40482 .51298 .40426 .51208 .40356 Mtetra
.662 .811 .955 r
.51208 .40356 .51298 .40426 .51461 .4037 .51372 .40299 Mtetra
.662 .811 .954 r
.51372 .40299 .51461 .4037 .51625 .40315 .51535 .40244 Mtetra
.661 .809 .954 r
.51535 .40244 .51625 .40315 .51788 .40259 .51699 .40188 Mtetra
.51699 .40188 .51788 .40259 .51952 .40204 .51863 .40133 Mtetra
.66 .808 .954 r
.51863 .40133 .51952 .40204 .52116 .40149 .52027 .40077 Mtetra
.659 .808 .954 r
.52027 .40077 .52116 .40149 .5228 .40094 .52191 .40022 Mtetra
.659 .807 .955 r
.52191 .40022 .5228 .40094 .52444 .40039 .52355 .39968 Mtetra
.658 .807 .955 r
.52355 .39968 .52444 .40039 .52608 .39985 .52519 .39913 Mtetra
.657 .807 .955 r
.52519 .39913 .52608 .39985 .52773 .39931 .52684 .39859 Mtetra
.656 .807 .955 r
.52684 .39859 .52773 .39931 .52937 .39877 .52848 .39805 Mtetra
.656 .807 .956 r
.52848 .39805 .52937 .39877 .53102 .39823 .53013 .39751 Mtetra
.655 .806 .956 r
.53013 .39751 .53102 .39823 .53266 .39769 .53178 .39697 Mtetra
.654 .806 .956 r
.53178 .39697 .53266 .39769 .53431 .39716 .53342 .39644 Mtetra
.653 .806 .957 r
.53342 .39644 .53431 .39716 .53596 .39662 .53507 .3959 Mtetra
.652 .806 .957 r
.53507 .3959 .53596 .39662 .53761 .39609 .53672 .39537 Mtetra
.651 .807 .958 r
.53672 .39537 .53761 .39609 .53926 .39556 .53837 .39485 Mtetra
.651 .808 .959 r
.53837 .39485 .53926 .39556 .54091 .39503 .54002 .39432 Mtetra
.648 .808 .96 r
.54002 .39432 .54091 .39503 .54256 .39451 .54168 .3938 Mtetra
.645 .809 .962 r
.54168 .3938 .54256 .39451 .54421 .39398 .54333 .39329 Mtetra
.636 .81 .967 r
.54333 .39329 .54421 .39398 .54586 .39346 .54499 .39281 Mtetra
.632 .818 .972 r
.54499 .39281 .54586 .39346 .54752 .39294 .54664 .39232 Mtetra
.63 .828 .977 r
.54664 .39232 .54752 .39294 .54918 .39241 .5483 .39183 Mtetra
.637 .841 .978 r
.5483 .39183 .54918 .39241 .55083 .39186 .54996 .3913 Mtetra
.641 .847 .979 r
.54996 .3913 .55083 .39186 .55249 .39131 .55162 .39076 Mtetra
.645 .851 .979 r
.55162 .39076 .55249 .39131 .55415 .39075 .55327 .3902 Mtetra
.65 .853 .978 r
.55327 .3902 .55415 .39075 .55581 .39005 .55494 .38963 Mtetra
.633 .882 .987 r
.55494 .38963 .55581 .39005 .55747 .38945 .5566 .38904 Mtetra
.632 .886 .987 r
.5566 .38904 .55747 .38945 .55913 .38906 .55826 .38846 Mtetra
.658 .841 .971 r
.55826 .38846 .55913 .38906 .5608 .38949 .55992 .38787 Mtetra
.657 .64 .822 r
.55992 .38787 .5608 .38949 .56248 .39033 .56159 .38729 Mtetra
.624 .519 .714 r
.56159 .38729 .56248 .39033 .56417 .39146 .56325 .38671 Mtetra
.603 .458 .657 r
.56325 .38671 .56417 .39146 .56584 .39132 .56492 .38611 Mtetra
.599 .448 .648 r
.56492 .38611 .56584 .39132 .56751 .39064 .56658 .38552 Mtetra
.599 .45 .65 r
.56658 .38552 .56751 .39064 .56918 .38973 .56825 .38493 Mtetra
.602 .457 .656 r
.56825 .38493 .56918 .38973 .57085 .3891 .56992 .38434 Mtetra
.602 .457 .657 r
.56992 .38434 .57085 .3891 .57252 .38849 .57159 .38376 Mtetra
.601 .457 .658 r
.57159 .38376 .57252 .38849 .57419 .38791 .57326 .38319 Mtetra
.625 .474 .656 r
.57326 .38319 .57419 .38791 .57585 .38669 .57493 .38224 Mtetra
.61 .469 .665 r
.57493 .38224 .57585 .38669 .57752 .38596 .5766 .38158 Mtetra
.565 .441 .669 r
.5766 .38158 .57752 .38596 .57921 .38625 .57828 .38154 Mtetra
.165 .161 .607 r
.57828 .38154 .57921 .38625 .58127 .40737 .58003 .38499 Mtetra
.986 .707 .381 r
.58003 .38499 .58127 .40737 .58626 .59053 .58525 .58467 Mtetra
0 0 .472 r
.58525 .58467 .58626 .59053 .58812 .59368 .58717 .59129 Mtetra
.481 .484 .783 r
.58717 .59129 .58812 .59368 .58992 .59395 .58898 .59173 Mtetra
.64 .586 .778 r
.58898 .59173 .58992 .59395 .59172 .59352 .59077 .59115 Mtetra
.679 .595 .755 r
.59077 .59115 .59172 .59352 .59351 .59275 .59255 .59016 Mtetra
.602 .54 .757 r
.59255 .59016 .59351 .59275 .5953 .59208 .59435 .58983 Mtetra
.59 .557 .786 r
.59435 .58983 .5953 .59208 .59709 .5914 .59615 .58962 Mtetra
.596 .606 .832 r
.59615 .58962 .59709 .5914 .59888 .59071 .59796 .58936 Mtetra
.63 .683 .881 r
.59796 .58936 .59888 .59071 .60068 .59027 .59976 .58892 Mtetra
.646 .69 .876 r
.59976 .58892 .60068 .59027 .60248 .5898 .60156 .5884 Mtetra
.654 .685 .867 r
.60156 .5884 .60248 .5898 .60428 .58914 .60336 .58784 Mtetra
.562 .662 .904 r
.60336 .58784 .60428 .58914 .60607 .58805 .60517 .58769 Mtetra
.495 .854 .991 r
.60517 .58769 .60607 .58805 .60784 .58637 .60697 .5873 Mtetra
0 0 0 r
.60697 .5873 .60784 .58637 .60959 .58357 .60877 .58626 Mtetra
.60877 .58626 .60959 .58357 .61105 .56973 .61047 .58183 Mtetra
.982 .704 .413 r
.61047 .58183 .61105 .56973 .60785 .37642 .60715 .38144 Mtetra
0 0 .007 r
.60715 .38144 .60785 .37642 .60946 .37257 .60864 .37294 Mtetra
.765 .987 .752 r
.60864 .37294 .60946 .37257 .61113 .37126 .6103 .37125 Mtetra
.412 .861 .883 r
.6103 .37125 .61113 .37126 .61282 .37071 .612 .37072 Mtetra
.102 .658 .758 r
.612 .37072 .61282 .37071 .61453 .3705 .6137 .37058 Mtetra
.443 .879 .849 r
.6137 .37058 .61453 .3705 .61623 .37014 .6154 .36991 Mtetra
.68 .943 .962 r
.6154 .36991 .61623 .37014 .61793 .36975 .61709 .36907 Mtetra
.719 .843 .941 r
.61709 .36907 .61793 .36975 .61963 .36934 .61878 .36827 Mtetra
.679 .739 .896 r
.61878 .36827 .61963 .36934 .62134 .36885 .62048 .36763 Mtetra
.659 .705 .881 r
.62048 .36763 .62134 .36885 .62304 .36829 .62218 .36708 Mtetra
.653 .704 .884 r
.62218 .36708 .62304 .36829 .62474 .36768 .62388 .36656 Mtetra
.659 .723 .897 r
.62388 .36656 .62474 .36768 .62643 .36689 .62559 .36602 Mtetra
.662 .78 .937 r
.62559 .36602 .62643 .36689 .62813 .36611 .62729 .36546 Mtetra
.654 .833 .969 r
.62729 .36546 .62813 .36611 .62983 .36551 .629 .36488 Mtetra
.663 .841 .968 r
.629 .36488 .62983 .36551 .63156 .36561 .6307 .36427 Mtetra
.671 .688 .857 r
.6307 .36427 .63156 .36561 .63331 .36622 .63241 .36364 Mtetra
.637 .551 .741 r
.63241 .36364 .63331 .36622 .63506 .36709 .63411 .363 Mtetra
.634 .493 .673 r
.63411 .363 .63506 .36709 .63678 .36661 .63581 .36206 Mtetra
.618 .473 .662 r
.63581 .36206 .63678 .36661 .63847 .36566 .63751 .36125 Mtetra
.584 .453 .669 r
.63751 .36125 .63847 .36566 .64019 .3653 .63923 .36096 Mtetra
.352 .301 .661 r
.63923 .36096 .64019 .3653 .64209 .36981 .64104 .36299 Mtetra
.777 .538 0 r
.64104 .36299 .64209 .36981 .65125 .56883 .64339 .37965 Mtetra
0 0 .408 r
.64339 .37965 .65125 .56883 .65326 .5733 .6523 .57043 Mtetra
.284 .328 .732 r
.6523 .57043 .65326 .5733 .65514 .57387 .65422 .57209 Mtetra
.575 .598 .838 r
.65422 .57209 .65514 .57387 .65697 .57317 .65607 .57194 Mtetra
.684 .728 .884 r
.65607 .57194 .65697 .57317 .65878 .57201 .65789 .57123 Mtetra
.682 .82 .949 r
.65789 .57123 .65878 .57201 .6606 .57112 .65972 .57052 Mtetra
.668 .864 .974 r
.65972 .57052 .6606 .57112 .66243 .57043 .66156 .56982 Mtetra
.692 .866 .964 r
.66156 .56982 .66243 .57043 .66426 .56977 .66339 .56904 Mtetra
.565 .794 .985 r
.66339 .56904 .66426 .56977 .66611 .56947 .66523 .5687 Mtetra
.587 .794 .978 r
.66523 .5687 .66611 .56947 .66796 .5691 .66708 .56831 Mtetra
.758 .838 .913 r
.66708 .56831 .66796 .5691 .66978 .56815 .6689 .56724 Mtetra
.944 .79 .66 r
.6689 .56724 .66978 .56815 .67149 .56438 .67057 .56265 Mtetra
.973 .686 .419 r
.67057 .56265 .67149 .56438 .66469 .3668 .66363 .36055 Mtetra
.784 .561 .598 r
.66363 .36055 .66469 .3668 .666 .35673 .66509 .35377 Mtetra
.754 .599 .684 r
.66509 .35377 .666 .35673 .66765 .35434 .66673 .35138 Mtetra
.666 .549 .712 r
.66673 .35138 .66765 .35434 .66937 .35364 .66844 .35033 Mtetra
.586 .487 .708 r
.66844 .35033 .66937 .35364 .67115 .35402 .67018 .35009 Mtetra
.383 .335 .68 r
.67018 .35009 .67115 .35402 .67308 .35765 .67202 .35172 Mtetra
0 0 .435 r
.67202 .35172 .67308 .35765 .68428 .55782 .67415 .35964 Mtetra
.006 0 .418 r
.67415 .35964 .68428 .55782 .68641 .56336 .68542 .55994 Mtetra
.263 .285 .696 r
.68542 .55994 .68641 .56336 .68835 .56447 .6874 .56208 Mtetra
.598 .554 .777 r
.6874 .56208 .68835 .56447 .69021 .56412 .68927 .56179 Mtetra
.668 .596 .766 r
.68927 .56179 .69021 .56412 .69206 .56334 .69111 .56093 Mtetra
.626 .567 .769 r
.69111 .56093 .69206 .56334 .69391 .56266 .69297 .56041 Mtetra
.578 .554 .792 r
.69297 .56041 .69391 .56266 .69577 .56213 .69485 .56027 Mtetra
.583 .595 .83 r
.69485 .56027 .69577 .56213 .69763 .56159 .69673 .56008 Mtetra
.614 .656 .868 r
.69673 .56008 .69763 .56159 .6995 .56116 .6986 .55971 Mtetra
.643 .678 .869 r
.6986 .55971 .6995 .56116 .70137 .56075 .70047 .55919 Mtetra
.65 .666 .852 r
.70047 .55919 .70137 .56075 .70323 .56015 .70233 .55862 Mtetra
.59 .641 .87 r
.70233 .55862 .70323 .56015 .70507 .55921 .70421 .55837 Mtetra
.527 .754 .979 r
.70421 .55837 .70507 .55921 .70689 .55774 .7061 .55817 Mtetra
0 0 0 r
.7061 .55817 .70689 .55774 .70866 .55537 .70796 .55742 Mtetra
.70796 .55742 .70866 .55537 .71019 .54875 .7097 .55451 Mtetra
.7097 .55451 .71019 .54875 .70092 .3477 .71091 .54205 Mtetra
.013 0 .416 r
.71091 .54205 .70092 .3477 .70243 .3427 .70173 .34369 Mtetra
.774 .882 .462 r
.70173 .34369 .70243 .3427 .7041 .34081 .70334 .34061 Mtetra
.713 .962 .942 r
.70334 .34061 .7041 .34081 .70586 .34025 .70506 .3396 Mtetra
.617 .829 .981 r
.70506 .3396 .70586 .34025 .70763 .34009 .70682 .33911 Mtetra
.634 .751 .933 r
.70682 .33911 .70763 .34009 .7094 .33974 .70858 .33865 Mtetra
.667 .739 .904 r
.70858 .33865 .7094 .33974 .71115 .33907 .71034 .33805 Mtetra
.659 .751 .918 r
.71034 .33805 .71115 .33907 .71291 .33853 .7121 .33749 Mtetra
.717 .768 .893 r
.7121 .33749 .71291 .33853 .71468 .33823 .71384 .33665 Mtetra
.708 .675 .816 r
.71384 .33665 .71468 .33823 .71648 .33836 .71557 .3357 Mtetra
.613 .535 .743 r
.71557 .3357 .71648 .33836 .71833 .33922 .71734 .33527 Mtetra
.4 .347 .683 r
.71734 .33527 .71833 .33922 .72038 .34331 .71923 .33681 Mtetra
.901 .617 .115 r
.71923 .33681 .72038 .34331 .73466 .54354 .72264 .36276 Mtetra
.028 0 .432 r
.72264 .36276 .73466 .54354 .73688 .54847 .73599 .54677 Mtetra
0 .131 .68 r
.73599 .54677 .73688 .54847 .7389 .55002 .73805 .54907 Mtetra
.48 .704 .968 r
.73805 .54907 .7389 .55002 .74084 .55013 .73998 .54905 Mtetra
.742 .782 .886 r
.73998 .54905 .74084 .55013 .74271 .54929 .74184 .548 Mtetra
.883 .773 .736 r
.74184 .548 .74271 .54929 .74444 .54636 .74358 .54511 Mtetra
.969 .74 .536 r
.74358 .54511 .74444 .54636 .74544 .53209 .74485 .53512 Mtetra
.979 .686 .375 r
.74485 .53512 .74544 .53209 .73417 .33326 .73346 .3336 Mtetra
.963 .933 .617 r
.73346 .3336 .73417 .33326 .73577 .33017 .73504 .33005 Mtetra
.72 .978 .917 r
.73504 .33005 .73577 .33017 .73754 .32946 .73677 .32893 Mtetra
.62 .866 .989 r
.73677 .32893 .73754 .32946 .73934 .32931 .73855 .32837 Mtetra
.626 .759 .942 r
.73855 .32837 .73934 .32931 .74114 .32909 .74033 .32792 Mtetra
.659 .722 .896 r
.74033 .32792 .74114 .32909 .7429 .32843 .7421 .32736 Mtetra
.648 .736 .914 r
.7421 .32736 .7429 .32843 .74468 .32789 .74389 .32684 Mtetra
.692 .759 .903 r
.74389 .32684 .74468 .32789 .74648 .32758 .74565 .32612 Mtetra
.71 .694 .833 r
.74565 .32612 .74648 .32758 .7483 .32767 .74741 .3252 Mtetra
.621 .552 .755 r
.74741 .3252 .7483 .32767 .75018 .32849 .74919 .32472 Mtetra
.459 .392 .695 r
.74919 .32472 .75018 .32849 .75227 .33217 .75109 .32572 Mtetra
0 .009 .522 r
.75109 .32572 .75227 .33217 .76873 .53349 .75344 .33295 Mtetra
.052 0 .444 r
.75344 .33295 .76873 .53349 .77105 .53871 .77001 .53491 Mtetra
.171 .21 .661 r
.77001 .53491 .77105 .53871 .77312 .54021 .77219 .53801 Mtetra
.531 .535 .804 r
.77219 .53801 .77312 .54021 .77505 .54002 .77416 .53815 Mtetra
.632 .623 .823 r
.77416 .53815 .77505 .54002 .77695 .53922 .77607 .53766 Mtetra
.639 .663 .858 r
.77607 .53766 .77695 .53922 .77882 .53807 .77799 .53714 Mtetra
.537 .739 .968 r
.77799 .53714 .77882 .53807 .78067 .53669 .77994 .53694 Mtetra
.272 .762 .685 r
.77994 .53694 .78067 .53669 .78247 .53454 .78184 .53621 Mtetra
0 0 0 r
.78184 .53621 .78247 .53454 .78406 .52982 .78363 .53401 Mtetra
0 0 .071 r
.78363 .53401 .78406 .52982 .77023 .3271 .78499 .52625 Mtetra
.048 0 .437 r
.78499 .52625 .77023 .3271 .77156 .32051 .77099 .32222 Mtetra
0 0 0 r
.77099 .32222 .77156 .32051 .7732 .31801 .77249 .31791 Mtetra
.747 .988 .895 r
.77249 .31791 .7732 .31801 .77498 .31728 .77423 .31665 Mtetra
.659 .855 .975 r
.77423 .31665 .77498 .31728 .7768 .317 .77603 .31601 Mtetra
.628 .749 .935 r
.77603 .31601 .7768 .317 .77863 .31675 .77783 .31555 Mtetra
.664 .723 .893 r
.77783 .31555 .77863 .31675 .78042 .31607 .77963 .31496 Mtetra
.651 .733 .909 r
.77963 .31496 .78042 .31607 .78221 .31537 .78144 .31442 Mtetra
.645 .767 .938 r
.78144 .31442 .78221 .31537 .784 .31465 .78324 .31389 Mtetra
.644 .815 .966 r
.78324 .31389 .784 .31465 .78579 .31393 .78505 .31333 Mtetra
.626 .853 .985 r
.78505 .31333 .78579 .31393 .78759 .31336 .78685 .31277 Mtetra
.629 .856 .985 r
.78685 .31277 .78759 .31336 .78942 .31315 .78866 .31219 Mtetra
.662 .772 .931 r
.78866 .31219 .78942 .31315 .79133 .3137 .79046 .3116 Mtetra
.643 .594 .784 r
.79046 .3116 .79133 .3137 .79326 .31465 .79227 .311 Mtetra
.614 .495 .694 r
.79227 .311 .79326 .31465 .79521 .31561 .79407 .31039 Mtetra
.598 .45 .651 r
.79407 .31039 .79521 .31561 .79704 .31532 .79588 .30978 Mtetra
.596 .443 .645 r
.79588 .30978 .79704 .31532 .79884 .31458 .79769 .30918 Mtetra
.596 .445 .648 r
.79769 .30918 .79884 .31458 .80064 .31381 .7995 .30859 Mtetra
.596 .448 .651 r
.7995 .30859 .80064 .31381 .80248 .31356 .80132 .30802 Mtetra
.593 .441 .645 r
.80132 .30802 .80248 .31356 .8043 .313 .80313 .30746 Mtetra
.80313 .30746 .8043 .313 .80605 .31167 .80495 .30691 Mtetra
.599 .458 .662 r
.80495 .30691 .80605 .31167 .80771 .30932 .80677 .30636 Mtetra
.619 .525 .726 r
.80677 .30636 .80771 .30932 .8094 .30734 .80859 .3058 Mtetra
.646 .659 .849 r
.80859 .3058 .8094 .30734 .81114 .30589 .81042 .30526 Mtetra
.612 .841 .987 r
.81042 .30526 .81114 .30589 .81295 .3052 .81224 .30475 Mtetra
.57 .873 .994 r
.81224 .30475 .81295 .3052 .81478 .30472 .81407 .30423 Mtetra
.582 .869 .995 r
.81407 .30423 .81478 .30472 .81662 .30434 .8159 .30371 Mtetra
.616 .843 .986 r
.8159 .30371 .81662 .30434 .81846 .30393 .81773 .30318 Mtetra
.638 .82 .97 r
.81773 .30318 .81846 .30393 .8203 .30351 .81956 .30263 Mtetra
.658 .793 .947 r
.81956 .30263 .8203 .30351 .82214 .30303 .82138 .30203 Mtetra
.677 .771 .922 r
.82138 .30203 .82214 .30303 .82396 .3024 .8232 .30137 Mtetra
.683 .766 .914 r
.8232 .30137 .82396 .3024 .82578 .30172 .82502 .30067 Mtetra
.702 .771 .905 r
.82502 .30067 .82578 .30172 .82759 .30093 .82683 .29988 Mtetra
.77 .794 .872 r
.82683 .29988 .82759 .30093 .82936 .29976 .8286 .2987 Mtetra
.691 .765 .908 r
.8286 .2987 .82936 .29976 .83118 .29903 .83042 .29797 Mtetra
.397 .619 .941 r
.83042 .29797 .83118 .29903 .83309 .29931 .83234 .29825 Mtetra
.827 .417 0 r
.83234 .29825 .83309 .29931 .83556 .30505 .83481 .3041 Mtetra
.973 .661 .312 r
.83481 .3041 .83556 .30505 .85793 .50999 .85715 .509 Mtetra
.716 .268 0 r
.85715 .509 .85793 .50999 .86037 .51413 .85958 .51309 Mtetra
.332 .603 .947 r
.85958 .51309 .86037 .51413 .86245 .51455 .86165 .51351 Mtetra
.668 .774 .929 r
.86165 .51351 .86245 .51455 .86441 .51388 .86361 .51283 Mtetra
.85 .824 .822 r
.86361 .51283 .86441 .51388 .86624 .51195 .86545 .5109 Mtetra
.978 .78 .571 r
.86545 .5109 .86624 .51195 .86759 .50531 .8668 .50427 Mtetra
.976 .67 .325 r
.8668 .50427 .86759 .50531 .84823 .29874 .84747 .29763 Mtetra
.966 .781 .603 r
.84747 .29763 .84823 .29874 .84957 .29338 .84882 .29226 Mtetra
.762 .779 .867 r
.84882 .29226 .84957 .29338 .85136 .29222 .85061 .2911 Mtetra
.631 .728 .917 r
.85061 .2911 .85136 .29222 .85322 .29176 .85247 .29063 Mtetra
.555 .691 .93 r
.85247 .29063 .85322 .29176 .85511 .29159 .85436 .29046 Mtetra
.752 .775 .872 r
.85436 .29046 .85511 .29159 .8569 .2905 .85615 .28937 Mtetra
.683 .749 .901 r
.85615 .28937 .8569 .2905 .85874 .2898 .85799 .28866 Mtetra
.479 .65 .934 r
.85799 .28866 .85874 .2898 .86066 .28988 .85991 .28875 Mtetra
.748 .331 0 r
.85991 .28875 .86066 .28988 .86311 .29484 .86236 .29369 Mtetra
.971 .656 .295 r
.86236 .29369 .86311 .29484 .88748 .50054 .88669 .49944 Mtetra
.731 .301 0 r
.88669 .49944 .88748 .50054 .89005 .5053 .88927 .50421 Mtetra
.304 .575 .935 r
.88927 .50421 .89005 .5053 .89216 .50583 .89138 .50474 Mtetra
.65 .761 .931 r
.89138 .50474 .89216 .50583 .89415 .50524 .89337 .50415 Mtetra
.829 .818 .838 r
.89337 .50415 .89415 .50524 .89602 .50351 .89524 .5024 Mtetra
.91 .73 .645 r
.256 .68799 .25705 .68889 .25904 .68309 .25803 .68171 Mtetra
.936 .686 .535 r
.25803 .68171 .25904 .68309 .27539 .48671 .27447 .485 Mtetra
.868 .687 .654 r
.27447 .485 .27539 .48671 .27727 .48121 .27632 .4799 Mtetra
.723 .688 .816 r
.27632 .4799 .27727 .48121 .27881 .48017 .27785 .47898 Mtetra
.589 .661 .888 r
.27785 .47898 .27881 .48017 .28029 .47986 .27933 .47878 Mtetra
.431 .617 .929 r
.27933 .47878 .28029 .47986 .28175 .47992 .28078 .47896 Mtetra
.64 .726 .911 r
.28078 .47896 .28175 .47992 .28325 .47948 .28227 .47856 Mtetra
.659 .741 .91 r
.28227 .47856 .28325 .47948 .28475 .47898 .28377 .47808 Mtetra
.669 .746 .908 r
.28377 .47808 .28475 .47898 .28626 .47846 .28528 .47756 Mtetra
.758 .761 .855 r
.28528 .47756 .28626 .47846 .2878 .47745 .28682 .47655 Mtetra
.708 .755 .889 r
.28682 .47655 .2878 .47745 .28932 .47675 .28834 .47585 Mtetra
.504 .693 .953 r
.28834 .47585 .28932 .47675 .29079 .47671 .28981 .47581 Mtetra
.925 .542 .246 r
.28981 .47581 .29079 .47671 .29199 .48063 .291 .47976 Mtetra
.939 .683 .522 r
.291 .47976 .29199 .48063 .27976 .67614 .27871 .67535 Mtetra
.933 .58 .333 r
.27871 .67535 .27976 .67614 .28095 .68159 .2799 .68075 Mtetra
0 .439 .859 r
.2799 .68075 .28095 .68159 .28246 .68237 .28142 .6814 Mtetra
.645 .738 .917 r
.28142 .6814 .28246 .68237 .28406 .68196 .28302 .68094 Mtetra
.777 .754 .832 r
.28302 .68094 .28406 .68196 .28572 .68053 .28468 .67967 Mtetra
.868 .768 .75 r
.28468 .67967 .28572 .68053 .28761 .67588 .28643 .67705 Mtetra
.988 .876 .629 r
.28643 .67705 .28761 .67588 .30234 .48058 .28836 .67171 Mtetra
0 0 .224 r
.28836 .67171 .30234 .48058 .30431 .47328 .30284 .47975 Mtetra
0 0 .181 r
.30284 .47975 .30431 .47328 .3059 .47167 .3047 .47412 Mtetra
0 0 0 r
.3047 .47412 .3059 .47167 .30742 .47103 .30635 .47159 Mtetra
.787 .995 .783 r
.30635 .47159 .30742 .47103 .30892 .47078 .30794 .47001 Mtetra
.726 .788 .902 r
.30794 .47001 .30892 .47078 .31043 .47035 .30948 .46924 Mtetra
.646 .699 .885 r
.30948 .46924 .31043 .47035 .31195 .46991 .31099 .4688 Mtetra
.606 .687 .9 r
.31099 .4688 .31195 .46991 .31346 .46949 .3125 .46853 Mtetra
.71 .745 .879 r
.3125 .46853 .31346 .46949 .31501 .4686 .31403 .4678 Mtetra
.696 .776 .913 r
.31403 .4678 .31501 .4686 .31654 .46791 .31556 .46716 Mtetra
.573 .758 .966 r
.31556 .46716 .31654 .46791 .31803 .4678 .31707 .46691 Mtetra
0 .052 .538 r
.31707 .46691 .31803 .4678 .31934 .47079 .31848 .46818 Mtetra
.698 .388 0 r
.31848 .46818 .31934 .47079 .30882 .66474 .31973 .47209 Mtetra
0 0 .253 r
.31973 .47209 .30882 .66474 .30995 .67205 .3094 .66333 Mtetra
.173 .1 .527 r
.3094 .66333 .30995 .67205 .31148 .67302 .31066 .66866 Mtetra
.32 .274 .649 r
.31066 .66866 .31148 .67302 .31308 .67279 .31213 .67058 Mtetra
.352 .415 .787 r
.31213 .67058 .31308 .67279 .31471 .67212 .31367 .67143 Mtetra
.466 .746 .99 r
.31367 .67143 .31471 .67212 .31633 .67159 .31527 .67135 Mtetra
.566 .89 .987 r
.31527 .67135 .31633 .67159 .31796 .67108 .31689 .67085 Mtetra
.652 .916 .979 r
.31689 .67085 .31796 .67108 .31958 .67054 .31852 .67017 Mtetra
.609 .875 .991 r
.31852 .67017 .31958 .67054 .32121 .67005 .32015 .66965 Mtetra
.581 .862 .995 r
.32015 .66965 .32121 .67005 .32283 .66958 .32177 .66921 Mtetra
.574 .865 .996 r
.32177 .66921 .32283 .66958 .32446 .66912 .3234 .66876 Mtetra
.421 .81 .988 r
.3234 .66876 .32446 .66912 .32606 .66905 .32501 .66856 Mtetra
.538 .826 .999 r
.32501 .66856 .32606 .66905 .32767 .66881 .32663 .66825 Mtetra
.703 .847 .952 r
.32663 .66825 .32767 .66881 .32932 .66797 .32827 .66752 Mtetra
.893 .834 .78 r
.32827 .66752 .32932 .66797 .33113 .66423 .33001 .66512 Mtetra
.985 .873 .638 r
.33001 .66512 .33113 .66423 .3434 .47075 .33189 .66004 Mtetra
0 0 .246 r
.33189 .66004 .3434 .47075 .34549 .46022 .34404 .46812 Mtetra
.162 0 .333 r
.34404 .46812 .34549 .46022 .3471 .45825 .34583 .46317 Mtetra
.481 .197 .405 r
.34583 .46317 .3471 .45825 .34865 .45769 .34738 .46258 Mtetra
.569 .278 .435 r
.34738 .46258 .34865 .45769 .35016 .4576 .34886 .46312 Mtetra
.585 .301 .451 r
.34886 .46312 .35016 .4576 .35169 .45733 .35033 .46397 Mtetra
.557 .285 .459 r
.35033 .46397 .35169 .45733 .35323 .45691 .35183 .46435 Mtetra
.467 .21 .44 r
.35183 .46435 .35323 .45691 .35477 .45644 .35342 .46309 Mtetra
.142 0 .308 r
.35342 .46309 .35477 .45644 .35632 .45574 .35517 .45876 Mtetra
0 0 0 r
.35517 .45876 .35632 .45574 .35788 .45495 .35686 .4554 Mtetra
.921 .973 .769 r
.35686 .4554 .35788 .45495 .35944 .45417 .35849 .45313 Mtetra
.762 .745 .837 r
.35849 .45313 .35944 .45417 .36099 .45357 .36007 .45202 Mtetra
.655 .638 .821 r
.36007 .45202 .36099 .45357 .36254 .45308 .36162 .45149 Mtetra
.615 .615 .828 r
.36162 .45149 .36254 .45308 .36408 .45264 .36316 .45118 Mtetra
.616 .633 .845 r
.36316 .45118 .36408 .45264 .36563 .45218 .3647 .45086 Mtetra
.622 .658 .864 r
.3647 .45086 .36563 .45218 .36718 .4517 .36624 .45053 Mtetra
.622 .682 .885 r
.36624 .45053 .36718 .4517 .36873 .45122 .36778 .45018 Mtetra
.641 .717 .903 r
.36778 .45018 .36873 .45122 .37028 .4507 .36933 .44976 Mtetra
.661 .743 .911 r
.36933 .44976 .37028 .4507 .37183 .45015 .37088 .44926 Mtetra
.676 .757 .912 r
.37088 .44926 .37183 .45015 .37339 .44959 .37244 .44869 Mtetra
.698 .761 .9 r
.37244 .44869 .37339 .44959 .37495 .44903 .374 .44803 Mtetra
.706 .742 .88 r
.374 .44803 .37495 .44903 .3765 .44846 .37557 .44731 Mtetra
.698 .712 .859 r
.37557 .44731 .3765 .44846 .37806 .4479 .37713 .44659 Mtetra
.708 .691 .832 r
.37713 .44659 .37806 .4479 .37963 .44706 .3787 .44577 Mtetra
.696 .69 .841 r
.3787 .44577 .37963 .44706 .3812 .44626 .38027 .44504 Mtetra
.628 .678 .878 r
.38027 .44504 .3812 .44626 .38275 .44597 .38182 .44468 Mtetra
.191 .44 .868 r
.38182 .44468 .38275 .44597 .38421 .44776 .38333 .44543 Mtetra
0 0 .484 r
.38333 .44543 .38421 .44776 .38502 .46492 .38475 .44821 Mtetra
.972 .709 .475 r
.38475 .44821 .38502 .46492 .37875 .65074 .37834 .63578 Mtetra
.028 0 .442 r
.37834 .63578 .37875 .65074 .38031 .65271 .37948 .6476 Mtetra
.303 .245 .626 r
.37948 .6476 .38031 .65271 .38195 .6527 .38102 .65005 Mtetra
.352 .379 .749 r
.38102 .65005 .38195 .6527 .38361 .65216 .38261 .65111 Mtetra
.434 .646 .947 r
.38261 .65111 .38361 .65216 .38528 .65161 .38425 .65126 Mtetra
.542 .864 .995 r
.38425 .65126 .38528 .65161 .38694 .65114 .38591 .65085 Mtetra
.638 .905 .983 r
.38591 .65085 .38694 .65114 .38861 .65061 .38758 .6502 Mtetra
.559 .856 .997 r
.38758 .6502 .38861 .65061 .39026 .65035 .38925 .64979 Mtetra
.536 .811 .996 r
.38925 .64979 .39026 .65035 .39192 .65012 .39091 .6495 Mtetra
.678 .836 .959 r
.39091 .6495 .39192 .65012 .3936 .64936 .39258 .64885 Mtetra
.869 .851 .822 r
.39258 .64885 .3936 .64936 .39536 .64651 .39431 .64693 Mtetra
.976 .873 .668 r
.39431 .64693 .39536 .64651 .39749 .6335 .39612 .64258 Mtetra
.964 .704 .492 r
.39612 .64258 .39749 .6335 .40613 .44109 .4046 .45638 Mtetra
.003 0 .323 r
.4046 .45638 .40613 .44109 .40779 .43831 .40662 .44374 Mtetra
.499 .22 .422 r
.40662 .44374 .40779 .43831 .40937 .43763 .4082 .44328 Mtetra
.536 .256 .437 r
.4082 .44328 .40937 .43763 .41093 .43744 .40976 .44332 Mtetra
.297 .05 .36 r
.40976 .44332 .41093 .43744 .41251 .43706 .41142 .44056 Mtetra
0 0 .072 r
.41142 .44056 .41251 .43706 .41409 .43628 .4131 .43705 Mtetra
.875 .98 .688 r
.4131 .43705 .41409 .43628 .41568 .43551 .41474 .43467 Mtetra
.802 .789 .841 r
.41474 .43467 .41568 .43551 .41726 .43487 .41635 .43332 Mtetra
.665 .645 .82 r
.41635 .43332 .41726 .43487 .41884 .43436 .41793 .43272 Mtetra
.627 .617 .821 r
.41793 .43272 .41884 .43436 .42042 .4339 .41951 .43234 Mtetra
.632 .629 .83 r
.41951 .43234 .42042 .4339 .422 .43341 .42109 .43193 Mtetra
.654 .649 .832 r
.42109 .43193 .422 .43341 .42358 .43289 .42267 .4314 Mtetra
.655 .649 .832 r
.42267 .4314 .42358 .43289 .42517 .43236 .42425 .43087 Mtetra
.671 .656 .827 r
.42425 .43087 .42517 .43236 .42675 .43179 .42584 .43025 Mtetra
.677 .65 .817 r
.42584 .43025 .42675 .43179 .42834 .43121 .42743 .42957 Mtetra
.642 .625 .817 r
.42743 .42957 .42834 .43121 .42993 .43065 .42902 .42909 Mtetra
.496 .565 .855 r
.42902 .42909 .42993 .43065 .43151 .43022 .43058 .42927 Mtetra
0 .157 .659 r
.43058 .42927 .43151 .43022 .43309 .42993 .43212 .43052 Mtetra
.796 .378 .255 r
.43212 .43052 .43309 .42993 .43467 .42967 .43363 .43281 Mtetra
.68 .354 .417 r
.43363 .43281 .43467 .42967 .43627 .42908 .43516 .43484 Mtetra
.46 .189 .415 r
.43516 .43484 .43627 .42908 .43787 .42819 .43677 .4338 Mtetra
.486 .211 .421 r
.43677 .4338 .43787 .42819 .43946 .42778 .43836 .43314 Mtetra
.759 .464 .485 r
.43836 .43314 .43946 .42778 .441 .42916 .43979 .43923 Mtetra
.94 .668 .497 r
.43979 .43923 .441 .42916 .43799 .6106 .43649 .63017 Mtetra
.607 .36 .518 r
.43649 .63017 .43799 .6106 .4391 .63334 .43808 .63388 Mtetra
.666 .18 .086 r
.43808 .63388 .4391 .63334 .44072 .63558 .43973 .63504 Mtetra
.529 .815 .998 r
.43973 .63504 .44072 .63558 .44242 .6354 .44143 .63474 Mtetra
.678 .832 .957 r
.44143 .63474 .44242 .6354 .44412 .63466 .44313 .63409 Mtetra
.66 .851 .973 r
.44313 .63409 .44412 .63466 .44583 .63386 .44483 .63348 Mtetra
.492 .839 .996 r
.44483 .63348 .44583 .63386 .44753 .63339 .44653 .63316 Mtetra
.442 .848 .97 r
.44653 .63316 .44753 .63339 .44923 .63291 .44823 .6328 Mtetra
.4 .845 .928 r
.44823 .6328 .44923 .63291 .45093 .63243 .44994 .63241 Mtetra
.412 .858 .906 r
.44994 .63241 .45093 .63243 .45264 .63197 .45164 .63193 Mtetra
.57 .929 .94 r
.45164 .63193 .45264 .63197 .45434 .63145 .45335 .63121 Mtetra
.81 .938 .913 r
.45335 .63121 .45434 .63145 .45605 .63082 .45508 .62992 Mtetra
.87 .787 .767 r
.45508 .62992 .45605 .63082 .45777 .63001 .45682 .62749 Mtetra
.811 .646 .678 r
.45682 .62749 .45777 .63001 .45948 .62918 .45859 .62402 Mtetra
.746 .552 .633 r
.45859 .62402 .45948 .62918 .4612 .62845 .46036 .61991 Mtetra
.609 .428 .611 r
.46036 .61991 .4612 .62845 .46291 .62793 .46209 .61859 Mtetra
.553 .382 .604 r
.46209 .61859 .46291 .62793 .46462 .62748 .46378 .61872 Mtetra
.528 .367 .606 r
.46378 .61872 .46462 .62748 .46633 .6272 .46547 .61941 Mtetra
.534 .378 .616 r
.46547 .61941 .46633 .6272 .46803 .62713 .46717 .61992 Mtetra
.589 .422 .623 r
.46717 .61992 .46803 .62713 .46975 .62654 .46888 .6193 Mtetra
.727 .521 .612 r
.46888 .6193 .46975 .62654 .47149 .62437 .47067 .61434 Mtetra
.947 .678 .495 r
.47067 .61434 .47149 .62437 .47337 .61322 .47534 .41982 Mtetra
.56 .344 .543 r
.47534 .41982 .47337 .61322 .47791 .4175 .47703 .41495 Mtetra
.763 .616 .696 r
.47703 .41495 .47791 .4175 .47957 .41398 .47867 .41265 Mtetra
.698 .69 .838 r
.47867 .41265 .47957 .41398 .48119 .41309 .48029 .41188 Mtetra
.633 .686 .882 r
.48029 .41188 .48119 .41309 .48281 .41274 .4819 .41147 Mtetra
.61 .667 .88 r
.4819 .41147 .48281 .41274 .48442 .41256 .48352 .41117 Mtetra
.653 .665 .849 r
.48352 .41117 .48442 .41256 .48604 .41207 .48514 .41065 Mtetra
.647 .659 .847 r
.48514 .41065 .48604 .41207 .48766 .4116 .48676 .41017 Mtetra
.637 .653 .849 r
.48676 .41017 .48766 .4116 .48928 .41112 .48838 .40973 Mtetra
.619 .652 .86 r
.48838 .40973 .48928 .41112 .4909 .41063 .49 .40939 Mtetra
.615 .675 .884 r
.49 .40939 .4909 .41063 .49252 .41014 .49162 .40906 Mtetra
.622 .71 .909 r
.49162 .40906 .49252 .41014 .49415 .40964 .49325 .40869 Mtetra
.649 .747 .921 r
.49325 .40869 .49415 .40964 .49577 .40914 .49487 .40821 Mtetra
.659 .754 .92 r
.49487 .40821 .49577 .40914 .4974 .40864 .4965 .40769 Mtetra
.664 .751 .915 r
.4965 .40769 .4974 .40864 .49903 .40813 .49813 .40715 Mtetra
.661 .744 .911 r
.49813 .40715 .49903 .40813 .50065 .4076 .49975 .40662 Mtetra
.669 .746 .908 r
.49975 .40662 .50065 .4076 .50228 .40705 .50138 .40606 Mtetra
.682 .747 .9 r
.50138 .40606 .50228 .40705 .50391 .40649 .50302 .40543 Mtetra
.701 .741 .882 r
.50302 .40543 .50391 .40649 .50555 .40589 .50465 .40471 Mtetra
.698 .716 .863 r
.50465 .40471 .50555 .40589 .50718 .40529 .50628 .40397 Mtetra
.687 .691 .848 r
.50628 .40397 .50718 .40529 .50881 .40469 .50792 .40328 Mtetra
.667 .668 .842 r
.50792 .40328 .50881 .40469 .51045 .40412 .50955 .40268 Mtetra
.661 .662 .841 r
.50955 .40268 .51045 .40412 .51208 .40356 .51119 .40211 Mtetra
.658 .661 .841 r
.51119 .40211 .51208 .40356 .51372 .40299 .51282 .40156 Mtetra
.66 .663 .842 r
.51282 .40156 .51372 .40299 .51535 .40244 .51446 .40099 Mtetra
.659 .662 .842 r
.51446 .40099 .51535 .40244 .51699 .40188 .5161 .40044 Mtetra
.658 .662 .842 r
.5161 .40044 .51699 .40188 .51863 .40133 .51774 .39988 Mtetra
.658 .661 .842 r
.51774 .39988 .51863 .40133 .52027 .40077 .51938 .39933 Mtetra
.657 .661 .842 r
.51938 .39933 .52027 .40077 .52191 .40022 .52102 .39878 Mtetra
.52102 .39878 .52191 .40022 .52355 .39968 .52266 .39823 Mtetra
.656 .661 .843 r
.52266 .39823 .52355 .39968 .52519 .39913 .5243 .39769 Mtetra
.5243 .39769 .52519 .39913 .52684 .39859 .52595 .39714 Mtetra
.52595 .39714 .52684 .39859 .52848 .39805 .52759 .3966 Mtetra
.655 .66 .843 r
.52759 .3966 .52848 .39805 .53013 .39751 .52924 .39606 Mtetra
.52924 .39606 .53013 .39751 .53178 .39697 .53089 .39552 Mtetra
.654 .66 .843 r
.53089 .39552 .53178 .39697 .53342 .39644 .53254 .39499 Mtetra
.53254 .39499 .53342 .39644 .53507 .3959 .53418 .39445 Mtetra
.653 .659 .844 r
.53418 .39445 .53507 .3959 .53672 .39537 .53583 .39393 Mtetra
.652 .659 .844 r
.53583 .39393 .53672 .39537 .53837 .39485 .53749 .3934 Mtetra
.654 .66 .844 r
.53749 .3934 .53837 .39485 .54002 .39432 .53914 .39287 Mtetra
.65 .658 .844 r
.53914 .39287 .54002 .39432 .54168 .3938 .54079 .39235 Mtetra
.644 .656 .847 r
.54079 .39235 .54168 .3938 .54333 .39329 .54244 .39187 Mtetra
.623 .652 .858 r
.54244 .39187 .54333 .39329 .54499 .39281 .5441 .3915 Mtetra
.619 .669 .876 r
.5441 .3915 .54499 .39281 .54664 .39232 .54576 .39115 Mtetra
.622 .694 .896 r
.54576 .39115 .54664 .39232 .5483 .39183 .54742 .39078 Mtetra
.649 .73 .908 r
.54742 .39078 .5483 .39183 .54996 .3913 .54908 .3903 Mtetra
.659 .741 .911 r
.54908 .3903 .54996 .3913 .55162 .39076 .55074 .38976 Mtetra
.666 .746 .91 r
.55074 .38976 .55162 .39076 .55327 .3902 .5524 .3892 Mtetra
.661 .744 .912 r
.5524 .3892 .55327 .3902 .55494 .38963 .55406 .38867 Mtetra
.668 .754 .915 r
.55406 .38867 .55494 .38963 .5566 .38904 .55572 .3881 Mtetra
.678 .761 .913 r
.55572 .3881 .5566 .38904 .55826 .38846 .55738 .38748 Mtetra
.704 .763 .898 r
.55738 .38748 .55826 .38846 .55992 .38787 .55904 .38674 Mtetra
.702 .731 .873 r
.55904 .38674 .55992 .38787 .56159 .38729 .56071 .38599 Mtetra
.692 .699 .852 r
.56071 .38599 .56159 .38729 .56325 .38671 .56237 .38526 Mtetra
.667 .667 .841 r
.56237 .38526 .56325 .38671 .56492 .38611 .56404 .38464 Mtetra
.661 .661 .84 r
.56404 .38464 .56492 .38611 .56658 .38552 .5657 .38406 Mtetra
.658 .662 .843 r
.5657 .38406 .56658 .38552 .56825 .38493 .56737 .3835 Mtetra
.661 .668 .846 r
.56737 .3835 .56825 .38493 .56992 .38434 .56904 .38293 Mtetra
.66 .67 .848 r
.56904 .38293 .56992 .38434 .57159 .38376 .57071 .38236 Mtetra
.659 .671 .85 r
.57071 .38236 .57159 .38376 .57326 .38319 .57239 .38179 Mtetra
.702 .689 .834 r
.57239 .38179 .57326 .38319 .57493 .38224 .57405 .38096 Mtetra
.676 .698 .863 r
.57405 .38096 .57493 .38224 .5766 .38158 .57573 .38033 Mtetra
.587 .666 .893 r
.57573 .38033 .5766 .38158 .57828 .38154 .57741 .3801 Mtetra
0 .176 .712 r
.57741 .3801 .57828 .38154 .58003 .38499 .57912 .38177 Mtetra
0 0 .408 r
.57912 .38177 .58003 .38499 .58525 .58467 .58089 .38652 Mtetra
0 0 .389 r
.58089 .38652 .58525 .58467 .58717 .59129 .58611 .5826 Mtetra
.507 .354 .608 r
.58611 .5826 .58717 .59129 .58898 .59173 .58793 .58378 Mtetra
.597 .423 .617 r
.58793 .58378 .58898 .59173 .59077 .59115 .58971 .58285 Mtetra
.591 .417 .614 r
.58971 .58285 .59077 .59115 .59255 .59016 .59149 .58205 Mtetra
.382 .269 .6 r
.59149 .58205 .59255 .59016 .59435 .58983 .59336 .58528 Mtetra
.337 .291 .659 r
.59336 .58528 .59435 .58983 .59615 .58962 .59521 .58746 Mtetra
.28 .384 .791 r
.59521 .58746 .59615 .58962 .59796 .58936 .59705 .58866 Mtetra
.461 .753 .993 r
.59705 .58866 .59796 .58936 .59976 .58892 .59885 .58856 Mtetra
.567 .883 .991 r
.59885 .58856 .59976 .58892 .60156 .5884 .60065 .58803 Mtetra
.646 .906 .982 r
.60065 .58803 .60156 .5884 .60336 .58784 .60245 .58731 Mtetra
.496 .815 1 r
.60245 .58731 .60336 .58784 .60517 .58769 .60426 .58704 Mtetra
.582 .817 .988 r
.60426 .58704 .60517 .58769 .60697 .5873 .60607 .58663 Mtetra
.715 .852 .947 r
.60607 .58663 .60697 .5873 .60877 .58626 .60786 .58579 Mtetra
.926 .87 .763 r
.60786 .58579 .60877 .58626 .61047 .58183 .60962 .58305 Mtetra
.971 .884 .508 r
.60962 .58305 .61047 .58183 .60715 .38144 .61129 .57745 Mtetra
0 0 .386 r
.61129 .57745 .60715 .38144 .60864 .37294 .60799 .38021 Mtetra
.338 .107 .409 r
.60799 .38021 .60864 .37294 .6103 .37125 .60962 .37689 Mtetra
.52 .24 .429 r
.60962 .37689 .6103 .37125 .612 .37072 .61133 .37669 Mtetra
.523 .246 .436 r
.61133 .37669 .612 .37072 .6137 .37058 .61304 .37651 Mtetra
.201 0 .346 r
.61304 .37651 .6137 .37058 .6154 .36991 .61464 .37246 Mtetra
0 0 .024 r
.61464 .37246 .6154 .36991 .61709 .36907 .61627 .36925 Mtetra
.908 .982 .768 r
.61627 .36925 .61709 .36907 .61878 .36827 .61792 .36704 Mtetra
.741 .732 .843 r
.61792 .36704 .61878 .36827 .62048 .36763 .61961 .366 Mtetra
.653 .64 .824 r
.61961 .366 .62048 .36763 .62218 .36708 .62131 .36543 Mtetra
.619 .622 .832 r
.62131 .36543 .62218 .36708 .62388 .36656 .62302 .36507 Mtetra
.623 .645 .851 r
.62302 .36507 .62388 .36656 .62559 .36602 .62473 .36468 Mtetra
.628 .672 .873 r
.62473 .36468 .62559 .36602 .62729 .36546 .62644 .36428 Mtetra
.638 .704 .894 r
.62644 .36428 .62729 .36546 .629 .36488 .62815 .36383 Mtetra
.684 .746 .898 r
.62815 .36383 .629 .36488 .6307 .36427 .62985 .36316 Mtetra
.703 .743 .882 r
.62985 .36316 .6307 .36427 .63241 .36364 .63155 .3624 Mtetra
.7 .717 .863 r
.63155 .3624 .63241 .36364 .63411 .363 .63325 .36162 Mtetra
.711 .699 .837 r
.63325 .36162 .63411 .363 .63581 .36206 .63495 .36073 Mtetra
.692 .7 .853 r
.63495 .36073 .63581 .36206 .63751 .36125 .63666 .35998 Mtetra
.622 .682 .885 r
.63666 .35998 .63751 .36125 .63923 .36096 .63838 .3596 Mtetra
.229 .453 .869 r
.63838 .3596 .63923 .36096 .64104 .36299 .64014 .36045 Mtetra
0 .108 .642 r
.64014 .36045 .64104 .36299 .64339 .37965 .64198 .36317 Mtetra
.983 .697 .362 r
.64198 .36317 .64339 .37965 .6523 .57043 .65072 .551 Mtetra
.133 .054 .493 r
.65072 .551 .6523 .57043 .65422 .57209 .65316 .56674 Mtetra
.342 .279 .64 r
.65316 .56674 .65422 .57209 .65607 .57194 .65511 .56934 Mtetra
.387 .412 .765 r
.65511 .56934 .65607 .57194 .65789 .57123 .65701 .57036 Mtetra
.512 .737 .975 r
.65701 .57036 .65789 .57123 .65972 .57052 .65886 .57022 Mtetra
.64 .925 .975 r
.65886 .57022 .65972 .57052 .66156 .56982 .66069 .56945 Mtetra
.743 .934 .95 r
.66069 .56945 .66156 .56982 .66339 .56904 .66251 .56839 Mtetra
.637 .843 .979 r
.66251 .56839 .66339 .56904 .66523 .5687 .66435 .56781 Mtetra
.624 .778 .955 r
.66435 .56781 .66523 .5687 .66708 .56831 .66619 .56734 Mtetra
.729 .793 .903 r
.66619 .56734 .66708 .56831 .6689 .56724 .66802 .5664 Mtetra
.908 .824 .752 r
.66802 .5664 .6689 .56724 .67057 .56265 .66977 .56358 Mtetra
.999 .824 .487 r
.66977 .56358 .67057 .56265 .66363 .36055 .67127 .55517 Mtetra
0 0 .404 r
.67127 .55517 .66363 .36055 .66509 .35377 .66445 .35718 Mtetra
0 0 .095 r
.66445 .35718 .66509 .35377 .66673 .35138 .666 .35256 Mtetra
0 0 0 r
.666 .35256 .66673 .35138 .66844 .35033 .66765 .35013 Mtetra
.814 .972 .9 r
.66765 .35013 .66844 .35033 .67018 .35009 .66934 .34877 Mtetra
.429 .578 .9 r
.66934 .34877 .67018 .35009 .67202 .35172 .67111 .34909 Mtetra
.086 .202 .689 r
.67111 .34909 .67202 .35172 .67415 .35964 .67298 .35144 Mtetra
0 0 .495 r
.67298 .35144 .67415 .35964 .68542 .55994 .67515 .35996 Mtetra
.041 0 .43 r
.67515 .35996 .68542 .55994 .6874 .56208 .68608 .55167 Mtetra
.564 .387 .6 r
.68608 .55167 .6874 .56208 .68927 .56179 .68794 .55146 Mtetra
.587 .404 .6 r
.68794 .55146 .68927 .56179 .69111 .56093 .68978 .55052 Mtetra
.42 .285 .59 r
.68978 .55052 .69111 .56093 .69297 .56041 .69183 .55404 Mtetra
.337 .26 .621 r
.69183 .55404 .69297 .56041 .69485 .56027 .69388 .55725 Mtetra
.309 .336 .728 r
.69388 .55725 .69485 .56027 .69673 .56008 .69585 .55891 Mtetra
.423 .622 .935 r
.69585 .55891 .69673 .56008 .6986 .55971 .69775 .55915 Mtetra
.626 .863 .987 r
.69775 .55915 .6986 .55971 .70047 .55919 .69961 .55855 Mtetra
.702 .866 .96 r
.69961 .55855 .70047 .55919 .70233 .55862 .70147 .55773 Mtetra
.596 .768 .962 r
.70147 .55773 .70233 .55862 .70421 .55837 .70334 .55734 Mtetra
.528 .706 .953 r
.70334 .55734 .70421 .55837 .7061 .55817 .70523 .55722 Mtetra
.632 .769 .946 r
.70523 .55722 .7061 .55817 .70796 .55742 .7071 .55672 Mtetra
.855 .87 .85 r
.7071 .55672 .70796 .55742 .7097 .55451 .70891 .55495 Mtetra
.97 .925 .608 r
.70891 .55495 .7097 .55451 .71091 .54205 .71059 .55094 Mtetra
0 0 .126 r
.71059 .55094 .71091 .54205 .70173 .34369 .71163 .53543 Mtetra
.029 0 .422 r
.71163 .53543 .70173 .34369 .70334 .34061 .70277 .34405 Mtetra
.033 0 .214 r
.70277 .34405 .70334 .34061 .70506 .3396 .70437 .34064 Mtetra
0 0 0 r
.70437 .34064 .70506 .3396 .70682 .33911 .70604 .33863 Mtetra
.79 .912 .923 r
.70604 .33863 .70682 .33911 .70858 .33865 .70776 .33745 Mtetra
.675 .721 .884 r
.70776 .33745 .70858 .33865 .71034 .33805 .70951 .33681 Mtetra
.637 .697 .889 r
.70951 .33681 .71034 .33805 .7121 .33749 .71128 .33635 Mtetra
.716 .746 .876 r
.71128 .33635 .7121 .33749 .71384 .33665 .71302 .33549 Mtetra
.753 .756 .854 r
.71302 .33549 .71384 .33665 .71557 .3357 .71475 .33438 Mtetra
.657 .693 .872 r
.71475 .33438 .71557 .3357 .71734 .33527 .71651 .33382 Mtetra
.026 .3 .792 r
.71651 .33382 .71734 .33527 .71923 .33681 .71839 .33528 Mtetra
.963 .633 .272 r
.71839 .33528 .71923 .33681 .72264 .36276 .72139 .35462 Mtetra
.979 .681 .35 r
.72139 .35462 .72264 .36276 .73599 .54677 .73516 .54617 Mtetra
.631 .104 0 r
.73516 .54617 .73599 .54677 .73805 .54907 .73722 .54837 Mtetra
.513 .783 .994 r
.73722 .54837 .73805 .54907 .73998 .54905 .73913 .54813 Mtetra
.762 .819 .898 r
.73913 .54813 .73998 .54905 .74184 .548 .74098 .54699 Mtetra
.864 .814 .798 r
.74098 .54699 .74184 .548 .74358 .54511 .74278 .54485 Mtetra
.976 .88 .672 r
.74278 .54485 .74358 .54511 .74485 .53512 .74445 .54094 Mtetra
0 0 0 r
.74445 .54094 .74485 .53512 .73346 .3336 .74551 .52769 Mtetra
.045 0 .431 r
.74551 .52769 .73346 .3336 .73504 .33005 .73454 .33355 Mtetra
.003 0 .213 r
.73454 .33355 .73504 .33005 .73677 .32893 .7361 .32982 Mtetra
0 0 0 r
.7361 .32982 .73677 .32893 .73855 .32837 .73777 .32765 Mtetra
.796 .86 .897 r
.73777 .32765 .73855 .32837 .74033 .32792 .7395 .32641 Mtetra
.648 .66 .848 r
.7395 .32641 .74033 .32792 .7421 .32736 .74128 .32588 Mtetra
.606 .645 .863 r
.74128 .32588 .7421 .32736 .74389 .32684 .74307 .32556 Mtetra
.656 .702 .88 r
.74307 .32556 .74389 .32684 .74565 .32612 .74485 .325 Mtetra
.734 .762 .875 r
.74485 .325 .74565 .32612 .74741 .3252 .7466 .32404 Mtetra
.681 .733 .89 r
.7466 .32404 .74741 .3252 .74919 .32472 .74838 .32336 Mtetra
.466 .594 .896 r
.74838 .32336 .74919 .32472 .75109 .32572 .75022 .32358 Mtetra
.036 .213 .716 r
.75022 .32358 .75109 .32572 .75344 .33295 .7522 .32578 Mtetra
0 0 .484 r
.7522 .32578 .75344 .33295 .77001 .53491 .75467 .33463 Mtetra
.066 0 .448 r
.75467 .33463 .77001 .53491 .77219 .53801 .77096 .53169 Mtetra
.355 .276 .628 r
.77096 .53169 .77219 .53801 .77416 .53815 .77314 .53479 Mtetra
.404 .382 .722 r
.77314 .53479 .77416 .53815 .77607 .53766 .7752 .53609 Mtetra
.422 .55 .88 r
.7752 .53609 .77607 .53766 .77799 .53714 .77719 .53654 Mtetra
.444 .779 .998 r
.77719 .53654 .77799 .53714 .77994 .53694 .77914 .53638 Mtetra
.655 .882 .982 r
.77914 .53638 .77994 .53694 .78184 .53621 .78104 .53566 Mtetra
.846 .915 .88 r
.78104 .53566 .78184 .53621 .78363 .53401 .78288 .53402 Mtetra
.971 .929 .672 r
.78288 .53402 .78363 .53401 .78499 .52625 .78457 .53053 Mtetra
0 0 .038 r
.78457 .53053 .78499 .52625 .77099 .32222 .78587 .52192 Mtetra
.063 0 .442 r
.78587 .52192 .77099 .32222 .77249 .31791 .77211 .32201 Mtetra
.042 0 .264 r
.77211 .32201 .77249 .31791 .77423 .31665 .77362 .31777 Mtetra
0 0 0 r
.77362 .31777 .77423 .31665 .77603 .31601 .77528 .31542 Mtetra
.832 .901 .888 r
.77528 .31542 .77603 .31601 .77783 .31555 .77701 .31398 Mtetra
.679 .667 .832 r
.77701 .31398 .77783 .31555 .77963 .31496 .7788 .31323 Mtetra
.632 .627 .827 r
.7788 .31323 .77963 .31496 .78144 .31442 .78061 .31276 Mtetra
.614 .626 .839 r
.78061 .31276 .78144 .31442 .78324 .31389 .78243 .3124 Mtetra
.624 .655 .859 r
.78243 .3124 .78324 .31389 .78505 .31333 .78424 .31199 Mtetra
.626 .679 .88 r
.78424 .31199 .78505 .31333 .78685 .31277 .78606 .31157 Mtetra
.648 .715 .897 r
.78606 .31157 .78685 .31277 .78866 .31219 .78787 .31104 Mtetra
.691 .742 .89 r
.78787 .31104 .78866 .31219 .79046 .3116 .78967 .3103 Mtetra
.693 .717 .868 r
.78967 .3103 .79046 .3116 .79227 .311 .79146 .30953 Mtetra
.681 .685 .847 r
.79146 .30953 .79227 .311 .79407 .31039 .79325 .3088 Mtetra
.659 .657 .837 r
.79325 .3088 .79407 .31039 .79588 .30978 .79506 .30817 Mtetra
.653 .652 .837 r
.79506 .30817 .79588 .30978 .79769 .30918 .79687 .30758 Mtetra
.652 .654 .839 r
.79687 .30758 .79769 .30918 .7995 .30859 .79868 .30701 Mtetra
.654 .657 .84 r
.79868 .30701 .7995 .30859 .80132 .30802 .8005 .30642 Mtetra
.648 .651 .839 r
.8005 .30642 .80132 .30802 .80313 .30746 .80232 .30586 Mtetra
.638 .646 .841 r
.80232 .30586 .80313 .30746 .80495 .30691 .80414 .30536 Mtetra
.62 .644 .852 r
.80414 .30536 .80495 .30691 .80677 .30636 .80597 .30496 Mtetra
.615 .667 .877 r
.80597 .30496 .80677 .30636 .80859 .3058 .80781 .30459 Mtetra
.617 .701 .904 r
.80781 .30459 .80859 .3058 .81042 .30526 .80965 .3042 Mtetra
.638 .741 .923 r
.80965 .3042 .81042 .30526 .81224 .30475 .81148 .30371 Mtetra
.645 .75 .926 r
.81148 .30371 .81224 .30475 .81407 .30423 .81331 .30318 Mtetra
.649 .749 .923 r
.81331 .30318 .81407 .30423 .8159 .30371 .81513 .30264 Mtetra
.645 .743 .921 r
.81513 .30264 .8159 .30371 .81773 .30318 .81697 .30212 Mtetra
.65 .747 .92 r
.81697 .30212 .81773 .30318 .81956 .30263 .8188 .30158 Mtetra
.66 .753 .919 r
.8188 .30158 .81956 .30263 .82138 .30203 .82062 .30098 Mtetra
.678 .761 .914 r
.82062 .30098 .82138 .30203 .8232 .30137 .82244 .30031 Mtetra
.684 .763 .911 r
.82244 .30031 .8232 .30137 .82502 .30067 .82426 .29961 Mtetra
.704 .769 .903 r
.82426 .29961 .82502 .30067 .82683 .29988 .82607 .29881 Mtetra
.77 .789 .869 r
.82607 .29881 .82683 .29988 .8286 .2987 .82784 .29762 Mtetra
.692 .761 .904 r
.82784 .29762 .8286 .2987 .83042 .29797 .82966 .29688 Mtetra
.401 .617 .938 r
.82966 .29688 .83042 .29797 .83234 .29825 .83158 .29717 Mtetra
.827 .418 0 r
.83158 .29717 .83234 .29825 .83481 .3041 .83406 .30308 Mtetra
.973 .661 .312 r
.83406 .30308 .83481 .3041 .85715 .509 .85635 .50798 Mtetra
.708 .261 0 r
.85635 .50798 .85715 .509 .85958 .51309 .85878 .51204 Mtetra
.336 .604 .946 r
.85878 .51204 .85958 .51309 .86165 .51351 .86086 .51245 Mtetra
.668 .774 .929 r
.86086 .51245 .86165 .51351 .86361 .51283 .86282 .51178 Mtetra
.85 .823 .822 r
.86282 .51178 .86361 .51283 .86545 .5109 .86466 .50984 Mtetra
.978 .78 .571 r
.86466 .50984 .86545 .5109 .8668 .50427 .86601 .50322 Mtetra
.976 .67 .325 r
.86601 .50322 .8668 .50427 .84747 .29763 .84672 .29652 Mtetra
.966 .781 .602 r
.84672 .29652 .84747 .29763 .84882 .29226 .84807 .29113 Mtetra
.762 .779 .867 r
.84807 .29113 .84882 .29226 .85061 .2911 .84985 .28997 Mtetra
.632 .728 .917 r
.84985 .28997 .85061 .2911 .85247 .29063 .85171 .28951 Mtetra
.555 .691 .93 r
.85171 .28951 .85247 .29063 .85436 .29046 .85361 .28933 Mtetra
.752 .775 .872 r
.85361 .28933 .85436 .29046 .85615 .28937 .8554 .28824 Mtetra
.684 .749 .901 r
.8554 .28824 .85615 .28937 .85799 .28866 .85724 .28753 Mtetra
.48 .651 .934 r
.85724 .28753 .85799 .28866 .85991 .28875 .85916 .28761 Mtetra
.746 .329 0 r
.85916 .28761 .85991 .28875 .86236 .29369 .86161 .29253 Mtetra
.971 .656 .295 r
.86161 .29253 .86236 .29369 .88669 .49944 .88591 .49833 Mtetra
.731 .302 0 r
.88591 .49833 .88669 .49944 .88927 .50421 .88848 .50312 Mtetra
.301 .572 .934 r
.88848 .50312 .88927 .50421 .89138 .50474 .8906 .50366 Mtetra
.651 .763 .931 r
.8906 .50366 .89138 .50474 .89337 .50415 .89259 .50306 Mtetra
.834 .82 .836 r
.89259 .50306 .89337 .50415 .89524 .5024 .89445 .50128 Mtetra
.911 .73 .645 r
.25495 .68709 .256 .68799 .25803 .68171 .25698 .68079 Mtetra
.936 .686 .535 r
.25698 .68079 .25803 .68171 .27447 .485 .27349 .48409 Mtetra
.902 .731 .659 r
.27349 .48409 .27447 .485 .27632 .4799 .27533 .479 Mtetra
.748 .759 .862 r
.27533 .479 .27632 .4799 .27785 .47898 .27687 .47806 Mtetra
.58 .717 .936 r
.27687 .47806 .27785 .47898 .27933 .47878 .27835 .47784 Mtetra
.406 .642 .952 r
.27835 .47784 .27933 .47878 .28078 .47896 .2798 .47801 Mtetra
.637 .727 .913 r
.2798 .47801 .28078 .47896 .28227 .47856 .28129 .47761 Mtetra
.655 .733 .907 r
.28129 .47761 .28227 .47856 .28377 .47808 .28279 .47715 Mtetra
.665 .739 .905 r
.28279 .47715 .28377 .47808 .28528 .47756 .2843 .47664 Mtetra
.756 .759 .855 r
.2843 .47664 .28528 .47756 .28682 .47655 .28584 .47564 Mtetra
.706 .754 .89 r
.28584 .47564 .28682 .47655 .28834 .47585 .28736 .47495 Mtetra
.498 .693 .955 r
.28736 .47495 .28834 .47585 .28981 .47581 .28883 .47492 Mtetra
.926 .544 .251 r
.28883 .47492 .28981 .47581 .291 .47976 .29002 .47892 Mtetra
.939 .683 .522 r
.29002 .47892 .291 .47976 .27871 .67535 .27767 .67455 Mtetra
.933 .579 .331 r
.27767 .67455 .27871 .67535 .2799 .68075 .27885 .6799 Mtetra
.12 .522 .913 r
.27885 .6799 .2799 .68075 .28142 .6814 .28039 .68041 Mtetra
.656 .738 .91 r
.28039 .68041 .28142 .6814 .28302 .68094 .28199 .67991 Mtetra
.756 .749 .846 r
.28199 .67991 .28302 .68094 .28468 .67967 .28364 .67881 Mtetra
.76 .782 .871 r
.28364 .67881 .28468 .67967 .28643 .67705 .28528 .67777 Mtetra
.683 .961 .728 r
.28528 .67777 .28643 .67705 .28836 .67171 .28696 .67624 Mtetra
.191 0 .262 r
.28696 .67624 .28836 .67171 .30284 .47975 .2887 .67367 Mtetra
.525 .311 .531 r
.2887 .67367 .30284 .47975 .3047 .47412 .29111 .66119 Mtetra
0 0 .224 r
.29111 .66119 .3047 .47412 .30635 .47159 .30523 .47298 Mtetra
.95 .94 .612 r
.30523 .47298 .30635 .47159 .30794 .47001 .30696 .46926 Mtetra
.784 .795 .862 r
.30696 .46926 .30794 .47001 .30948 .46924 .30852 .46812 Mtetra
.646 .698 .884 r
.30852 .46812 .30948 .46924 .31099 .4688 .31003 .46769 Mtetra
.564 .669 .909 r
.31003 .46769 .31099 .4688 .3125 .46853 .31153 .46755 Mtetra
.676 .735 .895 r
.31153 .46755 .3125 .46853 .31403 .4678 .31305 .46699 Mtetra
.681 .773 .921 r
.31305 .46699 .31403 .4678 .31556 .46716 .31458 .46642 Mtetra
.63 .777 .951 r
.31458 .46642 .31556 .46716 .31707 .46691 .3161 .46602 Mtetra
.524 .703 .952 r
.3161 .46602 .31707 .46691 .31848 .46818 .31759 .46593 Mtetra
.474 .471 .774 r
.31759 .46593 .31848 .46818 .31973 .47209 .31906 .46635 Mtetra
.443 .326 .625 r
.31906 .46635 .31973 .47209 .3094 .66333 .32046 .46778 Mtetra
.508 .301 .533 r
.32046 .46778 .3094 .66333 .31066 .66866 .32078 .48698 Mtetra
0 0 .254 r
.32078 .48698 .31066 .66866 .31213 .67058 .31125 .66728 Mtetra
0 0 .549 r
.31125 .66728 .31213 .67058 .31367 .67143 .31265 .67029 Mtetra
.347 .579 .929 r
.31265 .67029 .31367 .67143 .31527 .67135 .31422 .67065 Mtetra
.642 .803 .96 r
.31422 .67065 .31527 .67135 .31689 .67085 .31585 .67016 Mtetra
.728 .82 .922 r
.31585 .67016 .31689 .67085 .31852 .67017 .31749 .66934 Mtetra
.676 .78 .929 r
.31749 .66934 .31852 .67017 .32015 .66965 .31912 .66874 Mtetra
.654 .757 .926 r
.31912 .66874 .32015 .66965 .32177 .66921 .32075 .66824 Mtetra
.653 .745 .917 r
.32075 .66824 .32177 .66921 .3234 .66876 .32238 .66774 Mtetra
.618 .723 .921 r
.32238 .66774 .3234 .66876 .32501 .66856 .324 .66739 Mtetra
.63 .697 .893 r
.324 .66739 .32501 .66856 .32663 .66825 .32562 .66699 Mtetra
.669 .696 .867 r
.32562 .66699 .32663 .66825 .32827 .66752 .32726 .66641 Mtetra
.774 .742 .824 r
.32726 .66641 .32827 .66752 .33001 .66512 .32893 .6651 Mtetra
.887 .934 .842 r
.32893 .6651 .33001 .66512 .33189 .66004 .33064 .66323 Mtetra
.095 0 .151 r
.33064 .66323 .33189 .66004 .34404 .46812 .33237 .66103 Mtetra
.547 .329 .535 r
.33237 .66103 .34404 .46812 .34583 .46317 .33405 .65974 Mtetra
.549 .33 .535 r
.33405 .65974 .34583 .46317 .34738 .46258 .33568 .65929 Mtetra
.55 .331 .535 r
.33568 .65929 .34738 .46258 .34886 .46312 .33729 .65915 Mtetra
.55 .331 .536 r
.33729 .65915 .34886 .46312 .35033 .46397 .33889 .65938 Mtetra
.55 .331 .535 r
.33889 .65938 .35033 .46397 .35183 .46435 .3405 .65929 Mtetra
.548 .33 .535 r
.3405 .65929 .35183 .46435 .35342 .46309 .34217 .65829 Mtetra
.537 .321 .533 r
.34217 .65829 .35342 .46309 .35517 .45876 .34413 .65163 Mtetra
0 0 .257 r
.34413 .65163 .35517 .45876 .35686 .4554 .35576 .45716 Mtetra
.951 .913 .543 r
.35576 .45716 .35686 .4554 .35849 .45313 .35752 .45252 Mtetra
.842 .824 .83 r
.35752 .45252 .35849 .45313 .36007 .45202 .35913 .45092 Mtetra
.673 .712 .877 r
.35913 .45092 .36007 .45202 .36162 .45149 .36068 .45035 Mtetra
.585 .675 .902 r
.36068 .45035 .36162 .45149 .36316 .45118 .36221 .45014 Mtetra
.599 .702 .916 r
.36221 .45014 .36316 .45118 .3647 .45086 .36375 .44987 Mtetra
.619 .719 .918 r
.36375 .44987 .3647 .45086 .36624 .45053 .36529 .44953 Mtetra
.619 .718 .917 r
.36529 .44953 .36624 .45053 .36778 .45018 .36683 .44919 Mtetra
.637 .724 .911 r
.36683 .44919 .36778 .45018 .36933 .44976 .36838 .44878 Mtetra
.655 .732 .906 r
.36838 .44878 .36933 .44976 .37088 .44926 .36993 .4483 Mtetra
.668 .74 .905 r
.36993 .4483 .37088 .44926 .37244 .44869 .37149 .44777 Mtetra
.686 .752 .902 r
.37149 .44777 .37244 .44869 .374 .44803 .37305 .44716 Mtetra
.697 .767 .906 r
.37305 .44716 .374 .44803 .37557 .44731 .37461 .4465 Mtetra
.699 .782 .916 r
.37461 .4465 .37557 .44731 .37713 .44659 .37618 .44584 Mtetra
.709 .796 .919 r
.37618 .44584 .37713 .44659 .3787 .44577 .37774 .44513 Mtetra
.697 .822 .942 r
.37774 .44513 .3787 .44577 .38027 .44504 .37931 .44447 Mtetra
.633 .828 .975 r
.37931 .44447 .38027 .44504 .38182 .44468 .38087 .444 Mtetra
.499 .756 .987 r
.38087 .444 .38182 .44468 .38333 .44543 .38241 .44387 Mtetra
.434 .531 .857 r
.38241 .44387 .38333 .44543 .38475 .44821 .38393 .44424 Mtetra
.413 .345 .671 r
.38393 .44424 .38475 .44821 .37834 .63578 .38542 .44548 Mtetra
.538 .325 .539 r
.38542 .44548 .37834 .63578 .37948 .6476 .38671 .45158 Mtetra
0 0 .295 r
.38671 .45158 .37948 .6476 .38102 .65005 .38015 .64571 Mtetra
0 0 .533 r
.38015 .64571 .38102 .65005 .38261 .65111 .38163 .64957 Mtetra
.202 .418 .848 r
.38163 .64957 .38261 .65111 .38425 .65126 .38324 .65047 Mtetra
.603 .774 .962 r
.38324 .65047 .38425 .65126 .38591 .65085 .3849 .6501 Mtetra
.71 .812 .928 r
.3849 .6501 .38591 .65085 .38758 .6502 .38658 .64934 Mtetra
.676 .779 .928 r
.38658 .64934 .38758 .6502 .38925 .64979 .38825 .64873 Mtetra
.634 .726 .914 r
.38825 .64873 .38925 .64979 .39091 .6495 .38992 .6483 Mtetra
.671 .711 .879 r
.38992 .6483 .39091 .6495 .39258 .64885 .39159 .64771 Mtetra
.756 .741 .838 r
.39159 .64771 .39258 .64885 .39431 .64693 .39328 .64655 Mtetra
.87 .881 .841 r
.39328 .64655 .39431 .64693 .39612 .64258 .39501 .64474 Mtetra
0 0 0 r
.39501 .64474 .39612 .64258 .4046 .45638 .39674 .64256 Mtetra
.548 .329 .535 r
.39674 .64256 .4046 .45638 .40662 .44374 .39844 .64133 Mtetra
.55 .331 .535 r
.39844 .64133 .40662 .44374 .4082 .44328 .4001 .64124 Mtetra
.549 .33 .535 r
.4001 .64124 .4082 .44328 .40976 .44332 .40177 .64061 Mtetra
.542 .324 .534 r
.40177 .64061 .40976 .44332 .41142 .44056 .40359 .63601 Mtetra
0 0 .293 r
.40359 .63601 .41142 .44056 .4131 .43705 .41204 .43971 Mtetra
.848 .842 .376 r
.41204 .43971 .4131 .43705 .41474 .43467 .41379 .43427 Mtetra
.892 .859 .802 r
.41379 .43427 .41474 .43467 .41635 .43332 .41542 .4322 Mtetra
.694 .719 .869 r
.41542 .4322 .41635 .43332 .41793 .43272 .41701 .43152 Mtetra
.614 .677 .886 r
.41701 .43152 .41793 .43272 .41951 .43234 .41858 .4312 Mtetra
.619 .692 .896 r
.41858 .4312 .41951 .43234 .42109 .43193 .42016 .43086 Mtetra
.664 .721 .891 r
.42016 .43086 .42109 .43193 .42267 .4314 .42174 .43033 Mtetra
.663 .72 .891 r
.42174 .43033 .42267 .4314 .42425 .43087 .42333 .42981 Mtetra
.695 .73 .878 r
.42333 .42981 .42425 .43087 .42584 .43025 .42492 .42912 Mtetra
.706 .723 .863 r
.42492 .42912 .42584 .43025 .42743 .42957 .42651 .42836 Mtetra
.636 .686 .88 r
.42651 .42836 .42743 .42957 .42902 .42909 .42809 .42795 Mtetra
.116 .429 .871 r
.42809 .42795 .42902 .42909 .43058 .42927 .42964 .42874 Mtetra
.905 .499 .207 r
.42964 .42874 .43058 .42927 .43212 .43052 .43111 .43261 Mtetra
.951 .681 .489 r
.43111 .43261 .43212 .43052 .43363 .43281 .42716 .62782 Mtetra
.558 .338 .537 r
.42716 .62782 .43363 .43281 .43516 .43484 .4287 .63258 Mtetra
.549 .331 .535 r
.4287 .63258 .43516 .43484 .43677 .4338 .43038 .63231 Mtetra
.548 .33 .535 r
.43038 .63231 .43677 .4338 .43836 .43314 .43209 .63142 Mtetra
.55 .331 .535 r
.43209 .63142 .43836 .43314 .43979 .43923 .43376 .63146 Mtetra
.552 .333 .536 r
.43376 .63146 .43979 .43923 .43649 .63017 .43541 .63272 Mtetra
.604 .252 .346 r
.43541 .63272 .43649 .63017 .43808 .63388 .43708 .63359 Mtetra
.005 .562 .814 r
.43708 .63359 .43808 .63388 .43973 .63504 .43876 .63383 Mtetra
.628 .697 .894 r
.43876 .63383 .43973 .63504 .44143 .63474 .44045 .63343 Mtetra
.66 .69 .868 r
.44045 .63343 .44143 .63474 .44313 .63409 .44216 .63286 Mtetra
.65 .702 .885 r
.44216 .63286 .44313 .63409 .44483 .63348 .44386 .63236 Mtetra
.605 .706 .915 r
.44386 .63236 .44483 .63348 .44653 .63316 .44556 .63204 Mtetra
.611 .709 .914 r
.44556 .63204 .44653 .63316 .44823 .6328 .44726 .6317 Mtetra
.603 .708 .918 r
.44726 .6317 .44823 .6328 .44994 .63241 .44896 .63138 Mtetra
.599 .724 .932 r
.44896 .63138 .44994 .63241 .45164 .63193 .45066 .63107 Mtetra
.693 .788 .923 r
.45066 .63107 .45164 .63193 .45335 .63121 .45237 .63037 Mtetra
.84 .803 .815 r
.45237 .63037 .45335 .63121 .45508 .62992 .45411 .62856 Mtetra
.9 .729 .66 r
.45411 .62856 .45508 .62992 .45682 .62749 .45591 .62362 Mtetra
.954 .686 .491 r
.45591 .62362 .45682 .62749 .45859 .62402 .46143 .42742 Mtetra
.564 .347 .543 r
.46143 .42742 .45859 .62402 .46036 .61991 .46317 .42041 Mtetra
.553 .337 .542 r
.46317 .42041 .46036 .61991 .46209 .61859 .46479 .41935 Mtetra
.551 .336 .542 r
.46479 .41935 .46209 .61859 .46378 .61872 .4664 .41916 Mtetra
.55 .336 .541 r
.4664 .41916 .46378 .61872 .46547 .61941 .468 .41928 Mtetra
.551 .336 .542 r
.468 .41928 .46547 .61941 .46717 .61992 .46961 .41907 Mtetra
.552 .337 .542 r
.46961 .41907 .46717 .61992 .46888 .6193 .47122 .41857 Mtetra
.553 .338 .542 r
.47122 .41857 .46888 .6193 .47067 .61434 .47285 .41724 Mtetra
.555 .339 .542 r
.47285 .41724 .47067 .61434 .47534 .41982 .47449 .41506 Mtetra
.672 .504 .649 r
.47449 .41506 .47534 .41982 .47703 .41495 .47613 .41322 Mtetra
.74 .659 .77 r
.47613 .41322 .47703 .41495 .47867 .41265 .47776 .41192 Mtetra
.688 .808 .939 r
.47776 .41192 .47867 .41265 .48029 .41188 .47937 .41128 Mtetra
.623 .826 .979 r
.47937 .41128 .48029 .41188 .4819 .41147 .48099 .41082 Mtetra
.612 .808 .975 r
.48099 .41082 .4819 .41147 .48352 .41117 .48261 .4104 Mtetra
.656 .792 .947 r
.48261 .4104 .48352 .41117 .48514 .41065 .48423 .40988 Mtetra
.65 .789 .948 r
.48423 .40988 .48514 .41065 .48676 .41017 .48585 .40938 Mtetra
.638 .782 .95 r
.48585 .40938 .48676 .41017 .48838 .40973 .48747 .40892 Mtetra
.618 .768 .952 r
.48747 .40892 .48838 .40973 .49 .40939 .48909 .40853 Mtetra
.618 .757 .944 r
.48909 .40853 .49 .40939 .49162 .40906 .49072 .40815 Mtetra
.63 .748 .932 r
.49072 .40815 .49162 .40906 .49325 .40869 .49234 .40773 Mtetra
.654 .745 .917 r
.49234 .40773 .49325 .40869 .49487 .40821 .49397 .40723 Mtetra
.663 .744 .91 r
.49397 .40723 .49487 .40821 .4965 .40769 .4956 .4067 Mtetra
.667 .742 .907 r
.4956 .4067 .4965 .40769 .49813 .40715 .49722 .40614 Mtetra
.665 .74 .906 r
.49722 .40614 .49813 .40715 .49975 .40662 .49885 .4056 Mtetra
.671 .738 .9 r
.49885 .4056 .49975 .40662 .50138 .40606 .50048 .40502 Mtetra
.682 .739 .894 r
.50048 .40502 .50138 .40606 .50302 .40543 .50212 .40439 Mtetra
.699 .743 .886 r
.50212 .40439 .50302 .40543 .50465 .40471 .50375 .40368 Mtetra
.701 .746 .887 r
.50375 .40368 .50465 .40471 .50628 .40397 .50538 .40296 Mtetra
.695 .748 .892 r
.50538 .40296 .50628 .40397 .50792 .40328 .50702 .40227 Mtetra
.677 .745 .902 r
.50702 .40227 .50792 .40328 .50955 .40268 .50865 .40167 Mtetra
.671 .742 .903 r
.50865 .40167 .50955 .40268 .51119 .40211 .51029 .40109 Mtetra
.668 .739 .903 r
.51029 .40109 .51119 .40211 .51282 .40156 .51193 .40053 Mtetra
.669 .737 .901 r
.51193 .40053 .51282 .40156 .51446 .40099 .51357 .39996 Mtetra
.667 .736 .901 r
.51357 .39996 .51446 .40099 .5161 .40044 .5152 .3994 Mtetra
.666 .735 .901 r
.5152 .3994 .5161 .40044 .51774 .39988 .51684 .39884 Mtetra
.51684 .39884 .51774 .39988 .51938 .39933 .51849 .39829 Mtetra
.665 .734 .902 r
.51849 .39829 .51938 .39933 .52102 .39878 .52013 .39774 Mtetra
.664 .734 .902 r
.52013 .39774 .52102 .39878 .52266 .39823 .52177 .39719 Mtetra
.52177 .39719 .52266 .39823 .5243 .39769 .52341 .39664 Mtetra
.663 .734 .902 r
.52341 .39664 .5243 .39769 .52595 .39714 .52506 .3961 Mtetra
.663 .733 .902 r
.52506 .3961 .52595 .39714 .52759 .3966 .5267 .39556 Mtetra
.662 .733 .903 r
.5267 .39556 .52759 .3966 .52924 .39606 .52835 .39502 Mtetra
.661 .733 .903 r
.52835 .39502 .52924 .39606 .53089 .39552 .53 .39448 Mtetra
.53 .39448 .53089 .39552 .53254 .39499 .53165 .39395 Mtetra
.66 .733 .904 r
.53165 .39395 .53254 .39499 .53418 .39445 .5333 .39341 Mtetra
.659 .733 .904 r
.5333 .39341 .53418 .39445 .53583 .39393 .53495 .39289 Mtetra
.658 .733 .905 r
.53495 .39289 .53583 .39393 .53749 .3934 .5366 .39236 Mtetra
.658 .734 .906 r
.5366 .39236 .53749 .3934 .53914 .39287 .53825 .39184 Mtetra
.654 .735 .909 r
.53825 .39184 .53914 .39287 .54079 .39235 .53991 .39133 Mtetra
.646 .734 .913 r
.53991 .39133 .54079 .39235 .54244 .39187 .54156 .39086 Mtetra
.622 .726 .921 r
.54156 .39086 .54244 .39187 .5441 .3915 .54322 .39047 Mtetra
.618 .722 .92 r
.54322 .39047 .5441 .3915 .54576 .39115 .54488 .39011 Mtetra
.622 .72 .917 r
.54488 .39011 .54576 .39115 .54742 .39078 .54653 .38973 Mtetra
.647 .727 .907 r
.54653 .38973 .54742 .39078 .54908 .3903 .54819 .38924 Mtetra
.656 .731 .905 r
.54819 .38924 .54908 .3903 .55074 .38976 .54985 .38873 Mtetra
.662 .736 .905 r
.54985 .38873 .55074 .38976 .5524 .3892 .55151 .38818 Mtetra
.659 .739 .909 r
.55151 .38818 .5524 .3892 .55406 .38867 .55318 .38765 Mtetra
.665 .743 .908 r
.55318 .38765 .55406 .38867 .55572 .3881 .55484 .3871 Mtetra
.673 .748 .907 r
.55484 .3871 .55572 .3881 .55738 .38748 .5565 .3865 Mtetra
.694 .759 .902 r
.5565 .3865 .55738 .38748 .55904 .38674 .55817 .38582 Mtetra
.697 .772 .909 r
.55817 .38582 .55904 .38674 .56071 .38599 .55983 .38512 Mtetra
.695 .783 .919 r
.55983 .38512 .56071 .38599 .56237 .38526 .5615 .38443 Mtetra
.673 .787 .935 r
.5615 .38443 .56237 .38526 .56404 .38464 .56316 .38383 Mtetra
.665 .79 .941 r
.56316 .38383 .56404 .38464 .5657 .38406 .56483 .38326 Mtetra
.661 .791 .944 r
.56483 .38326 .5657 .38406 .56737 .3835 .5665 .3827 Mtetra
.663 .793 .944 r
.5665 .3827 .56737 .3835 .56904 .38293 .56817 .38214 Mtetra
.662 .796 .946 r
.56817 .38214 .56904 .38293 .57071 .38236 .56984 .38158 Mtetra
.662 .798 .948 r
.56984 .38158 .57071 .38236 .57239 .38179 .57152 .38102 Mtetra
.697 .808 .934 r
.57152 .38102 .57239 .38179 .57405 .38096 .57319 .38032 Mtetra
.669 .834 .962 r
.57319 .38032 .57405 .38096 .57573 .38033 .57486 .3797 Mtetra
.6 .819 .984 r
.57486 .3797 .57573 .38033 .57741 .3801 .57654 .37929 Mtetra
.265 .604 .953 r
.57654 .37929 .57741 .3801 .57912 .38177 .57823 .37965 Mtetra
.385 .438 .793 r
.57823 .37965 .57912 .38177 .58089 .38652 .57993 .38044 Mtetra
.488 .36 .632 r
.57993 .38044 .58089 .38652 .58611 .5826 .58164 .38155 Mtetra
.552 .337 .542 r
.58164 .38155 .58611 .5826 .58793 .58378 .58332 .38082 Mtetra
.58332 .38082 .58793 .58378 .58971 .58285 .585 .37998 Mtetra
.551 .336 .542 r
.585 .37998 .58971 .58285 .59149 .58205 .58669 .37997 Mtetra
.521 .313 .538 r
.58669 .37997 .59149 .58205 .59336 .58528 .5887 .39545 Mtetra
0 0 .391 r
.5887 .39545 .59336 .58528 .59521 .58746 .59425 .58431 Mtetra
0 .085 .616 r
.59425 .58431 .59521 .58746 .59705 .58866 .59612 .5875 Mtetra
.42 .621 .935 r
.59612 .5875 .59705 .58866 .59885 .58856 .59794 .58774 Mtetra
.643 .796 .956 r
.59794 .58774 .59885 .58856 .60065 .58803 .59974 .5872 Mtetra
.721 .815 .923 r
.59974 .5872 .60065 .58803 .60245 .58731 .60153 .58633 Mtetra
.634 .756 .936 r
.60153 .58633 .60245 .58731 .60426 .58704 .60334 .58585 Mtetra
.642 .718 .903 r
.60334 .58585 .60426 .58704 .60607 .58663 .60514 .58536 Mtetra
.682 .716 .875 r
.60514 .58536 .60607 .58663 .60786 .58579 .60695 .58465 Mtetra
.793 .77 .832 r
.60695 .58465 .60786 .58579 .60962 .58305 .60873 .58318 Mtetra
.87 .993 .812 r
.60873 .58318 .60962 .58305 .61129 .57745 .6105 .58121 Mtetra
.238 0 .278 r
.6105 .58121 .61129 .57745 .60799 .38021 .61226 .57892 Mtetra
.549 .33 .535 r
.61226 .57892 .60799 .38021 .60962 .37689 .61407 .57837 Mtetra
.549 .331 .535 r
.61407 .57837 .60962 .37689 .61133 .37669 .61589 .57814 Mtetra
.548 .33 .535 r
.61589 .57814 .61133 .37669 .61304 .37651 .61769 .57712 Mtetra
.534 .319 .534 r
.61769 .57712 .61304 .37651 .61464 .37246 .61925 .56762 Mtetra
0 0 .387 r
.61925 .56762 .61464 .37246 .61627 .36925 .61548 .37049 Mtetra
.903 .894 .478 r
.61548 .37049 .61627 .36925 .61792 .36704 .61708 .36623 Mtetra
.818 .824 .855 r
.61708 .36623 .61792 .36704 .61961 .366 .61875 .3648 Mtetra
.665 .711 .882 r
.61875 .3648 .61961 .366 .62131 .36543 .62045 .36423 Mtetra
.588 .677 .902 r
.62045 .36423 .62131 .36543 .62302 .36507 .62217 .36398 Mtetra
.612 .713 .917 r
.62217 .36398 .62302 .36507 .62473 .36468 .62388 .36363 Mtetra
.624 .725 .919 r
.62388 .36363 .62473 .36468 .62644 .36428 .62559 .36323 Mtetra
.632 .729 .918 r
.62559 .36323 .62644 .36428 .62815 .36383 .6273 .3628 Mtetra
.671 .748 .908 r
.6273 .3628 .62815 .36383 .62985 .36316 .629 .3622 Mtetra
.692 .768 .91 r
.629 .3622 .62985 .36316 .63155 .3624 .63071 .3615 Mtetra
.697 .786 .919 r
.63071 .3615 .63155 .3624 .63325 .36162 .63241 .36079 Mtetra
.708 .803 .924 r
.63241 .36079 .63325 .36162 .63495 .36073 .63412 .36003 Mtetra
.688 .831 .951 r
.63412 .36003 .63495 .36073 .63666 .35998 .63583 .35934 Mtetra
.627 .829 .978 r
.63583 .35934 .63666 .35998 .63838 .3596 .63754 .35884 Mtetra
.516 .752 .981 r
.63754 .35884 .63838 .3596 .64014 .36045 .63927 .35868 Mtetra
.478 .533 .836 r
.63927 .35868 .64014 .36045 .64198 .36317 .64102 .35899 Mtetra
.449 .37 .676 r
.64102 .35899 .64198 .36317 .65072 .551 .6428 .36015 Mtetra
.539 .327 .541 r
.6428 .36015 .65072 .551 .65316 .56674 .64477 .36633 Mtetra
.001 0 .412 r
.64477 .36633 .65316 .56674 .65511 .56934 .65409 .56505 Mtetra
.065 .116 .605 r
.65409 .56505 .65511 .56934 .65701 .57036 .6561 .56894 Mtetra
.365 .54 .894 r
.6561 .56894 .65701 .57036 .65886 .57022 .65798 .56947 Mtetra
.674 .828 .957 r
.65798 .56947 .65886 .57022 .66069 .56945 .65981 .56879 Mtetra
.77 .87 .921 r
.65981 .56879 .66069 .56945 .66251 .56839 .66163 .56766 Mtetra
.689 .837 .954 r
.66163 .56766 .66251 .56839 .66435 .56781 .66346 .56691 Mtetra
.645 .784 .948 r
.66346 .56691 .66435 .56781 .66619 .56734 .66531 .56636 Mtetra
.695 .783 .919 r
.66531 .56636 .66619 .56734 .66802 .5664 .66714 .56561 Mtetra
.785 .842 .894 r
.66714 .56561 .66802 .5664 .66977 .56358 .66896 .56436 Mtetra
.609 .875 .543 r
.66896 .56436 .66977 .56358 .67127 .55517 .67074 .56234 Mtetra
.311 .083 .398 r
.67074 .56234 .67127 .55517 .66445 .35718 .67245 .55862 Mtetra
.016 0 .412 r
.67245 .55862 .66445 .35718 .666 .35256 .66553 .35984 Mtetra
0 0 .27 r
.66553 .35984 .666 .35256 .66765 .35013 .66692 .35152 Mtetra
.639 .785 .331 r
.66692 .35152 .66765 .35013 .66934 .34877 .66854 .34837 Mtetra
.719 .919 .961 r
.66854 .34837 .66934 .34877 .67111 .34909 .67026 .34748 Mtetra
.431 .53 .858 r
.67026 .34748 .67111 .34909 .67298 .35144 .67204 .34792 Mtetra
.424 .377 .701 r
.67204 .34792 .67298 .35144 .67515 .35996 .67385 .34908 Mtetra
.549 .372 .593 r
.67385 .34908 .67515 .35996 .68608 .55167 .67563 .34931 Mtetra
.552 .337 .542 r
.67563 .34931 .68608 .55167 .68794 .55146 .67736 .34855 Mtetra
.551 .336 .542 r
.67736 .34855 .68794 .55146 .68978 .55052 .67911 .34823 Mtetra
.545 .331 .541 r
.67911 .34823 .68978 .55052 .69183 .55404 .68105 .35161 Mtetra
.023 0 .425 r
.68105 .35161 .69183 .55404 .69388 .55725 .69279 .55196 Mtetra
.026 .065 .564 r
.69279 .55196 .69388 .55725 .69585 .55891 .69494 .55718 Mtetra
.267 .432 .84 r
.69494 .55718 .69585 .55891 .69775 .55915 .69688 .5582 Mtetra
.634 .771 .945 r
.69688 .5582 .69775 .55915 .69961 .55855 .69875 .55769 Mtetra
.728 .821 .922 r
.69875 .55769 .69961 .55855 .70147 .55773 .7006 .55676 Mtetra
.658 .777 .937 r
.7006 .55676 .70147 .55773 .70334 .55734 .70246 .55616 Mtetra
.585 .702 .923 r
.70246 .55616 .70334 .55734 .70523 .55722 .70434 .55588 Mtetra
.629 .692 .889 r
.70434 .55588 .70523 .55722 .7071 .55672 .70622 .55543 Mtetra
.706 .73 .869 r
.70622 .55543 .7071 .55672 .70891 .55495 .70807 .55456 Mtetra
.825 .941 .902 r
.70807 .55456 .70891 .55495 .71059 .55094 .7099 .55309 Mtetra
0 0 .05 r
.7099 .55309 .71059 .55094 .71163 .53543 .71167 .55076 Mtetra
.388 .18 .472 r
.71167 .55076 .71163 .53543 .70277 .34405 .71324 .54478 Mtetra
.027 0 .421 r
.71324 .54478 .70277 .34405 .70437 .34064 .70378 .34371 Mtetra
0 0 0 r
.70378 .34371 .70437 .34064 .70604 .33863 .70526 .33829 Mtetra
.907 .929 .817 r
.70526 .33829 .70604 .33863 .70776 .33745 .70694 .33624 Mtetra
.688 .723 .877 r
.70694 .33624 .70776 .33745 .70951 .33681 .70869 .33552 Mtetra
.611 .679 .89 r
.70869 .33552 .70951 .33681 .71128 .33635 .71046 .33518 Mtetra
.691 .733 .883 r
.71046 .33518 .71128 .33635 .71302 .33549 .71221 .33445 Mtetra
.752 .779 .875 r
.71221 .33445 .71302 .33549 .71475 .33438 .71394 .3334 Mtetra
.645 .756 .93 r
.71394 .3334 .71475 .33438 .71651 .33382 .7157 .33289 Mtetra
0 .171 .679 r
.7157 .33289 .71651 .33382 .71839 .33528 .7176 .33443 Mtetra
.975 .675 .375 r
.7176 .33443 .71839 .33528 .72139 .35462 .73112 .52478 Mtetra
.585 .357 .537 r
.73112 .52478 .72139 .35462 .73516 .54617 .7343 .54519 Mtetra
0 .03 .55 r
.7343 .54519 .73516 .54617 .73722 .54837 .73636 .54726 Mtetra
.594 .723 .934 r
.73636 .54726 .73722 .54837 .73913 .54813 .73826 .54693 Mtetra
.74 .759 .868 r
.73826 .54693 .73913 .54813 .74098 .54699 .74012 .54586 Mtetra
.778 .781 .855 r
.74012 .54586 .74098 .54699 .74278 .54485 .74197 .54453 Mtetra
.808 .96 .911 r
.74197 .54453 .74278 .54485 .74445 .54094 .74381 .54312 Mtetra
.03 0 .085 r
.74381 .54312 .74445 .54094 .74551 .52769 .74559 .54091 Mtetra
.374 .166 .463 r
.74559 .54091 .74551 .52769 .73454 .33355 .74716 .53531 Mtetra
.043 0 .431 r
.74716 .53531 .73454 .33355 .7361 .32982 .73558 .33302 Mtetra
0 0 .032 r
.73558 .33302 .7361 .32982 .73777 .32765 .73702 .32745 Mtetra
.919 .953 .797 r
.73702 .32745 .73777 .32765 .7395 .32641 .73869 .32526 Mtetra
.676 .733 .893 r
.73869 .32526 .7395 .32641 .74128 .32588 .74046 .32461 Mtetra
.587 .672 .898 r
.74046 .32461 .74128 .32588 .74307 .32556 .74226 .32436 Mtetra
.617 .698 .902 r
.74226 .32436 .74307 .32556 .74485 .325 .74406 .32398 Mtetra
.709 .771 .901 r
.74406 .32398 .74485 .325 .7466 .32404 .74582 .32318 Mtetra
.682 .8 .938 r
.74582 .32318 .7466 .32404 .74838 .32336 .74759 .3225 Mtetra
.592 .766 .962 r
.74759 .3225 .74838 .32336 .75022 .32358 .74939 .32215 Mtetra
.487 .591 .884 r
.74939 .32215 .75022 .32358 .7522 .32578 .75123 .32233 Mtetra
.456 .402 .709 r
.75123 .32233 .7522 .32578 .75467 .33463 .75313 .32327 Mtetra
.428 .286 .585 r
.75313 .32327 .75467 .33463 .77096 .53169 .75523 .32702 Mtetra
.065 0 .448 r
.75523 .32702 .77096 .53169 .77314 .53479 .77193 .52865 Mtetra
.147 .137 .588 r
.77193 .52865 .77314 .53479 .7752 .53609 .77427 .53391 Mtetra
.23 .354 .783 r
.77427 .53391 .7752 .53609 .77719 .53654 .77634 .53544 Mtetra
.551 .707 .943 r
.77634 .53544 .77719 .53654 .77914 .53638 .77829 .53525 Mtetra
.695 .761 .903 r
.77829 .53525 .77914 .53638 .78104 .53566 .78019 .53446 Mtetra
.753 .768 .865 r
.78019 .53446 .78104 .53566 .78288 .53402 .78207 .53329 Mtetra
.811 .875 .894 r
.78207 .53329 .78288 .53402 .78457 .53053 .78393 .53188 Mtetra
0 0 0 r
.78393 .53188 .78457 .53053 .78587 .52192 .78572 .52969 Mtetra
.281 .071 .407 r
.78572 .52969 .78587 .52192 .77211 .32201 .78732 .52492 Mtetra
.064 0 .442 r
.78732 .52492 .77211 .32201 .77362 .31777 .77325 .32197 Mtetra
0 0 .152 r
.77325 .32197 .77362 .31777 .77528 .31542 .77458 .31541 Mtetra
.938 .965 .731 r
.77458 .31541 .77528 .31542 .77701 .31398 .77622 .31283 Mtetra
.715 .751 .881 r
.77622 .31283 .77701 .31398 .7788 .31323 .778 .31196 Mtetra
.624 .691 .893 r
.778 .31196 .7788 .31323 .78061 .31276 .77981 .31155 Mtetra
.586 .685 .91 r
.77981 .31155 .78061 .31276 .78243 .3124 .78164 .3113 Mtetra
.624 .724 .918 r
.78164 .3113 .78243 .3124 .78424 .31199 .78346 .31087 Mtetra
.624 .721 .916 r
.78346 .31087 .78424 .31199 .78606 .31157 .78528 .31044 Mtetra
.644 .729 .911 r
.78528 .31044 .78606 .31157 .78787 .31104 .78709 .30993 Mtetra
.681 .748 .902 r
.78709 .30993 .78787 .31104 .78967 .3103 .78889 .30925 Mtetra
.689 .763 .908 r
.78889 .30925 .78967 .3103 .79146 .30953 .79069 .30854 Mtetra
.684 .774 .919 r
.79069 .30854 .79146 .30953 .79325 .3088 .79249 .30785 Mtetra
.665 .776 .932 r
.79249 .30785 .79325 .3088 .79506 .30817 .7943 .30724 Mtetra
.659 .777 .937 r
.7943 .30724 .79506 .30817 .79687 .30758 .79611 .30665 Mtetra
.656 .778 .938 r
.79611 .30665 .79687 .30758 .79868 .30701 .79792 .30607 Mtetra
.658 .779 .938 r
.79792 .30607 .79868 .30701 .8005 .30642 .79974 .30549 Mtetra
.653 .777 .94 r
.79974 .30549 .8005 .30642 .80232 .30586 .80156 .30492 Mtetra
.641 .771 .942 r
.80156 .30492 .80232 .30586 .80414 .30536 .80338 .3044 Mtetra
.619 .758 .945 r
.80338 .3044 .80414 .30536 .80597 .30496 .80521 .30397 Mtetra
.615 .747 .94 r
.80521 .30397 .80597 .30496 .80781 .30459 .80705 .30356 Mtetra
.621 .74 .931 r
.80705 .30356 .80781 .30459 .80965 .3042 .80888 .30313 Mtetra
.641 .739 .92 r
.80888 .30313 .80965 .3042 .81148 .30371 .81071 .30262 Mtetra
.646 .74 .917 r
.81071 .30262 .81148 .30371 .81331 .30318 .81254 .3021 Mtetra
.649 .74 .916 r
.81254 .3021 .81331 .30318 .81513 .30264 .81437 .30156 Mtetra
.645 .74 .918 r
.81437 .30156 .81513 .30264 .81697 .30212 .8162 .30103 Mtetra
.651 .742 .916 r
.8162 .30103 .81697 .30212 .8188 .30158 .81803 .30049 Mtetra
.66 .746 .913 r
.81803 .30049 .8188 .30158 .82062 .30098 .81986 .2999 Mtetra
.678 .753 .908 r
.81986 .2999 .82062 .30098 .82244 .30031 .82168 .29922 Mtetra
.684 .755 .906 r
.82168 .29922 .82244 .30031 .82426 .29961 .8235 .29852 Mtetra
.703 .763 .898 r
.8235 .29852 .82426 .29961 .82607 .29881 .82531 .29772 Mtetra
.769 .785 .866 r
.82531 .29772 .82607 .29881 .82784 .29762 .82708 .29653 Mtetra
.692 .758 .902 r
.82708 .29653 .82784 .29762 .82966 .29688 .8289 .29578 Mtetra
.403 .615 .936 r
.8289 .29578 .82966 .29688 .83158 .29717 .83082 .29607 Mtetra
.828 .42 0 r
.83082 .29607 .83158 .29717 .83406 .30308 .83331 .30204 Mtetra
.973 .661 .312 r
.83331 .30204 .83406 .30308 .85635 .50798 .85556 .50695 Mtetra
.702 .256 0 r
.85556 .50695 .85635 .50798 .85878 .51204 .85799 .51099 Mtetra
.339 .605 .946 r
.85799 .51099 .85878 .51204 .86086 .51245 .86006 .5114 Mtetra
.668 .773 .928 r
.86006 .5114 .86086 .51245 .86282 .51178 .86202 .51072 Mtetra
.849 .823 .822 r
.86202 .51072 .86282 .51178 .86466 .50984 .86386 .50878 Mtetra
.977 .78 .572 r
.86386 .50878 .86466 .50984 .86601 .50322 .86522 .50216 Mtetra
.976 .67 .326 r
.86522 .50216 .86601 .50322 .84672 .29652 .84596 .2954 Mtetra
.966 .781 .602 r
.84596 .2954 .84672 .29652 .84807 .29113 .84731 .29001 Mtetra
.762 .779 .867 r
.84731 .29001 .84807 .29113 .84985 .28997 .8491 .28885 Mtetra
.632 .728 .917 r
.8491 .28885 .84985 .28997 .85171 .28951 .85096 .28838 Mtetra
.556 .691 .93 r
.85096 .28838 .85171 .28951 .85361 .28933 .85285 .2882 Mtetra
.752 .775 .872 r
.85285 .2882 .85361 .28933 .8554 .28824 .85465 .28711 Mtetra
.684 .749 .901 r
.85465 .28711 .8554 .28824 .85724 .28753 .85649 .28639 Mtetra
.481 .651 .934 r
.85649 .28639 .85724 .28753 .85916 .28761 .85841 .28647 Mtetra
.744 .326 0 r
.85841 .28647 .85916 .28761 .86161 .29253 .86086 .29136 Mtetra
.971 .656 .295 r
.86086 .29136 .86161 .29253 .88591 .49833 .88512 .49721 Mtetra
.731 .302 0 r
.88512 .49721 .88591 .49833 .88848 .50312 .88769 .50202 Mtetra
.304 .573 .934 r
.88769 .50202 .88848 .50312 .8906 .50366 .88981 .50256 Mtetra
.653 .759 .928 r
.88981 .50256 .8906 .50366 .89259 .50306 .8918 .50195 Mtetra
.833 .815 .833 r
.8918 .50195 .89259 .50306 .89445 .50128 .89367 .50016 Mtetra
.905 .737 .664 r
.2539 .68621 .25495 .68709 .25698 .68079 .25585 .68099 Mtetra
.938 .688 .534 r
.25585 .68099 .25698 .68079 .27349 .48409 .27233 .48542 Mtetra
.99 .85 .608 r
.27233 .48542 .27349 .48409 .27533 .479 .27427 .47917 Mtetra
.815 .984 .886 r
.27427 .47917 .27533 .479 .27687 .47806 .27583 .47786 Mtetra
.622 .91 .983 r
.27583 .47786 .27687 .47806 .27835 .47784 .27734 .47729 Mtetra
.518 .791 .995 r
.27734 .47729 .27835 .47784 .2798 .47801 .27882 .47708 Mtetra
.658 .739 .91 r
.27882 .47708 .2798 .47801 .28129 .47761 .28032 .47661 Mtetra
.651 .721 .899 r
.28032 .47661 .28129 .47761 .28279 .47715 .28182 .47616 Mtetra
.649 .724 .903 r
.28182 .47616 .28279 .47715 .2843 .47664 .28332 .47572 Mtetra
.753 .757 .855 r
.28332 .47572 .2843 .47664 .28584 .47564 .28486 .47473 Mtetra
.703 .752 .89 r
.28486 .47473 .28584 .47564 .28736 .47495 .28638 .47405 Mtetra
.49 .689 .955 r
.28638 .47405 .28736 .47495 .28883 .47492 .28785 .47404 Mtetra
.927 .549 .262 r
.28785 .47404 .28883 .47492 .29002 .47892 .28903 .47815 Mtetra
.939 .683 .522 r
.28903 .47815 .29002 .47892 .27767 .67455 .2766 .67394 Mtetra
.925 .571 .339 r
.2766 .67394 .27767 .67455 .27885 .6799 .2778 .67914 Mtetra
.189 .586 .942 r
.2778 .67914 .27885 .6799 .28039 .68041 .27934 .6795 Mtetra
.672 .759 .916 r
.27934 .6795 .28039 .68041 .28199 .67991 .28095 .67894 Mtetra
.745 .759 .864 r
.28095 .67894 .28199 .67991 .28364 .67881 .28259 .67796 Mtetra
.501 .717 .968 r
.28259 .67796 .28364 .67881 .28528 .67777 .28417 .67788 Mtetra
.198 .727 .774 r
.28417 .67788 .28528 .67777 .28696 .67624 .28576 .67759 Mtetra
.027 0 0 r
.28576 .67759 .28696 .67624 .2887 .67367 .2874 .6766 Mtetra
.79 .837 .373 r
.2874 .6766 .2887 .67367 .29111 .66119 .28931 .67172 Mtetra
.954 .703 .518 r
.28931 .67172 .29111 .66119 .30523 .47298 .30406 .4749 Mtetra
.995 .871 .566 r
.30406 .4749 .30523 .47298 .30696 .46926 .30598 .46837 Mtetra
.802 .768 .822 r
.30598 .46837 .30696 .46926 .30852 .46812 .30756 .46697 Mtetra
.64 .691 .882 r
.30756 .46697 .30852 .46812 .31003 .46769 .30907 .46656 Mtetra
.519 .649 .916 r
.30907 .46656 .31003 .46769 .31153 .46755 .31056 .46656 Mtetra
.639 .721 .907 r
.31056 .46656 .31153 .46755 .31305 .46699 .31208 .46615 Mtetra
.666 .761 .922 r
.31208 .46615 .31305 .46699 .31458 .46642 .3136 .46564 Mtetra
.667 .776 .931 r
.3136 .46564 .31458 .46642 .3161 .46602 .31512 .46511 Mtetra
.743 .763 .869 r
.31512 .46511 .3161 .46602 .31759 .46593 .31667 .46421 Mtetra
.675 .625 .791 r
.31667 .46421 .31759 .46593 .31906 .46635 .31821 .4635 Mtetra
.577 .494 .724 r
.31821 .4635 .31906 .46635 .32046 .46778 .31971 .46338 Mtetra
.124 .126 .589 r
.31971 .46338 .32046 .46778 .32078 .48698 .32103 .46629 Mtetra
.97 .714 .49 r
.32103 .46629 .32078 .48698 .31125 .66728 .31058 .66042 Mtetra
0 0 .31 r
.31058 .66042 .31125 .66728 .31265 .67029 .31171 .66795 Mtetra
.384 .422 .777 r
.31171 .66795 .31265 .67029 .31422 .67065 .31325 .66874 Mtetra
.64 .602 .796 r
.31325 .66874 .31422 .67065 .31585 .67016 .31488 .66824 Mtetra
.693 .625 .776 r
.31488 .66824 .31585 .67016 .31749 .66934 .31653 .66731 Mtetra
.621 .582 .789 r
.31653 .66731 .31749 .66934 .31912 .66874 .31815 .66691 Mtetra
.588 .586 .817 r
.31815 .66691 .31912 .66874 .32075 .66824 .31976 .66673 Mtetra
.591 .627 .856 r
.31976 .66673 .32075 .66824 .32238 .66774 .32137 .66651 Mtetra
.626 .686 .886 r
.32137 .66651 .32238 .66774 .324 .66739 .32299 .66614 Mtetra
.645 .689 .877 r
.32299 .66614 .324 .66739 .32562 .66699 .32462 .66567 Mtetra
.65 .68 .865 r
.32462 .66567 .32562 .66699 .32726 .66641 .32625 .66518 Mtetra
.646 .694 .88 r
.32625 .66518 .32726 .66641 .32893 .6651 .32788 .66471 Mtetra
.581 .865 .995 r
.32788 .66471 .32893 .6651 .33064 .66323 .32951 .66426 Mtetra
.207 0 0 r
.32951 .66426 .33064 .66323 .33237 .66103 .33114 .6638 Mtetra
.436 .095 .287 r
.33114 .6638 .33237 .66103 .33405 .65974 .33277 .66334 Mtetra
.465 .15 .347 r
.33277 .66334 .33405 .65974 .33568 .65929 .33441 .66287 Mtetra
.464 .149 .346 r
.33441 .66287 .33568 .65929 .33729 .65915 .33604 .6624 Mtetra
.499 .173 .345 r
.33604 .6624 .33729 .65915 .33889 .65938 .33766 .66227 Mtetra
.474 .136 .313 r
.33766 .66227 .33889 .65938 .3405 .65929 .33929 .66202 Mtetra
.365 .025 .248 r
.33929 .66202 .3405 .65929 .34217 .65829 .34095 .66119 Mtetra
0 0 0 r
.34095 .66119 .34217 .65829 .34413 .65163 .34274 .65771 Mtetra
.955 .698 .509 r
.34274 .65771 .34413 .65163 .35576 .45716 .35423 .46735 Mtetra
0 0 0 r
.35423 .46735 .35576 .45716 .35752 .45252 .35649 .45308 Mtetra
.896 .988 .76 r
.35649 .45308 .35752 .45252 .35913 .45092 .35812 .45093 Mtetra
.51 .906 .926 r
.35812 .45093 .35913 .45092 .36068 .45035 .35968 .45036 Mtetra
.12 .671 .776 r
.35968 .45036 .36068 .45035 .36221 .45014 .36121 .45023 Mtetra
.4 .855 .868 r
.36121 .45023 .36221 .45014 .36375 .44987 .36276 .44974 Mtetra
.678 .94 .964 r
.36276 .44974 .36375 .44987 .36529 .44953 .36432 .44897 Mtetra
.717 .845 .943 r
.36432 .44897 .36529 .44953 .36683 .44919 .36588 .44824 Mtetra
.682 .745 .899 r
.36588 .44824 .36683 .44919 .36838 .44878 .36744 .44764 Mtetra
.656 .702 .88 r
.36744 .44764 .36838 .44878 .36993 .4483 .36899 .44715 Mtetra
.648 .698 .882 r
.36899 .44715 .36993 .4483 .37149 .44777 .37055 .4467 Mtetra
.652 .714 .893 r
.37055 .4467 .37149 .44777 .37305 .44716 .3721 .44623 Mtetra
.656 .745 .915 r
.3721 .44623 .37305 .44716 .37461 .4465 .37366 .44574 Mtetra
.657 .786 .943 r
.37366 .44574 .37461 .4465 .37618 .44584 .37521 .44524 Mtetra
.662 .827 .963 r
.37521 .44524 .37618 .44584 .37774 .44513 .37677 .4447 Mtetra
.655 .869 .98 r
.37677 .4447 .37774 .44513 .37931 .44447 .37833 .44412 Mtetra
.641 .887 .985 r
.37833 .44412 .37931 .44447 .38087 .444 .3799 .44355 Mtetra
.736 .875 .945 r
.3799 .44355 .38087 .444 .38241 .44387 .38147 .44272 Mtetra
.711 .716 .853 r
.38147 .44272 .38241 .44387 .38393 .44424 .38305 .44193 Mtetra
.602 .541 .759 r
.38305 .44193 .38393 .44424 .38542 .44548 .3846 .44165 Mtetra
.3 .273 .66 r
.3846 .44165 .38542 .44548 .38671 .45158 .38606 .44349 Mtetra
.961 .696 .488 r
.38606 .44349 .38671 .45158 .38015 .64571 .37988 .62736 Mtetra
0 0 .303 r
.37988 .62736 .38015 .64571 .38163 .64957 .38071 .64675 Mtetra
.194 .263 .708 r
.38071 .64675 .38163 .64957 .38324 .65047 .38228 .64847 Mtetra
.613 .584 .797 r
.38228 .64847 .38324 .65047 .3849 .6501 .38394 .64813 Mtetra
.682 .619 .779 r
.38394 .64813 .3849 .6501 .38658 .64934 .38562 .64727 Mtetra
.645 .593 .782 r
.38562 .64727 .38658 .64934 .38825 .64873 .38729 .64669 Mtetra
.589 .567 .798 r
.38729 .64669 .38825 .64873 .38992 .6483 .38895 .64649 Mtetra
.592 .593 .822 r
.38895 .64649 .38992 .6483 .39159 .64771 .39061 .64628 Mtetra
.62 .655 .863 r
.39061 .64628 .39159 .64771 .39328 .64655 .39227 .64592 Mtetra
.633 .823 .973 r
.39227 .64592 .39328 .64655 .39501 .64474 .39394 .64542 Mtetra
.01 0 0 r
.39394 .64542 .39501 .64474 .39674 .64256 .39562 .64488 Mtetra
.45 .086 .255 r
.39562 .64488 .39674 .64256 .39844 .64133 .39728 .64461 Mtetra
.493 .167 .343 r
.39728 .64461 .39844 .64133 .4001 .64124 .39895 .64443 Mtetra
.419 .095 .306 r
.39895 .64443 .4001 .64124 .40177 .64061 .40063 .64372 Mtetra
0 0 .086 r
.40063 .64372 .40177 .64061 .40359 .63601 .40239 .64099 Mtetra
.946 .815 .368 r
.40239 .64099 .40359 .63601 .41204 .43971 .40448 .62873 Mtetra
0 0 .282 r
.40448 .62873 .41204 .43971 .41379 .43427 .41279 .43508 Mtetra
.936 .962 .672 r
.41279 .43508 .41379 .43427 .41542 .4322 .41446 .43213 Mtetra
.647 .948 .953 r
.41446 .43213 .41542 .4322 .41701 .43152 .41605 .43137 Mtetra
.336 .802 .929 r
.41605 .43137 .41701 .43152 .41858 .4312 .41762 .43113 Mtetra
.303 .791 .892 r
.41762 .43113 .41858 .4312 .42016 .43086 .4192 .43086 Mtetra
.469 .888 .915 r
.4192 .43086 .42016 .43086 .42174 .43033 .42078 .43033 Mtetra
.462 .884 .915 r
.42078 .43033 .42174 .43033 .42333 .42981 .42237 .42981 Mtetra
.606 .944 .935 r
.42237 .42981 .42333 .42981 .42492 .42912 .42396 .42906 Mtetra
.68 .957 .947 r
.42396 .42906 .42492 .42912 .42651 .42836 .42556 .42821 Mtetra
.424 .849 .952 r
.42556 .42821 .42651 .42836 .42809 .42795 .42714 .42786 Mtetra
.729 .209 0 r
.42714 .42786 .42809 .42795 .42964 .42874 .42867 .42936 Mtetra
.953 .682 .487 r
.42867 .42936 .42964 .42874 .43111 .43261 .42493 .61181 Mtetra
.589 .362 .541 r
.42493 .61181 .43111 .43261 .42716 .62782 .42598 .63359 Mtetra
.64 .349 .461 r
.42598 .63359 .42716 .62782 .4287 .63258 .42759 .63573 Mtetra
.486 .156 .332 r
.42759 .63573 .4287 .63258 .43038 .63231 .42928 .63552 Mtetra
.41 .087 .304 r
.42928 .63552 .43038 .63231 .43209 .63142 .43098 .63474 Mtetra
.413 .093 .311 r
.43098 .63474 .43209 .63142 .43376 .63146 .43269 .63394 Mtetra
.42 .066 .255 r
.43269 .63394 .43376 .63146 .43541 .63272 .43438 .63346 Mtetra
.098 0 0 r
.43438 .63346 .43541 .63272 .43708 .63359 .43608 .63298 Mtetra
.615 .828 .982 r
.43608 .63298 .43708 .63359 .43876 .63383 .43778 .63251 Mtetra
.639 .683 .875 r
.43778 .63251 .43876 .63383 .44045 .63343 .43948 .63206 Mtetra
.646 .677 .865 r
.43948 .63206 .44045 .63343 .44216 .63286 .44118 .63156 Mtetra
.668 .696 .867 r
.44118 .63156 .44216 .63286 .44386 .63236 .44289 .63096 Mtetra
.688 .688 .844 r
.44289 .63096 .44386 .63236 .44556 .63204 .44459 .63021 Mtetra
.676 .632 .798 r
.44459 .63021 .44556 .63204 .44726 .6317 .4463 .62944 Mtetra
.628 .572 .772 r
.4463 .62944 .44726 .6317 .44896 .63138 .44801 .62896 Mtetra
.573 .53 .769 r
.44801 .62896 .44896 .63138 .45066 .63107 .44971 .62886 Mtetra
.642 .583 .773 r
.44971 .62886 .45066 .63107 .45237 .63037 .45142 .62827 Mtetra
.786 .657 .72 r
.45142 .62827 .45237 .63037 .45411 .62856 .45316 .62595 Mtetra
.912 .682 .577 r
.45316 .62595 .45411 .62856 .45591 .62362 .45512 .61348 Mtetra
.946 .678 .498 r
.45512 .61348 .45591 .62362 .46143 .42742 .46066 .41915 Mtetra
.673 .473 .607 r
.46066 .41915 .46143 .42742 .46317 .42041 .46232 .41583 Mtetra
.622 .473 .659 r
.46232 .41583 .46317 .42041 .46479 .41935 .46394 .41497 Mtetra
.587 .454 .666 r
.46394 .41497 .46479 .41935 .4664 .41916 .46555 .41464 Mtetra
.577 .444 .663 r
.46555 .41464 .4664 .41916 .468 .41928 .46715 .41444 Mtetra
.596 .451 .654 r
.46715 .41444 .468 .41928 .46961 .41907 .46876 .41394 Mtetra
.593 .444 .648 r
.46876 .41394 .46961 .41907 .47122 .41857 .47038 .41345 Mtetra
.594 .445 .649 r
.47038 .41345 .47122 .41857 .47285 .41724 .47199 .41295 Mtetra
.602 .466 .668 r
.47199 .41295 .47285 .41724 .47449 .41506 .47361 .41244 Mtetra
.626 .539 .736 r
.47361 .41244 .47449 .41506 .47613 .41322 .47522 .41192 Mtetra
.658 .681 .86 r
.47522 .41192 .47613 .41322 .47776 .41192 .47684 .41139 Mtetra
.645 .849 .978 r
.47684 .41139 .47776 .41192 .47937 .41128 .47846 .41084 Mtetra
.631 .871 .987 r
.47846 .41084 .47937 .41128 .48099 .41082 .48008 .4103 Mtetra
.641 .852 .98 r
.48008 .4103 .48099 .41082 .48261 .4104 .4817 .40976 Mtetra
.649 .821 .966 r
.4817 .40976 .48261 .4104 .48423 .40988 .48332 .40923 Mtetra
.648 .82 .966 r
.48332 .40923 .48423 .40988 .48585 .40938 .48494 .40871 Mtetra
.648 .815 .964 r
.48494 .40871 .48585 .40938 .48747 .40892 .48656 .4082 Mtetra
.651 .802 .955 r
.48656 .4082 .48747 .40892 .48909 .40853 .48819 .40768 Mtetra
.657 .773 .935 r
.48819 .40768 .48909 .40853 .49072 .40815 .48981 .40716 Mtetra
.66 .743 .912 r
.48981 .40716 .49072 .40815 .49234 .40773 .49144 .40664 Mtetra
.662 .721 .893 r
.49144 .40664 .49234 .40773 .49397 .40723 .49307 .40611 Mtetra
.663 .715 .887 r
.49307 .40611 .49397 .40723 .4956 .4067 .49469 .40556 Mtetra
.667 .715 .884 r
.49469 .40556 .4956 .4067 .49722 .40614 .49632 .405 Mtetra
.675 .716 .88 r
.49632 .405 .49722 .40614 .49885 .4056 .49795 .4044 Mtetra
.669 .704 .873 r
.49795 .4044 .49885 .4056 .50048 .40502 .49958 .40382 Mtetra
.652 .697 .879 r
.49958 .40382 .50048 .40502 .50212 .40439 .50122 .40332 Mtetra
.607 .706 .914 r
.50122 .40332 .50212 .40439 .50375 .40368 .50285 .40301 Mtetra
.562 .787 .983 r
.50285 .40301 .50375 .40368 .50538 .40296 .50448 .40272 Mtetra
.452 .85 .974 r
.50448 .40272 .50538 .40296 .50702 .40227 .50611 .40238 Mtetra
.383 .846 .838 r
.50611 .40238 .50702 .40227 .50865 .40167 .50775 .40182 Mtetra
.389 .849 .816 r
.50775 .40182 .50865 .40167 .51029 .40109 .50939 .40121 Mtetra
.424 .869 .843 r
.50939 .40121 .51029 .40109 .51193 .40053 .51103 .40059 Mtetra
.432 .873 .873 r
.51103 .40059 .51193 .40053 .51357 .39996 .51267 .40001 Mtetra
.433 .873 .877 r
.51267 .40001 .51357 .39996 .5152 .3994 .51431 .39944 Mtetra
.433 .873 .88 r
.51431 .39944 .5152 .3994 .51684 .39884 .51595 .39888 Mtetra
.434 .873 .883 r
.51595 .39888 .51684 .39884 .51849 .39829 .51759 .39832 Mtetra
.433 .873 .884 r
.51759 .39832 .51849 .39829 .52013 .39774 .51923 .39777 Mtetra
.432 .872 .885 r
.51923 .39777 .52013 .39774 .52177 .39719 .52088 .39722 Mtetra
.431 .871 .885 r
.52088 .39722 .52177 .39719 .52341 .39664 .52252 .39667 Mtetra
.429 .87 .885 r
.52252 .39667 .52341 .39664 .52506 .3961 .52417 .39612 Mtetra
.426 .869 .885 r
.52417 .39612 .52506 .3961 .5267 .39556 .52581 .39558 Mtetra
.424 .867 .883 r
.52581 .39558 .5267 .39556 .52835 .39502 .52746 .39504 Mtetra
.419 .865 .882 r
.52746 .39504 .52835 .39502 .53 .39448 .52911 .39451 Mtetra
.414 .862 .879 r
.52911 .39451 .53 .39448 .53165 .39395 .53076 .39398 Mtetra
.407 .859 .875 r
.53076 .39398 .53165 .39395 .5333 .39341 .53241 .39345 Mtetra
.397 .853 .869 r
.53241 .39345 .5333 .39341 .53495 .39289 .53406 .39293 Mtetra
.384 .846 .862 r
.53406 .39293 .53495 .39289 .5366 .39236 .53572 .39242 Mtetra
.334 .817 .84 r
.53572 .39242 .5366 .39236 .53825 .39184 .53737 .39197 Mtetra
.305 .798 .795 r
.53737 .39197 .53825 .39184 .53991 .39133 .53903 .39148 Mtetra
.345 .822 .8 r
.53903 .39148 .53991 .39133 .54156 .39086 .54068 .39092 Mtetra
.554 .932 .892 r
.54068 .39092 .54156 .39086 .54322 .39047 .54234 .39014 Mtetra
.7 .918 .968 r
.54234 .39014 .54322 .39047 .54488 .39011 .54399 .38933 Mtetra
.712 .81 .926 r
.54399 .38933 .54488 .39011 .54653 .38973 .54565 .38857 Mtetra
.663 .714 .886 r
.54565 .38857 .54653 .38973 .54819 .38924 .54731 .38802 Mtetra
.651 .696 .879 r
.54731 .38802 .54819 .38924 .54985 .38873 .54897 .38752 Mtetra
.647 .697 .883 r
.54897 .38752 .54985 .38873 .55151 .38818 .55063 .38704 Mtetra
.659 .714 .889 r
.55063 .38704 .55151 .38818 .55318 .38765 .5523 .3865 Mtetra
.661 .714 .887 r
.5523 .3865 .55318 .38765 .55484 .3871 .55396 .38596 Mtetra
.663 .717 .888 r
.55396 .38596 .55484 .3871 .5565 .3865 .55562 .3854 Mtetra
.665 .725 .894 r
.55562 .3854 .5565 .3865 .55817 .38582 .55729 .38484 Mtetra
.667 .752 .914 r
.55729 .38484 .55817 .38582 .55983 .38512 .55896 .38427 Mtetra
.666 .782 .936 r
.55896 .38427 .55983 .38512 .5615 .38443 .56062 .3837 Mtetra
.66 .811 .955 r
.56062 .3837 .5615 .38443 .56316 .38383 .56229 .38314 Mtetra
.656 .818 .961 r
.56229 .38314 .56316 .38383 .56483 .38326 .56396 .38258 Mtetra
.653 .821 .964 r
.56396 .38258 .56483 .38326 .5665 .3827 .56563 .38203 Mtetra
.645 .819 .967 r
.56563 .38203 .5665 .3827 .56817 .38214 .5673 .3815 Mtetra
.641 .828 .972 r
.5673 .3815 .56817 .38214 .56984 .38158 .56898 .38098 Mtetra
.64 .837 .976 r
.56898 .38098 .56984 .38158 .57152 .38102 .57065 .38044 Mtetra
.649 .848 .976 r
.57065 .38044 .57152 .38102 .57319 .38032 .57232 .37987 Mtetra
.635 .878 .986 r
.57232 .37987 .57319 .38032 .57486 .3797 .574 .37929 Mtetra
.634 .885 .987 r
.574 .37929 .57486 .3797 .57654 .37929 .57568 .37869 Mtetra
.662 .846 .971 r
.57568 .37869 .57654 .37929 .57823 .37965 .57735 .37809 Mtetra
.661 .651 .829 r
.57735 .37809 .57823 .37965 .57993 .38044 .57903 .37749 Mtetra
.626 .524 .719 r
.57903 .37749 .57993 .38044 .58164 .38155 .58071 .37689 Mtetra
.627 .476 .658 r
.58071 .37689 .58164 .38155 .58332 .38082 .58238 .37591 Mtetra
.608 .459 .654 r
.58238 .37591 .58332 .38082 .585 .37998 .58406 .3752 Mtetra
.568 .434 .659 r
.58406 .3752 .585 .37998 .58669 .37997 .58575 .37511 Mtetra
.211 .189 .615 r
.58575 .37511 .58669 .37997 .5887 .39545 .58751 .37837 Mtetra
.983 .702 .392 r
.58751 .37837 .5887 .39545 .59425 .58431 .59322 .57809 Mtetra
0 0 .468 r
.59322 .57809 .59425 .58431 .59612 .5875 .59517 .58512 Mtetra
.459 .472 .785 r
.59517 .58512 .59612 .5875 .59794 .58774 .597 .58568 Mtetra
.641 .6 .793 r
.597 .58568 .59794 .58774 .59974 .5872 .5988 .58511 Mtetra
.688 .621 .776 r
.5988 .58511 .59974 .5872 .60153 .58633 .60059 .58413 Mtetra
.609 .572 .788 r
.60059 .58413 .60153 .58633 .60334 .58585 .6024 .58378 Mtetra
.589 .573 .804 r
.6024 .58378 .60334 .58585 .60514 .58536 .60421 .58357 Mtetra
.594 .606 .833 r
.60421 .58357 .60514 .58536 .60695 .58465 .60602 .58332 Mtetra
.626 .685 .886 r
.60602 .58332 .60695 .58465 .60873 .58318 .60783 .58289 Mtetra
.526 .883 .982 r
.60783 .58289 .60873 .58318 .6105 .58121 .60964 .58239 Mtetra
.242 0 0 r
.60964 .58239 .6105 .58121 .61226 .57892 .61145 .58183 Mtetra
.487 .146 .313 r
.61145 .58183 .61226 .57892 .61407 .57837 .61327 .58167 Mtetra
.471 .146 .332 r
.61327 .58167 .61407 .57837 .61589 .57814 .61509 .58129 Mtetra
.382 .062 .293 r
.61509 .58129 .61589 .57814 .61769 .57712 .61689 .58027 Mtetra
0 0 .03 r
.61689 .58027 .61769 .57712 .61925 .56762 .6186 .57604 Mtetra
.98 .699 .417 r
.6186 .57604 .61925 .56762 .61548 .37049 .6148 .37588 Mtetra
0 0 .01 r
.6148 .37588 .61548 .37049 .61708 .36623 .61626 .36656 Mtetra
.813 .995 .761 r
.61626 .36656 .61708 .36623 .61875 .3648 .61793 .36474 Mtetra
.472 .888 .92 r
.61793 .36474 .61875 .3648 .62045 .36423 .61963 .36417 Mtetra
.165 .702 .819 r
.61963 .36417 .62045 .36423 .62217 .36398 .62135 .36401 Mtetra
.453 .884 .875 r
.62135 .36401 .62217 .36398 .62388 .36363 .62305 .36338 Mtetra
.676 .938 .965 r
.62305 .36338 .62388 .36363 .62559 .36323 .62475 .36256 Mtetra
.713 .844 .944 r
.62475 .36256 .62559 .36323 .6273 .3628 .62645 .36177 Mtetra
.675 .749 .906 r
.62645 .36177 .6273 .3628 .629 .3622 .62815 .36115 Mtetra
.655 .739 .911 r
.62815 .36115 .629 .3622 .63071 .3615 .62987 .36062 Mtetra
.647 .773 .94 r
.62987 .36062 .63071 .3615 .63241 .36079 .63158 .36011 Mtetra
.655 .828 .966 r
.63158 .36011 .63241 .36079 .63412 .36003 .63329 .35954 Mtetra
.647 .874 .983 r
.63329 .35954 .63412 .36003 .63583 .35934 .635 .35892 Mtetra
.638 .89 .986 r
.635 .35892 .63583 .35934 .63754 .35884 .63671 .35829 Mtetra
.747 .883 .942 r
.63671 .35829 .63754 .35884 .63927 .35868 .63841 .35735 Mtetra
.703 .705 .849 r
.63841 .35735 .63927 .35868 .64102 .35899 .64012 .35653 Mtetra
.599 .537 .757 r
.64012 .35653 .64102 .35899 .6428 .36015 .64185 .35624 Mtetra
.316 .29 .671 r
.64185 .35624 .6428 .36015 .64477 .36633 .64366 .3583 Mtetra
.979 .689 .388 r
.64366 .3583 .64477 .36633 .65409 .56505 .65249 .54546 Mtetra
0 0 .432 r
.65249 .54546 .65409 .56505 .6561 .56894 .65513 .56608 Mtetra
.29 .333 .735 r
.65513 .56608 .6561 .56894 .65798 .56947 .65706 .5677 Mtetra
.578 .602 .841 r
.65706 .5677 .65798 .56947 .65981 .56879 .65891 .56753 Mtetra
.682 .724 .881 r
.65891 .56753 .65981 .56879 .66163 .56766 .66075 .56681 Mtetra
.673 .805 .946 r
.66075 .56681 .66163 .56766 .66346 .56691 .66258 .56615 Mtetra
.658 .819 .961 r
.66258 .56615 .66346 .56691 .66531 .56636 .66442 .56552 Mtetra
.677 .808 .945 r
.66442 .56552 .66531 .56636 .66714 .56561 .66626 .56484 Mtetra
.554 .782 .984 r
.66626 .56484 .66714 .56561 .66896 .56436 .66812 .56454 Mtetra
0 0 0 r
.66812 .56454 .66896 .56436 .67074 .56234 .66998 .56418 Mtetra
.255 0 .11 r
.66998 .56418 .67074 .56234 .67245 .55862 .6718 .56318 Mtetra
.081 0 .264 r
.6718 .56318 .67245 .55862 .66553 .35984 .6735 .55914 Mtetra
0 0 .406 r
.6735 .55914 .66553 .35984 .66692 .35152 .6664 .35758 Mtetra
0 0 .181 r
.6664 .35758 .66692 .35152 .66854 .34837 .66779 .34928 Mtetra
.652 .861 .479 r
.66779 .34928 .66854 .34837 .67026 .34748 .66945 .34695 Mtetra
.738 .89 .949 r
.66945 .34695 .67026 .34748 .67204 .34792 .67117 .34603 Mtetra
.635 .605 .802 r
.67117 .34603 .67204 .34792 .67385 .34908 .67291 .34553 Mtetra
.626 .504 .694 r
.67291 .34553 .67385 .34908 .67563 .34931 .67464 .3448 Mtetra
.615 .472 .664 r
.67464 .3448 .67563 .34931 .67736 .34855 .67636 .34404 Mtetra
.581 .45 .667 r
.67636 .34404 .67736 .34855 .67911 .34823 .67812 .34378 Mtetra
.411 .339 .666 r
.67812 .34378 .67911 .34823 .68105 .35161 .67996 .34538 Mtetra
0 0 .404 r
.67996 .34538 .68105 .35161 .69279 .55196 .68217 .35425 Mtetra
.01 0 .42 r
.68217 .35425 .69279 .55196 .69494 .55718 .69395 .55388 Mtetra
.213 .258 .693 r
.69395 .55388 .69494 .55718 .69688 .5582 .69596 .55622 Mtetra
.546 .563 .823 r
.69596 .55622 .69688 .5582 .69875 .55769 .69785 .55624 Mtetra
.651 .683 .867 r
.69785 .55624 .69875 .55769 .7006 .55676 .69972 .55568 Mtetra
.66 .751 .918 r
.69972 .55568 .7006 .55676 .70246 .55616 .70158 .55508 Mtetra
.64 .744 .924 r
.70158 .55508 .70246 .55616 .70434 .55588 .70345 .55456 Mtetra
.653 .704 .885 r
.70345 .55456 .70434 .55588 .70622 .55543 .70532 .55399 Mtetra
.583 .653 .885 r
.70532 .55399 .70622 .55543 .70807 .55456 .70721 .55376 Mtetra
.501 .754 .986 r
.70721 .55376 .70807 .55456 .7099 .55309 .70911 .55361 Mtetra
0 0 0 r
.70911 .55361 .7099 .55309 .71167 .55076 .71097 .55286 Mtetra
.71097 .55286 .71167 .55076 .71324 .54478 .71271 .54978 Mtetra
.956 .737 .283 r
.71271 .54978 .71324 .54478 .70378 .34371 .7133 .52636 Mtetra
.004 0 .413 r
.7133 .52636 .70378 .34371 .70526 .33829 .70448 .33776 Mtetra
.937 .869 .745 r
.70448 .33776 .70526 .33829 .70694 .33624 .70611 .33498 Mtetra
.692 .716 .868 r
.70611 .33498 .70694 .33624 .70869 .33552 .70786 .33423 Mtetra
.583 .664 .894 r
.70786 .33423 .70869 .33552 .71046 .33518 .70963 .334 Mtetra
.651 .716 .896 r
.70963 .334 .71046 .33518 .71221 .33445 .7114 .33347 Mtetra
.727 .784 .898 r
.7114 .33347 .71221 .33445 .71394 .3334 .71314 .33259 Mtetra
.606 .781 .965 r
.71314 .33259 .71394 .3334 .7157 .33289 .71491 .33218 Mtetra
0 .158 .633 r
.71491 .33218 .7157 .33289 .7176 .33443 .7168 .33359 Mtetra
.947 .589 .227 r
.7168 .33359 .7176 .33443 .73112 .52478 .71927 .34452 Mtetra
0 0 .413 r
.71927 .34452 .73112 .52478 .7343 .54519 .73336 .54275 Mtetra
.041 .201 .704 r
.73336 .54275 .7343 .54519 .73636 .54726 .73543 .54518 Mtetra
.554 .558 .812 r
.73543 .54518 .73636 .54726 .73826 .54693 .73736 .54517 Mtetra
.649 .642 .829 r
.73736 .54517 .73826 .54693 .74012 .54586 .73925 .54457 Mtetra
.635 .705 .896 r
.73925 .54457 .74012 .54586 .74197 .54453 .74115 .54408 Mtetra
.439 .813 .993 r
.74115 .54408 .74197 .54453 .74381 .54312 .74306 .54382 Mtetra
0 0 0 r
.74306 .54382 .74381 .54312 .74559 .54091 .74495 .54302 Mtetra
0 0 .028 r
.74495 .54302 .74559 .54091 .74716 .53531 .74671 .54043 Mtetra
0 0 .056 r
.74671 .54043 .74716 .53531 .73558 .33302 .748 .53068 Mtetra
.03 0 .426 r
.748 .53068 .73558 .33302 .73702 .32745 .73637 .32867 Mtetra
.749 .83 .37 r
.73637 .32867 .73702 .32745 .73869 .32526 .73795 .32504 Mtetra
.748 .97 .929 r
.73795 .32504 .73869 .32526 .74046 .32461 .73969 .32391 Mtetra
.647 .83 .97 r
.73969 .32391 .74046 .32461 .74226 .32436 .74146 .32333 Mtetra
.631 .742 .927 r
.74146 .32333 .74226 .32436 .74406 .32398 .74325 .32288 Mtetra
.663 .738 .905 r
.74325 .32288 .74406 .32398 .74582 .32318 .74503 .32229 Mtetra
.647 .781 .945 r
.74503 .32229 .74582 .32318 .74759 .3225 .74682 .32175 Mtetra
.69 .83 .951 r
.74682 .32175 .74759 .3225 .74939 .32215 .74859 .32103 Mtetra
.725 .759 .879 r
.74859 .32103 .74939 .32215 .75123 .32233 .75035 .32011 Mtetra
.625 .574 .777 r
.75035 .32011 .75123 .32233 .75313 .32327 .75215 .31963 Mtetra
.459 .397 .701 r
.75215 .31963 .75313 .32327 .75523 .32702 .75404 .3206 Mtetra
0 .02 .528 r
.75404 .3206 .75523 .32702 .77193 .52865 .75639 .32765 Mtetra
.052 0 .444 r
.75639 .32765 .77193 .52865 .77427 .53391 .77323 .53008 Mtetra
.162 .204 .658 r
.77323 .53008 .77427 .53391 .77634 .53544 .77542 .53326 Mtetra
.531 .538 .807 r
.77542 .53326 .77634 .53544 .77829 .53525 .77739 .53339 Mtetra
.634 .625 .824 r
.77739 .53339 .77829 .53525 .78019 .53446 .77932 .53288 Mtetra
.644 .664 .855 r
.77932 .53288 .78019 .53446 .78207 .53329 .78124 .53232 Mtetra
.543 .733 .963 r
.78124 .53232 .78207 .53329 .78393 .53188 .78319 .53212 Mtetra
.283 .771 .697 r
.78319 .53212 .78393 .53188 .78572 .52969 .7851 .53139 Mtetra
0 0 0 r
.7851 .53139 .78572 .52969 .78732 .52492 .7869 .52919 Mtetra
0 0 .065 r
.7869 .52919 .78732 .52492 .77325 .32197 .78823 .52111 Mtetra
.047 0 .437 r
.78823 .52111 .77325 .32197 .77458 .31541 .774 .31695 Mtetra
.679 .752 .256 r
.774 .31695 .77458 .31541 .77622 .31283 .77552 .31281 Mtetra
.599 .951 .887 r
.77552 .31281 .77622 .31283 .778 .31196 .77729 .31186 Mtetra
.315 .801 .886 r
.77729 .31186 .778 .31196 .77981 .31155 .77911 .3115 Mtetra
.241 .756 .835 r
.77911 .3115 .77981 .31155 .78164 .3113 .78094 .3112 Mtetra
.589 .943 .916 r
.78094 .3112 .78164 .3113 .78346 .31087 .78272 .31035 Mtetra
.706 .899 .966 r
.78272 .31035 .78346 .31087 .78528 .31044 .78451 .3095 Mtetra
.701 .79 .92 r
.78451 .3095 .78528 .31044 .78709 .30993 .7863 .30873 Mtetra
.665 .722 .892 r
.7863 .30873 .78709 .30993 .78889 .30925 .78811 .30812 Mtetra
.655 .733 .906 r
.78811 .30812 .78889 .30925 .79069 .30854 .78992 .30756 Mtetra
.652 .765 .932 r
.78992 .30756 .79069 .30854 .79249 .30785 .79173 .30701 Mtetra
.655 .8 .952 r
.79173 .30701 .79249 .30785 .7943 .30724 .79354 .30642 Mtetra
.653 .805 .956 r
.79354 .30642 .7943 .30724 .79611 .30665 .79536 .30583 Mtetra
.652 .805 .957 r
.79536 .30583 .79611 .30665 .79792 .30607 .79717 .30525 Mtetra
.651 .804 .956 r
.79717 .30525 .79792 .30607 .79974 .30549 .79899 .30467 Mtetra
.648 .806 .959 r
.79899 .30467 .79974 .30549 .80156 .30492 .80081 .3041 Mtetra
.646 .803 .958 r
.80081 .3041 .80156 .30492 .80338 .3044 .80263 .30354 Mtetra
.645 .792 .952 r
.80263 .30354 .80338 .3044 .80521 .30397 .80445 .30299 Mtetra
.648 .765 .934 r
.80445 .30299 .80521 .30397 .80705 .30356 .80627 .30245 Mtetra
.648 .736 .913 r
.80627 .30245 .80705 .30356 .80888 .30313 .8081 .30191 Mtetra
.647 .715 .897 r
.8081 .30191 .80888 .30313 .81071 .30262 .80993 .30139 Mtetra
.646 .71 .893 r
.80993 .30139 .81071 .30262 .81254 .3021 .81176 .30086 Mtetra
.645 .71 .895 r
.81176 .30086 .81254 .3021 .81437 .30156 .81359 .30034 Mtetra
.641 .712 .899 r
.81359 .30034 .81437 .30156 .8162 .30103 .81542 .29984 Mtetra
.645 .719 .902 r
.81542 .29984 .8162 .30103 .81803 .30049 .81726 .29933 Mtetra
.655 .729 .904 r
.81726 .29933 .81803 .30049 .81986 .2999 .81909 .29876 Mtetra
.674 .742 .902 r
.81909 .29876 .81986 .2999 .82168 .29922 .82091 .2981 Mtetra
.682 .748 .901 r
.82091 .2981 .82168 .29922 .8235 .29852 .82273 .29741 Mtetra
.702 .757 .895 r
.82273 .29741 .8235 .29852 .82531 .29772 .82454 .29661 Mtetra
.767 .78 .864 r
.82454 .29661 .82531 .29772 .82708 .29653 .82632 .29542 Mtetra
.692 .755 .9 r
.82632 .29542 .82708 .29653 .8289 .29578 .82814 .29467 Mtetra
.405 .613 .935 r
.82814 .29467 .8289 .29578 .83082 .29607 .83006 .29496 Mtetra
.827 .42 0 r
.83006 .29496 .83082 .29607 .83331 .30204 .83255 .30096 Mtetra
.973 .661 .312 r
.83255 .30096 .83331 .30204 .85556 .50695 .85476 .5059 Mtetra
.698 .253 0 r
.85476 .5059 .85556 .50695 .85799 .51099 .85719 .50993 Mtetra
.341 .605 .946 r
.85719 .50993 .85799 .51099 .86006 .5114 .85926 .51034 Mtetra
.669 .773 .928 r
.85926 .51034 .86006 .5114 .86202 .51072 .86123 .50966 Mtetra
.849 .823 .822 r
.86123 .50966 .86202 .51072 .86386 .50878 .86306 .50772 Mtetra
.977 .78 .572 r
.86306 .50772 .86386 .50878 .86522 .50216 .86443 .5011 Mtetra
.976 .67 .326 r
.86443 .5011 .86522 .50216 .84596 .2954 .84521 .29429 Mtetra
.966 .78 .602 r
.84521 .29429 .84596 .2954 .84731 .29001 .84656 .28888 Mtetra
.762 .779 .866 r
.84656 .28888 .84731 .29001 .8491 .28885 .84835 .28772 Mtetra
.632 .728 .917 r
.84835 .28772 .8491 .28885 .85096 .28838 .85021 .28725 Mtetra
.556 .692 .93 r
.85021 .28725 .85096 .28838 .85285 .2882 .8521 .28707 Mtetra
.752 .775 .871 r
.8521 .28707 .85285 .2882 .85465 .28711 .8539 .28597 Mtetra
.685 .749 .901 r
.8539 .28597 .85465 .28711 .85649 .28639 .85574 .28526 Mtetra
.483 .652 .934 r
.85574 .28526 .85649 .28639 .85841 .28647 .85766 .28533 Mtetra
.741 .324 0 r
.85766 .28533 .85841 .28647 .86086 .29136 .8601 .29019 Mtetra
.971 .656 .295 r
.8601 .29019 .86086 .29136 .88512 .49721 .88433 .49608 Mtetra
.731 .304 0 r
.88433 .49608 .88512 .49721 .88769 .50202 .88691 .50092 Mtetra
.322 .584 .937 r
.88691 .50092 .88769 .50202 .88981 .50256 .88902 .50141 Mtetra
.656 .751 .92 r
.88902 .50141 .88981 .50256 .8918 .50195 .89101 .50078 Mtetra
.823 .805 .834 r
.89101 .50078 .8918 .50195 .89367 .50016 .89288 .49905 Mtetra
.873 .765 .74 r
.25284 .68537 .2539 .68621 .25585 .68099 .25461 .68257 Mtetra
.992 .876 .608 r
.25461 .68257 .25585 .68099 .27233 .48542 .25661 .67662 Mtetra
0 0 .202 r
.25661 .67662 .27233 .48542 .27427 .47917 .27278 .48485 Mtetra
0 0 .164 r
.27278 .48485 .27427 .47917 .27583 .47786 .27461 .48009 Mtetra
0 0 0 r
.27461 .48009 .27583 .47786 .27734 .47729 .27625 .47773 Mtetra
.809 1 .827 r
.27625 .47773 .27734 .47729 .27882 .47708 .27783 .47623 Mtetra
.713 .766 .894 r
.27783 .47623 .27882 .47708 .28032 .47661 .27935 .47551 Mtetra
.647 .701 .886 r
.27935 .47551 .28032 .47661 .28182 .47616 .28085 .47508 Mtetra
.612 .693 .901 r
.28085 .47508 .28182 .47616 .28332 .47572 .28234 .47478 Mtetra
.752 .755 .855 r
.28234 .47478 .28332 .47572 .28486 .47473 .28388 .4738 Mtetra
.7 .748 .889 r
.28388 .4738 .28486 .47473 .28638 .47405 .2854 .47313 Mtetra
.475 .677 .954 r
.2854 .47313 .28638 .47405 .28785 .47404 .28687 .47316 Mtetra
.933 .567 .292 r
.28687 .47316 .28785 .47404 .28903 .47815 .28802 .47769 Mtetra
.939 .682 .522 r
.28802 .47769 .28903 .47815 .2766 .67394 .2755 .67394 Mtetra
.896 .543 .367 r
.2755 .67394 .2766 .67394 .2778 .67914 .27672 .67871 Mtetra
.121 .622 .904 r
.27672 .67871 .2778 .67914 .27934 .6795 .27828 .67891 Mtetra
.703 .837 .947 r
.27828 .67891 .27934 .6795 .28095 .67894 .2799 .6782 Mtetra
.774 .808 .88 r
.2799 .6782 .28095 .67894 .28259 .67796 .28154 .6771 Mtetra
.434 .69 .972 r
.28154 .6771 .28259 .67796 .28417 .67788 .28311 .67716 Mtetra
.505 .753 .985 r
.28311 .67716 .28417 .67788 .28576 .67759 .2847 .67702 Mtetra
.734 .847 .933 r
.2847 .67702 .28576 .67759 .2874 .6766 .28633 .67618 Mtetra
.928 .775 .671 r
.28633 .67618 .2874 .6766 .28931 .67172 .28824 .6713 Mtetra
.94 .688 .527 r
.28824 .6713 .28931 .67172 .30406 .4749 .30312 .47354 Mtetra
.899 .706 .634 r
.30312 .47354 .30406 .4749 .30598 .46837 .30504 .46701 Mtetra
.761 .694 .787 r
.30504 .46701 .30598 .46837 .30756 .46697 .30661 .46569 Mtetra
.613 .657 .869 r
.30661 .46569 .30756 .46697 .30907 .46656 .30812 .46539 Mtetra
.467 .616 .914 r
.30812 .46539 .30907 .46656 .31056 .46656 .3096 .46553 Mtetra
.613 .706 .911 r
.3096 .46553 .31056 .46656 .31208 .46615 .31111 .46522 Mtetra
.654 .739 .912 r
.31111 .46522 .31208 .46615 .3136 .46564 .31263 .46475 Mtetra
.671 .753 .913 r
.31263 .46475 .3136 .46564 .31512 .46511 .31415 .46421 Mtetra
.747 .765 .867 r
.31415 .46421 .31512 .46511 .31667 .46421 .3157 .46328 Mtetra
.728 .757 .876 r
.3157 .46328 .31667 .46421 .31821 .4635 .31725 .46246 Mtetra
.64 .712 .9 r
.31725 .46246 .31821 .4635 .31971 .46338 .31877 .46205 Mtetra
0 .144 .683 r
.31877 .46205 .31971 .46338 .32103 .46629 .32018 .46342 Mtetra
.679 .391 0 r
.32018 .46342 .32103 .46629 .31058 .66042 .32142 .46762 Mtetra
0 0 .253 r
.32142 .46762 .31058 .66042 .31171 .66795 .31116 .65908 Mtetra
.447 .303 .592 r
.31116 .65908 .31171 .66795 .31325 .66874 .31262 .6612 Mtetra
.599 .426 .619 r
.31262 .6612 .31325 .66874 .31488 .66824 .31427 .66032 Mtetra
.6 .424 .615 r
.31427 .66032 .31488 .66824 .31653 .66731 .31592 .65938 Mtetra
.376 .257 .588 r
.31592 .65938 .31653 .66731 .31815 .66691 .31734 .66222 Mtetra
.281 .238 .63 r
.31734 .66222 .31815 .66691 .31976 .66673 .3188 .66452 Mtetra
.189 .314 .761 r
.3188 .66452 .31976 .66673 .32137 .66651 .32032 .66582 Mtetra
.385 .709 .986 r
.32032 .66582 .32137 .66651 .32299 .66614 .32192 .66587 Mtetra
.546 .88 .989 r
.32192 .66587 .32299 .66614 .32462 .66567 .32355 .66542 Mtetra
.628 .906 .984 r
.32355 .66542 .32462 .66567 .32625 .66518 .32519 .6648 Mtetra
.545 .854 .998 r
.32519 .6648 .32625 .66518 .32788 .66471 .32682 .66441 Mtetra
.461 .839 .988 r
.32682 .66441 .32788 .66471 .32951 .66426 .32844 .66411 Mtetra
.408 .84 .949 r
.32844 .66411 .32951 .66426 .33114 .6638 .33006 .66378 Mtetra
.466 .882 .93 r
.33006 .66378 .33114 .6638 .33277 .66334 .3317 .66327 Mtetra
.554 .915 .957 r
.3317 .66327 .33277 .66334 .33441 .66287 .33334 .66266 Mtetra
.616 .913 .981 r
.33334 .66266 .33441 .66287 .33604 .6624 .33499 .66204 Mtetra
.493 .84 .996 r
.33499 .66204 .33604 .6624 .33766 .66227 .33662 .66173 Mtetra
.556 .82 .995 r
.33662 .66173 .33766 .66227 .33929 .66202 .33825 .6614 Mtetra
.697 .835 .949 r
.33825 .6614 .33929 .66202 .34095 .66119 .3399 .6607 Mtetra
.886 .835 .79 r
.3399 .6607 .34095 .66119 .34274 .65771 .34164 .65842 Mtetra
.982 .873 .65 r
.34164 .65842 .34274 .65771 .35423 .46735 .3435 .65362 Mtetra
0 0 .244 r
.3435 .65362 .35423 .46735 .35649 .45308 .35501 .4623 Mtetra
.161 0 .347 r
.35501 .4623 .35649 .45308 .35812 .45093 .35684 .45649 Mtetra
.512 .233 .428 r
.35684 .45649 .35812 .45093 .35968 .45036 .35838 .4562 Mtetra
.533 .255 .439 r
.35838 .4562 .35968 .45036 .36121 .45023 .3599 .4562 Mtetra
.205 0 .321 r
.3599 .4562 .36121 .45023 .36276 .44974 .36161 .45276 Mtetra
0 0 0 r
.36161 .45276 .36276 .44974 .36432 .44897 .3633 .44947 Mtetra
.913 .98 .763 r
.3633 .44947 .36432 .44897 .36588 .44824 .36493 .44724 Mtetra
.768 .753 .84 r
.36493 .44724 .36588 .44824 .36744 .44764 .36652 .4461 Mtetra
.657 .64 .821 r
.36652 .4461 .36744 .44764 .36899 .44715 .36807 .44555 Mtetra
.617 .616 .827 r
.36807 .44555 .36899 .44715 .37055 .4467 .36962 .44522 Mtetra
.617 .633 .844 r
.36962 .44522 .37055 .4467 .3721 .44623 .37117 .4449 Mtetra
.624 .658 .863 r
.37117 .4449 .3721 .44623 .37366 .44574 .37272 .44455 Mtetra
.625 .682 .884 r
.37272 .44455 .37366 .44574 .37521 .44524 .37427 .4442 Mtetra
.645 .717 .901 r
.37427 .4442 .37521 .44524 .37677 .4447 .37582 .44376 Mtetra
.665 .745 .91 r
.37582 .44376 .37677 .4447 .37833 .44412 .37738 .44323 Mtetra
.679 .759 .912 r
.37738 .44323 .37833 .44412 .3799 .44355 .37895 .44265 Mtetra
.734 .769 .881 r
.37895 .44265 .3799 .44355 .38147 .44272 .38053 .44179 Mtetra
.736 .763 .875 r
.38053 .44179 .38147 .44272 .38305 .44193 .3821 .44091 Mtetra
.663 .728 .898 r
.3821 .44091 .38305 .44193 .3846 .44165 .38367 .44039 Mtetra
.136 .416 .861 r
.38367 .44039 .3846 .44165 .38606 .44349 .38517 .44121 Mtetra
0 0 .345 r
.38517 .44121 .38606 .44349 .37988 .62736 .38658 .44445 Mtetra
0 0 .27 r
.38658 .44445 .37988 .62736 .38071 .64675 .38017 .63465 Mtetra
.271 .157 .535 r
.38017 .63465 .38071 .64675 .38228 .64847 .38155 .6409 Mtetra
.588 .418 .619 r
.38155 .6409 .38228 .64847 .38394 .64813 .38321 .64027 Mtetra
.604 .428 .616 r
.38321 .64027 .38394 .64813 .38562 .64727 .3849 .63922 Mtetra
.452 .314 .602 r
.3849 .63922 .38562 .64727 .38729 .64669 .38647 .64113 Mtetra
.314 .245 .618 r
.38647 .64113 .38729 .64669 .38895 .64649 .38802 .64371 Mtetra
.257 .309 .725 r
.38802 .64371 .38895 .64649 .39061 .64628 .38961 .6452 Mtetra
.334 .589 .938 r
.38961 .6452 .39061 .64628 .39227 .64592 .39125 .64556 Mtetra
.525 .856 .996 r
.39125 .64556 .39227 .64592 .39394 .64542 .39291 .64518 Mtetra
.609 .908 .983 r
.39291 .64518 .39394 .64542 .39562 .64488 .39459 .64456 Mtetra
.53 .868 .993 r
.39459 .64456 .39562 .64488 .39728 .64461 .39627 .64414 Mtetra
.511 .824 1 r
.39627 .64414 .39728 .64461 .39895 .64443 .39793 .64385 Mtetra
.676 .847 .965 r
.39793 .64385 .39895 .64443 .40063 .64372 .39962 .6432 Mtetra
.867 .85 .824 r
.39962 .6432 .40063 .64372 .40239 .64099 .40134 .64129 Mtetra
.973 .862 .668 r
.40134 .64129 .40239 .64099 .40448 .62873 .40316 .63687 Mtetra
.964 .703 .491 r
.40316 .63687 .40448 .62873 .41279 .43508 .41139 .44758 Mtetra
0 0 .296 r
.41139 .44758 .41279 .43508 .41446 .43213 .41333 .43675 Mtetra
.433 .148 .379 r
.41333 .43675 .41446 .43213 .41605 .43137 .41493 .43573 Mtetra
.534 .236 .407 r
.41493 .43573 .41605 .43137 .41762 .43113 .4165 .43582 Mtetra
.535 .242 .416 r
.4165 .43582 .41762 .43113 .4192 .43086 .41807 .43591 Mtetra
.488 .204 .409 r
.41807 .43591 .4192 .43086 .42078 .43033 .41966 .43536 Mtetra
.489 .205 .409 r
.41966 .43536 .42078 .43033 .42237 .42981 .42124 .43484 Mtetra
.443 .164 .394 r
.42124 .43484 .42237 .42981 .42396 .42906 .42285 .4338 Mtetra
.415 .135 .376 r
.42285 .4338 .42396 .42906 .42556 .42821 .42446 .43257 Mtetra
.511 .214 .399 r
.42446 .43257 .42556 .42821 .42714 .42786 .42604 .43239 Mtetra
.775 .474 .478 r
.42604 .43239 .42714 .42786 .42867 .42936 .42744 .43839 Mtetra
.94 .67 .498 r
.42744 .43839 .42867 .42936 .42493 .61181 .42338 .63029 Mtetra
.611 .362 .516 r
.42338 .63029 .42493 .61181 .42598 .63359 .42495 .63408 Mtetra
.661 .17 .073 r
.42495 .63408 .42598 .63359 .42759 .63573 .42659 .63522 Mtetra
.525 .821 .999 r
.42659 .63522 .42759 .63573 .42928 .63552 .42828 .63491 Mtetra
.684 .846 .961 r
.42828 .63491 .42928 .63552 .43098 .63474 .42998 .63423 Mtetra
.684 .87 .969 r
.42998 .63423 .43098 .63474 .43269 .63394 .43169 .63353 Mtetra
.596 .871 .993 r
.43169 .63353 .43269 .63394 .43438 .63346 .43338 .63302 Mtetra
.604 .866 .992 r
.43338 .63302 .43438 .63346 .43608 .63298 .43508 .63251 Mtetra
.569 .847 .997 r
.43508 .63251 .43608 .63298 .43778 .63251 .43678 .63209 Mtetra
.509 .838 .999 r
.43678 .63209 .43778 .63251 .43948 .63206 .43848 .63176 Mtetra
.577 .891 .989 r
.43848 .63176 .43948 .63206 .44118 .63156 .44018 .63122 Mtetra
.792 .917 .923 r
.44018 .63122 .44118 .63156 .44289 .63096 .4419 .63004 Mtetra
.865 .784 .77 r
.4419 .63004 .44289 .63096 .44459 .63021 .44365 .62767 Mtetra
.808 .644 .679 r
.44365 .62767 .44459 .63021 .4463 .62944 .44542 .62428 Mtetra
.722 .536 .638 r
.44542 .62428 .4463 .62944 .44801 .62896 .44719 .62098 Mtetra
.56 .395 .615 r
.44719 .62098 .44801 .62896 .44971 .62886 .44888 .62094 Mtetra
.572 .405 .616 r
.44888 .62094 .44971 .62886 .45142 .62827 .45058 .62062 Mtetra
.723 .516 .61 r
.45058 .62062 .45142 .62827 .45316 .62595 .45238 .61553 Mtetra
.945 .677 .499 r
.45238 .61553 .45316 .62595 .45512 .61348 .45808 .4214 Mtetra
.56 .343 .542 r
.45808 .4214 .45512 .61348 .46066 .41915 .45977 .41669 Mtetra
.762 .619 .701 r
.45977 .41669 .46066 .41915 .46232 .41583 .46141 .41449 Mtetra
.694 .688 .84 r
.46141 .41449 .46232 .41583 .46394 .41497 .46303 .41375 Mtetra
.628 .684 .883 r
.46303 .41375 .46394 .41497 .46555 .41464 .46464 .41337 Mtetra
.613 .667 .878 r
.46464 .41337 .46555 .41464 .46715 .41444 .46624 .41305 Mtetra
.656 .666 .848 r
.46624 .41305 .46715 .41444 .46876 .41394 .46786 .41252 Mtetra
.651 .66 .846 r
.46786 .41252 .46876 .41394 .47038 .41345 .46947 .41201 Mtetra
.64 .653 .847 r
.46947 .41201 .47038 .41345 .47199 .41295 .47108 .41156 Mtetra
.622 .652 .859 r
.47108 .41156 .47199 .41295 .47361 .41244 .4727 .41121 Mtetra
.624 .68 .883 r
.4727 .41121 .47361 .41244 .47522 .41192 .47431 .41084 Mtetra
.647 .718 .9 r
.47431 .41084 .47522 .41192 .47684 .41139 .47593 .41038 Mtetra
.69 .745 .894 r
.47593 .41038 .47684 .41139 .47846 .41084 .47755 .40972 Mtetra
.694 .724 .873 r
.47755 .40972 .47846 .41084 .48008 .4103 .47917 .40902 Mtetra
.682 .695 .855 r
.47917 .40902 .48008 .4103 .4817 .40976 .48079 .40836 Mtetra
.66 .668 .846 r
.48079 .40836 .4817 .40976 .48332 .40923 .48242 .4078 Mtetra
.655 .661 .843 r
.48242 .4078 .48332 .40923 .48494 .40871 .48404 .40727 Mtetra
.653 .658 .843 r
.48404 .40727 .48494 .40871 .48656 .4082 .48566 .40675 Mtetra
.653 .658 .842 r
.48566 .40675 .48656 .4082 .48819 .40768 .48729 .40622 Mtetra
.653 .656 .841 r
.48729 .40622 .48819 .40768 .48981 .40716 .48891 .4057 Mtetra
.654 .656 .839 r
.48891 .4057 .48981 .40716 .49144 .40664 .49054 .40516 Mtetra
.656 .655 .837 r
.49054 .40516 .49144 .40664 .49307 .40611 .49217 .40462 Mtetra
.657 .654 .835 r
.49217 .40462 .49307 .40611 .49469 .40556 .49379 .40406 Mtetra
.664 .656 .832 r
.49379 .40406 .49469 .40556 .49632 .405 .49542 .40347 Mtetra
.683 .659 .82 r
.49542 .40347 .49632 .405 .49795 .4044 .49706 .40274 Mtetra
.653 .631 .816 r
.49706 .40274 .49795 .4044 .49958 .40382 .49869 .40218 Mtetra
.573 .596 .838 r
.49869 .40218 .49958 .40382 .50122 .40332 .50032 .40206 Mtetra
.039 .351 .827 r
.50032 .40206 .50122 .40332 .50285 .40301 .50194 .40311 Mtetra
.785 .306 .092 r
.50194 .40311 .50285 .40301 .50448 .40272 .50356 .40512 Mtetra
.755 .41 .4 r
.50356 .40512 .50448 .40272 .50611 .40238 .50517 .40829 Mtetra
.557 .275 .444 r
.50517 .40829 .50611 .40238 .50775 .40182 .50681 .4087 Mtetra
.472 .21 .436 r
.50681 .4087 .50775 .40182 .50939 .40121 .50845 .40758 Mtetra
.438 .177 .419 r
.50845 .40758 .50939 .40121 .51103 .40059 .5101 .40608 Mtetra
.486 .208 .417 r
.5101 .40608 .51103 .40059 .51267 .40001 .51174 .40542 Mtetra
.485 .207 .416 r
.51174 .40542 .51267 .40001 .51431 .39944 .51339 .40476 Mtetra
.485 .206 .414 r
.51339 .40476 .51431 .39944 .51595 .39888 .51503 .40413 Mtetra
.487 .206 .413 r
.51503 .40413 .51595 .39888 .51759 .39832 .51668 .40353 Mtetra
.488 .207 .412 r
.51668 .40353 .51759 .39832 .51923 .39777 .51832 .40295 Mtetra
.489 .207 .412 r
.51832 .40295 .51923 .39777 .52088 .39722 .51997 .40238 Mtetra
.49 .207 .412 r
.51997 .40238 .52088 .39722 .52252 .39667 .52162 .40182 Mtetra
.491 .208 .412 r
.52162 .40182 .52252 .39667 .52417 .39612 .52327 .40128 Mtetra
.492 .209 .412 r
.52327 .40128 .52417 .39612 .52581 .39558 .52492 .40075 Mtetra
.492 .21 .413 r
.52492 .40075 .52581 .39558 .52746 .39504 .52657 .40023 Mtetra
.494 .211 .413 r
.52657 .40023 .52746 .39504 .52911 .39451 .52823 .39972 Mtetra
.496 .213 .415 r
.52823 .39972 .52911 .39451 .53076 .39398 .52988 .39924 Mtetra
.499 .217 .417 r
.52988 .39924 .53076 .39398 .53241 .39345 .53153 .39879 Mtetra
.501 .22 .419 r
.53153 .39879 .53241 .39345 .53406 .39293 .53319 .39836 Mtetra
.506 .225 .422 r
.53319 .39836 .53406 .39293 .53572 .39242 .53485 .39799 Mtetra
.564 .277 .439 r
.53485 .39799 .53572 .39242 .53737 .39197 .53651 .39853 Mtetra
.524 .252 .445 r
.53651 .39853 .53737 .39197 .53903 .39148 .53817 .39832 Mtetra
.416 .163 .421 r
.53817 .39832 .53903 .39148 .54068 .39092 .53982 .39635 Mtetra
.086 0 .283 r
.53982 .39635 .54068 .39092 .54234 .39014 .54147 .39198 Mtetra
0 0 0 r
.54147 .39198 .54234 .39014 .54399 .38933 .54311 .38909 Mtetra
.902 .919 .822 r
.54311 .38909 .54399 .38933 .54565 .38857 .54476 .38711 Mtetra
.691 .675 .829 r
.54476 .38711 .54565 .38857 .54731 .38802 .54642 .38634 Mtetra
.64 .625 .82 r
.54642 .38634 .54731 .38802 .54897 .38752 .54808 .38586 Mtetra
.615 .616 .828 r
.54808 .38586 .54897 .38752 .55063 .38704 .54975 .38551 Mtetra
.651 .65 .836 r
.54975 .38551 .55063 .38704 .5523 .3865 .55141 .38498 Mtetra
.652 .651 .836 r
.55141 .38498 .5523 .3865 .55396 .38596 .55307 .38445 Mtetra
.653 .653 .837 r
.55307 .38445 .55396 .38596 .55562 .3854 .55474 .3839 Mtetra
.656 .656 .838 r
.55474 .3839 .55562 .3854 .55729 .38484 .5564 .38335 Mtetra
.657 .657 .839 r
.5564 .38335 .55729 .38484 .55896 .38427 .55807 .38279 Mtetra
.657 .658 .84 r
.55807 .38279 .55896 .38427 .56062 .3837 .55974 .38223 Mtetra
.658 .66 .84 r
.55974 .38223 .56062 .3837 .56229 .38314 .56141 .38166 Mtetra
.655 .658 .841 r
.56141 .38166 .56229 .38314 .56396 .38258 .56308 .38111 Mtetra
.649 .658 .845 r
.56308 .38111 .56396 .38258 .56563 .38203 .56475 .38059 Mtetra
.63 .654 .855 r
.56475 .38059 .56563 .38203 .5673 .3815 .56642 .38018 Mtetra
.626 .671 .874 r
.56642 .38018 .5673 .3815 .56898 .38098 .5681 .3798 Mtetra
.629 .697 .895 r
.5681 .3798 .56898 .38098 .57065 .38044 .56978 .37939 Mtetra
.651 .732 .909 r
.56978 .37939 .57065 .38044 .57232 .37987 .57145 .37889 Mtetra
.666 .752 .915 r
.57145 .37889 .57232 .37987 .574 .37929 .57313 .37833 Mtetra
.68 .762 .913 r
.57313 .37833 .574 .37929 .57568 .37869 .5748 .3777 Mtetra
.704 .762 .897 r
.5748 .3777 .57568 .37869 .57735 .37809 .57648 .37695 Mtetra
.703 .733 .874 r
.57648 .37695 .57735 .37809 .57903 .37749 .57816 .37618 Mtetra
.693 .701 .853 r
.57816 .37618 .57903 .37749 .58071 .37689 .57983 .37544 Mtetra
.707 .684 .825 r
.57983 .37544 .58071 .37689 .58238 .37591 .58151 .37455 Mtetra
.678 .687 .851 r
.58151 .37455 .58238 .37591 .58406 .3752 .58319 .37389 Mtetra
.591 .657 .883 r
.58319 .37389 .58406 .3752 .58575 .37511 .58488 .37365 Mtetra
0 .214 .738 r
.58488 .37365 .58575 .37511 .58751 .37837 .5866 .37524 Mtetra
0 0 .423 r
.5866 .37524 .58751 .37837 .59322 .57809 .58839 .37983 Mtetra
0 0 .391 r
.58839 .37983 .59322 .57809 .59517 .58512 .59409 .5763 Mtetra
.492 .342 .606 r
.59409 .5763 .59517 .58512 .597 .58568 .59593 .57779 Mtetra
.596 .423 .617 r
.59593 .57779 .597 .58568 .5988 .58511 .59772 .5769 Mtetra
.592 .418 .615 r
.59772 .5769 .5988 .58511 .60059 .58413 .59951 .57607 Mtetra
.393 .278 .602 r
.59951 .57607 .60059 .58413 .6024 .58378 .6014 .57911 Mtetra
.341 .291 .656 r
.6014 .57911 .6024 .58378 .60421 .58357 .60326 .58132 Mtetra
.28 .375 .782 r
.60326 .58132 .60421 .58357 .60602 .58332 .60511 .58257 Mtetra
.374 .698 .983 r
.60511 .58257 .60602 .58332 .60783 .58289 .60693 .58267 Mtetra
.401 .833 .954 r
.60693 .58267 .60783 .58289 .60964 .58239 .60875 .58233 Mtetra
.445 .875 .912 r
.60875 .58233 .60964 .58239 .61145 .58183 .61056 .58176 Mtetra
.333 .812 .887 r
.61056 .58176 .61145 .58183 .61327 .58167 .61238 .58137 Mtetra
.556 .894 .983 r
.61238 .58137 .61327 .58167 .61509 .58129 .61419 .58081 Mtetra
.743 .905 .949 r
.61419 .58081 .61509 .58129 .61689 .58027 .61599 .5798 Mtetra
.927 .873 .763 r
.61599 .5798 .61689 .58027 .6186 .57604 .61775 .57706 Mtetra
.982 .884 .53 r
.61775 .57706 .6186 .57604 .6148 .37588 .61942 .57146 Mtetra
0 0 .387 r
.61942 .57146 .6148 .37588 .61626 .36656 .61564 .3738 Mtetra
.312 .085 .401 r
.61564 .3738 .61626 .36656 .61793 .36474 .61726 .37015 Mtetra
.515 .232 .423 r
.61726 .37015 .61793 .36474 .61963 .36417 .61897 .3699 Mtetra
.525 .244 .431 r
.61897 .3699 .61963 .36417 .62135 .36401 .6207 .36978 Mtetra
.217 0 .348 r
.6207 .36978 .62135 .36401 .62305 .36338 .62231 .36597 Mtetra
0 0 .042 r
.62231 .36597 .62305 .36338 .62475 .36256 .62393 .36279 Mtetra
.896 .988 .759 r
.62393 .36279 .62475 .36256 .62645 .36177 .62559 .36061 Mtetra
.733 .741 .859 r
.62559 .36061 .62645 .36177 .62815 .36115 .62729 .35965 Mtetra
.631 .648 .848 r
.62729 .35965 .62815 .36115 .62987 .36062 .629 .35922 Mtetra
.593 .645 .872 r
.629 .35922 .62987 .36062 .63158 .36011 .63073 .35897 Mtetra
.633 .711 .903 r
.63073 .35897 .63158 .36011 .63329 .35954 .63244 .35854 Mtetra
.664 .752 .916 r
.63244 .35854 .63329 .35954 .635 .35892 .63416 .35797 Mtetra
.678 .768 .919 r
.63416 .35797 .635 .35892 .63671 .35829 .63587 .35734 Mtetra
.745 .786 .886 r
.63587 .35734 .63671 .35829 .63841 .35735 .63757 .35636 Mtetra
.736 .778 .887 r
.63757 .35636 .63841 .35735 .64012 .35653 .63927 .35544 Mtetra
.658 .731 .904 r
.63927 .35544 .64012 .35653 .64185 .35624 .64099 .35489 Mtetra
.249 .468 .876 r
.64099 .35489 .64185 .35624 .64366 .3583 .64276 .35568 Mtetra
0 .1 .636 r
.64276 .35568 .64366 .3583 .65249 .54546 .64461 .3585 Mtetra
0 0 .402 r
.64461 .3585 .65249 .54546 .65513 .56608 .65369 .55069 Mtetra
.163 .083 .512 r
.65369 .55069 .65513 .56608 .65706 .5677 .656 .56248 Mtetra
.351 .287 .645 r
.656 .56248 .65706 .5677 .65891 .56753 .65795 .56492 Mtetra
.394 .417 .766 r
.65795 .56492 .65891 .56753 .66075 .56681 .65986 .5659 Mtetra
.51 .726 .971 r
.65986 .5659 .66075 .56681 .66258 .56615 .66172 .56578 Mtetra
.632 .911 .982 r
.66172 .56578 .66258 .56615 .66442 .56552 .66356 .56507 Mtetra
.721 .912 .961 r
.66356 .56507 .66442 .56552 .66626 .56484 .66539 .56413 Mtetra
.581 .806 .985 r
.66539 .56413 .66626 .56484 .66812 .56454 .66724 .56373 Mtetra
.535 .763 .981 r
.66724 .56373 .66812 .56454 .66998 .56418 .6691 .5635 Mtetra
.66 .841 .97 r
.6691 .5635 .66998 .56418 .6718 .56318 .67095 .56284 Mtetra
.909 .923 .813 r
.67095 .56284 .6718 .56318 .6735 .55914 .67272 .56063 Mtetra
.896 .864 .42 r
.67272 .56063 .6735 .55914 .6664 .35758 .67437 .55539 Mtetra
0 0 .406 r
.67437 .55539 .6664 .35758 .66779 .34928 .6673 .35582 Mtetra
0 0 .286 r
.6673 .35582 .66779 .34928 .66945 .34695 .66876 .349 Mtetra
0 0 0 r
.66876 .349 .66945 .34695 .67117 .34603 .67039 .34608 Mtetra
.871 .992 .813 r
.67039 .34608 .67117 .34603 .67291 .34553 .67206 .34421 Mtetra
.751 .726 .829 r
.67206 .34421 .67291 .34553 .67464 .3448 .67377 .34304 Mtetra
.659 .632 .811 r
.67377 .34304 .67464 .3448 .67636 .34404 .67551 .3424 Mtetra
.577 .605 .844 r
.67551 .3424 .67636 .34404 .67812 .34378 .67727 .34225 Mtetra
.304 .469 .858 r
.67727 .34225 .67812 .34378 .67996 .34538 .67907 .34304 Mtetra
0 .158 .678 r
.67907 .34304 .67996 .34538 .68217 .35425 .68096 .34548 Mtetra
0 0 .441 r
.68096 .34548 .68217 .35425 .69395 .55388 .68327 .35614 Mtetra
.028 0 .427 r
.68327 .35614 .69395 .55388 .69596 .55622 .69483 .55029 Mtetra
.338 .267 .629 r
.69483 .55029 .69596 .55622 .69785 .55624 .69687 .55325 Mtetra
.388 .39 .74 r
.69687 .55325 .69785 .55624 .69972 .55568 .69883 .55445 Mtetra
.484 .644 .927 r
.69883 .55445 .69972 .55568 .70158 .55508 .70073 .55454 Mtetra
.617 .867 .99 r
.70073 .55454 .70158 .55508 .70345 .55456 .7026 .55395 Mtetra
.698 .873 .964 r
.7026 .55395 .70345 .55456 .70532 .55399 .70446 .55312 Mtetra
.555 .76 .973 r
.70446 .55312 .70532 .55399 .70721 .55376 .70635 .55285 Mtetra
.46 .704 .973 r
.70635 .55285 .70721 .55376 .70911 .55361 .70825 .55286 Mtetra
.646 .825 .969 r
.70825 .55286 .70911 .55361 .71097 .55286 .71013 .55226 Mtetra
.936 .862 .742 r
.71013 .55226 .71097 .55286 .71271 .54978 .71187 .54923 Mtetra
.982 .717 .448 r
.71187 .54923 .71271 .54978 .7133 .52636 .71241 .52484 Mtetra
.976 .684 .4 r
.71241 .52484 .7133 .52636 .70448 .33776 .70363 .33625 Mtetra
.858 .733 .724 r
.70363 .33625 .70448 .33776 .70611 .33498 .70527 .33352 Mtetra
.665 .675 .849 r
.70527 .33352 .70611 .33498 .70786 .33423 .70702 .33289 Mtetra
.548 .64 .894 r
.70702 .33289 .70786 .33423 .70963 .334 .70881 .33282 Mtetra
.609 .697 .906 r
.70881 .33282 .70963 .334 .7114 .33347 .71059 .33247 Mtetra
.705 .772 .904 r
.71059 .33247 .7114 .33347 .71314 .33259 .71234 .3317 Mtetra
.632 .772 .947 r
.71234 .3317 .71314 .33259 .71491 .33218 .71411 .33122 Mtetra
.243 .552 .931 r
.71411 .33122 .71491 .33218 .7168 .33359 .71594 .33177 Mtetra
0 .043 .612 r
.71594 .33177 .7168 .33359 .71927 .34452 .7179 .33444 Mtetra
.979 .682 .343 r
.7179 .33444 .71927 .34452 .73336 .54275 .73149 .52547 Mtetra
.162 .083 .513 r
.73149 .52547 .73336 .54275 .73543 .54518 .73428 .53943 Mtetra
.37 .293 .639 r
.73428 .53943 .73543 .54518 .73736 .54517 .73637 .54202 Mtetra
.413 .398 .733 r
.73637 .54202 .73736 .54517 .73925 .54457 .73837 .54314 Mtetra
.426 .577 .9 r
.73837 .54314 .73925 .54457 .74115 .54408 .74032 .5435 Mtetra
.468 .797 .999 r
.74032 .5435 .74115 .54408 .74306 .54382 .74224 .54328 Mtetra
.677 .889 .975 r
.74224 .54328 .74306 .54382 .74495 .54302 .74412 .54249 Mtetra
.869 .912 .857 r
.74412 .54249 .74495 .54302 .74671 .54043 .74594 .54066 Mtetra
.974 .926 .633 r
.74594 .54066 .74671 .54043 .748 .53068 .74762 .53683 Mtetra
0 0 .071 r
.74762 .53683 .748 .53068 .73637 .32867 .74877 .52496 Mtetra
.044 0 .431 r
.74877 .52496 .73637 .32867 .73795 .32504 .73745 .32848 Mtetra
0 0 .205 r
.73745 .32848 .73795 .32504 .73969 .32391 .73901 .32475 Mtetra
.571 .82 .446 r
.73901 .32475 .73969 .32391 .74146 .32333 .74069 .3226 Mtetra
.796 .859 .896 r
.74069 .3226 .74146 .32333 .74325 .32288 .74242 .32136 Mtetra
.651 .662 .847 r
.74242 .32136 .74325 .32288 .74503 .32229 .7442 .3208 Mtetra
.609 .647 .862 r
.7442 .3208 .74503 .32229 .74682 .32175 .746 .32047 Mtetra
.654 .701 .881 r
.746 .32047 .74682 .32175 .74859 .32103 .74779 .31991 Mtetra
.733 .762 .875 r
.74779 .31991 .74859 .32103 .75035 .32011 .74955 .31895 Mtetra
.68 .733 .891 r
.74955 .31895 .75035 .32011 .75215 .31963 .75133 .31828 Mtetra
.469 .596 .897 r
.75133 .31828 .75215 .31963 .75404 .3206 .75317 .31848 Mtetra
.028 .21 .716 r
.75317 .31848 .75404 .3206 .75639 .32765 .75516 .32068 Mtetra
0 0 .476 r
.75516 .32068 .75639 .32765 .77323 .53008 .75766 .32958 Mtetra
.065 0 .448 r
.75766 .32958 .77323 .53008 .77542 .53326 .77419 .52695 Mtetra
.357 .277 .628 r
.77419 .52695 .77542 .53326 .77739 .53339 .77638 .53001 Mtetra
.408 .384 .721 r
.77638 .53001 .77739 .53339 .77932 .53288 .77843 .53128 Mtetra
.427 .55 .877 r
.77843 .53128 .77932 .53288 .78124 .53232 .78043 .53172 Mtetra
.444 .779 .998 r
.78043 .53172 .78124 .53232 .78319 .53212 .78239 .53156 Mtetra
.653 .883 .982 r
.78239 .53156 .78319 .53212 .7851 .53139 .7843 .53084 Mtetra
.855 .916 .872 r
.7843 .53084 .7851 .53139 .7869 .52919 .78614 .52913 Mtetra
.981 .907 .65 r
.78614 .52913 .7869 .52919 .78823 .52111 .78781 .52522 Mtetra
0 0 0 r
.78781 .52522 .78823 .52111 .774 .31695 .78897 .515 Mtetra
.069 0 .444 r
.78897 .515 .774 .31695 .77552 .31281 .77527 .31843 Mtetra
.473 .2 .418 r
.77527 .31843 .77552 .31281 .77729 .31186 .77704 .31748 Mtetra
.527 .243 .427 r
.77704 .31748 .77729 .31186 .77911 .3115 .77889 .31741 Mtetra
.418 .161 .414 r
.77889 .31741 .77911 .3115 .78094 .3112 .7806 .31557 Mtetra
.114 0 .297 r
.7806 .31557 .78094 .3112 .78272 .31035 .78213 .31157 Mtetra
0 0 0 r
.78213 .31157 .78272 .31035 .78451 .3095 .78376 .30886 Mtetra
.866 .89 .851 r
.78376 .30886 .78451 .3095 .7863 .30873 .78547 .30713 Mtetra
.68 .666 .829 r
.78547 .30713 .7863 .30873 .78811 .30812 .78727 .30636 Mtetra
.637 .626 .822 r
.78727 .30636 .78811 .30812 .78992 .30756 .78909 .30585 Mtetra
.627 .627 .831 r
.78909 .30585 .78992 .30756 .79173 .30701 .79091 .30541 Mtetra
.653 .654 .839 r
.79091 .30541 .79173 .30701 .79354 .30642 .79272 .30482 Mtetra
.652 .654 .839 r
.79272 .30482 .79354 .30642 .79536 .30583 .79453 .30424 Mtetra
.79453 .30424 .79536 .30583 .79717 .30525 .79635 .30366 Mtetra
.79635 .30366 .79717 .30525 .79899 .30467 .79817 .30307 Mtetra
.651 .653 .839 r
.79817 .30307 .79899 .30467 .80081 .3041 .79998 .3025 Mtetra
.649 .652 .839 r
.79998 .3025 .80081 .3041 .80263 .30354 .8018 .30193 Mtetra
.647 .65 .839 r
.8018 .30193 .80263 .30354 .80445 .30299 .80363 .30137 Mtetra
.645 .649 .839 r
.80363 .30137 .80445 .30299 .80627 .30245 .80545 .30083 Mtetra
.644 .648 .839 r
.80545 .30083 .80627 .30245 .8081 .30191 .80728 .30029 Mtetra
.645 .647 .838 r
.80728 .30029 .8081 .30191 .80993 .30139 .80911 .29974 Mtetra
.641 .643 .837 r
.80911 .29974 .80993 .30139 .81176 .30086 .81094 .29922 Mtetra
.633 .64 .839 r
.81094 .29922 .81176 .30086 .81359 .30034 .81277 .29875 Mtetra
.615 .637 .849 r
.81277 .29875 .81359 .30034 .81542 .29984 .81462 .29837 Mtetra
.615 .656 .867 r
.81462 .29837 .81542 .29984 .81726 .29933 .81647 .298 Mtetra
.627 .686 .886 r
.81647 .298 .81726 .29933 .81909 .29876 .81831 .29757 Mtetra
.665 .727 .896 r
.81831 .29757 .81909 .29876 .82091 .2981 .82014 .29695 Mtetra
.678 .741 .898 r
.82014 .29695 .82091 .2981 .82273 .29741 .82196 .29627 Mtetra
.701 .753 .892 r
.82196 .29627 .82273 .29741 .82454 .29661 .82378 .29547 Mtetra
.765 .775 .862 r
.82378 .29547 .82454 .29661 .82632 .29542 .82555 .29429 Mtetra
.69 .751 .898 r
.82555 .29429 .82632 .29542 .82814 .29467 .82737 .29355 Mtetra
.406 .611 .933 r
.82737 .29355 .82814 .29467 .83006 .29496 .8293 .29385 Mtetra
.827 .42 0 r
.8293 .29385 .83006 .29496 .83255 .30096 .83178 .29985 Mtetra
.973 .661 .312 r
.83178 .29985 .83255 .30096 .85476 .5059 .85396 .50484 Mtetra
.695 .251 0 r
.85396 .50484 .85476 .5059 .85719 .50993 .85639 .50887 Mtetra
.342 .605 .946 r
.85639 .50887 .85719 .50993 .85926 .51034 .85846 .50927 Mtetra
.669 .772 .927 r
.85846 .50927 .85926 .51034 .86123 .50966 .86043 .50859 Mtetra
.849 .822 .822 r
.86043 .50859 .86123 .50966 .86306 .50772 .86227 .50665 Mtetra
.977 .78 .572 r
.86227 .50665 .86306 .50772 .86443 .5011 .86363 .50004 Mtetra
.976 .67 .326 r
.86363 .50004 .86443 .5011 .84521 .29429 .84445 .29316 Mtetra
.966 .78 .602 r
.84445 .29316 .84521 .29429 .84656 .28888 .8458 .28776 Mtetra
.762 .778 .866 r
.8458 .28776 .84656 .28888 .84835 .28772 .84759 .28659 Mtetra
.633 .728 .917 r
.84759 .28659 .84835 .28772 .85021 .28725 .84945 .28612 Mtetra
.557 .692 .93 r
.84945 .28612 .85021 .28725 .8521 .28707 .85135 .28594 Mtetra
.752 .775 .871 r
.85135 .28594 .8521 .28707 .8539 .28597 .85314 .28483 Mtetra
.685 .749 .9 r
.85314 .28483 .8539 .28597 .85574 .28526 .85498 .28412 Mtetra
.484 .652 .934 r
.85498 .28412 .85574 .28526 .85766 .28533 .85691 .28419 Mtetra
.738 .32 0 r
.85691 .28419 .85766 .28533 .8601 .29019 .85935 .28901 Mtetra
.971 .656 .295 r
.85935 .28901 .8601 .29019 .88433 .49608 .88353 .49494 Mtetra
.731 .305 0 r
.88353 .49494 .88433 .49608 .88691 .50092 .88612 .49981 Mtetra
.372 .613 .944 r
.88612 .49981 .88691 .50092 .88902 .50141 .88821 .50017 Mtetra
.661 .735 .905 r
.88821 .50017 .88902 .50141 .89101 .50078 .8902 .49952 Mtetra
.793 .78 .841 r
.8902 .49952 .89101 .50078 .89288 .49905 .8921 .498 Mtetra
.76 .785 .874 r
.25178 .68455 .25284 .68537 .25461 .68257 .25341 .68351 Mtetra
.616 .912 .637 r
.25341 .68351 .25461 .68257 .25661 .67662 .25509 .68191 Mtetra
.226 0 .298 r
.25509 .68191 .25661 .67662 .27278 .48485 .25685 .67917 Mtetra
0 0 .281 r
.25685 .67917 .27278 .48485 .27461 .48009 .27153 .50665 Mtetra
0 0 .145 r
.27153 .50665 .27461 .48009 .27625 .47773 .27511 .47885 Mtetra
.962 .943 .662 r
.27511 .47885 .27625 .47773 .27783 .47623 .27684 .47538 Mtetra
.757 .772 .866 r
.27684 .47538 .27783 .47623 .27935 .47551 .27838 .47441 Mtetra
.643 .698 .886 r
.27838 .47441 .27935 .47551 .28085 .47508 .27988 .47399 Mtetra
.566 .675 .912 r
.27988 .47399 .28085 .47508 .28234 .47478 .28136 .47384 Mtetra
.749 .754 .857 r
.28136 .47384 .28234 .47478 .28388 .4738 .2829 .47288 Mtetra
.697 .75 .892 r
.2829 .47288 .28388 .4738 .2854 .47313 .28442 .47223 Mtetra
.463 .677 .957 r
.28442 .47223 .2854 .47313 .28687 .47316 .28589 .47228 Mtetra
.933 .568 .293 r
.28589 .47228 .28687 .47316 .28802 .47769 .28703 .47684 Mtetra
.939 .683 .522 r
.28703 .47684 .28802 .47769 .2755 .67394 .27445 .67309 Mtetra
.929 .562 .295 r
.27445 .67309 .2755 .67394 .27672 .67871 .27568 .67783 Mtetra
.351 .644 .965 r
.27568 .67783 .27672 .67871 .27828 .67891 .27723 .67804 Mtetra
.702 .773 .907 r
.27723 .67804 .27828 .67891 .2799 .6782 .27885 .67733 Mtetra
.768 .781 .864 r
.27885 .67733 .2799 .6782 .28154 .6771 .2805 .67623 Mtetra
.471 .7 .968 r
.2805 .67623 .28154 .6771 .28311 .67716 .28207 .67622 Mtetra
.563 .722 .947 r
.28207 .67622 .28311 .67716 .2847 .67702 .28366 .67602 Mtetra
.733 .753 .869 r
.28366 .67602 .2847 .67702 .28633 .67618 .2853 .67512 Mtetra
.899 .731 .665 r
.2853 .67512 .28633 .67618 .28824 .6713 .28722 .67006 Mtetra
.939 .687 .528 r
.28722 .67006 .28824 .6713 .30312 .47354 .30216 .47226 Mtetra
.899 .71 .638 r
.30216 .47226 .30312 .47354 .30504 .46701 .30407 .46602 Mtetra
.786 .752 .822 r
.30407 .46602 .30504 .46701 .30661 .46569 .30564 .46472 Mtetra
.61 .717 .921 r
.30564 .46472 .30661 .46569 .30812 .46539 .30715 .46441 Mtetra
.441 .648 .946 r
.30715 .46441 .30812 .46539 .3096 .46553 .30863 .46453 Mtetra
.608 .711 .918 r
.30863 .46453 .3096 .46553 .31111 .46522 .31014 .46424 Mtetra
.647 .726 .906 r
.31014 .46424 .31111 .46522 .31263 .46475 .31166 .4638 Mtetra
.661 .737 .906 r
.31166 .4638 .31263 .46475 .31415 .46421 .31318 .4633 Mtetra
.715 .756 .885 r
.31318 .4633 .31415 .46421 .3157 .46328 .31472 .46255 Mtetra
.715 .798 .916 r
.31472 .46255 .3157 .46328 .31725 .46246 .31626 .46183 Mtetra
.663 .814 .956 r
.31626 .46183 .31725 .46246 .31877 .46205 .31779 .4613 Mtetra
.276 .628 .962 r
.31779 .4613 .31877 .46205 .32018 .46342 .31927 .46156 Mtetra
.317 .421 .81 r
.31927 .46156 .32018 .46342 .32142 .46762 .32072 .46235 Mtetra
.461 .346 .637 r
.32072 .46235 .32142 .46762 .31116 .65908 .32214 .46349 Mtetra
.551 .336 .541 r
.32214 .46349 .31116 .65908 .31262 .6612 .32367 .46301 Mtetra
.552 .336 .541 r
.32367 .46301 .31262 .6612 .31427 .66032 .32523 .46215 Mtetra
.55 .335 .541 r
.32523 .46215 .31427 .66032 .31592 .65938 .32674 .46201 Mtetra
.533 .321 .538 r
.32674 .46201 .31592 .65938 .31734 .66222 .32776 .47011 Mtetra
0 0 .256 r
.32776 .47011 .31734 .66222 .3188 .66452 .31792 .66117 Mtetra
0 0 .47 r
.31792 .66117 .3188 .66452 .32032 .66582 .31931 .66467 Mtetra
.269 .537 .919 r
.31931 .66467 .32032 .66582 .32192 .66587 .32088 .66517 Mtetra
.625 .799 .966 r
.32088 .66517 .32192 .66587 .32355 .66542 .32251 .66473 Mtetra
.714 .821 .932 r
.32251 .66473 .32355 .66542 .32519 .6648 .32416 .66397 Mtetra
.644 .775 .943 r
.32416 .66397 .32519 .6648 .32682 .66441 .32579 .66349 Mtetra
.613 .745 .94 r
.32579 .66349 .32682 .66441 .32844 .66411 .32741 .66313 Mtetra
.626 .736 .926 r
.32741 .66313 .32844 .66411 .33006 .66378 .32904 .66274 Mtetra
.662 .734 .903 r
.32904 .66274 .33006 .66378 .3317 .66327 .33068 .6622 Mtetra
.678 .733 .892 r
.33068 .6622 .3317 .66327 .33334 .66266 .33233 .66159 Mtetra
.68 .731 .889 r
.33233 .66159 .33334 .66266 .33499 .66204 .33397 .66096 Mtetra
.636 .719 .907 r
.33397 .66096 .33499 .66204 .33662 .66173 .33561 .66053 Mtetra
.631 .695 .891 r
.33561 .66053 .33662 .66173 .33825 .6614 .33724 .66012 Mtetra
.666 .694 .867 r
.33724 .66012 .33825 .6614 .3399 .6607 .33889 .65955 Mtetra
.768 .739 .827 r
.33889 .65955 .3399 .6607 .34164 .65842 .34057 .65829 Mtetra
.883 .917 .844 r
.34057 .65829 .34164 .65842 .3435 .65362 .34228 .65645 Mtetra
.019 0 .083 r
.34228 .65645 .3435 .65362 .35501 .4623 .34402 .65425 Mtetra
.548 .329 .535 r
.34402 .65425 .35501 .4623 .35684 .45649 .34568 .65342 Mtetra
.549 .33 .535 r
.34568 .65342 .35684 .45649 .35838 .4562 .3473 .6533 Mtetra
.548 .329 .535 r
.3473 .6533 .35838 .4562 .3599 .4562 .34896 .65252 Mtetra
.538 .321 .533 r
.34896 .65252 .3599 .4562 .36161 .45276 .3509 .64622 Mtetra
0 0 .26 r
.3509 .64622 .36161 .45276 .3633 .44947 .3622 .45138 Mtetra
.937 .907 .519 r
.3622 .45138 .3633 .44947 .36493 .44724 .36396 .44666 Mtetra
.851 .831 .827 r
.36396 .44666 .36493 .44724 .36652 .4461 .36557 .44499 Mtetra
.677 .714 .876 r
.36557 .44499 .36652 .4461 .36807 .44555 .36713 .4444 Mtetra
.59 .676 .899 r
.36713 .4444 .36807 .44555 .36962 .44522 .36867 .44417 Mtetra
.599 .699 .914 r
.36867 .44417 .36962 .44522 .37117 .4449 .37022 .4439 Mtetra
.621 .718 .916 r
.37022 .4439 .37117 .4449 .37272 .44455 .37177 .44355 Mtetra
.37177 .44355 .37272 .44455 .37427 .4442 .37332 .4432 Mtetra
.64 .725 .91 r
.37332 .4432 .37427 .4442 .37582 .44376 .37488 .44277 Mtetra
.659 .735 .906 r
.37488 .44277 .37582 .44376 .37738 .44323 .37644 .44227 Mtetra
.671 .744 .905 r
.37644 .44227 .37738 .44323 .37895 .44265 .378 .44172 Mtetra
.707 .759 .893 r
.378 .44172 .37895 .44265 .38053 .44179 .37957 .44101 Mtetra
.718 .792 .91 r
.37957 .44101 .38053 .44179 .3821 .44091 .38114 .44026 Mtetra
.675 .816 .951 r
.38114 .44026 .3821 .44091 .38367 .44039 .38271 .43968 Mtetra
.416 .709 .983 r
.38271 .43968 .38367 .44039 .38517 .44121 .38425 .43971 Mtetra
.289 .461 .857 r
.38425 .43971 .38517 .44121 .38658 .44445 .38577 .4404 Mtetra
.438 .359 .671 r
.38577 .4404 .38658 .44445 .38017 .63465 .38727 .44148 Mtetra
.55 .335 .541 r
.38727 .44148 .38017 .63465 .38155 .6409 .38881 .44154 Mtetra
.552 .336 .541 r
.38881 .44154 .38155 .6409 .38321 .64027 .3904 .4406 Mtetra
.551 .336 .541 r
.3904 .4406 .38321 .64027 .3849 .63922 .39197 .44021 Mtetra
.542 .329 .54 r
.39197 .44021 .3849 .63922 .38647 .64113 .39336 .44406 Mtetra
0 0 .298 r
.39336 .44406 .38647 .64113 .38802 .64371 .38716 .63908 Mtetra
0 0 .48 r
.38716 .63908 .38802 .64371 .38961 .6452 .38863 .64363 Mtetra
.114 .359 .823 r
.38863 .64363 .38961 .6452 .39125 .64556 .39024 .64471 Mtetra
.603 .762 .955 r
.39024 .64471 .39125 .64556 .39291 .64518 .39191 .64436 Mtetra
.709 .796 .919 r
.39191 .64436 .39291 .64518 .39459 .64456 .39359 .6436 Mtetra
.678 .759 .912 r
.39359 .6436 .39459 .64456 .39627 .64414 .39527 .64298 Mtetra
.629 .704 .9 r
.39527 .64298 .39627 .64414 .39793 .64385 .39694 .64257 Mtetra
.665 .696 .869 r
.39694 .64257 .39793 .64385 .39962 .6432 .39863 .64199 Mtetra
.752 .731 .833 r
.39863 .64199 .39962 .6432 .40134 .64129 .40033 .64083 Mtetra
.87 .863 .83 r
.40033 .64083 .40134 .64129 .40316 .63687 .40206 .63895 Mtetra
0 0 0 r
.40206 .63895 .40316 .63687 .41139 .44758 .4038 .63662 Mtetra
.546 .327 .534 r
.4038 .63662 .41139 .44758 .41333 .43675 .40553 .63473 Mtetra
.548 .329 .535 r
.40553 .63473 .41333 .43675 .41493 .43573 .40721 .63405 Mtetra
.549 .33 .535 r
.40721 .63405 .41493 .43573 .4165 .43582 .40889 .63382 Mtetra
.40889 .63382 .4165 .43582 .41807 .43591 .41056 .63354 Mtetra
.548 .329 .535 r
.41056 .63354 .41807 .43591 .41966 .43536 .41225 .63304 Mtetra
.41225 .63304 .41966 .43536 .42124 .43484 .41393 .63254 Mtetra
.41393 .63254 .42124 .43484 .42285 .4338 .41562 .63186 Mtetra
.41562 .63186 .42285 .4338 .42446 .43257 .41732 .63106 Mtetra
.549 .33 .535 r
.41732 .63106 .42446 .43257 .42604 .43239 .419 .63068 Mtetra
.551 .331 .535 r
.419 .63068 .42604 .43239 .42744 .43839 .42065 .63144 Mtetra
.552 .332 .535 r
.42065 .63144 .42744 .43839 .42338 .63029 .42229 .63282 Mtetra
.611 .258 .347 r
.42229 .63282 .42338 .63029 .42495 .63408 .42394 .63376 Mtetra
.02 .569 .831 r
.42394 .63376 .42495 .63408 .42659 .63522 .42561 .63401 Mtetra
.627 .697 .895 r
.42561 .63401 .42659 .63522 .42828 .63491 .4273 .63361 Mtetra
.664 .694 .868 r
.4273 .63361 .42828 .63491 .42998 .63423 .429 .63303 Mtetra
.664 .711 .883 r
.429 .63303 .42998 .63423 .43169 .63353 .4307 .63246 Mtetra
.639 .728 .913 r
.4307 .63246 .43169 .63353 .43338 .63302 .4324 .632 Mtetra
.639 .738 .921 r
.4324 .632 .43338 .63302 .43508 .63251 .4341 .63154 Mtetra
.597 .735 .941 r
.4341 .63154 .43508 .63251 .43678 .63209 .43579 .63122 Mtetra
.548 .741 .966 r
.43579 .63122 .43678 .63209 .43848 .63176 .43749 .63102 Mtetra
.662 .808 .953 r
.43749 .63102 .43848 .63176 .44018 .63122 .43919 .63044 Mtetra
.842 .813 .822 r
.43919 .63044 .44018 .63122 .4419 .63004 .44093 .62865 Mtetra
.899 .726 .659 r
.44093 .62865 .4419 .63004 .44365 .62767 .44274 .62367 Mtetra
.952 .686 .494 r
.44274 .62367 .44365 .62767 .44542 .62428 .44901 .42745 Mtetra
.563 .345 .543 r
.44901 .42745 .44542 .62428 .44719 .62098 .45076 .42088 Mtetra
.552 .336 .541 r
.45076 .42088 .44719 .62098 .44888 .62094 .45237 .42009 Mtetra
.55 .335 .541 r
.45237 .42009 .44888 .62094 .45058 .62062 .45397 .41992 Mtetra
.552 .336 .541 r
.45397 .41992 .45058 .62062 .45238 .61553 .45559 .41903 Mtetra
.554 .338 .542 r
.45559 .41903 .45238 .61553 .45808 .4214 .45723 .41685 Mtetra
.676 .51 .653 r
.45723 .41685 .45808 .4214 .45977 .41669 .45887 .41503 Mtetra
.739 .665 .778 r
.45887 .41503 .45977 .41669 .46141 .41449 .46049 .41378 Mtetra
.682 .81 .943 r
.46049 .41378 .46141 .41449 .46303 .41375 .4621 .41316 Mtetra
.617 .825 .98 r
.4621 .41316 .46303 .41375 .46464 .41337 .46371 .41271 Mtetra
.616 .808 .974 r
.46371 .41271 .46464 .41337 .46624 .41305 .46532 .41229 Mtetra
.661 .794 .946 r
.46532 .41229 .46624 .41305 .46786 .41252 .46694 .41175 Mtetra
.658 .791 .946 r
.46694 .41175 .46786 .41252 .46947 .41201 .46855 .41122 Mtetra
.646 .783 .947 r
.46855 .41122 .46947 .41201 .47108 .41156 .47017 .41074 Mtetra
.626 .768 .948 r
.47017 .41074 .47108 .41156 .4727 .41121 .47178 .41033 Mtetra
.633 .756 .937 r
.47178 .41033 .4727 .41121 .47431 .41084 .4734 .4099 Mtetra
.657 .75 .919 r
.4734 .4099 .47431 .41084 .47593 .41038 .47502 .40939 Mtetra
.692 .751 .897 r
.47502 .40939 .47593 .41038 .47755 .40972 .47664 .40872 Mtetra
.697 .751 .893 r
.47664 .40872 .47755 .40972 .47917 .40902 .47826 .40803 Mtetra
.691 .75 .897 r
.47826 .40803 .47917 .40902 .48079 .40836 .47988 .40737 Mtetra
.671 .745 .906 r
.47988 .40737 .48079 .40836 .48242 .4078 .48151 .4068 Mtetra
.665 .74 .906 r
.48151 .4068 .48242 .4078 .48404 .40727 .48313 .40625 Mtetra
.662 .736 .905 r
.48313 .40625 .48404 .40727 .48566 .40675 .48475 .40572 Mtetra
.663 .734 .902 r
.48475 .40572 .48566 .40675 .48729 .40622 .48638 .40518 Mtetra
.663 .731 .9 r
.48638 .40518 .48729 .40622 .48891 .4057 .48801 .40464 Mtetra
.664 .729 .898 r
.48801 .40464 .48891 .4057 .49054 .40516 .48963 .4041 Mtetra
.667 .728 .895 r
.48963 .4041 .49054 .40516 .49217 .40462 .49126 .40354 Mtetra
.667 .726 .894 r
.49126 .40354 .49217 .40462 .49379 .40406 .49289 .40298 Mtetra
.681 .73 .887 r
.49289 .40298 .49379 .40406 .49542 .40347 .49452 .40236 Mtetra
.719 .735 .864 r
.49452 .40236 .49542 .40347 .49706 .40274 .49615 .40152 Mtetra
.661 .697 .873 r
.49615 .40152 .49706 .40274 .49869 .40218 .49779 .40097 Mtetra
.435 .6 .914 r
.49779 .40097 .49869 .40218 .50032 .40206 .49941 .40121 Mtetra
.832 .374 0 r
.49941 .40121 .50032 .40206 .50194 .40311 .50102 .40418 Mtetra
.959 .682 .466 r
.50102 .40418 .50194 .40311 .50356 .40512 .50133 .59702 Mtetra
.566 .344 .537 r
.50133 .59702 .50356 .40512 .50517 .40829 .50299 .60696 Mtetra
.55 .331 .535 r
.50299 .60696 .50517 .40829 .50681 .4087 .50473 .60721 Mtetra
.548 .329 .535 r
.50473 .60721 .50681 .4087 .50845 .40758 .50648 .6064 Mtetra
.547 .328 .535 r
.50648 .6064 .50845 .40758 .5101 .40608 .50823 .60515 Mtetra
.548 .329 .535 r
.50823 .60515 .5101 .40608 .51174 .40542 .50997 .60458 Mtetra
.50997 .60458 .51174 .40542 .51339 .40476 .51172 .60399 Mtetra
.51172 .60399 .51339 .40476 .51503 .40413 .51347 .60341 Mtetra
.51347 .60341 .51503 .40413 .51668 .40353 .51521 .60286 Mtetra
.51521 .60286 .51668 .40353 .51832 .40295 .51696 .60232 Mtetra
.51696 .60232 .51832 .40295 .51997 .40238 .51871 .60179 Mtetra
.51871 .60179 .51997 .40238 .52162 .40182 .52047 .60126 Mtetra
.52047 .60126 .52162 .40182 .52327 .40128 .52222 .60075 Mtetra
.548 .33 .535 r
.52222 .60075 .52327 .40128 .52492 .40075 .52397 .60024 Mtetra
.52397 .60024 .52492 .40075 .52657 .40023 .52573 .59974 Mtetra
.52573 .59974 .52657 .40023 .52823 .39972 .52748 .59926 Mtetra
.52748 .59926 .52823 .39972 .52988 .39924 .52924 .59878 Mtetra
.549 .33 .535 r
.52924 .59878 .52988 .39924 .53153 .39879 .531 .59834 Mtetra
.531 .59834 .53153 .39879 .53319 .39836 .53276 .59789 Mtetra
.53276 .59789 .53319 .39836 .53485 .39799 .53452 .59749 Mtetra
.55 .331 .535 r
.53452 .59749 .53485 .39799 .53651 .39853 .53629 .59776 Mtetra
.549 .33 .535 r
.53629 .59776 .53651 .39853 .53817 .39832 .53805 .59738 Mtetra
.546 .328 .534 r
.53805 .59738 .53817 .39832 .53982 .39635 .53981 .59566 Mtetra
0 0 .37 r
.53981 .59566 .53982 .39635 .54147 .39198 .54063 .40221 Mtetra
0 0 .194 r
.54063 .40221 .54147 .39198 .54311 .38909 .54223 .38956 Mtetra
.972 .928 .661 r
.54223 .38956 .54311 .38909 .54476 .38711 .54388 .38607 Mtetra
.741 .758 .866 r
.54388 .38607 .54476 .38711 .54642 .38634 .54554 .3851 Mtetra
.644 .691 .879 r
.54554 .3851 .54642 .38634 .54808 .38586 .5472 .38463 Mtetra
.583 .668 .897 r
.5472 .38463 .54808 .38586 .54975 .38551 .54886 .38441 Mtetra
.659 .723 .896 r
.54886 .38441 .54975 .38551 .55141 .38498 .55053 .38388 Mtetra
.658 .723 .897 r
.55053 .38388 .55141 .38498 .55307 .38445 .55219 .38335 Mtetra
.658 .724 .898 r
.55219 .38335 .55307 .38445 .55474 .3839 .55386 .38282 Mtetra
.662 .728 .898 r
.55386 .38282 .55474 .3839 .5564 .38335 .55552 .38227 Mtetra
.663 .73 .9 r
.55552 .38227 .5564 .38335 .55807 .38279 .55719 .38172 Mtetra
.662 .732 .901 r
.55719 .38172 .55807 .38279 .55974 .38223 .55886 .38117 Mtetra
.663 .735 .903 r
.55886 .38117 .55974 .38223 .56141 .38166 .56053 .38062 Mtetra
.66 .736 .906 r
.56053 .38062 .56141 .38166 .56308 .38111 .5622 .38008 Mtetra
.653 .736 .91 r
.5622 .38008 .56308 .38111 .56475 .38059 .56387 .37957 Mtetra
.63 .729 .919 r
.56387 .37957 .56475 .38059 .56642 .38018 .56555 .37915 Mtetra
.625 .726 .92 r
.56555 .37915 .56642 .38018 .5681 .3798 .56722 .37875 Mtetra
.628 .725 .917 r
.56722 .37875 .5681 .3798 .56978 .37939 .5689 .37834 Mtetra
.649 .731 .909 r
.5689 .37834 .56978 .37939 .57145 .37889 .57058 .37785 Mtetra
.662 .737 .906 r
.57058 .37785 .57145 .37889 .57313 .37833 .57225 .3773 Mtetra
.673 .745 .904 r
.57225 .3773 .57313 .37833 .5748 .3777 .57393 .3767 Mtetra
.693 .757 .901 r
.57393 .3767 .5748 .3777 .57648 .37695 .57561 .37601 Mtetra
.698 .771 .908 r
.57561 .37601 .57648 .37695 .57816 .37618 .57729 .3753 Mtetra
.696 .783 .918 r
.57729 .3753 .57816 .37618 .57983 .37544 .57896 .3746 Mtetra
.706 .796 .92 r
.57896 .3746 .57983 .37544 .58151 .37455 .58064 .37385 Mtetra
.675 .823 .954 r
.58064 .37385 .58151 .37455 .58319 .37389 .58232 .37323 Mtetra
.603 .811 .98 r
.58232 .37323 .58319 .37389 .58488 .37365 .58401 .37281 Mtetra
.286 .611 .955 r
.58401 .37281 .58488 .37365 .5866 .37524 .58571 .37315 Mtetra
.378 .438 .797 r
.58571 .37315 .5866 .37524 .58839 .37983 .58743 .37396 Mtetra
.482 .359 .635 r
.58743 .37396 .58839 .37983 .59409 .5763 .58915 .3751 Mtetra
.551 .336 .541 r
.58915 .3751 .59409 .5763 .59593 .57779 .59084 .37445 Mtetra
.552 .336 .541 r
.59084 .37445 .59593 .57779 .59772 .5769 .59252 .3736 Mtetra
.55 .335 .541 r
.59252 .3736 .59772 .5769 .59951 .57607 .59422 .37355 Mtetra
.527 .317 .538 r
.59422 .37355 .59951 .57607 .6014 .57911 .59621 .38604 Mtetra
0 0 .392 r
.59621 .38604 .6014 .57911 .60326 .58132 .60229 .57807 Mtetra
0 .08 .611 r
.60229 .57807 .60326 .58132 .60511 .58257 .60419 .58137 Mtetra
.354 .577 .925 r
.60419 .58137 .60511 .58257 .60693 .58267 .60602 .58179 Mtetra
.604 .77 .96 r
.60602 .58179 .60693 .58267 .60875 .58233 .60783 .58139 Mtetra
.695 .788 .922 r
.60783 .58139 .60875 .58233 .61056 .58176 .60964 .58065 Mtetra
.654 .737 .911 r
.60964 .58065 .61056 .58176 .61238 .58137 .61145 .58009 Mtetra
.667 .711 .881 r
.61145 .58009 .61238 .58137 .61419 .58081 .61327 .57946 Mtetra
.702 .714 .858 r
.61327 .57946 .61419 .58081 .61599 .5798 .61507 .57862 Mtetra
.795 .764 .825 r
.61507 .57862 .61599 .5798 .61775 .57706 .61686 .57709 Mtetra
.888 .982 .818 r
.61686 .57709 .61775 .57706 .61942 .57146 .61864 .57506 Mtetra
.207 0 .257 r
.61864 .57506 .61942 .57146 .61564 .3738 .6204 .57269 Mtetra
.548 .329 .535 r
.6204 .57269 .61564 .3738 .61726 .37015 .62222 .57203 Mtetra
.549 .33 .535 r
.62222 .57203 .61726 .37015 .61897 .3699 .62405 .57184 Mtetra
.548 .329 .535 r
.62405 .57184 .61897 .3699 .6207 .36978 .62585 .57089 Mtetra
.535 .319 .533 r
.62585 .57089 .6207 .36978 .62231 .36597 .62742 .56205 Mtetra
0 0 .39 r
.62742 .56205 .62231 .36597 .62393 .36279 .62316 .36419 Mtetra
.869 .874 .434 r
.62316 .36419 .62393 .36279 .62559 .36061 .62475 .35986 Mtetra
.818 .84 .865 r
.62475 .35986 .62559 .36061 .62729 .35965 .62643 .35846 Mtetra
.64 .705 .893 r
.62643 .35846 .62729 .35965 .629 .35922 .62815 .358 Mtetra
.556 .662 .907 r
.62815 .358 .629 .35922 .63073 .35897 .62987 .35787 Mtetra
.618 .712 .913 r
.62987 .35787 .63073 .35897 .63244 .35854 .63159 .35749 Mtetra
.657 .74 .911 r
.63159 .35749 .63244 .35854 .63416 .35797 .63331 .35695 Mtetra
.669 .751 .912 r
.63331 .35695 .63416 .35797 .63587 .35734 .63502 .35636 Mtetra
.715 .773 .898 r
.63502 .35636 .63587 .35734 .63757 .35636 .63673 .35555 Mtetra
.72 .811 .922 r
.63673 .35555 .63757 .35636 .63927 .35544 .63844 .35473 Mtetra
.673 .825 .957 r
.63844 .35473 .63927 .35544 .64099 .35489 .64015 .35409 Mtetra
.539 .753 .975 r
.64015 .35409 .64099 .35489 .64276 .35568 .64189 .35388 Mtetra
.473 .529 .834 r
.64189 .35388 .64276 .35568 .64461 .3585 .64364 .35422 Mtetra
.442 .364 .673 r
.64364 .35422 .64461 .3585 .65369 .55069 .64543 .35546 Mtetra
.538 .326 .54 r
.64543 .35546 .65369 .55069 .656 .56248 .64743 .3621 Mtetra
.001 0 .412 r
.64743 .3621 .656 .56248 .65795 .56492 .65693 .56068 Mtetra
.076 .125 .611 r
.65693 .56068 .65795 .56492 .65986 .5659 .65895 .56446 Mtetra
.361 .534 .891 r
.65895 .56446 .65986 .5659 .66172 .56578 .66083 .56501 Mtetra
.664 .82 .959 r
.66083 .56501 .66172 .56578 .66356 .56507 .66268 .56437 Mtetra
.754 .86 .928 r
.66268 .56437 .66356 .56507 .66539 .56413 .6645 .56332 Mtetra
.653 .81 .959 r
.6645 .56332 .66539 .56413 .66724 .56373 .66635 .56272 Mtetra
.597 .742 .946 r
.66635 .56272 .66724 .56373 .6691 .5635 .66821 .56237 Mtetra
.65 .737 .913 r
.66821 .56237 .6691 .5635 .67095 .56284 .67006 .56182 Mtetra
.742 .787 .889 r
.67006 .56182 .67095 .56284 .67272 .56063 .67189 .56079 Mtetra
.799 .999 .815 r
.67189 .56079 .67272 .56063 .67437 .55539 .67369 .55907 Mtetra
.13 0 .241 r
.67369 .55907 .67437 .55539 .6673 .35582 .67543 .55609 Mtetra
.521 .308 .532 r
.67543 .55609 .6673 .35582 .66876 .349 .67654 .53893 Mtetra
.002 0 .407 r
.67654 .53893 .66876 .349 .67039 .34608 .66967 .34765 Mtetra
.715 .796 .321 r
.66967 .34765 .67039 .34608 .67206 .34421 .67126 .34378 Mtetra
.865 .917 .863 r
.67126 .34378 .67206 .34421 .67377 .34304 .67295 .34213 Mtetra
.674 .778 .928 r
.67295 .34213 .67377 .34304 .67551 .3424 .67468 .3415 Mtetra
.532 .726 .963 r
.67468 .3415 .67551 .3424 .67727 .34225 .67644 .34135 Mtetra
.459 .691 .967 r
.67644 .34135 .67727 .34225 .67907 .34304 .67821 .34138 Mtetra
.47 .547 .853 r
.67821 .34138 .67907 .34304 .68096 .34548 .68 .34169 Mtetra
.448 .383 .692 r
.68 .34169 .68096 .34548 .68327 .35614 .68182 .34275 Mtetra
.411 .265 .571 r
.68182 .34275 .68327 .35614 .69483 .55029 .68384 .34746 Mtetra
.023 0 .425 r
.68384 .34746 .69483 .55029 .69687 .55325 .69579 .54809 Mtetra
.096 .116 .59 r
.69579 .54809 .69687 .55325 .69883 .55445 .69792 .55267 Mtetra
.303 .447 .84 r
.69792 .55267 .69883 .55445 .70073 .55454 .69986 .55361 Mtetra
.63 .777 .951 r
.69986 .55361 .70073 .55454 .7026 .55395 .70174 .55311 Mtetra
.728 .828 .927 r
.70174 .55311 .7026 .55395 .70446 .55312 .70359 .55219 Mtetra
.601 .762 .956 r
.70359 .55219 .70446 .55312 .70635 .55285 .70547 .55179 Mtetra
.509 .692 .951 r
.70547 .55179 .70635 .55285 .70825 .55286 .70738 .55173 Mtetra
.672 .749 .908 r
.70738 .55173 .70825 .55286 .71013 .55226 .70925 .55107 Mtetra
.897 .781 .726 r
.70925 .55107 .71013 .55226 .71187 .54923 .71098 .54795 Mtetra
.976 .685 .4 r
.71098 .54795 .71187 .54923 .71241 .52484 .70201 .35279 Mtetra
.585 .362 .543 r
.70201 .35279 .71241 .52484 .70363 .33625 .70281 .3351 Mtetra
.884 .778 .74 r
.70281 .3351 .70363 .33625 .70527 .33352 .70445 .33243 Mtetra
.672 .742 .903 r
.70445 .33243 .70527 .33352 .70702 .33289 .7062 .33181 Mtetra
.53 .681 .935 r
.7062 .33181 .70702 .33289 .70881 .33282 .70799 .33172 Mtetra
.583 .704 .926 r
.70799 .33172 .70881 .33282 .71059 .33247 .70977 .33146 Mtetra
.68 .762 .913 r
.70977 .33146 .71059 .33247 .71234 .3317 .71153 .3308 Mtetra
.649 .778 .942 r
.71153 .3308 .71234 .3317 .71411 .33122 .7133 .33027 Mtetra
.573 .732 .95 r
.7133 .33027 .71411 .33122 .71594 .33177 .71508 .33 Mtetra
.506 .554 .839 r
.71508 .33 .71594 .33177 .7179 .33444 .71689 .33019 Mtetra
.472 .386 .678 r
.71689 .33019 .7179 .33444 .73149 .52547 .71876 .33118 Mtetra
.541 .329 .541 r
.71876 .33118 .73149 .52547 .73428 .53943 .72086 .3359 Mtetra
.045 0 .437 r
.72086 .3359 .73428 .53943 .73637 .54202 .73524 .5367 Mtetra
.141 .145 .602 r
.73524 .5367 .73637 .54202 .73837 .54314 .73745 .54118 Mtetra
.255 .395 .811 r
.73745 .54118 .73837 .54314 .74032 .5435 .73946 .54242 Mtetra
.573 .722 .943 r
.73946 .54242 .74032 .5435 .74224 .54328 .74138 .54216 Mtetra
.707 .765 .897 r
.74138 .54216 .74224 .54328 .74412 .54249 .74326 .5413 Mtetra
.758 .769 .862 r
.74326 .5413 .74412 .54249 .74594 .54066 .74512 .5401 Mtetra
.83 .909 .892 r
.74512 .5401 .74594 .54066 .74762 .53683 .74696 .53859 Mtetra
0 0 0 r
.74696 .53859 .74762 .53683 .74877 .52496 .74874 .53621 Mtetra
.327 .123 .443 r
.74874 .53621 .74877 .52496 .73745 .32848 .75029 .53041 Mtetra
.043 0 .431 r
.75029 .53041 .73745 .32848 .73901 .32475 .7385 .3279 Mtetra
0 0 .029 r
.7385 .3279 .73901 .32475 .74069 .3226 .73994 .3224 Mtetra
.92 .954 .795 r
.73994 .3224 .74069 .3226 .74242 .32136 .74161 .3202 Mtetra
.678 .733 .891 r
.74161 .3202 .74242 .32136 .7442 .3208 .74339 .31953 Mtetra
.59 .674 .898 r
.74339 .31953 .7442 .3208 .746 .32047 .7452 .31927 Mtetra
.614 .699 .904 r
.7452 .31927 .746 .32047 .74779 .31991 .74699 .3189 Mtetra
.708 .773 .903 r
.74699 .3189 .74779 .31991 .74955 .31895 .74877 .31809 Mtetra
.681 .801 .939 r
.74877 .31809 .74955 .31895 .75133 .31828 .75055 .31742 Mtetra
.589 .766 .964 r
.75055 .31742 .75133 .31828 .75317 .31848 .75235 .31707 Mtetra
.478 .591 .888 r
.75235 .31707 .75317 .31848 .75516 .32068 .7542 .31727 Mtetra
.45 .4 .711 r
.7542 .31727 .75516 .32068 .75766 .32958 .7561 .31823 Mtetra
.427 .285 .585 r
.7561 .31823 .75766 .32958 .77419 .52695 .75822 .32199 Mtetra
.065 0 .448 r
.75822 .32199 .77419 .52695 .77638 .53001 .77515 .52381 Mtetra
.151 .139 .589 r
.77515 .52381 .77638 .53001 .77843 .53128 .77751 .52908 Mtetra
.23 .351 .781 r
.77751 .52908 .77843 .53128 .78043 .53172 .77959 .53063 Mtetra
.55 .709 .945 r
.77959 .53063 .78043 .53172 .78239 .53156 .78154 .53044 Mtetra
.694 .763 .905 r
.78154 .53044 .78239 .53156 .7843 .53084 .78345 .52964 Mtetra
.771 .775 .856 r
.78345 .52964 .7843 .53084 .78614 .52913 .78532 .52834 Mtetra
.857 .864 .845 r
.78532 .52834 .78614 .52913 .78781 .52522 .78715 .52651 Mtetra
0 0 0 r
.78715 .52651 .78781 .52522 .78897 .515 .78895 .52425 Mtetra
.467 .221 .457 r
.78895 .52425 .78897 .515 .77527 .31843 .79077 .52237 Mtetra
.549 .33 .535 r
.79077 .52237 .77527 .31843 .77704 .31748 .79274 .5222 Mtetra
.548 .33 .535 r
.79274 .5222 .77704 .31748 .77889 .31741 .79467 .52166 Mtetra
.545 .327 .535 r
.79467 .52166 .77889 .31741 .7806 .31557 .79641 .51875 Mtetra
.069 0 .445 r
.79641 .51875 .7806 .31557 .78213 .31157 .78182 .31634 Mtetra
0 0 .169 r
.78182 .31634 .78213 .31157 .78376 .30886 .78306 .30877 Mtetra
.956 .945 .716 r
.78306 .30877 .78376 .30886 .78547 .30713 .78468 .30594 Mtetra
.719 .747 .874 r
.78468 .30594 .78547 .30713 .78727 .30636 .78647 .30504 Mtetra
.634 .687 .883 r
.78647 .30504 .78727 .30636 .78909 .30585 .78829 .30458 Mtetra
.607 .684 .897 r
.78829 .30458 .78909 .30585 .79091 .30541 .79012 .30424 Mtetra
.661 .728 .899 r
.79012 .30424 .79091 .30541 .79272 .30482 .79193 .30365 Mtetra
.659 .727 .899 r
.79193 .30365 .79272 .30482 .79453 .30424 .79375 .30306 Mtetra
.658 .727 .9 r
.79375 .30306 .79453 .30424 .79635 .30366 .79557 .30248 Mtetra
.659 .727 .9 r
.79557 .30248 .79635 .30366 .79817 .30307 .79738 .3019 Mtetra
.658 .726 .899 r
.79738 .3019 .79817 .30307 .79998 .3025 .7992 .30132 Mtetra
.657 .725 .9 r
.7992 .30132 .79998 .3025 .8018 .30193 .80102 .30074 Mtetra
.654 .723 .9 r
.80102 .30074 .8018 .30193 .80363 .30137 .80284 .30018 Mtetra
.652 .721 .9 r
.80284 .30018 .80363 .30137 .80545 .30083 .80467 .29963 Mtetra
.65 .72 .9 r
.80467 .29963 .80545 .30083 .80728 .30029 .8065 .29909 Mtetra
.648 .719 .9 r
.8065 .29909 .80728 .30029 .80911 .29974 .80833 .29856 Mtetra
.644 .719 .903 r
.80833 .29856 .80911 .29974 .81094 .29922 .81016 .29804 Mtetra
.635 .717 .907 r
.81016 .29804 .81094 .29922 .81277 .29875 .81199 .29757 Mtetra
.615 .708 .912 r
.81199 .29757 .81277 .29875 .81462 .29837 .81384 .29718 Mtetra
.615 .706 .909 r
.81384 .29718 .81462 .29837 .81647 .298 .81569 .29679 Mtetra
.628 .708 .904 r
.81569 .29679 .81647 .298 .81831 .29757 .81753 .29635 Mtetra
.661 .721 .893 r
.81753 .29635 .81831 .29757 .82014 .29695 .81936 .29575 Mtetra
.673 .73 .893 r
.81936 .29575 .82014 .29695 .82196 .29627 .82119 .29509 Mtetra
.695 .744 .888 r
.82119 .29509 .82196 .29627 .82378 .29547 .82301 .29432 Mtetra
.762 .772 .861 r
.82301 .29432 .82378 .29547 .82555 .29429 .82479 .29315 Mtetra
.689 .748 .897 r
.82479 .29315 .82555 .29429 .82737 .29355 .82661 .29242 Mtetra
.406 .61 .932 r
.82661 .29242 .82737 .29355 .8293 .29385 .82853 .29272 Mtetra
.826 .419 0 r
.82853 .29272 .8293 .29385 .83178 .29985 .83102 .29872 Mtetra
.973 .661 .312 r
.83102 .29872 .83178 .29985 .85396 .50484 .85316 .50377 Mtetra
.692 .249 0 r
.85316 .50377 .85396 .50484 .85639 .50887 .85558 .5078 Mtetra
.343 .604 .945 r
.85558 .5078 .85639 .50887 .85846 .50927 .85766 .5082 Mtetra
.669 .772 .927 r
.85766 .5082 .85846 .50927 .86043 .50859 .85963 .50752 Mtetra
.849 .822 .822 r
.85963 .50752 .86043 .50859 .86227 .50665 .86147 .50558 Mtetra
.977 .78 .572 r
.86147 .50558 .86227 .50665 .86363 .50004 .86283 .49897 Mtetra
.976 .67 .326 r
.86283 .49897 .86363 .50004 .84445 .29316 .84369 .29203 Mtetra
.966 .78 .602 r
.84369 .29203 .84445 .29316 .8458 .28776 .84504 .28663 Mtetra
.762 .778 .866 r
.84504 .28663 .8458 .28776 .84759 .28659 .84683 .28546 Mtetra
.633 .728 .916 r
.84683 .28546 .84759 .28659 .84945 .28612 .8487 .28498 Mtetra
.557 .692 .93 r
.8487 .28498 .84945 .28612 .85135 .28594 .85059 .2848 Mtetra
.753 .775 .871 r
.85059 .2848 .85135 .28594 .85314 .28483 .85239 .2837 Mtetra
.685 .75 .9 r
.85239 .2837 .85314 .28483 .85498 .28412 .85423 .28298 Mtetra
.485 .653 .934 r
.85423 .28298 .85498 .28412 .85691 .28419 .85616 .28304 Mtetra
.735 .317 0 r
.85616 .28304 .85691 .28419 .85935 .28901 .85859 .28782 Mtetra
.971 .656 .295 r
.85859 .28782 .85935 .28901 .88353 .49494 .88274 .4938 Mtetra
.734 .308 0 r
.88274 .4938 .88353 .49494 .88612 .49981 .88533 .4987 Mtetra
.424 .643 .949 r
.88533 .4987 .88612 .49981 .88821 .50017 .88741 .49891 Mtetra
.666 .735 .901 r
.88741 .49891 .88821 .50017 .8902 .49952 .8894 .49823 Mtetra
.763 .768 .857 r
.8894 .49823 .8902 .49952 .8921 .498 .89132 .49695 Mtetra
.433 .692 .974 r
.25072 .68371 .25178 .68455 .25341 .68351 .25227 .68376 Mtetra
0 0 0 r
.25227 .68376 .25341 .68351 .25509 .68191 .25385 .68343 Mtetra
.046 0 0 r
.25385 .68343 .25509 .68191 .25685 .67917 .25548 .68238 Mtetra
.831 .851 .392 r
.25548 .68238 .25685 .67917 .27153 .50665 .25745 .67696 Mtetra
0 0 .09 r
.25745 .67696 .27153 .50665 .27511 .47885 .27394 .48044 Mtetra
.993 .872 .597 r
.27394 .48044 .27511 .47885 .27684 .47538 .27585 .47451 Mtetra
.779 .767 .842 r
.27585 .47451 .27684 .47538 .27838 .47441 .27741 .47333 Mtetra
.639 .704 .893 r
.27741 .47333 .27838 .47441 .27988 .47399 .27891 .47293 Mtetra
.52 .664 .926 r
.27891 .47293 .27988 .47399 .28136 .47384 .28038 .4729 Mtetra
.74 .753 .863 r
.28038 .4729 .28136 .47384 .2829 .47288 .28191 .472 Mtetra
.694 .758 .901 r
.28191 .472 .2829 .47288 .28442 .47223 .28343 .47137 Mtetra
.476 .694 .963 r
.28343 .47137 .28442 .47223 .28589 .47228 .2849 .47138 Mtetra
.919 .526 .218 r
.2849 .47138 .28589 .47228 .28703 .47684 .28611 .47504 Mtetra
.941 .684 .521 r
.28611 .47504 .28703 .47684 .27445 .67309 .27356 .66991 Mtetra
.877 .567 .053 r
.27356 .66991 .27445 .67309 .27568 .67783 .27471 .6758 Mtetra
.402 .463 .809 r
.27471 .6758 .27568 .67783 .27723 .67804 .27623 .6764 Mtetra
.618 .62 .831 r
.27623 .6764 .27723 .67804 .27885 .67733 .27783 .67606 Mtetra
.698 .699 .847 r
.27783 .67606 .27885 .67733 .2805 .67623 .27945 .6753 Mtetra
.514 .706 .958 r
.27945 .6753 .2805 .67623 .28207 .67622 .28103 .67522 Mtetra
.618 .725 .923 r
.28103 .67522 .28207 .67622 .28366 .67602 .28263 .67486 Mtetra
.742 .728 .838 r
.28263 .67486 .28366 .67602 .2853 .67512 .28428 .67382 Mtetra
.883 .718 .672 r
.28428 .67382 .2853 .67512 .28722 .67006 .28617 .6692 Mtetra
.94 .687 .528 r
.28617 .6692 .28722 .67006 .30216 .47226 .30105 .47327 Mtetra
.982 .817 .602 r
.30105 .47327 .30216 .47226 .30407 .46602 .30303 .4661 Mtetra
.876 .953 .855 r
.30303 .4661 .30407 .46602 .30564 .46472 .30462 .46445 Mtetra
.671 .908 .977 r
.30462 .46445 .30564 .46472 .30715 .46441 .30615 .46379 Mtetra
.557 .789 .986 r
.30615 .46379 .30715 .46441 .30863 .46453 .30766 .46353 Mtetra
.638 .721 .908 r
.30766 .46353 .30863 .46453 .31014 .46424 .30918 .46313 Mtetra
.638 .699 .89 r
.30918 .46313 .31014 .46424 .31166 .4638 .31069 .46273 Mtetra
.635 .705 .897 r
.31069 .46273 .31166 .4638 .31318 .4633 .31221 .46234 Mtetra
.658 .735 .906 r
.31221 .46234 .31318 .4633 .31472 .46255 .31373 .46185 Mtetra
.667 .797 .944 r
.31373 .46185 .31472 .46255 .31626 .46183 .31526 .46132 Mtetra
.662 .845 .97 r
.31526 .46132 .31626 .46183 .31779 .4613 .31679 .46077 Mtetra
.666 .84 .966 r
.31679 .46077 .31779 .4613 .31927 .46156 .31832 .46021 Mtetra
.666 .667 .842 r
.31832 .46021 .31927 .46156 .32072 .46235 .31986 .45965 Mtetra
.63 .533 .726 r
.31986 .45965 .32072 .46235 .32214 .46349 .32139 .45909 Mtetra
.629 .48 .661 r
.32139 .45909 .32214 .46349 .32367 .46301 .32294 .45819 Mtetra
.611 .46 .652 r
.32294 .45819 .32367 .46301 .32523 .46215 .32449 .45748 Mtetra
.572 .435 .656 r
.32449 .45748 .32523 .46215 .32674 .46201 .326 .45733 Mtetra
.208 .179 .604 r
.326 .45733 .32674 .46201 .32776 .47011 .32734 .46001 Mtetra
.957 .698 .502 r
.32734 .46001 .32776 .47011 .31792 .66117 .31727 .65385 Mtetra
0 0 .264 r
.31727 .65385 .31792 .66117 .31931 .66467 .31836 .66236 Mtetra
.319 .385 .774 r
.31836 .66236 .31931 .66467 .32088 .66517 .3199 .66335 Mtetra
.629 .607 .809 r
.3199 .66335 .32088 .66517 .32251 .66473 .32153 .66293 Mtetra
.696 .638 .787 r
.32153 .66293 .32251 .66473 .32416 .66397 .32319 .66201 Mtetra
.661 .608 .785 r
.32319 .66201 .32416 .66397 .32579 .66349 .32483 .66133 Mtetra
.637 .58 .774 r
.32483 .66133 .32579 .66349 .32741 .66313 .32647 .6608 Mtetra
.627 .563 .763 r
.32647 .6608 .32741 .66313 .32904 .66274 .3281 .66032 Mtetra
.6 .543 .762 r
.3281 .66032 .32904 .66274 .33068 .6622 .32972 .66004 Mtetra
.59 .556 .785 r
.32972 .66004 .33068 .6622 .33233 .66159 .33135 .65984 Mtetra
.594 .599 .827 r
.33135 .65984 .33233 .66159 .33397 .66096 .33297 .65962 Mtetra
.625 .668 .871 r
.33297 .65962 .33397 .66096 .33561 .66053 .3346 .65924 Mtetra
.644 .684 .873 r
.3346 .65924 .33561 .66053 .33724 .66012 .33624 .65878 Mtetra
.649 .676 .862 r
.33624 .65878 .33724 .66012 .33889 .65955 .33788 .65828 Mtetra
.644 .687 .875 r
.33788 .65828 .33889 .65955 .34057 .65829 .33952 .65782 Mtetra
.596 .849 .992 r
.33952 .65782 .34057 .65829 .34228 .65645 .34116 .65736 Mtetra
.167 0 0 r
.34116 .65736 .34228 .65645 .34402 .65425 .34281 .6569 Mtetra
.48 .132 .298 r
.34281 .6569 .34402 .65425 .34568 .65342 .34444 .65675 Mtetra
.483 .159 .341 r
.34444 .65675 .34568 .65342 .3473 .6533 .34607 .65649 Mtetra
.396 .072 .294 r
.34607 .65649 .3473 .6533 .34896 .65252 .34773 .65566 Mtetra
0 0 0 r
.34773 .65566 .34896 .65252 .3509 .64622 .34953 .6523 Mtetra
.956 .699 .507 r
.34953 .6523 .3509 .64622 .3622 .45138 .36052 .46489 Mtetra
0 0 .028 r
.36052 .46489 .3622 .45138 .36396 .44666 .36293 .44723 Mtetra
.909 .983 .75 r
.36293 .44723 .36396 .44666 .36557 .44499 .36458 .44496 Mtetra
.553 .92 .945 r
.36458 .44496 .36557 .44499 .36713 .4444 .36614 .44435 Mtetra
.184 .715 .833 r
.36614 .44435 .36713 .4444 .36867 .44417 .36767 .4442 Mtetra
.414 .861 .895 r
.36767 .4442 .36867 .44417 .37022 .4439 .36923 .44373 Mtetra
.677 .935 .967 r
.36923 .44373 .37022 .4439 .37177 .44355 .3708 .44299 Mtetra
.714 .844 .944 r
.3708 .44299 .37177 .44355 .37332 .4432 .37237 .44226 Mtetra
.683 .749 .901 r
.37237 .44226 .37332 .4432 .37488 .44277 .37393 .44165 Mtetra
.659 .707 .882 r
.37393 .44165 .37488 .44277 .37644 .44227 .37549 .44114 Mtetra
.652 .703 .884 r
.37549 .44114 .37644 .44227 .378 .44172 .37705 .44067 Mtetra
.657 .719 .895 r
.37705 .44067 .378 .44172 .37957 .44101 .37862 .44017 Mtetra
.662 .769 .929 r
.37862 .44017 .37957 .44101 .38114 .44026 .38018 .43966 Mtetra
.655 .827 .966 r
.38018 .43966 .38114 .44026 .38271 .43968 .38175 .43913 Mtetra
.656 .841 .971 r
.38175 .43913 .38271 .43968 .38425 .43971 .38331 .43859 Mtetra
.67 .71 .878 r
.38331 .43859 .38425 .43971 .38577 .4404 .38488 .43803 Mtetra
.636 .556 .748 r
.38488 .43803 .38577 .4404 .38727 .44148 .38645 .43747 Mtetra
.628 .488 .672 r
.38645 .43747 .38727 .44148 .38881 .44154 .38803 .43665 Mtetra
.616 .463 .651 r
.38803 .43665 .38881 .44154 .3904 .4406 .38961 .43583 Mtetra
.585 .443 .655 r
.38961 .43583 .3904 .4406 .39197 .44021 .39117 .4355 Mtetra
.394 .312 .645 r
.39117 .4355 .39197 .44021 .39336 .44406 .39266 .43711 Mtetra
.782 .573 .004 r
.39266 .43711 .39336 .44406 .38716 .63908 .39373 .44919 Mtetra
0 0 .289 r
.39373 .44919 .38716 .63908 .38863 .64363 .3877 .64074 Mtetra
.073 .178 .669 r
.3877 .64074 .38863 .64363 .39024 .64471 .38927 .6429 Mtetra
.552 .573 .829 r
.38927 .6429 .39024 .64471 .39191 .64436 .39092 .64288 Mtetra
.659 .664 .844 r
.39092 .64288 .39191 .64436 .39359 .6436 .3926 .64231 Mtetra
.67 .696 .865 r
.3926 .64231 .39359 .6436 .39527 .64298 .39428 .64169 Mtetra
.649 .69 .875 r
.39428 .64169 .39527 .64298 .39694 .64257 .39596 .6412 Mtetra
.657 .679 .859 r
.39596 .6412 .39694 .64257 .39863 .64199 .39764 .64065 Mtetra
.659 .685 .863 r
.39764 .64065 .39863 .64199 .40033 .64083 .39932 .64009 Mtetra
.654 .803 .955 r
.39932 .64009 .40033 .64083 .40206 .63895 .401 .63955 Mtetra
0 0 0 r
.401 .63955 .40206 .63895 .4038 .63662 .40268 .63901 Mtetra
.406 .047 .239 r
.40268 .63901 .4038 .63662 .40553 .63473 .40437 .63849 Mtetra
.467 .156 .353 r
.40437 .63849 .40553 .63473 .40721 .63405 .40605 .63801 Mtetra
.473 .165 .363 r
.40605 .63801 .40721 .63405 .40889 .63382 .40773 .63753 Mtetra
.466 .153 .35 r
.40773 .63753 .40889 .63382 .41056 .63354 .40942 .63705 Mtetra
.459 .141 .338 r
.40942 .63705 .41056 .63354 .41225 .63304 .4111 .63655 Mtetra
.4111 .63655 .41225 .63304 .41393 .63254 .41279 .63605 Mtetra
.458 .14 .338 r
.41279 .63605 .41393 .63254 .41562 .63186 .41448 .63554 Mtetra
.462 .148 .348 r
.41448 .63554 .41562 .63186 .41732 .63106 .41617 .63503 Mtetra
.469 .162 .362 r
.41617 .63503 .41732 .63106 .419 .63068 .41786 .63452 Mtetra
.469 .159 .357 r
.41786 .63452 .419 .63068 .42065 .63144 .41955 .63403 Mtetra
.429 .079 .268 r
.41955 .63403 .42065 .63144 .42229 .63282 .42124 .63357 Mtetra
.116 0 0 r
.42124 .63357 .42229 .63282 .42394 .63376 .42293 .63312 Mtetra
.613 .819 .979 r
.42293 .63312 .42394 .63376 .42561 .63401 .42463 .63267 Mtetra
.639 .679 .872 r
.42463 .63267 .42561 .63401 .4273 .63361 .42632 .63221 Mtetra
.647 .673 .861 r
.42632 .63221 .4273 .63361 .429 .63303 .42802 .63171 Mtetra
.668 .694 .865 r
.42802 .63171 .429 .63303 .4307 .63246 .42972 .63111 Mtetra
.689 .696 .851 r
.42972 .63111 .4307 .63246 .4324 .632 .43143 .63037 Mtetra
.681 .656 .818 r
.43143 .63037 .4324 .632 .4341 .63154 .43313 .62961 Mtetra
.627 .6 .803 r
.43313 .62961 .4341 .63154 .43579 .63122 .43483 .62918 Mtetra
.57 .56 .803 r
.43483 .62918 .43579 .63122 .43749 .63102 .43652 .62908 Mtetra
.65 .61 .796 r
.43652 .62908 .43749 .63102 .43919 .63044 .43823 .62848 Mtetra
.8 .671 .721 r
.43823 .62848 .43919 .63044 .44093 .62865 .43998 .62604 Mtetra
.916 .683 .571 r
.43998 .62604 .44093 .62865 .44274 .62367 .44201 .61207 Mtetra
.942 .676 .502 r
.44201 .61207 .44274 .62367 .44901 .42745 .44826 .41926 Mtetra
.669 .471 .608 r
.44826 .41926 .44901 .42745 .45076 .42088 .44992 .41608 Mtetra
.617 .465 .654 r
.44992 .41608 .45076 .42088 .45237 .42009 .45153 .41527 Mtetra
.581 .441 .655 r
.45153 .41527 .45237 .42009 .45397 .41992 .45314 .41498 Mtetra
.575 .434 .653 r
.45314 .41498 .45397 .41992 .45559 .41903 .45474 .41478 Mtetra
.601 .466 .669 r
.45474 .41478 .45559 .41903 .45723 .41685 .45634 .41428 Mtetra
.624 .54 .739 r
.45634 .41428 .45723 .41685 .45887 .41503 .45795 .41378 Mtetra
.652 .688 .87 r
.45795 .41378 .45887 .41503 .46049 .41378 .45956 .41329 Mtetra
.624 .854 .986 r
.45956 .41329 .46049 .41378 .4621 .41316 .46117 .41279 Mtetra
.604 .879 .992 r
.46117 .41279 .4621 .41316 .46371 .41271 .46279 .41227 Mtetra
.628 .869 .988 r
.46279 .41227 .46371 .41271 .46532 .41229 .4644 .41174 Mtetra
.655 .847 .974 r
.4644 .41174 .46532 .41229 .46694 .41175 .46601 .41117 Mtetra
.661 .841 .969 r
.46601 .41117 .46694 .41175 .46855 .41122 .46763 .4106 Mtetra
.667 .83 .962 r
.46763 .4106 .46855 .41122 .47017 .41074 .46925 .41001 Mtetra
.674 .806 .946 r
.46925 .41001 .47017 .41074 .47178 .41033 .47087 .40942 Mtetra
.668 .762 .921 r
.47087 .40942 .47178 .41033 .4734 .4099 .47249 .40887 Mtetra
.646 .727 .908 r
.47249 .40887 .4734 .4099 .47502 .40939 .4741 .4084 Mtetra
.602 .722 .929 r
.4741 .4084 .47502 .40939 .47664 .40872 .47572 .4081 Mtetra
.554 .795 .989 r
.47572 .4081 .47664 .40872 .47826 .40803 .47734 .40781 Mtetra
.45 .853 .971 r
.47734 .40781 .47826 .40803 .47988 .40737 .47896 .40746 Mtetra
.387 .848 .849 r
.47896 .40746 .47988 .40737 .48151 .4068 .48058 .40693 Mtetra
.397 .854 .835 r
.48058 .40693 .48151 .4068 .48313 .40625 .48221 .40635 Mtetra
.429 .872 .861 r
.48221 .40635 .48313 .40625 .48475 .40572 .48383 .40575 Mtetra
.436 .874 .887 r
.48383 .40575 .48475 .40572 .48638 .40518 .48546 .4052 Mtetra
.442 .877 .892 r
.48546 .4052 .48638 .40518 .48801 .40464 .48709 .40466 Mtetra
.453 .882 .899 r
.48709 .40466 .48801 .40464 .48963 .4041 .48871 .4041 Mtetra
.47 .89 .907 r
.48871 .4041 .48963 .4041 .49126 .40354 .49034 .40353 Mtetra
.474 .891 .912 r
.49034 .40353 .49126 .40354 .49289 .40298 .49197 .40297 Mtetra
.54 .92 .925 r
.49197 .40297 .49289 .40298 .49452 .40236 .49361 .40231 Mtetra
.705 .969 .933 r
.49361 .40231 .49452 .40236 .49615 .40152 .49524 .40134 Mtetra
.538 .9 .969 r
.49524 .40134 .49615 .40152 .49779 .40097 .49688 .40081 Mtetra
.364 0 0 r
.49688 .40081 .49779 .40097 .49941 .40121 .4985 .40143 Mtetra
.92 .57 .357 r
.4985 .40143 .49941 .40121 .50102 .40418 .50008 .40857 Mtetra
.955 .677 .471 r
.50008 .40857 .50102 .40418 .50133 .59702 .50029 .60673 Mtetra
.641 .369 .491 r
.50029 .60673 .50133 .59702 .50299 .60696 .50201 .61012 Mtetra
.507 .175 .338 r
.50201 .61012 .50299 .60696 .50473 .60721 .50375 .61009 Mtetra
.409 .073 .282 r
.50375 .61009 .50473 .60721 .50648 .6064 .5055 .6094 Mtetra
.375 .048 .276 r
.5055 .6094 .50648 .6064 .50823 .60515 .50725 .60846 Mtetra
.449 .125 .324 r
.50725 .60846 .50823 .60515 .50997 .60458 .50899 .60792 Mtetra
.449 .127 .326 r
.50899 .60792 .50997 .60458 .51172 .60399 .51074 .60737 Mtetra
.451 .129 .328 r
.51074 .60737 .51172 .60399 .51347 .60341 .51249 .60682 Mtetra
.454 .133 .331 r
.51249 .60682 .51347 .60341 .51521 .60286 .51425 .60628 Mtetra
.455 .135 .333 r
.51425 .60628 .51521 .60286 .51696 .60232 .516 .60576 Mtetra
.456 .136 .334 r
.516 .60576 .51696 .60232 .51871 .60179 .51775 .60524 Mtetra
.457 .137 .334 r
.51775 .60524 .51871 .60179 .52047 .60126 .51951 .60472 Mtetra
.457 .138 .335 r
.51951 .60472 .52047 .60126 .52222 .60075 .52126 .6042 Mtetra
.458 .138 .335 r
.52126 .6042 .52222 .60075 .52397 .60024 .52302 .60369 Mtetra
.52302 .60369 .52397 .60024 .52573 .59974 .52478 .60318 Mtetra
.459 .138 .334 r
.52478 .60318 .52573 .59974 .52748 .59926 .52654 .60268 Mtetra
.52654 .60268 .52748 .59926 .52924 .59878 .5283 .60219 Mtetra
.461 .139 .333 r
.5283 .60219 .52924 .59878 .531 .59834 .53006 .60171 Mtetra
.459 .137 .331 r
.53006 .60171 .531 .59834 .53276 .59789 .53182 .60123 Mtetra
.461 .137 .33 r
.53182 .60123 .53276 .59789 .53452 .59749 .53358 .60077 Mtetra
.507 .177 .343 r
.53358 .60077 .53452 .59749 .53629 .59776 .53535 .60072 Mtetra
.45 .114 .303 r
.53535 .60072 .53629 .59776 .53805 .59738 .53712 .60027 Mtetra
.313 0 .244 r
.53712 .60027 .53805 .59738 .53981 .59566 .53888 .59901 Mtetra
0 0 0 r
.53888 .59901 .53981 .59566 .54063 .40221 .54063 .59329 Mtetra
0 0 .338 r
.54063 .59329 .54063 .40221 .54223 .38956 .54136 .39204 Mtetra
.842 .814 .33 r
.54136 .39204 .54223 .38956 .54388 .38607 .543 .38608 Mtetra
.748 .985 .902 r
.543 .38608 .54388 .38607 .54554 .3851 .54466 .38491 Mtetra
.484 .876 .965 r
.54466 .38491 .54554 .3851 .5472 .38463 .54632 .38446 Mtetra
.19 .71 .875 r
.54632 .38446 .5472 .38463 .54886 .38441 .54799 .38439 Mtetra
.442 .875 .905 r
.54799 .38439 .54886 .38441 .55053 .38388 .54965 .38386 Mtetra
.432 .87 .902 r
.54965 .38386 .55053 .38388 .55219 .38335 .55132 .38334 Mtetra
.424 .866 .896 r
.55132 .38334 .55219 .38335 .55386 .38282 .55298 .38282 Mtetra
.428 .869 .892 r
.55298 .38282 .55386 .38282 .55552 .38227 .55465 .38228 Mtetra
.421 .866 .885 r
.55465 .38228 .55552 .38227 .55719 .38172 .55632 .38174 Mtetra
.412 .862 .877 r
.55632 .38174 .55719 .38172 .55886 .38117 .55799 .38121 Mtetra
.369 .837 .86 r
.55799 .38121 .55886 .38117 .56053 .38062 .55966 .38072 Mtetra
.341 .821 .82 r
.55966 .38072 .56053 .38062 .5622 .38008 .56133 .3802 Mtetra
.37 .838 .819 r
.56133 .3802 .5622 .38008 .56387 .37957 .56301 .37962 Mtetra
.555 .932 .893 r
.56301 .37962 .56387 .37957 .56555 .37915 .56468 .37883 Mtetra
.698 .924 .967 r
.56468 .37883 .56555 .37915 .56722 .37875 .56635 .37801 Mtetra
.716 .822 .931 r
.56635 .37801 .56722 .37875 .5689 .37834 .56802 .37723 Mtetra
.671 .726 .891 r
.56802 .37723 .5689 .37834 .57058 .37785 .5697 .37663 Mtetra
.657 .703 .88 r
.5697 .37663 .57058 .37785 .57225 .3773 .57138 .3761 Mtetra
.653 .703 .884 r
.57138 .3761 .57225 .3773 .57393 .3767 .57306 .37559 Mtetra
.663 .724 .894 r
.57306 .37559 .57393 .3767 .57561 .37601 .57474 .37502 Mtetra
.666 .752 .915 r
.57474 .37502 .57561 .37601 .57729 .3753 .57642 .37446 Mtetra
.665 .785 .938 r
.57642 .37446 .57729 .3753 .57896 .3746 .5781 .37388 Mtetra
.657 .815 .96 r
.5781 .37388 .57896 .3746 .58064 .37385 .57978 .37332 Mtetra
.639 .858 .983 r
.57978 .37332 .58064 .37385 .58232 .37323 .58146 .37276 Mtetra
.63 .873 .987 r
.58146 .37276 .58232 .37323 .58401 .37281 .58315 .37219 Mtetra
.657 .84 .97 r
.58315 .37219 .58401 .37281 .58571 .37315 .58483 .3716 Mtetra
.66 .653 .832 r
.58483 .3716 .58571 .37315 .58743 .37396 .58652 .37101 Mtetra
.625 .525 .72 r
.58652 .37101 .58743 .37396 .58915 .3751 .58821 .37042 Mtetra
.626 .475 .658 r
.58821 .37042 .58915 .3751 .59084 .37445 .58989 .36946 Mtetra
.607 .457 .652 r
.58989 .36946 .59084 .37445 .59252 .3736 .59157 .36874 Mtetra
.568 .434 .657 r
.59157 .36874 .59252 .3736 .59422 .37355 .59327 .36863 Mtetra
.238 .207 .62 r
.59327 .36863 .59422 .37355 .59621 .38604 .59505 .37175 Mtetra
.982 .698 .395 r
.59505 .37175 .59621 .38604 .60229 .57807 .60125 .57165 Mtetra
0 0 .462 r
.60125 .57165 .60229 .57807 .60419 .58137 .60324 .57898 Mtetra
.435 .458 .785 r
.60324 .57898 .60419 .58137 .60602 .58179 .60507 .57966 Mtetra
.635 .593 .789 r
.60507 .57966 .60602 .58179 .60783 .58139 .60689 .57912 Mtetra
.68 .604 .764 r
.60689 .57912 .60783 .58139 .60964 .58065 .60869 .57815 Mtetra
.612 .553 .763 r
.60869 .57815 .60964 .58065 .61145 .58009 .6105 .57774 Mtetra
.594 .553 .778 r
.6105 .57774 .61145 .58009 .61327 .57946 .61232 .57748 Mtetra
.602 .589 .811 r
.61232 .57748 .61327 .57946 .61507 .57862 .61415 .57718 Mtetra
.636 .674 .869 r
.61415 .57718 .61507 .57862 .61686 .57709 .61596 .57671 Mtetra
.58 .885 .991 r
.61596 .57671 .61686 .57709 .61864 .57506 .61778 .57615 Mtetra
.204 0 0 r
.61778 .57615 .61864 .57506 .6204 .57269 .6196 .57555 Mtetra
.486 .142 .308 r
.6196 .57555 .6204 .57269 .62222 .57203 .62143 .5754 Mtetra
.478 .153 .336 r
.62143 .5754 .62222 .57203 .62405 .57184 .62326 .57507 Mtetra
.396 .077 .302 r
.62326 .57507 .62405 .57184 .62585 .57089 .62507 .57412 Mtetra
0 0 .077 r
.62507 .57412 .62585 .57089 .62742 .56205 .62679 .57016 Mtetra
.98 .699 .413 r
.62679 .57016 .62742 .56205 .62316 .36419 .62255 .37112 Mtetra
0 0 .096 r
.62255 .37112 .62316 .36419 .62475 .35986 .62394 .36024 Mtetra
.864 .989 .723 r
.62394 .36024 .62475 .35986 .62643 .35846 .6256 .35806 Mtetra
.712 .915 .964 r
.6256 .35806 .62643 .35846 .62815 .358 .6273 .35721 Mtetra
.609 .784 .965 r
.6273 .35721 .62815 .358 .62987 .35787 .62902 .3568 Mtetra
.643 .731 .912 r
.62902 .3568 .62987 .35787 .63159 .35749 .63074 .35632 Mtetra
.65 .712 .893 r
.63074 .35632 .63159 .35749 .63331 .35695 .63245 .35581 Mtetra
.645 .716 .9 r
.63245 .35581 .63331 .35695 .63502 .35636 .63417 .35533 Mtetra
.664 .746 .911 r
.63417 .35533 .63502 .35636 .63673 .35555 .63589 .35475 Mtetra
.673 .805 .945 r
.63589 .35475 .63673 .35555 .63844 .35473 .63761 .35413 Mtetra
.664 .853 .972 r
.63761 .35413 .63844 .35473 .64015 .35409 .63932 .35349 Mtetra
.748 .872 .937 r
.63932 .35349 .64015 .35409 .64189 .35388 .64103 .35255 Mtetra
.704 .704 .848 r
.64103 .35255 .64189 .35388 .64364 .35422 .64274 .35172 Mtetra
.598 .535 .754 r
.64274 .35172 .64364 .35422 .64543 .35546 .64447 .35142 Mtetra
.323 .291 .668 r
.64447 .35142 .64543 .35546 .64743 .3621 .6463 .3535 Mtetra
.979 .689 .385 r
.6463 .3535 .64743 .3621 .65693 .56068 .65548 .54517 Mtetra
0 0 .44 r
.65548 .54517 .65693 .56068 .65895 .56446 .65798 .56165 Mtetra
.281 .332 .738 r
.65798 .56165 .65895 .56446 .66083 .56501 .65991 .56328 Mtetra
.576 .607 .846 r
.65991 .56328 .66083 .56501 .66268 .56437 .66177 .56311 Mtetra
.678 .723 .884 r
.66177 .56311 .66268 .56437 .6645 .56332 .66361 .56241 Mtetra
.662 .788 .942 r
.66361 .56241 .6645 .56332 .66635 .56272 .66546 .5618 Mtetra
.643 .778 .946 r
.66546 .5618 .66635 .56272 .66821 .56237 .66731 .56126 Mtetra
.66 .745 .912 r
.66731 .56126 .66821 .56237 .67006 .56182 .66916 .56066 Mtetra
.584 .704 .926 r
.66916 .56066 .67006 .56182 .67189 .56079 .67102 .56038 Mtetra
.471 .837 .992 r
.67102 .56038 .67189 .56079 .67369 .55907 .67289 .56005 Mtetra
.014 0 0 r
.67289 .56005 .67369 .55907 .67543 .55609 .67472 .55909 Mtetra
0 0 .086 r
.67472 .55909 .67543 .55609 .67654 .53893 .67644 .5554 Mtetra
.984 .702 .368 r
.67644 .5554 .67654 .53893 .66967 .34765 .66923 .35528 Mtetra
0 0 .201 r
.66923 .35528 .66967 .34765 .67126 .34378 .67051 .34467 Mtetra
.707 .885 .498 r
.67051 .34467 .67126 .34378 .67295 .34213 .67216 .34217 Mtetra
.596 .95 .879 r
.67216 .34217 .67295 .34213 .67468 .3415 .67389 .34123 Mtetra
.515 .882 .978 r
.67389 .34123 .67468 .3415 .67644 .34135 .67563 .34075 Mtetra
.689 .863 .965 r
.67563 .34075 .67644 .34135 .67821 .34138 .67737 .34002 Mtetra
.694 .7 .851 r
.67737 .34002 .67821 .34138 .68 .34169 .6791 .33924 Mtetra
.597 .539 .76 r
.6791 .33924 .68 .34169 .68182 .34275 .68086 .33896 Mtetra
.378 .337 .686 r
.68086 .33896 .68182 .34275 .68384 .34746 .68271 .34056 Mtetra
0 0 .405 r
.68271 .34056 .68384 .34746 .69579 .54809 .68498 .35017 Mtetra
.012 0 .421 r
.68498 .35017 .69579 .54809 .69792 .55267 .69692 .5494 Mtetra
.216 .262 .696 r
.69692 .5494 .69792 .55267 .69986 .55361 .69894 .5517 Mtetra
.548 .572 .83 r
.69894 .5517 .69986 .55361 .70174 .55311 .70084 .5517 Mtetra
.655 .691 .871 r
.70084 .5517 .70174 .55311 .70359 .55219 .70271 .55111 Mtetra
.599 .73 .936 r
.70271 .55111 .70359 .55219 .70547 .55179 .7046 .55075 Mtetra
.562 .723 .949 r
.7046 .55075 .70547 .55179 .70738 .55173 .70649 .55052 Mtetra
.702 .743 .883 r
.70649 .55052 .70738 .55173 .70925 .55107 .70835 .54968 Mtetra
.878 .758 .727 r
.70835 .54968 .70925 .55107 .71098 .54795 .7101 .54668 Mtetra
.972 .725 .504 r
.7101 .54668 .71098 .54795 .70201 .35279 .71122 .53252 Mtetra
0 0 .394 r
.71122 .53252 .70201 .35279 .70281 .3351 .70206 .33524 Mtetra
.959 .946 .69 r
.70206 .33524 .70281 .3351 .70445 .33243 .70368 .33222 Mtetra
.695 .958 .947 r
.70368 .33222 .70445 .33243 .7062 .33181 .70542 .33126 Mtetra
.578 .844 .995 r
.70542 .33126 .7062 .33181 .70799 .33172 .70718 .33082 Mtetra
.618 .765 .95 r
.70718 .33082 .70799 .33172 .70977 .33146 .70896 .3304 Mtetra
.663 .745 .911 r
.70896 .3304 .70977 .33146 .71153 .3308 .71072 .32982 Mtetra
.655 .759 .926 r
.71072 .32982 .71153 .3308 .7133 .33027 .71249 .32926 Mtetra
.709 .774 .903 r
.71249 .32926 .7133 .33027 .71508 .33 .71424 .32847 Mtetra
.704 .681 .825 r
.71424 .32847 .71508 .33 .71689 .33019 .71598 .32756 Mtetra
.612 .537 .746 r
.71598 .32756 .71689 .33019 .71876 .33118 .71776 .32713 Mtetra
.43 .364 .682 r
.71776 .32713 .71876 .33118 .72086 .3359 .71965 .32844 Mtetra
0 0 .451 r
.71965 .32844 .72086 .3359 .73524 .5367 .72205 .33803 Mtetra
.033 0 .433 r
.72205 .33803 .73524 .5367 .73745 .54118 .73644 .53777 Mtetra
.2 .246 .686 r
.73644 .53777 .73745 .54118 .73946 .54242 .73853 .54031 Mtetra
.555 .557 .81 r
.73853 .54031 .73946 .54242 .74138 .54216 .74047 .54029 Mtetra
.649 .632 .819 r
.74047 .54029 .74138 .54216 .74326 .5413 .74236 .53967 Mtetra
.636 .653 .85 r
.74236 .53967 .74326 .5413 .74512 .5401 .74427 .53917 Mtetra
.543 .741 .968 r
.74427 .53917 .74512 .5401 .74696 .53859 .74619 .53895 Mtetra
0 0 0 r
.74619 .53895 .74696 .53859 .74874 .53621 .74808 .53818 Mtetra
.74808 .53818 .74874 .53621 .75029 .53041 .74986 .53564 Mtetra
0 0 .064 r
.74986 .53564 .75029 .53041 .7385 .3279 .75113 .52576 Mtetra
.03 0 .426 r
.75113 .52576 .7385 .3279 .73994 .3224 .73929 .32357 Mtetra
.766 .84 .384 r
.73929 .32357 .73994 .3224 .74161 .3202 .74087 .31993 Mtetra
.751 .963 .935 r
.74087 .31993 .74161 .3202 .74339 .31953 .74261 .31881 Mtetra
.643 .825 .97 r
.74261 .31881 .74339 .31953 .7452 .31927 .7444 .31825 Mtetra
.626 .742 .931 r
.7444 .31825 .7452 .31927 .74699 .3189 .74619 .31781 Mtetra
.663 .743 .909 r
.74619 .31781 .74699 .3189 .74877 .31809 .74798 .31722 Mtetra
.646 .786 .948 r
.74798 .31722 .74877 .31809 .75055 .31742 .74977 .31668 Mtetra
.686 .834 .954 r
.74977 .31668 .75055 .31742 .75235 .31707 .75155 .31597 Mtetra
.726 .763 .883 r
.75155 .31597 .75235 .31707 .7542 .31727 .75332 .31505 Mtetra
.625 .574 .777 r
.75332 .31505 .7542 .31727 .7561 .31823 .75512 .31457 Mtetra
.463 .399 .7 r
.75512 .31457 .7561 .31823 .75822 .32199 .75702 .3155 Mtetra
.006 .029 .532 r
.75702 .3155 .75822 .32199 .77515 .52381 .75938 .32249 Mtetra
.052 0 .444 r
.75938 .32249 .77515 .52381 .77751 .52908 .77646 .52526 Mtetra
.154 .199 .657 r
.77646 .52526 .77751 .52908 .77959 .53063 .77867 .52848 Mtetra
.534 .543 .811 r
.77867 .52848 .77959 .53063 .78154 .53044 .78064 .52859 Mtetra
.637 .628 .825 r
.78064 .52859 .78154 .53044 .78345 .52964 .78257 .52805 Mtetra
.67 .676 .847 r
.78257 .52805 .78345 .52964 .78532 .52834 .78449 .52733 Mtetra
.636 .766 .942 r
.78449 .52733 .78532 .52834 .78715 .52651 .78642 .5268 Mtetra
0 0 0 r
.78642 .5268 .78715 .52651 .78895 .52425 .78835 .52621 Mtetra
.396 .01 .185 r
.78835 .52621 .78895 .52425 .79077 .52237 .79029 .52574 Mtetra
.491 .163 .337 r
.79029 .52574 .79077 .52237 .79274 .5222 .79225 .52553 Mtetra
.442 .121 .324 r
.79225 .52553 .79274 .5222 .79467 .52166 .79418 .52486 Mtetra
.25 0 .265 r
.79418 .52486 .79467 .52166 .79641 .51875 .796 .5228 Mtetra
0 0 .058 r
.796 .5228 .79641 .51875 .78182 .31634 .79734 .51503 Mtetra
.046 0 .438 r
.79734 .51503 .78182 .31634 .78306 .30877 .78248 .31018 Mtetra
.751 .791 .301 r
.78248 .31018 .78306 .30877 .78468 .30594 .78398 .30582 Mtetra
.677 .971 .916 r
.78398 .30582 .78468 .30594 .78647 .30504 .78575 .30477 Mtetra
.444 .854 .964 r
.78575 .30477 .78647 .30504 .78829 .30458 .78758 .30437 Mtetra
.302 .781 .92 r
.78758 .30437 .78829 .30458 .79012 .30424 .78942 .30414 Mtetra
.453 .88 .907 r
.78942 .30414 .79012 .30424 .79193 .30365 .79124 .30354 Mtetra
.447 .877 .908 r
.79124 .30354 .79193 .30365 .79375 .30306 .79305 .30296 Mtetra
.445 .876 .908 r
.79305 .30296 .79375 .30306 .79557 .30248 .79487 .30238 Mtetra
.447 .877 .907 r
.79487 .30238 .79557 .30248 .79738 .3019 .79669 .3018 Mtetra
.444 .876 .907 r
.79669 .3018 .79738 .3019 .7992 .30132 .79851 .30122 Mtetra
.438 .873 .906 r
.79851 .30122 .7992 .30132 .80102 .30074 .80033 .30065 Mtetra
.429 .868 .904 r
.80033 .30065 .80102 .30074 .80284 .30018 .80216 .30009 Mtetra
.418 .862 .9 r
.80216 .30009 .80284 .30018 .80467 .29963 .80399 .29954 Mtetra
.399 .852 .894 r
.80399 .29954 .80467 .29963 .8065 .29909 .80582 .29903 Mtetra
.349 .824 .873 r
.80582 .29903 .8065 .29909 .80833 .29856 .80765 .29856 Mtetra
.312 .803 .826 r
.80765 .29856 .80833 .29856 .81016 .29804 .80949 .29807 Mtetra
.349 .826 .821 r
.80949 .29807 .81016 .29804 .81199 .29757 .81132 .2975 Mtetra
.53 .92 .902 r
.81132 .2975 .81199 .29757 .81384 .29718 .81313 .29672 Mtetra
.681 .911 .974 r
.81313 .29672 .81384 .29718 .81569 .29679 .81494 .29591 Mtetra
.701 .808 .931 r
.81494 .29591 .81569 .29679 .81753 .29635 .81675 .29513 Mtetra
.67 .724 .89 r
.81675 .29513 .81753 .29635 .81936 .29575 .81858 .29448 Mtetra
.664 .713 .885 r
.81858 .29448 .81936 .29575 .82119 .29509 .82041 .29386 Mtetra
.682 .728 .885 r
.82041 .29386 .82119 .29509 .82301 .29432 .82223 .29316 Mtetra
.759 .769 .861 r
.82223 .29316 .82301 .29432 .82479 .29315 .82402 .292 Mtetra
.686 .745 .896 r
.82402 .292 .82479 .29315 .82661 .29242 .82584 .29128 Mtetra
.406 .608 .931 r
.82584 .29128 .82661 .29242 .82853 .29272 .82776 .29158 Mtetra
.824 .418 0 r
.82776 .29158 .82853 .29272 .83102 .29872 .83025 .29757 Mtetra
.973 .661 .312 r
.83025 .29757 .83102 .29872 .85316 .50377 .85235 .50269 Mtetra
.691 .249 0 r
.85235 .50269 .85316 .50377 .85558 .5078 .85478 .50673 Mtetra
.343 .604 .945 r
.85478 .50673 .85558 .5078 .85766 .5082 .85686 .50713 Mtetra
.669 .771 .927 r
.85686 .50713 .85766 .5082 .85963 .50752 .85883 .50645 Mtetra
.849 .822 .822 r
.85883 .50645 .85963 .50752 .86147 .50558 .86067 .50451 Mtetra
.977 .78 .572 r
.86067 .50451 .86147 .50558 .86283 .49897 .86204 .49789 Mtetra
.976 .67 .326 r
.86204 .49789 .86283 .49897 .84369 .29203 .84293 .2909 Mtetra
.966 .78 .602 r
.84293 .2909 .84369 .29203 .84504 .28663 .84429 .28549 Mtetra
.762 .778 .866 r
.84429 .28549 .84504 .28663 .84683 .28546 .84608 .28433 Mtetra
.633 .728 .916 r
.84608 .28433 .84683 .28546 .8487 .28498 .84794 .28385 Mtetra
.557 .692 .93 r
.84794 .28385 .8487 .28498 .85059 .2848 .84984 .28367 Mtetra
.753 .775 .871 r
.84984 .28367 .85059 .2848 .85239 .2837 .85164 .28256 Mtetra
.686 .75 .9 r
.85164 .28256 .85239 .2837 .85423 .28298 .85348 .28184 Mtetra
.486 .654 .934 r
.85348 .28184 .85423 .28298 .85616 .28304 .8554 .2819 Mtetra
.733 .315 0 r
.8554 .2819 .85616 .28304 .85859 .28782 .85783 .28665 Mtetra
.971 .656 .295 r
.85783 .28665 .85859 .28782 .88274 .4938 .88195 .49266 Mtetra
.738 .311 0 r
.88195 .49266 .88274 .4938 .88533 .4987 .88454 .49759 Mtetra
.463 .667 .951 r
.88454 .49759 .88533 .4987 .88741 .49891 .88661 .49768 Mtetra
.67 .743 .905 r
.88661 .49768 .88741 .49891 .8894 .49823 .88859 .49698 Mtetra
.738 .765 .875 r
.88859 .49698 .8894 .49823 .89132 .49695 .89054 .49588 Mtetra
.331 .636 .963 r
.24966 .68283 .25072 .68371 .25227 .68376 .25119 .68307 Mtetra
.512 .763 .987 r
.25119 .68307 .25227 .68376 .25385 .68343 .25276 .68291 Mtetra
.746 .853 .929 r
.25276 .68291 .25385 .68343 .25548 .68238 .25439 .68201 Mtetra
.928 .773 .668 r
.25439 .68201 .25548 .68238 .25745 .67696 .25633 .67692 Mtetra
.938 .687 .533 r
.25633 .67692 .25745 .67696 .27394 .48044 .27291 .48001 Mtetra
.93 .749 .635 r
.27291 .48001 .27394 .48044 .27585 .47451 .27487 .47354 Mtetra
.775 .751 .831 r
.27487 .47354 .27585 .47451 .27741 .47333 .27643 .47235 Mtetra
.634 .72 .91 r
.27643 .47235 .27741 .47333 .27891 .47293 .27792 .47196 Mtetra
.492 .673 .945 r
.27792 .47196 .27891 .47293 .28038 .4729 .27939 .47197 Mtetra
.717 .751 .879 r
.27939 .47197 .28038 .4729 .28191 .472 .28092 .47121 Mtetra
.687 .777 .919 r
.28092 .47121 .28191 .472 .28343 .47137 .28244 .47062 Mtetra
.544 .746 .97 r
.28244 .47062 .28343 .47137 .2849 .47138 .28392 .47044 Mtetra
.619 .11 0 r
.28392 .47044 .2849 .47138 .28611 .47504 .28528 .47199 Mtetra
.763 .471 0 r
.28528 .47199 .28611 .47504 .27356 .66991 .28642 .47668 Mtetra
0 0 .229 r
.28642 .47668 .27356 .66991 .27471 .6758 .27416 .66795 Mtetra
.242 .157 .555 r
.27416 .66795 .27471 .6758 .27623 .6764 .27543 .67204 Mtetra
.37 .308 .657 r
.27543 .67204 .27623 .6764 .27783 .67606 .27689 .67362 Mtetra
.426 .438 .769 r
.27689 .67362 .27783 .67606 .27945 .6753 .27842 .67427 Mtetra
.446 .653 .948 r
.27842 .67427 .27945 .6753 .28103 .67522 .27998 .67438 Mtetra
.626 .763 .945 r
.27998 .67438 .28103 .67522 .28263 .67486 .28159 .67397 Mtetra
.752 .776 .872 r
.28159 .67397 .28263 .67486 .28428 .67382 .28323 .67296 Mtetra
.868 .769 .75 r
.28323 .67296 .28428 .67382 .28617 .6692 .28499 .67033 Mtetra
.988 .865 .625 r
.28499 .67033 .28617 .6692 .30105 .47327 .28695 .66468 Mtetra
0 0 .219 r
.28695 .66468 .30105 .47327 .30303 .4661 .3016 .47185 Mtetra
0 0 .124 r
.3016 .47185 .30303 .4661 .30462 .46445 .30345 .46648 Mtetra
0 0 0 r
.30345 .46648 .30462 .46445 .30615 .46379 .30511 .46396 Mtetra
.863 .974 .858 r
.30511 .46396 .30615 .46379 .30766 .46353 .3067 .46238 Mtetra
.694 .707 .858 r
.3067 .46238 .30766 .46353 .30918 .46313 .30823 .4617 Mtetra
.612 .635 .849 r
.30823 .4617 .30918 .46313 .31069 .46273 .30974 .46141 Mtetra
.569 .634 .876 r
.30974 .46141 .31069 .46273 .31221 .46234 .31124 .46128 Mtetra
.63 .706 .901 r
.31124 .46128 .31221 .46234 .31373 .46185 .31276 .4609 Mtetra
.66 .738 .908 r
.31276 .4609 .31373 .46185 .31526 .46132 .31429 .46041 Mtetra
.677 .751 .907 r
.31429 .46041 .31526 .46132 .31679 .46077 .31582 .45985 Mtetra
.701 .754 .893 r
.31582 .45985 .31679 .46077 .31832 .46021 .31736 .45917 Mtetra
.704 .731 .872 r
.31736 .45917 .31832 .46021 .31986 .45965 .3189 .45846 Mtetra
.695 .702 .852 r
.3189 .45846 .31986 .45965 .32139 .45909 .32044 .45776 Mtetra
.709 .685 .825 r
.32044 .45776 .32139 .45909 .32294 .45819 .32199 .45693 Mtetra
.686 .688 .846 r
.32199 .45693 .32294 .45819 .32449 .45748 .32354 .45627 Mtetra
.602 .668 .886 r
.32354 .45627 .32449 .45748 .326 .45733 .32505 .45601 Mtetra
0 .147 .685 r
.32505 .45601 .326 .45733 .32734 .46001 .32647 .45737 Mtetra
.729 .416 0 r
.32647 .45737 .32734 .46001 .31727 .65385 .32773 .46151 Mtetra
0 0 .253 r
.32773 .46151 .31727 .65385 .31836 .66236 .3178 .65347 Mtetra
.385 .256 .58 r
.3178 .65347 .31836 .66236 .3199 .66335 .31922 .65651 Mtetra
.582 .419 .626 r
.31922 .65651 .3199 .66335 .32153 .66293 .32085 .65607 Mtetra
.629 .454 .626 r
.32085 .65607 .32153 .66293 .32319 .66201 .32253 .65458 Mtetra
.627 .448 .62 r
.32253 .65458 .32319 .66201 .32483 .66133 .32423 .65302 Mtetra
.6 .422 .612 r
.32423 .65302 .32483 .66133 .32647 .6608 .32589 .652 Mtetra
.544 .377 .605 r
.32589 .652 .32647 .6608 .3281 .66032 .32748 .65229 Mtetra
.371 .253 .586 r
.32748 .65229 .3281 .66032 .32972 .66004 .32892 .65523 Mtetra
.293 .244 .63 r
.32892 .65523 .32972 .66004 .33135 .65984 .3304 .65752 Mtetra
.212 .318 .756 r
.3304 .65752 .33135 .65984 .33297 .65962 .33193 .65883 Mtetra
.381 .686 .979 r
.33193 .65883 .33297 .65962 .3346 .65924 .33354 .65894 Mtetra
.549 .875 .992 r
.33354 .65894 .3346 .65924 .33624 .65878 .33518 .65849 Mtetra
.627 .902 .985 r
.33518 .65849 .33624 .65878 .33788 .65828 .33683 .65788 Mtetra
.551 .854 .998 r
.33683 .65788 .33788 .65828 .33952 .65782 .33847 .65748 Mtetra
.464 .835 .991 r
.33847 .65748 .33952 .65782 .34116 .65736 .3401 .6572 Mtetra
.414 .841 .955 r
.3401 .6572 .34116 .65736 .34281 .6569 .34174 .65686 Mtetra
.306 .795 .884 r
.34174 .65686 .34281 .6569 .34444 .65675 .34337 .65656 Mtetra
.509 .882 .975 r
.34337 .65656 .34444 .65675 .34607 .65649 .34502 .6561 Mtetra
.725 .896 .957 r
.34502 .6561 .34607 .65649 .34773 .65566 .34669 .65525 Mtetra
.893 .85 .793 r
.34669 .65525 .34773 .65566 .34953 .6523 .34843 .65296 Mtetra
.981 .871 .652 r
.34843 .65296 .34953 .6523 .36052 .46489 .35029 .64819 Mtetra
0 0 .236 r
.35029 .64819 .36052 .46489 .36293 .44723 .36146 .45676 Mtetra
.126 0 .336 r
.36146 .45676 .36293 .44723 .36458 .44496 .36331 .45037 Mtetra
.504 .223 .421 r
.36331 .45037 .36458 .44496 .36614 .44435 .36486 .44999 Mtetra
.53 .249 .434 r
.36486 .44999 .36614 .44435 .36767 .4442 .3664 .44996 Mtetra
.224 0 .324 r
.3664 .44996 .36767 .4442 .36923 .44373 .36809 .44678 Mtetra
0 0 0 r
.36809 .44678 .36923 .44373 .3708 .44299 .36978 .44352 Mtetra
.907 .984 .756 r
.36978 .44352 .3708 .44299 .37237 .44226 .37142 .44128 Mtetra
.774 .76 .841 r
.37142 .44128 .37237 .44226 .37393 .44165 .37301 .44011 Mtetra
.66 .642 .822 r
.37301 .44011 .37393 .44165 .37549 .44114 .37457 .43954 Mtetra
.621 .618 .827 r
.37457 .43954 .37549 .44114 .37705 .44067 .37613 .43919 Mtetra
.617 .634 .845 r
.37613 .43919 .37705 .44067 .37862 .44017 .37768 .43887 Mtetra
.625 .663 .867 r
.37768 .43887 .37862 .44017 .38018 .43966 .37924 .43851 Mtetra
.633 .693 .889 r
.37924 .43851 .38018 .43966 .38175 .43913 .3808 .43812 Mtetra
.673 .733 .895 r
.3808 .43812 .38175 .43913 .38331 .43859 .38237 .43755 Mtetra
.7 .736 .879 r
.38237 .43755 .38331 .43859 .38488 .43803 .38394 .43685 Mtetra
.698 .71 .858 r
.38394 .43685 .38488 .43803 .38645 .43747 .38552 .43613 Mtetra
.706 .688 .83 r
.38552 .43613 .38645 .43747 .38803 .43665 .3871 .43532 Mtetra
.695 .685 .836 r
.3871 .43532 .38803 .43665 .38961 .43583 .38868 .43457 Mtetra
.632 .675 .873 r
.38868 .43457 .38961 .43583 .39117 .4355 .39024 .43418 Mtetra
.239 .466 .876 r
.39024 .43418 .39117 .4355 .39266 .43711 .39177 .43487 Mtetra
0 0 .49 r
.39177 .43487 .39266 .43711 .39373 .44919 .39321 .43757 Mtetra
.967 .701 .479 r
.39321 .43757 .39373 .44919 .3877 .64074 .38733 .62392 Mtetra
0 0 .425 r
.38733 .62392 .3877 .64074 .38927 .6429 .38843 .63768 Mtetra
.307 .247 .625 r
.38843 .63768 .38927 .6429 .39092 .64288 .38999 .64014 Mtetra
.362 .38 .745 r
.38999 .64014 .39092 .64288 .3926 .64231 .3916 .6412 Mtetra
.439 .636 .939 r
.3916 .6412 .3926 .64231 .39428 .64169 .39325 .64135 Mtetra
.541 .867 .994 r
.39325 .64135 .39428 .64169 .39596 .6412 .39493 .64093 Mtetra
.634 .911 .982 r
.39493 .64093 .39596 .6412 .39764 .64065 .39661 .64027 Mtetra
.643 .889 .985 r
.39661 .64027 .39764 .64065 .39932 .64009 .3983 .63964 Mtetra
.605 .863 .992 r
.3983 .63964 .39932 .64009 .401 .63955 .39998 .63914 Mtetra
.596 .87 .993 r
.39998 .63914 .401 .63955 .40268 .63901 .40166 .63864 Mtetra
.585 .876 .994 r
.40166 .63864 .40268 .63901 .40437 .63849 .40334 .63814 Mtetra
.581 .877 .993 r
.40334 .63814 .40437 .63849 .40605 .63801 .40503 .63764 Mtetra
.583 .875 .994 r
.40503 .63764 .40605 .63801 .40773 .63753 .40671 .63714 Mtetra
.588 .873 .994 r
.40671 .63714 .40773 .63753 .40942 .63705 .4084 .63664 Mtetra
.591 .871 .994 r
.4084 .63664 .40942 .63705 .4111 .63655 .41009 .63615 Mtetra
.591 .87 .994 r
.41009 .63615 .4111 .63655 .41279 .63605 .41177 .63565 Mtetra
.59 .871 .994 r
.41177 .63565 .41279 .63605 .41448 .63554 .41346 .63515 Mtetra
.587 .872 .994 r
.41346 .63515 .41448 .63554 .41617 .63503 .41515 .63466 Mtetra
.582 .875 .994 r
.41515 .63466 .41617 .63503 .41786 .63452 .41685 .63416 Mtetra
.578 .877 .994 r
.41685 .63416 .41786 .63452 .41955 .63403 .41854 .63366 Mtetra
.58 .875 .994 r
.41854 .63366 .41955 .63403 .42124 .63357 .42023 .63317 Mtetra
.589 .87 .994 r
.42023 .63317 .42124 .63357 .42293 .63312 .42193 .63267 Mtetra
.553 .848 .998 r
.42193 .63267 .42293 .63312 .42463 .63267 .42362 .63228 Mtetra
.502 .841 .997 r
.42362 .63228 .42463 .63267 .42632 .63221 .42531 .63194 Mtetra
.575 .895 .986 r
.42531 .63194 .42632 .63221 .42802 .63171 .42701 .6314 Mtetra
.8 .92 .918 r
.42701 .6314 .42802 .63171 .42972 .63111 .42873 .63017 Mtetra
.864 .781 .767 r
.42873 .63017 .42972 .63111 .43143 .63037 .43048 .62777 Mtetra
.806 .641 .677 r
.43048 .62777 .43143 .63037 .43313 .62961 .43226 .62434 Mtetra
.714 .529 .638 r
.43226 .62434 .43313 .62961 .43483 .62918 .43403 .6212 Mtetra
.556 .392 .614 r
.43403 .6212 .43483 .62918 .43652 .62908 .43571 .62123 Mtetra
.572 .404 .616 r
.43571 .62123 .43652 .62908 .43823 .62848 .43741 .62092 Mtetra
.734 .525 .609 r
.43741 .62092 .43823 .62848 .43998 .62604 .43924 .61534 Mtetra
.944 .677 .502 r
.43924 .61534 .43998 .62604 .44201 .61207 .44566 .42146 Mtetra
.559 .342 .542 r
.44566 .42146 .44201 .61207 .44826 .41926 .44737 .41685 Mtetra
.761 .621 .705 r
.44737 .41685 .44826 .41926 .44992 .41608 .44901 .41472 Mtetra
.691 .683 .838 r
.44901 .41472 .44992 .41608 .45153 .41527 .45062 .41399 Mtetra
.622 .671 .876 r
.45062 .41399 .45153 .41527 .45314 .41498 .45222 .41364 Mtetra
.595 .648 .873 r
.45222 .41364 .45314 .41498 .45474 .41478 .45382 .4134 Mtetra
.619 .652 .861 r
.45382 .4134 .45474 .41478 .45634 .41428 .45543 .41305 Mtetra
.615 .677 .886 r
.45543 .41305 .45634 .41428 .45795 .41378 .45703 .41273 Mtetra
.625 .714 .91 r
.45703 .41273 .45795 .41378 .45956 .41329 .45864 .41235 Mtetra
.65 .748 .921 r
.45864 .41235 .45956 .41329 .46117 .41279 .46025 .41186 Mtetra
.666 .757 .918 r
.46025 .41186 .46117 .41279 .46279 .41227 .46187 .41132 Mtetra
.684 .754 .904 r
.46187 .41132 .46279 .41227 .4644 .41174 .46348 .41069 Mtetra
.699 .739 .882 r
.46348 .41069 .4644 .41174 .46601 .41117 .4651 .40998 Mtetra
.695 .711 .861 r
.4651 .40998 .46601 .41117 .46763 .4106 .46672 .40926 Mtetra
.691 .687 .842 r
.46672 .40926 .46763 .4106 .46925 .41001 .46834 .40853 Mtetra
.686 .666 .825 r
.46834 .40853 .46925 .41001 .47087 .40942 .46996 .4078 Mtetra
.648 .633 .821 r
.46996 .4078 .47087 .40942 .47249 .40887 .47158 .40728 Mtetra
.545 .589 .849 r
.47158 .40728 .47249 .40887 .4741 .4084 .47319 .40727 Mtetra
0 .298 .791 r
.47319 .40727 .4741 .4084 .47572 .4081 .47479 .40838 Mtetra
.79 .333 .159 r
.47479 .40838 .47572 .4081 .47734 .40781 .47637 .41047 Mtetra
.74 .402 .409 r
.47637 .41047 .47734 .40781 .47896 .40746 .47794 .41346 Mtetra
.553 .272 .444 r
.47794 .41346 .47896 .40746 .48058 .40693 .47956 .41381 Mtetra
.472 .21 .434 r
.47956 .41381 .48058 .40693 .48221 .40635 .4812 .41271 Mtetra
.448 .184 .42 r
.4812 .41271 .48221 .40635 .48383 .40575 .48284 .41137 Mtetra
.494 .216 .421 r
.48284 .41137 .48383 .40575 .48546 .4052 .48447 .41081 Mtetra
.493 .215 .421 r
.48447 .41081 .48546 .4052 .48709 .40466 .4861 .41024 Mtetra
.491 .213 .42 r
.4861 .41024 .48709 .40466 .48871 .4041 .48773 .40965 Mtetra
.488 .21 .418 r
.48773 .40965 .48871 .4041 .49034 .40353 .48936 .40902 Mtetra
.487 .209 .417 r
.48936 .40902 .49034 .40353 .49197 .40297 .491 .4084 Mtetra
.467 .191 .41 r
.491 .4084 .49197 .40297 .49361 .40231 .49264 .40753 Mtetra
.402 .132 .385 r
.49264 .40753 .49361 .40231 .49524 .40134 .49428 .40597 Mtetra
.481 .191 .395 r
.49428 .40597 .49524 .40134 .49688 .40081 .49592 .40542 Mtetra
.667 .362 .446 r
.49592 .40542 .49688 .40081 .4985 .40143 .49753 .40785 Mtetra
.952 .674 .474 r
.49753 .40785 .4985 .40143 .50008 .40857 .49761 .60307 Mtetra
.557 .336 .535 r
.49761 .60307 .50008 .40857 .50029 .60673 .49931 .6079 Mtetra
.714 .296 .251 r
.49931 .6079 .50029 .60673 .50201 .61012 .50104 .60964 Mtetra
.449 .801 .998 r
.50104 .60964 .50201 .61012 .50375 .61009 .50278 .60944 Mtetra
.67 .837 .964 r
.50278 .60944 .50375 .61009 .5055 .6094 .50453 .60879 Mtetra
.713 .857 .951 r
.50453 .60879 .5055 .6094 .50725 .60846 .50628 .60798 Mtetra
.613 .865 .99 r
.50628 .60798 .50725 .60846 .50899 .60792 .50803 .60743 Mtetra
.614 .866 .99 r
.50803 .60743 .50899 .60792 .51074 .60737 .50978 .60689 Mtetra
.612 .866 .991 r
.50978 .60689 .51074 .60737 .51249 .60682 .51153 .60634 Mtetra
.606 .866 .992 r
.51153 .60634 .51249 .60682 .51425 .60628 .51329 .60581 Mtetra
.603 .865 .992 r
.51329 .60581 .51425 .60628 .516 .60576 .51504 .60529 Mtetra
.601 .865 .993 r
.51504 .60529 .516 .60576 .51775 .60524 .51679 .60477 Mtetra
.6 .865 .993 r
.51679 .60477 .51775 .60524 .51951 .60472 .51855 .60425 Mtetra
.598 .864 .993 r
.51855 .60425 .51951 .60472 .52126 .6042 .52031 .60373 Mtetra
.596 .864 .993 r
.52031 .60373 .52126 .6042 .52302 .60369 .52206 .60322 Mtetra
.595 .863 .994 r
.52206 .60322 .52302 .60369 .52478 .60318 .52382 .60271 Mtetra
.593 .862 .994 r
.52382 .60271 .52478 .60318 .52654 .60268 .52558 .60221 Mtetra
.591 .861 .994 r
.52558 .60221 .52654 .60268 .5283 .60219 .52735 .60171 Mtetra
.586 .859 .995 r
.52735 .60171 .5283 .60219 .53006 .60171 .52911 .60122 Mtetra
.587 .858 .995 r
.52911 .60122 .53006 .60171 .53182 .60123 .53087 .60073 Mtetra
.581 .855 .995 r
.53087 .60073 .53182 .60123 .53358 .60077 .53264 .60027 Mtetra
.446 .796 .998 r
.53264 .60027 .53358 .60077 .53535 .60072 .5344 .60008 Mtetra
.603 .824 .984 r
.5344 .60008 .53535 .60072 .53712 .60027 .53617 .59962 Mtetra
.752 .856 .927 r
.53617 .59962 .53712 .60027 .53888 .59901 .53794 .59862 Mtetra
.942 .852 .725 r
.53794 .59862 .53888 .59901 .54063 .59329 .53969 .5953 Mtetra
.968 .857 .454 r
.53969 .5953 .54063 .59329 .54136 .39204 .54143 .58806 Mtetra
0 0 .358 r
.54143 .58806 .54136 .39204 .543 .38608 .54214 .39146 Mtetra
.373 .111 .382 r
.54214 .39146 .543 .38608 .54466 .38491 .5438 .38951 Mtetra
.504 .21 .401 r
.5438 .38951 .54466 .38491 .54632 .38446 .54547 .38923 Mtetra
.571 .273 .423 r
.54547 .38923 .54632 .38446 .54799 .38439 .54715 .38987 Mtetra
.5 .219 .42 r
.54715 .38987 .54799 .38439 .54965 .38386 .54881 .38941 Mtetra
.502 .222 .422 r
.54881 .38941 .54965 .38386 .55132 .38334 .55049 .38897 Mtetra
.503 .224 .424 r
.55049 .38897 .55132 .38334 .55298 .38282 .55216 .38854 Mtetra
.502 .224 .425 r
.55216 .38854 .55298 .38282 .55465 .38228 .55383 .38807 Mtetra
.501 .224 .426 r
.55383 .38807 .55465 .38228 .55632 .38174 .5555 .38759 Mtetra
.5 .224 .427 r
.5555 .38759 .55632 .38174 .55799 .38121 .55718 .38708 Mtetra
.56 .276 .441 r
.55718 .38708 .55799 .38121 .55966 .38072 .55887 .38758 Mtetra
.523 .253 .447 r
.55887 .38758 .55966 .38072 .56133 .3802 .56055 .38735 Mtetra
.428 .176 .428 r
.56055 .38735 .56133 .3802 .56301 .37962 .56221 .38545 Mtetra
.116 0 .306 r
.56221 .38545 .56301 .37962 .56468 .37883 .56384 .38092 Mtetra
0 0 0 r
.56384 .38092 .56468 .37883 .56635 .37801 .56548 .37791 Mtetra
.913 .945 .81 r
.56548 .37791 .56635 .37801 .56802 .37723 .56714 .37583 Mtetra
.708 .692 .833 r
.56714 .37583 .56802 .37723 .5697 .37663 .56881 .37497 Mtetra
.646 .631 .821 r
.56881 .37497 .5697 .37663 .57138 .3761 .57049 .37444 Mtetra
.62 .62 .829 r
.57049 .37444 .57138 .3761 .57306 .37559 .57217 .37406 Mtetra
.654 .654 .837 r
.57217 .37406 .57306 .37559 .57474 .37502 .57385 .37351 Mtetra
.655 .655 .838 r
.57385 .37351 .57474 .37502 .57642 .37446 .57553 .37295 Mtetra
.65 .655 .841 r
.57553 .37295 .57642 .37446 .5781 .37388 .57722 .37242 Mtetra
.63 .652 .853 r
.57722 .37242 .5781 .37388 .57978 .37332 .5789 .37201 Mtetra
.629 .675 .874 r
.5789 .37201 .57978 .37332 .58146 .37276 .58059 .3716 Mtetra
.64 .707 .895 r
.58059 .3716 .58146 .37276 .58315 .37219 .58228 .37114 Mtetra
.69 .747 .895 r
.58228 .37114 .58315 .37219 .58483 .3716 .58396 .37045 Mtetra
.7 .731 .875 r
.58396 .37045 .58483 .3716 .58652 .37101 .58564 .3697 Mtetra
.693 .701 .853 r
.58564 .3697 .58652 .37101 .58821 .37042 .58733 .36895 Mtetra
.705 .682 .825 r
.58733 .36895 .58821 .37042 .58989 .36946 .58901 .36807 Mtetra
.677 .684 .849 r
.58901 .36807 .58989 .36946 .59157 .36874 .5907 .3674 Mtetra
.593 .656 .881 r
.5907 .3674 .59157 .36874 .59327 .36863 .5924 .36715 Mtetra
0 .236 .753 r
.5924 .36715 .59327 .36863 .59505 .37175 .59414 .36869 Mtetra
0 0 .421 r
.59414 .36869 .59505 .37175 .60125 .57165 .59594 .37325 Mtetra
0 0 .392 r
.59594 .37325 .60125 .57165 .60324 .57898 .60214 .57023 Mtetra
.477 .332 .605 r
.60214 .57023 .60324 .57898 .60507 .57966 .604 .57201 Mtetra
.594 .423 .62 r
.604 .57201 .60507 .57966 .60689 .57912 .6058 .57118 Mtetra
.594 .421 .617 r
.6058 .57118 .60689 .57912 .60869 .57815 .6076 .57031 Mtetra
.408 .291 .607 r
.6076 .57031 .60869 .57815 .6105 .57774 .60949 .57304 Mtetra
.353 .299 .657 r
.60949 .57304 .6105 .57774 .61232 .57748 .61137 .57516 Mtetra
.306 .386 .781 r
.61137 .57516 .61232 .57748 .61415 .57718 .61324 .57636 Mtetra
.454 .72 .982 r
.61324 .57636 .61415 .57718 .61596 .57671 .61507 .57633 Mtetra
.551 .876 .992 r
.61507 .57633 .61596 .57671 .61778 .57615 .61689 .57583 Mtetra
.617 .913 .981 r
.61689 .57583 .61778 .57615 .6196 .57555 .6187 .57514 Mtetra
.466 .831 .994 r
.6187 .57514 .6196 .57555 .62143 .5754 .62053 .57483 Mtetra
.554 .832 .997 r
.62053 .57483 .62143 .5754 .62326 .57507 .62236 .57444 Mtetra
.705 .862 .957 r
.62236 .57444 .62326 .57507 .62507 .57412 .62417 .57362 Mtetra
.909 .881 .795 r
.62417 .57362 .62507 .57412 .62679 .57016 .62594 .57124 Mtetra
.955 .902 .523 r
.62594 .57124 .62679 .57016 .62255 .37112 .62764 .56639 Mtetra
0 0 .388 r
.62764 .56639 .62255 .37112 .62394 .36024 .62337 .36845 Mtetra
0 0 .309 r
.62337 .36845 .62394 .36024 .6256 .35806 .62485 .36042 Mtetra
0 0 .01 r
.62485 .36042 .6256 .35806 .6273 .35721 .62649 .35748 Mtetra
.821 .998 .779 r
.62649 .35748 .6273 .35721 .62902 .3568 .62817 .35568 Mtetra
.721 .745 .871 r
.62817 .35568 .62902 .3568 .63074 .35632 .62987 .3548 Mtetra
.627 .645 .848 r
.62987 .3548 .63074 .35632 .63245 .35581 .63159 .35439 Mtetra
.588 .641 .871 r
.63159 .35439 .63245 .35581 .63417 .35533 .63332 .35417 Mtetra
.631 .707 .901 r
.63332 .35417 .63417 .35533 .63589 .35475 .63504 .35374 Mtetra
.665 .75 .914 r
.63504 .35374 .63589 .35475 .63761 .35413 .63676 .35316 Mtetra
.679 .766 .916 r
.63676 .35316 .63761 .35413 .63932 .35349 .63848 .35252 Mtetra
.745 .783 .884 r
.63848 .35252 .63932 .35349 .64103 .35255 .64018 .35154 Mtetra
.736 .774 .883 r
.64018 .35154 .64103 .35255 .64274 .35172 .64189 .3506 Mtetra
.659 .728 .9 r
.64189 .3506 .64274 .35172 .64447 .35142 .64361 .35005 Mtetra
.252 .466 .873 r
.64361 .35005 .64447 .35142 .6463 .3535 .64539 .35085 Mtetra
0 .082 .624 r
.64539 .35085 .6463 .3535 .65548 .54517 .64725 .35379 Mtetra
0 0 .405 r
.64725 .35379 .65548 .54517 .65798 .56165 .6566 .54826 Mtetra
.181 .102 .524 r
.6566 .54826 .65798 .56165 .65991 .56328 .65885 .55817 Mtetra
.357 .294 .649 r
.65885 .55817 .65991 .56328 .66177 .56311 .66081 .5605 Mtetra
.395 .418 .766 r
.66081 .5605 .66177 .56311 .66361 .56241 .66272 .56147 Mtetra
.457 .694 .968 r
.66272 .56147 .66361 .56241 .66546 .5618 .6646 .5615 Mtetra
.51 .877 .98 r
.6646 .5615 .66546 .5618 .66731 .56126 .66645 .561 Mtetra
.601 .922 .971 r
.66645 .561 .66731 .56126 .66916 .56066 .6683 .56028 Mtetra
.501 .857 .991 r
.6683 .56028 .66916 .56066 .67102 .56038 .67016 .55986 Mtetra
.527 .835 .999 r
.67016 .55986 .67102 .56038 .67289 .56005 .67202 .55949 Mtetra
.685 .882 .971 r
.67202 .55949 .67289 .56005 .67472 .55909 .67386 .5587 Mtetra
.907 .917 .814 r
.67386 .5587 .67472 .55909 .67644 .5554 .67565 .55649 Mtetra
.942 .893 .494 r
.67565 .55649 .67644 .5554 .66923 .35528 .67731 .55155 Mtetra
0 0 .404 r
.67731 .55155 .66923 .35528 .67051 .34467 .67008 .35231 Mtetra
0 0 .311 r
.67008 .35231 .67051 .34467 .67216 .34217 .67149 .34459 Mtetra
0 0 .057 r
.67149 .34459 .67216 .34217 .67389 .34123 .67312 .34168 Mtetra
.744 .967 .691 r
.67312 .34168 .67389 .34123 .67563 .34075 .67481 .33983 Mtetra
.79 .808 .867 r
.67481 .33983 .67563 .34075 .67737 .34002 .67652 .33856 Mtetra
.693 .686 .838 r
.67652 .33856 .67737 .34002 .6791 .33924 .67825 .33776 Mtetra
.606 .644 .862 r
.67825 .33776 .6791 .33924 .68086 .33896 .68001 .33745 Mtetra
.325 .487 .866 r
.68001 .33745 .68086 .33896 .68271 .34056 .68182 .33816 Mtetra
0 .154 .675 r
.68182 .33816 .68271 .34056 .68498 .35017 .68372 .34066 Mtetra
0 0 .394 r
.68372 .34066 .68498 .35017 .69692 .5494 .68615 .35348 Mtetra
.028 0 .427 r
.68615 .35348 .69692 .5494 .69894 .5517 .69782 .54591 Mtetra
.345 .275 .633 r
.69782 .54591 .69894 .5517 .70084 .5517 .69986 .54872 Mtetra
.396 .396 .742 r
.69986 .54872 .70084 .5517 .70271 .55111 .70182 .54986 Mtetra
.43 .613 .926 r
.70182 .54986 .70271 .55111 .7046 .55075 .70374 .55011 Mtetra
.561 .821 .994 r
.70374 .55011 .7046 .55075 .70649 .55052 .70563 .54972 Mtetra
.74 .84 .926 r
.70563 .54972 .70649 .55052 .70835 .54968 .70748 .54873 Mtetra
.866 .821 .803 r
.70748 .54873 .70835 .54968 .7101 .54668 .70928 .5466 Mtetra
.984 .88 .644 r
.70928 .5466 .7101 .54668 .71122 .53252 .71095 .54228 Mtetra
.982 .695 .369 r
.71095 .54228 .71122 .53252 .70206 .33524 .70208 .34939 Mtetra
.038 0 .375 r
.70208 .34939 .70206 .33524 .70368 .33222 .7031 .33552 Mtetra
.044 0 .207 r
.7031 .33552 .70368 .33222 .70542 .33126 .70472 .33232 Mtetra
0 0 0 r
.70472 .33232 .70542 .33126 .70718 .33082 .7064 .33037 Mtetra
.783 .923 .929 r
.7064 .33037 .70718 .33082 .70896 .3304 .70813 .32922 Mtetra
.672 .725 .889 r
.70813 .32922 .70896 .3304 .71072 .32982 .70989 .32859 Mtetra
.635 .701 .894 r
.70989 .32859 .71072 .32982 .71249 .32926 .71167 .32813 Mtetra
.695 .743 .889 r
.71167 .32813 .71249 .32926 .71424 .32847 .71342 .32739 Mtetra
.741 .769 .876 r
.71342 .32739 .71424 .32847 .71598 .32756 .71516 .32639 Mtetra
.677 .73 .89 r
.71516 .32639 .71598 .32756 .71776 .32713 .71693 .32573 Mtetra
.416 .56 .89 r
.71693 .32573 .71776 .32713 .71965 .32844 .71876 .32612 Mtetra
0 .165 .683 r
.71876 .32612 .71965 .32844 .72205 .33803 .72072 .3286 Mtetra
0 0 .365 r
.72072 .3286 .72205 .33803 .73644 .53777 .72342 .34282 Mtetra
.048 0 .438 r
.72342 .34282 .73644 .53777 .73853 .54031 .73735 .53419 Mtetra
.385 .298 .634 r
.73735 .53419 .73853 .54031 .74047 .54029 .73945 .53674 Mtetra
.44 .397 .714 r
.73945 .53674 .74047 .54029 .74236 .53967 .74145 .53781 Mtetra
.458 .529 .843 r
.74145 .53781 .74236 .53967 .74427 .53917 .74342 .53823 Mtetra
.483 .71 .97 r
.74342 .53823 .74427 .53917 .74619 .53895 .74535 .53818 Mtetra
.65 .825 .967 r
.74535 .53818 .74619 .53895 .74808 .53818 .74726 .53756 Mtetra
.853 .895 .866 r
.74726 .53756 .74808 .53818 .74986 .53564 .74909 .53585 Mtetra
.975 .924 .634 r
.74909 .53585 .74986 .53564 .75113 .52576 .75077 .53198 Mtetra
0 0 .049 r
.75077 .53198 .75113 .52576 .73929 .32357 .75185 .51928 Mtetra
.044 0 .431 r
.75185 .51928 .73929 .32357 .74087 .31993 .74036 .32327 Mtetra
0 0 .198 r
.74036 .32327 .74087 .31993 .74261 .31881 .74194 .31964 Mtetra
.563 .818 .448 r
.74194 .31964 .74261 .31881 .7444 .31825 .74362 .31753 Mtetra
.796 .863 .899 r
.74362 .31753 .7444 .31825 .74619 .31781 .74536 .31629 Mtetra
.651 .663 .848 r
.74536 .31629 .74619 .31781 .74798 .31722 .74715 .31573 Mtetra
.609 .647 .863 r
.74715 .31573 .74798 .31722 .74977 .31668 .74896 .31539 Mtetra
.651 .7 .882 r
.74896 .31539 .74977 .31668 .75155 .31597 .75075 .31485 Mtetra
.733 .762 .876 r
.75075 .31485 .75155 .31597 .75332 .31505 .75251 .31388 Mtetra
.68 .733 .891 r
.75251 .31388 .75332 .31505 .75512 .31457 .7543 .3132 Mtetra
.474 .598 .896 r
.7543 .3132 .75512 .31457 .75702 .3155 .75615 .3134 Mtetra
.019 .205 .714 r
.75615 .3134 .75702 .3155 .75938 .32249 .75815 .31562 Mtetra
0 0 .461 r
.75815 .31562 .75938 .32249 .77646 .52526 .76068 .32482 Mtetra
.065 0 .448 r
.76068 .32482 .77646 .52526 .77867 .52848 .77743 .52222 Mtetra
.361 .281 .63 r
.77743 .52222 .77867 .52848 .78064 .52859 .77963 .52518 Mtetra
.41 .385 .721 r
.77963 .52518 .78064 .52859 .78257 .52805 .78169 .52645 Mtetra
.437 .555 .877 r
.78169 .52645 .78257 .52805 .78449 .52733 .7837 .52685 Mtetra
.428 .802 .993 r
.7837 .52685 .78449 .52733 .78642 .5268 .78565 .52663 Mtetra
.429 .861 .933 r
.78565 .52663 .78642 .5268 .78835 .52621 .78759 .52612 Mtetra
.412 .859 .898 r
.78759 .52612 .78835 .52621 .79029 .52574 .78952 .52555 Mtetra
.406 .846 .934 r
.78952 .52555 .79029 .52574 .79225 .52553 .79147 .5251 Mtetra
.649 .912 .98 r
.79147 .5251 .79225 .52553 .79418 .52486 .79339 .52432 Mtetra
.848 .92 .88 r
.79339 .52432 .79418 .52486 .796 .5228 .79524 .52266 Mtetra
.982 .9 .652 r
.79524 .52266 .796 .5228 .79734 .51503 .7969 .5187 Mtetra
.749 .665 .112 r
.7969 .5187 .79734 .51503 .78248 .31018 .79802 .50816 Mtetra
.069 0 .445 r
.79802 .50816 .78248 .31018 .78398 .30582 .78371 .3109 Mtetra
.414 .145 .394 r
.78371 .3109 .78398 .30582 .78575 .30477 .78544 .3093 Mtetra
.512 .214 .397 r
.78544 .3093 .78575 .30477 .78758 .30437 .78729 .30912 Mtetra
.544 .244 .408 r
.78729 .30912 .78758 .30437 .78942 .30414 .78918 .30939 Mtetra
.489 .207 .412 r
.78918 .30939 .78942 .30414 .79124 .30354 .79099 .30878 Mtetra
.491 .209 .412 r
.79099 .30878 .79124 .30354 .79305 .30296 .79282 .30819 Mtetra
.492 .209 .412 r
.79282 .30819 .79305 .30296 .79487 .30238 .79464 .30763 Mtetra
.493 .21 .413 r
.79464 .30763 .79487 .30238 .79669 .3018 .79646 .30706 Mtetra
.495 .212 .413 r
.79646 .30706 .79669 .3018 .79851 .30122 .79829 .30652 Mtetra
.498 .215 .415 r
.79829 .30652 .79851 .30122 .80033 .30065 .80013 .30603 Mtetra
.503 .22 .417 r
.80013 .30603 .80033 .30065 .80216 .30009 .80197 .3056 Mtetra
.507 .225 .42 r
.80197 .3056 .80216 .30009 .80399 .29954 .80381 .30522 Mtetra
.523 .239 .426 r
.80381 .30522 .80399 .29954 .80582 .29903 .80568 .30508 Mtetra
.569 .281 .438 r
.80568 .30508 .80582 .29903 .80765 .29856 .80764 .30584 Mtetra
.533 .262 .451 r
.80764 .30584 .80765 .29856 .80949 .29807 .80952 .30579 Mtetra
.416 .176 .44 r
.80952 .30579 .80949 .29807 .81132 .2975 .81117 .30324 Mtetra
.202 0 .364 r
.81117 .30324 .81132 .2975 .81313 .29672 .81265 .29879 Mtetra
0 0 .048 r
.81265 .29879 .81313 .29672 .81494 .29591 .81427 .29586 Mtetra
.868 .995 .801 r
.81427 .29586 .81494 .29591 .81675 .29513 .81597 .29393 Mtetra
.704 .742 .881 r
.81597 .29393 .81675 .29513 .81858 .29448 .81778 .2931 Mtetra
.652 .689 .872 r
.81778 .2931 .81858 .29448 .82041 .29386 .81962 .29254 Mtetra
.651 .698 .88 r
.81962 .29254 .82041 .29386 .82223 .29316 .82146 .29198 Mtetra
.756 .766 .861 r
.82146 .29198 .82223 .29316 .82402 .292 .82324 .29084 Mtetra
.684 .742 .895 r
.82324 .29084 .82402 .292 .82584 .29128 .82507 .29012 Mtetra
.404 .605 .929 r
.82507 .29012 .82584 .29128 .82776 .29158 .827 .29044 Mtetra
.823 .417 0 r
.827 .29044 .82776 .29158 .83025 .29757 .82948 .29641 Mtetra
.973 .661 .312 r
.82948 .29641 .83025 .29757 .85235 .50269 .85155 .50161 Mtetra
.691 .249 0 r
.85155 .50161 .85235 .50269 .85478 .50673 .85398 .50565 Mtetra
.343 .603 .945 r
.85398 .50565 .85478 .50673 .85686 .50713 .85605 .50606 Mtetra
.669 .771 .927 r
.85605 .50606 .85686 .50713 .85883 .50645 .85802 .50537 Mtetra
.849 .821 .822 r
.85802 .50537 .85883 .50645 .86067 .50451 .85987 .50343 Mtetra
.977 .78 .572 r
.85987 .50343 .86067 .50451 .86204 .49789 .86124 .49681 Mtetra
.976 .67 .326 r
.86124 .49681 .86204 .49789 .84293 .2909 .84217 .28977 Mtetra
.966 .78 .602 r
.84217 .28977 .84293 .2909 .84429 .28549 .84353 .28436 Mtetra
.762 .778 .866 r
.84353 .28436 .84429 .28549 .84608 .28433 .84532 .28319 Mtetra
.633 .728 .916 r
.84532 .28319 .84608 .28433 .84794 .28385 .84718 .28271 Mtetra
.557 .692 .93 r
.84718 .28271 .84794 .28385 .84984 .28367 .84908 .28253 Mtetra
.753 .775 .871 r
.84908 .28253 .84984 .28367 .85164 .28256 .85088 .28142 Mtetra
.686 .75 .901 r
.85088 .28142 .85164 .28256 .85348 .28184 .85272 .2807 Mtetra
.486 .654 .934 r
.85272 .2807 .85348 .28184 .8554 .2819 .85465 .28076 Mtetra
.733 .314 0 r
.85465 .28076 .8554 .2819 .85783 .28665 .85708 .2855 Mtetra
.971 .656 .295 r
.85708 .2855 .85783 .28665 .88195 .49266 .88115 .49155 Mtetra
.743 .315 0 r
.88115 .49155 .88195 .49266 .88454 .49759 .88374 .4965 Mtetra
.469 .672 .952 r
.88374 .4965 .88454 .49759 .88661 .49768 .88581 .49656 Mtetra
.672 .765 .92 r
.88581 .49656 .88661 .49768 .88859 .49698 .8878 .49585 Mtetra
.739 .788 .893 r
.8878 .49585 .88859 .49698 .89054 .49588 .88975 .49479 Mtetra
.368 .65 .965 r
.2486 .68194 .24966 .68283 .25119 .68307 .25014 .68213 Mtetra
.568 .721 .946 r
.25014 .68213 .25119 .68307 .25276 .68291 .25171 .68192 Mtetra
.739 .754 .865 r
.25171 .68192 .25276 .68291 .25439 .68201 .25334 .68097 Mtetra
.899 .729 .662 r
.25334 .68097 .25439 .68201 .25633 .67692 .2553 .67571 Mtetra
.936 .686 .534 r
.2553 .67571 .25633 .67692 .27291 .48001 .27195 .47873 Mtetra
.896 .708 .64 r
.27195 .47873 .27291 .48001 .27487 .47354 .27389 .47255 Mtetra
.771 .748 .833 r
.27389 .47255 .27487 .47354 .27643 .47235 .27544 .47139 Mtetra
.629 .725 .917 r
.27544 .47139 .27643 .47235 .27792 .47196 .27694 .47102 Mtetra
.484 .677 .95 r
.27694 .47102 .27792 .47196 .27939 .47197 .27841 .47104 Mtetra
.687 .745 .896 r
.27841 .47104 .27939 .47197 .28092 .47121 .27992 .47043 Mtetra
.678 .778 .926 r
.27992 .47043 .28092 .47121 .28244 .47062 .28144 .46988 Mtetra
.621 .774 .954 r
.28144 .46988 .28244 .47062 .28392 .47044 .28294 .4695 Mtetra
.497 .682 .949 r
.28294 .4695 .28392 .47044 .28528 .47199 .28441 .46949 Mtetra
.464 .444 .752 r
.28441 .46949 .28528 .47199 .28642 .47668 .28585 .46999 Mtetra
.447 .316 .609 r
.28585 .46999 .28642 .47668 .27416 .66795 .28722 .47157 Mtetra
0 0 .265 r
.28722 .47157 .27416 .66795 .27543 .67204 .27559 .65435 Mtetra
0 0 .33 r
.27559 .65435 .27543 .67204 .27689 .67362 .27601 .67038 Mtetra
0 .004 .558 r
.27601 .67038 .27689 .67362 .27842 .67427 .27738 .67322 Mtetra
.34 .598 .942 r
.27738 .67322 .27842 .67427 .27998 .67438 .27893 .67353 Mtetra
.643 .768 .939 r
.27893 .67353 .27998 .67438 .28159 .67397 .28054 .67307 Mtetra
.747 .775 .876 r
.28054 .67307 .28159 .67397 .28323 .67296 .28218 .6721 Mtetra
.764 .783 .869 r
.28218 .6721 .28323 .67296 .28499 .67033 .28383 .67102 Mtetra
.737 .981 .752 r
.28383 .67102 .28499 .67033 .28695 .66468 .28552 .66939 Mtetra
.161 0 .252 r
.28552 .66939 .28695 .66468 .3016 .47185 .28729 .66657 Mtetra
0 0 .254 r
.28729 .66657 .3016 .47185 .30345 .46648 .30144 .48086 Mtetra
0 0 .107 r
.30144 .48086 .30345 .46648 .30511 .46396 .30399 .46507 Mtetra
.958 .945 .653 r
.30399 .46507 .30511 .46396 .3067 .46238 .30571 .46162 Mtetra
.771 .796 .873 r
.30571 .46162 .3067 .46238 .30823 .4617 .30727 .46058 Mtetra
.618 .689 .894 r
.30727 .46058 .30823 .4617 .30974 .46141 .30878 .46025 Mtetra
.524 .647 .912 r
.30878 .46025 .30974 .46141 .31124 .46128 .31028 .46024 Mtetra
.62 .706 .907 r
.31028 .46024 .31124 .46128 .31276 .4609 .31179 .4599 Mtetra
.653 .724 .902 r
.31179 .4599 .31276 .4609 .31429 .46041 .31332 .45944 Mtetra
.666 .734 .901 r
.31332 .45944 .31429 .46041 .31582 .45985 .31485 .45892 Mtetra
.687 .749 .899 r
.31485 .45892 .31582 .45985 .31736 .45917 .31638 .45831 Mtetra
.697 .765 .905 r
.31638 .45831 .31736 .45917 .3189 .45846 .31792 .45766 Mtetra
.697 .78 .915 r
.31792 .45766 .3189 .45846 .32044 .45776 .31946 .45701 Mtetra
.709 .794 .917 r
.31946 .45701 .32044 .45776 .32199 .45693 .321 .45631 Mtetra
.685 .823 .949 r
.321 .45631 .32199 .45693 .32354 .45627 .32254 .45571 Mtetra
.61 .821 .981 r
.32254 .45571 .32354 .45627 .32505 .45601 .32407 .4553 Mtetra
.213 .605 .95 r
.32407 .4553 .32505 .45601 .32647 .45737 .32555 .45561 Mtetra
.271 .407 .817 r
.32555 .45561 .32647 .45737 .32773 .46151 .32701 .45646 Mtetra
.447 .34 .64 r
.32701 .45646 .32773 .46151 .3178 .65347 .32844 .45768 Mtetra
.549 .334 .54 r
.32844 .45768 .3178 .65347 .31922 .65651 .32993 .45794 Mtetra
.551 .335 .54 r
.32993 .45794 .31922 .65651 .32085 .65607 .33148 .45736 Mtetra
.551 .336 .541 r
.33148 .45736 .32085 .65607 .32253 .65458 .33304 .45649 Mtetra
.552 .336 .541 r
.33304 .45649 .32253 .65458 .32423 .65302 .33462 .45529 Mtetra
.551 .336 .541 r
.33462 .45529 .32423 .65302 .32589 .652 .33618 .45445 Mtetra
.549 .334 .54 r
.33618 .45445 .32589 .652 .32748 .65229 .33769 .45453 Mtetra
.534 .322 .538 r
.33769 .45453 .32748 .65229 .32892 .65523 .3388 .46175 Mtetra
0 0 .262 r
.3388 .46175 .32892 .65523 .3304 .65752 .32951 .65397 Mtetra
0 0 .477 r
.32951 .65397 .3304 .65752 .33193 .65883 .33092 .65761 Mtetra
.231 .499 .901 r
.33092 .65761 .33193 .65883 .33354 .65894 .3325 .65822 Mtetra
.617 .794 .967 r
.3325 .65822 .33354 .65894 .33518 .65849 .33414 .6578 Mtetra
.709 .821 .934 r
.33414 .6578 .33518 .65849 .33683 .65788 .3358 .65706 Mtetra
.647 .778 .943 r
.3358 .65706 .33683 .65788 .33847 .65748 .33744 .65657 Mtetra
.609 .745 .942 r
.33744 .65657 .33847 .65748 .3401 .6572 .33908 .65621 Mtetra
.622 .736 .928 r
.33908 .65621 .3401 .6572 .34174 .65686 .34072 .65583 Mtetra
.634 .728 .916 r
.34072 .65583 .34174 .65686 .34337 .65656 .34236 .6554 Mtetra
.66 .712 .886 r
.34236 .6554 .34337 .65656 .34502 .6561 .34401 .65486 Mtetra
.694 .709 .859 r
.34401 .65486 .34502 .6561 .34669 .65525 .34567 .65413 Mtetra
.776 .745 .825 r
.34567 .65413 .34669 .65525 .34843 .65296 .34736 .6528 Mtetra
.885 .912 .84 r
.34736 .6528 .34843 .65296 .35029 .64819 .34909 .65092 Mtetra
0 0 .053 r
.34909 .65092 .35029 .64819 .36146 .45676 .35082 .64868 Mtetra
.547 .328 .534 r
.35082 .64868 .36146 .45676 .36331 .45037 .3525 .64772 Mtetra
.548 .329 .534 r
.3525 .64772 .36331 .45037 .36486 .44999 .35413 .64758 Mtetra
.547 .328 .534 r
.35413 .64758 .36486 .44999 .3664 .44996 .3558 .64682 Mtetra
.538 .32 .532 r
.3558 .64682 .3664 .44996 .36809 .44678 .35772 .64075 Mtetra
0 0 .264 r
.35772 .64075 .36809 .44678 .36978 .44352 .36868 .44552 Mtetra
.926 .901 .5 r
.36868 .44552 .36978 .44352 .37142 .44128 .37045 .44073 Mtetra
.859 .836 .823 r
.37045 .44073 .37142 .44128 .37301 .44011 .37207 .43899 Mtetra
.681 .714 .874 r
.37207 .43899 .37301 .44011 .37457 .43954 .37363 .43838 Mtetra
.595 .676 .897 r
.37363 .43838 .37457 .43954 .37613 .43919 .37518 .43813 Mtetra
.596 .697 .914 r
.37518 .43813 .37613 .43919 .37768 .43887 .37673 .43787 Mtetra
.62 .72 .917 r
.37673 .43787 .37768 .43887 .37924 .43851 .37829 .43751 Mtetra
.625 .723 .917 r
.37829 .43751 .37924 .43851 .3808 .43812 .37985 .43714 Mtetra
.662 .738 .907 r
.37985 .43714 .3808 .43812 .38237 .43755 .38142 .43663 Mtetra
.69 .757 .903 r
.38142 .43663 .38237 .43755 .38394 .43685 .38299 .43599 Mtetra
.696 .773 .91 r
.38299 .43599 .38394 .43685 .38552 .43613 .38456 .43533 Mtetra
.707 .788 .915 r
.38456 .43533 .38552 .43613 .3871 .43532 .38614 .43463 Mtetra
.696 .813 .937 r
.38614 .43463 .3871 .43532 .38868 .43457 .38772 .43397 Mtetra
.636 .822 .972 r
.38772 .43397 .38868 .43457 .39024 .43418 .38929 .43349 Mtetra
.499 .754 .986 r
.38929 .43349 .39024 .43418 .39177 .43487 .39084 .43336 Mtetra
.418 .534 .867 r
.39084 .43336 .39177 .43487 .39321 .43757 .39238 .43375 Mtetra
.403 .343 .676 r
.39238 .43375 .39321 .43757 .38733 .62392 .39388 .43499 Mtetra
.537 .324 .538 r
.39388 .43499 .38733 .62392 .38843 .63768 .39521 .44067 Mtetra
0 0 .298 r
.39521 .44067 .38843 .63768 .38999 .64014 .38912 .63558 Mtetra
0 .004 .532 r
.38912 .63558 .38999 .64014 .3916 .6412 .39062 .63958 Mtetra
.177 .392 .834 r
.39062 .63958 .3916 .6412 .39325 .64135 .39224 .64057 Mtetra
.597 .777 .966 r
.39224 .64057 .39325 .64135 .39493 .64093 .39391 .64021 Mtetra
.71 .822 .934 r
.39391 .64021 .39493 .64093 .39661 .64027 .3956 .63945 Mtetra
.703 .796 .922 r
.3956 .63945 .39661 .64027 .3983 .63964 .39729 .63871 Mtetra
.66 .762 .925 r
.39729 .63871 .3983 .63964 .39998 .63914 .39898 .63816 Mtetra
.661 .753 .918 r
.39898 .63816 .39998 .63914 .40166 .63864 .40066 .63761 Mtetra
.658 .742 .912 r
.40066 .63761 .40166 .63864 .40334 .63814 .40235 .63708 Mtetra
.654 .733 .908 r
.40235 .63708 .40334 .63814 .40503 .63764 .40403 .63656 Mtetra
.652 .729 .906 r
.40403 .63656 .40503 .63764 .40671 .63714 .40572 .63605 Mtetra
.651 .726 .904 r
.40572 .63605 .40671 .63714 .4084 .63664 .4074 .63554 Mtetra
.65 .725 .904 r
.4074 .63554 .4084 .63664 .41009 .63615 .40909 .63504 Mtetra
.648 .724 .904 r
.40909 .63504 .41009 .63615 .41177 .63565 .41078 .63455 Mtetra
.647 .724 .905 r
.41078 .63455 .41177 .63565 .41346 .63515 .41247 .63406 Mtetra
.646 .725 .906 r
.41247 .63406 .41346 .63515 .41515 .63466 .41416 .63357 Mtetra
.644 .726 .908 r
.41416 .63357 .41515 .63466 .41685 .63416 .41585 .63309 Mtetra
.64 .729 .913 r
.41585 .63309 .41685 .63416 .41854 .63366 .41754 .63263 Mtetra
.635 .734 .92 r
.41754 .63263 .41854 .63366 .42023 .63317 .41924 .63218 Mtetra
.635 .745 .927 r
.41924 .63218 .42023 .63317 .42193 .63267 .42093 .63173 Mtetra
.588 .739 .948 r
.42093 .63173 .42193 .63267 .42362 .63228 .42262 .63144 Mtetra
.546 .748 .97 r
.42262 .63144 .42362 .63228 .42531 .63194 .42431 .63123 Mtetra
.666 .815 .955 r
.42431 .63123 .42531 .63194 .42701 .6314 .42601 .63063 Mtetra
.849 .814 .815 r
.42601 .63063 .42701 .6314 .42873 .63017 .42775 .62876 Mtetra
.899 .724 .656 r
.42775 .62876 .42873 .63017 .43048 .62777 .42958 .62363 Mtetra
.951 .686 .497 r
.42958 .62363 .43048 .62777 .43226 .62434 .4366 .42715 Mtetra
.561 .344 .542 r
.4366 .42715 .43226 .62434 .43403 .6212 .43835 .42113 Mtetra
.551 .335 .54 r
.43835 .42113 .43403 .6212 .43571 .62123 .43996 .42039 Mtetra
.55 .334 .54 r
.43996 .42039 .43571 .62123 .43741 .62092 .44155 .42024 Mtetra
.551 .336 .541 r
.44155 .42024 .43741 .62092 .43924 .61534 .44317 .41927 Mtetra
.554 .338 .541 r
.44317 .41927 .43924 .61534 .44566 .42146 .44482 .41706 Mtetra
.679 .514 .656 r
.44482 .41706 .44566 .42146 .44737 .41685 .44646 .41523 Mtetra
.74 .67 .782 r
.44646 .41523 .44737 .41685 .44901 .41472 .44808 .414 Mtetra
.683 .807 .941 r
.44808 .414 .44901 .41472 .45062 .41399 .44969 .41337 Mtetra
.615 .818 .978 r
.44969 .41337 .45062 .41399 .45222 .41364 .45129 .41294 Mtetra
.596 .792 .974 r
.45129 .41294 .45222 .41364 .45382 .4134 .4529 .41259 Mtetra
.619 .768 .951 r
.4529 .41259 .45382 .4134 .45543 .41305 .4545 .41219 Mtetra
.62 .757 .944 r
.4545 .41219 .45543 .41305 .45703 .41273 .45611 .41181 Mtetra
.635 .749 .93 r
.45611 .41181 .45703 .41273 .45864 .41235 .45772 .41138 Mtetra
.657 .744 .914 r
.45772 .41138 .45864 .41235 .46025 .41186 .45933 .41087 Mtetra
.67 .742 .905 r
.45933 .41087 .46025 .41186 .46187 .41132 .46095 .4103 Mtetra
.685 .743 .895 r
.46095 .4103 .46187 .41132 .46348 .41069 .46257 .40967 Mtetra
.701 .746 .886 r
.46257 .40967 .46348 .41069 .4651 .40998 .46418 .40895 Mtetra
.701 .745 .886 r
.46418 .40895 .4651 .40998 .46672 .40926 .4658 .40823 Mtetra
.71 .748 .881 r
.4658 .40823 .46672 .40926 .46834 .40853 .46743 .40747 Mtetra
.722 .743 .869 r
.46743 .40747 .46834 .40853 .46996 .4078 .46905 .40662 Mtetra
.654 .701 .881 r
.46905 .40662 .46996 .4078 .47158 .40728 .47067 .40612 Mtetra
.339 .559 .917 r
.47067 .40612 .47158 .40728 .47319 .40727 .47227 .40654 Mtetra
.871 .429 .064 r
.47227 .40654 .47319 .40727 .47479 .40838 .47383 .4098 Mtetra
.957 .682 .474 r
.47383 .4098 .47479 .40838 .47637 .41047 .47247 .60444 Mtetra
.562 .34 .536 r
.47247 .60444 .47637 .41047 .47794 .41346 .47408 .61193 Mtetra
.549 .33 .534 r
.47408 .61193 .47794 .41346 .47956 .41381 .4758 .61209 Mtetra
.547 .328 .534 r
.4758 .61209 .47956 .41381 .4812 .41271 .47753 .61126 Mtetra
.47753 .61126 .4812 .41271 .48284 .41137 .47927 .61013 Mtetra
.548 .329 .534 r
.47927 .61013 .48284 .41137 .48447 .41081 .481 .60962 Mtetra
.481 .60962 .48447 .41081 .4861 .41024 .48273 .6091 Mtetra
.48273 .6091 .4861 .41024 .48773 .40965 .48446 .60856 Mtetra
.48446 .60856 .48773 .40965 .48936 .40902 .4862 .60802 Mtetra
.4862 .60802 .48936 .40902 .491 .4084 .48793 .60748 Mtetra
.548 .328 .534 r
.48793 .60748 .491 .4084 .49264 .40753 .48967 .60685 Mtetra
.547 .328 .534 r
.48967 .60685 .49264 .40753 .49428 .40597 .49141 .60596 Mtetra
.548 .329 .534 r
.49141 .60596 .49428 .40597 .49592 .40542 .49315 .60539 Mtetra
.549 .33 .534 r
.49315 .60539 .49592 .40542 .49753 .40785 .49488 .60562 Mtetra
.551 .331 .534 r
.49488 .60562 .49753 .40785 .49761 .60307 .49661 .607 Mtetra
.598 .281 .402 r
.49661 .607 .49761 .60307 .49931 .6079 .49834 .60801 Mtetra
.372 0 0 r
.49834 .60801 .49931 .6079 .50104 .60964 .50008 .60846 Mtetra
.619 .706 .907 r
.50008 .60846 .50104 .60964 .50278 .60944 .50182 .60808 Mtetra
.664 .691 .865 r
.50182 .60808 .50278 .60944 .50453 .60879 .50357 .60747 Mtetra
.679 .703 .865 r
.50357 .60747 .50453 .60879 .50628 .60798 .50532 .60679 Mtetra
.655 .717 .894 r
.50532 .60679 .50628 .60798 .50803 .60743 .50707 .60624 Mtetra
.655 .716 .894 r
.50707 .60624 .50803 .60743 .50978 .60689 .50882 .6057 Mtetra
.654 .716 .894 r
.50882 .6057 .50978 .60689 .51153 .60634 .51057 .60516 Mtetra
.652 .717 .896 r
.51057 .60516 .51153 .60634 .51329 .60581 .51233 .60463 Mtetra
.651 .716 .896 r
.51233 .60463 .51329 .60581 .51504 .60529 .51408 .6041 Mtetra
.65 .716 .896 r
.51408 .6041 .51504 .60529 .51679 .60477 .51584 .60358 Mtetra
.649 .716 .897 r
.51584 .60358 .51679 .60477 .51855 .60425 .51759 .60306 Mtetra
.648 .716 .897 r
.51759 .60306 .51855 .60425 .52031 .60373 .51935 .60254 Mtetra
.648 .715 .897 r
.51935 .60254 .52031 .60373 .52206 .60322 .52111 .60203 Mtetra
.647 .715 .898 r
.52111 .60203 .52206 .60322 .52382 .60271 .52287 .60152 Mtetra
.646 .715 .898 r
.52287 .60152 .52382 .60271 .52558 .60221 .52463 .60102 Mtetra
.645 .714 .898 r
.52463 .60102 .52558 .60221 .52735 .60171 .52639 .60052 Mtetra
.643 .713 .899 r
.52639 .60052 .52735 .60171 .52911 .60122 .52816 .60002 Mtetra
.642 .712 .898 r
.52816 .60002 .52911 .60122 .53087 .60073 .52992 .59954 Mtetra
.639 .711 .899 r
.52992 .59954 .53087 .60073 .53264 .60027 .53168 .59906 Mtetra
.606 .697 .908 r
.53168 .59906 .53264 .60027 .5344 .60008 .53345 .59873 Mtetra
.636 .684 .878 r
.53345 .59873 .5344 .60008 .53617 .59962 .53522 .59827 Mtetra
.685 .701 .86 r
.53522 .59827 .53617 .59962 .53794 .59862 .53699 .59754 Mtetra
.814 .776 .817 r
.53699 .59754 .53794 .59862 .53969 .5953 .53875 .59587 Mtetra
.815 .985 .715 r
.53875 .59587 .53969 .5953 .54143 .58806 .54052 .59374 Mtetra
.338 .081 .369 r
.54052 .59374 .54143 .58806 .54214 .39146 .54228 .59132 Mtetra
.547 .328 .534 r
.54228 .59132 .54214 .39146 .5438 .38951 .54405 .5904 Mtetra
.548 .329 .534 r
.54405 .5904 .5438 .38951 .54547 .38923 .54582 .59004 Mtetra
.549 .329 .534 r
.54582 .59004 .54547 .38923 .54715 .38987 .5476 .58993 Mtetra
.548 .329 .534 r
.5476 .58993 .54715 .38987 .54881 .38941 .54937 .58946 Mtetra
.54937 .58946 .54881 .38941 .55049 .38897 .55115 .58898 Mtetra
.55115 .58898 .55049 .38897 .55216 .38854 .55292 .58851 Mtetra
.55292 .58851 .55216 .38854 .55383 .38807 .5547 .58803 Mtetra
.5547 .58803 .55383 .38807 .5555 .38759 .55648 .58754 Mtetra
.55648 .58754 .5555 .38759 .55718 .38708 .55826 .58702 Mtetra
.549 .33 .534 r
.55826 .58702 .55718 .38708 .55887 .38758 .56005 .58721 Mtetra
.548 .329 .534 r
.56005 .58721 .55887 .38758 .56055 .38735 .56184 .58683 Mtetra
.546 .327 .534 r
.56184 .58683 .56055 .38735 .56221 .38545 .56361 .58532 Mtetra
.514 .303 .53 r
.56361 .58532 .56221 .38545 .56384 .38092 .56517 .56589 Mtetra
0 0 .364 r
.56517 .56589 .56384 .38092 .56548 .37791 .56463 .37862 Mtetra
.966 .929 .612 r
.56463 .37862 .56548 .37791 .56714 .37583 .56626 .37484 Mtetra
.766 .777 .862 r
.56626 .37484 .56714 .37583 .56881 .37497 .56793 .37372 Mtetra
.654 .696 .877 r
.56793 .37372 .56881 .37497 .57049 .37444 .56961 .37319 Mtetra
.59 .671 .895 r
.56961 .37319 .57049 .37444 .57217 .37406 .5713 .37295 Mtetra
.657 .722 .897 r
.5713 .37295 .57217 .37406 .57385 .37351 .57298 .37242 Mtetra
.659 .727 .9 r
.57298 .37242 .57385 .37351 .57553 .37295 .57466 .37188 Mtetra
.652 .729 .905 r
.57466 .37188 .57553 .37295 .57722 .37242 .57634 .37137 Mtetra
.629 .725 .916 r
.57634 .37137 .57722 .37242 .5789 .37201 .57803 .37095 Mtetra
.626 .724 .917 r
.57803 .37095 .5789 .37201 .58059 .3716 .57972 .37055 Mtetra
.636 .728 .915 r
.57972 .37055 .58059 .3716 .58228 .37114 .5814 .3701 Mtetra
.679 .746 .902 r
.5814 .3701 .58228 .37114 .58396 .37045 .58309 .36947 Mtetra
.693 .763 .905 r
.58309 .36947 .58396 .37045 .58564 .3697 .58478 .36878 Mtetra
.695 .777 .914 r
.58478 .36878 .58564 .3697 .58733 .36895 .58646 .36808 Mtetra
.703 .79 .919 r
.58646 .36808 .58733 .36895 .58901 .36807 .58815 .36735 Mtetra
.674 .818 .953 r
.58815 .36735 .58901 .36807 .5907 .3674 .58984 .36672 Mtetra
.602 .808 .979 r
.58984 .36672 .5907 .3674 .5924 .36715 .59153 .36631 Mtetra
.287 .612 .956 r
.59153 .36631 .5924 .36715 .59414 .36869 .59325 .36665 Mtetra
.363 .435 .801 r
.59325 .36665 .59414 .36869 .59594 .37325 .59497 .36749 Mtetra
.474 .355 .637 r
.59497 .36749 .59594 .37325 .60214 .57023 .59671 .36871 Mtetra
.551 .335 .54 r
.59671 .36871 .60214 .57023 .604 .57201 .59841 .36815 Mtetra
.59841 .36815 .604 .57201 .6058 .57118 .6001 .36728 Mtetra
.55 .334 .54 r
.6001 .36728 .6058 .57118 .6076 .57031 .60181 .36718 Mtetra
.528 .318 .538 r
.60181 .36718 .6076 .57031 .60949 .57304 .6038 .37849 Mtetra
0 0 .395 r
.6038 .37849 .60949 .57304 .61137 .57516 .6104 .57176 Mtetra
0 .095 .615 r
.6104 .57176 .61137 .57516 .61324 .57636 .61231 .57509 Mtetra
.393 .585 .919 r
.61231 .57509 .61324 .57636 .61507 .57633 .61415 .57545 Mtetra
.642 .783 .949 r
.61415 .57545 .61507 .57633 .61689 .57583 .61597 .57491 Mtetra
.719 .799 .914 r
.61597 .57491 .61689 .57583 .6187 .57514 .61779 .57405 Mtetra
.638 .737 .92 r
.61779 .57405 .6187 .57514 .62053 .57483 .61961 .57355 Mtetra
.633 .7 .894 r
.61961 .57355 .62053 .57483 .62236 .57444 .62144 .57309 Mtetra
.673 .704 .87 r
.62144 .57309 .62236 .57444 .62417 .57362 .62326 .57242 Mtetra
.747 .752 .856 r
.62326 .57242 .62417 .57362 .62594 .57124 .62507 .5713 Mtetra
.834 .996 .846 r
.62507 .5713 .62594 .57124 .62764 .56639 .62686 .56958 Mtetra
.062 0 .176 r
.62686 .56958 .62764 .56639 .62337 .36845 .62861 .56677 Mtetra
.529 .314 .532 r
.62861 .56677 .62337 .36845 .62485 .36042 .6301 .55538 Mtetra
0 0 .39 r
.6301 .55538 .62485 .36042 .62649 .35748 .62572 .35898 Mtetra
.796 .846 .388 r
.62572 .35898 .62649 .35748 .62817 .35568 .62732 .35498 Mtetra
.818 .852 .874 r
.62732 .35498 .62817 .35568 .62987 .3548 .62901 .3536 Mtetra
.637 .702 .893 r
.62901 .3536 .62987 .3548 .63159 .35439 .63073 .35315 Mtetra
.553 .657 .905 r
.63073 .35315 .63159 .35439 .63332 .35417 .63247 .35303 Mtetra
.615 .706 .91 r
.63247 .35303 .63332 .35417 .63504 .35374 .63419 .35267 Mtetra
.657 .736 .907 r
.63419 .35267 .63504 .35374 .63676 .35316 .63591 .35212 Mtetra
.67 .747 .908 r
.63591 .35212 .63676 .35316 .63848 .35252 .63763 .35152 Mtetra
.715 .77 .896 r
.63763 .35152 .63848 .35252 .64018 .35154 .63934 .3507 Mtetra
.721 .808 .918 r
.63934 .3507 .64018 .35154 .64189 .3506 .64106 .34987 Mtetra
.674 .822 .954 r
.64106 .34987 .64189 .3506 .64361 .35005 .64278 .34923 Mtetra
.534 .747 .974 r
.64278 .34923 .64361 .35005 .64539 .35085 .64452 .34904 Mtetra
.462 .522 .833 r
.64452 .34904 .64539 .35085 .64725 .35379 .64628 .34942 Mtetra
.433 .356 .669 r
.64628 .34942 .64725 .35379 .6566 .54826 .64808 .35076 Mtetra
.536 .324 .539 r
.64808 .35076 .6566 .54826 .65885 .55817 .65012 .35808 Mtetra
.001 0 .412 r
.65012 .35808 .65885 .55817 .66081 .5605 .65979 .55635 Mtetra
.079 .131 .616 r
.65979 .55635 .66081 .5605 .66272 .56147 .66181 .56002 Mtetra
.315 .507 .886 r
.66181 .56002 .66272 .56147 .6646 .5615 .66371 .5607 Mtetra
.611 .798 .971 r
.66371 .5607 .6646 .5615 .66645 .561 .66557 .56024 Mtetra
.713 .838 .941 r
.66557 .56024 .66645 .561 .6683 .56028 .66741 .55939 Mtetra
.66 .792 .945 r
.66741 .55939 .6683 .56028 .67016 .55986 .66926 .55877 Mtetra
.635 .74 .924 r
.66926 .55877 .67016 .55986 .67202 .55949 .67112 .55829 Mtetra
.679 .734 .892 r
.67112 .55829 .67202 .55949 .67386 .5587 .67297 .55759 Mtetra
.751 .773 .871 r
.67297 .55759 .67386 .5587 .67565 .55649 .6748 .55647 Mtetra
.84 .993 .85 r
.6748 .55647 .67565 .55649 .67731 .55155 .67661 .55473 Mtetra
.07 0 .187 r
.67661 .55473 .67731 .55155 .67008 .35231 .67836 .55187 Mtetra
.531 .316 .533 r
.67836 .55187 .67008 .35231 .67149 .34459 .67975 .54112 Mtetra
.003 0 .408 r
.67975 .54112 .67149 .34459 .67312 .34168 .67242 .34349 Mtetra
.672 .753 .26 r
.67242 .34349 .67312 .34168 .67481 .33983 .674 .33933 Mtetra
.878 .901 .843 r
.674 .33933 .67481 .33983 .67652 .33856 .67569 .33754 Mtetra
.7 .763 .901 r
.67569 .33754 .67652 .33856 .67825 .33776 .67742 .33679 Mtetra
.579 .728 .945 r
.67742 .33679 .67825 .33776 .68001 .33745 .67918 .33652 Mtetra
.486 .695 .961 r
.67918 .33652 .68001 .33745 .68182 .33816 .68096 .3365 Mtetra
.467 .544 .852 r
.68096 .3365 .68182 .33816 .68372 .34066 .68275 .33682 Mtetra
.442 .377 .69 r
.68275 .33682 .68372 .34066 .68615 .35348 .68459 .33794 Mtetra
.426 .27 .566 r
.68459 .33794 .68615 .35348 .69782 .54591 .68662 .34288 Mtetra
.024 0 .425 r
.68662 .34288 .69782 .54591 .69986 .54872 .69877 .54362 Mtetra
.107 .125 .596 r
.69877 .54362 .69986 .54872 .70182 .54986 .70091 .54806 Mtetra
.278 .43 .835 r
.70091 .54806 .70182 .54986 .70374 .55011 .70287 .54909 Mtetra
.609 .747 .943 r
.70287 .54909 .70374 .55011 .70563 .54972 .70475 .54868 Mtetra
.735 .788 .895 r
.70475 .54868 .70563 .54972 .70748 .54873 .70661 .54769 Mtetra
.77 .796 .875 r
.70661 .54769 .70748 .54873 .70928 .5466 .70845 .54647 Mtetra
.8 .986 .891 r
.70845 .54647 .70928 .5466 .71095 .54228 .71028 .545 Mtetra
.112 0 .168 r
.71028 .545 .71095 .54228 .70208 .34939 .71207 .54269 Mtetra
.539 .322 .533 r
.71207 .54269 .70208 .34939 .7031 .33552 .71364 .53664 Mtetra
.025 0 .42 r
.71364 .53664 .7031 .33552 .70472 .33232 .70413 .33541 Mtetra
0 0 .001 r
.70413 .33541 .70472 .33232 .7064 .33037 .70563 .33008 Mtetra
.908 .939 .816 r
.70563 .33008 .7064 .33037 .70813 .32922 .70731 .32802 Mtetra
.687 .727 .881 r
.70731 .32802 .70813 .32922 .70989 .32859 .70906 .32731 Mtetra
.61 .682 .893 r
.70906 .32731 .70989 .32859 .71167 .32813 .71084 .32697 Mtetra
.653 .721 .898 r
.71084 .32697 .71167 .32813 .71342 .32739 .71261 .32642 Mtetra
.72 .787 .905 r
.71261 .32642 .71342 .32739 .71516 .32639 .71436 .32557 Mtetra
.686 .81 .941 r
.71436 .32557 .71516 .32639 .71693 .32573 .71613 .32488 Mtetra
.579 .762 .965 r
.71613 .32488 .71693 .32573 .71876 .32612 .71791 .32456 Mtetra
.478 .567 .867 r
.71791 .32456 .71876 .32612 .72072 .3286 .71973 .32481 Mtetra
.452 .387 .694 r
.71973 .32481 .72072 .3286 .72342 .34282 .72161 .32585 Mtetra
.462 .295 .568 r
.72161 .32585 .72342 .34282 .73735 .53419 .72368 .32995 Mtetra
.047 0 .438 r
.72368 .32995 .73735 .53419 .73945 .53674 .73827 .53068 Mtetra
.148 .137 .588 r
.73827 .53068 .73945 .53674 .74145 .53781 .74053 .53572 Mtetra
.227 .362 .792 r
.74053 .53572 .74145 .53781 .74342 .53823 .74256 .53715 Mtetra
.521 .699 .95 r
.74256 .53715 .74342 .53823 .74535 .53818 .74449 .53705 Mtetra
.677 .754 .909 r
.74449 .53705 .74535 .53818 .74726 .53756 .74639 .53635 Mtetra
.745 .763 .868 r
.74639 .53635 .74726 .53756 .74909 .53585 .74826 .53524 Mtetra
.83 .901 .89 r
.74826 .53524 .74909 .53585 .75077 .53198 .7501 .53372 Mtetra
0 0 0 r
.7501 .53372 .75077 .53198 .75185 .51928 .75189 .53129 Mtetra
.337 .133 .449 r
.75189 .53129 .75185 .51928 .74036 .32327 .75343 .52535 Mtetra
.043 0 .431 r
.75343 .52535 .74036 .32327 .74194 .31964 .74142 .32275 Mtetra
0 0 .029 r
.74142 .32275 .74194 .31964 .74362 .31753 .74288 .31733 Mtetra
.92 .956 .794 r
.74288 .31733 .74362 .31753 .74536 .31629 .74455 .31512 Mtetra
.678 .732 .891 r
.74455 .31512 .74536 .31629 .74715 .31573 .74633 .31445 Mtetra
.59 .674 .898 r
.74633 .31445 .74715 .31573 .74896 .31539 .74815 .31419 Mtetra
.611 .697 .905 r
.74815 .31419 .74896 .31539 .75075 .31485 .74995 .31382 Mtetra
.708 .773 .903 r
.74995 .31382 .75075 .31485 .75251 .31388 .75173 .31302 Mtetra
.681 .801 .939 r
.75173 .31302 .75251 .31388 .7543 .3132 .75351 .31234 Mtetra
.587 .765 .964 r
.75351 .31234 .7543 .3132 .75615 .3134 .75533 .31199 Mtetra
.469 .589 .891 r
.75533 .31199 .75615 .3134 .75815 .31562 .75718 .31222 Mtetra
.443 .397 .712 r
.75718 .31222 .75815 .31562 .76068 .32482 .7591 .31323 Mtetra
.427 .284 .583 r
.7591 .31323 .76068 .32482 .77743 .52222 .76123 .31704 Mtetra
.065 0 .448 r
.76123 .31704 .77743 .52222 .77963 .52518 .7784 .51902 Mtetra
.151 .139 .59 r
.7784 .51902 .77963 .52518 .78169 .52645 .78077 .52426 Mtetra
.218 .346 .78 r
.78077 .52426 .78169 .52645 .7837 .52685 .78286 .52584 Mtetra
.528 .718 .959 r
.78286 .52584 .7837 .52685 .78565 .52663 .78482 .52569 Mtetra
.657 .79 .946 r
.78482 .52569 .78565 .52663 .78759 .52612 .78675 .52506 Mtetra
.688 .775 .918 r
.78675 .52506 .78759 .52612 .78952 .52555 .78867 .5243 Mtetra
.651 .724 .902 r
.78867 .5243 .78952 .52555 .79147 .5251 .79061 .52372 Mtetra
.683 .714 .873 r
.79061 .52372 .79147 .5251 .79339 .52432 .79253 .52296 Mtetra
.742 .74 .85 r
.79253 .52296 .79339 .52432 .79524 .52266 .79442 .5218 Mtetra
.859 .853 .834 r
.79442 .5218 .79524 .52266 .7969 .5187 .79625 .51989 Mtetra
0 0 0 r
.79625 .51989 .7969 .5187 .79802 .50816 .79804 .51755 Mtetra
.451 .209 .455 r
.79804 .51755 .79802 .50816 .78371 .3109 .79984 .51526 Mtetra
.547 .328 .534 r
.79984 .51526 .78371 .3109 .78544 .3093 .80175 .51433 Mtetra
.548 .329 .534 r
.80175 .51433 .78544 .3093 .78729 .30912 .80371 .51392 Mtetra
.80371 .51392 .78729 .30912 .78918 .30939 .80567 .51363 Mtetra
.80567 .51363 .78918 .30939 .79099 .30878 .80762 .51302 Mtetra
.80762 .51302 .79099 .30878 .79282 .30819 .80956 .51243 Mtetra
.80956 .51243 .79282 .30819 .79464 .30763 .81151 .51185 Mtetra
.81151 .51185 .79464 .30763 .79646 .30706 .81345 .51128 Mtetra
.81345 .51128 .79646 .30706 .79829 .30652 .81541 .51073 Mtetra
.81541 .51073 .79829 .30652 .80013 .30603 .81736 .51021 Mtetra
.81736 .51021 .80013 .30603 .80197 .3056 .81932 .50974 Mtetra
.81932 .50974 .80197 .3056 .80381 .30522 .82129 .50929 Mtetra
.82129 .50929 .80381 .30522 .80568 .30508 .82327 .50901 Mtetra
.549 .329 .534 r
.82327 .50901 .80568 .30508 .80764 .30584 .82529 .50921 Mtetra
.548 .329 .534 r
.82529 .50921 .80764 .30584 .80952 .30579 .82726 .50876 Mtetra
.546 .327 .534 r
.82726 .50876 .80952 .30579 .81117 .30324 .82909 .50667 Mtetra
.116 .022 .462 r
.82909 .50667 .81117 .30324 .81265 .29879 .81347 .31503 Mtetra
0 0 .382 r
.81347 .31503 .81265 .29879 .81427 .29586 .81363 .29623 Mtetra
.938 .933 .579 r
.81363 .29623 .81427 .29586 .81597 .29393 .81519 .29273 Mtetra
.735 .754 .868 r
.81519 .29273 .81597 .29393 .81778 .2931 .81699 .29172 Mtetra
.642 .684 .874 r
.81699 .29172 .81778 .2931 .81962 .29254 .81883 .29121 Mtetra
.621 .683 .887 r
.81883 .29121 .81962 .29254 .82146 .29198 .82069 .2908 Mtetra
.754 .765 .861 r
.82069 .2908 .82146 .29198 .82324 .29084 .82247 .28967 Mtetra
.681 .74 .896 r
.82247 .28967 .82324 .29084 .82507 .29012 .8243 .28897 Mtetra
.402 .603 .928 r
.8243 .28897 .82507 .29012 .827 .29044 .82623 .28929 Mtetra
.821 .415 0 r
.82623 .28929 .827 .29044 .82948 .29641 .8287 .29523 Mtetra
.973 .661 .312 r
.8287 .29523 .82948 .29641 .85155 .50161 .85074 .50052 Mtetra
.691 .25 0 r
.85074 .50052 .85155 .50161 .85398 .50565 .85317 .50457 Mtetra
.342 .603 .944 r
.85317 .50457 .85398 .50565 .85605 .50606 .85525 .50498 Mtetra
.668 .771 .927 r
.85525 .50498 .85605 .50606 .85802 .50537 .85722 .5043 Mtetra
.849 .821 .821 r
.85722 .5043 .85802 .50537 .85987 .50343 .85906 .50236 Mtetra
.977 .78 .572 r
.85906 .50236 .85987 .50343 .86124 .49681 .86044 .49573 Mtetra
.976 .67 .326 r
.86044 .49573 .86124 .49681 .84217 .28977 .84141 .28864 Mtetra
.965 .78 .602 r
.84141 .28864 .84217 .28977 .84353 .28436 .84277 .28323 Mtetra
.762 .778 .866 r
.84277 .28323 .84353 .28436 .84532 .28319 .84456 .28206 Mtetra
.633 .728 .917 r
.84456 .28206 .84532 .28319 .84718 .28271 .84643 .28158 Mtetra
.557 .692 .93 r
.84643 .28158 .84718 .28271 .84908 .28253 .84832 .28139 Mtetra
.753 .776 .872 r
.84832 .28139 .84908 .28253 .85088 .28142 .85012 .28029 Mtetra
.686 .751 .901 r
.85012 .28029 .85088 .28142 .85272 .2807 .85197 .27956 Mtetra
.486 .655 .935 r
.85197 .27956 .85272 .2807 .85465 .28076 .85389 .27962 Mtetra
.734 .314 0 r
.85389 .27962 .85465 .28076 .85708 .2855 .85632 .28436 Mtetra
.971 .656 .295 r
.85632 .28436 .85708 .2855 .88115 .49155 .88036 .49046 Mtetra
.747 .318 0 r
.88036 .49046 .88115 .49155 .88374 .4965 .88295 .49541 Mtetra
.468 .673 .953 r
.88295 .49541 .88374 .4965 .88581 .49656 .88502 .49547 Mtetra
.673 .772 .925 r
.88502 .49547 .88581 .49656 .8878 .49585 .88701 .49476 Mtetra
.743 .797 .895 r
.88701 .49476 .8878 .49585 .88975 .49479 .88896 .49367 Mtetra
.441 .701 .976 r
.24754 .68111 .2486 .68194 .25014 .68213 .24909 .68114 Mtetra
.619 .729 .925 r
.24909 .68114 .25014 .68213 .25171 .68192 .25067 .68078 Mtetra
.751 .731 .834 r
.25067 .68078 .25171 .68192 .25334 .68097 .25231 .67968 Mtetra
.892 .713 .652 r
.25231 .67968 .25334 .68097 .2553 .67571 .25431 .67395 Mtetra
.936 .685 .534 r
.25431 .67395 .2553 .67571 .27195 .47873 .27101 .47708 Mtetra
.877 .691 .647 r
.27101 .47708 .27195 .47873 .27389 .47255 .27291 .4715 Mtetra
.759 .737 .832 r
.27291 .4715 .27389 .47255 .27544 .47139 .27446 .47041 Mtetra
.621 .717 .915 r
.27446 .47041 .27544 .47139 .27694 .47102 .27596 .47007 Mtetra
.479 .671 .948 r
.27596 .47007 .27694 .47102 .27841 .47104 .27742 .4701 Mtetra
.655 .737 .91 r
.27742 .4701 .27841 .47104 .27992 .47043 .27893 .46963 Mtetra
.668 .77 .926 r
.27893 .46963 .27992 .47043 .28144 .46988 .28044 .46911 Mtetra
.672 .78 .931 r
.28044 .46911 .28144 .46988 .28294 .4695 .28195 .46857 Mtetra
.754 .758 .856 r
.28195 .46857 .28294 .4695 .28441 .46949 .2835 .46758 Mtetra
.666 .603 .775 r
.2835 .46758 .28441 .46949 .28585 .46999 .28503 .46689 Mtetra
.565 .474 .711 r
.28503 .46689 .28585 .46999 .28722 .47157 .28651 .46686 Mtetra
0 0 .51 r
.28651 .46686 .28722 .47157 .27559 .65435 .28771 .47065 Mtetra
0 0 .181 r
.28771 .47065 .27559 .65435 .27601 .67038 .27516 .66665 Mtetra
.752 .484 0 r
.27516 .66665 .27601 .67038 .27738 .67322 .27633 .67229 Mtetra
.199 .55 .931 r
.27633 .67229 .27738 .67322 .27893 .67353 .27787 .67274 Mtetra
.661 .785 .94 r
.27787 .67274 .27893 .67353 .28054 .67307 .27949 .67221 Mtetra
.748 .782 .881 r
.27949 .67221 .28054 .67307 .28218 .6721 .28113 .67124 Mtetra
.527 .729 .966 r
.28113 .67124 .28218 .6721 .28383 .67102 .28272 .67111 Mtetra
.25 .763 .813 r
.28272 .67111 .28383 .67102 .28552 .66939 .28432 .67078 Mtetra
.038 0 0 r
.28432 .67078 .28552 .66939 .28729 .66657 .28597 .66979 Mtetra
0 0 0 r
.28597 .66979 .28729 .66657 .30144 .48086 .28785 .66529 Mtetra
0 0 .18 r
.28785 .66529 .30144 .48086 .30399 .46507 .30266 .46934 Mtetra
.849 .815 .332 r
.30266 .46934 .30399 .46507 .30571 .46162 .30466 .46187 Mtetra
.875 .978 .84 r
.30466 .46187 .30571 .46162 .30727 .46058 .30626 .46017 Mtetra
.697 .877 .965 r
.30626 .46017 .30727 .46058 .30878 .46025 .3078 .45949 Mtetra
.587 .76 .961 r
.3078 .45949 .30878 .46025 .31028 .46024 .30931 .4592 Mtetra
.647 .716 .899 r
.30931 .4592 .31028 .46024 .31179 .4599 .31083 .45876 Mtetra
.648 .697 .881 r
.31083 .45876 .31179 .4599 .31332 .45944 .31236 .45831 Mtetra
.642 .697 .886 r
.31236 .45831 .31332 .45944 .31485 .45892 .31388 .45789 Mtetra
.65 .719 .898 r
.31388 .45789 .31485 .45892 .31638 .45831 .31541 .45743 Mtetra
.655 .754 .922 r
.31541 .45743 .31638 .45831 .31792 .45766 .31693 .45696 Mtetra
.655 .795 .95 r
.31693 .45696 .31792 .45766 .31946 .45701 .31846 .45646 Mtetra
.656 .835 .969 r
.31846 .45646 .31946 .45701 .321 .45631 .32 .45593 Mtetra
.641 .876 .985 r
.32 .45593 .321 .45631 .32254 .45571 .32153 .45539 Mtetra
.632 .889 .987 r
.32153 .45539 .32254 .45571 .32407 .4553 .32307 .45484 Mtetra
.65 .856 .978 r
.32307 .45484 .32407 .4553 .32555 .45561 .32461 .4543 Mtetra
.662 .673 .851 r
.32461 .4543 .32555 .45561 .32701 .45646 .32614 .45377 Mtetra
.627 .532 .727 r
.32614 .45377 .32701 .45646 .32844 .45768 .32768 .45323 Mtetra
.604 .462 .661 r
.32768 .45323 .32844 .45768 .32993 .45794 .32922 .45267 Mtetra
.597 .444 .644 r
.32922 .45267 .32993 .45794 .33148 .45736 .33076 .4521 Mtetra
.597 .443 .644 r
.33076 .4521 .33148 .45736 .33304 .45649 .33231 .45154 Mtetra
.618 .463 .649 r
.33231 .45154 .33304 .45649 .33462 .45529 .33387 .45069 Mtetra
.612 .465 .657 r
.33387 .45069 .33462 .45529 .33618 .45445 .33542 .44998 Mtetra
.573 .44 .662 r
.33542 .44998 .33618 .45445 .33769 .45453 .33694 .44983 Mtetra
.249 .208 .615 r
.33694 .44983 .33769 .45453 .3388 .46175 .33831 .45231 Mtetra
.958 .697 .499 r
.33831 .45231 .3388 .46175 .32951 .65397 .3289 .64578 Mtetra
0 0 .264 r
.3289 .64578 .32951 .65397 .33092 .65761 .32997 .65526 Mtetra
.267 .35 .763 r
.32997 .65526 .33092 .65761 .3325 .65822 .33152 .65643 Mtetra
.623 .608 .815 r
.33152 .65643 .3325 .65822 .33414 .6578 .33316 .65604 Mtetra
.694 .643 .794 r
.33316 .65604 .33414 .6578 .3358 .65706 .33482 .65515 Mtetra
.664 .616 .79 r
.33482 .65515 .3358 .65706 .33744 .65657 .33648 .65446 Mtetra
.637 .586 .78 r
.33648 .65446 .33744 .65657 .33908 .65621 .33812 .65394 Mtetra
.628 .568 .768 r
.33812 .65394 .33908 .65621 .34072 .65583 .33977 .65346 Mtetra
.603 .548 .766 r
.33977 .65346 .34072 .65583 .34236 .6554 .3414 .65316 Mtetra
.592 .551 .778 r
.3414 .65316 .34236 .6554 .34401 .65486 .34304 .65294 Mtetra
.596 .582 .808 r
.34304 .65294 .34401 .65486 .34567 .65413 .34467 .6527 Mtetra
.623 .656 .861 r
.34467 .6527 .34567 .65413 .34736 .6528 .34632 .65233 Mtetra
.601 .853 .992 r
.34632 .65233 .34736 .6528 .34909 .65092 .34797 .65186 Mtetra
.147 0 0 r
.34797 .65186 .34909 .65092 .35082 .64868 .34962 .65135 Mtetra
.472 .124 .294 r
.34962 .65135 .35082 .64868 .3525 .64772 .35126 .65115 Mtetra
.484 .162 .344 r
.35126 .65115 .3525 .64772 .35413 .64758 .3529 .65089 Mtetra
.402 .081 .302 r
.3529 .65089 .35413 .64758 .3558 .64682 .35457 .65007 Mtetra
0 0 .005 r
.35457 .65007 .3558 .64682 .35772 .64075 .35636 .6468 Mtetra
.957 .699 .504 r
.35636 .6468 .35772 .64075 .36868 .44552 .36674 .46499 Mtetra
0 0 .102 r
.36674 .46499 .36868 .44552 .37045 .44073 .36942 .44129 Mtetra
.921 .976 .746 r
.36942 .44129 .37045 .44073 .37207 .43899 .37107 .4389 Mtetra
.592 .927 .962 r
.37107 .4389 .37207 .43899 .37363 .43838 .37264 .43827 Mtetra
.245 .751 .884 r
.37264 .43827 .37363 .43838 .37518 .43813 .37419 .4381 Mtetra
.421 .861 .917 r
.37419 .4381 .37518 .43813 .37673 .43787 .37575 .43767 Mtetra
.672 .929 .971 r
.37575 .43767 .37673 .43787 .37829 .43751 .37732 .43694 Mtetra
.707 .843 .948 r
.37732 .43694 .37829 .43751 .37985 .43714 .3789 .43623 Mtetra
.679 .757 .91 r
.3789 .43623 .37985 .43714 .38142 .43663 .38047 .43565 Mtetra
.655 .735 .908 r
.38047 .43565 .38142 .43663 .38299 .43599 .38204 .43516 Mtetra
.647 .766 .936 r
.38204 .43516 .38299 .43599 .38456 .43533 .3836 .43469 Mtetra
.653 .816 .962 r
.3836 .43469 .38456 .43533 .38614 .43463 .38517 .43418 Mtetra
.65 .865 .98 r
.38517 .43418 .38614 .43463 .38772 .43397 .38675 .43361 Mtetra
.634 .886 .987 r
.38675 .43361 .38772 .43397 .38929 .43349 .38832 .43305 Mtetra
.726 .88 .952 r
.38832 .43305 .38929 .43349 .39084 .43336 .3899 .43225 Mtetra
.713 .726 .86 r
.3899 .43225 .39084 .43336 .39238 .43375 .39149 .43145 Mtetra
.604 .545 .761 r
.39149 .43145 .39238 .43375 .39388 .43499 .39305 .43115 Mtetra
.333 .295 .666 r
.39305 .43115 .39388 .43499 .39521 .44067 .39454 .43281 Mtetra
.883 .651 .129 r
.39454 .43281 .39521 .44067 .38912 .63558 .39546 .44896 Mtetra
0 0 .29 r
.39546 .44896 .38912 .63558 .39062 .63958 .38969 .63674 Mtetra
.133 .222 .692 r
.38969 .63674 .39062 .63958 .39224 .64057 .39127 .63867 Mtetra
.609 .593 .81 r
.39127 .63867 .39224 .64057 .39391 .64021 .39294 .63836 Mtetra
.686 .633 .79 r
.39294 .63836 .39391 .64021 .3956 .63945 .39464 .63749 Mtetra
.66 .612 .79 r
.39464 .63749 .3956 .63945 .39729 .63871 .39632 .63682 Mtetra
.601 .59 .812 r
.39632 .63682 .39729 .63871 .39898 .63816 .398 .63655 Mtetra
.604 .624 .844 r
.398 .63655 .39898 .63816 .40066 .63761 .39967 .63626 Mtetra
.626 .672 .874 r
.39967 .63626 .40066 .63761 .40235 .63708 .40135 .63587 Mtetra
.652 .705 .887 r
.40135 .63587 .40235 .63708 .40403 .63656 .40304 .63536 Mtetra
.659 .709 .885 r
.40304 .63536 .40403 .63656 .40572 .63605 .40473 .63481 Mtetra
.656 .702 .881 r
.40473 .63481 .40572 .63605 .4074 .63554 .40641 .63428 Mtetra
.649 .695 .879 r
.40641 .63428 .4074 .63554 .40909 .63504 .4081 .63378 Mtetra
.647 .694 .88 r
.4081 .63378 .40909 .63504 .41078 .63455 .40979 .63328 Mtetra
.642 .693 .882 r
.40979 .63328 .41078 .63455 .41247 .63406 .41148 .63282 Mtetra
.638 .695 .887 r
.41148 .63282 .41247 .63406 .41416 .63357 .41317 .63237 Mtetra
.645 .704 .89 r
.41317 .63237 .41416 .63357 .41585 .63309 .41486 .63188 Mtetra
.667 .711 .881 r
.41486 .63188 .41585 .63309 .41754 .63263 .41656 .6313 Mtetra
.685 .697 .855 r
.41656 .6313 .41754 .63263 .41924 .63218 .41826 .63058 Mtetra
.679 .658 .823 r
.41826 .63058 .41924 .63218 .42093 .63173 .41996 .62986 Mtetra
.621 .602 .81 r
.41996 .62986 .42093 .63173 .42262 .63144 .42166 .62946 Mtetra
.571 .567 .81 r
.42166 .62946 .42262 .63144 .42431 .63123 .42334 .62936 Mtetra
.655 .619 .801 r
.42334 .62936 .42431 .63123 .42601 .63063 .42504 .62874 Mtetra
.81 .678 .719 r
.42504 .62874 .42601 .63063 .42775 .62876 .4268 .62615 Mtetra
.921 .684 .563 r
.4268 .62615 .42775 .62876 .42958 .62363 .42894 .6099 Mtetra
.938 .672 .507 r
.42894 .6099 .42958 .62363 .4366 .42715 .43586 .41935 Mtetra
.67 .474 .611 r
.43586 .41935 .4366 .42715 .43835 .42113 .43753 .4163 Mtetra
.615 .463 .653 r
.43753 .4163 .43835 .42113 .43996 .42039 .43913 .41552 Mtetra
.58 .439 .654 r
.43913 .41552 .43996 .42039 .44155 .42024 .44073 .41525 Mtetra
.575 .433 .651 r
.44073 .41525 .44155 .42024 .44317 .41927 .44233 .41503 Mtetra
.602 .466 .669 r
.44233 .41503 .44317 .41927 .44482 .41706 .44393 .41452 Mtetra
.626 .543 .741 r
.44393 .41452 .44482 .41706 .44646 .41523 .44554 .41401 Mtetra
.657 .694 .873 r
.44554 .41401 .44646 .41523 .44808 .414 .44714 .4135 Mtetra
.636 .856 .983 r
.44714 .4135 .44808 .414 .44969 .41337 .44875 .41297 Mtetra
.621 .876 .989 r
.44875 .41297 .44969 .41337 .45129 .41294 .45036 .41244 Mtetra
.638 .854 .982 r
.45036 .41244 .45129 .41294 .4529 .41259 .45197 .41191 Mtetra
.653 .813 .96 r
.45197 .41191 .4529 .41259 .4545 .41219 .45358 .41138 Mtetra
.661 .78 .937 r
.45358 .41138 .4545 .41219 .45611 .41181 .45519 .41085 Mtetra
.668 .749 .911 r
.45519 .41085 .45611 .41181 .45772 .41138 .4568 .41029 Mtetra
.673 .725 .888 r
.4568 .41029 .45772 .41138 .45933 .41087 .45842 .40971 Mtetra
.667 .709 .879 r
.45842 .40971 .45933 .41087 .46095 .4103 .46003 .40915 Mtetra
.65 .704 .887 r
.46003 .40915 .46095 .4103 .46257 .40967 .46165 .40867 Mtetra
.617 .724 .923 r
.46165 .40867 .46257 .40967 .46418 .40895 .46326 .40831 Mtetra
.578 .801 .984 r
.46326 .40831 .46418 .40895 .4658 .40823 .46487 .40798 Mtetra
.584 .899 .985 r
.46487 .40798 .4658 .40823 .46743 .40747 .46649 .40743 Mtetra
.692 .967 .934 r
.46649 .40743 .46743 .40747 .46905 .40662 .46812 .4065 Mtetra
.502 .892 .954 r
.46812 .4065 .46905 .40662 .47067 .40612 .46974 .406 Mtetra
.523 0 0 r
.46974 .406 .47067 .40612 .47227 .40654 .47133 .40687 Mtetra
.926 .595 .394 r
.47133 .40687 .47227 .40654 .47383 .4098 .4728 .41597 Mtetra
.95 .675 .481 r
.4728 .41597 .47383 .4098 .47247 .60444 .47137 .61218 Mtetra
.645 .364 .479 r
.47137 .61218 .47247 .60444 .47408 .61193 .47304 .61509 Mtetra
.5 .168 .335 r
.47304 .61509 .47408 .61193 .4758 .61209 .47477 .61501 Mtetra
.408 .073 .282 r
.47477 .61501 .4758 .61209 .47753 .61126 .4765 .61431 Mtetra
.388 .06 .283 r
.4765 .61431 .47753 .61126 .47927 .61013 .47824 .61344 Mtetra
.455 .13 .325 r
.47824 .61344 .47927 .61013 .481 .60962 .47997 .61296 Mtetra
.455 .131 .327 r
.47997 .61296 .481 .60962 .48273 .6091 .48171 .61247 Mtetra
.455 .132 .328 r
.48171 .61247 .48273 .6091 .48446 .60856 .48344 .61197 Mtetra
.455 .133 .33 r
.48344 .61197 .48446 .60856 .4862 .60802 .48518 .61146 Mtetra
.454 .134 .331 r
.48518 .61146 .4862 .60802 .48793 .60748 .48692 .61094 Mtetra
.454 .134 .333 r
.48692 .61094 .48793 .60748 .48967 .60685 .48866 .6104 Mtetra
.455 .138 .338 r
.48866 .6104 .48967 .60685 .49141 .60596 .4904 .60986 Mtetra
.464 .155 .356 r
.4904 .60986 .49141 .60596 .49315 .60539 .49214 .60931 Mtetra
.464 .156 .357 r
.49214 .60931 .49315 .60539 .49488 .60562 .49388 .60875 Mtetra
.441 .111 .309 r
.49388 .60875 .49488 .60562 .49661 .607 .49563 .60821 Mtetra
.238 0 0 r
.49563 .60821 .49661 .607 .49834 .60801 .49737 .60766 Mtetra
.585 .887 .991 r
.49737 .60766 .49834 .60801 .50008 .60846 .49912 .60711 Mtetra
.657 .69 .869 r
.49912 .60711 .50008 .60846 .50182 .60808 .50086 .60655 Mtetra
.653 .662 .846 r
.50086 .60655 .50182 .60808 .50357 .60747 .50261 .60599 Mtetra
.653 .668 .851 r
.50261 .60599 .50357 .60747 .50532 .60679 .50436 .60543 Mtetra
.653 .687 .869 r
.50436 .60543 .50532 .60679 .50707 .60624 .50611 .60488 Mtetra
.652 .686 .869 r
.50611 .60488 .50707 .60624 .50882 .6057 .50786 .60434 Mtetra
.651 .686 .87 r
.50786 .60434 .50882 .6057 .51057 .60516 .50962 .6038 Mtetra
.65 .686 .871 r
.50962 .6038 .51057 .60516 .51233 .60463 .51137 .60327 Mtetra
.649 .686 .871 r
.51137 .60327 .51233 .60463 .51408 .6041 .51312 .60274 Mtetra
.648 .686 .871 r
.51312 .60274 .51408 .6041 .51584 .60358 .51488 .60222 Mtetra
.648 .686 .872 r
.51488 .60222 .51584 .60358 .51759 .60306 .51664 .6017 Mtetra
.647 .685 .872 r
.51664 .6017 .51759 .60306 .51935 .60254 .51839 .60118 Mtetra
.51839 .60118 .51935 .60254 .52111 .60203 .52015 .60067 Mtetra
.646 .685 .872 r
.52015 .60067 .52111 .60203 .52287 .60152 .52191 .60016 Mtetra
.645 .685 .873 r
.52191 .60016 .52287 .60152 .52463 .60102 .52368 .59965 Mtetra
.644 .684 .873 r
.52368 .59965 .52463 .60102 .52639 .60052 .52544 .59915 Mtetra
.643 .684 .873 r
.52544 .59915 .52639 .60052 .52816 .60002 .5272 .59865 Mtetra
.642 .682 .873 r
.5272 .59865 .52816 .60002 .52992 .59954 .52897 .59816 Mtetra
.64 .681 .873 r
.52897 .59816 .52992 .59954 .53168 .59906 .53073 .59768 Mtetra
.638 .679 .873 r
.53073 .59768 .53168 .59906 .53345 .59873 .5325 .59721 Mtetra
.636 .658 .855 r
.5325 .59721 .53345 .59873 .53522 .59827 .53427 .59674 Mtetra
.636 .657 .854 r
.53427 .59674 .53522 .59827 .53699 .59754 .53604 .59627 Mtetra
.641 .7 .889 r
.53604 .59627 .53699 .59754 .53875 .59587 .53781 .59579 Mtetra
.424 .861 .921 r
.53781 .59579 .53875 .59587 .54052 .59374 .53958 .5953 Mtetra
.333 0 .087 r
.53958 .5953 .54052 .59374 .54228 .59132 .54135 .59481 Mtetra
.463 .143 .337 r
.54135 .59481 .54228 .59132 .54405 .5904 .54313 .59434 Mtetra
.473 .164 .36 r
.54313 .59434 .54405 .5904 .54582 .59004 .5449 .59386 Mtetra
.47 .158 .355 r
.5449 .59386 .54582 .59004 .5476 .58993 .54668 .59338 Mtetra
.459 .138 .334 r
.54668 .59338 .5476 .58993 .54937 .58946 .54846 .59288 Mtetra
.457 .136 .332 r
.54846 .59288 .54937 .58946 .55115 .58898 .55024 .59237 Mtetra
.456 .133 .329 r
.55024 .59237 .55115 .58898 .55292 .58851 .55202 .59186 Mtetra
.456 .132 .328 r
.55202 .59186 .55292 .58851 .5547 .58803 .5538 .59136 Mtetra
.454 .129 .326 r
.5538 .59136 .5547 .58803 .55648 .58754 .55558 .59085 Mtetra
.451 .126 .323 r
.55558 .59085 .55648 .58754 .55826 .58702 .55736 .59032 Mtetra
.498 .169 .339 r
.55736 .59032 .55826 .58702 .56005 .58721 .55915 .5902 Mtetra
.448 .112 .303 r
.55915 .5902 .56005 .58721 .56184 .58683 .56094 .58973 Mtetra
.334 .007 .253 r
.56094 .58973 .56184 .58683 .56361 .58532 .56272 .58857 Mtetra
0 0 0 r
.56272 .58857 .56361 .58532 .56517 .56589 .56445 .58341 Mtetra
.984 .711 .417 r
.56445 .58341 .56517 .56589 .56463 .37862 .5638 .38177 Mtetra
.777 .752 .235 r
.5638 .38177 .56463 .37862 .56626 .37484 .5654 .37488 Mtetra
.799 .993 .876 r
.5654 .37488 .56626 .37484 .56793 .37372 .56707 .37348 Mtetra
.539 .893 .977 r
.56707 .37348 .56793 .37372 .56961 .37319 .56875 .37297 Mtetra
.259 .747 .92 r
.56875 .37297 .56961 .37319 .5713 .37295 .57043 .37286 Mtetra
.427 .862 .924 r
.57043 .37286 .5713 .37295 .57298 .37242 .57212 .3724 Mtetra
.412 .86 .893 r
.57212 .3724 .57298 .37242 .57466 .37188 .5738 .37189 Mtetra
.422 .867 .881 r
.5738 .37189 .57466 .37188 .57634 .37137 .57548 .37134 Mtetra
.57 .934 .922 r
.57548 .37134 .57634 .37137 .57803 .37095 .57717 .37059 Mtetra
.693 .915 .97 r
.57717 .37059 .57803 .37095 .57972 .37055 .57885 .3698 Mtetra
.711 .821 .933 r
.57885 .3698 .57972 .37055 .5814 .3701 .58053 .36903 Mtetra
.673 .737 .898 r
.58053 .36903 .5814 .3701 .58309 .36947 .58222 .36842 Mtetra
.66 .737 .907 r
.58222 .36842 .58309 .36947 .58478 .36878 .58391 .36788 Mtetra
.652 .767 .934 r
.58391 .36788 .58478 .36878 .58646 .36808 .5856 .36735 Mtetra
.65 .811 .961 r
.5856 .36735 .58646 .36808 .58815 .36735 .58729 .36681 Mtetra
.633 .856 .984 r
.58729 .36681 .58815 .36735 .58984 .36672 .58898 .36626 Mtetra
.622 .872 .989 r
.58898 .36626 .58984 .36672 .59153 .36631 .59067 .3657 Mtetra
.65 .843 .974 r
.59067 .3657 .59153 .36631 .59325 .36665 .59237 .36513 Mtetra
.658 .657 .838 r
.59237 .36513 .59325 .36665 .59497 .36749 .59406 .36455 Mtetra
.624 .525 .721 r
.59406 .36455 .59497 .36749 .59671 .36871 .59576 .36397 Mtetra
.625 .473 .656 r
.59576 .36397 .59671 .36871 .59841 .36815 .59745 .363 Mtetra
.607 .455 .649 r
.59745 .363 .59841 .36815 .6001 .36728 .59914 .36226 Mtetra
.57 .432 .654 r
.59914 .36226 .6001 .36728 .60181 .36718 .60085 .3621 Mtetra
.282 .235 .626 r
.60085 .3621 .60181 .36718 .6038 .37849 .60263 .36498 Mtetra
.982 .697 .392 r
.60263 .36498 .6038 .37849 .6104 .57176 .60932 .56451 Mtetra
0 0 .458 r
.60932 .56451 .6104 .57176 .61231 .57509 .61136 .57266 Mtetra
.362 .411 .778 r
.61136 .57266 .61231 .57509 .61415 .57545 .61322 .57368 Mtetra
.596 .611 .838 r
.61322 .57368 .61415 .57545 .61597 .57491 .61504 .57342 Mtetra
.678 .683 .848 r
.61504 .57342 .61597 .57491 .61779 .57405 .61686 .57269 Mtetra
.651 .694 .877 r
.61686 .57269 .61779 .57405 .61961 .57355 .61868 .57214 Mtetra
.646 .682 .87 r
.61868 .57214 .61961 .57355 .62144 .57309 .62051 .57161 Mtetra
.653 .675 .859 r
.62051 .57161 .62144 .57309 .62326 .57242 .62233 .57103 Mtetra
.573 .656 .893 r
.62233 .57103 .62326 .57242 .62507 .5713 .62417 .57084 Mtetra
.507 .84 .998 r
.62417 .57084 .62507 .5713 .62686 .56958 .626 .57048 Mtetra
0 0 0 r
.626 .57048 .62686 .56958 .62861 .56677 .62782 .5695 Mtetra
.62782 .5695 .62861 .56677 .6301 .55538 .62954 .56554 Mtetra
.982 .7 .406 r
.62954 .56554 .6301 .55538 .62572 .35898 .62512 .36615 Mtetra
0 0 .123 r
.62512 .36615 .62572 .35898 .62732 .35498 .62652 .35537 Mtetra
.861 .988 .717 r
.62652 .35537 .62732 .35498 .62901 .3536 .62818 .35317 Mtetra
.709 .908 .965 r
.62818 .35317 .62901 .3536 .63073 .35315 .62989 .35234 Mtetra
.605 .778 .963 r
.62989 .35234 .63073 .35315 .63247 .35303 .63161 .35195 Mtetra
.64 .727 .911 r
.63161 .35195 .63247 .35303 .63419 .35267 .63333 .35148 Mtetra
.65 .71 .891 r
.63333 .35148 .63419 .35267 .63591 .35212 .63506 .35096 Mtetra
.646 .714 .897 r
.63506 .35096 .63591 .35212 .63763 .35152 .63678 .35047 Mtetra
.665 .742 .908 r
.63678 .35047 .63763 .35152 .63934 .3507 .6385 .34989 Mtetra
.674 .801 .943 r
.6385 .34989 .63934 .3507 .64106 .34987 .64022 .34926 Mtetra
.664 .851 .971 r
.64022 .34926 .64106 .34987 .64278 .34923 .64195 .34862 Mtetra
.744 .87 .939 r
.64195 .34862 .64278 .34923 .64452 .34904 .64366 .34769 Mtetra
.701 .703 .848 r
.64366 .34769 .64452 .34904 .64628 .34942 .64537 .34687 Mtetra
.595 .531 .752 r
.64537 .34687 .64628 .34942 .64808 .35076 .64711 .3466 Mtetra
.318 .284 .663 r
.64711 .3466 .64808 .35076 .65012 .35808 .64895 .34877 Mtetra
.98 .689 .381 r
.64895 .34877 .65012 .35808 .65979 .55635 .65848 .54476 Mtetra
0 0 .45 r
.65848 .54476 .65979 .55635 .66181 .56002 .66085 .55734 Mtetra
.319 .365 .753 r
.66085 .55734 .66181 .56002 .66371 .5607 .66278 .55871 Mtetra
.625 .603 .808 r
.66278 .55871 .66371 .5607 .66557 .56024 .66463 .55825 Mtetra
.69 .635 .79 r
.66463 .55825 .66557 .56024 .66741 .55939 .66647 .55729 Mtetra
.639 .6 .794 r
.66647 .55729 .66741 .55939 .66926 .55877 .66832 .55671 Mtetra
.594 .58 .807 r
.66832 .55671 .66926 .55877 .67112 .55829 .67019 .55645 Mtetra
.601 .608 .83 r
.67019 .55645 .67112 .55829 .67297 .55759 .67206 .55615 Mtetra
.566 .645 .888 r
.67206 .55615 .67297 .55759 .6748 .55647 .67394 .55599 Mtetra
.495 .831 .999 r
.67394 .55599 .6748 .55647 .67661 .55473 .67581 .55566 Mtetra
0 0 0 r
.67581 .55566 .67661 .55473 .67836 .55187 .67765 .5547 Mtetra
0 0 .067 r
.67765 .5547 .67836 .55187 .67975 .54112 .67938 .55117 Mtetra
.982 .697 .383 r
.67938 .55117 .67975 .54112 .67242 .34349 .67208 .35295 Mtetra
0 0 .224 r
.67208 .35295 .67242 .34349 .674 .33933 .67324 .33993 Mtetra
.854 .96 .621 r
.67324 .33993 .674 .33933 .67569 .33754 .67489 .33731 Mtetra
.706 .955 .95 r
.67489 .33731 .67569 .33754 .67742 .33679 .67662 .33635 Mtetra
.574 .869 .995 r
.67662 .33635 .67742 .33679 .67918 .33652 .67837 .33586 Mtetra
.689 .85 .96 r
.67837 .33586 .67918 .33652 .68096 .3365 .68011 .33514 Mtetra
.697 .703 .852 r
.68011 .33514 .68096 .3365 .68275 .33682 .68185 .33435 Mtetra
.597 .538 .759 r
.68185 .33435 .68275 .33682 .68459 .33794 .68361 .33406 Mtetra
.383 .338 .683 r
.68361 .33406 .68459 .33794 .68662 .34288 .68547 .33565 Mtetra
0 0 .398 r
.68547 .33565 .68662 .34288 .69877 .54362 .68778 .3458 Mtetra
.012 0 .421 r
.68778 .3458 .69877 .54362 .70091 .54806 .69991 .54483 Mtetra
.213 .263 .698 r
.69991 .54483 .70091 .54806 .70287 .54909 .70194 .54711 Mtetra
.555 .569 .823 r
.70194 .54711 .70287 .54909 .70475 .54868 .70385 .54708 Mtetra
.655 .664 .846 r
.70385 .54708 .70475 .54868 .70661 .54769 .70572 .54646 Mtetra
.603 .702 .913 r
.70572 .54646 .70661 .54769 .70845 .54647 .70761 .54611 Mtetra
.356 .788 .968 r
.70761 .54611 .70845 .54647 .71028 .545 .70952 .54593 Mtetra
.073 0 0 r
.70952 .54593 .71028 .545 .71207 .54269 .71139 .54513 Mtetra
0 0 .043 r
.71139 .54513 .71207 .54269 .71364 .53664 .71313 .54207 Mtetra
.902 .721 .216 r
.71313 .54207 .71364 .53664 .70413 .33541 .71396 .52278 Mtetra
.003 0 .412 r
.71396 .52278 .70413 .33541 .70563 .33008 .70484 .32963 Mtetra
.945 .881 .739 r
.70484 .32963 .70563 .33008 .70731 .32802 .70648 .32677 Mtetra
.693 .721 .871 r
.70648 .32677 .70731 .32802 .70906 .32731 .70823 .32602 Mtetra
.585 .666 .895 r
.70823 .32602 .70906 .32731 .71084 .32697 .71002 .32578 Mtetra
.598 .693 .91 r
.71002 .32578 .71084 .32697 .71261 .32642 .7118 .32548 Mtetra
.67 .774 .928 r
.7118 .32548 .71261 .32642 .71436 .32557 .71357 .32486 Mtetra
.664 .83 .963 r
.71357 .32486 .71436 .32557 .71613 .32488 .71533 .32423 Mtetra
.724 .864 .947 r
.71533 .32423 .71613 .32488 .71791 .32456 .71709 .32336 Mtetra
.728 .743 .863 r
.71709 .32336 .71791 .32456 .71973 .32481 .71884 .3224 Mtetra
.619 .555 .761 r
.71884 .3224 .71973 .32481 .72161 .32585 .72062 .32194 Mtetra
.417 .36 .687 r
.72062 .32194 .72161 .32585 .72368 .32995 .72252 .32331 Mtetra
0 0 .284 r
.72252 .32331 .72368 .32995 .73827 .53068 .72511 .33562 Mtetra
.027 0 .431 r
.72511 .33562 .73827 .53068 .74053 .53572 .73961 .53379 Mtetra
0 .165 .7 r
.73961 .53379 .74053 .53572 .74256 .53715 .7417 .53611 Mtetra
.57 .728 .948 r
.7417 .53611 .74256 .53715 .74449 .53705 .74362 .53584 Mtetra
.71 .749 .883 r
.74362 .53584 .74449 .53705 .74639 .53635 .74551 .53495 Mtetra
.673 .704 .87 r
.74551 .53495 .74639 .53635 .74826 .53524 .74741 .53425 Mtetra
.549 .731 .959 r
.74741 .53425 .74826 .53524 .7501 .53372 .74934 .53403 Mtetra
0 0 0 r
.74934 .53403 .7501 .53372 .75189 .53129 .75124 .53329 Mtetra
0 0 .007 r
.75124 .53329 .75189 .53129 .75343 .52535 .75302 .5308 Mtetra
0 0 .083 r
.75302 .5308 .75343 .52535 .74142 .32275 .75428 .52078 Mtetra
.03 0 .426 r
.75428 .52078 .74142 .32275 .74288 .31733 .74223 .31847 Mtetra
.778 .848 .394 r
.74223 .31847 .74288 .31733 .74455 .31512 .7438 .31482 Mtetra
.752 .957 .939 r
.7438 .31482 .74455 .31512 .74633 .31445 .74556 .31371 Mtetra
.639 .819 .969 r
.74556 .31371 .74633 .31445 .74815 .31419 .74735 .31316 Mtetra
.62 .741 .933 r
.74735 .31316 .74815 .31419 .74995 .31382 .74915 .31274 Mtetra
.662 .745 .911 r
.74915 .31274 .74995 .31382 .75173 .31302 .75094 .31215 Mtetra
.645 .789 .951 r
.75094 .31215 .75173 .31302 .75351 .31234 .75274 .31161 Mtetra
.681 .836 .958 r
.75274 .31161 .75351 .31234 .75533 .31199 .75453 .31091 Mtetra
.725 .768 .887 r
.75453 .31091 .75533 .31199 .75718 .31222 .7563 .31 Mtetra
.624 .574 .778 r
.7563 .31 .75718 .31222 .7591 .31323 .7581 .30952 Mtetra
.464 .398 .699 r
.7581 .30952 .7591 .31323 .76123 .31704 .76002 .31045 Mtetra
0 .009 .521 r
.76002 .31045 .76123 .31704 .7784 .51902 .76242 .31784 Mtetra
.051 0 .444 r
.76242 .31784 .7784 .51902 .78077 .52426 .77973 .52061 Mtetra
.157 .208 .666 r
.77973 .52061 .78077 .52426 .78286 .52584 .78193 .52366 Mtetra
.581 .567 .803 r
.78193 .52366 .78286 .52584 .78482 .52569 .7839 .52348 Mtetra
.665 .609 .782 r
.7839 .52348 .78482 .52569 .78675 .52506 .78581 .52265 Mtetra
.663 .593 .766 r
.78581 .52265 .78675 .52506 .78867 .5243 .78772 .52178 Mtetra
.599 .55 .771 r
.78772 .52178 .78867 .5243 .79061 .52372 .78968 .52146 Mtetra
.601 .571 .793 r
.78968 .52146 .79061 .52372 .79253 .52296 .79163 .52113 Mtetra
.617 .623 .834 r
.79163 .52113 .79253 .52296 .79442 .5218 .79358 .52072 Mtetra
.645 .756 .93 r
.79358 .52072 .79442 .5218 .79625 .51989 .79552 .52016 Mtetra
0 0 0 r
.79552 .52016 .79625 .51989 .79804 .51755 .79746 .51955 Mtetra
.371 0 .181 r
.79746 .51955 .79804 .51755 .79984 .51526 .7994 .51893 Mtetra
.461 .146 .344 r
.7994 .51893 .79984 .51526 .80175 .51433 .80134 .51836 Mtetra
.469 .162 .362 r
.80134 .51836 .80175 .51433 .80371 .51392 .80329 .51778 Mtetra
.464 .154 .353 r
.80329 .51778 .80371 .51392 .80567 .51363 .80523 .51718 Mtetra
.454 .137 .337 r
.80523 .51718 .80567 .51363 .80762 .51302 .80718 .51656 Mtetra
.453 .136 .336 r
.80718 .51656 .80762 .51302 .80956 .51243 .80912 .51594 Mtetra
.453 .135 .335 r
.80912 .51594 .80956 .51243 .81151 .51185 .81107 .51533 Mtetra
.455 .135 .333 r
.81107 .51533 .81151 .51185 .81345 .51128 .81302 .51474 Mtetra
.456 .136 .333 r
.81302 .51474 .81345 .51128 .81541 .51073 .81497 .51417 Mtetra
.458 .136 .332 r
.81497 .51417 .81541 .51073 .81736 .51021 .81693 .51362 Mtetra
.46 .137 .33 r
.81693 .51362 .81736 .51021 .81932 .50974 .81889 .51309 Mtetra
.459 .134 .327 r
.81889 .51309 .81932 .50974 .82129 .50929 .82085 .51258 Mtetra
.469 .14 .326 r
.82085 .51258 .82129 .50929 .82327 .50901 .82283 .51217 Mtetra
.501 .162 .325 r
.82283 .51217 .82327 .50901 .82529 .50921 .82483 .51211 Mtetra
.443 .104 .294 r
.82483 .51211 .82529 .50921 .82726 .50876 .8268 .51159 Mtetra
.275 0 .245 r
.8268 .51159 .82726 .50876 .82909 .50667 .82866 .50992 Mtetra
0 0 .017 r
.82866 .50992 .82909 .50667 .81347 .31503 .83006 .5032 Mtetra
.018 0 .432 r
.83006 .5032 .81347 .31503 .81363 .29623 .813 .29669 Mtetra
.978 .874 .5 r
.813 .29669 .81363 .29623 .81519 .29273 .81441 .29153 Mtetra
.755 .761 .857 r
.81441 .29153 .81519 .29273 .81699 .29172 .8162 .29038 Mtetra
.633 .688 .883 r
.8162 .29038 .81699 .29172 .81883 .29121 .81804 .28991 Mtetra
.594 .677 .898 r
.81804 .28991 .81883 .29121 .82069 .2908 .81991 .28962 Mtetra
.753 .765 .863 r
.81991 .28962 .82069 .2908 .82247 .28967 .8217 .2885 Mtetra
.679 .74 .896 r
.8217 .2885 .82247 .28967 .8243 .28897 .82353 .28781 Mtetra
.4 .601 .928 r
.82353 .28781 .8243 .28897 .82623 .28929 .82546 .28813 Mtetra
.819 .412 0 r
.82546 .28813 .82623 .28929 .8287 .29523 .82793 .29404 Mtetra
.973 .661 .312 r
.82793 .29404 .8287 .29523 .85074 .50052 .84993 .49942 Mtetra
.691 .251 0 r
.84993 .49942 .85074 .50052 .85317 .50457 .85236 .50349 Mtetra
.342 .602 .944 r
.85236 .50349 .85317 .50457 .85525 .50498 .85444 .5039 Mtetra
.668 .77 .926 r
.85444 .5039 .85525 .50498 .85722 .5043 .85642 .50322 Mtetra
.849 .821 .821 r
.85642 .50322 .85722 .5043 .85906 .50236 .85826 .50128 Mtetra
.977 .78 .572 r
.85826 .50128 .85906 .50236 .86044 .49573 .85964 .49465 Mtetra
.976 .67 .326 r
.85964 .49465 .86044 .49573 .84141 .28864 .84064 .2875 Mtetra
.965 .78 .602 r
.84064 .2875 .84141 .28864 .84277 .28323 .84201 .28209 Mtetra
.762 .778 .866 r
.84201 .28209 .84277 .28323 .84456 .28206 .8438 .28092 Mtetra
.633 .728 .917 r
.8438 .28092 .84456 .28206 .84643 .28158 .84567 .28044 Mtetra
.557 .692 .93 r
.84567 .28044 .84643 .28158 .84832 .28139 .84756 .28026 Mtetra
.753 .776 .872 r
.84756 .28026 .84832 .28139 .85012 .28029 .84937 .27915 Mtetra
.686 .751 .901 r
.84937 .27915 .85012 .28029 .85197 .27956 .85121 .27843 Mtetra
.485 .655 .935 r
.85121 .27843 .85197 .27956 .85389 .27962 .85314 .27848 Mtetra
.735 .315 0 r
.85314 .27848 .85389 .27962 .85632 .28436 .85557 .28323 Mtetra
.971 .656 .295 r
.85557 .28323 .85632 .28436 .88036 .49046 .87957 .48939 Mtetra
.75 .319 0 r
.87957 .48939 .88036 .49046 .88295 .49541 .88216 .49433 Mtetra
.455 .669 .955 r
.88216 .49433 .88295 .49541 .88502 .49547 .88424 .49442 Mtetra
.669 .78 .932 r
.88424 .49442 .88502 .49547 .88701 .49476 .88623 .49373 Mtetra
.748 .812 .903 r
.88623 .49373 .88701 .49476 .88896 .49367 .88817 .49262 Mtetra
.386 .769 .99 r
.24644 .68066 .24754 .68111 .24909 .68114 .248 .68057 Mtetra
.64 .831 .974 r
.248 .68057 .24909 .68114 .25067 .68078 .2496 .68007 Mtetra
.796 .808 .861 r
.2496 .68007 .25067 .68078 .25231 .67968 .25125 .67879 Mtetra
.912 .732 .645 r
.25125 .67879 .25231 .67968 .25431 .67395 .2533 .67252 Mtetra
.936 .686 .534 r
.2533 .67252 .25431 .67395 .27101 .47708 .27009 .47529 Mtetra
.866 .683 .653 r
.27009 .47529 .27101 .47708 .27291 .4715 .27195 .47016 Mtetra
.727 .687 .811 r
.27195 .47016 .27291 .4715 .27446 .47041 .2735 .46919 Mtetra
.593 .661 .885 r
.2735 .46919 .27446 .47041 .27596 .47007 .27498 .46897 Mtetra
.44 .62 .928 r
.27498 .46897 .27596 .47007 .27742 .4701 .27644 .46914 Mtetra
.635 .726 .914 r
.27644 .46914 .27742 .4701 .27893 .46963 .27794 .46874 Mtetra
.662 .75 .916 r
.27794 .46874 .27893 .46963 .28044 .46911 .27945 .46825 Mtetra
.679 .76 .912 r
.27945 .46825 .28044 .46911 .28195 .46857 .28097 .46768 Mtetra
.778 .767 .843 r
.28097 .46768 .28195 .46857 .2835 .46758 .28253 .46651 Mtetra
.725 .728 .853 r
.28253 .46651 .2835 .46758 .28503 .46689 .28406 .46566 Mtetra
.578 .653 .888 r
.28406 .46566 .28503 .46689 .28651 .46686 .28555 .46549 Mtetra
.917 .525 .138 r
.28555 .46549 .28651 .46686 .28771 .47065 .28676 .46925 Mtetra
.941 .684 .52 r
.28676 .46925 .28771 .47065 .27516 .66665 .27408 .66617 Mtetra
.924 .579 .364 r
.27408 .66617 .27516 .66665 .27633 .67229 .27525 .67188 Mtetra
0 .526 .825 r
.27525 .67188 .27633 .67229 .27787 .67274 .2768 .67221 Mtetra
.694 .851 .958 r
.2768 .67221 .27787 .67274 .27949 .67221 .27842 .67152 Mtetra
.777 .819 .886 r
.27842 .67152 .27949 .67221 .28113 .67124 .28008 .67041 Mtetra
.528 .735 .969 r
.28008 .67041 .28113 .67124 .28272 .67111 .28167 .67026 Mtetra
.55 .74 .964 r
.28167 .67026 .28272 .67111 .28432 .67078 .28326 .67007 Mtetra
.688 .809 .94 r
.28326 .67007 .28432 .67078 .28597 .66979 .28488 .66942 Mtetra
.899 .838 .777 r
.28488 .66942 .28597 .66979 .28785 .66529 .28664 .66693 Mtetra
.986 .9 .596 r
.28664 .66693 .28785 .66529 .30266 .46934 .28858 .66157 Mtetra
0 0 .218 r
.28858 .66157 .30266 .46934 .30466 .46187 .30321 .46785 Mtetra
0 0 .119 r
.30321 .46785 .30466 .46187 .30626 .46017 .30509 .46217 Mtetra
0 0 0 r
.30509 .46217 .30626 .46017 .3078 .45949 .30675 .45963 Mtetra
.867 .969 .857 r
.30675 .45963 .3078 .45949 .30931 .4592 .30835 .45802 Mtetra
.717 .71 .843 r
.30835 .45802 .30931 .4592 .31083 .45876 .3099 .45719 Mtetra
.644 .63 .822 r
.3099 .45719 .31083 .45876 .31236 .45831 .31142 .45673 Mtetra
.608 .613 .831 r
.31142 .45673 .31236 .45831 .31388 .45789 .31294 .45645 Mtetra
.618 .637 .847 r
.31294 .45645 .31388 .45789 .31541 .45743 .31445 .45613 Mtetra
.621 .659 .866 r
.31445 .45613 .31541 .45743 .31693 .45696 .31597 .4558 Mtetra
.624 .686 .888 r
.31597 .4558 .31693 .45696 .31846 .45646 .3175 .45545 Mtetra
.646 .722 .904 r
.3175 .45545 .31846 .45646 .32 .45593 .31902 .45501 Mtetra
.663 .746 .911 r
.31902 .45501 .32 .45593 .32153 .45539 .32056 .4545 Mtetra
.678 .757 .91 r
.32056 .4545 .32153 .45539 .32307 .45484 .3221 .45393 Mtetra
.7 .757 .897 r
.3221 .45393 .32307 .45484 .32461 .4543 .32364 .45326 Mtetra
.702 .731 .873 r
.32364 .45326 .32461 .4543 .32614 .45377 .32519 .45255 Mtetra
.693 .699 .85 r
.32519 .45255 .32614 .45377 .32768 .45323 .32674 .45185 Mtetra
.673 .668 .837 r
.32674 .45185 .32768 .45323 .32922 .45267 .32828 .45124 Mtetra
.663 .657 .835 r
.32828 .45124 .32922 .45267 .33076 .4521 .32982 .45069 Mtetra
.658 .657 .838 r
.32982 .45069 .33076 .4521 .33231 .45154 .33136 .45016 Mtetra
.693 .674 .827 r
.33136 .45016 .33231 .45154 .33387 .45069 .33292 .44942 Mtetra
.683 .688 .848 r
.33292 .44942 .33387 .45069 .33542 .44998 .33447 .44877 Mtetra
.605 .67 .886 r
.33447 .44877 .33542 .44998 .33694 .44983 .336 .4485 Mtetra
0 .202 .728 r
.336 .4485 .33694 .44983 .33831 .45231 .33744 .44977 Mtetra
.721 .402 0 r
.33744 .44977 .33831 .45231 .3289 .64578 .33872 .45378 Mtetra
0 0 .256 r
.33872 .45378 .3289 .64578 .32997 .65526 .3294 .64622 Mtetra
.355 .233 .573 r
.3294 .64622 .32997 .65526 .33152 .65643 .33081 .64972 Mtetra
.577 .417 .627 r
.33081 .64972 .33152 .65643 .33316 .65604 .33244 .64937 Mtetra
.626 .453 .628 r
.33244 .64937 .33316 .65604 .33482 .65515 .33413 .648 Mtetra
.626 .449 .623 r
.33413 .648 .33482 .65515 .33648 .65446 .33583 .64652 Mtetra
.6 .424 .615 r
.33583 .64652 .33648 .65446 .33812 .65394 .3375 .64555 Mtetra
.549 .383 .608 r
.3375 .64555 .33812 .65394 .33977 .65346 .33911 .64572 Mtetra
.394 .273 .595 r
.33911 .64572 .33977 .65346 .3414 .65316 .34059 .64827 Mtetra
.31 .255 .632 r
.34059 .64827 .3414 .65316 .34304 .65294 .34209 .65049 Mtetra
.234 .321 .749 r
.34209 .65049 .34304 .65294 .34467 .6527 .34365 .65182 Mtetra
.297 .619 .958 r
.34365 .65182 .34467 .6527 .34632 .65233 .34526 .65212 Mtetra
.38 .817 .956 r
.34526 .65212 .34632 .65233 .34797 .65186 .3469 .65186 Mtetra
.43 .867 .912 r
.3469 .65186 .34797 .65186 .34962 .65135 .34855 .65137 Mtetra
.329 .812 .869 r
.34855 .65137 .34962 .65135 .35126 .65115 .3502 .65099 Mtetra
.498 .882 .968 r
.3502 .65099 .35126 .65115 .3529 .65089 .35185 .65052 Mtetra
.723 .902 .959 r
.35185 .65052 .3529 .65089 .35457 .65007 .35353 .64967 Mtetra
.893 .854 .796 r
.35353 .64967 .35457 .65007 .35636 .6468 .35527 .6474 Mtetra
.98 .867 .652 r
.35527 .6474 .35636 .6468 .36674 .46499 .35714 .64259 Mtetra
0 0 .217 r
.35714 .64259 .36674 .46499 .36942 .44129 .36798 .45038 Mtetra
.098 0 .32 r
.36798 .45038 .36942 .44129 .37107 .4389 .36983 .444 Mtetra
.497 .212 .411 r
.36983 .444 .37107 .4389 .37264 .43827 .37139 .44358 Mtetra
.529 .245 .427 r
.37139 .44358 .37264 .43827 .37419 .4381 .37293 .44358 Mtetra
.245 0 .326 r
.37293 .44358 .37419 .4381 .37575 .43767 .37461 .44071 Mtetra
0 0 0 r
.37461 .44071 .37575 .43767 .37732 .43694 .3763 .43752 Mtetra
.895 .988 .749 r
.3763 .43752 .37732 .43694 .3789 .43623 .37794 .43532 Mtetra
.77 .772 .855 r
.37794 .43532 .3789 .43623 .38047 .43565 .37954 .43421 Mtetra
.638 .649 .844 r
.37954 .43421 .38047 .43565 .38204 .43516 .3811 .43378 Mtetra
.594 .639 .865 r
.3811 .43378 .38204 .43516 .3836 .43469 .38266 .43355 Mtetra
.618 .691 .896 r
.38266 .43355 .3836 .43469 .38517 .43418 .38422 .43321 Mtetra
.661 .742 .91 r
.38422 .43321 .38517 .43418 .38675 .43361 .38579 .4327 Mtetra
.673 .756 .913 r
.38579 .4327 .38675 .43361 .38832 .43305 .38737 .43214 Mtetra
.728 .768 .885 r
.38737 .43214 .38832 .43305 .3899 .43225 .38896 .43131 Mtetra
.736 .763 .875 r
.38896 .43131 .3899 .43225 .39149 .43145 .39054 .43042 Mtetra
.666 .728 .896 r
.39054 .43042 .39149 .43145 .39305 .43115 .39212 .42988 Mtetra
.194 .451 .875 r
.39212 .42988 .39305 .43115 .39454 .43281 .39365 .43061 Mtetra
0 0 .349 r
.39365 .43061 .39454 .43281 .39546 .44896 .39508 .43379 Mtetra
.971 .706 .472 r
.39508 .43379 .39546 .44896 .38969 .63674 .38913 .62444 Mtetra
.233 .128 .523 r
.38913 .62444 .38969 .63674 .39127 .63867 .39051 .63138 Mtetra
.585 .417 .621 r
.39051 .63138 .39127 .63867 .39294 .63836 .39219 .63083 Mtetra
.605 .431 .619 r
.39219 .63083 .39294 .63836 .39464 .63749 .39389 .62977 Mtetra
.474 .333 .609 r
.39389 .62977 .39464 .63749 .39632 .63682 .39549 .63126 Mtetra
.325 .253 .62 r
.39549 .63126 .39632 .63682 .398 .63655 .39706 .63374 Mtetra
.268 .315 .727 r
.39706 .63374 .398 .63655 .39967 .63626 .39867 .6352 Mtetra
.317 .585 .939 r
.39867 .6352 .39967 .63626 .40135 .63587 .40032 .63558 Mtetra
.51 .866 .988 r
.40032 .63558 .40135 .63587 .40304 .63536 .40201 .63517 Mtetra
.6 .917 .975 r
.40201 .63517 .40304 .63536 .40473 .63481 .4037 .63453 Mtetra
.618 .904 .985 r
.4037 .63453 .40473 .63481 .40641 .63428 .40539 .6339 Mtetra
.584 .875 .994 r
.40539 .6339 .40641 .63428 .4081 .63378 .40708 .63341 Mtetra
.583 .875 .994 r
.40708 .63341 .4081 .63378 .40979 .63328 .40877 .63291 Mtetra
.531 .856 .996 r
.40877 .63291 .40979 .63328 .41148 .63282 .41046 .63251 Mtetra
.471 .847 .986 r
.41046 .63251 .41148 .63282 .41317 .63237 .41215 .63217 Mtetra
.555 .901 .976 r
.41215 .63217 .41317 .63237 .41486 .63188 .41384 .63161 Mtetra
.805 .929 .916 r
.41384 .63161 .41486 .63188 .41656 .6313 .41556 .63035 Mtetra
.863 .779 .767 r
.41556 .63035 .41656 .6313 .41826 .63058 .41731 .62796 Mtetra
.804 .639 .678 r
.41731 .62796 .41826 .63058 .41996 .62986 .4191 .62457 Mtetra
.705 .523 .64 r
.4191 .62457 .41996 .62986 .42166 .62946 .42087 .62167 Mtetra
.556 .393 .616 r
.42087 .62167 .42166 .62946 .42334 .62936 .42254 .62171 Mtetra
.574 .408 .618 r
.42254 .62171 .42334 .62936 .42504 .62874 .42424 .62134 Mtetra
.745 .533 .608 r
.42424 .62134 .42504 .62874 .4268 .62615 .42609 .61535 Mtetra
.942 .677 .504 r
.42609 .61535 .4268 .62615 .42894 .6099 .43325 .42157 Mtetra
.558 .341 .541 r
.43325 .42157 .42894 .6099 .43586 .41935 .43496 .41702 Mtetra
.761 .626 .71 r
.43496 .41702 .43586 .41935 .43753 .4163 .43661 .41495 Mtetra
.688 .684 .84 r
.43661 .41495 .43753 .4163 .43913 .41552 .43821 .41424 Mtetra
.619 .67 .878 r
.43821 .41424 .43913 .41552 .44073 .41525 .43981 .4139 Mtetra
.595 .648 .873 r
.43981 .4139 .44073 .41525 .44233 .41503 .44141 .41366 Mtetra
.619 .655 .863 r
.44141 .41366 .44233 .41503 .44393 .41452 .44301 .41332 Mtetra
.621 .684 .888 r
.44301 .41332 .44393 .41452 .44554 .41401 .44461 .41296 Mtetra
.649 .723 .903 r
.44461 .41296 .44554 .41401 .44714 .4135 .44622 .41249 Mtetra
.69 .744 .893 r
.44622 .41249 .44714 .4135 .44875 .41297 .44783 .41183 Mtetra
.693 .72 .871 r
.44783 .41183 .44875 .41297 .45036 .41244 .44944 .41114 Mtetra
.68 .689 .852 r
.44944 .41114 .45036 .41244 .45197 .41191 .45105 .41048 Mtetra
.661 .664 .842 r
.45105 .41048 .45197 .41191 .45358 .41138 .45266 .40992 Mtetra
.656 .657 .839 r
.45266 .40992 .45358 .41138 .45519 .41085 .45428 .40938 Mtetra
.666 .66 .834 r
.45428 .40938 .45519 .41085 .4568 .41029 .45589 .40878 Mtetra
.68 .659 .822 r
.45589 .40878 .4568 .41029 .45842 .40971 .45751 .40807 Mtetra
.648 .631 .819 r
.45751 .40807 .45842 .40971 .46003 .40915 .45912 .40755 Mtetra
.543 .587 .848 r
.45912 .40755 .46003 .40915 .46165 .40867 .46073 .40755 Mtetra
0 .305 .795 r
.46073 .40755 .46165 .40867 .46326 .40831 .46231 .40862 Mtetra
.781 .324 .158 r
.46231 .40862 .46326 .40831 .46487 .40798 .46388 .41062 Mtetra
.703 .361 .395 r
.46388 .41062 .46487 .40798 .46649 .40743 .46545 .41284 Mtetra
.457 .181 .405 r
.46545 .41284 .46649 .40743 .46812 .4065 .46709 .41187 Mtetra
.474 .195 .41 r
.46709 .41187 .46812 .4065 .46974 .406 .46871 .41112 Mtetra
.682 .383 .461 r
.46871 .41112 .46974 .406 .47133 .40687 .47028 .41414 Mtetra
.948 .673 .483 r
.47028 .41414 .47133 .40687 .4728 .41597 .46871 .60874 Mtetra
.556 .335 .535 r
.46871 .60874 .4728 .41597 .47137 .61218 .47036 .6131 Mtetra
.702 .261 .201 r
.47036 .6131 .47137 .61218 .47304 .61509 .47206 .61461 Mtetra
.473 .811 .999 r
.47206 .61461 .47304 .61509 .47477 .61501 .47378 .61437 Mtetra
.667 .839 .966 r
.47378 .61437 .47477 .61501 .4765 .61431 .47552 .61373 Mtetra
.68 .858 .967 r
.47552 .61373 .4765 .61431 .47824 .61344 .47726 .61304 Mtetra
.51 .845 .997 r
.47726 .61304 .47824 .61344 .47997 .61296 .47899 .61268 Mtetra
.458 .849 .979 r
.47899 .61268 .47997 .61296 .48171 .61247 .48072 .61232 Mtetra
.415 .848 .942 r
.48072 .61232 .48171 .61247 .48344 .61197 .48246 .61193 Mtetra
.414 .858 .909 r
.48246 .61193 .48344 .61197 .48518 .61146 .4842 .61144 Mtetra
.419 .862 .901 r
.4842 .61144 .48518 .61146 .48692 .61094 .48593 .61092 Mtetra
.424 .866 .901 r
.48593 .61092 .48692 .61094 .48866 .6104 .48768 .6104 Mtetra
.411 .859 .896 r
.48768 .6104 .48866 .6104 .4904 .60986 .48942 .60988 Mtetra
.409 .859 .883 r
.48942 .60988 .4904 .60986 .49214 .60931 .49116 .60934 Mtetra
.439 .876 .887 r
.49116 .60934 .49214 .60931 .49388 .60875 .4929 .60875 Mtetra
.531 .917 .921 r
.4929 .60875 .49388 .60875 .49563 .60821 .49465 .60804 Mtetra
.609 .929 .966 r
.49465 .60804 .49563 .60821 .49737 .60766 .4964 .60732 Mtetra
.646 .906 .982 r
.4964 .60732 .49737 .60766 .49912 .60711 .49815 .60663 Mtetra
.629 .869 .987 r
.49815 .60663 .49912 .60711 .50086 .60655 .4999 .60604 Mtetra
.619 .861 .989 r
.4999 .60604 .50086 .60655 .50261 .60599 .50164 .6055 Mtetra
.609 .863 .991 r
.50164 .6055 .50261 .60599 .50436 .60543 .50339 .60497 Mtetra
.607 .87 .992 r
.50339 .60497 .50436 .60543 .50611 .60488 .50515 .60443 Mtetra
.603 .87 .992 r
.50515 .60443 .50611 .60488 .50786 .60434 .5069 .60389 Mtetra
.6 .87 .993 r
.5069 .60389 .50786 .60434 .50962 .6038 .50865 .60336 Mtetra
.597 .871 .993 r
.50865 .60336 .50962 .6038 .51137 .60327 .51041 .60283 Mtetra
.595 .871 .993 r
.51041 .60283 .51137 .60327 .51312 .60274 .51216 .6023 Mtetra
.593 .871 .994 r
.51216 .6023 .51312 .60274 .51488 .60222 .51392 .60178 Mtetra
.592 .871 .994 r
.51392 .60178 .51488 .60222 .51664 .6017 .51568 .60126 Mtetra
.59 .87 .994 r
.51568 .60126 .51664 .6017 .51839 .60118 .51744 .60075 Mtetra
.589 .87 .994 r
.51744 .60075 .51839 .60118 .52015 .60067 .5192 .60023 Mtetra
.588 .869 .994 r
.5192 .60023 .52015 .60067 .52191 .60016 .52096 .59972 Mtetra
.587 .869 .994 r
.52096 .59972 .52191 .60016 .52368 .59965 .52272 .59921 Mtetra
.586 .868 .995 r
.52272 .59921 .52368 .59965 .52544 .59915 .52448 .5987 Mtetra
.585 .867 .995 r
.52448 .5987 .52544 .59915 .5272 .59865 .52625 .5982 Mtetra
.584 .865 .995 r
.52625 .5982 .5272 .59865 .52897 .59816 .52801 .5977 Mtetra
.583 .863 .995 r
.52801 .5977 .52897 .59816 .53073 .59768 .52978 .59721 Mtetra
.591 .864 .994 r
.52978 .59721 .53073 .59768 .5325 .59721 .53155 .5967 Mtetra
.588 .854 .994 r
.53155 .5967 .5325 .59721 .53427 .59674 .53332 .59622 Mtetra
.572 .846 .996 r
.53332 .59622 .53427 .59674 .53604 .59627 .53509 .59579 Mtetra
.507 .828 1 r
.53509 .59579 .53604 .59627 .53781 .59579 .53686 .59547 Mtetra
.438 .834 .981 r
.53686 .59547 .53781 .59579 .53958 .5953 .53863 .59516 Mtetra
.36 .82 .924 r
.53863 .59516 .53958 .5953 .54135 .59481 .54041 .59482 Mtetra
.349 .825 .869 r
.54041 .59482 .54135 .59481 .54313 .59434 .54218 .59436 Mtetra
.363 .833 .865 r
.54218 .59436 .54313 .59434 .5449 .59386 .54396 .59387 Mtetra
.389 .848 .88 r
.54396 .59387 .5449 .59386 .54668 .59338 .54574 .59335 Mtetra
.403 .854 .896 r
.54574 .59335 .54668 .59338 .54846 .59288 .54752 .59284 Mtetra
.412 .858 .902 r
.54752 .59284 .54846 .59288 .55024 .59237 .5493 .59233 Mtetra
.42 .862 .906 r
.5493 .59233 .55024 .59237 .55202 .59186 .55108 .59181 Mtetra
.412 .857 .907 r
.55108 .59181 .55202 .59186 .5538 .59136 .55286 .59131 Mtetra
.425 .864 .91 r
.55286 .59131 .5538 .59136 .55558 .59085 .55464 .59079 Mtetra
.454 .879 .919 r
.55464 .59079 .55558 .59085 .55736 .59032 .55643 .59023 Mtetra
.354 .823 .903 r
.55643 .59023 .55736 .59032 .55915 .5902 .55822 .58984 Mtetra
.606 .897 .988 r
.55822 .58984 .55915 .5902 .56094 .58973 .56 .58922 Mtetra
.764 .895 .936 r
.56 .58922 .56094 .58973 .56272 .58857 .56178 .58815 Mtetra
.939 .857 .733 r
.56178 .58815 .56272 .58857 .56445 .58341 .56354 .58497 Mtetra
.978 .867 .487 r
.56354 .58497 .56445 .58341 .5638 .38177 .56526 .57831 Mtetra
0 0 .365 r
.56526 .57831 .5638 .38177 .5654 .37488 .5646 .38054 Mtetra
.329 .078 .374 r
.5646 .38054 .5654 .37488 .56707 .37348 .56626 .37799 Mtetra
.488 .194 .392 r
.56626 .37799 .56707 .37348 .56875 .37297 .56794 .37754 Mtetra
.56 .258 .413 r
.56794 .37754 .56875 .37297 .57043 .37286 .56964 .37802 Mtetra
.553 .261 .425 r
.56964 .37802 .57043 .37286 .57212 .3724 .57134 .3784 Mtetra
.522 .244 .434 r
.57134 .3784 .57212 .3724 .5738 .37189 .57303 .37824 Mtetra
.439 .177 .419 r
.57303 .37824 .5738 .37189 .57548 .37134 .57471 .37675 Mtetra
.138 0 .305 r
.57471 .37675 .57548 .37134 .57717 .37059 .57634 .37269 Mtetra
0 0 0 r
.57634 .37269 .57717 .37059 .57885 .3698 .57799 .36976 Mtetra
.91 .959 .809 r
.57799 .36976 .57885 .3698 .58053 .36903 .57965 .36769 Mtetra
.718 .706 .837 r
.57965 .36769 .58053 .36903 .58222 .36842 .58133 .36676 Mtetra
.649 .635 .822 r
.58133 .36676 .58222 .36842 .58391 .36788 .58302 .36622 Mtetra
.617 .62 .831 r
.58302 .36622 .58391 .36788 .5856 .36735 .58472 .36586 Mtetra
.623 .645 .851 r
.58472 .36586 .5856 .36735 .58729 .36681 .58641 .36547 Mtetra
.625 .671 .874 r
.58641 .36547 .58729 .36681 .58898 .36626 .58811 .36508 Mtetra
.634 .703 .896 r
.58811 .36508 .58898 .36626 .59067 .3657 .5898 .36465 Mtetra
.685 .745 .897 r
.5898 .36465 .59067 .3657 .59237 .36513 .5915 .36398 Mtetra
.698 .732 .877 r
.5915 .36398 .59237 .36513 .59406 .36455 .59319 .36324 Mtetra
.692 .703 .855 r
.59319 .36324 .59406 .36455 .59576 .36397 .59488 .36249 Mtetra
.707 .684 .825 r
.59488 .36249 .59576 .36397 .59745 .363 .59657 .3616 Mtetra
.681 .684 .846 r
.59657 .3616 .59745 .363 .59914 .36226 .59827 .3609 Mtetra
.601 .657 .877 r
.59827 .3609 .59914 .36226 .60085 .3621 .59997 .36061 Mtetra
.085 .337 .811 r
.59997 .36061 .60085 .3621 .60263 .36498 .60172 .36185 Mtetra
0 0 .533 r
.60172 .36185 .60263 .36498 .60932 .56451 .60353 .36568 Mtetra
0 0 .394 r
.60353 .36568 .60932 .56451 .61136 .57266 .61024 .56356 Mtetra
.246 .166 .564 r
.61024 .56356 .61136 .57266 .61322 .57368 .61221 .56922 Mtetra
.37 .317 .667 r
.61221 .56922 .61322 .57368 .61504 .57342 .61409 .57109 Mtetra
.408 .448 .791 r
.61409 .57109 .61504 .57342 .61686 .57269 .61595 .57187 Mtetra
.488 .738 .982 r
.61595 .57187 .61686 .57269 .61868 .57214 .61779 .57176 Mtetra
.559 .88 .991 r
.61779 .57176 .61868 .57214 .62051 .57161 .61961 .57124 Mtetra
.638 .908 .982 r
.61961 .57124 .62051 .57161 .62233 .57103 .62143 .57052 Mtetra
.503 .825 1 r
.62143 .57052 .62233 .57103 .62417 .57084 .62327 .57021 Mtetra
.561 .817 .993 r
.62327 .57021 .62417 .57084 .626 .57048 .6251 .56983 Mtetra
.7 .858 .957 r
.6251 .56983 .626 .57048 .62782 .5695 .62692 .56903 Mtetra
.91 .888 .798 r
.62692 .56903 .62782 .5695 .62954 .56554 .6287 .56667 Mtetra
.949 .9 .514 r
.6287 .56667 .62954 .56554 .62512 .36615 .63039 .56179 Mtetra
0 0 .388 r
.63039 .56179 .62512 .36615 .62652 .35537 .62595 .3635 Mtetra
0 0 .307 r
.62595 .3635 .62652 .35537 .62818 .35317 .62744 .35553 Mtetra
0 0 .014 r
.62744 .35553 .62818 .35317 .62989 .35234 .62908 .35261 Mtetra
.814 .997 .775 r
.62908 .35261 .62989 .35234 .63161 .35195 .63076 .35082 Mtetra
.722 .747 .872 r
.63076 .35082 .63161 .35195 .63333 .35148 .63247 .34993 Mtetra
.628 .643 .846 r
.63247 .34993 .63333 .35148 .63506 .35096 .63419 .34951 Mtetra
.59 .639 .868 r
.63419 .34951 .63506 .35096 .63678 .35047 .63592 .34928 Mtetra
.631 .703 .898 r
.63592 .34928 .63678 .35047 .6385 .34989 .63765 .34885 Mtetra
.666 .746 .91 r
.63765 .34885 .6385 .34989 .64022 .34926 .63938 .34826 Mtetra
.679 .76 .912 r
.63938 .34826 .64022 .34926 .64195 .34862 .6411 .34762 Mtetra
.74 .776 .882 r
.6411 .34762 .64195 .34862 .64366 .34769 .64281 .34666 Mtetra
.732 .768 .882 r
.64281 .34666 .64366 .34769 .64537 .34687 .64452 .34573 Mtetra
.654 .722 .899 r
.64452 .34573 .64537 .34687 .64711 .3466 .64625 .3452 Mtetra
.175 .413 .852 r
.64625 .3452 .64711 .3466 .64895 .34877 .64804 .34619 Mtetra
0 0 .531 r
.64804 .34619 .64895 .34877 .65848 .54476 .64994 .34977 Mtetra
0 0 .407 r
.64994 .34977 .65848 .54476 .66085 .55734 .65956 .54647 Mtetra
.379 .252 .58 r
.65956 .54647 .66085 .55734 .66278 .55871 .66161 .55092 Mtetra
.59 .419 .619 r
.66161 .55092 .66278 .55871 .66463 .55825 .66345 .55014 Mtetra
.601 .425 .615 r
.66345 .55014 .66463 .55825 .66647 .55729 .66527 .54905 Mtetra
.447 .316 .609 r
.66527 .54905 .66647 .55729 .66832 .55671 .66724 .5513 Mtetra
.358 .289 .642 r
.66724 .5513 .66832 .55671 .67019 .55645 .66923 .55375 Mtetra
.32 .365 .752 r
.66923 .55375 .67019 .55645 .67206 .55615 .67117 .55513 Mtetra
.311 .598 .947 r
.67117 .55513 .67206 .55615 .67394 .55599 .67307 .55554 Mtetra
.471 .827 .996 r
.67307 .55554 .67394 .55599 .67581 .55566 .67494 .55523 Mtetra
.704 .918 .967 r
.67494 .55523 .67581 .55566 .67765 .5547 .67679 .55432 Mtetra
.909 .92 .813 r
.67679 .55432 .67765 .5547 .67938 .55117 .67858 .55209 Mtetra
.954 .903 .524 r
.67858 .55209 .67938 .55117 .67208 .35295 .68025 .54734 Mtetra
0 0 .402 r
.68025 .54734 .67208 .35295 .67324 .33993 .67286 .34847 Mtetra
0 0 .321 r
.67286 .34847 .67324 .33993 .67489 .33731 .67423 .33982 Mtetra
0 0 .071 r
.67423 .33982 .67489 .33731 .67662 .33635 .67586 .33683 Mtetra
.732 .959 .673 r
.67586 .33683 .67662 .33635 .67837 .33586 .67755 .33495 Mtetra
.793 .812 .867 r
.67755 .33495 .67837 .33586 .68011 .33514 .67926 .33367 Mtetra
.695 .685 .836 r
.67926 .33367 .68011 .33514 .68185 .33435 .681 .33285 Mtetra
.607 .643 .86 r
.681 .33285 .68185 .33435 .68361 .33406 .68276 .33253 Mtetra
.325 .485 .864 r
.68276 .33253 .68361 .33406 .68547 .33565 .68458 .33325 Mtetra
0 .138 .666 r
.68458 .33325 .68547 .33565 .68778 .3458 .68649 .33583 Mtetra
0 0 .304 r
.68649 .33583 .68778 .3458 .69991 .54483 .68911 .35188 Mtetra
.029 0 .427 r
.68911 .35188 .69991 .54483 .70194 .54711 .7008 .54113 Mtetra
.375 .292 .634 r
.7008 .54113 .70194 .54711 .70385 .54708 .70284 .54369 Mtetra
.431 .397 .721 r
.70284 .54369 .70385 .54708 .70572 .54646 .70481 .54475 Mtetra
.404 .52 .861 r
.70481 .54475 .70572 .54646 .70761 .54611 .70675 .5453 Mtetra
.402 .703 .983 r
.70675 .5453 .70761 .54611 .70952 .54593 .70867 .54537 Mtetra
.663 .881 .979 r
.70867 .54537 .70952 .54593 .71139 .54513 .71054 .54464 Mtetra
.945 .88 .74 r
.71054 .54464 .71139 .54513 .71313 .54207 .71229 .54159 Mtetra
.984 .73 .463 r
.71229 .54159 .71313 .54207 .71396 .52278 .71318 .5233 Mtetra
.977 .686 .392 r
.71318 .5233 .71396 .52278 .70484 .32963 .70399 .32812 Mtetra
.863 .735 .72 r
.70399 .32812 .70484 .32963 .70648 .32677 .70563 .3253 Mtetra
.667 .674 .847 r
.70563 .3253 .70648 .32677 .70823 .32602 .70739 .32465 Mtetra
.551 .638 .89 r
.70739 .32465 .70823 .32602 .71002 .32578 .70919 .32456 Mtetra
.566 .672 .91 r
.70919 .32456 .71002 .32578 .7118 .32548 .71098 .32438 Mtetra
.659 .738 .908 r
.71098 .32438 .7118 .32548 .71357 .32486 .71275 .32381 Mtetra
.672 .754 .912 r
.71275 .32381 .71357 .32486 .71533 .32423 .71452 .32318 Mtetra
.739 .776 .883 r
.71452 .32318 .71533 .32423 .71709 .32336 .71627 .32221 Mtetra
.757 .76 .855 r
.71627 .32221 .71709 .32336 .71884 .3224 .71801 .32107 Mtetra
.663 .696 .87 r
.71801 .32107 .71884 .3224 .72062 .32194 .71978 .32047 Mtetra
.11 .355 .821 r
.71978 .32047 .72062 .32194 .72252 .32331 .72167 .32174 Mtetra
.94 .589 .178 r
.72167 .32174 .72252 .32331 .72511 .33562 .72423 .33353 Mtetra
.976 .675 .365 r
.72423 .33353 .72511 .33562 .73961 .53379 .73878 .53319 Mtetra
.644 .119 0 r
.73878 .53319 .73961 .53379 .7417 .53611 .74086 .53547 Mtetra
.564 .828 .995 r
.74086 .53547 .7417 .53611 .74362 .53584 .74278 .53505 Mtetra
.748 .851 .926 r
.74278 .53505 .74362 .53584 .74551 .53495 .74466 .53401 Mtetra
.697 .801 .93 r
.74466 .53401 .74551 .53495 .74741 .53425 .74655 .53322 Mtetra
.532 .714 .956 r
.74655 .53322 .74741 .53425 .74934 .53403 .74849 .53306 Mtetra
.626 .771 .95 r
.74849 .53306 .74934 .53403 .75124 .53329 .7504 .53257 Mtetra
.832 .876 .876 r
.7504 .53257 .75124 .53329 .75302 .5308 .75225 .531 Mtetra
.976 .923 .632 r
.75225 .531 .75302 .5308 .75428 .52078 .75393 .5271 Mtetra
0 0 .035 r
.75393 .5271 .75428 .52078 .74223 .31847 .75496 .51373 Mtetra
.044 0 .431 r
.75496 .51373 .74223 .31847 .7438 .31482 .7433 .31812 Mtetra
0 0 .196 r
.7433 .31812 .7438 .31482 .74556 .31371 .74489 .31455 Mtetra
0 0 0 r
.74489 .31455 .74556 .31371 .74735 .31316 .74657 .31246 Mtetra
.796 .868 .902 r
.74657 .31246 .74735 .31316 .74915 .31274 .74832 .31122 Mtetra
.651 .663 .849 r
.74832 .31122 .74915 .31274 .75094 .31215 .75011 .31066 Mtetra
.609 .647 .863 r
.75011 .31066 .75094 .31215 .75274 .31161 .75193 .31032 Mtetra
.647 .698 .883 r
.75193 .31032 .75274 .31161 .75453 .31091 .75373 .30979 Mtetra
.732 .763 .877 r
.75373 .30979 .75453 .31091 .7563 .31 .75549 .30883 Mtetra
.679 .734 .892 r
.75549 .30883 .7563 .31 .7581 .30952 .75729 .30815 Mtetra
.454 .588 .897 r
.75729 .30815 .7581 .30952 .76002 .31045 .75915 .30841 Mtetra
0 .116 .662 r
.75915 .30841 .76002 .31045 .76242 .31784 .76119 .31103 Mtetra
0 0 .252 r
.76119 .31103 .76242 .31784 .77973 .52061 .76411 .32512 Mtetra
.07 0 .45 r
.76411 .32512 .77973 .52061 .78193 .52366 .78059 .51604 Mtetra
.568 .407 .622 r
.78059 .51604 .78193 .52366 .7839 .52348 .78254 .5158 Mtetra
.6 .428 .62 r
.78254 .5158 .7839 .52348 .78581 .52265 .78444 .51478 Mtetra
.533 .381 .62 r
.78444 .51478 .78581 .52265 .78772 .52178 .78646 .51533 Mtetra
.394 .301 .631 r
.78646 .51533 .78772 .52178 .78968 .52146 .78864 .51795 Mtetra
.369 .355 .712 r
.78864 .51795 .78968 .52146 .79163 .52113 .79075 .51955 Mtetra
.355 .511 .875 r
.79075 .51955 .79163 .52113 .79358 .52072 .79279 .52023 Mtetra
.438 .807 .994 r
.79279 .52023 .79358 .52072 .79552 .52016 .79476 .51999 Mtetra
.419 .856 .928 r
.79476 .51999 .79552 .52016 .79746 .51955 .79671 .51948 Mtetra
.41 .86 .884 r
.79671 .51948 .79746 .51955 .7994 .51893 .79865 .51888 Mtetra
.376 .841 .872 r
.79865 .51888 .7994 .51893 .80134 .51836 .8006 .51832 Mtetra
.393 .851 .866 r
.8006 .51832 .80134 .51836 .80329 .51778 .80254 .51771 Mtetra
.447 .88 .889 r
.80254 .51771 .80329 .51778 .80523 .51718 .80448 .51704 Mtetra
.531 .915 .929 r
.80448 .51704 .80523 .51718 .80718 .51656 .80642 .51629 Mtetra
.594 .925 .965 r
.80642 .51629 .80718 .51656 .80912 .51594 .80835 .51552 Mtetra
.624 .907 .984 r
.80835 .51552 .80912 .51594 .81107 .51533 .81029 .51479 Mtetra
.613 .876 .991 r
.81029 .51479 .81107 .51533 .81302 .51474 .81224 .51416 Mtetra
.605 .863 .992 r
.81224 .51416 .81302 .51474 .81497 .51417 .81419 .51357 Mtetra
.596 .856 .993 r
.81419 .51357 .81497 .51417 .81693 .51362 .81615 .51302 Mtetra
.588 .853 .994 r
.81615 .51302 .81693 .51362 .81889 .51309 .81811 .51249 Mtetra
.584 .85 .994 r
.81811 .51249 .81889 .51309 .82085 .51258 .82007 .51197 Mtetra
.543 .831 .998 r
.82007 .51197 .82085 .51258 .82283 .51217 .82205 .51157 Mtetra
.395 .755 .993 r
.82205 .51157 .82283 .51217 .82483 .51211 .82405 .5115 Mtetra
.584 .848 .994 r
.82405 .5115 .82483 .51211 .8268 .51159 .82602 .51099 Mtetra
.844 .914 .882 r
.82602 .51099 .8268 .51159 .82866 .50992 .82789 .50935 Mtetra
.991 .81 .564 r
.82789 .50935 .82866 .50992 .83006 .5032 .82932 .50294 Mtetra
.977 .674 .339 r
.82932 .50294 .83006 .5032 .813 .29669 .81224 .29575 Mtetra
.972 .791 .6 r
.81224 .29575 .813 .29669 .81441 .29153 .81363 .29031 Mtetra
.756 .759 .856 r
.81363 .29031 .81441 .29153 .8162 .29038 .81541 .28916 Mtetra
.629 .707 .903 r
.81541 .28916 .8162 .29038 .81804 .28991 .81726 .28871 Mtetra
.583 .69 .915 r
.81726 .28871 .81804 .28991 .81991 .28962 .81913 .28845 Mtetra
.751 .766 .865 r
.81913 .28845 .81991 .28962 .8217 .2885 .82092 .28734 Mtetra
.678 .741 .898 r
.82092 .28734 .8217 .2885 .82353 .28781 .82275 .28665 Mtetra
.398 .602 .929 r
.82275 .28665 .82353 .28781 .82546 .28813 .82468 .28698 Mtetra
.818 .41 0 r
.82468 .28698 .82546 .28813 .82793 .29404 .82715 .29285 Mtetra
.973 .661 .312 r
.82715 .29285 .82793 .29404 .84993 .49942 .84912 .49832 Mtetra
.692 .253 0 r
.84912 .49832 .84993 .49942 .85236 .50349 .85156 .50241 Mtetra
.341 .601 .944 r
.85156 .50241 .85236 .50349 .85444 .5039 .85364 .50282 Mtetra
.668 .77 .926 r
.85364 .50282 .85444 .5039 .85642 .50322 .85561 .50214 Mtetra
.849 .821 .821 r
.85561 .50214 .85642 .50322 .85826 .50128 .85746 .50019 Mtetra
.977 .78 .572 r
.85746 .50019 .85826 .50128 .85964 .49465 .85883 .49356 Mtetra
.976 .67 .326 r
.85883 .49356 .85964 .49465 .84064 .2875 .83988 .28636 Mtetra
.965 .78 .603 r
.83988 .28636 .84064 .2875 .84201 .28209 .84125 .28095 Mtetra
.762 .778 .866 r
.84125 .28095 .84201 .28209 .8438 .28092 .84304 .27978 Mtetra
.632 .728 .917 r
.84304 .27978 .8438 .28092 .84567 .28044 .84491 .27931 Mtetra
.556 .692 .93 r
.84491 .27931 .84567 .28044 .84756 .28026 .84681 .27912 Mtetra
.753 .776 .872 r
.84681 .27912 .84756 .28026 .84937 .27915 .84861 .27802 Mtetra
.685 .752 .902 r
.84861 .27802 .84937 .27915 .85121 .27843 .85045 .27729 Mtetra
.484 .655 .936 r
.85045 .27729 .85121 .27843 .85314 .27848 .85238 .27735 Mtetra
.734 .314 0 r
.85238 .27735 .85314 .27848 .85557 .28323 .85481 .28208 Mtetra
.971 .656 .295 r
.85481 .28208 .85557 .28323 .87957 .48939 .87878 .48829 Mtetra
.749 .321 0 r
.87878 .48829 .87957 .48939 .88216 .49433 .88137 .49327 Mtetra
.403 .645 .955 r
.88137 .49327 .88216 .49433 .88424 .49442 .88346 .4935 Mtetra
.63 .794 .961 r
.88346 .4935 .88424 .49442 .88623 .49373 .88547 .49295 Mtetra
.727 .863 .945 r
.88547 .49295 .88623 .49373 .88817 .49262 .88743 .49196 Mtetra
.513 .715 .963 r
.24538 .67977 .24644 .68066 .248 .68057 .24694 .67968 Mtetra
.656 .759 .925 r
.24694 .67968 .248 .68057 .2496 .68007 .24854 .67917 Mtetra
.785 .775 .843 r
.24854 .67917 .2496 .68007 .25125 .67879 .25019 .67789 Mtetra
.912 .731 .644 r
.25019 .67789 .25125 .67879 .2533 .67252 .25224 .67158 Mtetra
.937 .686 .534 r
.25224 .67158 .2533 .67252 .27009 .47529 .2691 .47432 Mtetra
.901 .729 .659 r
.2691 .47432 .27009 .47529 .27195 .47016 .27096 .46923 Mtetra
.751 .756 .856 r
.27096 .46923 .27195 .47016 .2735 .46919 .27251 .46825 Mtetra
.582 .714 .934 r
.27251 .46825 .2735 .46919 .27498 .46897 .27399 .46802 Mtetra
.408 .642 .952 r
.27399 .46802 .27498 .46897 .27644 .46914 .27545 .46818 Mtetra
.631 .728 .917 r
.27545 .46818 .27644 .46914 .27794 .46874 .27695 .46781 Mtetra
.656 .737 .91 r
.27695 .46781 .27794 .46874 .27945 .46825 .27846 .46733 Mtetra
.671 .746 .907 r
.27846 .46733 .27945 .46825 .28097 .46768 .27998 .4668 Mtetra
.773 .768 .848 r
.27998 .4668 .28097 .46768 .28253 .46651 .28153 .46568 Mtetra
.73 .774 .888 r
.28153 .46568 .28253 .46651 .28406 .46566 .28307 .46487 Mtetra
.524 .73 .968 r
.28307 .46487 .28406 .46566 .28555 .46549 .28456 .46474 Mtetra
.92 .538 .264 r
.28456 .46474 .28555 .46549 .28676 .46925 .28575 .46868 Mtetra
.939 .683 .521 r
.28575 .46868 .28676 .46925 .27408 .66617 .27301 .66564 Mtetra
.923 .573 .352 r
.27301 .66564 .27408 .66617 .27525 .67188 .27419 .67106 Mtetra
.256 .613 .956 r
.27419 .67106 .27525 .67188 .2768 .67221 .27574 .67137 Mtetra
.7 .781 .914 r
.27574 .67137 .2768 .67221 .27842 .67152 .27737 .67067 Mtetra
.77 .786 .866 r
.27737 .67067 .27842 .67152 .28008 .67041 .27902 .66955 Mtetra
.607 .755 .949 r
.27902 .66955 .28008 .67041 .28167 .67026 .28063 .6692 Mtetra
.601 .71 .92 r
.28063 .6692 .28167 .67026 .28326 .67007 .28223 .66891 Mtetra
.657 .708 .885 r
.28223 .66891 .28326 .67007 .28488 .66942 .28384 .66839 Mtetra
.755 .753 .851 r
.28384 .66839 .28488 .66942 .28664 .66693 .2855 .66731 Mtetra
.853 .994 .833 r
.2855 .66731 .28664 .66693 .28858 .66157 .2872 .66557 Mtetra
.008 0 .146 r
.2872 .66557 .28858 .66157 .30321 .46785 .28899 .66255 Mtetra
0 0 .253 r
.28899 .66255 .30321 .46785 .30509 .46217 .30309 .47643 Mtetra
0 0 .104 r
.30309 .47643 .30509 .46217 .30675 .45963 .30564 .46072 Mtetra
.96 .944 .655 r
.30564 .46072 .30675 .45963 .30835 .45802 .30736 .45725 Mtetra
.789 .792 .855 r
.30736 .45725 .30835 .45802 .3099 .45719 .30893 .45605 Mtetra
.654 .699 .879 r
.30893 .45605 .3099 .45719 .31142 .45673 .31046 .45558 Mtetra
.572 .667 .903 r
.31046 .45558 .31142 .45673 .31294 .45645 .31197 .45541 Mtetra
.607 .704 .913 r
.31197 .45541 .31294 .45645 .31445 .45613 .31348 .45512 Mtetra
.616 .713 .914 r
.31348 .45512 .31445 .45613 .31597 .4558 .315 .45479 Mtetra
.618 .715 .915 r
.315 .45479 .31597 .4558 .3175 .45545 .31653 .45446 Mtetra
.642 .724 .908 r
.31653 .45446 .3175 .45545 .31902 .45501 .31805 .45403 Mtetra
.658 .732 .904 r
.31805 .45403 .31902 .45501 .32056 .4545 .31959 .45354 Mtetra
.671 .74 .902 r
.31959 .45354 .32056 .4545 .3221 .45393 .32112 .453 Mtetra
.69 .751 .898 r
.32112 .453 .3221 .45393 .32364 .45326 .32267 .45237 Mtetra
.698 .762 .902 r
.32267 .45237 .32364 .45326 .32519 .45255 .32421 .45171 Mtetra
.697 .773 .91 r
.32421 .45171 .32519 .45255 .32674 .45185 .32576 .45106 Mtetra
.681 .78 .925 r
.32576 .45106 .32674 .45185 .32828 .45124 .3273 .45048 Mtetra
.67 .784 .934 r
.3273 .45048 .32828 .45124 .32982 .45069 .32884 .44993 Mtetra
.664 .786 .939 r
.32884 .44993 .32982 .45069 .33136 .45016 .33038 .44941 Mtetra
.693 .793 .927 r
.33038 .44941 .33136 .45016 .33292 .44942 .33193 .44878 Mtetra
.679 .818 .95 r
.33193 .44878 .33292 .44942 .33447 .44877 .33348 .44819 Mtetra
.609 .817 .98 r
.33348 .44819 .33447 .44877 .336 .4485 .33502 .44779 Mtetra
.232 .614 .954 r
.33502 .44779 .336 .4485 .33744 .44977 .33651 .44808 Mtetra
.242 .401 .822 r
.33651 .44808 .33744 .44977 .33872 .45378 .33798 .44895 Mtetra
.432 .334 .644 r
.33798 .44895 .33872 .45378 .3294 .64622 .33942 .45025 Mtetra
.548 .333 .54 r
.33942 .45025 .3294 .64622 .33081 .64972 .34092 .45066 Mtetra
.55 .334 .54 r
.34092 .45066 .33081 .64972 .33244 .64937 .34247 .45013 Mtetra
.551 .335 .54 r
.34247 .45013 .33244 .64937 .33413 .648 .34404 .44926 Mtetra
.34404 .44926 .33413 .648 .33583 .64652 .34563 .44806 Mtetra
.34563 .44806 .33583 .64652 .3375 .64555 .3472 .44718 Mtetra
.549 .333 .54 r
.3472 .44718 .3375 .64555 .33911 .64572 .34872 .44723 Mtetra
.535 .322 .537 r
.34872 .44723 .33911 .64572 .34059 .64827 .34989 .45397 Mtetra
0 0 .269 r
.34989 .45397 .34059 .64827 .34209 .65049 .34121 .64678 Mtetra
0 0 .485 r
.34121 .64678 .34209 .65049 .34365 .65182 .34264 .65051 Mtetra
.146 .43 .869 r
.34264 .65051 .34365 .65182 .34526 .65212 .34422 .65132 Mtetra
.569 .763 .97 r
.34422 .65132 .34526 .65212 .3469 .65186 .34586 .65105 Mtetra
.685 .792 .931 r
.34586 .65105 .3469 .65186 .34855 .65137 .34752 .65041 Mtetra
.666 .753 .916 r
.34752 .65041 .34855 .65137 .3502 .65099 .34918 .64984 Mtetra
.663 .717 .889 r
.34918 .64984 .3502 .65099 .35185 .65052 .35084 .64929 Mtetra
.698 .712 .86 r
.35084 .64929 .35185 .65052 .35353 .64967 .35251 .64853 Mtetra
.777 .745 .823 r
.35251 .64853 .35353 .64967 .35527 .6474 .35421 .64718 Mtetra
.887 .9 .833 r
.35421 .64718 .35527 .6474 .35714 .64259 .35594 .64524 Mtetra
0 0 .015 r
.35594 .64524 .35714 .64259 .36798 .45038 .35769 .6429 Mtetra
.546 .327 .533 r
.35769 .6429 .36798 .45038 .36983 .444 .35938 .64181 Mtetra
.548 .328 .534 r
.35938 .64181 .36983 .444 .37139 .44358 .36102 .64171 Mtetra
.547 .327 .533 r
.36102 .64171 .37139 .44358 .37293 .44358 .36269 .64101 Mtetra
.537 .32 .532 r
.36269 .64101 .37293 .44358 .37461 .44071 .3646 .63518 Mtetra
0 0 .267 r
.3646 .63518 .37461 .44071 .3763 .43752 .3752 .43966 Mtetra
.904 .891 .471 r
.3752 .43966 .3763 .43752 .37794 .43532 .37697 .43483 Mtetra
.862 .851 .83 r
.37697 .43483 .37794 .43532 .37954 .43421 .37859 .4331 Mtetra
.657 .71 .887 r
.37859 .4331 .37954 .43421 .3811 .43378 .38016 .4326 Mtetra
.561 .662 .905 r
.38016 .4326 .3811 .43378 .38266 .43355 .38171 .43247 Mtetra
.594 .694 .912 r
.38171 .43247 .38266 .43355 .38422 .43321 .38327 .43222 Mtetra
.654 .732 .907 r
.38327 .43222 .38422 .43321 .38579 .4327 .38485 .43173 Mtetra
.665 .741 .907 r
.38485 .43173 .38579 .4327 .38737 .43214 .38642 .4312 Mtetra
.702 .757 .895 r
.38642 .4312 .38737 .43214 .38896 .43131 .388 .4305 Mtetra
.718 .79 .909 r
.388 .4305 .38896 .43131 .39054 .43042 .38958 .42974 Mtetra
.676 .814 .949 r
.38958 .42974 .39054 .43042 .39212 .42988 .39116 .42915 Mtetra
.43 .714 .984 r
.39116 .42915 .39212 .42988 .39365 .43061 .39272 .42917 Mtetra
.253 .452 .862 r
.39272 .42917 .39365 .43061 .39508 .43379 .39425 .42989 Mtetra
.417 .35 .675 r
.39425 .42989 .39508 .43379 .38913 .62444 .39576 .43107 Mtetra
.548 .333 .54 r
.39576 .43107 .38913 .62444 .39051 .63138 .39731 .43132 Mtetra
.551 .335 .54 r
.39731 .43132 .39051 .63138 .39219 .63083 .39891 .43037 Mtetra
.55 .334 .54 r
.39891 .43037 .39219 .63083 .39389 .62977 .40049 .42994 Mtetra
.542 .327 .539 r
.40049 .42994 .39389 .62977 .39549 .63126 .40192 .43354 Mtetra
0 0 .301 r
.40192 .43354 .39549 .63126 .39706 .63374 .39619 .62903 Mtetra
0 0 .481 r
.39619 .62903 .39706 .63374 .39867 .6352 .39769 .63365 Mtetra
.048 .321 .805 r
.39769 .63365 .39867 .6352 .40032 .63558 .39931 .63484 Mtetra
.577 .783 .977 r
.39931 .63484 .40032 .63558 .40201 .63517 .40099 .63452 Mtetra
.699 .836 .949 r
.40099 .63452 .40201 .63517 .4037 .63453 .40269 .63379 Mtetra
.695 .815 .94 r
.40269 .63379 .4037 .63453 .40539 .6339 .40438 .63309 Mtetra
.642 .784 .95 r
.40438 .63309 .40539 .6339 .40708 .63341 .40607 .63259 Mtetra
.643 .785 .95 r
.40607 .63259 .40708 .63341 .40877 .63291 .40776 .63209 Mtetra
.588 .768 .965 r
.40776 .63209 .40877 .63291 .41046 .63251 .40945 .63176 Mtetra
.547 .77 .981 r
.40945 .63176 .41046 .63251 .41215 .63217 .41114 .63152 Mtetra
.671 .831 .96 r
.41114 .63152 .41215 .63217 .41384 .63161 .41283 .63089 Mtetra
.856 .819 .811 r
.41283 .63089 .41384 .63161 .41556 .63035 .41458 .62894 Mtetra
.899 .723 .655 r
.41458 .62894 .41556 .63035 .41731 .62796 .41642 .62375 Mtetra
.95 .686 .5 r
.41642 .62375 .41731 .62796 .4191 .62457 .42419 .42727 Mtetra
.56 .342 .541 r
.42419 .42727 .4191 .62457 .42087 .62167 .42595 .4215 Mtetra
.55 .334 .54 r
.42595 .4215 .42087 .62167 .42254 .62171 .42755 .42079 Mtetra
.549 .334 .54 r
.42755 .42079 .42254 .62171 .42424 .62134 .42914 .42066 Mtetra
.551 .335 .54 r
.42914 .42066 .42424 .62134 .42609 .61535 .43076 .41957 Mtetra
.553 .337 .54 r
.43076 .41957 .42609 .61535 .43325 .42157 .43241 .41731 Mtetra
.683 .52 .658 r
.43241 .41731 .43325 .42157 .43496 .41702 .43405 .41547 Mtetra
.742 .677 .787 r
.43405 .41547 .43496 .41702 .43661 .41495 .43567 .41424 Mtetra
.68 .81 .945 r
.43567 .41424 .43661 .41495 .43821 .41424 .43727 .41363 Mtetra
.611 .818 .98 r
.43727 .41363 .43821 .41424 .43981 .4139 .43887 .41321 Mtetra
.597 .793 .974 r
.43887 .41321 .43981 .4139 .44141 .41366 .44047 .41285 Mtetra
.621 .769 .951 r
.44047 .41285 .44141 .41366 .44301 .41332 .44208 .41245 Mtetra
.63 .759 .94 r
.44208 .41245 .44301 .41332 .44461 .41296 .44368 .41203 Mtetra
.66 .753 .919 r
.44368 .41203 .44461 .41296 .44622 .41249 .44529 .41151 Mtetra
.694 .752 .896 r
.44529 .41151 .44622 .41249 .44783 .41183 .4469 .41083 Mtetra
.699 .75 .891 r
.4469 .41083 .44783 .41183 .44944 .41114 .44851 .41013 Mtetra
.691 .746 .894 r
.44851 .41013 .44944 .41114 .45105 .41048 .45013 .40947 Mtetra
.674 .739 .899 r
.45013 .40947 .45105 .41048 .45266 .40992 .45174 .40888 Mtetra
.668 .733 .898 r
.45174 .40888 .45266 .40992 .45428 .40938 .45335 .40832 Mtetra
.689 .735 .886 r
.45335 .40832 .45428 .40938 .45589 .40878 .45497 .40766 Mtetra
.714 .732 .865 r
.45497 .40766 .45589 .40878 .45751 .40807 .45659 .40685 Mtetra
.65 .692 .876 r
.45659 .40685 .45751 .40807 .45912 .40755 .4582 .40636 Mtetra
.317 .542 .911 r
.4582 .40636 .45912 .40755 .46073 .40755 .4598 .40684 Mtetra
.876 .438 .081 r
.4598 .40684 .46073 .40755 .46231 .40862 .46134 .41013 Mtetra
.956 .681 .477 r
.46134 .41013 .46231 .40862 .46388 .41062 .45922 .60474 Mtetra
.561 .338 .535 r
.45922 .60474 .46388 .41062 .46545 .41284 .4608 .61189 Mtetra
.548 .328 .534 r
.4608 .61189 .46545 .41284 .46709 .41187 .46252 .61176 Mtetra
.547 .327 .533 r
.46252 .61176 .46709 .41187 .46871 .41112 .46425 .6109 Mtetra
.548 .328 .534 r
.46425 .6109 .46871 .41112 .47028 .41414 .46597 .61068 Mtetra
.551 .33 .534 r
.46597 .61068 .47028 .41414 .46871 .60874 .46766 .61207 Mtetra
.603 .271 .381 r
.46766 .61207 .46871 .60874 .47036 .6131 .46937 .61306 Mtetra
.265 0 0 r
.46937 .61306 .47036 .6131 .47206 .61461 .47108 .61344 Mtetra
.62 .707 .907 r
.47108 .61344 .47206 .61461 .47378 .61437 .47281 .61305 Mtetra
.659 .695 .872 r
.47281 .61305 .47378 .61437 .47552 .61373 .47455 .61248 Mtetra
.66 .706 .881 r
.47455 .61248 .47552 .61373 .47726 .61304 .47628 .61191 Mtetra
.611 .711 .916 r
.47628 .61191 .47726 .61304 .47899 .61268 .47802 .61156 Mtetra
.61 .711 .917 r
.47802 .61156 .47899 .61268 .48072 .61232 .47975 .6112 Mtetra
.619 .716 .915 r
.47975 .6112 .48072 .61232 .48246 .61193 .48149 .61081 Mtetra
.64 .725 .91 r
.48149 .61081 .48246 .61193 .4842 .61144 .48322 .61034 Mtetra
.647 .73 .909 r
.48322 .61034 .4842 .61144 .48593 .61092 .48496 .60983 Mtetra
.65 .732 .909 r
.48496 .60983 .48593 .61092 .48768 .6104 .48671 .60931 Mtetra
.647 .733 .912 r
.48671 .60931 .48768 .6104 .48942 .60988 .48845 .6088 Mtetra
.652 .736 .911 r
.48845 .6088 .48942 .60988 .49116 .60934 .49019 .60827 Mtetra
.662 .741 .909 r
.49019 .60827 .49116 .60934 .4929 .60875 .49194 .60769 Mtetra
.68 .75 .904 r
.49194 .60769 .4929 .60875 .49465 .60804 .49368 .60703 Mtetra
.684 .76 .909 r
.49368 .60703 .49465 .60804 .4964 .60732 .49543 .60636 Mtetra
.679 .768 .918 r
.49543 .60636 .4964 .60732 .49815 .60663 .49718 .6057 Mtetra
.659 .771 .933 r
.49718 .6057 .49815 .60663 .4999 .60604 .49893 .60513 Mtetra
.651 .773 .938 r
.49893 .60513 .4999 .60604 .50164 .6055 .50068 .60459 Mtetra
.648 .773 .94 r
.50068 .60459 .50164 .6055 .50339 .60497 .50243 .60407 Mtetra
.65 .775 .94 r
.50243 .60407 .50339 .60497 .50515 .60443 .50418 .60353 Mtetra
.649 .775 .941 r
.50418 .60353 .50515 .60443 .5069 .60389 .50593 .603 Mtetra
.648 .776 .942 r
.50593 .603 .5069 .60389 .50865 .60336 .50769 .60247 Mtetra
.647 .776 .942 r
.50769 .60247 .50865 .60336 .51041 .60283 .50944 .60194 Mtetra
.646 .777 .943 r
.50944 .60194 .51041 .60283 .51216 .6023 .5112 .60142 Mtetra
.645 .777 .944 r
.5112 .60142 .51216 .6023 .51392 .60178 .51296 .60089 Mtetra
.644 .777 .944 r
.51296 .60089 .51392 .60178 .51568 .60126 .51472 .60037 Mtetra
.51472 .60037 .51568 .60126 .51744 .60075 .51648 .59986 Mtetra
.643 .776 .944 r
.51648 .59986 .51744 .60075 .5192 .60023 .51824 .59934 Mtetra
.51824 .59934 .5192 .60023 .52096 .59972 .52 .59883 Mtetra
.642 .776 .945 r
.52 .59883 .52096 .59972 .52272 .59921 .52176 .59831 Mtetra
.641 .775 .945 r
.52176 .59831 .52272 .59921 .52448 .5987 .52353 .59781 Mtetra
.64 .774 .944 r
.52353 .59781 .52448 .5987 .52625 .5982 .52529 .5973 Mtetra
.639 .773 .944 r
.52529 .5973 .52625 .5982 .52801 .5977 .52706 .5968 Mtetra
.638 .772 .944 r
.52706 .5968 .52801 .5977 .52978 .59721 .52883 .5963 Mtetra
.641 .772 .942 r
.52883 .5963 .52978 .59721 .53155 .5967 .53059 .59579 Mtetra
.636 .769 .944 r
.53059 .59579 .53155 .5967 .53332 .59622 .53236 .5953 Mtetra
.627 .765 .945 r
.53236 .5953 .53332 .59622 .53509 .59579 .53414 .59484 Mtetra
.602 .751 .949 r
.53414 .59484 .53509 .59579 .53686 .59547 .53591 .59448 Mtetra
.602 .741 .942 r
.53591 .59448 .53686 .59547 .53863 .59516 .53768 .59412 Mtetra
.611 .734 .933 r
.53768 .59412 .53863 .59516 .54041 .59482 .53946 .59374 Mtetra
.636 .735 .92 r
.53946 .59374 .54041 .59482 .54218 .59436 .54123 .59327 Mtetra
.643 .735 .916 r
.54123 .59327 .54218 .59436 .54396 .59387 .54301 .59277 Mtetra
.647 .735 .913 r
.54301 .59277 .54396 .59387 .54574 .59335 .54479 .59225 Mtetra
.646 .734 .913 r
.54479 .59225 .54574 .59335 .54752 .59284 .54657 .59173 Mtetra
.647 .733 .912 r
.54657 .59173 .54752 .59284 .5493 .59233 .54835 .59121 Mtetra
.648 .733 .911 r
.54835 .59121 .5493 .59233 .55108 .59181 .55013 .59069 Mtetra
.645 .731 .911 r
.55013 .59069 .55108 .59181 .55286 .59131 .55192 .59018 Mtetra
.65 .73 .908 r
.55192 .59018 .55286 .59131 .55464 .59079 .5537 .58965 Mtetra
.657 .731 .904 r
.5537 .58965 .55464 .59079 .55643 .59023 .55548 .58908 Mtetra
.649 .727 .906 r
.55548 .58908 .55643 .59023 .55822 .58984 .55727 .58855 Mtetra
.672 .71 .876 r
.55727 .58855 .55822 .58984 .56 .58922 .55906 .5879 Mtetra
.707 .717 .857 r
.55906 .5879 .56 .58922 .56178 .58815 .56084 .58703 Mtetra
.815 .774 .814 r
.56084 .58703 .56178 .58815 .56354 .58497 .56262 .58533 Mtetra
.869 .994 .762 r
.56262 .58533 .56354 .58497 .56526 .57831 .56439 .58316 Mtetra
.281 .021 .329 r
.56439 .58316 .56526 .57831 .5646 .38054 .56616 .58062 Mtetra
.546 .327 .533 r
.56616 .58062 .5646 .38054 .56626 .37799 .56794 .57948 Mtetra
.547 .328 .533 r
.56794 .57948 .56626 .37799 .56794 .37754 .56973 .57902 Mtetra
.548 .328 .534 r
.56973 .57902 .56794 .37754 .56964 .37802 .57153 .57886 Mtetra
.549 .329 .534 r
.57153 .57886 .56964 .37802 .57134 .3784 .57333 .57912 Mtetra
.548 .328 .533 r
.57333 .57912 .57134 .3784 .57303 .37824 .57513 .57882 Mtetra
.546 .327 .533 r
.57513 .57882 .57303 .37824 .57471 .37675 .57691 .57737 Mtetra
.515 .303 .53 r
.57691 .57737 .57471 .37675 .57634 .37269 .57842 .55865 Mtetra
0 0 .368 r
.57842 .55865 .57634 .37269 .57799 .36976 .57714 .37056 Mtetra
.956 .929 .59 r
.57714 .37056 .57799 .36976 .57965 .36769 .57878 .36674 Mtetra
.781 .79 .86 r
.57878 .36674 .57965 .36769 .58133 .36676 .58046 .36553 Mtetra
.656 .701 .879 r
.58046 .36553 .58133 .36676 .58302 .36622 .58215 .36499 Mtetra
.583 .672 .901 r
.58215 .36499 .58302 .36622 .58472 .36586 .58384 .36477 Mtetra
.615 .713 .915 r
.58384 .36477 .58472 .36586 .58641 .36547 .58554 .3644 Mtetra
.619 .719 .918 r
.58554 .3644 .58641 .36547 .58811 .36508 .58724 .36402 Mtetra
.627 .724 .917 r
.58724 .36402 .58811 .36508 .5898 .36465 .58893 .36361 Mtetra
.673 .746 .906 r
.58893 .36361 .5898 .36465 .5915 .36398 .59063 .363 Mtetra
.69 .763 .908 r
.59063 .363 .5915 .36398 .59319 .36324 .59232 .36232 Mtetra
.694 .778 .916 r
.59232 .36232 .59319 .36324 .59488 .36249 .59402 .36162 Mtetra
.707 .793 .918 r
.59402 .36162 .59488 .36249 .59657 .3616 .59571 .36086 Mtetra
.682 .819 .949 r
.59571 .36086 .59657 .3616 .59827 .3609 .59741 .36021 Mtetra
.612 .809 .976 r
.59741 .36021 .59827 .3609 .59997 .36061 .59911 .35977 Mtetra
.462 .705 .973 r
.59911 .35977 .59997 .36061 .60172 .36185 .60083 .35976 Mtetra
.433 .473 .801 r
.60083 .35976 .60172 .36185 .60353 .36568 .60256 .36035 Mtetra
.419 .324 .641 r
.60256 .36035 .60353 .36568 .61024 .56356 .60432 .36208 Mtetra
.018 0 .412 r
.60432 .36208 .61024 .56356 .61221 .56922 .61081 .54937 Mtetra
.029 0 .453 r
.61081 .54937 .61221 .56922 .61409 .57109 .61311 .56763 Mtetra
.078 .157 .645 r
.61311 .56763 .61409 .57109 .61595 .57187 .61502 .57059 Mtetra
.396 .588 .92 r
.61502 .57059 .61595 .57187 .61779 .57176 .61687 .57094 Mtetra
.633 .798 .962 r
.61687 .57094 .61779 .57176 .61961 .57124 .6187 .57043 Mtetra
.717 .823 .931 r
.6187 .57043 .61961 .57124 .62143 .57052 .62052 .56957 Mtetra
.639 .768 .941 r
.62052 .56957 .62143 .57052 .62327 .57021 .62235 .56905 Mtetra
.636 .725 .913 r
.62235 .56905 .62327 .57021 .6251 .56983 .62418 .56857 Mtetra
.679 .722 .882 r
.62418 .56857 .6251 .56983 .62692 .56903 .62601 .56787 Mtetra
.752 .763 .861 r
.62601 .56787 .62692 .56903 .6287 .56667 .62782 .56673 Mtetra
.835 .996 .842 r
.62782 .56673 .6287 .56667 .63039 .56179 .62961 .56499 Mtetra
.056 0 .173 r
.62961 .56499 .63039 .56179 .62595 .3635 .63138 .56214 Mtetra
.529 .314 .532 r
.63138 .56214 .62595 .3635 .62744 .35553 .63287 .55092 Mtetra
0 0 .39 r
.63287 .55092 .62744 .35553 .62908 .35261 .62831 .35415 Mtetra
.786 .839 .377 r
.62831 .35415 .62908 .35261 .63076 .35082 .62991 .35012 Mtetra
.822 .854 .871 r
.62991 .35012 .63076 .35082 .63247 .34993 .63161 .34871 Mtetra
.64 .7 .89 r
.63161 .34871 .63247 .34993 .63419 .34951 .63333 .34824 Mtetra
.557 .656 .901 r
.63333 .34824 .63419 .34951 .63592 .34928 .63507 .34812 Mtetra
.616 .702 .906 r
.63507 .34812 .63592 .34928 .63765 .34885 .6368 .34775 Mtetra
.659 .732 .904 r
.6368 .34775 .63765 .34885 .63938 .34826 .63853 .34719 Mtetra
.67 .742 .905 r
.63853 .34719 .63938 .34826 .6411 .34762 .64025 .34659 Mtetra
.71 .764 .894 r
.64025 .34659 .6411 .34762 .64281 .34666 .64197 .34579 Mtetra
.716 .801 .918 r
.64197 .34579 .64281 .34666 .64452 .34573 .64369 .34498 Mtetra
.668 .816 .954 r
.64369 .34498 .64452 .34573 .64625 .3452 .64541 .34436 Mtetra
.413 .685 .974 r
.64541 .34436 .64625 .3452 .64804 .34619 .64717 .34446 Mtetra
.354 .469 .838 r
.64717 .34446 .64804 .34619 .64994 .34977 .64895 .34519 Mtetra
.458 .367 .665 r
.64895 .34519 .64994 .34977 .65956 .54647 .65075 .34634 Mtetra
.549 .334 .54 r
.65075 .34634 .65956 .54647 .66161 .55092 .65251 .34619 Mtetra
.551 .335 .54 r
.65251 .34619 .66161 .55092 .66345 .55014 .65423 .34521 Mtetra
.55 .334 .54 r
.65423 .34521 .66345 .55014 .66527 .54905 .65597 .34486 Mtetra
.54 .326 .539 r
.65597 .34486 .66527 .54905 .66724 .5513 .65795 .35001 Mtetra
.004 0 .414 r
.65795 .35001 .66724 .5513 .66923 .55375 .6682 .54947 Mtetra
.02 .087 .592 r
.6682 .54947 .66923 .55375 .67117 .55513 .67025 .55362 Mtetra
.239 .451 .865 r
.67025 .55362 .67117 .55513 .67307 .55554 .67218 .55454 Mtetra
.597 .747 .949 r
.67218 .55454 .67307 .55554 .67494 .55523 .67405 .55418 Mtetra
.726 .78 .896 r
.67405 .55418 .67494 .55523 .67679 .55432 .6759 .55324 Mtetra
.773 .786 .864 r
.6759 .55324 .67679 .55432 .67858 .55209 .67773 .55198 Mtetra
.852 .982 .86 r
.67773 .55198 .67858 .55209 .68025 .54734 .67954 .55023 Mtetra
.015 0 .142 r
.67954 .55023 .68025 .54734 .67286 .34847 .6813 .54738 Mtetra
.532 .316 .532 r
.6813 .54738 .67286 .34847 .67423 .33982 .68273 .5376 Mtetra
.003 0 .408 r
.68273 .5376 .67423 .33982 .67586 .33683 .67517 .33874 Mtetra
0 0 0 r
.67517 .33874 .67586 .33683 .67755 .33495 .67674 .33447 Mtetra
.883 .904 .839 r
.67674 .33447 .67755 .33495 .67926 .33367 .67843 .33263 Mtetra
.702 .762 .899 r
.67843 .33263 .67926 .33367 .681 .33285 .68017 .33186 Mtetra
.581 .727 .943 r
.68017 .33186 .681 .33285 .68276 .33253 .68193 .33158 Mtetra
.482 .691 .96 r
.68193 .33158 .68276 .33253 .68458 .33325 .68371 .33158 Mtetra
.461 .54 .852 r
.68371 .33158 .68458 .33325 .68649 .33583 .68552 .33192 Mtetra
.441 .375 .687 r
.68552 .33192 .68649 .33583 .68911 .35188 .68736 .33306 Mtetra
.457 .288 .562 r
.68736 .33306 .68911 .35188 .7008 .54113 .68939 .33768 Mtetra
.026 0 .426 r
.68939 .33768 .7008 .54113 .70284 .54369 .70173 .5382 Mtetra
.118 .124 .589 r
.70173 .5382 .70284 .54369 .70481 .54475 .70389 .54289 Mtetra
.153 .342 .799 r
.70389 .54289 .70481 .54475 .70675 .5453 .70588 .54435 Mtetra
.434 .682 .968 r
.70588 .54435 .70675 .5453 .70867 .54537 .7078 .54444 Mtetra
.716 .804 .92 r
.7078 .54444 .70867 .54537 .71054 .54464 .70967 .54356 Mtetra
.909 .796 .724 r
.70967 .54356 .71054 .54464 .71229 .54159 .71141 .54035 Mtetra
.977 .707 .452 r
.71141 .54035 .71229 .54159 .71318 .5233 .71183 .51366 Mtetra
.968 .675 .417 r
.71183 .51366 .71318 .5233 .70399 .32812 .70317 .32695 Mtetra
.887 .777 .734 r
.70317 .32695 .70399 .32812 .70563 .3253 .70481 .32418 Mtetra
.675 .739 .898 r
.70481 .32418 .70563 .3253 .70739 .32465 .70657 .32353 Mtetra
.536 .678 .93 r
.70657 .32353 .70739 .32465 .70919 .32456 .70837 .32343 Mtetra
.559 .688 .926 r
.70837 .32343 .70919 .32456 .71098 .32438 .71016 .32326 Mtetra
.654 .73 .905 r
.71016 .32326 .71098 .32438 .71275 .32381 .71193 .32271 Mtetra
.665 .739 .905 r
.71193 .32271 .71275 .32381 .71452 .32318 .7137 .32211 Mtetra
.73 .768 .883 r
.7137 .32211 .71452 .32318 .71627 .32221 .71545 .32117 Mtetra
.758 .784 .875 r
.71545 .32117 .71627 .32221 .71801 .32107 .7172 .32009 Mtetra
.657 .762 .927 r
.7172 .32009 .71801 .32107 .71978 .32047 .71897 .31952 Mtetra
0 .256 .75 r
.71897 .31952 .71978 .32047 .72167 .32174 .72087 .32086 Mtetra
.955 .608 .254 r
.72087 .32086 .72167 .32174 .72423 .33353 .72356 .33477 Mtetra
.974 .672 .376 r
.72356 .33477 .72423 .33353 .73878 .53319 .73792 .53225 Mtetra
0 0 .5 r
.73792 .53225 .73878 .53319 .74086 .53547 .74 .53446 Mtetra
.613 .753 .945 r
.74 .53446 .74086 .53547 .74278 .53505 .74192 .53402 Mtetra
.744 .796 .894 r
.74192 .53402 .74278 .53505 .74466 .53401 .7438 .53297 Mtetra
.717 .786 .906 r
.7438 .53297 .74466 .53401 .74655 .53322 .74568 .53206 Mtetra
.591 .716 .93 r
.74568 .53206 .74655 .53322 .74849 .53306 .74761 .53174 Mtetra
.632 .7 .895 r
.74761 .53174 .74849 .53306 .7504 .53257 .74953 .53126 Mtetra
.705 .732 .872 r
.74953 .53126 .7504 .53257 .75225 .531 .75142 .53038 Mtetra
.831 .899 .888 r
.75142 .53038 .75225 .531 .75393 .5271 .75327 .52884 Mtetra
0 0 0 r
.75327 .52884 .75393 .5271 .75496 .51373 .75505 .5264 Mtetra
.35 .145 .454 r
.75505 .5264 .75496 .51373 .7433 .31812 .7566 .52047 Mtetra
.044 0 .431 r
.7566 .52047 .7433 .31812 .74489 .31455 .74438 .31771 Mtetra
0 0 .039 r
.74438 .31771 .74489 .31455 .74657 .31246 .74583 .31229 Mtetra
.921 .959 .789 r
.74583 .31229 .74657 .31246 .74832 .31122 .74751 .31005 Mtetra
.679 .733 .891 r
.74751 .31005 .74832 .31122 .75011 .31066 .7493 .30937 Mtetra
.59 .673 .898 r
.7493 .30937 .75011 .31066 .75193 .31032 .75112 .30911 Mtetra
.606 .695 .906 r
.75112 .30911 .75193 .31032 .75373 .30979 .75293 .30876 Mtetra
.706 .773 .904 r
.75293 .30876 .75373 .30979 .75549 .30883 .75471 .30796 Mtetra
.679 .801 .94 r
.75471 .30796 .75549 .30883 .75729 .30815 .7565 .30729 Mtetra
.545 .748 .971 r
.7565 .30729 .75729 .30815 .75915 .30841 .75833 .30706 Mtetra
.333 .523 .892 r
.75833 .30706 .75915 .30841 .76119 .31103 .76022 .30767 Mtetra
.431 .391 .713 r
.76022 .30767 .76119 .31103 .76411 .32512 .76215 .30876 Mtetra
.538 .35 .574 r
.76215 .30876 .76411 .32512 .78059 .51604 .76406 .3095 Mtetra
.551 .335 .54 r
.76406 .3095 .78059 .51604 .78254 .5158 .76583 .30851 Mtetra
.55 .334 .54 r
.76583 .30851 .78254 .5158 .78444 .51478 .76764 .30788 Mtetra
.546 .331 .54 r
.76764 .30788 .78444 .51478 .78646 .51533 .76964 .30978 Mtetra
.07 0 .45 r
.76964 .30978 .78646 .51533 .78864 .51795 .78738 .51142 Mtetra
.11 .107 .573 r
.78738 .51142 .78864 .51795 .79075 .51955 .78983 .51742 Mtetra
.145 .305 .768 r
.78983 .51742 .79075 .51955 .79279 .52023 .79196 .51923 Mtetra
.524 .721 .963 r
.79196 .51923 .79279 .52023 .79476 .51999 .79394 .51908 Mtetra
.651 .799 .954 r
.79394 .51908 .79476 .51999 .79671 .51948 .79588 .51847 Mtetra
.687 .786 .926 r
.79588 .51847 .79671 .51948 .79865 .51888 .79781 .51771 Mtetra
.649 .739 .915 r
.79781 .51771 .79865 .51888 .8006 .51832 .79975 .51713 Mtetra
.66 .74 .909 r
.79975 .51713 .8006 .51832 .80254 .51771 .8017 .5165 Mtetra
.672 .741 .902 r
.8017 .5165 .80254 .51771 .80448 .51704 .80364 .5158 Mtetra
.686 .743 .894 r
.80364 .5158 .80448 .51704 .80642 .51629 .80557 .51504 Mtetra
.688 .741 .892 r
.80557 .51504 .80642 .51629 .80835 .51552 .8075 .51425 Mtetra
.682 .736 .892 r
.8075 .51425 .80835 .51552 .81029 .51479 .80944 .51351 Mtetra
.663 .726 .896 r
.80944 .51351 .81029 .51479 .81224 .51416 .81139 .51286 Mtetra
.654 .719 .896 r
.81139 .51286 .81224 .51416 .81419 .51357 .81334 .51225 Mtetra
.646 .712 .896 r
.81334 .51225 .81419 .51357 .81615 .51302 .8153 .51169 Mtetra
.64 .707 .896 r
.8153 .51169 .81615 .51302 .81811 .51249 .81726 .51116 Mtetra
.636 .705 .896 r
.81726 .51116 .81811 .51249 .82007 .51197 .81922 .51064 Mtetra
.611 .694 .903 r
.81922 .51064 .82007 .51197 .82205 .51157 .8212 .51025 Mtetra
.525 .655 .917 r
.8212 .51025 .82205 .51157 .82405 .5115 .82321 .51021 Mtetra
.632 .712 .904 r
.82321 .51021 .82405 .5115 .82602 .51099 .82518 .50971 Mtetra
.805 .777 .826 r
.82518 .50971 .82602 .51099 .82789 .50935 .82705 .50805 Mtetra
.965 .764 .583 r
.82705 .50805 .82789 .50935 .82932 .50294 .82846 .50139 Mtetra
.977 .674 .343 r
.82846 .50139 .82932 .50294 .81224 .29575 .81144 .29432 Mtetra
.944 .757 .619 r
.81144 .29432 .81224 .29575 .81363 .29031 .81285 .28911 Mtetra
.753 .76 .859 r
.81285 .28911 .81363 .29031 .81541 .28916 .81464 .28798 Mtetra
.626 .714 .91 r
.81464 .28798 .81541 .28916 .81726 .28871 .81649 .28754 Mtetra
.58 .695 .921 r
.81649 .28754 .81726 .28871 .81913 .28845 .81836 .28728 Mtetra
.75 .766 .866 r
.81836 .28728 .81913 .28845 .82092 .28734 .82015 .28618 Mtetra
.677 .741 .899 r
.82015 .28618 .82092 .28734 .82275 .28665 .82198 .2855 Mtetra
.398 .602 .929 r
.82198 .2855 .82275 .28665 .82468 .28698 .82391 .28582 Mtetra
.815 .408 0 r
.82391 .28582 .82468 .28698 .82715 .29285 .82638 .29165 Mtetra
.973 .661 .312 r
.82638 .29165 .82715 .29285 .84912 .49832 .84831 .49721 Mtetra
.693 .254 0 r
.84831 .49721 .84912 .49832 .85156 .50241 .85075 .50132 Mtetra
.34 .6 .943 r
.85075 .50132 .85156 .50241 .85364 .50282 .85283 .50174 Mtetra
.668 .77 .926 r
.85283 .50174 .85364 .50282 .85561 .50214 .8548 .50106 Mtetra
.848 .821 .821 r
.8548 .50106 .85561 .50214 .85746 .50019 .85665 .49911 Mtetra
.977 .78 .572 r
.85665 .49911 .85746 .50019 .85883 .49356 .85803 .49247 Mtetra
.976 .67 .326 r
.85803 .49247 .85883 .49356 .83988 .28636 .83912 .28522 Mtetra
.965 .78 .603 r
.83912 .28522 .83988 .28636 .84125 .28095 .84048 .27981 Mtetra
.762 .778 .866 r
.84048 .27981 .84125 .28095 .84304 .27978 .84228 .27865 Mtetra
.632 .728 .917 r
.84228 .27865 .84304 .27978 .84491 .27931 .84415 .27817 Mtetra
.556 .692 .931 r
.84415 .27817 .84491 .27931 .84681 .27912 .84605 .27799 Mtetra
.753 .776 .872 r
.84605 .27799 .84681 .27912 .84861 .27802 .84785 .27688 Mtetra
.685 .752 .902 r
.84785 .27688 .84861 .27802 .85045 .27729 .8497 .27616 Mtetra
.482 .655 .936 r
.8497 .27616 .85045 .27729 .85238 .27735 .85163 .27623 Mtetra
.739 .319 0 r
.85163 .27623 .85238 .27735 .85481 .28208 .85406 .28099 Mtetra
.971 .656 .295 r
.85406 .28099 .85481 .28208 .87878 .48829 .87799 .48727 Mtetra
.76 .326 0 r
.87799 .48727 .87878 .48829 .88137 .49327 .88058 .49221 Mtetra
.41 .648 .955 r
.88058 .49221 .88137 .49327 .88346 .4935 .88267 .49242 Mtetra
.642 .763 .936 r
.88267 .49242 .88346 .4935 .88547 .49295 .88468 .49185 Mtetra
.728 .793 .903 r
.88468 .49185 .88547 .49295 .88743 .49196 .88664 .49085 Mtetra
.505 .529 .815 r
.2444 .67781 .24538 .67977 .24694 .67968 .24594 .67801 Mtetra
.579 .6 .838 r
.24594 .67801 .24694 .67968 .24854 .67917 .24751 .67786 Mtetra
.713 .698 .834 r
.24751 .67786 .24854 .67917 .25019 .67789 .24913 .67699 Mtetra
.904 .737 .664 r
.24913 .67699 .25019 .67789 .25224 .67158 .2511 .67179 Mtetra
.938 .688 .533 r
.2511 .67179 .25224 .67158 .2691 .47432 .26795 .4755 Mtetra
.986 .842 .614 r
.26795 .4755 .2691 .47432 .27096 .46923 .2699 .46926 Mtetra
.826 .963 .897 r
.2699 .46926 .27096 .46923 .27251 .46825 .27147 .46796 Mtetra
.623 .892 .988 r
.27147 .46796 .27251 .46825 .27399 .46802 .27298 .46743 Mtetra
.501 .776 .994 r
.27298 .46743 .27399 .46802 .27545 .46818 .27446 .46727 Mtetra
.652 .741 .915 r
.27446 .46727 .27545 .46818 .27695 .46781 .27597 .46681 Mtetra
.65 .724 .902 r
.27597 .46681 .27695 .46781 .27846 .46733 .27748 .46636 Mtetra
.649 .728 .907 r
.27748 .46636 .27846 .46733 .27998 .4668 .27898 .46591 Mtetra
.75 .766 .866 r
.27898 .46591 .27998 .4668 .28153 .46568 .28053 .46496 Mtetra
.705 .799 .923 r
.28053 .46496 .28153 .46568 .28307 .46487 .28206 .46429 Mtetra
.422 .747 .994 r
.28206 .46429 .28307 .46487 .28456 .46474 .28354 .46424 Mtetra
.905 .516 .269 r
.28354 .46424 .28456 .46474 .28575 .46868 .28475 .46782 Mtetra
.94 .683 .521 r
.28475 .46782 .28575 .46868 .27301 .66564 .27207 .66318 Mtetra
.943 .606 .184 r
.27207 .66318 .27301 .66564 .27419 .67106 .2732 .66919 Mtetra
.369 .465 .828 r
.2732 .66919 .27419 .67106 .27574 .67137 .27473 .66982 Mtetra
.62 .635 .843 r
.27473 .66982 .27574 .67137 .27737 .67067 .27634 .66947 Mtetra
.703 .713 .857 r
.27634 .66947 .27737 .67067 .27902 .66955 .27797 .6687 Mtetra
.658 .77 .932 r
.27797 .6687 .27902 .66955 .28063 .6692 .27958 .66818 Mtetra
.658 .734 .905 r
.27958 .66818 .28063 .6692 .28223 .66891 .2812 .66766 Mtetra
.661 .695 .871 r
.2812 .66766 .28223 .66891 .28384 .66839 .28282 .66712 Mtetra
.548 .648 .9 r
.28282 .66712 .28384 .66839 .2855 .66731 .28441 .66703 Mtetra
.472 .848 .987 r
.28441 .66703 .2855 .66731 .2872 .66557 .28601 .66671 Mtetra
0 0 0 r
.28601 .66671 .2872 .66557 .28899 .66255 .28767 .66572 Mtetra
.655 .757 .274 r
.28767 .66572 .28899 .66255 .30309 .47643 .28956 .66117 Mtetra
0 0 .18 r
.28956 .66117 .30309 .47643 .30564 .46072 .30433 .46467 Mtetra
.873 .832 .361 r
.30433 .46467 .30564 .46072 .30736 .45725 .30631 .45743 Mtetra
.854 .98 .861 r
.30631 .45743 .30736 .45725 .30893 .45605 .30791 .45589 Mtetra
.535 .892 .976 r
.30791 .45589 .30893 .45605 .31046 .45558 .30943 .45543 Mtetra
.201 .718 .879 r
.30943 .45543 .31046 .45558 .31197 .45541 .31093 .45535 Mtetra
.54 .909 .957 r
.31093 .45535 .31197 .45541 .31348 .45512 .31247 .45481 Mtetra
.684 .9 .974 r
.31247 .45481 .31348 .45512 .315 .45479 .31401 .45413 Mtetra
.701 .813 .935 r
.31401 .45413 .315 .45479 .31653 .45446 .31555 .45346 Mtetra
.671 .733 .897 r
.31555 .45346 .31653 .45446 .31805 .45403 .31709 .45292 Mtetra
.656 .705 .883 r
.31709 .45292 .31805 .45403 .31959 .45354 .31862 .45243 Mtetra
.652 .705 .886 r
.31862 .45243 .31959 .45354 .32112 .453 .32016 .45196 Mtetra
.66 .722 .895 r
.32016 .45196 .32112 .453 .32267 .45237 .32169 .45146 Mtetra
.665 .749 .913 r
.32169 .45146 .32267 .45237 .32421 .45171 .32323 .45094 Mtetra
.664 .782 .936 r
.32323 .45094 .32421 .45171 .32576 .45106 .32477 .45042 Mtetra
.66 .814 .957 r
.32477 .45042 .32576 .45106 .3273 .45048 .32631 .4499 Mtetra
.655 .829 .966 r
.32631 .4499 .3273 .45048 .32884 .44993 .32785 .44937 Mtetra
.653 .833 .969 r
.32785 .44937 .32884 .44993 .33038 .44941 .32939 .44885 Mtetra
.65 .833 .97 r
.32939 .44885 .33038 .44941 .33193 .44878 .33093 .44833 Mtetra
.634 .861 .985 r
.33093 .44833 .33193 .44878 .33348 .44819 .33248 .44782 Mtetra
.619 .877 .99 r
.33248 .44782 .33348 .44819 .33502 .44779 .33402 .44731 Mtetra
.636 .853 .982 r
.33402 .44731 .33502 .44779 .33651 .44808 .33556 .44681 Mtetra
.657 .68 .86 r
.33556 .44681 .33651 .44808 .33798 .44895 .33711 .4463 Mtetra
.625 .534 .731 r
.33711 .4463 .33798 .44895 .33942 .45025 .33865 .44578 Mtetra
.603 .461 .661 r
.33865 .44578 .33942 .45025 .34092 .45066 .3402 .44524 Mtetra
.595 .44 .641 r
.3402 .44524 .34092 .45066 .34247 .45013 .34175 .44468 Mtetra
.595 .439 .641 r
.34175 .44468 .34247 .45013 .34404 .44926 .34331 .44412 Mtetra
.615 .458 .646 r
.34331 .44412 .34404 .44926 .34563 .44806 .34487 .44328 Mtetra
.612 .461 .653 r
.34487 .44328 .34563 .44806 .3472 .44718 .34644 .44255 Mtetra
.574 .438 .658 r
.34644 .44255 .3472 .44718 .34872 .44723 .34797 .44237 Mtetra
.292 .236 .621 r
.34797 .44237 .34872 .44723 .34989 .45397 .34937 .44468 Mtetra
.959 .697 .495 r
.34937 .44468 .34989 .45397 .34121 .64678 .34061 .63784 Mtetra
0 0 .268 r
.34061 .63784 .34121 .64678 .34264 .65051 .34169 .64811 Mtetra
.232 .324 .753 r
.34169 .64811 .34264 .65051 .34422 .65132 .34324 .64942 Mtetra
.62 .596 .805 r
.34324 .64942 .34422 .65132 .34586 .65105 .34489 .64903 Mtetra
.681 .615 .775 r
.34489 .64903 .34586 .65105 .34752 .65041 .34657 .64817 Mtetra
.636 .575 .769 r
.34657 .64817 .34752 .65041 .34918 .64984 .34822 .64763 Mtetra
.599 .558 .78 r
.34822 .64763 .34918 .64984 .35084 .64929 .34987 .64735 Mtetra
.605 .586 .805 r
.34987 .64735 .35084 .64929 .35251 .64853 .35151 .64706 Mtetra
.632 .653 .853 r
.35151 .64706 .35251 .64853 .35421 .64718 .35317 .64664 Mtetra
.631 .843 .981 r
.35317 .64664 .35421 .64718 .35594 .64524 .35483 .64612 Mtetra
.099 0 0 r
.35483 .64612 .35594 .64524 .35769 .6429 .35649 .64557 Mtetra
.471 .122 .292 r
.35649 .64557 .35769 .6429 .35938 .64181 .35814 .64537 Mtetra
.492 .172 .352 r
.35814 .64537 .35938 .64181 .36102 .64171 .35979 .64515 Mtetra
.417 .098 .315 r
.35979 .64515 .36102 .64171 .36269 .64101 .36146 .64439 Mtetra
0 0 .064 r
.36146 .64439 .36269 .64101 .3646 .63518 .36325 .64131 Mtetra
.982 .81 .407 r
.36325 .64131 .3646 .63518 .3752 .43966 .36568 .62427 Mtetra
0 0 .257 r
.36568 .62427 .3752 .43966 .37697 .43483 .37594 .43545 Mtetra
.939 .965 .72 r
.37594 .43545 .37697 .43483 .37859 .4331 .37761 .43277 Mtetra
.74 .908 .951 r
.37761 .43277 .37859 .4331 .38016 .4326 .3792 .43189 Mtetra
.615 .789 .965 r
.3792 .43189 .38016 .4326 .38171 .43247 .38076 .4315 Mtetra
.63 .731 .92 r
.38076 .4315 .38171 .43247 .38327 .43222 .38233 .43111 Mtetra
.656 .711 .888 r
.38233 .43111 .38327 .43222 .38485 .43173 .3839 .43061 Mtetra
.648 .706 .89 r
.3839 .43061 .38485 .43173 .38642 .4312 .38547 .43015 Mtetra
.653 .722 .899 r
.38547 .43015 .38642 .4312 .388 .4305 .38705 .42967 Mtetra
.66 .771 .931 r
.38705 .42967 .388 .4305 .38958 .42974 .38862 .42915 Mtetra
.651 .83 .969 r
.38862 .42915 .38958 .42974 .39116 .42915 .3902 .42862 Mtetra
.649 .846 .976 r
.3902 .42862 .39116 .42915 .39272 .42917 .39178 .42808 Mtetra
.667 .72 .889 r
.39178 .42808 .39272 .42917 .39425 .42989 .39335 .42754 Mtetra
.634 .558 .751 r
.39335 .42754 .39425 .42989 .39576 .43107 .39493 .42699 Mtetra
.625 .485 .671 r
.39493 .42699 .39576 .43107 .39731 .43132 .39653 .4262 Mtetra
.614 .458 .647 r
.39653 .4262 .39731 .43132 .39891 .43037 .39812 .42537 Mtetra
.584 .439 .65 r
.39812 .42537 .39891 .43037 .40049 .42994 .39969 .42502 Mtetra
.411 .32 .642 r
.39969 .42502 .40049 .42994 .40192 .43354 .4012 .42655 Mtetra
.804 .588 .026 r
.4012 .42655 .40192 .43354 .39619 .62903 .40229 .43922 Mtetra
0 0 .291 r
.40229 .43922 .39619 .62903 .39769 .63365 .39675 .63093 Mtetra
.04 .17 .673 r
.39675 .63093 .39769 .63365 .39931 .63484 .39833 .63306 Mtetra
.594 .599 .827 r
.39833 .63306 .39931 .63484 .40099 .63452 .40001 .63282 Mtetra
.687 .65 .807 r
.40001 .63282 .40099 .63452 .40269 .63379 .40171 .632 Mtetra
.68 .637 .8 r
.40171 .632 .40269 .63379 .40438 .63309 .40341 .63121 Mtetra
.636 .609 .806 r
.40341 .63121 .40438 .63309 .40607 .63259 .4051 .63071 Mtetra
.638 .61 .805 r
.4051 .63071 .40607 .63259 .40776 .63209 .40679 .63021 Mtetra
.598 .591 .815 r
.40679 .63021 .40776 .63209 .40945 .63176 .40848 .62995 Mtetra
.576 .588 .828 r
.40848 .62995 .40945 .63176 .41114 .63152 .41016 .62981 Mtetra
.67 .642 .814 r
.41016 .62981 .41114 .63152 .41283 .63089 .41186 .62912 Mtetra
.822 .69 .718 r
.41186 .62912 .41283 .63089 .41458 .62894 .41363 .62639 Mtetra
.923 .685 .56 r
.41363 .62639 .41458 .62894 .41642 .62375 .41586 .60892 Mtetra
.936 .671 .51 r
.41586 .60892 .41642 .62375 .42419 .42727 .42346 .41952 Mtetra
.668 .472 .611 r
.42346 .41952 .42419 .42727 .42595 .4215 .42513 .41657 Mtetra
.612 .46 .651 r
.42513 .41657 .42595 .4215 .42755 .42079 .42674 .4158 Mtetra
.578 .435 .651 r
.42674 .4158 .42755 .42079 .42914 .42066 .42833 .41554 Mtetra
.575 .431 .649 r
.42833 .41554 .42914 .42066 .43076 .41957 .42992 .41532 Mtetra
.602 .466 .669 r
.42992 .41532 .43076 .41957 .43241 .41731 .43152 .41481 Mtetra
.626 .545 .743 r
.43152 .41481 .43241 .41731 .43405 .41547 .43312 .4143 Mtetra
.655 .703 .882 r
.43312 .4143 .43405 .41547 .43567 .41424 .43472 .41379 Mtetra
.619 .863 .989 r
.43472 .41379 .43567 .41424 .43727 .41363 .43632 .41329 Mtetra
.6 .884 .991 r
.43632 .41329 .43727 .41363 .43887 .41321 .43793 .41277 Mtetra
.635 .871 .986 r
.43793 .41277 .43887 .41321 .44047 .41285 .43954 .41222 Mtetra
.671 .83 .96 r
.43954 .41222 .44047 .41285 .44208 .41245 .44114 .41163 Mtetra
.672 .781 .932 r
.44114 .41163 .44208 .41245 .44368 .41203 .44275 .41106 Mtetra
.651 .74 .915 r
.44275 .41106 .44368 .41203 .44529 .41151 .44436 .41057 Mtetra
.613 .737 .934 r
.44436 .41057 .44529 .41151 .4469 .41083 .44596 .41022 Mtetra
.577 .807 .987 r
.44596 .41022 .4469 .41083 .44851 .41013 .44757 .40988 Mtetra
.515 .874 .984 r
.44757 .40988 .44851 .41013 .45013 .40947 .44918 .40946 Mtetra
.491 .898 .92 r
.44918 .40946 .45013 .40947 .45174 .40888 .45079 .40888 Mtetra
.506 .906 .918 r
.45079 .40888 .45174 .40888 .45335 .40832 .45241 .40827 Mtetra
.618 .945 .943 r
.45241 .40827 .45335 .40832 .45497 .40766 .45403 .40752 Mtetra
.719 .954 .949 r
.45403 .40752 .45497 .40766 .45659 .40685 .45565 .40659 Mtetra
.533 .881 .985 r
.45565 .40659 .45659 .40685 .4582 .40636 .45727 .40614 Mtetra
.553 0 0 r
.45727 .40614 .4582 .40636 .4598 .40684 .45885 .40715 Mtetra
.928 .602 .401 r
.45885 .40715 .4598 .40684 .46134 .41013 .46027 .4168 Mtetra
.948 .674 .484 r
.46027 .4168 .46134 .41013 .45922 .60474 .45807 .61254 Mtetra
.64 .36 .479 r
.45807 .61254 .45922 .60474 .4608 .61189 .45973 .61532 Mtetra
.502 .177 .349 r
.45973 .61532 .4608 .61189 .46252 .61176 .46145 .61522 Mtetra
.429 .11 .322 r
.46145 .61522 .46252 .61176 .46425 .6109 .46318 .61451 Mtetra
.415 .102 .323 r
.46318 .61451 .46425 .6109 .46597 .61068 .46492 .61364 Mtetra
.436 .1 .295 r
.46492 .61364 .46597 .61068 .46766 .61207 .46665 .61313 Mtetra
.198 0 0 r
.46665 .61313 .46766 .61207 .46937 .61306 .46838 .6126 Mtetra
.6 .866 .993 r
.46838 .6126 .46937 .61306 .47108 .61344 .47011 .61209 Mtetra
.643 .683 .872 r
.47011 .61209 .47108 .61344 .47281 .61305 .47184 .6116 Mtetra
.647 .669 .857 r
.47184 .6116 .47281 .61305 .47455 .61248 .47358 .61108 Mtetra
.66 .682 .86 r
.47358 .61108 .47455 .61248 .47628 .61191 .47531 .6105 Mtetra
.682 .688 .85 r
.47531 .6105 .47628 .61191 .47802 .61156 .47705 .60978 Mtetra
.672 .639 .809 r
.47705 .60978 .47802 .61156 .47975 .6112 .47879 .60904 Mtetra
.653 .595 .777 r
.47879 .60904 .47975 .6112 .48149 .61081 .48053 .60836 Mtetra
.627 .561 .76 r
.48053 .60836 .48149 .61081 .48322 .61034 .48227 .60784 Mtetra
.621 .555 .758 r
.48227 .60784 .48322 .61034 .48496 .60983 .48401 .60737 Mtetra
.621 .557 .76 r
.48401 .60737 .48496 .60983 .48671 .60931 .48575 .60689 Mtetra
.627 .563 .763 r
.48575 .60689 .48671 .60931 .48845 .6088 .48749 .60638 Mtetra
.628 .563 .762 r
.48749 .60638 .48845 .6088 .49019 .60827 .48923 .60586 Mtetra
.629 .564 .763 r
.48923 .60586 .49019 .60827 .49194 .60769 .49098 .60532 Mtetra
.631 .569 .766 r
.49098 .60532 .49194 .60769 .49368 .60703 .49272 .60478 Mtetra
.634 .579 .775 r
.49272 .60478 .49368 .60703 .49543 .60636 .49447 .60424 Mtetra
.637 .591 .786 r
.49447 .60424 .49543 .60636 .49718 .6057 .49622 .60369 Mtetra
.639 .602 .796 r
.49622 .60369 .49718 .6057 .49893 .60513 .49797 .60315 Mtetra
.639 .604 .798 r
.49797 .60315 .49893 .60513 .50068 .60459 .49972 .6026 Mtetra
.49972 .6026 .50068 .60459 .50243 .60407 .50147 .60206 Mtetra
.638 .602 .797 r
.50147 .60206 .50243 .60407 .50418 .60353 .50322 .60153 Mtetra
.638 .602 .798 r
.50322 .60153 .50418 .60353 .50593 .603 .50498 .601 Mtetra
.637 .602 .798 r
.50498 .601 .50593 .603 .50769 .60247 .50673 .60047 Mtetra
.50673 .60047 .50769 .60247 .50944 .60194 .50849 .59994 Mtetra
.636 .602 .798 r
.50849 .59994 .50944 .60194 .5112 .60142 .51024 .59942 Mtetra
.51024 .59942 .5112 .60142 .51296 .60089 .512 .59889 Mtetra
.512 .59889 .51296 .60089 .51472 .60037 .51376 .59837 Mtetra
.51376 .59837 .51472 .60037 .51648 .59986 .51552 .59785 Mtetra
.635 .601 .798 r
.51552 .59785 .51648 .59986 .51824 .59934 .51728 .59734 Mtetra
.635 .601 .799 r
.51728 .59734 .51824 .59934 .52 .59883 .51904 .59682 Mtetra
.51904 .59682 .52 .59883 .52176 .59831 .5208 .59631 Mtetra
.634 .601 .799 r
.5208 .59631 .52176 .59831 .52353 .59781 .52257 .5958 Mtetra
.52257 .5958 .52353 .59781 .52529 .5973 .52433 .59529 Mtetra
.633 .6 .799 r
.52433 .59529 .52529 .5973 .52706 .5968 .5261 .59479 Mtetra
.5261 .59479 .52706 .5968 .52883 .5963 .52787 .59429 Mtetra
.632 .6 .799 r
.52787 .59429 .52883 .5963 .53059 .59579 .52964 .59379 Mtetra
.632 .601 .8 r
.52964 .59379 .53059 .59579 .53236 .5953 .53141 .5933 Mtetra
.631 .6 .8 r
.53141 .5933 .53236 .5953 .53414 .59484 .53318 .59281 Mtetra
.63 .597 .797 r
.53318 .59281 .53414 .59484 .53591 .59448 .53495 .59232 Mtetra
.628 .585 .786 r
.53495 .59232 .53591 .59448 .53768 .59412 .53673 .59183 Mtetra
.626 .573 .775 r
.53673 .59183 .53768 .59412 .53946 .59374 .5385 .59134 Mtetra
.625 .564 .766 r
.5385 .59134 .53946 .59374 .54123 .59327 .54028 .59084 Mtetra
.625 .563 .764 r
.54028 .59084 .54123 .59327 .54301 .59277 .54206 .59034 Mtetra
.626 .563 .764 r
.54206 .59034 .54301 .59277 .54479 .59225 .54383 .58983 Mtetra
.627 .564 .765 r
.54383 .58983 .54479 .59225 .54657 .59173 .54561 .58931 Mtetra
.627 .564 .764 r
.54561 .58931 .54657 .59173 .54835 .59121 .54739 .58878 Mtetra
.628 .564 .764 r
.54739 .58878 .54835 .59121 .55013 .59069 .54918 .58825 Mtetra
.633 .567 .762 r
.54918 .58825 .55013 .59069 .55192 .59018 .55096 .58767 Mtetra
.629 .56 .758 r
.55096 .58767 .55192 .59018 .5537 .58965 .55274 .58712 Mtetra
.623 .556 .758 r
.55274 .58712 .5537 .58965 .55548 .58908 .55453 .58662 Mtetra
.601 .548 .767 r
.55453 .58662 .55548 .58908 .55727 .58855 .55632 .5863 Mtetra
.6 .563 .785 r
.55632 .5863 .55727 .58855 .55906 .5879 .55811 .586 Mtetra
.607 .6 .818 r
.55811 .586 .55906 .5879 .56084 .58703 .5599 .58568 Mtetra
.643 .688 .877 r
.5599 .58568 .56084 .58703 .56262 .58533 .56169 .58517 Mtetra
.503 .892 .955 r
.56169 .58517 .56262 .58533 .56439 .58316 .56348 .58461 Mtetra
.287 0 .041 r
.56348 .58461 .56439 .58316 .56616 .58062 .56527 .58403 Mtetra
.452 .13 .328 r
.56527 .58403 .56616 .58062 .56794 .57948 .56706 .58349 Mtetra
.468 .161 .36 r
.56706 .58349 .56794 .57948 .56973 .57902 .56886 .58296 Mtetra
.466 .157 .357 r
.56886 .58296 .56973 .57902 .57153 .57886 .57065 .58241 Mtetra
.504 .181 .352 r
.57065 .58241 .57153 .57886 .57333 .57912 .57246 .58232 Mtetra
.462 .132 .32 r
.57246 .58232 .57333 .57912 .57513 .57882 .57426 .58191 Mtetra
.359 .037 .276 r
.57426 .58191 .57513 .57882 .57691 .57737 .57605 .58081 Mtetra
0 0 0 r
.57605 .58081 .57691 .57737 .57842 .55865 .57778 .57584 Mtetra
.984 .71 .411 r
.57778 .57584 .57842 .55865 .57714 .37056 .57634 .3739 Mtetra
.75 .729 .203 r
.57634 .3739 .57714 .37056 .57878 .36674 .57792 .36677 Mtetra
.817 .993 .867 r
.57792 .36677 .57878 .36674 .58046 .36553 .57959 .36529 Mtetra
.529 .89 .976 r
.57959 .36529 .58046 .36553 .58215 .36499 .58129 .36478 Mtetra
.257 .749 .912 r
.58129 .36478 .58215 .36499 .58384 .36477 .58299 .36466 Mtetra
.547 .917 .946 r
.58299 .36466 .58384 .36477 .58554 .3644 .58468 .36401 Mtetra
.678 .906 .975 r
.58468 .36401 .58554 .3644 .58724 .36402 .58637 .36327 Mtetra
.697 .819 .94 r
.58637 .36327 .58724 .36402 .58893 .36361 .58806 .36256 Mtetra
.665 .741 .907 r
.58806 .36256 .58893 .36361 .59063 .363 .58976 .36199 Mtetra
.652 .744 .917 r
.58976 .36199 .59063 .363 .59232 .36232 .59145 .36147 Mtetra
.645 .78 .946 r
.59145 .36147 .59232 .36232 .59402 .36162 .59315 .36096 Mtetra
.655 .833 .968 r
.59315 .36096 .59402 .36162 .59571 .36086 .59485 .36039 Mtetra
.641 .876 .985 r
.59485 .36039 .59571 .36086 .59741 .36021 .59655 .35978 Mtetra
.629 .886 .988 r
.59655 .35978 .59741 .36021 .59911 .35977 .59825 .35918 Mtetra
.748 .873 .937 r
.59825 .35918 .59911 .35977 .60083 .35976 .59995 .35824 Mtetra
.681 .667 .83 r
.59995 .35824 .60083 .35976 .60256 .36035 .60165 .35751 Mtetra
.575 .501 .735 r
.60165 .35751 .60256 .36035 .60432 .36208 .60336 .35738 Mtetra
.235 .211 .627 r
.60336 .35738 .60432 .36208 .61081 .54937 .60516 .36037 Mtetra
0 0 .375 r
.60516 .36037 .61081 .54937 .61311 .56763 .61204 .56072 Mtetra
0 0 .477 r
.61204 .56072 .61311 .56763 .61502 .57059 .61407 .56822 Mtetra
.405 .443 .787 r
.61407 .56822 .61502 .57059 .61687 .57094 .61593 .56903 Mtetra
.637 .615 .811 r
.61593 .56903 .61687 .57094 .6187 .57043 .61776 .5685 Mtetra
.693 .64 .792 r
.61776 .5685 .6187 .57043 .62052 .56957 .61957 .56752 Mtetra
.627 .598 .801 r
.61957 .56752 .62052 .56957 .62235 .56905 .6214 .56705 Mtetra
.599 .587 .811 r
.6214 .56705 .62235 .56905 .62418 .56857 .62324 .56676 Mtetra
.606 .612 .831 r
.62324 .56676 .62418 .56857 .62601 .56787 .62508 .56643 Mtetra
.558 .64 .888 r
.62508 .56643 .62601 .56787 .62782 .56673 .62692 .56631 Mtetra
.496 .843 .996 r
.62692 .56631 .62782 .56673 .62961 .56499 .62876 .56594 Mtetra
0 0 0 r
.62876 .56594 .62961 .56499 .63138 .56214 .63058 .56493 Mtetra
.63058 .56493 .63138 .56214 .63287 .55092 .63231 .56102 Mtetra
.982 .7 .404 r
.63231 .56102 .63287 .55092 .62831 .35415 .62772 .36158 Mtetra
0 0 .131 r
.62772 .36158 .62831 .35415 .62991 .35012 .62911 .35049 Mtetra
.874 .988 .723 r
.62911 .35049 .62991 .35012 .63161 .34871 .63077 .34824 Mtetra
.713 .899 .963 r
.63077 .34824 .63161 .34871 .63333 .34824 .63249 .3474 Mtetra
.607 .772 .959 r
.63249 .3474 .63333 .34824 .63507 .34812 .63421 .34701 Mtetra
.644 .725 .908 r
.63421 .34701 .63507 .34812 .6368 .34775 .63594 .34652 Mtetra
.656 .707 .885 r
.63594 .34652 .6368 .34775 .63853 .34719 .63767 .34598 Mtetra
.65 .706 .888 r
.63767 .34598 .63853 .34719 .64025 .34659 .6394 .34546 Mtetra
.658 .726 .899 r
.6394 .34546 .64025 .34659 .64197 .34579 .64112 .34491 Mtetra
.662 .781 .937 r
.64112 .34491 .64197 .34579 .64369 .34498 .64285 .34433 Mtetra
.653 .837 .971 r
.64285 .34433 .64369 .34498 .64541 .34436 .64458 .34374 Mtetra
.654 .845 .973 r
.64458 .34374 .64541 .34436 .64717 .34446 .64631 .34314 Mtetra
.666 .694 .867 r
.64631 .34314 .64717 .34446 .64895 .34519 .64804 .34253 Mtetra
.631 .545 .739 r
.64804 .34253 .64895 .34519 .65075 .34634 .64977 .34192 Mtetra
.625 .48 .665 r
.64977 .34192 .65075 .34634 .65251 .34619 .65149 .341 Mtetra
.612 .458 .649 r
.65149 .341 .65251 .34619 .65423 .34521 .65322 .34016 Mtetra
.58 .439 .653 r
.65322 .34016 .65423 .34521 .65597 .34486 .65497 .33984 Mtetra
.388 .311 .647 r
.65497 .33984 .65597 .34486 .65795 .35001 .65681 .34182 Mtetra
.979 .687 .379 r
.65681 .34182 .65795 .35001 .6682 .54947 .6667 .53414 Mtetra
0 0 .434 r
.6667 .53414 .6682 .54947 .67025 .55362 .66929 .55087 Mtetra
.243 .312 .736 r
.66929 .55087 .67025 .55362 .67218 .55454 .67125 .55263 Mtetra
.573 .586 .828 r
.67125 .55263 .67218 .55454 .67405 .55418 .67313 .55249 Mtetra
.665 .657 .832 r
.67313 .55249 .67405 .55418 .6759 .55324 .67499 .5518 Mtetra
.615 .669 .879 r
.67499 .5518 .6759 .55324 .67773 .55198 .67686 .55141 Mtetra
.521 .824 1 r
.67686 .55141 .67773 .55198 .67954 .55023 .67873 .55107 Mtetra
0 0 0 r
.67873 .55107 .67954 .55023 .6813 .54738 .68058 .55011 Mtetra
0 0 .054 r
.68058 .55011 .6813 .54738 .68273 .5376 .68232 .54667 Mtetra
.982 .696 .383 r
.68232 .54667 .68273 .5376 .67517 .33874 .67492 .35025 Mtetra
0 0 .256 r
.67492 .35025 .67517 .33874 .67674 .33447 .67598 .33507 Mtetra
.86 .958 .617 r
.67598 .33507 .67674 .33447 .67843 .33263 .67763 .33239 Mtetra
.701 .953 .953 r
.67763 .33239 .67843 .33263 .68017 .33186 .67937 .33144 Mtetra
.556 .868 .995 r
.67937 .33144 .68017 .33186 .68193 .33158 .68112 .33098 Mtetra
.688 .864 .966 r
.68112 .33098 .68193 .33158 .68371 .33158 .68287 .33025 Mtetra
.706 .711 .852 r
.68287 .33025 .68371 .33158 .68552 .33192 .68461 .32939 Mtetra
.599 .536 .755 r
.68461 .32939 .68552 .33192 .68736 .33306 .68638 .32908 Mtetra
.368 .324 .678 r
.68638 .32908 .68736 .33306 .68939 .33768 .68826 .33083 Mtetra
.979 .683 .365 r
.68826 .33083 .68939 .33768 .70173 .5382 .69956 .51253 Mtetra
0 0 .42 r
.69956 .51253 .70173 .5382 .70389 .54289 .70297 .54117 Mtetra
0 .148 .692 r
.70297 .54117 .70389 .54289 .70588 .54435 .705 .54335 Mtetra
.49 .7 .963 r
.705 .54335 .70588 .54435 .7078 .54444 .70692 .54332 Mtetra
.746 .776 .877 r
.70692 .54332 .7078 .54444 .70967 .54356 .70877 .54222 Mtetra
.889 .766 .72 r
.70877 .54222 .70967 .54356 .71141 .54035 .71052 .53904 Mtetra
.971 .726 .508 r
.71052 .53904 .71141 .54035 .71183 .51366 .71168 .52558 Mtetra
.983 .695 .361 r
.71168 .52558 .71183 .51366 .70317 .32695 .7024 .32696 Mtetra
.966 .932 .697 r
.7024 .32696 .70317 .32695 .70481 .32418 .70403 .32386 Mtetra
.72 .945 .954 r
.70403 .32386 .70481 .32418 .70657 .32353 .70577 .32289 Mtetra
.595 .827 .988 r
.70577 .32289 .70657 .32353 .70837 .32343 .70755 .32245 Mtetra
.614 .745 .939 r
.70755 .32245 .70837 .32343 .71016 .32326 .70933 .32205 Mtetra
.654 .714 .892 r
.70933 .32205 .71016 .32326 .71193 .32271 .7111 .3215 Mtetra
.648 .711 .894 r
.7111 .3215 .71193 .32271 .7137 .32211 .71288 .32098 Mtetra
.701 .747 .887 r
.71288 .32098 .7137 .32211 .71545 .32117 .71464 .3202 Mtetra
.733 .789 .897 r
.71464 .3202 .71545 .32117 .7172 .32009 .71639 .31927 Mtetra
.62 .789 .963 r
.71639 .31927 .7172 .32009 .71897 .31952 .71818 .31881 Mtetra
0 .219 .686 r
.71818 .31881 .71897 .31952 .72087 .32086 .72007 .32008 Mtetra
.939 .571 .202 r
.72007 .32008 .72087 .32086 .72356 .33477 .72249 .3297 Mtetra
.978 .678 .356 r
.72249 .3297 .72356 .33477 .73792 .53225 .73698 .52996 Mtetra
0 .161 .688 r
.73698 .52996 .73792 .53225 .74 .53446 .73908 .53252 Mtetra
.561 .579 .829 r
.73908 .53252 .74 .53446 .74192 .53402 .74102 .53244 Mtetra
.666 .674 .848 r
.74102 .53244 .74192 .53402 .7438 .53297 .74292 .53175 Mtetra
.691 .743 .891 r
.74292 .53175 .7438 .53297 .74568 .53206 .74482 .53097 Mtetra
.65 .751 .923 r
.74482 .53097 .74568 .53206 .74761 .53174 .74673 .53039 Mtetra
.659 .708 .884 r
.74673 .53039 .74761 .53174 .74953 .53126 .74864 .52977 Mtetra
.616 .666 .876 r
.74864 .52977 .74953 .53126 .75142 .53038 .75057 .52937 Mtetra
.544 .725 .958 r
.75057 .52937 .75142 .53038 .75327 .52884 .75251 .52917 Mtetra
0 0 0 r
.75251 .52917 .75327 .52884 .75505 .5264 .75441 .52846 Mtetra
0 0 .031 r
.75441 .52846 .75505 .5264 .7566 .52047 .7562 .52603 Mtetra
0 0 .106 r
.7562 .52603 .7566 .52047 .74438 .31771 .75748 .51622 Mtetra
.03 0 .427 r
.75748 .51622 .74438 .31771 .74583 .31229 .74519 .31344 Mtetra
.78 .846 .39 r
.74519 .31344 .74583 .31229 .74751 .31005 .74676 .30972 Mtetra
.753 .953 .941 r
.74676 .30972 .74751 .31005 .7493 .30937 .74852 .30862 Mtetra
.635 .815 .969 r
.74852 .30862 .7493 .30937 .75112 .30911 .75032 .30808 Mtetra
.613 .739 .935 r
.75032 .30808 .75112 .30911 .75293 .30876 .75213 .30769 Mtetra
.658 .746 .914 r
.75213 .30769 .75293 .30876 .75471 .30796 .75393 .30711 Mtetra
.643 .792 .954 r
.75393 .30711 .75471 .30796 .7565 .30729 .75573 .30657 Mtetra
.634 .824 .973 r
.75573 .30657 .7565 .30729 .75833 .30706 .75754 .30602 Mtetra
.662 .756 .92 r
.75754 .30602 .75833 .30706 .76022 .30767 .75934 .30543 Mtetra
.638 .581 .773 r
.75934 .30543 .76022 .30767 .76215 .30876 .76114 .30483 Mtetra
.62 .491 .683 r
.76114 .30483 .76215 .30876 .76406 .3095 .76293 .30408 Mtetra
.615 .457 .645 r
.76293 .30408 .76406 .3095 .76583 .30851 .76471 .30312 Mtetra
.591 .442 .648 r
.76471 .30312 .76583 .30851 .76764 .30788 .76652 .30259 Mtetra
.503 .385 .652 r
.76652 .30259 .76764 .30788 .76964 .30978 .76843 .30341 Mtetra
0 .026 .532 r
.76843 .30341 .76964 .30978 .78738 .51142 .77084 .31039 Mtetra
.052 0 .445 r
.77084 .31039 .78738 .51142 .78983 .51742 .7888 .51389 Mtetra
.108 .181 .659 r
.7888 .51389 .78983 .51742 .79196 .51923 .79104 .51714 Mtetra
.571 .571 .814 r
.79104 .51714 .79196 .51923 .79394 .51908 .79302 .51701 Mtetra
.668 .623 .795 r
.79302 .51701 .79394 .51908 .79588 .51847 .79494 .51619 Mtetra
.684 .614 .771 r
.79494 .51619 .79588 .51847 .79781 .51771 .79685 .51516 Mtetra
.638 .57 .762 r
.79685 .51516 .79781 .51771 .79975 .51713 .79879 .51449 Mtetra
.634 .563 .756 r
.79879 .51449 .79975 .51713 .8017 .5165 .80073 .51383 Mtetra
.625 .556 .757 r
.80073 .51383 .8017 .5165 .80364 .5158 .80268 .51326 Mtetra
.608 .554 .769 r
.80268 .51326 .80364 .5158 .80557 .51504 .80464 .51286 Mtetra
.61 .585 .8 r
.80464 .51286 .80557 .51504 .8075 .51425 .80661 .51247 Mtetra
.625 .633 .838 r
.80661 .51247 .8075 .51425 .80944 .51351 .80857 .512 Mtetra
.657 .686 .866 r
.80857 .512 .80944 .51351 .81139 .51286 .81052 .51137 Mtetra
.662 .691 .867 r
.81052 .51137 .81139 .51286 .81334 .51225 .81247 .51071 Mtetra
.656 .68 .86 r
.81247 .51071 .81334 .51225 .8153 .51169 .81442 .51007 Mtetra
.639 .662 .856 r
.81442 .51007 .8153 .51169 .81726 .51116 .81639 .50953 Mtetra
.633 .658 .857 r
.81639 .50953 .81726 .51116 .81922 .51064 .81835 .50902 Mtetra
.609 .647 .863 r
.81835 .50902 .81922 .51064 .8212 .51025 .82033 .50866 Mtetra
.53 .61 .878 r
.82033 .50866 .8212 .51025 .82321 .51021 .82235 .50867 Mtetra
.626 .668 .871 r
.82235 .50867 .82321 .51021 .82518 .50971 .82432 .50821 Mtetra
.791 .74 .806 r
.82432 .50821 .82518 .50971 .82705 .50805 .82619 .50654 Mtetra
.959 .749 .576 r
.82619 .50654 .82705 .50805 .82846 .50139 .82756 .49941 Mtetra
.977 .673 .344 r
.82756 .49941 .82846 .50139 .81144 .29432 .81063 .29283 Mtetra
.935 .752 .63 r
.81063 .29283 .81144 .29432 .81285 .28911 .81207 .28792 Mtetra
.749 .762 .863 r
.81207 .28792 .81285 .28911 .81464 .28798 .81386 .28682 Mtetra
.625 .719 .914 r
.81386 .28682 .81464 .28798 .81649 .28754 .81571 .28638 Mtetra
.581 .699 .923 r
.81571 .28638 .81649 .28754 .81836 .28728 .81758 .28611 Mtetra
.75 .767 .867 r
.81758 .28611 .81836 .28728 .82015 .28618 .81937 .28502 Mtetra
.677 .741 .899 r
.81937 .28502 .82015 .28618 .82198 .2855 .82121 .28434 Mtetra
.4 .602 .929 r
.82121 .28434 .82198 .2855 .82391 .28582 .82314 .28466 Mtetra
.812 .404 0 r
.82314 .28466 .82391 .28582 .82638 .29165 .8256 .29044 Mtetra
.973 .661 .312 r
.8256 .29044 .82638 .29165 .84831 .49721 .8475 .49609 Mtetra
.694 .256 0 r
.8475 .49609 .84831 .49721 .85075 .50132 .84994 .50023 Mtetra
.339 .599 .943 r
.84994 .50023 .85075 .50132 .85283 .50174 .85202 .50065 Mtetra
.667 .769 .926 r
.85202 .50065 .85283 .50174 .8548 .50106 .85399 .49997 Mtetra
.848 .821 .821 r
.85399 .49997 .8548 .50106 .85665 .49911 .85585 .49802 Mtetra
.977 .78 .572 r
.85585 .49802 .85665 .49911 .85803 .49247 .85722 .49137 Mtetra
.976 .67 .326 r
.85722 .49137 .85803 .49247 .83912 .28522 .83835 .28408 Mtetra
.965 .78 .603 r
.83835 .28408 .83912 .28522 .84048 .27981 .83972 .27867 Mtetra
.762 .778 .867 r
.83972 .27867 .84048 .27981 .84228 .27865 .84152 .27751 Mtetra
.631 .728 .917 r
.84152 .27751 .84228 .27865 .84415 .27817 .84338 .27703 Mtetra
.555 .692 .931 r
.84338 .27703 .84415 .27817 .84605 .27799 .84529 .27685 Mtetra
.752 .777 .873 r
.84529 .27685 .84605 .27799 .84785 .27688 .84709 .27575 Mtetra
.684 .752 .903 r
.84709 .27575 .84785 .27688 .8497 .27616 .84894 .27503 Mtetra
.479 .654 .937 r
.84894 .27503 .8497 .27616 .85163 .27623 .85087 .2751 Mtetra
.753 .334 0 r
.85087 .2751 .85163 .27623 .85406 .28099 .85332 .28005 Mtetra
.971 .656 .296 r
.85332 .28005 .85406 .28099 .87799 .48727 .87722 .48639 Mtetra
.771 .326 0 r
.87722 .48639 .87799 .48727 .88058 .49221 .87979 .49113 Mtetra
.536 .712 .953 r
.87979 .49113 .88058 .49221 .88267 .49242 .88184 .49096 Mtetra
.71 .72 .857 r
.88184 .49096 .88267 .49242 .88468 .49185 .8838 .48998 Mtetra
.739 .682 .795 r
.8838 .48998 .88468 .49185 .88664 .49085 .88572 .4886 Mtetra
.323 .217 .576 r
.24388 .67014 .2444 .67781 .24594 .67801 .24518 .67331 Mtetra
.317 .26 .635 r
.24518 .67331 .24594 .67801 .24751 .67786 .24657 .6753 Mtetra
.4 .413 .758 r
.24657 .6753 .24751 .67786 .24913 .67699 .24807 .67608 Mtetra
.858 .762 .755 r
.24807 .67608 .24913 .67699 .2511 .67179 .24982 .6736 Mtetra
.99 .889 .594 r
.24982 .6736 .2511 .67179 .26795 .4755 .25184 .66774 Mtetra
0 0 .194 r
.25184 .66774 .26795 .4755 .2699 .46926 .26842 .4746 Mtetra
0 0 .148 r
.26842 .4746 .2699 .46926 .27147 .46796 .27024 .47014 Mtetra
0 0 0 r
.27024 .47014 .27147 .46796 .27298 .46743 .27188 .46788 Mtetra
.787 .999 .825 r
.27188 .46788 .27298 .46743 .27446 .46727 .27346 .46644 Mtetra
.712 .773 .901 r
.27346 .46644 .27446 .46727 .27597 .46681 .27499 .46573 Mtetra
.645 .706 .891 r
.27499 .46573 .27597 .46681 .27748 .46636 .2765 .4653 Mtetra
.61 .699 .907 r
.2765 .4653 .27748 .46636 .27898 .46591 .27799 .465 Mtetra
.726 .758 .878 r
.27799 .465 .27898 .46591 .28053 .46496 .27953 .46419 Mtetra
.697 .785 .919 r
.27953 .46419 .28053 .46496 .28206 .46429 .28105 .46355 Mtetra
.554 .756 .972 r
.28105 .46355 .28206 .46429 .28354 .46424 .28255 .46334 Mtetra
.635 .122 0 r
.28255 .46334 .28354 .46424 .28475 .46782 .28391 .4649 Mtetra
.825 .516 0 r
.28391 .4649 .28475 .46782 .27207 .66318 .28503 .46982 Mtetra
0 0 .224 r
.28503 .46982 .27207 .66318 .2732 .66919 .27262 .66181 Mtetra
.215 .141 .553 r
.27262 .66181 .2732 .66919 .27473 .66982 .2739 .66586 Mtetra
.34 .3 .668 r
.2739 .66586 .27473 .66982 .27634 .66947 .27536 .66744 Mtetra
.385 .455 .81 r
.27536 .66744 .27634 .66947 .27797 .6687 .27689 .66809 Mtetra
.557 .802 .99 r
.27689 .66809 .27797 .6687 .27958 .66818 .2785 .66779 Mtetra
.675 .885 .976 r
.2785 .66779 .27958 .66818 .2812 .66766 .28012 .66712 Mtetra
.725 .853 .942 r
.28012 .66712 .2812 .66766 .28282 .66712 .28176 .66631 Mtetra
.508 .734 .975 r
.28176 .66631 .28282 .66712 .28441 .66703 .28335 .66619 Mtetra
.546 .741 .966 r
.28335 .66619 .28441 .66703 .28601 .66671 .28495 .666 Mtetra
.686 .811 .942 r
.28495 .666 .28601 .66671 .28767 .66572 .28658 .66536 Mtetra
.907 .832 .761 r
.28658 .66536 .28767 .66572 .28956 .66117 .28835 .66263 Mtetra
.992 .87 .603 r
.28835 .66263 .28956 .66117 .30433 .46467 .29035 .65652 Mtetra
0 0 .218 r
.29035 .65652 .30433 .46467 .30631 .45743 .30489 .46311 Mtetra
.292 .036 .343 r
.30489 .46311 .30631 .45743 .30791 .45589 .30655 .46061 Mtetra
.512 .22 .408 r
.30655 .46061 .30791 .45589 .30943 .45543 .30806 .46044 Mtetra
.522 .234 .418 r
.30806 .46044 .30943 .45543 .31093 .45535 .30957 .46036 Mtetra
.115 0 .249 r
.30957 .46036 .31093 .45535 .31247 .45481 .31128 .45709 Mtetra
0 0 0 r
.31128 .45709 .31247 .45481 .31401 .45413 .31296 .45428 Mtetra
.909 .945 .815 r
.31296 .45428 .31401 .45413 .31555 .45346 .31459 .45228 Mtetra
.731 .714 .835 r
.31459 .45228 .31555 .45346 .31709 .45292 .31615 .45135 Mtetra
.65 .633 .82 r
.31615 .45135 .31709 .45292 .31862 .45243 .31769 .45084 Mtetra
.62 .618 .827 r
.31769 .45084 .31862 .45243 .32016 .45196 .31921 .45049 Mtetra
.645 .645 .835 r
.31921 .45049 .32016 .45196 .32169 .45146 .32075 .45003 Mtetra
.654 .654 .837 r
.32075 .45003 .32169 .45146 .32323 .45094 .32229 .44952 Mtetra
.654 .655 .838 r
.32229 .44952 .32323 .45094 .32477 .45042 .32382 .44901 Mtetra
.656 .658 .839 r
.32382 .44901 .32477 .45042 .32631 .4499 .32536 .44849 Mtetra
.655 .658 .84 r
.32536 .44849 .32631 .4499 .32785 .44937 .3269 .44798 Mtetra
.651 .658 .843 r
.3269 .44798 .32785 .44937 .32939 .44885 .32844 .44749 Mtetra
.632 .655 .855 r
.32844 .44749 .32939 .44885 .33093 .44833 .32998 .44709 Mtetra
.625 .673 .876 r
.32998 .44709 .33093 .44833 .33248 .44782 .33151 .44674 Mtetra
.633 .705 .897 r
.33151 .44674 .33248 .44782 .33402 .44731 .33305 .44634 Mtetra
.678 .741 .899 r
.33305 .44634 .33402 .44731 .33556 .44681 .3346 .44576 Mtetra
.697 .731 .877 r
.3346 .44576 .33556 .44681 .33711 .4463 .33615 .44508 Mtetra
.692 .7 .853 r
.33615 .44508 .33711 .4463 .33865 .44578 .33771 .44439 Mtetra
.671 .667 .837 r
.33771 .44439 .33865 .44578 .3402 .44524 .33926 .44379 Mtetra
.659 .655 .834 r
.33926 .44379 .3402 .44524 .34175 .44468 .34081 .44325 Mtetra
.655 .655 .838 r
.34081 .44325 .34175 .44468 .34331 .44412 .34236 .44273 Mtetra
.691 .673 .828 r
.34236 .44273 .34331 .44412 .34487 .44328 .34393 .44199 Mtetra
.686 .687 .846 r
.34393 .44199 .34487 .44328 .34644 .44255 .34549 .44133 Mtetra
.612 .671 .883 r
.34549 .44133 .34644 .44255 .34797 .44237 .34703 .44102 Mtetra
0 .258 .768 r
.34703 .44102 .34797 .44237 .34937 .44468 .34849 .4422 Mtetra
.706 .384 0 r
.34849 .4422 .34937 .44468 .34061 .63784 .34981 .4461 Mtetra
0 0 .261 r
.34981 .4461 .34061 .63784 .34169 .64811 .3411 .63891 Mtetra
.36 .236 .573 r
.3411 .63891 .34169 .64811 .34324 .64942 .34254 .64241 Mtetra
.589 .422 .624 r
.34254 .64241 .34324 .64942 .34489 .64903 .34419 .64181 Mtetra
.601 .43 .622 r
.34419 .64181 .34489 .64903 .34657 .64817 .34587 .64089 Mtetra
.44 .311 .608 r
.34587 .64089 .34657 .64817 .34822 .64763 .3474 .64272 Mtetra
.325 .265 .635 r
.3474 .64272 .34822 .64763 .34987 .64735 .34892 .64485 Mtetra
.266 .337 .75 r
.34892 .64485 .34987 .64735 .35151 .64706 .35049 .64611 Mtetra
.379 .647 .961 r
.35049 .64611 .35151 .64706 .35317 .64664 .35211 .64631 Mtetra
.534 .866 .994 r
.35211 .64631 .35317 .64664 .35483 .64612 .35377 .64589 Mtetra
.608 .91 .982 r
.35377 .64589 .35483 .64612 .35649 .64557 .35544 .64527 Mtetra
.484 .852 .988 r
.35544 .64527 .35649 .64557 .35814 .64537 .35709 .64492 Mtetra
.507 .829 1 r
.35709 .64492 .35814 .64537 .35979 .64515 .35875 .64462 Mtetra
.684 .858 .966 r
.35875 .64462 .35979 .64515 .36146 .64439 .36042 .64394 Mtetra
.874 .858 .822 r
.36042 .64394 .36146 .64439 .36325 .64131 .36215 .64197 Mtetra
.979 .894 .664 r
.36215 .64197 .36325 .64131 .36568 .62427 .36399 .63771 Mtetra
.967 .71 .493 r
.36399 .63771 .36568 .62427 .37594 .43545 .37442 .44687 Mtetra
0 0 .203 r
.37442 .44687 .37594 .43545 .37761 .43277 .37649 .43549 Mtetra
0 0 0 r
.37649 .43549 .37761 .43277 .3792 .43189 .37818 .43245 Mtetra
.827 .996 .762 r
.37818 .43245 .3792 .43189 .38076 .4315 .37981 .43062 Mtetra
.764 .78 .866 r
.37981 .43062 .38076 .4315 .38233 .43111 .3814 .42957 Mtetra
.659 .645 .824 r
.3814 .42957 .38233 .43111 .3839 .43061 .38298 .429 Mtetra
.619 .618 .828 r
.38298 .429 .3839 .43061 .38547 .43015 .38454 .42866 Mtetra
.614 .631 .845 r
.38454 .42866 .38547 .43015 .38705 .42967 .38611 .42834 Mtetra
.623 .661 .866 r
.38611 .42834 .38705 .42967 .38862 .42915 .38768 .42798 Mtetra
.63 .692 .889 r
.38768 .42798 .38862 .42915 .3902 .42862 .38925 .4276 Mtetra
.668 .732 .897 r
.38925 .4276 .3902 .42862 .39178 .42808 .39083 .42705 Mtetra
.698 .738 .882 r
.39083 .42705 .39178 .42808 .39335 .42754 .39241 .42635 Mtetra
.696 .71 .86 r
.39241 .42635 .39335 .42754 .39493 .42699 .394 .42564 Mtetra
.703 .687 .832 r
.394 .42564 .39493 .42699 .39653 .4262 .39559 .42484 Mtetra
.695 .683 .834 r
.39559 .42484 .39653 .4262 .39812 .42537 .39718 .42409 Mtetra
.633 .674 .871 r
.39718 .42409 .39812 .42537 .39969 .42502 .39876 .42369 Mtetra
.19 .437 .866 r
.39876 .42369 .39969 .42502 .4012 .42655 .40029 .42446 Mtetra
0 0 .302 r
.40029 .42446 .4012 .42655 .40229 .43922 .40174 .4277 Mtetra
.967 .701 .475 r
.40174 .4277 .40229 .43922 .39675 .63093 .39614 .61928 Mtetra
.192 .101 .516 r
.39614 .61928 .39675 .63093 .39833 .63306 .39754 .62642 Mtetra
.56 .405 .629 r
.39754 .62642 .39833 .63306 .40001 .63282 .3992 .62639 Mtetra
.618 .449 .631 r
.3992 .62639 .40001 .63282 .40171 .632 .40091 .62523 Mtetra
.614 .443 .627 r
.40091 .62523 .40171 .632 .40341 .63121 .40262 .6241 Mtetra
.582 .417 .623 r
.40262 .6241 .40341 .63121 .4051 .63071 .40431 .6236 Mtetra
.583 .418 .623 r
.40431 .6236 .4051 .63071 .40679 .63021 .406 .62309 Mtetra
.556 .398 .623 r
.406 .62309 .40679 .63021 .40848 .62995 .40767 .62311 Mtetra
.545 .393 .626 r
.40767 .62311 .40848 .62995 .41016 .62981 .40934 .62334 Mtetra
.602 .438 .631 r
.40934 .62334 .41016 .62981 .41186 .62912 .41104 .6225 Mtetra
.763 .551 .611 r
.41104 .6225 .41186 .62912 .41363 .62639 .41292 .61624 Mtetra
.942 .677 .506 r
.41292 .61624 .41363 .62639 .41586 .60892 .42083 .42188 Mtetra
.558 .341 .541 r
.42083 .42188 .41586 .60892 .42346 .41952 .42256 .41726 Mtetra
.762 .629 .713 r
.42256 .41726 .42346 .41952 .42513 .41657 .42421 .41522 Mtetra
.687 .684 .841 r
.42421 .41522 .42513 .41657 .42674 .4158 .42581 .41452 Mtetra
.615 .668 .878 r
.42581 .41452 .42674 .4158 .42833 .41554 .4274 .41419 Mtetra
.595 .648 .872 r
.4274 .41419 .42833 .41554 .42992 .41532 .42899 .41395 Mtetra
.62 .656 .863 r
.42899 .41395 .42992 .41532 .43152 .41481 .43059 .4136 Mtetra
.617 .683 .889 r
.43059 .4136 .43152 .41481 .43312 .4143 .43219 .41326 Mtetra
.63 .72 .912 r
.43219 .41326 .43312 .4143 .43472 .41379 .43379 .41286 Mtetra
.655 .751 .921 r
.43379 .41286 .43472 .41379 .43632 .41329 .43539 .41236 Mtetra
.67 .756 .915 r
.43539 .41236 .43632 .41329 .43793 .41277 .437 .4118 Mtetra
.702 .755 .893 r
.437 .4118 .43793 .41277 .43954 .41222 .43861 .41109 Mtetra
.719 .729 .858 r
.43861 .41109 .43954 .41222 .44114 .41163 .44022 .41024 Mtetra
.677 .675 .84 r
.44022 .41024 .44114 .41163 .44275 .41106 .44183 .40958 Mtetra
.547 .607 .865 r
.44183 .40958 .44275 .41106 .44436 .41057 .44343 .40954 Mtetra
0 .269 .762 r
.44343 .40954 .44436 .41057 .44596 .41022 .445 .41064 Mtetra
.783 .337 .191 r
.445 .41064 .44596 .41022 .44757 .40988 .44655 .41268 Mtetra
.712 .376 .408 r
.44655 .41268 .44757 .40988 .44918 .40946 .44809 .41517 Mtetra
.528 .246 .431 r
.44809 .41517 .44918 .40946 .45079 .40888 .4497 .41513 Mtetra
.455 .188 .418 r
.4497 .41513 .45079 .40888 .45241 .40827 .45133 .41396 Mtetra
.409 .142 .394 r
.45133 .41396 .45241 .40827 .45403 .40752 .45297 .41238 Mtetra
.4 .122 .372 r
.45297 .41238 .45403 .40752 .45565 .40659 .45461 .41098 Mtetra
.491 .194 .389 r
.45461 .41098 .45565 .40659 .45727 .40614 .45623 .4106 Mtetra
.717 .41 .457 r
.45623 .4106 .45727 .40614 .45885 .40715 .45776 .41427 Mtetra
.947 .673 .485 r
.45776 .41427 .45885 .40715 .46027 .4168 .45543 .60902 Mtetra
.555 .334 .534 r
.45543 .60902 .46027 .4168 .45807 .61254 .45705 .6134 Mtetra
.706 .262 .195 r
.45705 .6134 .45807 .61254 .45973 .61532 .45874 .61493 Mtetra
.344 .767 .975 r
.45874 .61493 .45973 .61532 .46145 .61522 .46046 .61483 Mtetra
.586 .876 .993 r
.46046 .61483 .46145 .61522 .46318 .61451 .46219 .61431 Mtetra
.614 .924 .972 r
.46219 .61431 .46318 .61451 .46492 .61364 .46392 .61361 Mtetra
.52 .91 .928 r
.46392 .61361 .46492 .61364 .46665 .61313 .46565 .61296 Mtetra
.604 .926 .968 r
.46565 .61296 .46665 .61313 .46838 .6126 .46739 .61226 Mtetra
.617 .897 .987 r
.46739 .61226 .46838 .6126 .47011 .61209 .46912 .61164 Mtetra
.529 .844 .999 r
.46912 .61164 .47011 .61209 .47184 .6116 .47085 .61127 Mtetra
.57 .886 .99 r
.47085 .61127 .47184 .6116 .47358 .61108 .47259 .61075 Mtetra
.75 .924 .948 r
.47259 .61075 .47358 .61108 .47531 .6105 .47433 .60973 Mtetra
.872 .817 .791 r
.47433 .60973 .47531 .6105 .47705 .60978 .47609 .60751 Mtetra
.813 .661 .693 r
.47609 .60751 .47705 .60978 .47879 .60904 .47786 .60441 Mtetra
.749 .561 .641 r
.47786 .60441 .47879 .60904 .48053 .60836 .47964 .60066 Mtetra
.612 .435 .618 r
.47964 .60066 .48053 .60836 .48227 .60784 .48139 .59937 Mtetra
.562 .393 .61 r
.48139 .59937 .48227 .60784 .48401 .60737 .48312 .59924 Mtetra
.549 .386 .613 r
.48312 .59924 .48401 .60737 .48575 .60689 .48485 .5994 Mtetra
.581 .414 .62 r
.48485 .5994 .48575 .60689 .48749 .60638 .48659 .5989 Mtetra
.48659 .5989 .48749 .60638 .48923 .60586 .48833 .59839 Mtetra
.582 .415 .62 r
.48833 .59839 .48923 .60586 .49098 .60532 .49007 .59785 Mtetra
.584 .417 .62 r
.49007 .59785 .49098 .60532 .49272 .60478 .49182 .59727 Mtetra
.585 .417 .62 r
.49182 .59727 .49272 .60478 .49447 .60424 .49356 .59667 Mtetra
.585 .416 .619 r
.49356 .59667 .49447 .60424 .49622 .60369 .49531 .59607 Mtetra
.584 .415 .619 r
.49531 .59607 .49622 .60369 .49797 .60315 .49705 .59548 Mtetra
.583 .414 .618 r
.49705 .59548 .49797 .60315 .49972 .6026 .4988 .5949 Mtetra
.4988 .5949 .49972 .6026 .50147 .60206 .50055 .59433 Mtetra
.582 .413 .618 r
.50055 .59433 .50147 .60206 .50322 .60153 .5023 .59376 Mtetra
.582 .413 .617 r
.5023 .59376 .50322 .60153 .50498 .601 .50405 .5932 Mtetra
.581 .412 .617 r
.50405 .5932 .50498 .601 .50673 .60047 .5058 .59265 Mtetra
.5058 .59265 .50673 .60047 .50849 .59994 .50756 .59211 Mtetra
.581 .411 .617 r
.50756 .59211 .50849 .59994 .51024 .59942 .50931 .59157 Mtetra
.58 .411 .617 r
.50931 .59157 .51024 .59942 .512 .59889 .51106 .59104 Mtetra
.51106 .59104 .512 .59889 .51376 .59837 .51282 .59052 Mtetra
.51282 .59052 .51376 .59837 .51552 .59785 .51458 .59 Mtetra
.58 .41 .617 r
.51458 .59 .51552 .59785 .51728 .59734 .51634 .58948 Mtetra
.579 .41 .617 r
.51634 .58948 .51728 .59734 .51904 .59682 .5181 .58897 Mtetra
.5181 .58897 .51904 .59682 .5208 .59631 .51986 .58847 Mtetra
.51986 .58847 .5208 .59631 .52257 .5958 .52162 .58798 Mtetra
.52162 .58798 .52257 .5958 .52433 .59529 .52338 .58749 Mtetra
.578 .41 .617 r
.52338 .58749 .52433 .59529 .5261 .59479 .52514 .58701 Mtetra
.52514 .58701 .5261 .59479 .52787 .59429 .52691 .58654 Mtetra
.578 .41 .618 r
.52691 .58654 .52787 .59429 .52964 .59379 .52868 .58608 Mtetra
.577 .41 .618 r
.52868 .58608 .52964 .59379 .53141 .5933 .53044 .58563 Mtetra
.577 .41 .619 r
.53044 .58563 .53141 .5933 .53318 .59281 .53221 .58518 Mtetra
.576 .41 .619 r
.53221 .58518 .53318 .59281 .53495 .59232 .53398 .58476 Mtetra
.577 .411 .62 r
.53398 .58476 .53495 .59232 .53673 .59183 .53575 .58433 Mtetra
.577 .412 .62 r
.53575 .58433 .53673 .59183 .5385 .59134 .53753 .58389 Mtetra
.579 .413 .621 r
.53753 .58389 .5385 .59134 .54028 .59084 .5393 .58343 Mtetra
.58 .414 .621 r
.5393 .58343 .54028 .59084 .54206 .59034 .54107 .58294 Mtetra
.581 .415 .622 r
.54107 .58294 .54206 .59034 .54383 .58983 .54285 .58244 Mtetra
.583 .416 .622 r
.54285 .58244 .54383 .58983 .54561 .58931 .54463 .58189 Mtetra
.583 .416 .621 r
.54463 .58189 .54561 .58931 .54739 .58878 .5464 .58134 Mtetra
.5464 .58134 .54739 .58878 .54918 .58825 .54818 .58079 Mtetra
.615 .438 .62 r
.54818 .58079 .54918 .58825 .55096 .58767 .54996 .57947 Mtetra
.587 .414 .614 r
.54996 .57947 .55096 .58767 .55274 .58712 .55174 .57873 Mtetra
.535 .375 .611 r
.55174 .57873 .55274 .58712 .55453 .58662 .55353 .57922 Mtetra
.378 .272 .605 r
.55353 .57922 .55453 .58662 .55632 .5863 .55534 .58211 Mtetra
.346 .307 .672 r
.55534 .58211 .55632 .5863 .55811 .586 .55715 .58399 Mtetra
.282 .402 .808 r
.55715 .58399 .55811 .586 .5599 .58568 .55896 .58505 Mtetra
.411 .751 .994 r
.55896 .58505 .5599 .58568 .56169 .58517 .56075 .585 Mtetra
.409 .844 .944 r
.56075 .585 .56169 .58517 .56348 .58461 .56255 .5846 Mtetra
.438 .874 .896 r
.56255 .5846 .56348 .58461 .56527 .58403 .56434 .58401 Mtetra
.468 .889 .904 r
.56434 .58401 .56527 .58403 .56706 .58349 .56613 .58338 Mtetra
.547 .917 .945 r
.56613 .58338 .56706 .58349 .56886 .58296 .56793 .5827 Mtetra
.612 .919 .976 r
.56793 .5827 .56886 .58296 .57065 .58241 .56972 .58199 Mtetra
.46 .824 .994 r
.56972 .58199 .57065 .58241 .57246 .58232 .57152 .58171 Mtetra
.589 .833 .991 r
.57152 .58171 .57246 .58232 .57426 .58191 .57332 .58126 Mtetra
.727 .859 .944 r
.57332 .58126 .57426 .58191 .57605 .58081 .57512 .58036 Mtetra
.936 .86 .741 r
.57512 .58036 .57605 .58081 .57778 .57584 .57688 .5773 Mtetra
.98 .866 .491 r
.57688 .5773 .57778 .57584 .57634 .3739 .57859 .57068 Mtetra
0 0 .369 r
.57859 .57068 .57634 .3739 .57792 .36677 .57715 .3723 Mtetra
.357 .1 .38 r
.57715 .3723 .57792 .36677 .57959 .36529 .57882 .37011 Mtetra
.51 .217 .405 r
.57882 .37011 .57959 .36529 .58129 .36478 .58052 .36989 Mtetra
.515 .226 .414 r
.58052 .36989 .58129 .36478 .58299 .36466 .58222 .36971 Mtetra
.167 0 .306 r
.58222 .36971 .58299 .36466 .58468 .36401 .58386 .36613 Mtetra
0 0 0 r
.58386 .36613 .58468 .36401 .58637 .36327 .58552 .36328 Mtetra
.902 .971 .811 r
.58552 .36328 .58637 .36327 .58806 .36256 .58718 .36127 Mtetra
.704 .71 .853 r
.58718 .36127 .58806 .36256 .58976 .36199 .58887 .36045 Mtetra
.624 .641 .846 r
.58887 .36045 .58976 .36199 .59145 .36147 .59058 .36006 Mtetra
.589 .643 .872 r
.59058 .36006 .59145 .36147 .59315 .36096 .59228 .35983 Mtetra
.64 .714 .901 r
.59228 .35983 .59315 .36096 .59485 .36039 .59398 .35936 Mtetra
.663 .746 .912 r
.59398 .35936 .59485 .36039 .59655 .35978 .59568 .3588 Mtetra
.675 .758 .914 r
.59568 .3588 .59655 .35978 .59825 .35918 .59739 .35818 Mtetra
.744 .774 .877 r
.59739 .35818 .59825 .35918 .59995 .35824 .59908 .35719 Mtetra
.721 .76 .883 r
.59908 .35719 .59995 .35824 .60165 .35751 .60078 .35633 Mtetra
.633 .704 .897 r
.60078 .35633 .60165 .35751 .60336 .35738 .60248 .3559 Mtetra
.005 .284 .783 r
.60248 .3559 .60336 .35738 .60516 .36037 .60424 .3573 Mtetra
0 0 .432 r
.60424 .3573 .60516 .36037 .61204 .56072 .60608 .36185 Mtetra
0 0 .394 r
.60608 .36185 .61204 .56072 .61407 .56822 .61295 .55966 Mtetra
.46 .321 .605 r
.61295 .55966 .61407 .56822 .61593 .56903 .61484 .5617 Mtetra
.594 .426 .623 r
.61484 .5617 .61593 .56903 .61776 .5685 .61666 .56088 Mtetra
.598 .426 .62 r
.61666 .56088 .61776 .5685 .61957 .56752 .61847 .55995 Mtetra
.426 .306 .612 r
.61847 .55995 .61957 .56752 .6214 .56705 .62038 .56229 Mtetra
.36 .303 .658 r
.62038 .56229 .6214 .56705 .62324 .56676 .62229 .56437 Mtetra
.318 .388 .777 r
.62229 .56437 .62324 .56676 .62508 .56643 .62417 .56555 Mtetra
.328 .643 .966 r
.62417 .56555 .62508 .56643 .62692 .56631 .62602 .56582 Mtetra
.513 .836 .999 r
.62602 .56582 .62692 .56631 .62876 .56594 .62787 .56546 Mtetra
.726 .906 .958 r
.62787 .56546 .62876 .56594 .63058 .56493 .62969 .56451 Mtetra
.916 .897 .795 r
.62969 .56451 .63058 .56493 .63231 .56102 .63147 .56211 Mtetra
.953 .9 .517 r
.63147 .56211 .63231 .56102 .62772 .36158 .63317 .5572 Mtetra
0 0 .387 r
.63317 .5572 .62772 .36158 .62911 .35049 .62854 .35842 Mtetra
0 0 .302 r
.62854 .35842 .62911 .35049 .63077 .34824 .63003 .35058 Mtetra
0 0 .009 r
.63003 .35058 .63077 .34824 .63249 .3474 .63168 .34768 Mtetra
.816 .997 .774 r
.63168 .34768 .63249 .3474 .63421 .34701 .63336 .34587 Mtetra
.741 .751 .86 r
.63336 .34587 .63421 .34701 .63594 .34652 .63507 .34486 Mtetra
.653 .639 .823 r
.63507 .34486 .63594 .34652 .63767 .34598 .63679 .34427 Mtetra
.619 .618 .828 r
.63679 .34427 .63767 .34598 .6394 .34546 .63853 .34389 Mtetra
.62 .637 .845 r
.63853 .34389 .6394 .34546 .64112 .34491 .64026 .34351 Mtetra
.627 .665 .867 r
.64026 .34351 .64112 .34491 .64285 .34433 .642 .34309 Mtetra
.636 .697 .89 r
.642 .34309 .64285 .34433 .64458 .34374 .64373 .34264 Mtetra
.678 .74 .897 r
.64373 .34264 .64458 .34374 .64631 .34314 .64546 .34199 Mtetra
.7 .739 .881 r
.64546 .34199 .64631 .34314 .64804 .34253 .64719 .34123 Mtetra
.696 .71 .859 r
.64719 .34123 .64804 .34253 .64977 .34192 .64891 .34045 Mtetra
.706 .689 .831 r
.64891 .34045 .64977 .34192 .65149 .341 .65063 .33956 Mtetra
.691 .686 .841 r
.65063 .33956 .65149 .341 .65322 .34016 .65236 .33878 Mtetra
.624 .668 .872 r
.65236 .33878 .65322 .34016 .65497 .33984 .6541 .33838 Mtetra
.257 .454 .862 r
.6541 .33838 .65497 .33984 .65681 .34182 .6559 .33923 Mtetra
0 .051 .606 r
.6559 .33923 .65681 .34182 .6667 .53414 .65779 .34231 Mtetra
0 0 .405 r
.65779 .34231 .6667 .53414 .66929 .55087 .66792 .53871 Mtetra
.189 .112 .533 r
.66792 .53871 .66929 .55087 .67125 .55263 .67018 .54757 Mtetra
.367 .302 .652 r
.67018 .54757 .67125 .55263 .67313 .55249 .67216 .54977 Mtetra
.413 .423 .761 r
.67216 .54977 .67313 .55249 .67499 .5518 .67409 .55069 Mtetra
.408 .631 .945 r
.67409 .55069 .67499 .5518 .67686 .55141 .67599 .55092 Mtetra
.485 .826 .998 r
.67599 .55092 .67686 .55141 .67873 .55107 .67787 .55061 Mtetra
.707 .912 .966 r
.67787 .55061 .67873 .55107 .68058 .55011 .67972 .5497 Mtetra
.907 .915 .814 r
.67972 .5497 .68058 .55011 .68232 .54667 .68151 .54748 Mtetra
.964 .905 .542 r
.68151 .54748 .68232 .54667 .67492 .35025 .68319 .54276 Mtetra
0 0 .4 r
.68319 .54276 .67492 .35025 .67598 .33507 .67563 .34408 Mtetra
.012 0 .33 r
.67563 .34408 .67598 .33507 .67763 .33239 .67698 .33514 Mtetra
0 0 .132 r
.67698 .33514 .67763 .33239 .67937 .33144 .67862 .33225 Mtetra
0 0 0 r
.67862 .33225 .67937 .33144 .68112 .33098 .68032 .33043 Mtetra
.837 .898 .883 r
.68032 .33043 .68112 .33098 .68287 .33025 .68203 .32897 Mtetra
.74 .732 .844 r
.68203 .32897 .68287 .33025 .68461 .32939 .68376 .32791 Mtetra
.619 .65 .859 r
.68376 .32791 .68461 .32939 .68638 .32908 .68552 .32753 Mtetra
0 .227 .746 r
.68552 .32753 .68638 .32908 .68826 .33083 .6874 .32925 Mtetra
.966 .639 .287 r
.6874 .32925 .68826 .33083 .69956 .51253 .69022 .34902 Mtetra
0 0 .38 r
.69022 .34902 .69956 .51253 .70297 .54117 .70212 .54057 Mtetra
.619 .086 0 r
.70212 .54057 .70297 .54117 .705 .54335 .70414 .54264 Mtetra
.518 .785 .993 r
.70414 .54264 .705 .54335 .70692 .54332 .70604 .54238 Mtetra
.767 .819 .893 r
.70604 .54238 .70692 .54332 .70877 .54222 .7079 .54121 Mtetra
.873 .813 .787 r
.7079 .54121 .70877 .54222 .71052 .53904 .70969 .53892 Mtetra
.984 .876 .643 r
.70969 .53892 .71052 .53904 .71168 .52558 .71137 .53455 Mtetra
.982 .693 .369 r
.71137 .53455 .71168 .52558 .7024 .32696 .70234 .33944 Mtetra
.014 0 .359 r
.70234 .33944 .7024 .32696 .70403 .32386 .70343 .32682 Mtetra
0 0 .149 r
.70343 .32682 .70403 .32386 .70577 .32289 .70505 .32358 Mtetra
.628 .884 .548 r
.70505 .32358 .70577 .32289 .70755 .32245 .70674 .32161 Mtetra
.772 .828 .896 r
.70674 .32161 .70755 .32245 .70933 .32205 .70848 .32049 Mtetra
.643 .653 .845 r
.70848 .32049 .70933 .32205 .7111 .3215 .71026 .31997 Mtetra
.6 .637 .859 r
.71026 .31997 .7111 .3215 .71288 .32098 .71205 .31968 Mtetra
.648 .696 .881 r
.71205 .31968 .71288 .32098 .71464 .3202 .71382 .31915 Mtetra
.709 .769 .899 r
.71382 .31915 .71464 .3202 .71639 .31927 .71559 .31834 Mtetra
.641 .771 .942 r
.71559 .31834 .71639 .31927 .71818 .31881 .71737 .31783 Mtetra
.273 .569 .937 r
.71737 .31783 .71818 .31881 .72007 .32008 .71921 .31832 Mtetra
0 .037 .607 r
.71921 .31832 .72007 .32008 .72249 .3297 .72119 .32097 Mtetra
.979 .68 .342 r
.72119 .32097 .72249 .3297 .73698 .52996 .73503 .51174 Mtetra
.149 .072 .507 r
.73503 .51174 .73698 .52996 .73908 .53252 .73792 .52674 Mtetra
.374 .296 .639 r
.73792 .52674 .73908 .53252 .74102 .53244 .74002 .52926 Mtetra
.423 .404 .733 r
.74002 .52926 .74102 .53244 .74292 .53175 .74204 .53031 Mtetra
.498 .616 .899 r
.74204 .53031 .74292 .53175 .74482 .53097 .74399 .53041 Mtetra
.621 .87 .989 r
.74399 .53041 .74482 .53097 .74673 .53039 .7459 .52979 Mtetra
.699 .884 .966 r
.7459 .52979 .74673 .53039 .74864 .52977 .7478 .52893 Mtetra
.64 .807 .963 r
.7478 .52893 .74864 .52977 .75057 .52937 .74971 .52835 Mtetra
.519 .713 .96 r
.74971 .52835 .75057 .52937 .75251 .52917 .75166 .52823 Mtetra
.615 .774 .957 r
.75166 .52823 .75251 .52917 .75441 .52846 .75358 .52777 Mtetra
.827 .884 .884 r
.75358 .52777 .75441 .52846 .7562 .52603 .75543 .52624 Mtetra
.974 .925 .631 r
.75543 .52624 .7562 .52603 .75748 .51622 .75712 .52236 Mtetra
0 0 .037 r
.75712 .52236 .75748 .51622 .74519 .31344 .75818 .50942 Mtetra
.044 0 .431 r
.75818 .50942 .74519 .31344 .74676 .30972 .74627 .31305 Mtetra
0 0 .2 r
.74627 .31305 .74676 .30972 .74852 .30862 .74785 .30949 Mtetra
0 0 0 r
.74785 .30949 .74852 .30862 .75032 .30808 .74954 .3074 Mtetra
.797 .874 .904 r
.74954 .3074 .75032 .30808 .75213 .30769 .75129 .30616 Mtetra
.65 .662 .849 r
.75129 .30616 .75213 .30769 .75393 .30711 .7531 .30559 Mtetra
.608 .645 .861 r
.7531 .30559 .75393 .30711 .75573 .30657 .75491 .30526 Mtetra
.622 .685 .888 r
.75491 .30526 .75573 .30657 .75754 .30602 .75673 .30485 Mtetra
.691 .739 .888 r
.75673 .30485 .75754 .30602 .75934 .30543 .75852 .30411 Mtetra
.691 .712 .864 r
.75852 .30411 .75934 .30543 .76114 .30483 .76031 .30333 Mtetra
.693 .686 .839 r
.76031 .30333 .76114 .30483 .76293 .30408 .7621 .30251 Mtetra
.695 .677 .829 r
.7621 .30251 .76293 .30408 .76471 .30312 .76388 .30165 Mtetra
.647 .671 .859 r
.76388 .30165 .76471 .30312 .76652 .30259 .76569 .30111 Mtetra
.446 .565 .881 r
.76569 .30111 .76652 .30259 .76843 .30341 .76757 .30144 Mtetra
0 .097 .651 r
.76757 .30144 .76843 .30341 .77084 .31039 .76964 .30411 Mtetra
0 0 .152 r
.76964 .30411 .77084 .31039 .7888 .51389 .77275 .32005 Mtetra
.071 0 .451 r
.77275 .32005 .7888 .51389 .79104 .51714 .78972 .50998 Mtetra
.547 .396 .628 r
.78972 .50998 .79104 .51714 .79302 .51701 .79172 .5102 Mtetra
.61 .442 .63 r
.79172 .5102 .79302 .51701 .79494 .51619 .79362 .50908 Mtetra
.633 .455 .624 r
.79362 .50908 .79494 .51619 .79685 .51516 .79546 .5073 Mtetra
.616 .437 .617 r
.79546 .5073 .79685 .51516 .79879 .51449 .79733 .5058 Mtetra
.585 .41 .611 r
.79733 .5058 .79879 .51449 .80073 .51383 .79926 .50504 Mtetra
.505 .355 .611 r
.79926 .50504 .80073 .51383 .80268 .51326 .80136 .5063 Mtetra
.395 .296 .624 r
.80136 .5063 .80268 .51326 .80464 .51286 .80359 .50911 Mtetra
.377 .351 .703 r
.80359 .50911 .80464 .51286 .80661 .51247 .80573 .51076 Mtetra
.391 .515 .864 r
.80573 .51076 .80661 .51247 .80857 .512 .80778 .51138 Mtetra
.613 .857 .99 r
.80778 .51138 .80857 .512 .81052 .51137 .80974 .51079 Mtetra
.697 .896 .969 r
.80974 .51079 .81052 .51137 .81247 .51071 .81167 .50991 Mtetra
.719 .849 .943 r
.81167 .50991 .81247 .51071 .81442 .51007 .8136 .50898 Mtetra
.648 .758 .93 r
.8136 .50898 .81442 .51007 .81639 .50953 .81555 .5084 Mtetra
.631 .742 .928 r
.81555 .5084 .81639 .50953 .81835 .50902 .81752 .50789 Mtetra
.579 .719 .938 r
.81752 .50789 .81835 .50902 .82033 .50866 .81951 .50759 Mtetra
.425 .655 .956 r
.81951 .50759 .82033 .50866 .82235 .50867 .82154 .50776 Mtetra
.567 .765 .971 r
.82154 .50776 .82235 .50867 .82432 .50821 .82353 .50743 Mtetra
.824 .876 .883 r
.82353 .50743 .82432 .50821 .82619 .50654 .82541 .5059 Mtetra
.989 .802 .56 r
.82541 .5059 .82619 .50654 .82756 .49941 .82682 .49921 Mtetra
.977 .674 .339 r
.82682 .49921 .82756 .49941 .81063 .29283 .80987 .29197 Mtetra
.974 .801 .607 r
.80987 .29197 .81063 .29283 .81207 .28792 .81129 .28677 Mtetra
.754 .771 .867 r
.81129 .28677 .81207 .28792 .81386 .28682 .81308 .28565 Mtetra
.624 .717 .913 r
.81308 .28565 .81386 .28682 .81571 .28638 .81493 .28521 Mtetra
.579 .696 .922 r
.81493 .28521 .81571 .28638 .81758 .28611 .8168 .28496 Mtetra
.751 .769 .868 r
.8168 .28496 .81758 .28611 .81937 .28502 .8186 .28386 Mtetra
.677 .741 .899 r
.8186 .28386 .81937 .28502 .82121 .28434 .82043 .28317 Mtetra
.404 .603 .928 r
.82043 .28317 .82121 .28434 .82314 .28466 .82236 .28349 Mtetra
.807 .399 0 r
.82236 .28349 .82314 .28466 .8256 .29044 .82481 .28919 Mtetra
.973 .661 .311 r
.82481 .28919 .8256 .29044 .8475 .49609 .84668 .49496 Mtetra
.695 .258 0 r
.84668 .49496 .8475 .49609 .84994 .50023 .84913 .49913 Mtetra
.337 .597 .942 r
.84913 .49913 .84994 .50023 .85202 .50065 .85121 .49956 Mtetra
.667 .769 .926 r
.85121 .49956 .85202 .50065 .85399 .49997 .85319 .49888 Mtetra
.848 .82 .821 r
.85319 .49888 .85399 .49997 .85585 .49802 .85504 .49693 Mtetra
.977 .779 .572 r
.85504 .49693 .85585 .49802 .85722 .49137 .85642 .49028 Mtetra
.976 .67 .326 r
.85642 .49028 .85722 .49137 .83835 .28408 .83758 .28294 Mtetra
.965 .78 .603 r
.83758 .28294 .83835 .28408 .83972 .27867 .83896 .27753 Mtetra
.761 .778 .867 r
.83896 .27753 .83972 .27867 .84152 .27751 .84075 .27637 Mtetra
.631 .728 .917 r
.84075 .27637 .84152 .27751 .84338 .27703 .84262 .27589 Mtetra
.553 .692 .931 r
.84262 .27589 .84338 .27703 .84529 .27685 .84452 .27572 Mtetra
.751 .777 .874 r
.84452 .27572 .84529 .27685 .84709 .27575 .84633 .27462 Mtetra
.683 .753 .904 r
.84633 .27462 .84709 .27575 .84894 .27503 .84818 .27391 Mtetra
.475 .654 .938 r
.84818 .27391 .84894 .27503 .85087 .2751 .85011 .27399 Mtetra
.786 .372 0 r
.85011 .27399 .85087 .2751 .85332 .28005 .85262 .27945 Mtetra
.971 .656 .297 r
.85262 .27945 .85332 .28005 .87722 .48639 .87648 .48578 Mtetra
.779 .311 0 r
.87648 .48578 .87722 .48639 .87979 .49113 .87899 .48997 Mtetra
.81 .806 .847 r
.87899 .48997 .87979 .49113 .88184 .49096 .88088 .48837 Mtetra
.817 .661 .69 r
.88088 .48837 .88184 .49096 .8838 .48998 .88261 .48522 Mtetra
.789 .582 .62 r
.88261 .48522 .8838 .48998 .88572 .4886 .88414 .48027 Mtetra
.529 .317 .535 r
.25863 .47351 .24388 .67014 .24518 .67331 .2594 .48218 Mtetra
0 0 .206 r
.2594 .48218 .24518 .67331 .24657 .6753 .24572 .67178 Mtetra
0 0 .472 r
.24572 .67178 .24657 .6753 .24807 .67608 .24701 .67517 Mtetra
.653 .755 .924 r
.24701 .67517 .24807 .67608 .24982 .6736 .2486 .67467 Mtetra
.557 .868 .573 r
.2486 .67467 .24982 .6736 .25184 .66774 .25029 .67304 Mtetra
.126 0 .248 r
.25029 .67304 .25184 .66774 .26842 .4746 .25211 .66975 Mtetra
0 0 .244 r
.25211 .66975 .26842 .4746 .27024 .47014 .26783 .48737 Mtetra
0 0 .11 r
.26783 .48737 .27024 .47014 .27188 .46788 .27073 .46906 Mtetra
.957 .947 .656 r
.27073 .46906 .27188 .46788 .27346 .46644 .27246 .46562 Mtetra
.759 .78 .87 r
.27246 .46562 .27346 .46644 .27499 .46573 .27401 .46463 Mtetra
.64 .701 .89 r
.27401 .46463 .27499 .46573 .2765 .4653 .27552 .46422 Mtetra
.563 .678 .917 r
.27552 .46422 .2765 .4653 .27799 .465 .277 .46407 Mtetra
.695 .751 .895 r
.277 .46407 .27799 .465 .27953 .46419 .27853 .46343 Mtetra
.686 .786 .927 r
.27853 .46343 .27953 .46419 .28105 .46355 .28005 .46284 Mtetra
.624 .784 .958 r
.28005 .46284 .28105 .46355 .28255 .46334 .28156 .46244 Mtetra
.47 .684 .959 r
.28156 .46244 .28255 .46334 .28391 .4649 .28303 .46246 Mtetra
.436 .434 .758 r
.28303 .46246 .28391 .4649 .28503 .46982 .28447 .46306 Mtetra
.425 .299 .604 r
.28447 .46306 .28503 .46982 .27262 .66181 .28582 .46488 Mtetra
0 0 .243 r
.28582 .46488 .27262 .66181 .2739 .66586 .27361 .65444 Mtetra
0 0 .372 r
.27361 .65444 .2739 .66586 .27536 .66744 .27446 .66447 Mtetra
0 .025 .579 r
.27446 .66447 .27536 .66744 .27689 .66809 .27585 .66706 Mtetra
.472 .668 .948 r
.27585 .66706 .27689 .66809 .2785 .66779 .27743 .66711 Mtetra
.693 .817 .941 r
.27743 .66711 .2785 .66779 .28012 .66712 .27905 .66643 Mtetra
.755 .822 .905 r
.27905 .66643 .28012 .66712 .28176 .66631 .2807 .66547 Mtetra
.599 .759 .955 r
.2807 .66547 .28176 .66631 .28335 .66619 .28231 .66513 Mtetra
.599 .71 .922 r
.28231 .66513 .28335 .66619 .28495 .666 .28392 .66484 Mtetra
.655 .709 .887 r
.28392 .66484 .28495 .666 .28658 .66536 .28554 .66434 Mtetra
.793 .758 .82 r
.28554 .66434 .28658 .66536 .28835 .66263 .28722 .66289 Mtetra
.903 .962 .818 r
.28722 .66289 .28835 .66263 .29035 .65652 .28895 .66082 Mtetra
.167 0 .237 r
.28895 .66082 .29035 .65652 .30489 .46311 .29071 .6583 Mtetra
.547 .327 .533 r
.29071 .6583 .30489 .46311 .30655 .46061 .29233 .65777 Mtetra
.547 .328 .533 r
.29233 .65777 .30655 .46061 .30806 .46044 .29393 .65767 Mtetra
.546 .326 .533 r
.29393 .65767 .30806 .46044 .30957 .46036 .29558 .65674 Mtetra
.524 .308 .528 r
.29558 .65674 .30957 .46036 .31128 .45709 .29796 .64468 Mtetra
0 0 .222 r
.29796 .64468 .31128 .45709 .31296 .45428 .31185 .45539 Mtetra
.974 .926 .644 r
.31185 .45539 .31296 .45428 .31459 .45228 .31361 .45149 Mtetra
.801 .791 .843 r
.31361 .45149 .31459 .45228 .31615 .45135 .31519 .45018 Mtetra
.664 .698 .872 r
.31519 .45018 .31615 .45135 .31769 .45084 .31673 .44965 Mtetra
.593 .67 .893 r
.31673 .44965 .31769 .45084 .31921 .45049 .31825 .44942 Mtetra
.642 .709 .895 r
.31825 .44942 .31921 .45049 .32075 .45003 .31978 .44899 Mtetra
.66 .722 .895 r
.31978 .44899 .32075 .45003 .32229 .44952 .32132 .44849 Mtetra
.659 .723 .897 r
.32132 .44849 .32229 .44952 .32382 .44901 .32285 .448 Mtetra
.661 .727 .898 r
.32285 .448 .32382 .44901 .32536 .44849 .32439 .44749 Mtetra
.66 .73 .901 r
.32439 .44749 .32536 .44849 .3269 .44798 .32593 .44699 Mtetra
.654 .731 .906 r
.32593 .44699 .3269 .44798 .32844 .44749 .32747 .44651 Mtetra
.63 .727 .917 r
.32747 .44651 .32844 .44749 .32998 .44709 .32901 .44613 Mtetra
.62 .725 .921 r
.32901 .44613 .32998 .44709 .33151 .44674 .33054 .44577 Mtetra
.628 .729 .92 r
.33054 .44577 .33151 .44674 .33305 .44634 .33208 .44539 Mtetra
.669 .744 .906 r
.33208 .44539 .33305 .44634 .3346 .44576 .33363 .44485 Mtetra
.69 .757 .903 r
.33363 .44485 .3346 .44576 .33615 .44508 .33518 .44423 Mtetra
.694 .77 .91 r
.33518 .44423 .33615 .44508 .33771 .44439 .33673 .44358 Mtetra
.676 .777 .926 r
.33673 .44358 .33771 .44439 .33926 .44379 .33829 .44301 Mtetra
.664 .782 .937 r
.33829 .44301 .33926 .44379 .34081 .44325 .33984 .44249 Mtetra
.659 .786 .942 r
.33984 .44249 .34081 .44325 .34236 .44273 .34139 .44198 Mtetra
.691 .795 .929 r
.34139 .44198 .34236 .44273 .34393 .44199 .34294 .44135 Mtetra
.683 .819 .948 r
.34294 .44135 .34393 .44199 .34549 .44133 .3445 .44074 Mtetra
.617 .82 .978 r
.3445 .44074 .34549 .44133 .34703 .44102 .34605 .44032 Mtetra
.266 .636 .963 r
.34605 .44032 .34703 .44102 .34849 .4422 .34756 .44056 Mtetra
.232 .405 .829 r
.34756 .44056 .34849 .4422 .34981 .4461 .34904 .44142 Mtetra
.424 .333 .648 r
.34904 .44142 .34981 .4461 .3411 .63891 .3505 .44274 Mtetra
.548 .333 .539 r
.3505 .44274 .3411 .63891 .34254 .64241 .35203 .4427 Mtetra
.55 .334 .539 r
.35203 .4427 .34254 .64241 .34419 .64181 .35361 .44179 Mtetra
.549 .333 .539 r
.35361 .44179 .34419 .64181 .34587 .64089 .35516 .44151 Mtetra
.535 .322 .537 r
.35516 .44151 .34587 .64089 .3474 .64272 .35637 .44774 Mtetra
0 0 .272 r
.35637 .44774 .3474 .64272 .34892 .64485 .34805 .64095 Mtetra
0 0 .499 r
.34805 .64095 .34892 .64485 .35049 .64611 .34949 .64473 Mtetra
.2 .449 .872 r
.34949 .64473 .35049 .64611 .35211 .64631 .35108 .6455 Mtetra
.618 .776 .957 r
.35108 .6455 .35211 .64631 .35377 .64589 .35274 .64509 Mtetra
.713 .799 .919 r
.35274 .64509 .35377 .64589 .35544 .64527 .35441 .64431 Mtetra
.66 .754 .92 r
.35441 .64431 .35544 .64527 .35709 .64492 .35608 .64377 Mtetra
.626 .706 .903 r
.35608 .64377 .35709 .64492 .35875 .64462 .35774 .64337 Mtetra
.667 .703 .873 r
.35774 .64337 .35875 .64462 .36042 .64394 .35941 .64278 Mtetra
.737 .737 .851 r
.35941 .64278 .36042 .64394 .36215 .64197 .3611 .64178 Mtetra
.856 .925 .873 r
.3611 .64178 .36215 .64197 .36399 .63771 .36281 .64018 Mtetra
0 0 0 r
.36281 .64018 .36399 .63771 .37442 .44687 .36458 .63758 Mtetra
.532 .315 .53 r
.36458 .63758 .37442 .44687 .37649 .43549 .36659 .62954 Mtetra
0 0 .268 r
.36659 .62954 .37649 .43549 .37818 .43245 .37708 .43454 Mtetra
.863 .885 .454 r
.37708 .43454 .37818 .43245 .37981 .43062 .37883 .43018 Mtetra
.866 .86 .832 r
.37883 .43018 .37981 .43062 .3814 .42957 .38046 .42844 Mtetra
.682 .715 .874 r
.38046 .42844 .3814 .42957 .38298 .429 .38203 .42782 Mtetra
.596 .675 .896 r
.38203 .42782 .38298 .429 .38454 .42866 .3836 .42756 Mtetra
.59 .691 .912 r
.3836 .42756 .38454 .42866 .38611 .42834 .38516 .42732 Mtetra
.617 .717 .917 r
.38516 .42732 .38611 .42834 .38768 .42798 .38673 .42698 Mtetra
.621 .721 .918 r
.38673 .42698 .38768 .42798 .38925 .4276 .3883 .42662 Mtetra
.656 .738 .91 r
.3883 .42662 .38925 .4276 .39083 .42705 .38988 .42612 Mtetra
.687 .757 .905 r
.38988 .42612 .39083 .42705 .39241 .42635 .39146 .42549 Mtetra
.694 .773 .912 r
.39146 .42549 .39241 .42635 .394 .42564 .39305 .42483 Mtetra
.703 .787 .917 r
.39305 .42483 .394 .42564 .39559 .42484 .39464 .42414 Mtetra
.693 .812 .939 r
.39464 .42414 .39559 .42484 .39718 .42409 .39622 .42349 Mtetra
.631 .824 .975 r
.39622 .42349 .39718 .42409 .39876 .42369 .3978 .42302 Mtetra
.363 .698 .983 r
.3978 .42302 .39876 .42369 .40029 .42446 .39936 .42311 Mtetra
.181 .425 .859 r
.39936 .42311 .40029 .42446 .40174 .4277 .4009 .42392 Mtetra
.391 .337 .677 r
.4009 .42392 .40174 .4277 .39614 .61928 .40242 .42522 Mtetra
.547 .331 .539 r
.40242 .42522 .39614 .61928 .39754 .62642 .40395 .42612 Mtetra
.549 .333 .539 r
.40395 .42612 .39754 .62642 .3992 .62639 .40554 .42574 Mtetra
.55 .334 .539 r
.40554 .42574 .3992 .62639 .40091 .62523 .40714 .42489 Mtetra
.40714 .42489 .40091 .62523 .40262 .6241 .40874 .4241 Mtetra
.549 .333 .539 r
.40874 .4241 .40262 .6241 .40431 .6236 .41033 .42356 Mtetra
.41033 .42356 .40431 .6236 .406 .62309 .41193 .42303 Mtetra
.41193 .42303 .406 .62309 .40767 .62311 .41351 .4227 Mtetra
.41351 .4227 .40767 .62311 .40934 .62334 .4151 .42251 Mtetra
.55 .333 .539 r
.4151 .42251 .40934 .62334 .41104 .6225 .4167 .42188 Mtetra
.552 .335 .54 r
.4167 .42188 .41104 .6225 .41292 .61624 .41834 .42007 Mtetra
.553 .336 .54 r
.41834 .42007 .41292 .61624 .42083 .42188 .42 .41767 Mtetra
.688 .524 .659 r
.42 .41767 .42083 .42188 .42256 .41726 .42164 .41576 Mtetra
.746 .684 .791 r
.42164 .41576 .42256 .41726 .42421 .41522 .42326 .41453 Mtetra
.679 .812 .947 r
.42326 .41453 .42421 .41522 .42581 .41452 .42486 .41392 Mtetra
.606 .818 .981 r
.42486 .41392 .42581 .41452 .4274 .41419 .42646 .41351 Mtetra
.595 .793 .975 r
.42646 .41351 .4274 .41419 .42899 .41395 .42805 .41315 Mtetra
.62 .771 .953 r
.42805 .41315 .42899 .41395 .43059 .4136 .42965 .41275 Mtetra
.623 .761 .945 r
.42965 .41275 .43059 .4136 .43219 .41326 .43125 .41236 Mtetra
.641 .753 .93 r
.43125 .41236 .43219 .41326 .43379 .41286 .43285 .4119 Mtetra
.664 .748 .913 r
.43285 .4119 .43379 .41286 .43539 .41236 .43446 .41136 Mtetra
.675 .743 .902 r
.43446 .41136 .43539 .41236 .437 .4118 .43607 .41078 Mtetra
.714 .749 .88 r
.43607 .41078 .437 .4118 .43861 .41109 .43768 .40999 Mtetra
.738 .741 .854 r
.43768 .40999 .43861 .41109 .44022 .41024 .4393 .40903 Mtetra
.674 .704 .87 r
.4393 .40903 .44022 .41024 .44183 .40958 .44091 .40843 Mtetra
.291 .535 .913 r
.44091 .40843 .44183 .40958 .44343 .40954 .44249 .40893 Mtetra
.889 .463 .138 r
.44249 .40893 .44343 .40954 .445 .41064 .444 .41241 Mtetra
.954 .681 .482 r
.444 .41241 .445 .41064 .44655 .41268 .44082 .60766 Mtetra
.558 .336 .534 r
.44082 .60766 .44655 .41268 .44809 .41517 .44237 .61381 Mtetra
.548 .328 .533 r
.44237 .61381 .44809 .41517 .4497 .41513 .44407 .61383 Mtetra
.546 .326 .533 r
.44407 .61383 .4497 .41513 .45133 .41396 .4458 .61289 Mtetra
.545 .326 .533 r
.4458 .61289 .45133 .41396 .45297 .41238 .44753 .61163 Mtetra
.546 .326 .533 r
.44753 .61163 .45297 .41238 .45461 .41098 .44926 .61076 Mtetra
.547 .327 .533 r
.44926 .61076 .45461 .41098 .45623 .4106 .45098 .61028 Mtetra
.548 .328 .533 r
.45098 .61028 .45623 .4106 .45776 .41427 .45268 .61082 Mtetra
.55 .33 .533 r
.45268 .61082 .45776 .41427 .45543 .60902 .45436 .61229 Mtetra
.608 .275 .38 r
.45436 .61229 .45543 .60902 .45705 .6134 .45605 .61334 Mtetra
.302 0 0 r
.45605 .61334 .45705 .6134 .45874 .61493 .45776 .61379 Mtetra
.576 .696 .923 r
.45776 .61379 .45874 .61493 .46046 .61483 .45948 .61356 Mtetra
.633 .694 .888 r
.45948 .61356 .46046 .61483 .46219 .61431 .46121 .61312 Mtetra
.66 .717 .891 r
.46121 .61312 .46219 .61431 .46392 .61361 .46294 .61256 Mtetra
.669 .745 .908 r
.46294 .61256 .46392 .61361 .46565 .61296 .46467 .61195 Mtetra
.678 .758 .912 r
.46467 .61195 .46565 .61296 .46739 .61226 .46641 .61131 Mtetra
.651 .762 .931 r
.46641 .61131 .46739 .61226 .46912 .61164 .46814 .61078 Mtetra
.554 .748 .967 r
.46814 .61078 .46912 .61164 .47085 .61127 .46987 .61054 Mtetra
.646 .812 .963 r
.46987 .61054 .47085 .61127 .47259 .61075 .4716 .61 Mtetra
.817 .83 .86 r
.4716 .61 .47259 .61075 .47433 .60973 .47336 .60853 Mtetra
.904 .747 .675 r
.47336 .60853 .47433 .60973 .47609 .60751 .47515 .60415 Mtetra
.957 .687 .482 r
.47515 .60415 .47609 .60751 .47786 .60441 .47958 .41121 Mtetra
.571 .351 .542 r
.47958 .41121 .47786 .60441 .47964 .60066 .48137 .39935 Mtetra
.551 .334 .539 r
.48137 .39935 .47964 .60066 .48139 .59937 .48302 .39809 Mtetra
.549 .333 .539 r
.48302 .39809 .48139 .59937 .48312 .59924 .48465 .39783 Mtetra
.548 .332 .539 r
.48465 .39783 .48312 .59924 .48485 .5994 .48628 .3979 Mtetra
.549 .333 .539 r
.48628 .3979 .48485 .5994 .48659 .5989 .48792 .39736 Mtetra
.48792 .39736 .48659 .5989 .48833 .59839 .48956 .39684 Mtetra
.48956 .39684 .48833 .59839 .49007 .59785 .4912 .3963 Mtetra
.4912 .3963 .49007 .59785 .49182 .59727 .49284 .39573 Mtetra
.49284 .39573 .49182 .59727 .49356 .59667 .49449 .39515 Mtetra
.49449 .39515 .49356 .59667 .49531 .59607 .49613 .39456 Mtetra
.49613 .39456 .49531 .59607 .49705 .59548 .49778 .39399 Mtetra
.49778 .39399 .49705 .59548 .4988 .5949 .49942 .39342 Mtetra
.49942 .39342 .4988 .5949 .50055 .59433 .50107 .39285 Mtetra
.50107 .39285 .50055 .59433 .5023 .59376 .50272 .39228 Mtetra
.50272 .39228 .5023 .59376 .50405 .5932 .50437 .39171 Mtetra
.50437 .39171 .50405 .5932 .5058 .59265 .50602 .39115 Mtetra
.50602 .39115 .5058 .59265 .50756 .59211 .50767 .39059 Mtetra
.50767 .39059 .50756 .59211 .50931 .59157 .50932 .39004 Mtetra
.50932 .39004 .50931 .59157 .51106 .59104 .51097 .38948 Mtetra
.51097 .38948 .51106 .59104 .51282 .59052 .51263 .38893 Mtetra
.51263 .38893 .51282 .59052 .51458 .59 .51428 .38838 Mtetra
.51428 .38838 .51458 .59 .51634 .58948 .51594 .38783 Mtetra
.51594 .38783 .51634 .58948 .5181 .58897 .51759 .38728 Mtetra
.51759 .38728 .5181 .58897 .51986 .58847 .51925 .38674 Mtetra
.51925 .38674 .51986 .58847 .52162 .58798 .52091 .3862 Mtetra
.52091 .3862 .52162 .58798 .52338 .58749 .52257 .38566 Mtetra
.52257 .38566 .52338 .58749 .52514 .58701 .52423 .38512 Mtetra
.52423 .38512 .52514 .58701 .52691 .58654 .52589 .38459 Mtetra
.52589 .38459 .52691 .58654 .52868 .58608 .52755 .38406 Mtetra
.52755 .38406 .52868 .58608 .53044 .58563 .52922 .38353 Mtetra
.52922 .38353 .53044 .58563 .53221 .58518 .53088 .38301 Mtetra
.53088 .38301 .53221 .58518 .53398 .58476 .53255 .3825 Mtetra
.53255 .3825 .53398 .58476 .53575 .58433 .53422 .38199 Mtetra
.53422 .38199 .53575 .58433 .53753 .58389 .53588 .38147 Mtetra
.53588 .38147 .53753 .58389 .5393 .58343 .53755 .38094 Mtetra
.53755 .38094 .5393 .58343 .54107 .58294 .53922 .3804 Mtetra
.53922 .3804 .54107 .58294 .54285 .58244 .54089 .37985 Mtetra
.54089 .37985 .54285 .58244 .54463 .58189 .54257 .37926 Mtetra
.54257 .37926 .54463 .58189 .5464 .58134 .54424 .37868 Mtetra
.54424 .37868 .5464 .58134 .54818 .58079 .54591 .37811 Mtetra
.551 .334 .539 r
.54591 .37811 .54818 .58079 .54996 .57947 .54758 .37681 Mtetra
.55 .334 .539 r
.54758 .37681 .54996 .57947 .55174 .57873 .54926 .37611 Mtetra
.548 .332 .539 r
.54926 .37611 .55174 .57873 .55353 .57922 .55094 .37655 Mtetra
0 0 .384 r
.55094 .37655 .55353 .57922 .55534 .58211 .5543 .56997 Mtetra
0 0 .46 r
.5543 .56997 .55534 .58211 .55715 .58399 .55619 .58117 Mtetra
0 .091 .629 r
.55619 .58117 .55715 .58399 .55896 .58505 .55801 .584 Mtetra
.426 .649 .952 r
.55801 .584 .55896 .58505 .56075 .585 .55981 .58416 Mtetra
.619 .785 .961 r
.55981 .58416 .56075 .585 .56255 .5846 .5616 .5837 Mtetra
.701 .795 .923 r
.5616 .5837 .56255 .5846 .56434 .58401 .5634 .58293 Mtetra
.677 .75 .906 r
.5634 .58293 .56434 .58401 .56613 .58338 .56519 .58226 Mtetra
.685 .746 .898 r
.56519 .58226 .56613 .58338 .56793 .5827 .56699 .58156 Mtetra
.686 .743 .894 r
.56699 .58156 .56793 .5827 .56972 .58199 .56878 .58084 Mtetra
.627 .72 .913 r
.56878 .58084 .56972 .58199 .57152 .58171 .57058 .5804 Mtetra
.641 .697 .886 r
.57058 .5804 .57152 .58171 .57332 .58126 .57238 .57991 Mtetra
.68 .704 .866 r
.57238 .57991 .57332 .58126 .57512 .58036 .57418 .5792 Mtetra
.807 .768 .817 r
.57418 .5792 .57512 .58036 .57688 .5773 .57597 .57756 Mtetra
.886 .991 .777 r
.57597 .57756 .57688 .5773 .57859 .57068 .57774 .57536 Mtetra
.256 0 .314 r
.57774 .57536 .57859 .57068 .57715 .3723 .57951 .57272 Mtetra
.547 .327 .533 r
.57951 .57272 .57715 .3723 .57882 .37011 .58132 .57228 Mtetra
.58132 .57228 .57882 .37011 .58052 .36989 .58313 .57209 Mtetra
.546 .326 .533 r
.58313 .57209 .58052 .36989 .58222 .36971 .58492 .57102 Mtetra
.519 .305 .529 r
.58492 .57102 .58222 .36971 .58386 .36613 .58644 .55441 Mtetra
0 0 .371 r
.58644 .55441 .58386 .36613 .58552 .36328 .58468 .36421 Mtetra
.938 .926 .562 r
.58468 .36421 .58552 .36328 .58718 .36127 .58631 .36037 Mtetra
.775 .8 .873 r
.58631 .36037 .58718 .36127 .58887 .36045 .588 .35921 Mtetra
.627 .69 .889 r
.588 .35921 .58887 .36045 .59058 .36006 .5897 .35881 Mtetra
.549 .653 .904 r
.5897 .35881 .59058 .36006 .59228 .35983 .59141 .35871 Mtetra
.629 .714 .908 r
.59141 .35871 .59228 .35983 .59398 .35936 .59311 .35829 Mtetra
.657 .734 .906 r
.59311 .35829 .59398 .35936 .59568 .3588 .59481 .35775 Mtetra
.667 .743 .907 r
.59481 .35775 .59568 .3588 .59739 .35818 .59652 .35716 Mtetra
.714 .765 .893 r
.59652 .35716 .59739 .35818 .59908 .35719 .59821 .35635 Mtetra
.71 .802 .922 r
.59821 .35635 .59908 .35719 .60078 .35633 .59991 .35558 Mtetra
.655 .808 .957 r
.59991 .35558 .60078 .35633 .60248 .3559 .60162 .35502 Mtetra
.334 .63 .96 r
.60162 .35502 .60248 .3559 .60424 .3573 .60335 .35529 Mtetra
.347 .43 .804 r
.60335 .35529 .60424 .3573 .60608 .36185 .60509 .35617 Mtetra
.462 .348 .638 r
.60509 .35617 .60608 .36185 .61295 .55966 .60685 .35752 Mtetra
.549 .333 .539 r
.60685 .35752 .61295 .55966 .61484 .5617 .60857 .3571 Mtetra
.55 .334 .539 r
.60857 .3571 .61484 .5617 .61666 .56088 .61027 .35616 Mtetra
.549 .333 .539 r
.61027 .35616 .61666 .56088 .61847 .55995 .612 .35599 Mtetra
.529 .317 .537 r
.612 .35599 .61847 .55995 .62038 .56229 .61402 .36649 Mtetra
0 0 .397 r
.61402 .36649 .62038 .56229 .62229 .56437 .6213 .56084 Mtetra
0 .101 .616 r
.6213 .56084 .62229 .56437 .62417 .56555 .62324 .56423 Mtetra
.314 .533 .905 r
.62324 .56423 .62417 .56555 .62602 .56582 .62511 .56482 Mtetra
.619 .752 .941 r
.62511 .56482 .62602 .56582 .62787 .56546 .62695 .56438 Mtetra
.732 .772 .885 r
.62695 .56438 .62787 .56546 .62969 .56451 .62877 .56341 Mtetra
.77 .777 .858 r
.62877 .56341 .62969 .56451 .63147 .56211 .63059 .56215 Mtetra
.846 .994 .841 r
.63059 .56215 .63147 .56211 .63317 .5572 .63239 .56036 Mtetra
.029 0 .159 r
.63239 .56036 .63317 .5572 .62854 .35842 .63415 .55743 Mtetra
.528 .312 .531 r
.63415 .55743 .62854 .35842 .63003 .35058 .63562 .54575 Mtetra
0 0 .39 r
.63562 .54575 .63003 .35058 .63168 .34768 .63091 .34917 Mtetra
.797 .846 .388 r
.63091 .34917 .63168 .34768 .63336 .34587 .63251 .34514 Mtetra
.835 .849 .856 r
.63251 .34514 .63336 .34587 .63507 .34486 .63421 .34361 Mtetra
.669 .708 .877 r
.63421 .34361 .63507 .34486 .63679 .34427 .63593 .34299 Mtetra
.594 .671 .894 r
.63593 .34299 .63679 .34427 .63853 .34389 .63767 .34272 Mtetra
.605 .698 .909 r
.63767 .34272 .63853 .34389 .64026 .34351 .63941 .34239 Mtetra
.622 .716 .913 r
.63941 .34239 .64026 .34351 .642 .34309 .64114 .34199 Mtetra
.628 .721 .914 r
.64114 .34199 .642 .34309 .64373 .34264 .64288 .34157 Mtetra
.666 .742 .907 r
.64288 .34157 .64373 .34264 .64546 .34199 .64461 .34098 Mtetra
.69 .762 .906 r
.64461 .34098 .64546 .34199 .64719 .34123 .64634 .34028 Mtetra
.696 .778 .914 r
.64634 .34028 .64719 .34123 .64891 .34045 .64807 .33955 Mtetra
.707 .793 .918 r
.64807 .33955 .64891 .34045 .65063 .33956 .6498 .33878 Mtetra
.691 .817 .943 r
.6498 .33878 .65063 .33956 .65236 .33878 .65153 .33807 Mtetra
.63 .817 .972 r
.65153 .33807 .65236 .33878 .6541 .33838 .65327 .33757 Mtetra
.497 .734 .978 r
.65327 .33757 .6541 .33838 .6559 .33923 .65503 .33746 Mtetra
.439 .515 .84 r
.65503 .33746 .6559 .33923 .65779 .34231 .65681 .33791 Mtetra
.423 .348 .668 r
.65681 .33791 .65779 .34231 .66792 .53871 .65863 .33934 Mtetra
.534 .322 .538 r
.65863 .33934 .66792 .53871 .67018 .54757 .66073 .34703 Mtetra
.005 0 .414 r
.66073 .34703 .67018 .54757 .67216 .54977 .67112 .54546 Mtetra
.115 .151 .622 r
.67112 .54546 .67216 .54977 .67409 .55069 .67317 .54908 Mtetra
.295 .47 .862 r
.67317 .54908 .67409 .55069 .67599 .55092 .6751 .54991 Mtetra
.599 .745 .946 r
.6751 .54991 .67599 .55092 .67787 .55061 .67697 .54954 Mtetra
.725 .776 .893 r
.67697 .54954 .67787 .55061 .67972 .5497 .67883 .54859 Mtetra
.774 .782 .86 r
.67883 .54859 .67972 .5497 .68151 .54748 .68066 .54731 Mtetra
.857 .975 .864 r
.68066 .54731 .68151 .54748 .68319 .54276 .68248 .54556 Mtetra
.003 0 .127 r
.68248 .54556 .68319 .54276 .67563 .34408 .68425 .54275 Mtetra
.534 .317 .532 r
.68425 .54275 .67563 .34408 .67698 .33514 .68574 .53441 Mtetra
.005 0 .408 r
.68574 .53441 .67698 .33514 .67862 .33225 .67795 .33454 Mtetra
0 0 0 r
.67795 .33454 .67862 .33225 .68032 .33043 .67951 .33001 Mtetra
.912 .907 .804 r
.67951 .33001 .68032 .33043 .68203 .32897 .68119 .32783 Mtetra
.75 .759 .86 r
.68119 .32783 .68203 .32897 .68376 .32791 .68292 .32675 Mtetra
.584 .694 .918 r
.68292 .32675 .68376 .32791 .68552 .32753 .68469 .32649 Mtetra
0 .074 .604 r
.68469 .32649 .68552 .32753 .6874 .32925 .68658 .32834 Mtetra
.975 .677 .385 r
.68658 .32834 .6874 .32925 .69022 .34902 .6982 .51784 Mtetra
.586 .357 .535 r
.6982 .51784 .69022 .34902 .70212 .54057 .70124 .53961 Mtetra
0 .055 .569 r
.70124 .53961 .70212 .54057 .70414 .54264 .70326 .54154 Mtetra
.597 .727 .935 r
.70326 .54154 .70414 .54264 .70604 .54238 .70515 .54119 Mtetra
.744 .762 .867 r
.70515 .54119 .70604 .54238 .7079 .54121 .70701 .54008 Mtetra
.781 .784 .855 r
.70701 .54008 .7079 .54121 .70969 .53892 .70886 .53873 Mtetra
.823 .979 .888 r
.70886 .53873 .70969 .53892 .71137 .53455 .71069 .53717 Mtetra
.054 0 .136 r
.71069 .53717 .71137 .53455 .70234 .33944 .71248 .5347 Mtetra
.536 .319 .532 r
.71248 .5347 .70234 .33944 .70343 .32682 .71401 .52781 Mtetra
.02 0 .417 r
.71401 .52781 .70343 .32682 .70505 .32358 .70444 .32616 Mtetra
0 0 0 r
.70444 .32616 .70505 .32358 .70674 .32161 .70596 .32125 Mtetra
.898 .932 .829 r
.70596 .32125 .70674 .32161 .70848 .32049 .70765 .31928 Mtetra
.666 .72 .889 r
.70765 .31928 .70848 .32049 .71026 .31997 .70942 .31867 Mtetra
.578 .664 .897 r
.70942 .31867 .71026 .31997 .71205 .31968 .71122 .31846 Mtetra
.61 .694 .903 r
.71122 .31846 .71205 .31968 .71382 .31915 .71301 .3181 Mtetra
.684 .758 .907 r
.71301 .3181 .71382 .31915 .71559 .31834 .71478 .31741 Mtetra
.654 .775 .937 r
.71478 .31741 .71559 .31834 .71737 .31783 .71655 .31685 Mtetra
.573 .73 .949 r
.71655 .31685 .71737 .31783 .71921 .31832 .71835 .31659 Mtetra
.494 .554 .846 r
.71835 .31659 .71921 .31832 .72119 .32097 .72018 .31681 Mtetra
.463 .383 .681 r
.72018 .31681 .72119 .32097 .73503 .51174 .72206 .31784 Mtetra
.54 .326 .539 r
.72206 .31784 .73503 .51174 .73792 .52674 .72417 .3224 Mtetra
.043 0 .435 r
.72417 .3224 .73792 .52674 .74002 .52926 .73887 .52374 Mtetra
.147 .146 .6 r
.73887 .52374 .74002 .52926 .74204 .53031 .74111 .52831 Mtetra
.281 .409 .814 r
.74111 .52831 .74204 .53031 .74399 .53041 .74314 .52947 Mtetra
.627 .779 .954 r
.74314 .52947 .74399 .53041 .7459 .52979 .74505 .52897 Mtetra
.729 .839 .932 r
.74505 .52897 .7459 .52979 .7478 .52893 .74694 .52802 Mtetra
.694 .808 .935 r
.74694 .52802 .7478 .52893 .74971 .52835 .74885 .52723 Mtetra
.581 .717 .936 r
.74885 .52723 .74971 .52835 .75166 .52823 .75078 .52693 Mtetra
.625 .703 .901 r
.75078 .52693 .75166 .52823 .75358 .52777 .75271 .52648 Mtetra
.702 .737 .878 r
.75271 .52648 .75358 .52777 .75543 .52624 .75461 .52562 Mtetra
.832 .9 .887 r
.75461 .52562 .75543 .52624 .75712 .52236 .75646 .52407 Mtetra
0 0 0 r
.75646 .52407 .75712 .52236 .75818 .50942 .75825 .52161 Mtetra
.344 .138 .45 r
.75825 .52161 .75818 .50942 .74627 .31305 .7598 .51578 Mtetra
.044 0 .431 r
.7598 .51578 .74627 .31305 .74785 .30949 .74736 .31276 Mtetra
0 0 .056 r
.74736 .31276 .74785 .30949 .74954 .3074 .74881 .30725 Mtetra
.923 .962 .783 r
.74881 .30725 .74954 .3074 .75129 .30616 .75048 .30497 Mtetra
.679 .732 .89 r
.75048 .30497 .75129 .30616 .7531 .30559 .75228 .30429 Mtetra
.589 .67 .896 r
.75228 .30429 .7531 .30559 .75491 .30526 .7541 .30402 Mtetra
.59 .684 .906 r
.7541 .30402 .75491 .30526 .75673 .30485 .75593 .30375 Mtetra
.681 .75 .903 r
.75593 .30375 .75673 .30485 .75852 .30411 .75772 .30306 Mtetra
.688 .764 .91 r
.75772 .30306 .75852 .30411 .76031 .30333 .75952 .30235 Mtetra
.692 .779 .918 r
.75952 .30235 .76031 .30333 .7621 .30251 .76131 .30161 Mtetra
.692 .8 .932 r
.76131 .30161 .7621 .30251 .76388 .30165 .76311 .30088 Mtetra
.644 .815 .965 r
.76311 .30088 .76388 .30165 .76569 .30111 .76492 .30032 Mtetra
.502 .746 .983 r
.76492 .30032 .76569 .30111 .76757 .30144 .76676 .30017 Mtetra
.29 .513 .897 r
.76676 .30017 .76757 .30144 .76964 .30411 .76867 .30084 Mtetra
.414 .385 .718 r
.76867 .30084 .76964 .30411 .77275 .32005 .77062 .30202 Mtetra
.53 .342 .57 r
.77062 .30202 .77275 .32005 .78972 .50998 .77258 .30317 Mtetra
.549 .333 .539 r
.77258 .30317 .78972 .50998 .79172 .5102 .77441 .3028 Mtetra
.55 .334 .539 r
.77441 .3028 .79172 .5102 .79362 .50908 .7762 .30186 Mtetra
.551 .334 .539 r
.7762 .30186 .79362 .50908 .79546 .5073 .77797 .3006 Mtetra
.77797 .3006 .79546 .5073 .79733 .5058 .77972 .29925 Mtetra
.549 .333 .539 r
.77972 .29925 .79733 .5058 .79926 .50504 .78154 .29862 Mtetra
.546 .331 .539 r
.78154 .29862 .79926 .50504 .80136 .5063 .78353 .30011 Mtetra
.078 0 .454 r
.78353 .30011 .80136 .5063 .80359 .50911 .80218 .50112 Mtetra
.122 .099 .557 r
.80218 .50112 .80359 .50911 .80573 .51076 .80478 .50837 Mtetra
.168 .295 .751 r
.80478 .50837 .80573 .51076 .80778 .51138 .80695 .51033 Mtetra
.603 .748 .946 r
.80695 .51033 .80778 .51138 .80974 .51079 .80892 .50992 Mtetra
.723 .833 .933 r
.80892 .50992 .80974 .51079 .81167 .50991 .81085 .50899 Mtetra
.747 .828 .915 r
.81085 .50899 .81167 .50991 .8136 .50898 .81277 .50792 Mtetra
.648 .764 .933 r
.81277 .50792 .8136 .50898 .81555 .5084 .81473 .50733 Mtetra
.631 .756 .938 r
.81473 .50733 .81555 .5084 .81752 .50789 .81669 .50682 Mtetra
.578 .731 .947 r
.81669 .50682 .81752 .50789 .81951 .50759 .81868 .5065 Mtetra
.431 .653 .953 r
.81868 .5065 .81951 .50759 .82154 .50776 .82071 .50667 Mtetra
.585 .731 .944 r
.82071 .50667 .82154 .50776 .82353 .50743 .8227 .50634 Mtetra
.806 .808 .853 r
.8227 .50634 .82353 .50743 .82541 .5059 .82458 .5048 Mtetra
.973 .775 .576 r
.82458 .5048 .82541 .5059 .82682 .49921 .82599 .49808 Mtetra
.977 .674 .341 r
.82599 .49808 .82682 .49921 .80987 .29197 .80909 .29081 Mtetra
.959 .778 .616 r
.80909 .29081 .80987 .29197 .81129 .28677 .81051 .28564 Mtetra
.756 .774 .868 r
.81051 .28564 .81129 .28677 .81308 .28565 .8123 .28451 Mtetra
.625 .723 .917 r
.8123 .28451 .81308 .28565 .81493 .28521 .81415 .28406 Mtetra
.58 .701 .925 r
.81415 .28406 .81493 .28521 .8168 .28496 .81603 .2838 Mtetra
.751 .77 .868 r
.81603 .2838 .8168 .28496 .8186 .28386 .81782 .2827 Mtetra
.678 .742 .899 r
.81782 .2827 .8186 .28386 .82043 .28317 .81966 .28201 Mtetra
.405 .605 .929 r
.81966 .28201 .82043 .28317 .82236 .28349 .82159 .28232 Mtetra
.805 .395 0 r
.82159 .28232 .82236 .28349 .82481 .28919 .82403 .28795 Mtetra
.973 .661 .311 r
.82403 .28795 .82481 .28919 .84668 .49496 .84587 .49382 Mtetra
.698 .262 0 r
.84587 .49382 .84668 .49496 .84913 .49913 .84831 .49803 Mtetra
.336 .596 .942 r
.84831 .49803 .84913 .49913 .85121 .49956 .8504 .49846 Mtetra
.666 .768 .926 r
.8504 .49846 .85121 .49956 .85319 .49888 .85238 .49779 Mtetra
.848 .82 .821 r
.85238 .49779 .85319 .49888 .85504 .49693 .85423 .49584 Mtetra
.977 .779 .572 r
.85423 .49584 .85504 .49693 .85642 .49028 .85561 .48918 Mtetra
.976 .67 .326 r
.85561 .48918 .85642 .49028 .83758 .28294 .83682 .28179 Mtetra
.965 .78 .603 r
.83682 .28179 .83758 .28294 .83896 .27753 .83819 .27639 Mtetra
.761 .778 .867 r
.83819 .27639 .83896 .27753 .84075 .27637 .83999 .27523 Mtetra
.63 .727 .918 r
.83999 .27523 .84075 .27637 .84262 .27589 .84186 .27476 Mtetra
.552 .691 .931 r
.84186 .27476 .84262 .27589 .84452 .27572 .84376 .27459 Mtetra
.75 .776 .874 r
.84376 .27459 .84452 .27572 .84633 .27462 .84557 .27349 Mtetra
.682 .753 .905 r
.84557 .27349 .84633 .27462 .84818 .27391 .84742 .27278 Mtetra
.472 .652 .938 r
.84742 .27278 .84818 .27391 .85011 .27399 .84936 .27287 Mtetra
.816 .409 0 r
.84936 .27287 .85011 .27399 .85262 .27945 .85193 .27897 Mtetra
.971 .656 .297 r
.85193 .27897 .85262 .27945 .87648 .48578 .87573 .48516 Mtetra
.739 .256 0 r
.87573 .48516 .87648 .48578 .87899 .48997 .87819 .48881 Mtetra
.937 .808 .693 r
.87819 .48881 .87899 .48997 .88088 .48837 .87985 .48509 Mtetra
.963 .686 .462 r
.87985 .48509 .88088 .48837 .88261 .48522 .87989 .46629 Mtetra
.967 .655 .368 r
.87989 .46629 .88261 .48522 .88414 .48027 .86094 .27278 Mtetra
.172 .145 .585 r
.25795 .46866 .25863 .47351 .2594 .48218 .25918 .47149 Mtetra
.951 .697 .517 r
.25918 .47149 .2594 .48218 .24572 .67178 .24497 .667 Mtetra
.792 .551 0 r
.24497 .667 .24572 .67178 .24701 .67517 .24594 .67426 Mtetra
0 .374 .819 r
.24594 .67426 .24701 .67517 .2486 .67467 .24744 .67503 Mtetra
0 0 0 r
.24744 .67503 .2486 .67467 .25029 .67304 .24903 .67465 Mtetra
.24903 .67465 .25029 .67304 .25211 .66975 .25071 .6732 Mtetra
.755 .808 .329 r
.25071 .6732 .25211 .66975 .26783 .48737 .25268 .66794 Mtetra
0 0 .13 r
.25268 .66794 .26783 .48737 .27073 .46906 .26952 .47094 Mtetra
.993 .878 .579 r
.26952 .47094 .27073 .46906 .27246 .46562 .27147 .46476 Mtetra
.785 .774 .843 r
.27147 .46476 .27246 .46562 .27401 .46463 .27303 .46355 Mtetra
.636 .704 .895 r
.27303 .46355 .27401 .46463 .27552 .46422 .27454 .46316 Mtetra
.513 .662 .928 r
.27454 .46316 .27552 .46422 .277 .46407 .27601 .46314 Mtetra
.66 .741 .91 r
.27601 .46314 .277 .46407 .27853 .46343 .27753 .46265 Mtetra
.673 .778 .929 r
.27753 .46265 .27853 .46343 .28005 .46284 .27904 .4621 Mtetra
.672 .79 .937 r
.27904 .4621 .28005 .46284 .28156 .46244 .28056 .46156 Mtetra
.75 .768 .867 r
.28056 .46156 .28156 .46244 .28303 .46246 .28211 .46061 Mtetra
.665 .608 .782 r
.28211 .46061 .28303 .46246 .28447 .46306 .28364 .45994 Mtetra
.564 .473 .71 r
.28364 .45994 .28447 .46306 .28582 .46488 .28513 .4599 Mtetra
.066 .068 .548 r
.28513 .4599 .28582 .46488 .27361 .65444 .28636 .46336 Mtetra
0 0 .206 r
.28636 .46336 .27361 .65444 .27446 .66447 .27375 .65878 Mtetra
0 0 .306 r
.27375 .65878 .27446 .66447 .27585 .66706 .27488 .66502 Mtetra
.37 .446 .809 r
.27488 .66502 .27585 .66706 .27743 .66711 .27641 .66571 Mtetra
.616 .657 .867 r
.27641 .66571 .27743 .66711 .27905 .66643 .27801 .66538 Mtetra
.705 .741 .879 r
.27801 .66538 .27905 .66643 .2807 .66547 .27965 .66462 Mtetra
.653 .773 .937 r
.27965 .66462 .2807 .66547 .28231 .66513 .28127 .66412 Mtetra
.652 .735 .91 r
.28127 .66412 .28231 .66513 .28392 .66484 .28288 .66362 Mtetra
.656 .699 .877 r
.28288 .66362 .28392 .66484 .28554 .66434 .28451 .6631 Mtetra
.652 .695 .878 r
.28451 .6631 .28554 .66434 .28722 .66289 .28613 .6626 Mtetra
.573 .885 .991 r
.28613 .6626 .28722 .66289 .28895 .66082 .28775 .66211 Mtetra
.254 0 0 r
.28775 .66211 .28895 .66082 .29071 .6583 .28937 .66162 Mtetra
.505 .179 .348 r
.28937 .66162 .29071 .6583 .29233 .65777 .29097 .66156 Mtetra
.487 .174 .36 r
.29097 .66156 .29233 .65777 .29393 .65767 .29258 .66128 Mtetra
.396 .082 .312 r
.29258 .66128 .29393 .65767 .29558 .65674 .29423 .66035 Mtetra
0 0 0 r
.29423 .66035 .29558 .65674 .29796 .64468 .29611 .65607 Mtetra
.957 .705 .513 r
.29611 .65607 .29796 .64468 .31185 .45539 .31053 .45963 Mtetra
.887 .829 .36 r
.31053 .45963 .31185 .45539 .31361 .45149 .31256 .45164 Mtetra
.881 .966 .845 r
.31256 .45164 .31361 .45149 .31519 .45018 .31417 .44993 Mtetra
.61 .899 .987 r
.31417 .44993 .31519 .45018 .31673 .44965 .31571 .44938 Mtetra
.318 .771 .954 r
.31571 .44938 .31673 .44965 .31825 .44942 .31722 .44927 Mtetra
.471 .868 .966 r
.31722 .44927 .31825 .44942 .31978 .44899 .31875 .44888 Mtetra
.522 .896 .964 r
.31875 .44888 .31978 .44899 .32132 .44849 .32029 .44839 Mtetra
.509 .893 .96 r
.32029 .44839 .32132 .44849 .32285 .448 .32183 .44791 Mtetra
.485 .884 .951 r
.32183 .44791 .32285 .448 .32439 .44749 .32336 .44746 Mtetra
.463 .88 .933 r
.32336 .44746 .32439 .44749 .32593 .44699 .3249 .44699 Mtetra
.473 .888 .924 r
.3249 .44699 .32593 .44699 .32747 .44651 .32644 .44648 Mtetra
.581 .929 .949 r
.32644 .44648 .32747 .44651 .32901 .44613 .328 .44584 Mtetra
.682 .909 .974 r
.328 .44584 .32901 .44613 .33054 .44577 .32955 .44515 Mtetra
.703 .826 .94 r
.32955 .44515 .33054 .44577 .33208 .44539 .33111 .44446 Mtetra
.675 .75 .907 r
.33111 .44446 .33208 .44539 .33363 .44485 .33266 .4439 Mtetra
.658 .74 .91 r
.33266 .4439 .33363 .44485 .33518 .44423 .3342 .44341 Mtetra
.648 .768 .936 r
.3342 .44341 .33518 .44423 .33673 .44358 .33575 .44294 Mtetra
.642 .811 .964 r
.33575 .44294 .33673 .44358 .33829 .44301 .33729 .44246 Mtetra
.636 .834 .977 r
.33729 .44246 .33829 .44301 .33984 .44249 .33884 .44198 Mtetra
.634 .844 .981 r
.33884 .44198 .33984 .44249 .34139 .44198 .34039 .44149 Mtetra
.643 .851 .98 r
.34039 .44149 .34139 .44198 .34294 .44135 .34194 .44097 Mtetra
.633 .877 .987 r
.34194 .44097 .34294 .44135 .3445 .44074 .3435 .44043 Mtetra
.622 .891 .988 r
.3435 .44043 .3445 .44074 .34605 .44032 .34505 .43988 Mtetra
.642 .866 .983 r
.34505 .43988 .34605 .44032 .34756 .44056 .34661 .43934 Mtetra
.663 .692 .867 r
.34661 .43934 .34756 .44056 .34904 .44142 .34816 .4388 Mtetra
.628 .537 .733 r
.34816 .4388 .34904 .44142 .3505 .44274 .34972 .43827 Mtetra
.623 .475 .66 r
.34972 .43827 .3505 .44274 .35203 .4427 .3513 .43741 Mtetra
.609 .452 .643 r
.3513 .43741 .35203 .4427 .35361 .44179 .35287 .43663 Mtetra
.576 .431 .646 r
.35287 .43663 .35361 .44179 .35516 .44151 .35441 .43638 Mtetra
.341 .264 .623 r
.35441 .43638 .35516 .44151 .35637 .44774 .35584 .43848 Mtetra
.96 .697 .492 r
.35584 .43848 .35637 .44774 .34805 .64095 .34754 .62996 Mtetra
0 0 .275 r
.34754 .62996 .34805 .64095 .34949 .64473 .34854 .64224 Mtetra
.145 .26 .725 r
.34854 .64224 .34949 .64473 .35108 .6455 .35009 .64384 Mtetra
.578 .606 .844 r
.35009 .64384 .35108 .6455 .35274 .64509 .35173 .64368 Mtetra
.676 .681 .846 r
.35173 .64368 .35274 .64509 .35441 .64431 .3534 .64301 Mtetra
.667 .694 .866 r
.3534 .64301 .35441 .64431 .35608 .64377 .35507 .64242 Mtetra
.644 .678 .867 r
.35507 .64242 .35608 .64377 .35774 .64337 .35674 .64194 Mtetra
.652 .668 .853 r
.35674 .64194 .35774 .64337 .35941 .64278 .3584 .64141 Mtetra
.591 .654 .881 r
.3584 .64141 .35941 .64278 .3611 .64178 .36006 .64117 Mtetra
.529 .799 .995 r
.36006 .64117 .3611 .64178 .36281 .64018 .36171 .64091 Mtetra
0 0 0 r
.36171 .64091 .36281 .64018 .36458 .63758 .3634 .6401 Mtetra
.3634 .6401 .36458 .63758 .36659 .62954 .36519 .63692 Mtetra
.96 .702 .499 r
.36519 .63692 .36659 .62954 .37708 .43454 .37524 .45289 Mtetra
0 0 .112 r
.37524 .45289 .37708 .43454 .37883 .43018 .3778 .43076 Mtetra
.927 .973 .733 r
.3778 .43076 .37883 .43018 .38046 .42844 .37947 .42825 Mtetra
.633 .923 .976 r
.37947 .42825 .38046 .42844 .38203 .42782 .38105 .4276 Mtetra
.325 .785 .944 r
.38105 .4276 .38203 .42782 .3836 .42756 .38261 .42743 Mtetra
.431 .854 .951 r
.38261 .42743 .3836 .42756 .38516 .42732 .38418 .42706 Mtetra
.66 .915 .978 r
.38418 .42706 .38516 .42732 .38673 .42698 .38576 .42639 Mtetra
.694 .839 .953 r
.38576 .42639 .38673 .42698 .3883 .42662 .38735 .42572 Mtetra
.674 .762 .917 r
.38735 .42572 .3883 .42662 .38988 .42612 .38893 .42515 Mtetra
.652 .74 .914 r
.38893 .42515 .38988 .42612 .39146 .42549 .3905 .42467 Mtetra
.644 .771 .941 r
.3905 .42467 .39146 .42549 .39305 .42483 .39208 .4242 Mtetra
.643 .82 .968 r
.39208 .4242 .39305 .42483 .39464 .42414 .39366 .42371 Mtetra
.633 .869 .986 r
.39366 .42371 .39464 .42414 .39622 .42349 .39525 .42317 Mtetra
.612 .891 .989 r
.39525 .42317 .39622 .42349 .3978 .42302 .39683 .42263 Mtetra
.623 .877 .989 r
.39683 .42263 .3978 .42302 .39936 .42311 .39842 .4221 Mtetra
.661 .734 .904 r
.39842 .4221 .39936 .42311 .4009 .42392 .4 .42158 Mtetra
.632 .558 .754 r
.4 .42158 .4009 .42392 .40242 .42522 .40159 .42106 Mtetra
.605 .47 .67 r
.40159 .42106 .40242 .42522 .40395 .42612 .40318 .42051 Mtetra
.593 .437 .639 r
.40318 .42051 .40395 .42612 .40554 .42574 .40477 .41995 Mtetra
.592 .434 .636 r
.40477 .41995 .40554 .42574 .40714 .42489 .40636 .41938 Mtetra
.594 .438 .64 r
.40636 .41938 .40714 .42489 .40874 .4241 .40795 .41882 Mtetra
.594 .442 .645 r
.40795 .41882 .40874 .4241 .41033 .42356 .40954 .41828 Mtetra
.40954 .41828 .41033 .42356 .41193 .42303 .41113 .41775 Mtetra
.593 .441 .645 r
.41113 .41775 .41193 .42303 .41351 .4227 .41273 .41724 Mtetra
.591 .437 .641 r
.41273 .41724 .41351 .4227 .4151 .42251 .41432 .41674 Mtetra
.589 .432 .636 r
.41432 .41674 .4151 .42251 .4167 .42188 .41591 .41623 Mtetra
.59 .434 .638 r
.41591 .41623 .4167 .42188 .41834 .42007 .41751 .41571 Mtetra
.602 .464 .665 r
.41751 .41571 .41834 .42007 .42 .41767 .41911 .41517 Mtetra
.63 .548 .743 r
.41911 .41517 .42 .41767 .42164 .41576 .42071 .41463 Mtetra
.66 .713 .887 r
.42071 .41463 .42164 .41576 .42326 .41453 .4223 .4141 Mtetra
.614 .868 .99 r
.4223 .4141 .42326 .41453 .42486 .41392 .4239 .4136 Mtetra
.591 .886 .991 r
.4239 .4136 .42486 .41392 .42646 .41351 .4255 .41309 Mtetra
.623 .872 .989 r
.4255 .41309 .42646 .41351 .42805 .41315 .4271 .41256 Mtetra
.656 .836 .969 r
.4271 .41256 .42805 .41315 .42965 .41275 .42871 .41201 Mtetra
.669 .799 .944 r
.42871 .41201 .42965 .41275 .43125 .41236 .43031 .41144 Mtetra
.677 .761 .914 r
.43031 .41144 .43125 .41236 .43285 .4119 .43192 .41084 Mtetra
.68 .732 .89 r
.43192 .41084 .43285 .4119 .43446 .41136 .43353 .41023 Mtetra
.671 .715 .882 r
.43353 .41023 .43446 .41136 .43607 .41078 .43514 .40965 Mtetra
.688 .721 .875 r
.43514 .40965 .43607 .41078 .43768 .40999 .43675 .40898 Mtetra
.702 .749 .888 r
.43675 .40898 .43768 .40999 .4393 .40903 .43836 .40826 Mtetra
.563 .761 .971 r
.43836 .40826 .4393 .40903 .44091 .40843 .43996 .40801 Mtetra
.626 .067 0 r
.43996 .40801 .44091 .40843 .44249 .40893 .44152 .40935 Mtetra
.935 .627 .432 r
.44152 .40935 .44249 .40893 .444 .41241 .44277 .42331 Mtetra
.94 .667 .493 r
.44277 .42331 .444 .41241 .44082 .60766 .43963 .61469 Mtetra
.637 .353 .471 r
.43963 .61469 .44082 .60766 .44237 .61381 .44127 .61715 Mtetra
.492 .165 .339 r
.44127 .61715 .44237 .61381 .44407 .61383 .44298 .61698 Mtetra
.408 .08 .294 r
.44298 .61698 .44407 .61383 .4458 .61289 .44471 .61623 Mtetra
.402 .081 .303 r
.44471 .61623 .4458 .61289 .44753 .61163 .44644 .61537 Mtetra
.461 .147 .346 r
.44644 .61537 .44753 .61163 .44926 .61076 .44816 .61486 Mtetra
.47 .163 .363 r
.44816 .61486 .44926 .61076 .45098 .61028 .44988 .61434 Mtetra
.471 .163 .362 r
.44988 .61434 .45098 .61028 .45268 .61082 .4516 .61385 Mtetra
.445 .11 .302 r
.4516 .61385 .45268 .61082 .45436 .61229 .45333 .61338 Mtetra
.224 0 0 r
.45333 .61338 .45436 .61229 .45605 .61334 .45505 .6129 Mtetra
.621 .875 .989 r
.45505 .6129 .45605 .61334 .45776 .61379 .45678 .61232 Mtetra
.679 .68 .844 r
.45678 .61232 .45776 .61379 .45948 .61356 .45851 .61161 Mtetra
.666 .619 .793 r
.45851 .61161 .45948 .61356 .46121 .61312 .46025 .61088 Mtetra
.649 .587 .771 r
.46025 .61088 .46121 .61312 .46294 .61256 .46198 .61022 Mtetra
.628 .569 .768 r
.46198 .61022 .46294 .61256 .46467 .61195 .46371 .6097 Mtetra
.625 .574 .777 r
.46371 .6097 .46467 .61195 .46641 .61131 .46544 .60923 Mtetra
.608 .579 .796 r
.46544 .60923 .46641 .61131 .46814 .61078 .46717 .60889 Mtetra
.563 .576 .825 r
.46717 .60889 .46814 .61078 .46987 .61054 .4689 .60881 Mtetra
.649 .635 .822 r
.4689 .60881 .46987 .61054 .4716 .61 .47064 .60824 Mtetra
.787 .686 .752 r
.47064 .60824 .4716 .61 .47336 .60853 .47239 .60629 Mtetra
.907 .69 .598 r
.47239 .60629 .47336 .60853 .47515 .60415 .47426 .59732 Mtetra
.953 .683 .486 r
.47426 .59732 .47515 .60415 .47958 .41121 .47883 .39821 Mtetra
.646 .437 .585 r
.47883 .39821 .47958 .41121 .48137 .39935 .48051 .39427 Mtetra
.621 .464 .648 r
.48051 .39427 .48137 .39935 .48302 .39809 .48215 .3933 Mtetra
.587 .446 .656 r
.48215 .3933 .48302 .39809 .48465 .39783 .48379 .39291 Mtetra
.573 .434 .654 r
.48379 .39291 .48465 .39783 .48628 .3979 .48542 .39271 Mtetra
.595 .445 .647 r
.48542 .39271 .48628 .3979 .48792 .39736 .48706 .39217 Mtetra
.594 .444 .647 r
.48706 .39217 .48792 .39736 .48956 .39684 .48869 .39163 Mtetra
.48869 .39163 .48956 .39684 .4912 .3963 .49033 .3911 Mtetra
.595 .445 .647 r
.49033 .3911 .4912 .3963 .49284 .39573 .49197 .39054 Mtetra
.595 .445 .648 r
.49197 .39054 .49284 .39573 .49449 .39515 .49362 .38999 Mtetra
.596 .446 .648 r
.49362 .38999 .49449 .39515 .49613 .39456 .49526 .38943 Mtetra
.596 .446 .649 r
.49526 .38943 .49613 .39456 .49778 .39399 .4969 .38887 Mtetra
.596 .447 .649 r
.4969 .38887 .49778 .39399 .49942 .39342 .49855 .38832 Mtetra
.49855 .38832 .49942 .39342 .50107 .39285 .50019 .38776 Mtetra
.596 .447 .65 r
.50019 .38776 .50107 .39285 .50272 .39228 .50184 .3872 Mtetra
.50184 .3872 .50272 .39228 .50437 .39171 .50348 .38665 Mtetra
.596 .448 .65 r
.50348 .38665 .50437 .39171 .50602 .39115 .50513 .38609 Mtetra
.50513 .38609 .50602 .39115 .50767 .39059 .50678 .38554 Mtetra
.50678 .38554 .50767 .39059 .50932 .39004 .50843 .38498 Mtetra
.596 .448 .651 r
.50843 .38498 .50932 .39004 .51097 .38948 .51008 .38443 Mtetra
.51008 .38443 .51097 .38948 .51263 .38893 .51174 .38388 Mtetra
.51174 .38388 .51263 .38893 .51428 .38838 .51339 .38333 Mtetra
.51339 .38333 .51428 .38838 .51594 .38783 .51504 .38277 Mtetra
.51504 .38277 .51594 .38783 .51759 .38728 .5167 .38222 Mtetra
.596 .448 .65 r
.5167 .38222 .51759 .38728 .51925 .38674 .51836 .38167 Mtetra
.51836 .38167 .51925 .38674 .52091 .3862 .52001 .38112 Mtetra
.596 .447 .65 r
.52001 .38112 .52091 .3862 .52257 .38566 .52167 .38057 Mtetra
.52167 .38057 .52257 .38566 .52423 .38512 .52333 .38002 Mtetra
.595 .447 .65 r
.52333 .38002 .52423 .38512 .52589 .38459 .52499 .37948 Mtetra
.595 .446 .65 r
.52499 .37948 .52589 .38459 .52755 .38406 .52665 .37893 Mtetra
.595 .446 .649 r
.52665 .37893 .52755 .38406 .52922 .38353 .52831 .37838 Mtetra
.52831 .37838 .52922 .38353 .53088 .38301 .52998 .37784 Mtetra
.595 .445 .648 r
.52998 .37784 .53088 .38301 .53255 .3825 .53164 .37729 Mtetra
.594 .444 .648 r
.53164 .37729 .53255 .3825 .53422 .38199 .53331 .37675 Mtetra
.594 .444 .647 r
.53331 .37675 .53422 .38199 .53588 .38147 .53497 .3762 Mtetra
.594 .443 .647 r
.53497 .3762 .53588 .38147 .53755 .38094 .53664 .37565 Mtetra
.594 .443 .646 r
.53664 .37565 .53755 .38094 .53922 .3804 .53831 .3751 Mtetra
.53831 .3751 .53922 .3804 .54089 .37985 .53998 .37454 Mtetra
.595 .444 .646 r
.53998 .37454 .54089 .37985 .54257 .37926 .54165 .37396 Mtetra
.54165 .37396 .54257 .37926 .54424 .37868 .54332 .37339 Mtetra
.54332 .37339 .54424 .37868 .54591 .37811 .54499 .37283 Mtetra
.619 .46 .645 r
.54499 .37283 .54591 .37811 .54758 .37681 .54666 .37185 Mtetra
.602 .454 .653 r
.54666 .37185 .54758 .37681 .54926 .37611 .54834 .37122 Mtetra
.557 .425 .656 r
.54834 .37122 .54926 .37611 .55094 .37655 .55002 .37123 Mtetra
.135 .125 .581 r
.55002 .37123 .55094 .37655 .5543 .56997 .55173 .37522 Mtetra
0 0 .359 r
.55173 .37522 .5543 .56997 .55619 .58117 .55521 .57621 Mtetra
0 0 .471 r
.55521 .57621 .55619 .58117 .55801 .584 .55706 .58191 Mtetra
.498 .523 .813 r
.55706 .58191 .55801 .584 .55981 .58416 .55886 .58218 Mtetra
.649 .613 .8 r
.55886 .58218 .55981 .58416 .5616 .5837 .56065 .58156 Mtetra
.69 .619 .771 r
.56065 .58156 .5616 .5837 .5634 .58293 .56244 .58055 Mtetra
.612 .561 .772 r
.56244 .58055 .5634 .58293 .56519 .58226 .56424 .58015 Mtetra
.608 .58 .796 r
.56424 .58015 .56519 .58226 .56699 .58156 .56603 .57979 Mtetra
.615 .62 .832 r
.56603 .57979 .56699 .58156 .56878 .58084 .56783 .57942 Mtetra
.641 .677 .869 r
.56783 .57942 .56878 .58084 .57058 .5804 .56963 .57892 Mtetra
.648 .672 .859 r
.56963 .57892 .57058 .5804 .57238 .57991 .57143 .57837 Mtetra
.651 .666 .851 r
.57143 .57837 .57238 .57991 .57418 .5792 .57324 .5778 Mtetra
.652 .687 .87 r
.57324 .5778 .57418 .5792 .57597 .57756 .57504 .57725 Mtetra
.56 .891 .986 r
.57504 .57725 .57597 .57756 .57774 .57536 .57684 .57669 Mtetra
.271 0 .003 r
.57684 .57669 .57774 .57536 .57951 .57272 .57865 .57614 Mtetra
.503 .175 .344 r
.57865 .57614 .57951 .57272 .58132 .57228 .58046 .57606 Mtetra
.481 .165 .354 r
.58046 .57606 .58132 .57228 .58313 .57209 .58227 .5757 Mtetra
.398 .088 .319 r
.58227 .5757 .58313 .57209 .58492 .57102 .58407 .57466 Mtetra
0 0 .055 r
.58407 .57466 .58492 .57102 .58644 .55441 .58581 .56998 Mtetra
.984 .708 .41 r
.58581 .56998 .58644 .55441 .58468 .36421 .58389 .3682 Mtetra
0 0 0 r
.58389 .3682 .58468 .36421 .58631 .36037 .58546 .36042 Mtetra
.866 .989 .833 r
.58546 .36042 .58631 .36037 .588 .35921 .58713 .35865 Mtetra
.692 .867 .965 r
.58713 .35865 .588 .35921 .5897 .35881 .58883 .35792 Mtetra
.59 .752 .955 r
.58883 .35792 .5897 .35881 .59141 .35871 .59053 .3576 Mtetra
.65 .725 .904 r
.59053 .3576 .59141 .35871 .59311 .35829 .59224 .35709 Mtetra
.653 .709 .889 r
.59224 .35709 .59311 .35829 .59481 .35775 .59394 .35657 Mtetra
.648 .71 .893 r
.59394 .35657 .59481 .35775 .59652 .35716 .59564 .35607 Mtetra
.658 .731 .903 r
.59564 .35607 .59652 .35716 .59821 .35635 .59735 .35552 Mtetra
.659 .791 .945 r
.59735 .35552 .59821 .35635 .59991 .35558 .59906 .35496 Mtetra
.648 .841 .974 r
.59906 .35496 .59991 .35558 .60162 .35502 .60076 .35438 Mtetra
.652 .839 .972 r
.60076 .35438 .60162 .35502 .60335 .35529 .60247 .3538 Mtetra
.658 .663 .843 r
.60247 .3538 .60335 .35529 .60509 .35617 .60418 .35322 Mtetra
.624 .525 .721 r
.60418 .35322 .60509 .35617 .60685 .35752 .60589 .35263 Mtetra
.622 .469 .653 r
.60589 .35263 .60685 .35752 .60857 .3571 .60759 .35167 Mtetra
.606 .45 .644 r
.60759 .35167 .60857 .3571 .61027 .35616 .60929 .35089 Mtetra
.571 .429 .648 r
.60929 .35089 .61027 .35616 .612 .35599 .61102 .35069 Mtetra
.315 .254 .627 r
.61102 .35069 .612 .35599 .61402 .36649 .61282 .3534 Mtetra
.982 .695 .386 r
.61282 .3534 .61402 .36649 .6213 .56084 .6202 .55328 Mtetra
0 0 .455 r
.6202 .55328 .6213 .56084 .62324 .56423 .62229 .56183 Mtetra
.326 .392 .777 r
.62229 .56183 .62324 .56423 .62511 .56482 .62417 .56299 Mtetra
.594 .605 .832 r
.62417 .56299 .62511 .56482 .62695 .56438 .62601 .56273 Mtetra
.675 .664 .831 r
.62601 .56273 .62695 .56438 .62877 .56341 .62785 .56198 Mtetra
.594 .66 .884 r
.62785 .56198 .62877 .56341 .63059 .56215 .62969 .56169 Mtetra
.515 .845 .998 r
.62969 .56169 .63059 .56215 .63239 .56036 .63154 .56131 Mtetra
0 0 0 r
.63154 .56131 .63239 .56036 .63415 .55743 .63336 .56027 Mtetra
.63336 .56027 .63415 .55743 .63562 .54575 .63509 .55628 Mtetra
.982 .7 .401 r
.63509 .55628 .63562 .54575 .63091 .34917 .6303 .3556 Mtetra
0 0 .087 r
.6303 .3556 .63091 .34917 .63251 .34514 .6317 .34541 Mtetra
.87 .994 .757 r
.6317 .34541 .63251 .34514 .63421 .34361 .63338 .34333 Mtetra
.595 .91 .98 r
.63338 .34333 .63421 .34361 .63593 .34299 .6351 .3427 Mtetra
.344 .789 .958 r
.6351 .3427 .63593 .34299 .63767 .34272 .63685 .34251 Mtetra
.506 .888 .964 r
.63685 .34251 .63767 .34272 .63941 .34239 .63858 .342 Mtetra
.668 .909 .978 r
.63858 .342 .63941 .34239 .64114 .34199 .6403 .34126 Mtetra
.694 .829 .948 r
.6403 .34126 .64114 .34199 .64288 .34157 .64203 .34054 Mtetra
.671 .753 .912 r
.64203 .34054 .64288 .34157 .64461 .34098 .64376 .33993 Mtetra
.655 .743 .914 r
.64376 .33993 .64461 .34098 .64634 .34028 .6455 .33939 Mtetra
.648 .777 .942 r
.6455 .33939 .64634 .34028 .64807 .33955 .64723 .33886 Mtetra
.653 .828 .967 r
.64723 .33886 .64807 .33955 .6498 .33878 .64897 .33827 Mtetra
.643 .875 .984 r
.64897 .33827 .6498 .33878 .65153 .33807 .65071 .33765 Mtetra
.627 .891 .987 r
.65071 .33765 .65153 .33807 .65327 .33757 .65244 .33703 Mtetra
.731 .89 .952 r
.65244 .33703 .65327 .33757 .65503 .33746 .65417 .33613 Mtetra
.703 .71 .853 r
.65417 .33613 .65503 .33746 .65681 .33791 .6559 .3353 Mtetra
.596 .529 .749 r
.6559 .3353 .65681 .33791 .65863 .33934 .65765 .33501 Mtetra
.35 .302 .662 r
.65765 .33501 .65863 .33934 .66073 .34703 .6595 .33701 Mtetra
.98 .688 .371 r
.6595 .33701 .66073 .34703 .67112 .54546 .66968 .53184 Mtetra
0 0 .45 r
.66968 .53184 .67112 .54546 .67317 .54908 .6722 .54627 Mtetra
.259 .319 .735 r
.6722 .54627 .67317 .54908 .6751 .54991 .67416 .54799 Mtetra
.581 .59 .827 r
.67416 .54799 .6751 .54991 .67697 .54954 .67605 .5478 Mtetra
.67 .654 .826 r
.67605 .5478 .67697 .54954 .67883 .54859 .67791 .54707 Mtetra
.615 .657 .868 r
.67791 .54707 .67883 .54859 .68066 .54731 .67979 .54668 Mtetra
.512 .804 .998 r
.67979 .54668 .68066 .54731 .68248 .54556 .68168 .5464 Mtetra
0 0 0 r
.68168 .5464 .68248 .54556 .68425 .54275 .68353 .54547 Mtetra
0 0 .04 r
.68353 .54547 .68425 .54275 .68574 .53441 .68527 .54192 Mtetra
.981 .694 .386 r
.68527 .54192 .68574 .53441 .67795 .33454 .67748 .341 Mtetra
0 0 .069 r
.67748 .341 .67795 .33454 .67951 .33001 .6787 .32949 Mtetra
.935 .87 .749 r
.6787 .32949 .67951 .33001 .68119 .32783 .68035 .32674 Mtetra
.737 .765 .875 r
.68035 .32674 .68119 .32783 .68292 .32675 .68209 .32576 Mtetra
.513 .698 .953 r
.68209 .32576 .68292 .32675 .68469 .32649 .68387 .32569 Mtetra
0 .023 .52 r
.68387 .32569 .68469 .32649 .68658 .32834 .68575 .32749 Mtetra
.952 .6 .253 r
.68575 .32749 .68658 .32834 .6982 .51784 .68815 .33924 Mtetra
0 0 .395 r
.68815 .33924 .6982 .51784 .70124 .53961 .70029 .53736 Mtetra
.022 .209 .717 r
.70029 .53736 .70124 .53961 .70326 .54154 .70233 .53958 Mtetra
.563 .577 .826 r
.70233 .53958 .70326 .54154 .70515 .54119 .70424 .53949 Mtetra
.661 .657 .835 r
.70424 .53949 .70515 .54119 .70701 .54008 .70612 .53881 Mtetra
.628 .707 .903 r
.70612 .53881 .70701 .54008 .70886 .53873 .70802 .53835 Mtetra
.41 .816 .98 r
.70802 .53835 .70886 .53873 .71069 .53717 .70992 .53808 Mtetra
.043 0 0 r
.70992 .53808 .71069 .53717 .71248 .5347 .7118 .53724 Mtetra
0 0 .079 r
.7118 .53724 .71248 .5347 .71401 .52781 .71357 .53435 Mtetra
0 0 .049 r
.71357 .53435 .71401 .52781 .70444 .32616 .71478 .52179 Mtetra
.007 0 .413 r
.71478 .52179 .70444 .32616 .70596 .32125 .70524 .32207 Mtetra
.846 .918 .522 r
.70524 .32207 .70596 .32125 .70765 .31928 .70687 .31887 Mtetra
.741 .929 .952 r
.70687 .31887 .70765 .31928 .70942 .31867 .70862 .31787 Mtetra
.623 .795 .965 r
.70862 .31787 .70942 .31867 .71122 .31846 .7104 .3174 Mtetra
.624 .733 .925 r
.7104 .3174 .71122 .31846 .71301 .3181 .71218 .31697 Mtetra
.664 .734 .902 r
.71218 .31697 .71301 .3181 .71478 .31741 .71396 .31637 Mtetra
.655 .75 .92 r
.71396 .31637 .71478 .31741 .71655 .31685 .71574 .31582 Mtetra
.702 .768 .903 r
.71574 .31582 .71655 .31685 .71835 .31659 .71751 .31504 Mtetra
.704 .681 .826 r
.71751 .31504 .71835 .31659 .72018 .31681 .71927 .31413 Mtetra
.612 .535 .744 r
.71927 .31413 .72018 .31681 .72206 .31784 .72106 .31368 Mtetra
.442 .37 .68 r
.72106 .31368 .72206 .31784 .72417 .3224 .72295 .3149 Mtetra
0 0 .482 r
.72295 .3149 .72417 .3224 .73887 .52374 .72533 .3237 Mtetra
.03 0 .431 r
.72533 .3237 .73887 .52374 .74111 .52831 .7401 .52494 Mtetra
.165 .226 .681 r
.7401 .52494 .74111 .52831 .74314 .52947 .74222 .52763 Mtetra
.553 .587 .841 r
.74222 .52763 .74314 .52947 .74505 .52897 .74417 .52757 Mtetra
.666 .704 .876 r
.74417 .52757 .74505 .52897 .74694 .52802 .74608 .52691 Mtetra
.687 .765 .911 r
.74608 .52691 .74694 .52802 .74885 .52723 .74798 .52616 Mtetra
.638 .753 .932 r
.74798 .52616 .74885 .52723 .75078 .52693 .74991 .52562 Mtetra
.651 .713 .893 r
.74991 .52562 .75078 .52693 .75271 .52648 .75182 .52504 Mtetra
.615 .676 .884 r
.75182 .52504 .75271 .52648 .75461 .52562 .75376 .52465 Mtetra
.545 .736 .964 r
.75376 .52465 .75461 .52562 .75646 .52407 .7557 .52442 Mtetra
0 0 0 r
.7557 .52442 .75646 .52407 .75825 .52161 .75761 .5237 Mtetra
0 0 .041 r
.75761 .5237 .75825 .52161 .7598 .51578 .75941 .52131 Mtetra
0 0 .119 r
.75941 .52131 .7598 .51578 .74736 .31276 .76071 .51184 Mtetra
.03 0 .426 r
.76071 .51184 .74736 .31276 .74881 .30725 .74816 .30842 Mtetra
.784 .843 .385 r
.74816 .30842 .74881 .30725 .75048 .30497 .74973 .30461 Mtetra
.756 .947 .942 r
.74973 .30461 .75048 .30497 .75228 .30429 .7515 .30351 Mtetra
.634 .808 .966 r
.7515 .30351 .75228 .30429 .7541 .30402 .7533 .30298 Mtetra
.608 .733 .934 r
.7533 .30298 .7541 .30402 .75593 .30375 .75512 .3026 Mtetra
.658 .732 .904 r
.75512 .3026 .75593 .30375 .75772 .30306 .75693 .30202 Mtetra
.648 .751 .924 r
.75693 .30202 .75772 .30306 .75952 .30235 .75874 .30148 Mtetra
.642 .79 .953 r
.75874 .30148 .75952 .30235 .76131 .30161 .76055 .30094 Mtetra
.636 .839 .978 r
.76055 .30094 .76131 .30161 .76311 .30088 .76236 .30037 Mtetra
.612 .873 .991 r
.76236 .30037 .76311 .30088 .76492 .30032 .76417 .29979 Mtetra
.615 .871 .99 r
.76417 .29979 .76492 .30032 .76676 .30017 .76598 .29921 Mtetra
.656 .774 .936 r
.76598 .29921 .76676 .30017 .76867 .30084 .76779 .29864 Mtetra
.638 .584 .777 r
.76779 .29864 .76867 .30084 .77062 .30202 .7696 .29804 Mtetra
.61 .483 .683 r
.7696 .29804 .77062 .30202 .77258 .30317 .77141 .29742 Mtetra
.596 .44 .641 r
.77141 .29742 .77258 .30317 .77441 .3028 .77322 .29674 Mtetra
.594 .435 .636 r
.77322 .29674 .77441 .3028 .7762 .30186 .77503 .29606 Mtetra
.602 .444 .639 r
.77503 .29606 .7762 .30186 .77797 .3006 .77683 .29526 Mtetra
.619 .461 .646 r
.77683 .29526 .77797 .3006 .77972 .29925 .77861 .29423 Mtetra
.598 .453 .655 r
.77861 .29423 .77972 .29925 .78154 .29862 .78043 .29362 Mtetra
.52 .402 .659 r
.78043 .29362 .78154 .29862 .78353 .30011 .78234 .29416 Mtetra
.132 .126 .583 r
.78234 .29416 .78353 .30011 .80218 .50112 .78465 .29943 Mtetra
.055 0 .447 r
.78465 .29943 .80218 .50112 .80478 .50837 .80369 .50416 Mtetra
.082 .138 .623 r
.80369 .50416 .80478 .50837 .80695 .51033 .80603 .50825 Mtetra
.531 .551 .82 r
.80603 .50825 .80695 .51033 .80892 .50992 .80805 .50835 Mtetra
.653 .676 .859 r
.80805 .50835 .80892 .50992 .81085 .50899 .81 .50774 Mtetra
.7 .747 .889 r
.81 .50774 .81085 .50899 .81277 .50792 .81194 .50689 Mtetra
.624 .761 .944 r
.81194 .50689 .81277 .50792 .81473 .50733 .81391 .50639 Mtetra
.633 .786 .955 r
.81391 .50639 .81473 .50733 .81669 .50682 .81588 .50584 Mtetra
.621 .774 .954 r
.81588 .50584 .81669 .50682 .81868 .5065 .81785 .50535 Mtetra
.554 .702 .939 r
.81785 .50535 .81868 .5065 .82071 .50667 .81985 .50514 Mtetra
.662 .688 .863 r
.81985 .50514 .82071 .50667 .8227 .50634 .8218 .50447 Mtetra
.786 .698 .767 r
.8218 .50447 .8227 .50634 .82458 .5048 .82365 .50257 Mtetra
.94 .713 .567 r
.82365 .50257 .82458 .5048 .82599 .49808 .82494 .49441 Mtetra
.976 .672 .349 r
.82494 .49441 .82599 .49808 .80909 .29081 .80825 .28898 Mtetra
.906 .725 .647 r
.80825 .28898 .80909 .29081 .81051 .28564 .80973 .2845 Mtetra
.75 .773 .872 r
.80973 .2845 .81051 .28564 .8123 .28451 .81153 .28342 Mtetra
.629 .736 .925 r
.81153 .28342 .8123 .28451 .81415 .28406 .81338 .28295 Mtetra
.591 .714 .929 r
.81338 .28295 .81415 .28406 .81603 .2838 .81525 .28264 Mtetra
.754 .77 .866 r
.81525 .28264 .81603 .2838 .81782 .2827 .81704 .28152 Mtetra
.681 .74 .896 r
.81704 .28152 .81782 .2827 .81966 .28201 .81888 .28081 Mtetra
.418 .606 .925 r
.81888 .28081 .81966 .28201 .82159 .28232 .8208 .2811 Mtetra
.79 .382 0 r
.8208 .2811 .82159 .28232 .82403 .28795 .82324 .28659 Mtetra
.973 .661 .311 r
.82324 .28659 .82403 .28795 .84587 .49382 .84504 .49263 Mtetra
.694 .263 0 r
.84504 .49263 .84587 .49382 .84831 .49803 .8475 .49692 Mtetra
.333 .593 .94 r
.8475 .49692 .84831 .49803 .8504 .49846 .84959 .49737 Mtetra
.665 .767 .926 r
.84959 .49737 .8504 .49846 .85238 .49779 .85156 .4967 Mtetra
.848 .82 .821 r
.85156 .4967 .85238 .49779 .85423 .49584 .85342 .49475 Mtetra
.977 .779 .571 r
.85342 .49475 .85423 .49584 .85561 .48918 .8548 .48807 Mtetra
.976 .67 .326 r
.8548 .48807 .85561 .48918 .83682 .28179 .83605 .28064 Mtetra
.965 .78 .604 r
.83605 .28064 .83682 .28179 .83819 .27639 .83742 .27525 Mtetra
.761 .778 .867 r
.83742 .27525 .83819 .27639 .83999 .27523 .83922 .27409 Mtetra
.629 .727 .918 r
.83922 .27409 .83999 .27523 .84186 .27476 .8411 .27362 Mtetra
.551 .69 .932 r
.8411 .27362 .84186 .27476 .84376 .27459 .843 .27345 Mtetra
.749 .776 .875 r
.843 .27345 .84376 .27459 .84557 .27349 .84481 .27236 Mtetra
.681 .752 .905 r
.84481 .27236 .84557 .27349 .84742 .27278 .84666 .27166 Mtetra
.469 .65 .938 r
.84666 .27166 .84742 .27278 .84936 .27287 .8486 .27176 Mtetra
.838 .437 0 r
.8486 .27176 .84936 .27287 .85193 .27897 .85123 .27847 Mtetra
.971 .656 .297 r
.85123 .27847 .85193 .27897 .87573 .48516 .87497 .48445 Mtetra
.673 .185 0 r
.87497 .48445 .87573 .48516 .87819 .48881 .87738 .48767 Mtetra
.976 .782 .578 r
.87738 .48767 .87819 .48881 .87985 .48509 .87877 .4813 Mtetra
.974 .666 .321 r
.87877 .4813 .87985 .48509 .87989 .46629 .85836 .27271 Mtetra
.557 .339 .539 r
.85836 .27271 .87989 .46629 .86094 .27278 .85974 .26752 Mtetra
.796 .366 0 r
.25699 .46724 .25795 .46866 .25918 .47149 .25825 .46981 Mtetra
.938 .684 .525 r
.25825 .46981 .25918 .47149 .24497 .667 .244 .66488 Mtetra
.968 .654 .357 r
.244 .66488 .24497 .667 .24594 .67426 .24488 .67338 Mtetra
0 .226 .691 r
.24488 .67338 .24594 .67426 .24744 .67503 .24636 .67436 Mtetra
.53 .777 .988 r
.24636 .67436 .24744 .67503 .24903 .67465 .24793 .67414 Mtetra
.807 .854 .885 r
.24793 .67414 .24903 .67465 .25071 .6732 .2496 .67287 Mtetra
.93 .779 .672 r
.2496 .67287 .25071 .6732 .25268 .66794 .25155 .66795 Mtetra
.938 .688 .532 r
.25155 .66795 .25268 .66794 .26952 .47094 .26847 .47063 Mtetra
.936 .752 .63 r
.26847 .47063 .26952 .47094 .27147 .46476 .27048 .46378 Mtetra
.779 .752 .828 r
.27048 .46378 .27147 .46476 .27303 .46355 .27204 .46255 Mtetra
.63 .717 .91 r
.27204 .46255 .27303 .46355 .27454 .46316 .27355 .46217 Mtetra
.483 .667 .944 r
.27355 .46217 .27454 .46316 .27601 .46314 .27502 .4622 Mtetra
.645 .736 .915 r
.27502 .4622 .27601 .46314 .27753 .46265 .27653 .46177 Mtetra
.664 .754 .917 r
.27653 .46177 .27753 .46265 .27904 .4621 .27805 .46126 Mtetra
.677 .765 .917 r
.27805 .46126 .27904 .4621 .28056 .46156 .27957 .4607 Mtetra
.761 .773 .863 r
.27957 .4607 .28056 .46156 .28211 .46061 .28112 .45968 Mtetra
.729 .757 .875 r
.28112 .45968 .28211 .46061 .28364 .45994 .28267 .45885 Mtetra
.631 .702 .897 r
.28267 .45885 .28364 .45994 .28513 .4599 .28417 .45848 Mtetra
0 .117 .664 r
.28417 .45848 .28513 .4599 .28636 .46336 .28555 .4599 Mtetra
0 0 .241 r
.28555 .4599 .28636 .46336 .27375 .65878 .28672 .46436 Mtetra
0 0 .224 r
.28672 .46436 .27375 .65878 .27488 .66502 .2743 .65745 Mtetra
.194 .124 .544 r
.2743 .65745 .27488 .66502 .27641 .66571 .27557 .66176 Mtetra
.333 .296 .667 r
.27557 .66176 .27641 .66571 .27801 .66538 .27703 .66337 Mtetra
.375 .452 .812 r
.27703 .66337 .27801 .66538 .27965 .66462 .27857 .66403 Mtetra
.473 .776 .997 r
.27857 .66403 .27965 .66462 .28127 .66412 .28016 .66388 Mtetra
.563 .891 .986 r
.28016 .66388 .28127 .66412 .28288 .66362 .28178 .66338 Mtetra
.646 .912 .98 r
.28178 .66338 .28288 .66362 .28451 .6631 .28342 .66272 Mtetra
.601 .87 .993 r
.28342 .66272 .28451 .6631 .28613 .6626 .28504 .66222 Mtetra
.58 .866 .995 r
.28504 .66222 .28613 .6626 .28775 .66211 .28666 .66177 Mtetra
.57 .872 .995 r
.28666 .66177 .28775 .66211 .28937 .66162 .28828 .66131 Mtetra
.383 .802 .975 r
.28828 .66131 .28937 .66162 .29097 .66156 .28989 .66112 Mtetra
.537 .839 .999 r
.28989 .66112 .29097 .66156 .29258 .66128 .2915 .66078 Mtetra
.716 .864 .952 r
.2915 .66078 .29258 .66128 .29423 .66035 .29315 .65999 Mtetra
.907 .835 .763 r
.29315 .65999 .29423 .66035 .29611 .65607 .29492 .65729 Mtetra
.99 .864 .614 r
.29492 .65729 .29611 .65607 .31053 .45963 .29691 .65136 Mtetra
0 0 .219 r
.29691 .65136 .31053 .45963 .31256 .45164 .31113 .45749 Mtetra
.186 0 .302 r
.31113 .45749 .31256 .45164 .31417 .44993 .31286 .45413 Mtetra
.467 .169 .375 r
.31286 .45413 .31417 .44993 .31571 .44938 .3144 .45359 Mtetra
.554 .251 .409 r
.3144 .45359 .31571 .44938 .31722 .44927 .31588 .45394 Mtetra
.509 .216 .404 r
.31588 .45394 .31722 .44927 .31875 .44888 .3174 .45375 Mtetra
.49 .201 .402 r
.3174 .45375 .31875 .44888 .32029 .44839 .31894 .45331 Mtetra
.491 .203 .404 r
.31894 .45331 .32029 .44839 .32183 .44791 .32048 .45288 Mtetra
.539 .249 .422 r
.32048 .45288 .32183 .44791 .32336 .44746 .32198 .45304 Mtetra
.527 .245 .43 r
.32198 .45304 .32336 .44746 .3249 .44699 .3235 .453 Mtetra
.445 .175 .409 r
.3235 .453 .3249 .44699 .32644 .44648 .32509 .45184 Mtetra
.12 0 .262 r
.32509 .45184 .32644 .44648 .328 .44584 .32681 .44835 Mtetra
0 0 0 r
.32681 .44835 .328 .44584 .32955 .44515 .3285 .44544 Mtetra
.911 .965 .802 r
.3285 .44544 .32955 .44515 .33111 .44446 .33014 .44337 Mtetra
.748 .734 .84 r
.33014 .44337 .33111 .44446 .33266 .4439 .33172 .44235 Mtetra
.654 .638 .822 r
.33172 .44235 .33266 .4439 .3342 .44341 .33327 .44181 Mtetra
.617 .618 .829 r
.33327 .44181 .3342 .44341 .33575 .44294 .3348 .44148 Mtetra
.618 .637 .847 r
.3348 .44148 .33575 .44294 .33729 .44246 .33634 .44115 Mtetra
.62 .66 .867 r
.33634 .44115 .33729 .44246 .33884 .44198 .33788 .44081 Mtetra
.621 .686 .89 r
.33788 .44081 .33884 .44198 .34039 .44149 .33942 .44047 Mtetra
.64 .722 .908 r
.33942 .44047 .34039 .44149 .34194 .44097 .34097 .44005 Mtetra
.659 .749 .916 r
.34097 .44005 .34194 .44097 .3435 .44043 .34252 .43955 Mtetra
.675 .761 .916 r
.34252 .43955 .3435 .44043 .34505 .43988 .34408 .43898 Mtetra
.697 .762 .902 r
.34408 .43898 .34505 .43988 .34661 .43934 .34564 .43831 Mtetra
.704 .738 .878 r
.34564 .43831 .34661 .43934 .34816 .4388 .34721 .4376 Mtetra
.695 .704 .854 r
.34721 .4376 .34816 .4388 .34972 .43827 .34878 .43689 Mtetra
.706 .682 .824 r
.34878 .43689 .34972 .43827 .3513 .43741 .35035 .43605 Mtetra
.691 .68 .834 r
.35035 .43605 .3513 .43741 .35287 .43663 .35192 .43533 Mtetra
.62 .663 .87 r
.35192 .43533 .35287 .43663 .35441 .43638 .35347 .43499 Mtetra
.105 .372 .834 r
.35347 .43499 .35441 .43638 .35584 .43848 .35495 .43592 Mtetra
0 0 .383 r
.35495 .43592 .35584 .43848 .34754 .62996 .35632 .43919 Mtetra
0 0 .261 r
.35632 .43919 .34754 .62996 .34854 .64224 .34799 .63189 Mtetra
.09 .029 .487 r
.34799 .63189 .34854 .64224 .35009 .64384 .34925 .63918 Mtetra
.325 .272 .643 r
.34925 .63918 .35009 .64384 .35173 .64368 .35078 .64119 Mtetra
.379 .41 .767 r
.35078 .64119 .35173 .64368 .3534 .64301 .35238 .64205 Mtetra
.458 .681 .961 r
.35238 .64205 .3534 .64301 .35507 .64242 .35402 .6421 Mtetra
.545 .871 .993 r
.35402 .6421 .35507 .64242 .35674 .64194 .35568 .64166 Mtetra
.635 .907 .983 r
.35568 .64166 .35674 .64194 .3584 .64141 .35735 .64101 Mtetra
.534 .849 .998 r
.35735 .64101 .3584 .64141 .36006 .64117 .35901 .64063 Mtetra
.531 .816 .998 r
.35901 .64063 .36006 .64117 .36171 .64091 .36067 .64034 Mtetra
.684 .849 .962 r
.36067 .64034 .36171 .64091 .3634 .6401 .36235 .63966 Mtetra
.885 .857 .809 r
.36235 .63966 .3634 .6401 .36519 .63692 .36409 .63754 Mtetra
.982 .87 .649 r
.36409 .63754 .36519 .63692 .37524 .45289 .36597 .63269 Mtetra
0 0 .224 r
.36597 .63269 .37524 .45289 .3778 .43076 .37642 .43929 Mtetra
.059 0 .298 r
.37642 .43929 .3778 .43076 .37947 .42825 .37826 .43295 Mtetra
.487 .195 .396 r
.37826 .43295 .37947 .42825 .38105 .4276 .37983 .4325 Mtetra
.528 .236 .415 r
.37983 .4325 .38105 .4276 .38261 .42743 .38139 .43251 Mtetra
.279 .019 .328 r
.38139 .43251 .38261 .42743 .38418 .42706 .38305 .43011 Mtetra
0 0 .009 r
.38305 .43011 .38418 .42706 .38576 .42639 .38474 .42703 Mtetra
.875 .99 .734 r
.38474 .42703 .38576 .42639 .38735 .42572 .38639 .42485 Mtetra
.777 .784 .858 r
.38639 .42485 .38735 .42572 .38893 .42515 .38799 .4237 Mtetra
.638 .649 .845 r
.38799 .4237 .38893 .42515 .3905 .42467 .38957 .42327 Mtetra
.592 .637 .865 r
.38957 .42327 .3905 .42467 .39208 .4242 .39114 .42304 Mtetra
.607 .685 .898 r
.39114 .42304 .39208 .4242 .39366 .42371 .39271 .42274 Mtetra
.65 .74 .916 r
.39271 .42274 .39366 .42371 .39525 .42317 .39429 .42227 Mtetra
.664 .758 .92 r
.39429 .42227 .39525 .42317 .39683 .42263 .39588 .42173 Mtetra
.687 .766 .912 r
.39588 .42173 .39683 .42263 .39842 .4221 .39747 .42111 Mtetra
.7 .749 .889 r
.39747 .42111 .39842 .4221 .4 .42158 .39906 .4204 Mtetra
.695 .713 .863 r
.39906 .4204 .4 .42158 .40159 .42106 .40066 .4197 Mtetra
.677 .678 .843 r
.40066 .4197 .40159 .42106 .40318 .42051 .40225 .41905 Mtetra
.661 .658 .836 r
.40225 .41905 .40318 .42051 .40477 .41995 .40384 .41849 Mtetra
.657 .656 .837 r
.40384 .41849 .40477 .41995 .40636 .41938 .40543 .41794 Mtetra
.656 .659 .841 r
.40543 .41794 .40636 .41938 .40795 .41882 .40702 .41741 Mtetra
.657 .662 .843 r
.40702 .41741 .40795 .41882 .40954 .41828 .40861 .41687 Mtetra
.656 .662 .844 r
.40861 .41687 .40954 .41828 .41113 .41775 .41021 .41633 Mtetra
.41021 .41633 .41113 .41775 .41273 .41724 .4118 .4158 Mtetra
.655 .659 .841 r
.4118 .4158 .41273 .41724 .41432 .41674 .41339 .41527 Mtetra
.65 .653 .839 r
.41339 .41527 .41432 .41674 .41591 .41623 .41499 .41476 Mtetra
.637 .647 .843 r
.41499 .41476 .41591 .41623 .41751 .41571 .41658 .41432 Mtetra
.624 .653 .859 r
.41658 .41432 .41751 .41571 .41911 .41517 .41817 .41396 Mtetra
.623 .682 .885 r
.41817 .41396 .41911 .41517 .42071 .41463 .41977 .41359 Mtetra
.634 .722 .911 r
.41977 .41359 .42071 .41463 .4223 .4141 .42136 .41318 Mtetra
.654 .753 .922 r
.42136 .41318 .4223 .4141 .4239 .4136 .42296 .41268 Mtetra
.669 .758 .918 r
.42296 .41268 .4239 .4136 .4255 .41309 .42456 .41212 Mtetra
.686 .753 .902 r
.42456 .41212 .4255 .41309 .4271 .41256 .42617 .41149 Mtetra
.698 .734 .879 r
.42617 .41149 .4271 .41256 .42871 .41201 .42778 .41078 Mtetra
.693 .706 .857 r
.42778 .41078 .42871 .41201 .43031 .41144 .42939 .41006 Mtetra
.692 .683 .837 r
.42939 .41006 .43031 .41144 .43192 .41084 .431 .40932 Mtetra
.685 .66 .82 r
.431 .40932 .43192 .41084 .43353 .41023 .43261 .40858 Mtetra
.648 .63 .818 r
.43261 .40858 .43353 .41023 .43514 .40965 .43422 .40806 Mtetra
.559 .596 .847 r
.43422 .40806 .43514 .40965 .43675 .40898 .43581 .40799 Mtetra
.099 .458 .887 r
.43581 .40799 .43675 .40898 .43836 .40826 .43739 .40868 Mtetra
.762 .306 .167 r
.43739 .40868 .43836 .40826 .43996 .40801 .43894 .4105 Mtetra
.853 .535 .449 r
.43894 .4105 .43996 .40801 .44152 .40935 .44034 .41813 Mtetra
.943 .671 .491 r
.44034 .41813 .44152 .40935 .44277 .42331 .43698 .61195 Mtetra
.554 .332 .533 r
.43698 .61195 .44277 .42331 .43963 .61469 .43859 .61554 Mtetra
.656 .197 .151 r
.43859 .61554 .43963 .61469 .44127 .61715 .44027 .61668 Mtetra
.496 .824 1 r
.44027 .61668 .44127 .61715 .44298 .61698 .44198 .61639 Mtetra
.676 .851 .966 r
.44198 .61639 .44298 .61698 .44471 .61623 .4437 .61572 Mtetra
.669 .869 .975 r
.4437 .61572 .44471 .61623 .44644 .61537 .44543 .61504 Mtetra
.479 .847 .989 r
.44543 .61504 .44644 .61537 .44816 .61486 .44715 .61469 Mtetra
.415 .845 .949 r
.44715 .61469 .44816 .61486 .44988 .61434 .44887 .61432 Mtetra
.362 .83 .891 r
.44887 .61432 .44988 .61434 .4516 .61385 .45059 .6139 Mtetra
.367 .836 .863 r
.45059 .6139 .4516 .61385 .45333 .61338 .45232 .6134 Mtetra
.53 .918 .916 r
.45232 .6134 .45333 .61338 .45505 .6129 .45405 .6127 Mtetra
.786 .951 .926 r
.45405 .6127 .45505 .6129 .45678 .61232 .45579 .61148 Mtetra
.867 .803 .785 r
.45579 .61148 .45678 .61232 .45851 .61161 .45755 .60924 Mtetra
.806 .652 .692 r
.45755 .60924 .45851 .61161 .46025 .61088 .45933 .60617 Mtetra
.738 .552 .643 r
.45933 .60617 .46025 .61088 .46198 .61022 .46112 .60272 Mtetra
.608 .433 .62 r
.46112 .60272 .46198 .61022 .46371 .6097 .46286 .60156 Mtetra
.561 .394 .613 r
.46286 .60156 .46371 .6097 .46544 .60923 .46458 .60145 Mtetra
.537 .38 .615 r
.46458 .60145 .46544 .60923 .46717 .60889 .46629 .60184 Mtetra
.535 .385 .623 r
.46629 .60184 .46717 .60889 .4689 .60881 .46801 .60223 Mtetra
.588 .427 .631 r
.46801 .60223 .4689 .60881 .47064 .60824 .46974 .60166 Mtetra
.706 .51 .621 r
.46974 .60166 .47064 .60824 .47239 .60629 .47153 .59799 Mtetra
.951 .681 .488 r
.47153 .59799 .47239 .60629 .47426 .59732 .47623 .40101 Mtetra
.559 .341 .54 r
.47623 .40101 .47426 .59732 .47883 .39821 .47794 .39537 Mtetra
.763 .606 .683 r
.47794 .39537 .47883 .39821 .48051 .39427 .4796 .39282 Mtetra
.701 .679 .826 r
.4796 .39282 .48051 .39427 .48215 .3933 .48124 .39199 Mtetra
.637 .676 .87 r
.48124 .39199 .48215 .3933 .48379 .39291 .48287 .39155 Mtetra
.61 .656 .87 r
.48287 .39155 .48379 .39291 .48542 .39271 .48451 .39124 Mtetra
.655 .658 .841 r
.48451 .39124 .48542 .39271 .48706 .39217 .48615 .39069 Mtetra
.654 .657 .841 r
.48615 .39069 .48706 .39217 .48869 .39163 .48779 .39015 Mtetra
.654 .657 .84 r
.48779 .39015 .48869 .39163 .49033 .3911 .48942 .38961 Mtetra
.656 .657 .839 r
.48942 .38961 .49033 .3911 .49197 .39054 .49107 .38906 Mtetra
.49107 .38906 .49197 .39054 .49362 .38999 .49271 .38851 Mtetra
.656 .658 .84 r
.49271 .38851 .49362 .38999 .49526 .38943 .49435 .38795 Mtetra
.49435 .38795 .49526 .38943 .4969 .38887 .49599 .3874 Mtetra
.49599 .3874 .4969 .38887 .49855 .38832 .49764 .38684 Mtetra
.656 .659 .841 r
.49764 .38684 .49855 .38832 .50019 .38776 .49929 .38629 Mtetra
.49929 .38629 .50019 .38776 .50184 .3872 .50093 .38573 Mtetra
.50093 .38573 .50184 .3872 .50348 .38665 .50258 .38518 Mtetra
.656 .66 .842 r
.50258 .38518 .50348 .38665 .50513 .38609 .50423 .38462 Mtetra
.50423 .38462 .50513 .38609 .50678 .38554 .50588 .38407 Mtetra
.50588 .38407 .50678 .38554 .50843 .38498 .50753 .38351 Mtetra
.50753 .38351 .50843 .38498 .51008 .38443 .50918 .38296 Mtetra
.50918 .38296 .51008 .38443 .51174 .38388 .51083 .38241 Mtetra
.51083 .38241 .51174 .38388 .51339 .38333 .51249 .38185 Mtetra
.655 .66 .842 r
.51249 .38185 .51339 .38333 .51504 .38277 .51414 .3813 Mtetra
.51414 .3813 .51504 .38277 .5167 .38222 .5158 .38075 Mtetra
.5158 .38075 .5167 .38222 .51836 .38167 .51745 .3802 Mtetra
.655 .659 .842 r
.51745 .3802 .51836 .38167 .52001 .38112 .51911 .37964 Mtetra
.51911 .37964 .52001 .38112 .52167 .38057 .52077 .37909 Mtetra
.52077 .37909 .52167 .38057 .52333 .38002 .52243 .37854 Mtetra
.52243 .37854 .52333 .38002 .52499 .37948 .52409 .37799 Mtetra
.654 .658 .841 r
.52409 .37799 .52499 .37948 .52665 .37893 .52575 .37744 Mtetra
.52575 .37744 .52665 .37893 .52831 .37838 .52742 .37689 Mtetra
.654 .657 .841 r
.52742 .37689 .52831 .37838 .52998 .37784 .52908 .37634 Mtetra
.654 .657 .84 r
.52908 .37634 .52998 .37784 .53164 .37729 .53074 .37579 Mtetra
.654 .656 .84 r
.53074 .37579 .53164 .37729 .53331 .37675 .53241 .37524 Mtetra
.654 .656 .839 r
.53241 .37524 .53331 .37675 .53497 .3762 .53408 .37469 Mtetra
.654 .655 .839 r
.53408 .37469 .53497 .3762 .53664 .37565 .53574 .37414 Mtetra
.654 .655 .838 r
.53574 .37414 .53664 .37565 .53831 .3751 .53741 .37358 Mtetra
.655 .655 .838 r
.53741 .37358 .53831 .3751 .53998 .37454 .53908 .37302 Mtetra
.657 .656 .837 r
.53908 .37302 .53998 .37454 .54165 .37396 .54075 .37245 Mtetra
.657 .656 .838 r
.54075 .37245 .54165 .37396 .54332 .37339 .54243 .37188 Mtetra
.656 .657 .839 r
.54243 .37188 .54332 .37339 .54499 .37283 .5441 .37132 Mtetra
.698 .674 .823 r
.5441 .37132 .54499 .37283 .54666 .37185 .54577 .37048 Mtetra
.668 .681 .853 r
.54577 .37048 .54666 .37185 .54834 .37122 .54744 .36986 Mtetra
.576 .645 .882 r
.54744 .36986 .54834 .37122 .55002 .37123 .54912 .36968 Mtetra
0 .096 .652 r
.54912 .36968 .55002 .37123 .55173 .37522 .55082 .3716 Mtetra
0 0 .302 r
.55082 .3716 .55173 .37522 .55521 .57621 .55255 .37742 Mtetra
0 0 .372 r
.55255 .37742 .55521 .57621 .55706 .58191 .55605 .57433 Mtetra
.525 .374 .619 r
.55605 .57433 .55706 .58191 .55886 .58218 .55785 .57495 Mtetra
.598 .428 .623 r
.55785 .57495 .55886 .58218 .56065 .58156 .55964 .57407 Mtetra
.594 .424 .62 r
.55964 .57407 .56065 .58156 .56244 .58055 .56143 .57324 Mtetra
.391 .282 .609 r
.56143 .57324 .56244 .58055 .56424 .58015 .56326 .57592 Mtetra
.353 .311 .672 r
.56326 .57592 .56424 .58015 .56603 .57979 .56508 .57776 Mtetra
.299 .412 .81 r
.56508 .57776 .56603 .57979 .56783 .57942 .5669 .57878 Mtetra
.488 .785 .997 r
.5669 .57878 .56783 .57942 .56963 .57892 .5687 .57858 Mtetra
.573 .89 .988 r
.5687 .57858 .56963 .57892 .57143 .57837 .5705 .57801 Mtetra
.645 .91 .981 r
.5705 .57801 .57143 .57837 .57324 .5778 .5723 .57729 Mtetra
.603 .861 .992 r
.5723 .57729 .57324 .5778 .57504 .57725 .57411 .57675 Mtetra
.588 .862 .994 r
.57411 .57675 .57504 .57725 .57684 .57669 .57591 .57625 Mtetra
.577 .869 .995 r
.57591 .57625 .57684 .57669 .57865 .57614 .57772 .57574 Mtetra
.409 .805 .986 r
.57772 .57574 .57865 .57614 .58046 .57606 .57953 .57552 Mtetra
.555 .839 .998 r
.57953 .57552 .58046 .57606 .58227 .5757 .58134 .57511 Mtetra
.718 .874 .954 r
.58134 .57511 .58227 .5757 .58407 .57466 .58315 .57424 Mtetra
.926 .877 .768 r
.58315 .57424 .58407 .57466 .58581 .56998 .58492 .57153 Mtetra
.948 .879 .472 r
.58492 .57153 .58581 .56998 .58389 .3682 .58664 .56581 Mtetra
0 0 .37 r
.58664 .56581 .58389 .3682 .58546 .36042 .58471 .36622 Mtetra
0 0 .25 r
.58471 .36622 .58546 .36042 .58713 .35865 .58632 .36056 Mtetra
0 0 0 r
.58632 .36056 .58713 .35865 .58883 .35792 .58798 .35796 Mtetra
.848 .991 .847 r
.58798 .35796 .58883 .35792 .59053 .3576 .58966 .35631 Mtetra
.716 .714 .848 r
.58966 .35631 .59053 .3576 .59224 .35709 .59135 .35542 Mtetra
.645 .633 .823 r
.59135 .35542 .59224 .35709 .59394 .35657 .59305 .35488 Mtetra
.613 .616 .83 r
.59305 .35488 .59394 .35657 .59564 .35607 .59476 .35453 Mtetra
.621 .64 .848 r
.59476 .35453 .59564 .35607 .59735 .35552 .59647 .35415 Mtetra
.626 .667 .87 r
.59647 .35415 .59735 .35552 .59906 .35496 .59818 .35375 Mtetra
.636 .7 .892 r
.59818 .35375 .59906 .35496 .60076 .35438 .59989 .3533 Mtetra
.683 .742 .896 r
.59989 .3533 .60076 .35438 .60247 .3538 .6016 .35264 Mtetra
.698 .731 .876 r
.6016 .35264 .60247 .3538 .60418 .35322 .6033 .35188 Mtetra
.693 .701 .853 r
.6033 .35188 .60418 .35322 .60589 .35263 .60501 .35112 Mtetra
.706 .681 .823 r
.60501 .35112 .60589 .35263 .60759 .35167 .60671 .35022 Mtetra
.684 .68 .84 r
.60671 .35022 .60759 .35167 .60929 .35089 .60842 .34949 Mtetra
.607 .655 .871 r
.60842 .34949 .60929 .35089 .61102 .35069 .61014 .34917 Mtetra
.122 .358 .82 r
.61014 .34917 .61102 .35069 .61282 .3534 .6119 .35035 Mtetra
0 0 .528 r
.6119 .35035 .61282 .3534 .6202 .55328 .61374 .3542 Mtetra
0 0 .395 r
.61374 .3542 .6202 .55328 .62229 .56183 .62114 .55284 Mtetra
.242 .165 .565 r
.62114 .55284 .62229 .56183 .62417 .56299 .62315 .55848 Mtetra
.378 .322 .668 r
.62315 .55848 .62417 .56299 .62601 .56273 .62506 .5603 Mtetra
.422 .449 .783 r
.62506 .5603 .62601 .56273 .62785 .56198 .62693 .56104 Mtetra
.4 .667 .968 r
.62693 .56104 .62785 .56198 .62969 .56169 .62879 .56119 Mtetra
.523 .838 .999 r
.62879 .56119 .62969 .56169 .63154 .56131 .63064 .56082 Mtetra
.731 .906 .956 r
.63064 .56082 .63154 .56131 .63336 .56027 .63247 .55985 Mtetra
.927 .89 .774 r
.63247 .55985 .63336 .56027 .63509 .55628 .63424 .55721 Mtetra
.983 .883 .53 r
.63424 .55721 .63509 .55628 .6303 .3556 .63592 .5516 Mtetra
0 0 .387 r
.63592 .5516 .6303 .3556 .6317 .34541 .63111 .35219 Mtetra
.244 .027 .372 r
.63111 .35219 .6317 .34541 .63338 .34333 .63272 .34803 Mtetra
.494 .201 .397 r
.63272 .34803 .63338 .34333 .6351 .3427 .63446 .34763 Mtetra
.518 .225 .408 r
.63446 .34763 .6351 .3427 .63685 .34251 .63621 .34752 Mtetra
.255 .011 .339 r
.63621 .34752 .63685 .34251 .63858 .342 .63785 .34456 Mtetra
0 0 .057 r
.63785 .34456 .63858 .342 .6403 .34126 .6395 .34155 Mtetra
.871 .992 .745 r
.6395 .34155 .6403 .34126 .64203 .34054 .64118 .33941 Mtetra
.745 .756 .861 r
.64118 .33941 .64203 .34054 .64376 .33993 .64289 .33837 Mtetra
.633 .645 .844 r
.64289 .33837 .64376 .33993 .6455 .33939 .64463 .33791 Mtetra
.596 .64 .865 r
.64463 .33791 .6455 .33939 .64723 .33886 .64638 .33765 Mtetra
.626 .7 .898 r
.64638 .33765 .64723 .33886 .64897 .33827 .64812 .33723 Mtetra
.66 .747 .914 r
.64812 .33723 .64897 .33827 .65071 .33765 .64986 .33666 Mtetra
.674 .763 .918 r
.64986 .33666 .65071 .33765 .65244 .33703 .6516 .33604 Mtetra
.738 .781 .888 r
.6516 .33604 .65244 .33703 .65417 .33613 .65332 .33509 Mtetra
.736 .771 .881 r
.65332 .33509 .65417 .33613 .6559 .3353 .65505 .33413 Mtetra
.66 .721 .894 r
.65505 .33413 .6559 .3353 .65765 .33501 .65679 .33356 Mtetra
.282 .474 .87 r
.65679 .33356 .65765 .33501 .6595 .33701 .65859 .33433 Mtetra
0 .057 .608 r
.65859 .33433 .6595 .33701 .66968 .53184 .66049 .33745 Mtetra
0 0 .408 r
.66049 .33745 .66968 .53184 .6722 .54627 .67083 .53438 Mtetra
.208 .127 .539 r
.67083 .53438 .6722 .54627 .67416 .54799 .67308 .54268 Mtetra
.397 .318 .65 r
.67308 .54268 .67416 .54799 .67605 .5478 .67506 .54468 Mtetra
.451 .423 .736 r
.67506 .54468 .67605 .5478 .67791 .54707 .67699 .5455 Mtetra
.415 .548 .881 r
.67699 .5455 .67791 .54707 .67979 .54668 .67891 .54593 Mtetra
.434 .735 .99 r
.67891 .54593 .67979 .54668 .68168 .5464 .68081 .5459 Mtetra
.693 .9 .971 r
.68081 .5459 .68168 .5464 .68353 .54547 .68267 .54505 Mtetra
.958 .871 .709 r
.68267 .54505 .68353 .54547 .68527 .54192 .68441 .54156 Mtetra
.976 .686 .405 r
.68441 .54156 .68527 .54192 .67748 .341 .67667 .3407 Mtetra
.986 .749 .491 r
.67667 .3407 .67748 .341 .6787 .32949 .67785 .32806 Mtetra
.86 .741 .731 r
.67785 .32806 .6787 .32949 .68035 .32674 .67951 .3254 Mtetra
.697 .708 .856 r
.67951 .3254 .68035 .32674 .68209 .32576 .68125 .3246 Mtetra
.512 .659 .926 r
.68125 .3246 .68209 .32576 .68387 .32569 .68304 .32459 Mtetra
.07 .408 .86 r
.68304 .32459 .68387 .32569 .68575 .32749 .68488 .32557 Mtetra
0 .001 .578 r
.68488 .32557 .68575 .32749 .68815 .33924 .68681 .32842 Mtetra
.98 .686 .353 r
.68681 .32842 .68815 .33924 .70029 .53736 .6987 .52264 Mtetra
.166 .089 .518 r
.6987 .52264 .70029 .53736 .70233 .53958 .70121 .53406 Mtetra
.369 .296 .643 r
.70121 .53406 .70233 .53958 .70424 .53949 .70325 .53646 Mtetra
.416 .407 .741 r
.70325 .53646 .70424 .53949 .70612 .53881 .70523 .53749 Mtetra
.417 .592 .916 r
.70523 .53749 .70612 .53881 .70802 .53835 .70716 .53781 Mtetra
.456 .799 .998 r
.70716 .53781 .70802 .53835 .70992 .53808 .70908 .53758 Mtetra
.676 .899 .976 r
.70908 .53758 .70992 .53808 .7118 .53724 .71096 .53678 Mtetra
.884 .921 .843 r
.71096 .53678 .7118 .53724 .71357 .53435 .71277 .53481 Mtetra
.971 .92 .595 r
.71277 .53481 .71357 .53435 .71478 .52179 .71446 .53062 Mtetra
.865 .681 .151 r
.71446 .53062 .71478 .52179 .70524 .32207 .71478 .50246 Mtetra
.021 0 .417 r
.71478 .50246 .70524 .32207 .70687 .31887 .70628 .32185 Mtetra
0 0 .146 r
.70628 .32185 .70687 .31887 .70862 .31787 .70789 .31854 Mtetra
.642 .893 .56 r
.70789 .31854 .70862 .31787 .7104 .3174 .70959 .31656 Mtetra
.774 .829 .895 r
.70959 .31656 .7104 .3174 .71218 .31697 .71133 .31542 Mtetra
.646 .657 .846 r
.71133 .31542 .71218 .31697 .71396 .31637 .71311 .31488 Mtetra
.609 .647 .863 r
.71311 .31488 .71396 .31637 .71574 .31582 .71491 .31455 Mtetra
.669 .711 .879 r
.71491 .31455 .71574 .31582 .71751 .31504 .71668 .31391 Mtetra
.736 .762 .873 r
.71668 .31391 .71751 .31504 .71927 .31413 .71844 .31293 Mtetra
.677 .727 .887 r
.71844 .31293 .71927 .31413 .72106 .31368 .72022 .31226 Mtetra
.431 .566 .889 r
.72022 .31226 .72106 .31368 .72295 .3149 .72206 .3126 Mtetra
0 .16 .682 r
.72206 .3126 .72295 .3149 .72533 .3237 .72404 .31508 Mtetra
0 0 .292 r
.72404 .31508 .72533 .3237 .7401 .52494 .72684 .33028 Mtetra
.044 0 .436 r
.72684 .33028 .7401 .52494 .74222 .52763 .74105 .52183 Mtetra
.368 .292 .638 r
.74105 .52183 .74222 .52763 .74417 .52757 .74317 .52442 Mtetra
.418 .402 .735 r
.74317 .52442 .74417 .52757 .74608 .52691 .74519 .52549 Mtetra
.467 .604 .904 r
.74519 .52549 .74608 .52691 .74798 .52616 .74716 .52569 Mtetra
.519 .852 .996 r
.74716 .52569 .74798 .52616 .74991 .52562 .74909 .52526 Mtetra
.594 .906 .983 r
.74909 .52526 .74991 .52562 .75182 .52504 .751 .52459 Mtetra
.57 .875 .994 r
.751 .52459 .75182 .52504 .75376 .52465 .75293 .52403 Mtetra
.5 .807 1 r
.75293 .52403 .75376 .52465 .7557 .52442 .75487 .52375 Mtetra
.64 .849 .98 r
.75487 .52375 .7557 .52442 .75761 .5237 .75679 .52312 Mtetra
.843 .91 .881 r
.75679 .52312 .75761 .5237 .75941 .52131 .75864 .52149 Mtetra
.975 .923 .632 r
.75864 .52149 .75941 .52131 .76071 .51184 .76034 .51759 Mtetra
0 0 .015 r
.76034 .51759 .76071 .51184 .74816 .30842 .76141 .50497 Mtetra
.043 0 .431 r
.76141 .50497 .74816 .30842 .74973 .30461 .74925 .30796 Mtetra
.005 0 .202 r
.74925 .30796 .74973 .30461 .7515 .30351 .75084 .30439 Mtetra
0 0 0 r
.75084 .30439 .7515 .30351 .7533 .30298 .75253 .30229 Mtetra
.808 .877 .897 r
.75253 .30229 .7533 .30298 .75512 .3026 .75428 .30098 Mtetra
.672 .661 .831 r
.75428 .30098 .75512 .3026 .75693 .30202 .75608 .30026 Mtetra
.628 .623 .826 r
.75608 .30026 .75693 .30202 .75874 .30148 .75789 .2998 Mtetra
.611 .624 .839 r
.75789 .2998 .75874 .30148 .76055 .30094 .75972 .29944 Mtetra
.62 .654 .862 r
.75972 .29944 .76055 .30094 .76236 .30037 .76154 .29904 Mtetra
.623 .683 .886 r
.76154 .29904 .76236 .30037 .76417 .29979 .76336 .29863 Mtetra
.647 .724 .905 r
.76336 .29863 .76417 .29979 .76598 .29921 .76518 .29809 Mtetra
.691 .751 .898 r
.76518 .29809 .76598 .29921 .76779 .29864 .76698 .29735 Mtetra
.695 .723 .871 r
.76698 .29735 .76779 .29864 .7696 .29804 .76878 .29657 Mtetra
.684 .688 .847 r
.76878 .29657 .7696 .29804 .77141 .29742 .77058 .2958 Mtetra
.666 .66 .835 r
.77058 .2958 .77141 .29742 .77322 .29674 .77239 .29513 Mtetra
.663 .658 .835 r
.77239 .29513 .77322 .29674 .77503 .29606 .7742 .29446 Mtetra
.676 .667 .834 r
.7742 .29446 .77503 .29606 .77683 .29526 .776 .29372 Mtetra
.705 .688 .831 r
.776 .29372 .77683 .29526 .77861 .29423 .77779 .2928 Mtetra
.665 .686 .86 r
.77779 .2928 .77861 .29423 .78043 .29362 .77961 .29216 Mtetra
.512 .606 .884 r
.77961 .29216 .78043 .29362 .78234 .29416 .78149 .29223 Mtetra
.051 .25 .746 r
.78149 .29223 .78234 .29416 .78465 .29943 .78352 .29419 Mtetra
0 .004 .533 r
.78352 .29419 .78465 .29943 .80369 .50416 .78592 .30051 Mtetra
.073 0 .453 r
.78592 .30051 .80369 .50416 .80603 .50825 .80468 .50094 Mtetra
.372 .277 .617 r
.80468 .50094 .80603 .50825 .80805 .50835 .80696 .50424 Mtetra
.438 .379 .693 r
.80696 .50424 .80805 .50835 .81 .50774 .80907 .50551 Mtetra
.484 .509 .808 r
.80907 .50551 .81 .50774 .81194 .50689 .81112 .5059 Mtetra
.53 .73 .966 r
.81112 .5059 .81194 .50689 .81391 .50639 .81312 .50572 Mtetra
.632 .853 .984 r
.81312 .50572 .81391 .50639 .81588 .50584 .81507 .50509 Mtetra
.754 .87 .932 r
.81507 .50509 .81588 .50584 .81785 .50535 .81699 .50399 Mtetra
.807 .766 .814 r
.81699 .50399 .81785 .50535 .81985 .50514 .81886 .50226 Mtetra
.778 .627 .692 r
.81886 .50226 .81985 .50514 .8218 .50447 .82064 .49954 Mtetra
.802 .587 .611 r
.82064 .49954 .8218 .50447 .82365 .50257 .82214 .49384 Mtetra
.974 .669 .365 r
.82214 .49384 .82365 .50257 .82494 .49441 .80592 .29166 Mtetra
.558 .339 .539 r
.80592 .29166 .82494 .49441 .80825 .28898 .8073 .28597 Mtetra
.767 .608 .681 r
.8073 .28597 .80825 .28898 .80973 .2845 .80895 .28336 Mtetra
.721 .762 .885 r
.80895 .28336 .80973 .2845 .81153 .28342 .81076 .28245 Mtetra
.636 .767 .942 r
.81076 .28245 .81153 .28342 .81338 .28295 .81261 .28194 Mtetra
.631 .754 .936 r
.81261 .28194 .81338 .28295 .81525 .28264 .81447 .28145 Mtetra
.771 .77 .853 r
.81447 .28145 .81525 .28264 .81704 .28152 .81625 .2802 Mtetra
.7 .722 .867 r
.81625 .2802 .81704 .28152 .81888 .28081 .81807 .27937 Mtetra
.492 .599 .888 r
.81807 .27937 .81888 .28081 .8208 .2811 .81999 .27951 Mtetra
.67 .288 0 r
.81999 .27951 .8208 .2811 .82324 .28659 .82236 .28442 Mtetra
.973 .662 .308 r
.82236 .28442 .82324 .28659 .84504 .49263 .84419 .49111 Mtetra
.652 .255 0 r
.84419 .49111 .84504 .49263 .8475 .49692 .84668 .4958 Mtetra
.324 .584 .937 r
.84668 .4958 .8475 .49692 .84959 .49737 .84877 .49628 Mtetra
.664 .769 .928 r
.84877 .49628 .84959 .49737 .85156 .4967 .85075 .49561 Mtetra
.849 .822 .821 r
.85075 .49561 .85156 .4967 .85342 .49475 .85261 .49365 Mtetra
.977 .779 .571 r
.85261 .49365 .85342 .49475 .8548 .48807 .85399 .48697 Mtetra
.976 .67 .326 r
.85399 .48697 .8548 .48807 .83605 .28064 .83528 .27949 Mtetra
.965 .78 .604 r
.83528 .27949 .83605 .28064 .83742 .27525 .83666 .2741 Mtetra
.76 .778 .867 r
.83666 .2741 .83742 .27525 .83922 .27409 .83846 .27294 Mtetra
.629 .727 .918 r
.83846 .27294 .83922 .27409 .8411 .27362 .84033 .27247 Mtetra
.55 .69 .932 r
.84033 .27247 .8411 .27362 .843 .27345 .84224 .27231 Mtetra
.749 .776 .875 r
.84224 .27231 .843 .27345 .84481 .27236 .84405 .27123 Mtetra
.68 .751 .905 r
.84405 .27123 .84481 .27236 .84666 .27166 .8459 .27052 Mtetra
.467 .648 .937 r
.8459 .27052 .84666 .27166 .8486 .27176 .84784 .27063 Mtetra
.844 .445 0 r
.84784 .27063 .8486 .27176 .85123 .27847 .8505 .27756 Mtetra
.971 .656 .296 r
.8505 .27756 .85123 .27847 .87497 .48445 .87419 .48349 Mtetra
.582 .119 0 r
.87419 .48349 .87497 .48445 .87738 .48767 .87659 .4866 Mtetra
.982 .779 .556 r
.87659 .4866 .87738 .48767 .87877 .4813 .87791 .47958 Mtetra
.974 .666 .314 r
.87791 .47958 .87877 .4813 .85836 .27271 .85751 .27069 Mtetra
.909 .717 .631 r
.85751 .27069 .85836 .27271 .85974 .26752 .85893 .26585 Mtetra
.875 .436 .098 r
.25598 .46643 .25699 .46724 .25825 .46981 .25723 .46905 Mtetra
.937 .682 .526 r
.25723 .46905 .25825 .46981 .244 .66488 .24291 .6643 Mtetra
.933 .618 .421 r
.24291 .6643 .244 .66488 .24488 .67338 .24381 .6725 Mtetra
0 .258 .718 r
.24381 .6725 .24488 .67338 .24636 .67436 .24529 .67343 Mtetra
.581 .731 .946 r
.24529 .67343 .24636 .67436 .24793 .67414 .24687 .67317 Mtetra
.784 .763 .834 r
.24687 .67317 .24793 .67414 .2496 .67287 .24854 .67186 Mtetra
.899 .732 .666 r
.24854 .67186 .2496 .67287 .25155 .66795 .2505 .66678 Mtetra
.937 .686 .533 r
.2505 .66678 .25155 .66795 .26847 .47063 .2675 .46931 Mtetra
.898 .707 .635 r
.2675 .46931 .26847 .47063 .27048 .46378 .26949 .46278 Mtetra
.775 .747 .828 r
.26949 .46278 .27048 .46378 .27204 .46255 .27105 .46157 Mtetra
.626 .721 .915 r
.27105 .46157 .27204 .46255 .27355 .46217 .27256 .46121 Mtetra
.472 .667 .948 r
.27256 .46121 .27355 .46217 .27502 .4622 .27403 .46125 Mtetra
.637 .731 .916 r
.27403 .46125 .27502 .4622 .27653 .46177 .27554 .46084 Mtetra
.656 .742 .913 r
.27554 .46084 .27653 .46177 .27805 .46126 .27705 .46036 Mtetra
.669 .752 .913 r
.27705 .46036 .27805 .46126 .27957 .4607 .27857 .45983 Mtetra
.734 .77 .882 r
.27857 .45983 .27957 .4607 .28112 .45968 .28011 .45899 Mtetra
.726 .808 .916 r
.28011 .45899 .28112 .45968 .28267 .45885 .28165 .45822 Mtetra
.664 .814 .956 r
.28165 .45822 .28267 .45885 .28417 .45848 .28317 .45769 Mtetra
.42 .691 .975 r
.28317 .45769 .28417 .45848 .28555 .4599 .28465 .45775 Mtetra
.378 .424 .783 r
.28465 .45775 .28555 .4599 .28672 .46436 .28609 .45846 Mtetra
.377 .275 .61 r
.28609 .45846 .28672 .46436 .2743 .65745 .28743 .46049 Mtetra
0 0 .242 r
.28743 .46049 .2743 .65745 .27557 .66176 .27527 .65032 Mtetra
0 0 .37 r
.27527 .65032 .27557 .66176 .27703 .66337 .27612 .66041 Mtetra
0 .016 .574 r
.27612 .66041 .27703 .66337 .27857 .66403 .27752 .66302 Mtetra
.387 .633 .952 r
.27752 .66302 .27857 .66403 .28016 .66388 .27909 .66323 Mtetra
.644 .815 .965 r
.27909 .66323 .28016 .66388 .28178 .66338 .28071 .66272 Mtetra
.726 .826 .927 r
.28071 .66272 .28178 .66338 .28342 .66272 .28236 .6619 Mtetra
.668 .783 .935 r
.28236 .6619 .28342 .66272 .28504 .66222 .28398 .66133 Mtetra
.654 .763 .93 r
.28398 .66133 .28504 .66222 .28666 .66177 .28561 .66082 Mtetra
.654 .751 .921 r
.28561 .66082 .28666 .66177 .28828 .66131 .28723 .66032 Mtetra
.612 .728 .928 r
.28723 .66032 .28828 .66131 .28989 .66112 .28885 .65997 Mtetra
.632 .703 .898 r
.28885 .65997 .28989 .66112 .2915 .66078 .29047 .65956 Mtetra
.676 .706 .87 r
.29047 .65956 .2915 .66078 .29315 .65999 .29211 .65893 Mtetra
.793 .753 .817 r
.29211 .65893 .29315 .65999 .29492 .65729 .2938 .65746 Mtetra
.906 .948 .819 r
.2938 .65746 .29492 .65729 .29691 .65136 .29553 .65537 Mtetra
.123 0 .203 r
.29553 .65537 .29691 .65136 .31113 .45749 .2973 .65282 Mtetra
.544 .325 .532 r
.2973 .65282 .31113 .45749 .31286 .45413 .29899 .65141 Mtetra
.546 .326 .532 r
.29899 .65141 .31286 .45413 .3144 .45359 .30061 .65095 Mtetra
.547 .327 .532 r
.30061 .65095 .3144 .45359 .31588 .45394 .30222 .65088 Mtetra
.546 .326 .532 r
.30222 .65088 .31588 .45394 .3174 .45375 .30384 .65054 Mtetra
.30384 .65054 .3174 .45375 .31894 .45331 .30547 .6501 Mtetra
.30547 .6501 .31894 .45331 .32048 .45288 .3071 .64965 Mtetra
.547 .327 .532 r
.3071 .64965 .32048 .45288 .32198 .45304 .30869 .64982 Mtetra
.30869 .64982 .32198 .45304 .3235 .453 .31031 .64969 Mtetra
.545 .325 .532 r
.31031 .64969 .3235 .453 .32509 .45184 .31199 .64853 Mtetra
.529 .312 .529 r
.31199 .64853 .32509 .45184 .32681 .44835 .31415 .63936 Mtetra
0 0 .232 r
.31415 .63936 .32681 .44835 .3285 .44544 .32739 .44682 Mtetra
.967 .927 .605 r
.32739 .44682 .3285 .44544 .33014 .44337 .32915 .44266 Mtetra
.822 .808 .837 r
.32915 .44266 .33014 .44337 .33172 .44235 .33076 .4412 Mtetra
.669 .705 .875 r
.33076 .4412 .33172 .44235 .33327 .44181 .33231 .44064 Mtetra
.587 .672 .899 r
.33231 .44064 .33327 .44181 .3348 .44148 .33384 .44043 Mtetra
.602 .701 .913 r
.33384 .44043 .3348 .44148 .33634 .44115 .33537 .44014 Mtetra
.614 .716 .918 r
.33537 .44014 .33634 .44115 .33788 .44081 .33692 .43981 Mtetra
.613 .717 .919 r
.33692 .43981 .33788 .44081 .33942 .44047 .33846 .43948 Mtetra
.635 .727 .914 r
.33846 .43948 .33942 .44047 .34097 .44005 .34 .43908 Mtetra
.654 .736 .91 r
.34 .43908 .34097 .44005 .34252 .43955 .34155 .4386 Mtetra
.668 .745 .908 r
.34155 .4386 .34252 .43955 .34408 .43898 .34311 .43806 Mtetra
.687 .755 .903 r
.34311 .43806 .34408 .43898 .34564 .43831 .34467 .43743 Mtetra
.698 .767 .905 r
.34467 .43743 .34564 .43831 .34721 .4376 .34624 .43677 Mtetra
.699 .778 .913 r
.34624 .43677 .34721 .4376 .34878 .43689 .3478 .43609 Mtetra
.712 .789 .912 r
.3478 .43609 .34878 .43689 .35035 .43605 .34937 .43537 Mtetra
.696 .813 .937 r
.34937 .43537 .35035 .43605 .35192 .43533 .35094 .43471 Mtetra
.629 .816 .972 r
.35094 .43471 .35192 .43533 .35347 .43499 .35249 .43426 Mtetra
.457 .725 .983 r
.35249 .43426 .35347 .43499 .35495 .43592 .35403 .43423 Mtetra
.381 .484 .839 r
.35403 .43423 .35495 .43592 .35632 .43919 .35553 .43477 Mtetra
.378 .307 .65 r
.35553 .43477 .35632 .43919 .34799 .63189 .35699 .43634 Mtetra
.528 .316 .535 r
.35699 .43634 .34799 .63189 .34925 .63918 .35806 .44547 Mtetra
0 0 .273 r
.35806 .44547 .34925 .63918 .35078 .64119 .34991 .63727 Mtetra
0 .02 .554 r
.34991 .63727 .35078 .64119 .35238 .64205 .35137 .64064 Mtetra
.239 .466 .876 r
.35137 .64064 .35238 .64205 .35402 .6421 .35298 .64135 Mtetra
.608 .789 .968 r
.35298 .64135 .35402 .6421 .35568 .64166 .35464 .64095 Mtetra
.711 .822 .934 r
.35464 .64095 .35568 .64166 .35735 .64101 .35632 .64018 Mtetra
.665 .786 .938 r
.35632 .64018 .35735 .64101 .35901 .64063 .35799 .63961 Mtetra
.632 .734 .921 r
.35799 .63961 .35901 .64063 .36067 .64034 .35966 .63918 Mtetra
.675 .721 .884 r
.35966 .63918 .36067 .64034 .36235 .63966 .36133 .63856 Mtetra
.772 .752 .835 r
.36133 .63856 .36235 .63966 .36409 .63754 .36304 .63729 Mtetra
.888 .895 .828 r
.36304 .63729 .36409 .63754 .36597 .63269 .36478 .63529 Mtetra
0 0 0 r
.36478 .63529 .36597 .63269 .37642 .43929 .36654 .63282 Mtetra
.545 .325 .532 r
.36654 .63282 .37642 .43929 .37826 .43295 .36825 .63152 Mtetra
.547 .327 .532 r
.36825 .63152 .37826 .43295 .37983 .4325 .3699 .63146 Mtetra
.546 .326 .532 r
.3699 .63146 .37983 .4325 .38139 .43251 .37158 .63084 Mtetra
.537 .319 .531 r
.37158 .63084 .38139 .43251 .38305 .43011 .37347 .62539 Mtetra
0 0 .271 r
.37347 .62539 .38305 .43011 .38474 .42703 .38364 .42937 Mtetra
.874 .872 .431 r
.38364 .42937 .38474 .42703 .38639 .42485 .38541 .42441 Mtetra
.874 .86 .824 r
.38541 .42441 .38639 .42485 .38799 .4237 .38705 .42258 Mtetra
.658 .711 .887 r
.38705 .42258 .38799 .4237 .38957 .42327 .38863 .42207 Mtetra
.559 .659 .904 r
.38863 .42207 .38957 .42327 .39114 .42304 .39019 .42195 Mtetra
.577 .687 .916 r
.39019 .42195 .39114 .42304 .39271 .42274 .39176 .42174 Mtetra
.644 .73 .912 r
.39176 .42174 .39271 .42274 .39429 .42227 .39334 .42129 Mtetra
.655 .739 .912 r
.39334 .42129 .39429 .42227 .39588 .42173 .39493 .42079 Mtetra
.676 .753 .909 r
.39493 .42079 .39588 .42173 .39747 .42111 .39652 .42021 Mtetra
.693 .767 .909 r
.39652 .42021 .39747 .42111 .39906 .4204 .39811 .41956 Mtetra
.695 .779 .915 r
.39811 .41956 .39906 .4204 .40066 .4197 .3997 .41889 Mtetra
.684 .786 .928 r
.3997 .41889 .40066 .4197 .40225 .41905 .40129 .41828 Mtetra
.668 .789 .939 r
.40129 .41828 .40225 .41905 .40384 .41849 .40288 .41772 Mtetra
.662 .791 .943 r
.40288 .41772 .40384 .41849 .40543 .41794 .40447 .41718 Mtetra
.661 .792 .944 r
.40447 .41718 .40543 .41794 .40702 .41741 .40607 .41665 Mtetra
.662 .793 .944 r
.40607 .41665 .40702 .41741 .40861 .41687 .40766 .41611 Mtetra
.661 .793 .945 r
.40766 .41611 .40861 .41687 .41021 .41633 .40925 .41557 Mtetra
.662 .792 .944 r
.40925 .41557 .41021 .41633 .4118 .4158 .41085 .41503 Mtetra
.663 .791 .943 r
.41085 .41503 .4118 .4158 .41339 .41527 .41244 .41449 Mtetra
.658 .787 .944 r
.41244 .41449 .41339 .41527 .41499 .41476 .41404 .41397 Mtetra
.642 .78 .947 r
.41404 .41397 .41499 .41476 .41658 .41432 .41563 .4135 Mtetra
.626 .768 .948 r
.41563 .4135 .41658 .41432 .41817 .41396 .41723 .41309 Mtetra
.628 .758 .94 r
.41723 .41309 .41817 .41396 .41977 .41359 .41882 .41268 Mtetra
.643 .751 .927 r
.41882 .41268 .41977 .41359 .42136 .41318 .42042 .41222 Mtetra
.662 .747 .913 r
.42042 .41222 .42136 .41318 .42296 .41268 .42202 .41169 Mtetra
.674 .744 .903 r
.42202 .41169 .42296 .41268 .42456 .41212 .42363 .41111 Mtetra
.689 .744 .893 r
.42363 .41111 .42456 .41212 .42617 .41149 .42523 .41045 Mtetra
.702 .743 .883 r
.42523 .41045 .42617 .41149 .42778 .41078 .42684 .40972 Mtetra
.701 .739 .881 r
.42684 .40972 .42778 .41078 .42939 .41006 .42845 .409 Mtetra
.715 .741 .872 r
.42845 .409 .42939 .41006 .431 .40932 .43007 .4082 Mtetra
.718 .731 .861 r
.43007 .4082 .431 .40932 .43261 .40858 .43168 .40736 Mtetra
.648 .692 .877 r
.43168 .40736 .43261 .40858 .43422 .40806 .43329 .40688 Mtetra
.282 .526 .909 r
.43329 .40688 .43422 .40806 .43581 .40799 .43487 .40741 Mtetra
.87 .425 .095 r
.43487 .40741 .43581 .40799 .43739 .40868 .43638 .41045 Mtetra
.953 .681 .483 r
.43638 .41045 .43739 .40868 .43894 .4105 .43277 .60426 Mtetra
.562 .339 .535 r
.43277 .60426 .43894 .4105 .44034 .41813 .43423 .613 Mtetra
.55 .329 .533 r
.43423 .613 .44034 .41813 .43698 .61195 .43589 .61477 Mtetra
.58 .233 .346 r
.43589 .61477 .43698 .61195 .43859 .61554 .43757 .61546 Mtetra
.012 .585 .748 r
.43757 .61546 .43859 .61554 .44027 .61668 .43928 .61551 Mtetra
.625 .709 .906 r
.43928 .61551 .44027 .61668 .44198 .61639 .44099 .6151 Mtetra
.664 .701 .874 r
.44099 .6151 .44198 .61639 .4437 .61572 .44272 .61451 Mtetra
.657 .712 .888 r
.44272 .61451 .4437 .61572 .44543 .61504 .44444 .61395 Mtetra
.603 .716 .924 r
.44444 .61395 .44543 .61504 .44715 .61469 .44616 .61362 Mtetra
.608 .721 .925 r
.44616 .61362 .44715 .61469 .44887 .61432 .44788 .61327 Mtetra
.604 .725 .93 r
.44788 .61327 .44887 .61432 .45059 .6139 .4496 .61293 Mtetra
.598 .739 .943 r
.4496 .61293 .45059 .6139 .45232 .6134 .45132 .61259 Mtetra
.689 .803 .935 r
.45132 .61259 .45232 .6134 .45405 .6127 .45306 .6119 Mtetra
.833 .817 .835 r
.45306 .6119 .45405 .6127 .45579 .61148 .45481 .61022 Mtetra
.901 .74 .672 r
.45481 .61022 .45579 .61148 .45755 .60924 .45662 .60573 Mtetra
.956 .687 .487 r
.45662 .60573 .45755 .60924 .45933 .60617 .4621 .4119 Mtetra
.568 .348 .541 r
.4621 .4119 .45933 .60617 .46112 .60272 .46392 .40138 Mtetra
.55 .334 .539 r
.46392 .40138 .46112 .60272 .46286 .60156 .46556 .40018 Mtetra
.548 .332 .539 r
.46556 .40018 .46286 .60156 .46458 .60145 .46718 .39997 Mtetra
.547 .331 .538 r
.46718 .39997 .46458 .60145 .46629 .60184 .4688 .40017 Mtetra
.548 .332 .538 r
.4688 .40017 .46629 .60184 .46801 .60223 .47043 .40003 Mtetra
.549 .332 .539 r
.47043 .40003 .46801 .60223 .46974 .60166 .47206 .39953 Mtetra
.551 .334 .539 r
.47206 .39953 .46974 .60166 .47153 .59799 .47371 .39806 Mtetra
.553 .336 .539 r
.47371 .39806 .47153 .59799 .47623 .40101 .47537 .39553 Mtetra
.669 .491 .636 r
.47537 .39553 .47623 .40101 .47794 .39537 .47703 .39347 Mtetra
.744 .649 .755 r
.47703 .39347 .47794 .39537 .4796 .39282 .47868 .39202 Mtetra
.697 .797 .927 r
.47868 .39202 .4796 .39282 .48124 .39199 .48032 .39133 Mtetra
.634 .817 .97 r
.48032 .39133 .48124 .39199 .48287 .39155 .48195 .39084 Mtetra
.617 .799 .969 r
.48195 .39084 .48287 .39155 .48451 .39124 .48359 .39042 Mtetra
.661 .784 .939 r
.48359 .39042 .48451 .39124 .48615 .39069 .48523 .38987 Mtetra
.661 .783 .939 r
.48523 .38987 .48615 .39069 .48779 .39015 .48687 .38932 Mtetra
.661 .782 .938 r
.48687 .38932 .48779 .39015 .48942 .38961 .48851 .38878 Mtetra
.663 .781 .937 r
.48851 .38878 .48942 .38961 .49107 .38906 .49015 .38822 Mtetra
.49015 .38822 .49107 .38906 .49271 .38851 .49179 .38767 Mtetra
.49179 .38767 .49271 .38851 .49435 .38795 .49344 .38711 Mtetra
.49344 .38711 .49435 .38795 .49599 .3874 .49508 .38656 Mtetra
.663 .782 .937 r
.49508 .38656 .49599 .3874 .49764 .38684 .49673 .38601 Mtetra
.49673 .38601 .49764 .38684 .49929 .38629 .49837 .38545 Mtetra
.663 .782 .938 r
.49837 .38545 .49929 .38629 .50093 .38573 .50002 .3849 Mtetra
.662 .782 .938 r
.50002 .3849 .50093 .38573 .50258 .38518 .50167 .38434 Mtetra
.662 .783 .938 r
.50167 .38434 .50258 .38518 .50423 .38462 .50332 .38379 Mtetra
.50332 .38379 .50423 .38462 .50588 .38407 .50497 .38323 Mtetra
.50497 .38323 .50588 .38407 .50753 .38351 .50662 .38268 Mtetra
.50662 .38268 .50753 .38351 .50918 .38296 .50827 .38213 Mtetra
.50827 .38213 .50918 .38296 .51083 .38241 .50993 .38157 Mtetra
.662 .783 .939 r
.50993 .38157 .51083 .38241 .51249 .38185 .51158 .38102 Mtetra
.661 .783 .939 r
.51158 .38102 .51249 .38185 .51414 .3813 .51324 .38046 Mtetra
.51324 .38046 .51414 .3813 .5158 .38075 .51489 .37991 Mtetra
.51489 .37991 .5158 .38075 .51745 .3802 .51655 .37936 Mtetra
.51655 .37936 .51745 .3802 .51911 .37964 .51821 .3788 Mtetra
.661 .782 .939 r
.51821 .3788 .51911 .37964 .52077 .37909 .51987 .37825 Mtetra
.661 .782 .938 r
.51987 .37825 .52077 .37909 .52243 .37854 .52153 .3777 Mtetra
.52153 .3777 .52243 .37854 .52409 .37799 .52319 .37715 Mtetra
.52319 .37715 .52409 .37799 .52575 .37744 .52485 .37659 Mtetra
.661 .781 .938 r
.52485 .37659 .52575 .37744 .52742 .37689 .52652 .37604 Mtetra
.66 .781 .938 r
.52652 .37604 .52742 .37689 .52908 .37634 .52818 .37549 Mtetra
.66 .78 .938 r
.52818 .37549 .52908 .37634 .53074 .37579 .52985 .37494 Mtetra
.66 .78 .937 r
.52985 .37494 .53074 .37579 .53241 .37524 .53151 .37439 Mtetra
.661 .779 .937 r
.53151 .37439 .53241 .37524 .53408 .37469 .53318 .37383 Mtetra
.53318 .37383 .53408 .37469 .53574 .37414 .53485 .37328 Mtetra
.661 .779 .936 r
.53485 .37328 .53574 .37414 .53741 .37358 .53652 .37272 Mtetra
.662 .779 .936 r
.53652 .37272 .53741 .37358 .53908 .37302 .53819 .37216 Mtetra
.663 .78 .936 r
.53819 .37216 .53908 .37302 .54075 .37245 .53986 .3716 Mtetra
.663 .781 .937 r
.53986 .3716 .54075 .37245 .54243 .37188 .54153 .37103 Mtetra
.663 .782 .937 r
.54153 .37103 .54243 .37188 .5441 .37132 .54321 .37047 Mtetra
.698 .792 .923 r
.54321 .37047 .5441 .37132 .54577 .37048 .54488 .36976 Mtetra
.667 .816 .955 r
.54488 .36976 .54577 .37048 .54744 .36986 .54655 .36916 Mtetra
.593 .798 .978 r
.54655 .36916 .54744 .36986 .54912 .36968 .54823 .36878 Mtetra
.202 .547 .93 r
.54823 .36878 .54912 .36968 .55082 .3716 .54992 .36929 Mtetra
.346 .397 .772 r
.54992 .36929 .55082 .3716 .55255 .37742 .55161 .37029 Mtetra
.473 .337 .615 r
.55161 .37029 .55255 .37742 .55605 .57433 .55331 .37173 Mtetra
.549 .333 .539 r
.55331 .37173 .55605 .57433 .55785 .57495 .55499 .37093 Mtetra
.55499 .37093 .55785 .57495 .55964 .57407 .55667 .37009 Mtetra
.548 .332 .538 r
.55667 .37009 .55964 .57407 .56143 .57324 .55836 .37015 Mtetra
0 0 .388 r
.55836 .37015 .56143 .57324 .56326 .57592 .56218 .5627 Mtetra
.001 0 .458 r
.56218 .5627 .56326 .57592 .56508 .57776 .56411 .57484 Mtetra
0 .099 .631 r
.56411 .57484 .56508 .57776 .5669 .57878 .56595 .57771 Mtetra
.454 .662 .951 r
.56595 .57771 .5669 .57878 .5687 .57858 .56776 .57781 Mtetra
.65 .812 .961 r
.56776 .57781 .5687 .57858 .5705 .57801 .56956 .57722 Mtetra
.725 .827 .929 r
.56956 .57722 .5705 .57801 .5723 .57729 .57136 .57634 Mtetra
.661 .774 .933 r
.57136 .57634 .5723 .57729 .57411 .57675 .57317 .57574 Mtetra
.654 .759 .927 r
.57317 .57574 .57411 .57675 .57591 .57625 .57497 .57518 Mtetra
.654 .747 .918 r
.57497 .57518 .57591 .57625 .57772 .57574 .57678 .57462 Mtetra
.61 .721 .924 r
.57678 .57462 .57772 .57574 .57953 .57552 .57859 .57424 Mtetra
.633 .7 .894 r
.57859 .57424 .57953 .57552 .58134 .57511 .5804 .57378 Mtetra
.678 .708 .871 r
.5804 .57378 .58134 .57511 .58315 .57424 .58221 .57308 Mtetra
.766 .764 .851 r
.58221 .57308 .58315 .57424 .58492 .57153 .58401 .57184 Mtetra
.827 .998 .783 r
.58401 .57184 .58492 .57153 .58664 .56581 .58579 .56991 Mtetra
.101 0 .235 r
.58579 .56991 .58664 .56581 .58471 .36622 .58756 .56664 Mtetra
0 0 .385 r
.58756 .56664 .58471 .36622 .58632 .36056 .5857 .37304 Mtetra
0 0 .272 r
.5857 .37304 .58632 .36056 .58798 .35796 .58714 .35896 Mtetra
.902 .928 .547 r
.58714 .35896 .58798 .35796 .58966 .35631 .58878 .35541 Mtetra
.789 .804 .864 r
.58878 .35541 .58966 .35631 .59135 .35542 .59047 .35415 Mtetra
.655 .698 .878 r
.59047 .35415 .59135 .35542 .59305 .35488 .59218 .35361 Mtetra
.583 .667 .896 r
.59218 .35361 .59305 .35488 .59476 .35453 .59389 .35339 Mtetra
.61 .703 .91 r
.59389 .35339 .59476 .35453 .59647 .35415 .5956 .35304 Mtetra
.619 .714 .913 r
.5956 .35304 .59647 .35415 .59818 .35375 .59731 .35266 Mtetra
.627 .721 .914 r
.59731 .35266 .59818 .35375 .59989 .3533 .59902 .35224 Mtetra
.671 .744 .905 r
.59902 .35224 .59989 .3533 .6016 .35264 .60073 .35163 Mtetra
.691 .762 .906 r
.60073 .35163 .6016 .35264 .6033 .35188 .60244 .35094 Mtetra
.696 .776 .914 r
.60244 .35094 .6033 .35188 .60501 .35112 .60414 .35022 Mtetra
.709 .79 .915 r
.60414 .35022 .60501 .35112 .60671 .35022 .60585 .34945 Mtetra
.686 .816 .945 r
.60585 .34945 .60671 .35022 .60842 .34949 .60756 .34877 Mtetra
.617 .808 .973 r
.60756 .34877 .60842 .34949 .61014 .34917 .60928 .34832 Mtetra
.459 .703 .973 r
.60928 .34832 .61014 .34917 .6119 .35035 .61101 .34832 Mtetra
.42 .472 .808 r
.61101 .34832 .6119 .35035 .61374 .3542 .61276 .34893 Mtetra
.411 .32 .642 r
.61276 .34893 .61374 .3542 .62114 .55284 .61454 .35071 Mtetra
.026 0 .415 r
.61454 .35071 .62114 .55284 .62315 .55848 .62164 .53699 Mtetra
.035 0 .452 r
.62164 .53699 .62315 .55848 .62506 .5603 .62406 .55666 Mtetra
.104 .168 .646 r
.62406 .55666 .62506 .5603 .62693 .56104 .626 .55965 Mtetra
.35 .542 .901 r
.626 .55965 .62693 .56104 .62879 .56119 .62788 .56018 Mtetra
.623 .753 .939 r
.62788 .56018 .62879 .56119 .63064 .56082 .62972 .55973 Mtetra
.734 .772 .884 r
.62972 .55973 .63064 .56082 .63247 .55985 .63155 .55873 Mtetra
.808 .783 .83 r
.63155 .55873 .63247 .55985 .63424 .55721 .63336 .55713 Mtetra
.905 .965 .813 r
.63336 .55713 .63424 .55721 .63592 .5516 .63515 .55496 Mtetra
.118 0 .207 r
.63515 .55496 .63592 .5516 .63111 .35219 .63693 .55229 Mtetra
.545 .325 .532 r
.63693 .55229 .63111 .35219 .63272 .34803 .63876 .55126 Mtetra
.547 .327 .532 r
.63876 .55126 .63272 .34803 .63446 .34763 .64061 .5511 Mtetra
.546 .326 .532 r
.64061 .5511 .63446 .34763 .63621 .34752 .64245 .55024 Mtetra
.533 .316 .531 r
.64245 .55024 .63621 .34752 .63785 .34456 .64402 .5419 Mtetra
0 0 .392 r
.64402 .5419 .63785 .34456 .6395 .34155 .63874 .34311 Mtetra
.825 .846 .383 r
.63874 .34311 .6395 .34155 .64118 .33941 .64034 .33868 Mtetra
.838 .851 .855 r
.64034 .33868 .64118 .33941 .64289 .33837 .64203 .33712 Mtetra
.644 .7 .887 r
.64203 .33712 .64289 .33837 .64463 .33791 .64377 .33663 Mtetra
.561 .656 .9 r
.64377 .33663 .64463 .33791 .64638 .33765 .64552 .33648 Mtetra
.606 .7 .91 r
.64552 .33648 .64638 .33765 .64812 .33723 .64727 .33615 Mtetra
.653 .735 .91 r
.64727 .33615 .64812 .33723 .64986 .33666 .64901 .33561 Mtetra
.666 .746 .91 r
.64901 .33561 .64986 .33666 .6516 .33604 .65075 .33502 Mtetra
.711 .768 .897 r
.65075 .33502 .6516 .33604 .65332 .33509 .65248 .33421 Mtetra
.723 .802 .914 r
.65248 .33421 .65332 .33509 .65505 .33413 .65421 .33336 Mtetra
.677 .815 .949 r
.65421 .33336 .65505 .33413 .65679 .33356 .65595 .3327 Mtetra
.532 .737 .969 r
.65595 .3327 .65679 .33356 .65859 .33433 .65771 .33252 Mtetra
.443 .513 .836 r
.65771 .33252 .65859 .33433 .66049 .33745 .6595 .33297 Mtetra
.427 .349 .666 r
.6595 .33297 .66049 .33745 .67083 .53438 .66134 .33438 Mtetra
.535 .322 .538 r
.66134 .33438 .67083 .53438 .67308 .54268 .6634 .34102 Mtetra
.007 0 .415 r
.6634 .34102 .67308 .54268 .67506 .54468 .674 .53997 Mtetra
.132 .151 .613 r
.674 .53997 .67506 .54468 .67699 .5455 .67607 .5438 Mtetra
.183 .386 .828 r
.67607 .5438 .67699 .5455 .67891 .54593 .67802 .54501 Mtetra
.472 .709 .973 r
.67802 .54501 .67891 .54593 .68081 .5459 .67992 .54498 Mtetra
.737 .814 .911 r
.67992 .54498 .68081 .5459 .68267 .54505 .68178 .54399 Mtetra
.92 .793 .703 r
.68178 .54399 .68267 .54505 .68441 .54156 .68351 .54037 Mtetra
.975 .686 .407 r
.68351 .54037 .68441 .54156 .67667 .3407 .67579 .33872 Mtetra
.95 .707 .534 r
.67579 .33872 .67667 .3407 .67785 .32806 .67701 .32693 Mtetra
.879 .781 .749 r
.67701 .32693 .67785 .32806 .67951 .3254 .67867 .32438 Mtetra
.692 .765 .907 r
.67867 .32438 .67951 .3254 .68125 .3246 .68042 .32366 Mtetra
.507 .707 .961 r
.68042 .32366 .68125 .3246 .68304 .32459 .68221 .32358 Mtetra
.439 .657 .952 r
.68221 .32358 .68304 .32459 .68488 .32557 .684 .3237 Mtetra
.475 .526 .83 r
.684 .3237 .68488 .32557 .68681 .32842 .68581 .32404 Mtetra
.451 .368 .672 r
.68581 .32404 .68681 .32842 .6987 .52264 .68767 .32521 Mtetra
.538 .324 .538 r
.68767 .32521 .6987 .52264 .70121 .53406 .68975 .33071 Mtetra
.022 0 .423 r
.68975 .33071 .70121 .53406 .70325 .53646 .70216 .53147 Mtetra
.125 .141 .605 r
.70216 .53147 .70325 .53646 .70523 .53749 .7043 .53566 Mtetra
.257 .415 .829 r
.7043 .53566 .70523 .53749 .70716 .53781 .70628 .53676 Mtetra
.57 .729 .949 r
.70628 .53676 .70716 .53781 .70908 .53758 .70819 .53649 Mtetra
.708 .771 .902 r
.70819 .53649 .70908 .53758 .71096 .53678 .71007 .53563 Mtetra
.764 .778 .864 r
.71007 .53563 .71096 .53678 .71277 .53481 .71193 .5344 Mtetra
.85 .938 .881 r
.71193 .5344 .71277 .53481 .71446 .53062 .71377 .53275 Mtetra
0 0 .004 r
.71377 .53275 .71446 .53062 .71478 .50246 .71555 .53012 Mtetra
.449 .238 .5 r
.71555 .53012 .71478 .50246 .70628 .32185 .71708 .5232 Mtetra
.02 0 .417 r
.71708 .5232 .70628 .32185 .70789 .31854 .70728 .32116 Mtetra
0 0 0 r
.70728 .32116 .70789 .31854 .70959 .31656 .70881 .31621 Mtetra
.901 .934 .825 r
.70881 .31621 .70959 .31656 .71133 .31542 .7105 .31421 Mtetra
.669 .721 .888 r
.7105 .31421 .71133 .31542 .71311 .31488 .71228 .31358 Mtetra
.586 .668 .896 r
.71228 .31358 .71311 .31488 .71491 .31455 .71408 .31333 Mtetra
.629 .705 .9 r
.71408 .31333 .71491 .31455 .71668 .31391 .71587 .31289 Mtetra
.714 .776 .901 r
.71587 .31289 .71668 .31391 .71844 .31293 .71763 .31206 Mtetra
.683 .799 .937 r
.71763 .31206 .71844 .31293 .72022 .31226 .71941 .31137 Mtetra
.574 .753 .962 r
.71941 .31137 .72022 .31226 .72206 .3126 .72121 .31107 Mtetra
.452 .559 .873 r
.72121 .31107 .72206 .3126 .72404 .31508 .72305 .31139 Mtetra
.429 .376 .697 r
.72305 .31139 .72404 .31508 .72684 .33028 .72495 .31257 Mtetra
.449 .283 .564 r
.72495 .31257 .72684 .33028 .74105 .52183 .72708 .31727 Mtetra
.043 0 .435 r
.72708 .31727 .74105 .52183 .74317 .52442 .74202 .51894 Mtetra
.142 .144 .599 r
.74202 .51894 .74317 .52442 .74519 .52549 .74427 .52352 Mtetra
.246 .39 .811 r
.74427 .52352 .74519 .52549 .74716 .52569 .74631 .52479 Mtetra
.572 .764 .97 r
.74631 .52479 .74716 .52569 .74909 .52526 .74825 .52446 Mtetra
.689 .832 .952 r
.74825 .52446 .74909 .52526 .751 .52459 .75015 .52368 Mtetra
.685 .809 .941 r
.75015 .52368 .751 .52459 .75293 .52403 .75206 .52293 Mtetra
.619 .74 .933 r
.75206 .52293 .75293 .52403 .75487 .52375 .754 .52248 Mtetra
.66 .725 .897 r
.754 .52248 .75487 .52375 .75679 .52312 .75592 .52185 Mtetra
.723 .749 .872 r
.75592 .52185 .75679 .52312 .75864 .52149 .75782 .52086 Mtetra
.838 .899 .881 r
.75782 .52086 .75864 .52149 .76034 .51759 .75967 .51926 Mtetra
0 0 0 r
.75967 .51926 .76034 .51759 .76141 .50497 .76146 .51676 Mtetra
.337 .131 .446 r
.76146 .51676 .76141 .50497 .74925 .30796 .76302 .51099 Mtetra
.044 0 .431 r
.76302 .51099 .74925 .30796 .75084 .30439 .75035 .30773 Mtetra
0 0 .062 r
.75035 .30773 .75084 .30439 .75253 .30229 .75179 .30214 Mtetra
.93 .957 .772 r
.75179 .30214 .75253 .30229 .75428 .30098 .75347 .29976 Mtetra
.704 .737 .876 r
.75347 .29976 .75428 .30098 .75608 .30026 .75526 .29893 Mtetra
.617 .681 .887 r
.75526 .29893 .75608 .30026 .75789 .2998 .75708 .29854 Mtetra
.582 .677 .906 r
.75708 .29854 .75789 .2998 .75972 .29944 .75891 .2983 Mtetra
.613 .714 .917 r
.75891 .2983 .75972 .29944 .76154 .29904 .76074 .29791 Mtetra
.613 .717 .92 r
.76074 .29791 .76154 .29904 .76336 .29863 .76256 .29752 Mtetra
.637 .733 .918 r
.76256 .29752 .76336 .29863 .76518 .29809 .76438 .29703 Mtetra
.68 .759 .911 r
.76438 .29703 .76518 .29809 .76698 .29735 .76619 .29635 Mtetra
.691 .776 .916 r
.76619 .29635 .76698 .29735 .76878 .29657 .76799 .29561 Mtetra
.69 .787 .925 r
.76799 .29561 .76878 .29657 .77058 .2958 .7698 .29489 Mtetra
.674 .791 .937 r
.7698 .29489 .77058 .2958 .77239 .29513 .77161 .29423 Mtetra
.672 .795 .94 r
.77161 .29423 .77239 .29513 .7742 .29446 .77342 .29357 Mtetra
.685 .801 .937 r
.77342 .29357 .7742 .29446 .776 .29372 .77523 .29286 Mtetra
.711 .818 .931 r
.77523 .29286 .776 .29372 .77779 .2928 .77703 .29204 Mtetra
.674 .831 .959 r
.77703 .29204 .77779 .2928 .77961 .29216 .77884 .29136 Mtetra
.589 .787 .974 r
.77884 .29136 .77961 .29216 .78149 .29223 .78068 .29097 Mtetra
.475 .623 .915 r
.78068 .29097 .78149 .29223 .78352 .29419 .78256 .29111 Mtetra
.458 .422 .731 r
.78256 .29111 .78352 .29419 .78592 .30051 .78451 .2919 Mtetra
.438 .307 .604 r
.78451 .2919 .78592 .30051 .80468 .50094 .7866 .29453 Mtetra
.08 0 .455 r
.7866 .29453 .80468 .50094 .80696 .50424 .80545 .49512 Mtetra
.159 .116 .556 r
.80545 .49512 .80696 .50424 .80907 .50551 .80811 .50282 Mtetra
.189 .286 .733 r
.80811 .50282 .80907 .50551 .81112 .5059 .8103 .50493 Mtetra
.415 .673 .968 r
.8103 .50493 .81112 .5059 .81312 .50572 .81232 .50506 Mtetra
.653 .864 .979 r
.81232 .50506 .81312 .50572 .81507 .50509 .81427 .50436 Mtetra
.852 .886 .863 r
.81427 .50436 .81507 .50509 .81699 .50399 .81614 .50261 Mtetra
.929 .773 .666 r
.81614 .50261 .81699 .50399 .81886 .50226 .81778 .4983 Mtetra
.976 .673 .354 r
.81778 .4983 .81886 .50226 .82064 .49954 .80239 .30227 Mtetra
.573 .35 .539 r
.80239 .30227 .82064 .49954 .82214 .49384 .80299 .28778 Mtetra
.552 .335 .539 r
.80299 .28778 .82214 .49384 .80592 .29166 .80464 .28504 Mtetra
.634 .455 .624 r
.80464 .28504 .80592 .29166 .8073 .28597 .80638 .28336 Mtetra
.683 .582 .736 r
.80638 .28336 .8073 .28597 .80895 .28336 .80817 .28222 Mtetra
.688 .75 .898 r
.80817 .28222 .80895 .28336 .81076 .28245 .81 .28148 Mtetra
.649 .773 .939 r
.81 .28148 .81076 .28245 .81261 .28194 .81184 .28092 Mtetra
.666 .767 .926 r
.81184 .28092 .81261 .28194 .81447 .28145 .81369 .28029 Mtetra
.772 .776 .856 r
.81369 .28029 .81447 .28145 .81625 .2802 .81547 .27904 Mtetra
.706 .754 .889 r
.81547 .27904 .81625 .2802 .81807 .27937 .81729 .2782 Mtetra
.461 .637 .932 r
.81729 .2782 .81807 .27937 .81999 .27951 .81921 .27834 Mtetra
.758 .34 0 r
.81921 .27834 .81999 .27951 .82236 .28442 .82158 .28319 Mtetra
.973 .661 .312 r
.82158 .28319 .82236 .28442 .84419 .49111 .84336 .48993 Mtetra
.738 .31 0 r
.84336 .48993 .84419 .49111 .84668 .4958 .84586 .49468 Mtetra
.319 .581 .936 r
.84586 .49468 .84668 .4958 .84877 .49628 .84796 .49517 Mtetra
.663 .764 .925 r
.84796 .49517 .84877 .49628 .85075 .49561 .84994 .49451 Mtetra
.848 .819 .82 r
.84994 .49451 .85075 .49561 .85261 .49365 .8518 .49255 Mtetra
.977 .779 .571 r
.8518 .49255 .85261 .49365 .85399 .48697 .85318 .48586 Mtetra
.976 .67 .326 r
.85318 .48586 .85399 .48697 .83528 .27949 .83451 .27835 Mtetra
.965 .78 .604 r
.83451 .27835 .83528 .27949 .83666 .2741 .83589 .27296 Mtetra
.76 .778 .868 r
.83589 .27296 .83666 .2741 .83846 .27294 .83769 .2718 Mtetra
.628 .727 .918 r
.83769 .2718 .83846 .27294 .84033 .27247 .83957 .27133 Mtetra
.549 .689 .932 r
.83957 .27133 .84033 .27247 .84224 .27231 .84147 .27117 Mtetra
.748 .775 .875 r
.84147 .27117 .84224 .27231 .84405 .27123 .84329 .27009 Mtetra
.68 .75 .905 r
.84329 .27009 .84405 .27123 .8459 .27052 .84514 .26939 Mtetra
.465 .647 .937 r
.84514 .26939 .8459 .27052 .84784 .27063 .84708 .2695 Mtetra
.846 .448 0 r
.84708 .2695 .84784 .27063 .8505 .27756 .84974 .27651 Mtetra
.971 .656 .295 r
.84974 .27651 .8505 .27756 .87419 .48349 .8734 .48245 Mtetra
0 0 .437 r
.8734 .48245 .87419 .48349 .87659 .4866 .87579 .48555 Mtetra
.982 .782 .561 r
.87579 .48555 .87659 .4866 .87791 .47958 .87714 .47873 Mtetra
.974 .667 .311 r
.87714 .47873 .87791 .47958 .85751 .27069 .85678 .26976 Mtetra
.974 .806 .612 r
.85678 .26976 .85751 .27069 .85893 .26585 .85818 .26481 Mtetra
.884 .463 .193 r
.25495 .46588 .25598 .46643 .25723 .46905 .25619 .46869 Mtetra
.937 .682 .526 r
.25619 .46869 .25723 .46905 .24291 .6643 .24177 .66433 Mtetra
.912 .593 .428 r
.24177 .66433 .24291 .6643 .24381 .6725 .24273 .67163 Mtetra
0 .365 .807 r
.24273 .67163 .24381 .6725 .24529 .67343 .24423 .67239 Mtetra
.627 .722 .915 r
.24423 .67239 .24529 .67343 .24687 .67317 .24583 .672 Mtetra
.785 .733 .804 r
.24583 .672 .24687 .67317 .24854 .67186 .24751 .67053 Mtetra
.89 .713 .656 r
.24751 .67053 .24854 .67186 .2505 .66678 .2495 .66502 Mtetra
.936 .685 .533 r
.2495 .66502 .2505 .66678 .2675 .46931 .26657 .46757 Mtetra
.877 .688 .643 r
.26657 .46757 .2675 .46931 .26949 .46278 .2685 .46172 Mtetra
.766 .738 .828 r
.2685 .46172 .26949 .46278 .27105 .46157 .27006 .46057 Mtetra
.621 .716 .914 r
.27006 .46057 .27105 .46157 .27256 .46121 .27157 .46022 Mtetra
.471 .663 .946 r
.27157 .46022 .27256 .46121 .27403 .46125 .27304 .46027 Mtetra
.633 .725 .914 r
.27304 .46027 .27403 .46125 .27554 .46084 .27455 .45988 Mtetra
.649 .733 .911 r
.27455 .45988 .27554 .46084 .27705 .46036 .27606 .45943 Mtetra
.657 .741 .912 r
.27606 .45943 .27705 .46036 .27857 .45983 .27757 .45895 Mtetra
.679 .757 .91 r
.27757 .45895 .27857 .45983 .28011 .45899 .2791 .45838 Mtetra
.682 .823 .951 r
.2791 .45838 .28011 .45899 .28165 .45822 .28062 .45778 Mtetra
.669 .866 .974 r
.28062 .45778 .28165 .45822 .28317 .45769 .28215 .45719 Mtetra
.766 .856 .917 r
.28215 .45719 .28317 .45769 .28465 .45775 .2837 .45624 Mtetra
.677 .651 .817 r
.2837 .45624 .28465 .45775 .28609 .45846 .28524 .45558 Mtetra
.563 .484 .724 r
.28524 .45558 .28609 .45846 .28743 .46049 .28672 .45555 Mtetra
.048 .056 .544 r
.28672 .45555 .28743 .46049 .27527 .65032 .28796 .45905 Mtetra
0 0 .205 r
.28796 .45905 .27527 .65032 .27612 .66041 .27539 .65495 Mtetra
0 0 .3 r
.27539 .65495 .27612 .66041 .27752 .66302 .27654 .66104 Mtetra
.41 .476 .818 r
.27654 .66104 .27752 .66302 .27909 .66323 .27809 .66158 Mtetra
.65 .636 .823 r
.27809 .66158 .27909 .66323 .28071 .66272 .27971 .66105 Mtetra
.705 .655 .798 r
.27971 .66105 .28071 .66272 .28236 .6619 .28136 .6601 Mtetra
.631 .611 .812 r
.28136 .6601 .28236 .6619 .28398 .66133 .28298 .65967 Mtetra
.611 .617 .833 r
.28298 .65967 .28398 .66133 .28561 .66082 .28459 .65935 Mtetra
.614 .645 .857 r
.28459 .65935 .28561 .66082 .28723 .66032 .28621 .65902 Mtetra
.635 .681 .876 r
.28621 .65902 .28723 .66032 .28885 .65997 .28783 .6586 Mtetra
.644 .672 .862 r
.28783 .6586 .28885 .65997 .29047 .65956 .28945 .65813 Mtetra
.647 .663 .852 r
.28945 .65813 .29047 .65956 .29211 .65893 .29108 .65763 Mtetra
.649 .684 .87 r
.29108 .65763 .29211 .65893 .2938 .65746 .29271 .65714 Mtetra
.58 .88 .993 r
.29271 .65714 .2938 .65746 .29553 .65537 .29434 .65665 Mtetra
.253 0 0 r
.29434 .65665 .29553 .65537 .2973 .65282 .29597 .65616 Mtetra
.452 .127 .323 r
.29597 .65616 .2973 .65282 .29899 .65141 .2976 .65569 Mtetra
.476 .173 .372 r
.2976 .65569 .29899 .65141 .30061 .65095 .29923 .65524 Mtetra
.29923 .65524 .30061 .65095 .30222 .65088 .30086 .65478 Mtetra
.467 .156 .355 r
.30086 .65478 .30222 .65088 .30384 .65054 .30249 .65431 Mtetra
.462 .148 .347 r
.30249 .65431 .30384 .65054 .30547 .6501 .30413 .65383 Mtetra
.46 .145 .344 r
.30413 .65383 .30547 .6501 .3071 .64965 .30576 .65333 Mtetra
.503 .185 .361 r
.30576 .65333 .3071 .64965 .30869 .64982 .30738 .65321 Mtetra
.477 .153 .337 r
.30738 .65321 .30869 .64982 .31031 .64969 .309 .65293 Mtetra
.379 .054 .283 r
.309 .65293 .31031 .64969 .31199 .64853 .31067 .65202 Mtetra
0 0 0 r
.31067 .65202 .31199 .64853 .31415 .63936 .31252 .64812 Mtetra
.956 .702 .511 r
.31252 .64812 .31415 .63936 .32739 .44682 .32601 .45242 Mtetra
.819 .772 .264 r
.32601 .45242 .32739 .44682 .32915 .44266 .32811 .44288 Mtetra
.9 .966 .82 r
.32811 .44288 .32915 .44266 .33076 .4412 .32974 .44096 Mtetra
.607 .903 .985 r
.32974 .44096 .33076 .4412 .33231 .44064 .33129 .44041 Mtetra
.301 .768 .942 r
.33129 .44041 .33231 .44064 .33384 .44043 .33282 .44028 Mtetra
.513 .888 .97 r
.33282 .44028 .33384 .44043 .33537 .44014 .33437 .43982 Mtetra
.668 .899 .978 r
.33437 .43982 .33537 .44014 .33692 .43981 .33592 .43917 Mtetra
.69 .822 .946 r
.33592 .43917 .33692 .43981 .33846 .43948 .33748 .43854 Mtetra
.669 .746 .908 r
.33748 .43854 .33846 .43948 .34 .43908 .33904 .438 Mtetra
.654 .714 .892 r
.33904 .438 .34 .43908 .34155 .4386 .34059 .43751 Mtetra
.65 .713 .894 r
.34059 .43751 .34155 .4386 .34311 .43806 .34214 .43705 Mtetra
.654 .729 .904 r
.34214 .43705 .34311 .43806 .34467 .43743 .3437 .43656 Mtetra
.659 .76 .925 r
.3437 .43656 .34467 .43743 .34624 .43677 .34525 .43606 Mtetra
.659 .8 .95 r
.34525 .43606 .34624 .43677 .3478 .43609 .34681 .43554 Mtetra
.662 .839 .968 r
.34681 .43554 .3478 .43609 .34937 .43537 .34837 .43498 Mtetra
.65 .879 .983 r
.34837 .43498 .34937 .43537 .35094 .43471 .34994 .4344 Mtetra
.632 .894 .986 r
.34994 .4344 .35094 .43471 .35249 .43426 .3515 .43382 Mtetra
.737 .88 .946 r
.3515 .43382 .35249 .43426 .35403 .43423 .35308 .43298 Mtetra
.7 .701 .847 r
.35308 .43298 .35403 .43423 .35553 .43477 .35465 .43223 Mtetra
.589 .52 .745 r
.35465 .43223 .35553 .43477 .35699 .43634 .3562 .43201 Mtetra
.271 .235 .634 r
.3562 .43201 .35699 .43634 .35806 .44547 .35762 .43418 Mtetra
.963 .7 .488 r
.35762 .43418 .35806 .44547 .34991 .63727 .34934 .62726 Mtetra
0 0 .3 r
.34934 .62726 .34991 .63727 .35137 .64064 .35042 .63817 Mtetra
.194 .295 .74 r
.35042 .63817 .35137 .64064 .35298 .64135 .35199 .63962 Mtetra
.62 .617 .826 r
.35199 .63962 .35298 .64135 .35464 .64095 .35365 .63924 Mtetra
.694 .651 .802 r
.35365 .63924 .35464 .64095 .35632 .64018 .35533 .63836 Mtetra
.656 .623 .805 r
.35533 .63836 .35632 .64018 .35799 .63961 .35701 .63775 Mtetra
.608 .597 .815 r
.35701 .63775 .35799 .63961 .35966 .63918 .35867 .63743 Mtetra
.611 .612 .827 r
.35867 .63743 .35966 .63918 .36133 .63856 .36033 .6371 Mtetra
.633 .659 .857 r
.36033 .6371 .36133 .63856 .36304 .63729 .362 .63667 Mtetra
.637 .83 .975 r
.362 .63667 .36304 .63729 .36478 .63529 .36367 .63615 Mtetra
.089 0 0 r
.36367 .63615 .36478 .63529 .36654 .63282 .36535 .6356 Mtetra
.47 .124 .297 r
.36535 .6356 .36654 .63282 .36825 .63152 .36701 .63538 Mtetra
.498 .184 .365 r
.36701 .63538 .36825 .63152 .3699 .63146 .36867 .6352 Mtetra
.432 .119 .333 r
.36867 .6352 .3699 .63146 .37158 .63084 .37036 .63447 Mtetra
.002 0 .133 r
.37036 .63447 .37158 .63084 .37347 .62539 .37214 .63156 Mtetra
.938 .805 .347 r
.37214 .63156 .37347 .62539 .38364 .42937 .37442 .61739 Mtetra
0 0 .26 r
.37442 .61739 .38364 .42937 .38541 .42441 .38439 .42505 Mtetra
.947 .959 .709 r
.38439 .42505 .38541 .42441 .38705 .42258 .38607 .4222 Mtetra
.738 .898 .951 r
.38607 .4222 .38705 .42258 .38863 .42207 .38766 .42134 Mtetra
.602 .781 .966 r
.38766 .42134 .38863 .42207 .39019 .42195 .38924 .42098 Mtetra
.608 .727 .93 r
.38924 .42098 .39019 .42195 .39176 .42174 .39082 .42065 Mtetra
.645 .714 .898 r
.39082 .42065 .39176 .42174 .39334 .42129 .3924 .4202 Mtetra
.637 .711 .9 r
.3924 .4202 .39334 .42129 .39493 .42079 .39398 .41978 Mtetra
.644 .728 .91 r
.39398 .41978 .39493 .42079 .39652 .42021 .39556 .41932 Mtetra
.655 .76 .927 r
.39556 .41932 .39652 .42021 .39811 .41956 .39715 .41882 Mtetra
.655 .797 .951 r
.39715 .41882 .39811 .41956 .3997 .41889 .39874 .41831 Mtetra
.648 .834 .972 r
.39874 .41831 .3997 .41889 .40129 .41828 .40033 .41778 Mtetra
.64 .855 .982 r
.40033 .41778 .40129 .41828 .40288 .41772 .40192 .41725 Mtetra
.639 .861 .983 r
.40192 .41725 .40288 .41772 .40447 .41718 .40351 .41671 Mtetra
.639 .86 .983 r
.40351 .41671 .40447 .41718 .40607 .41665 .4051 .41617 Mtetra
.64 .859 .983 r
.4051 .41617 .40607 .41665 .40766 .41611 .40669 .41563 Mtetra
.64 .86 .983 r
.40669 .41563 .40766 .41611 .40925 .41557 .40829 .41509 Mtetra
.641 .859 .982 r
.40829 .41509 .40925 .41557 .41085 .41503 .40988 .41454 Mtetra
.641 .858 .982 r
.40988 .41454 .41085 .41503 .41244 .41449 .41148 .414 Mtetra
.643 .859 .981 r
.41148 .414 .41244 .41449 .41404 .41397 .41308 .41345 Mtetra
.65 .854 .978 r
.41308 .41345 .41404 .41397 .41563 .4135 .41468 .41289 Mtetra
.663 .833 .965 r
.41468 .41289 .41563 .4135 .41723 .41309 .41628 .41232 Mtetra
.672 .795 .941 r
.41628 .41232 .41723 .41309 .41882 .41268 .41788 .41175 Mtetra
.676 .758 .913 r
.41788 .41175 .41882 .41268 .42042 .41222 .41948 .41116 Mtetra
.676 .731 .891 r
.41948 .41116 .42042 .41222 .42202 .41169 .42109 .41056 Mtetra
.67 .716 .883 r
.42109 .41056 .42202 .41169 .42363 .41111 .42269 .40999 Mtetra
.655 .713 .89 r
.42269 .40999 .42363 .41111 .42523 .41045 .42429 .40948 Mtetra
.633 .737 .923 r
.42429 .40948 .42523 .41045 .42684 .40972 .42589 .40906 Mtetra
.609 .805 .975 r
.42589 .40906 .42684 .40972 .42845 .409 .42749 .40866 Mtetra
.662 .901 .98 r
.42749 .40866 .42845 .409 .43007 .4082 .4291 .408 Mtetra
.729 .943 .953 r
.4291 .408 .43007 .4082 .43168 .40736 .43072 .40708 Mtetra
.546 .881 .989 r
.43072 .40708 .43168 .40736 .43329 .40688 .43233 .40663 Mtetra
.615 .047 0 r
.43233 .40663 .43329 .40688 .43487 .40741 .43389 .4078 Mtetra
.929 .613 .421 r
.43389 .4078 .43487 .40741 .43638 .41045 .43518 .41902 Mtetra
.943 .671 .492 r
.43518 .41902 .43638 .41045 .43277 .60426 .4315 .61321 Mtetra
.624 .351 .484 r
.4315 .61321 .43277 .60426 .43423 .613 .43313 .61575 Mtetra
.483 .134 .298 r
.43313 .61575 .43423 .613 .43589 .61477 .43484 .61563 Mtetra
.003 0 0 r
.43484 .61563 .43589 .61477 .43757 .61546 .43656 .61491 Mtetra
.711 .869 .956 r
.43656 .61491 .43757 .61546 .43928 .61551 .43829 .6141 Mtetra
.643 .674 .865 r
.43829 .6141 .43928 .61551 .44099 .6151 .44001 .61361 Mtetra
.648 .664 .852 r
.44001 .61361 .44099 .6151 .44272 .61451 .44173 .61308 Mtetra
.659 .679 .857 r
.44173 .61308 .44272 .61451 .44444 .61395 .44346 .6125 Mtetra
.671 .679 .849 r
.44346 .6125 .44444 .61395 .44616 .61362 .44518 .61184 Mtetra
.663 .635 .812 r
.44518 .61184 .44616 .61362 .44788 .61327 .44691 .61117 Mtetra
.625 .586 .79 r
.44691 .61117 .44788 .61327 .4496 .61293 .44864 .61072 Mtetra
.57 .548 .791 r
.44864 .61072 .4496 .61293 .45132 .61259 .45035 .61062 Mtetra
.644 .607 .797 r
.45035 .61062 .45132 .61259 .45306 .6119 .45208 .61004 Mtetra
.789 .677 .741 r
.45208 .61004 .45306 .6119 .45481 .61022 .45385 .60795 Mtetra
.908 .689 .594 r
.45385 .60795 .45481 .61022 .45662 .60573 .45576 .59841 Mtetra
.951 .682 .491 r
.45576 .59841 .45662 .60573 .4621 .4119 .46138 .39992 Mtetra
.649 .441 .588 r
.46138 .39992 .4621 .4119 .46392 .40138 .46307 .39618 Mtetra
.617 .46 .646 r
.46307 .39618 .46392 .40138 .46556 .40018 .46471 .39526 Mtetra
.584 .441 .653 r
.46471 .39526 .46556 .40018 .46718 .39997 .46633 .3949 Mtetra
.572 .43 .65 r
.46633 .3949 .46718 .39997 .4688 .40017 .46796 .39471 Mtetra
.59 .437 .642 r
.46796 .39471 .4688 .40017 .47043 .40003 .46959 .3942 Mtetra
.588 .431 .636 r
.46959 .3942 .47043 .40003 .47206 .39953 .47122 .3937 Mtetra
.47122 .3937 .47206 .39953 .47371 .39806 .47285 .39318 Mtetra
.598 .452 .654 r
.47285 .39318 .47371 .39806 .47537 .39553 .47448 .39263 Mtetra
.624 .524 .721 r
.47448 .39263 .47537 .39553 .47703 .39347 .47612 .39206 Mtetra
.66 .668 .847 r
.47612 .39206 .47703 .39347 .47868 .39202 .47775 .39149 Mtetra
.643 .854 .98 r
.47775 .39149 .47868 .39202 .48032 .39133 .47939 .39094 Mtetra
.619 .882 .989 r
.47939 .39094 .48032 .39133 .48195 .39084 .48103 .39038 Mtetra
.631 .869 .987 r
.48103 .39038 .48195 .39084 .48359 .39042 .48267 .38983 Mtetra
.649 .841 .974 r
.48267 .38983 .48359 .39042 .48523 .38987 .48431 .38928 Mtetra
.649 .84 .973 r
.48431 .38928 .48523 .38987 .48687 .38932 .48595 .38873 Mtetra
.65 .838 .973 r
.48595 .38873 .48687 .38932 .48851 .38878 .48759 .38817 Mtetra
.651 .836 .972 r
.48759 .38817 .48851 .38878 .49015 .38822 .48923 .38762 Mtetra
.651 .836 .971 r
.48923 .38762 .49015 .38822 .49179 .38767 .49087 .38706 Mtetra
.49087 .38706 .49179 .38767 .49344 .38711 .49252 .3865 Mtetra
.49252 .3865 .49344 .38711 .49508 .38656 .49416 .38595 Mtetra
.65 .836 .972 r
.49416 .38595 .49508 .38656 .49673 .38601 .49581 .38539 Mtetra
.49581 .38539 .49673 .38601 .49837 .38545 .49746 .38484 Mtetra
.49746 .38484 .49837 .38545 .50002 .3849 .49911 .38429 Mtetra
.49911 .38429 .50002 .3849 .50167 .38434 .50076 .38373 Mtetra
.649 .836 .972 r
.50076 .38373 .50167 .38434 .50332 .38379 .50241 .38318 Mtetra
.649 .837 .972 r
.50241 .38318 .50332 .38379 .50497 .38323 .50406 .38262 Mtetra
.50406 .38262 .50497 .38323 .50662 .38268 .50571 .38207 Mtetra
.50571 .38207 .50662 .38268 .50827 .38213 .50736 .38152 Mtetra
.649 .837 .973 r
.50736 .38152 .50827 .38213 .50993 .38157 .50902 .38096 Mtetra
.50902 .38096 .50993 .38157 .51158 .38102 .51067 .38041 Mtetra
.51067 .38041 .51158 .38102 .51324 .38046 .51233 .37985 Mtetra
.648 .837 .973 r
.51233 .37985 .51324 .38046 .51489 .37991 .51399 .3793 Mtetra
.51399 .3793 .51489 .37991 .51655 .37936 .51564 .37874 Mtetra
.648 .836 .973 r
.51564 .37874 .51655 .37936 .51821 .3788 .5173 .37819 Mtetra
.5173 .37819 .51821 .3788 .51987 .37825 .51896 .37764 Mtetra
.51896 .37764 .51987 .37825 .52153 .3777 .52063 .37708 Mtetra
.52063 .37708 .52153 .3777 .52319 .37715 .52229 .37653 Mtetra
.648 .836 .972 r
.52229 .37653 .52319 .37715 .52485 .37659 .52395 .37597 Mtetra
.648 .835 .972 r
.52395 .37597 .52485 .37659 .52652 .37604 .52562 .37542 Mtetra
.52562 .37542 .52652 .37604 .52818 .37549 .52728 .37487 Mtetra
.52728 .37487 .52818 .37549 .52985 .37494 .52895 .37431 Mtetra
.648 .834 .972 r
.52895 .37431 .52985 .37494 .53151 .37439 .53061 .37376 Mtetra
.53061 .37376 .53151 .37439 .53318 .37383 .53228 .3732 Mtetra
.53228 .3732 .53318 .37383 .53485 .37328 .53395 .37265 Mtetra
.649 .834 .971 r
.53395 .37265 .53485 .37328 .53652 .37272 .53562 .37209 Mtetra
.649 .834 .972 r
.53562 .37209 .53652 .37272 .53819 .37216 .53729 .37154 Mtetra
.649 .835 .972 r
.53729 .37154 .53819 .37216 .53986 .3716 .53897 .37098 Mtetra
.649 .837 .973 r
.53897 .37098 .53986 .3716 .54153 .37103 .54064 .37042 Mtetra
.648 .838 .973 r
.54064 .37042 .54153 .37103 .54321 .37047 .54231 .36986 Mtetra
.649 .84 .974 r
.54231 .36986 .54321 .37047 .54488 .36976 .54399 .36929 Mtetra
.629 .872 .988 r
.54399 .36929 .54488 .36976 .54655 .36916 .54567 .36873 Mtetra
.622 .879 .989 r
.54567 .36873 .54655 .36916 .54823 .36878 .54734 .36816 Mtetra
.65 .838 .973 r
.54734 .36816 .54823 .36878 .54992 .36929 .54902 .36759 Mtetra
.651 .632 .818 r
.54902 .36759 .54992 .36929 .55161 .37029 .5507 .36703 Mtetra
.617 .507 .706 r
.5507 .36703 .55161 .37029 .55331 .37173 .55238 .36646 Mtetra
.62 .461 .645 r
.55238 .36646 .55331 .37173 .55499 .37093 .55406 .36546 Mtetra
.6 .445 .643 r
.55406 .36546 .55499 .37093 .55667 .37009 .55574 .36477 Mtetra
.561 .42 .647 r
.55574 .36477 .55667 .37009 .55836 .37015 .55743 .36472 Mtetra
.181 .156 .592 r
.55743 .36472 .55836 .37015 .56218 .5627 .55916 .36846 Mtetra
0 0 .36 r
.55916 .36846 .56218 .5627 .56411 .57484 .56312 .5696 Mtetra
0 0 .465 r
.56312 .5696 .56411 .57484 .56595 .57771 .565 .57564 Mtetra
.475 .512 .817 r
.565 .57564 .56595 .57771 .56776 .57781 .56681 .57601 Mtetra
.652 .634 .82 r
.56681 .57601 .56776 .57781 .56956 .57722 .56861 .5754 Mtetra
.704 .654 .798 r
.56861 .5754 .56956 .57722 .57136 .57634 .57041 .57438 Mtetra
.623 .603 .81 r
.57041 .57438 .57136 .57634 .57317 .57574 .57221 .57394 Mtetra
.612 .615 .83 r
.57221 .57394 .57317 .57574 .57497 .57518 .57402 .57358 Mtetra
.616 .643 .854 r
.57402 .57358 .57497 .57518 .57678 .57462 .57583 .5732 Mtetra
.634 .678 .874 r
.57583 .5732 .57678 .57462 .57859 .57424 .57764 .57273 Mtetra
.642 .667 .859 r
.57764 .57273 .57859 .57424 .5804 .57378 .57945 .57221 Mtetra
.648 .662 .85 r
.57945 .57221 .5804 .57378 .58221 .57308 .58126 .57166 Mtetra
.562 .645 .89 r
.58126 .57166 .58221 .57308 .58401 .57184 .58308 .57152 Mtetra
.487 .86 .984 r
.58308 .57152 .58401 .57184 .58579 .56991 .5849 .5711 Mtetra
.002 0 0 r
.5849 .5711 .58579 .56991 .58756 .56664 .5867 .56999 Mtetra
0 0 0 r
.5867 .56999 .58756 .56664 .5857 .37304 .58844 .56517 Mtetra
0 0 .355 r
.58844 .56517 .5857 .37304 .58714 .35896 .58636 .36274 Mtetra
0 0 0 r
.58636 .36274 .58714 .35896 .58878 .35541 .58793 .35542 Mtetra
.842 .99 .855 r
.58793 .35542 .58878 .35541 .59047 .35415 .58961 .35382 Mtetra
.573 .888 .989 r
.58961 .35382 .59047 .35415 .59218 .35361 .59132 .35329 Mtetra
.328 .773 .961 r
.59132 .35329 .59218 .35361 .59389 .35339 .59303 .35316 Mtetra
.556 .904 .974 r
.59303 .35316 .59389 .35339 .5956 .35304 .59474 .35259 Mtetra
.67 .891 .978 r
.59474 .35259 .5956 .35304 .59731 .35266 .59644 .35189 Mtetra
.688 .814 .942 r
.59644 .35189 .59731 .35266 .59902 .35224 .59815 .3512 Mtetra
.664 .745 .91 r
.59815 .3512 .59902 .35224 .60073 .35163 .59986 .35062 Mtetra
.653 .748 .919 r
.59986 .35062 .60073 .35163 .60244 .35094 .60157 .3501 Mtetra
.647 .785 .948 r
.60157 .3501 .60244 .35094 .60414 .35022 .60328 .34957 Mtetra
.654 .836 .97 r
.60328 .34957 .60414 .35022 .60585 .34945 .605 .34898 Mtetra
.639 .88 .986 r
.605 .34898 .60585 .34945 .60756 .34877 .60671 .34837 Mtetra
.625 .892 .988 r
.60671 .34837 .60756 .34877 .60928 .34832 .60842 .34776 Mtetra
.744 .882 .943 r
.60842 .34776 .60928 .34832 .61101 .34832 .61013 .34682 Mtetra
.686 .675 .834 r
.61013 .34682 .61101 .34832 .61276 .34893 .61184 .34607 Mtetra
.579 .503 .734 r
.61184 .34607 .61276 .34893 .61454 .35071 .61357 .3459 Mtetra
.279 .239 .633 r
.61357 .3459 .61454 .35071 .62164 .53699 .61538 .34864 Mtetra
0 0 .376 r
.61538 .34864 .62164 .53699 .62406 .55666 .62295 .54896 Mtetra
0 0 .473 r
.62295 .54896 .62406 .55666 .626 .55965 .62504 .55722 Mtetra
.333 .395 .776 r
.62504 .55722 .626 .55965 .62788 .56018 .62693 .55836 Mtetra
.601 .61 .833 r
.62693 .55836 .62788 .56018 .62972 .55973 .62878 .55806 Mtetra
.68 .665 .828 r
.62878 .55806 .62972 .55973 .63155 .55873 .63062 .55727 Mtetra
.667 .688 .86 r
.63062 .55727 .63155 .55873 .63336 .55713 .63246 .55661 Mtetra
.622 .87 .989 r
.63246 .55661 .63336 .55713 .63515 .55496 .63431 .556 Mtetra
.17 0 0 r
.63431 .556 .63515 .55496 .63693 .55229 .63615 .55537 Mtetra
.48 .142 .315 r
.63615 .55537 .63693 .55229 .63876 .55126 .63801 .55516 Mtetra
.488 .173 .358 r
.63801 .55516 .63876 .55126 .64061 .5511 .63987 .55486 Mtetra
.421 .112 .333 r
.63987 .55486 .64061 .5511 .64245 .55024 .64171 .55395 Mtetra
0 0 .175 r
.64171 .55395 .64245 .55024 .64402 .5419 .64345 .55022 Mtetra
.981 .697 .401 r
.64345 .55022 .64402 .5419 .63874 .34311 .6382 .35097 Mtetra
0 0 .131 r
.6382 .35097 .63874 .34311 .64034 .33868 .63953 .33894 Mtetra
.905 .984 .736 r
.63953 .33894 .64034 .33868 .64203 .33712 .6412 .33658 Mtetra
.712 .884 .96 r
.6412 .33658 .64203 .33712 .64377 .33663 .64293 .33576 Mtetra
.596 .763 .959 r
.64293 .33576 .64377 .33663 .64552 .33648 .64467 .3354 Mtetra
.628 .726 .918 r
.64467 .3354 .64552 .33648 .64727 .33615 .64642 .33497 Mtetra
.65 .716 .897 r
.64642 .33497 .64727 .33615 .64901 .33561 .64816 .33445 Mtetra
.646 .718 .9 r
.64816 .33445 .64901 .33561 .65075 .33502 .6499 .33394 Mtetra
.663 .741 .909 r
.6499 .33394 .65075 .33502 .65248 .33421 .65164 .33336 Mtetra
.673 .797 .941 r
.65164 .33336 .65248 .33421 .65421 .33336 .65338 .33273 Mtetra
.663 .85 .971 r
.65338 .33273 .65421 .33336 .65595 .3327 .65512 .33209 Mtetra
.741 .873 .941 r
.65512 .33209 .65595 .3327 .65771 .33252 .65685 .33116 Mtetra
.707 .705 .846 r
.65685 .33116 .65771 .33252 .6595 .33297 .65859 .33029 Mtetra
.597 .525 .744 r
.65859 .33029 .6595 .33297 .66134 .33438 .66035 .32997 Mtetra
.339 .292 .659 r
.66035 .32997 .66134 .33438 .6634 .34102 .66221 .33209 Mtetra
.98 .687 .372 r
.66221 .33209 .6634 .34102 .674 .53997 .67277 .53115 Mtetra
0 0 .423 r
.67277 .53115 .674 .53997 .67607 .5438 .67515 .5422 Mtetra
0 .219 .742 r
.67515 .5422 .67607 .5438 .67802 .54501 .67713 .54401 Mtetra
.529 .719 .96 r
.67713 .54401 .67802 .54501 .67992 .54498 .67902 .54385 Mtetra
.762 .778 .866 r
.67902 .54385 .67992 .54498 .68178 .54399 .68087 .54265 Mtetra
.899 .763 .702 r
.68087 .54265 .68178 .54399 .68351 .54037 .68261 .53908 Mtetra
.975 .686 .407 r
.68261 .53908 .68351 .54037 .67579 .33872 .67526 .34425 Mtetra
.88 .715 .199 r
.67526 .34425 .67579 .33872 .67701 .32693 .67622 .3268 Mtetra
.952 .929 .741 r
.67622 .3268 .67701 .32693 .67867 .32438 .67787 .32405 Mtetra
.713 .938 .959 r
.67787 .32405 .67867 .32438 .68042 .32366 .67961 .32312 Mtetra
.574 .844 .996 r
.67961 .32312 .68042 .32366 .68221 .32358 .68138 .32268 Mtetra
.681 .79 .932 r
.68138 .32268 .68221 .32358 .684 .3237 .68314 .32202 Mtetra
.684 .654 .815 r
.68314 .32202 .684 .3237 .68581 .32404 .68489 .32121 Mtetra
.594 .516 .736 r
.68489 .32121 .68581 .32404 .68767 .32521 .68666 .32091 Mtetra
.401 .337 .67 r
.68666 .32091 .68767 .32521 .68975 .33071 .68854 .32251 Mtetra
0 0 .368 r
.68854 .32251 .68975 .33071 .70216 .53147 .69097 .33449 Mtetra
.01 0 .419 r
.69097 .33449 .70216 .53147 .7043 .53566 .70331 .53258 Mtetra
.193 .26 .705 r
.70331 .53258 .7043 .53566 .70628 .53676 .70535 .53483 Mtetra
.561 .58 .83 r
.70535 .53483 .70628 .53676 .70819 .53649 .70727 .53475 Mtetra
.659 .651 .831 r
.70727 .53475 .70819 .53649 .71007 .53563 .70916 .53408 Mtetra
.631 .662 .862 r
.70916 .53408 .71007 .53563 .71193 .5344 .71106 .5336 Mtetra
.539 .773 .984 r
.71106 .5336 .71193 .5344 .71377 .53275 .71298 .53333 Mtetra
0 0 0 r
.71298 .53333 .71377 .53275 .71555 .53012 .71486 .53249 Mtetra
0 0 .044 r
.71486 .53249 .71555 .53012 .71708 .5232 .71663 .52964 Mtetra
0 0 .058 r
.71663 .52964 .71708 .5232 .70728 .32116 .71786 .51747 Mtetra
.007 0 .413 r
.71786 .51747 .70728 .32116 .70881 .31621 .70809 .31702 Mtetra
.855 .919 .523 r
.70809 .31702 .70881 .31621 .7105 .31421 .70972 .31376 Mtetra
.745 .922 .95 r
.70972 .31376 .7105 .31421 .71228 .31358 .71147 .31276 Mtetra
.625 .79 .961 r
.71147 .31276 .71228 .31358 .71408 .31333 .71326 .31228 Mtetra
.623 .734 .927 r
.71326 .31228 .71408 .31333 .71587 .31289 .71505 .31185 Mtetra
.666 .755 .916 r
.71505 .31185 .71587 .31289 .71763 .31206 .71683 .31124 Mtetra
.65 .803 .956 r
.71683 .31124 .71763 .31206 .71941 .31137 .71861 .31067 Mtetra
.697 .849 .955 r
.71861 .31067 .71941 .31137 .72121 .31107 .72039 .30991 Mtetra
.719 .75 .877 r
.72039 .30991 .72121 .31107 .72305 .31139 .72215 .30901 Mtetra
.615 .557 .766 r
.72215 .30901 .72305 .31139 .72495 .31257 .72395 .30858 Mtetra
.435 .37 .686 r
.72395 .30858 .72495 .31257 .72708 .31727 .72586 .3098 Mtetra
0 0 .461 r
.72586 .3098 .72708 .31727 .74202 .51894 .72829 .31915 Mtetra
.03 0 .431 r
.72829 .31915 .74202 .51894 .74427 .52352 .74326 .52029 Mtetra
.165 .234 .689 r
.74326 .52029 .74427 .52352 .74631 .52479 .74539 .52286 Mtetra
.591 .598 .827 r
.74539 .52286 .74631 .52479 .74825 .52446 .74733 .5226 Mtetra
.682 .651 .812 r
.74733 .5226 .74825 .52446 .75015 .52368 .74923 .52173 Mtetra
.674 .637 .805 r
.74923 .52173 .75015 .52368 .75206 .52293 .75114 .52089 Mtetra
.606 .595 .813 r
.75114 .52089 .75206 .52293 .754 .52248 .75308 .52054 Mtetra
.61 .606 .823 r
.75308 .52054 .754 .52248 .75592 .52185 .75502 .52016 Mtetra
.594 .629 .856 r
.75502 .52016 .75592 .52185 .75782 .52086 .75696 .51988 Mtetra
.548 .737 .963 r
.75696 .51988 .75782 .52086 .75967 .51926 .75892 .51964 Mtetra
0 0 0 r
.75892 .51964 .75967 .51926 .76146 .51676 .76083 .51888 Mtetra
0 0 .048 r
.76083 .51888 .76146 .51676 .76302 .51099 .76263 .51648 Mtetra
0 0 .11 r
.76263 .51648 .76302 .51099 .75035 .30773 .76392 .50685 Mtetra
.029 0 .426 r
.76392 .50685 .75035 .30773 .75179 .30214 .75114 .3032 Mtetra
.809 .863 .417 r
.75114 .3032 .75179 .30214 .75347 .29976 .75272 .29946 Mtetra
.684 .945 .96 r
.75272 .29946 .75347 .29976 .75526 .29893 .75451 .29855 Mtetra
.448 .832 .987 r
.75451 .29855 .75526 .29893 .75708 .29854 .75633 .29824 Mtetra
.37 .806 .961 r
.75633 .29824 .75708 .29854 .75891 .2983 .75817 .29799 Mtetra
.601 .918 .975 r
.75817 .29799 .75891 .2983 .76074 .29791 .75997 .2973 Mtetra
.666 .867 .975 r
.75997 .2973 .76074 .29791 .76256 .29752 .76178 .29661 Mtetra
.671 .791 .939 r
.76178 .29661 .76256 .29752 .76438 .29703 .76358 .29596 Mtetra
.653 .749 .92 r
.76358 .29596 .76438 .29703 .76619 .29635 .7654 .2954 Mtetra
.648 .774 .94 r
.7654 .2954 .76619 .29635 .76799 .29561 .76722 .29485 Mtetra
.644 .818 .967 r
.76722 .29485 .76799 .29561 .7698 .29489 .76904 .29428 Mtetra
.644 .859 .981 r
.76904 .29428 .7698 .29489 .77161 .29423 .77085 .29365 Mtetra
.648 .87 .982 r
.77085 .29365 .77161 .29423 .77342 .29357 .77267 .293 Mtetra
.659 .874 .979 r
.77267 .293 .77342 .29357 .77523 .29286 .77448 .29231 Mtetra
.668 .883 .978 r
.77448 .29231 .77523 .29286 .77703 .29204 .77629 .29159 Mtetra
.653 .904 .981 r
.77629 .29159 .77703 .29204 .77884 .29136 .7781 .29086 Mtetra
.698 .905 .969 r
.7781 .29086 .77884 .29136 .78068 .29097 .7799 .29001 Mtetra
.759 .809 .892 r
.7799 .29001 .78068 .29097 .78256 .29111 .78168 .28892 Mtetra
.645 .591 .779 r
.78168 .28892 .78256 .29111 .78451 .2919 .7835 .28827 Mtetra
.506 .429 .704 r
.7835 .28827 .78451 .2919 .7866 .29453 .78542 .28879 Mtetra
.073 .089 .57 r
.78542 .28879 .7866 .29453 .80545 .49512 .78778 .29444 Mtetra
.05 0 .446 r
.78778 .29444 .80545 .49512 .80811 .50282 .80712 .49992 Mtetra
0 .026 .588 r
.80712 .49992 .80811 .50282 .8103 .50493 .80947 .50395 Mtetra
.317 .614 .954 r
.80947 .50395 .8103 .50493 .81232 .50506 .81152 .50433 Mtetra
.676 .853 .967 r
.81152 .50433 .81232 .50506 .81427 .50436 .81347 .50357 Mtetra
.896 .87 .805 r
.81347 .50357 .81427 .50436 .81614 .50261 .81529 .50128 Mtetra
.972 .752 .545 r
.81529 .50128 .81614 .50261 .81778 .4983 .81657 .49287 Mtetra
.975 .672 .357 r
.81657 .49287 .81778 .4983 .80239 .30227 .80035 .28705 Mtetra
.637 .422 .574 r
.80035 .28705 .80239 .30227 .80299 .28778 .80185 .28268 Mtetra
.621 .466 .651 r
.80185 .28268 .80299 .28778 .80464 .28504 .80365 .28165 Mtetra
.598 .495 .709 r
.80365 .28165 .80464 .28504 .80638 .28336 .80551 .28125 Mtetra
.58 .562 .799 r
.80551 .28125 .80638 .28336 .80817 .28222 .80739 .28107 Mtetra
.664 .74 .906 r
.80739 .28107 .80817 .28222 .81 .28148 .80923 .28045 Mtetra
.662 .763 .925 r
.80923 .28045 .81 .28148 .81184 .28092 .81107 .27984 Mtetra
.671 .757 .915 r
.81107 .27984 .81184 .28092 .81369 .28029 .81291 .27918 Mtetra
.728 .773 .889 r
.81291 .27918 .81369 .28029 .81547 .27904 .81472 .27823 Mtetra
.635 .81 .967 r
.81472 .27823 .81547 .27904 .81729 .2782 .81657 .27769 Mtetra
.084 .566 .901 r
.81657 .27769 .81729 .2782 .81921 .27834 .81852 .27813 Mtetra
.891 .468 .095 r
.81852 .27813 .81921 .27834 .82158 .28319 .821 .28416 Mtetra
.973 .66 .32 r
.821 .28416 .82158 .28319 .84336 .48993 .84262 .48954 Mtetra
.809 .334 0 r
.84262 .48954 .84336 .48993 .84586 .49468 .84505 .49357 Mtetra
.331 .591 .939 r
.84505 .49357 .84586 .49468 .84796 .49517 .84714 .49402 Mtetra
.66 .754 .92 r
.84714 .49402 .84796 .49517 .84994 .49451 .84912 .49337 Mtetra
.842 .812 .821 r
.84912 .49337 .84994 .49451 .8518 .49255 .85098 .49146 Mtetra
.977 .779 .571 r
.85098 .49146 .8518 .49255 .85318 .48586 .85237 .48476 Mtetra
.976 .67 .326 r
.85237 .48476 .85318 .48586 .83451 .27835 .83374 .2772 Mtetra
.965 .78 .604 r
.83374 .2772 .83451 .27835 .83589 .27296 .83512 .27181 Mtetra
.76 .778 .868 r
.83512 .27181 .83589 .27296 .83769 .2718 .83692 .27065 Mtetra
.628 .727 .918 r
.83692 .27065 .83769 .2718 .83957 .27133 .8388 .27019 Mtetra
.548 .689 .932 r
.8388 .27019 .83957 .27133 .84147 .27117 .84071 .27003 Mtetra
.748 .775 .875 r
.84071 .27003 .84147 .27117 .84329 .27009 .84252 .26895 Mtetra
.679 .75 .905 r
.84252 .26895 .84329 .27009 .84514 .26939 .84438 .26825 Mtetra
.463 .645 .937 r
.84438 .26825 .84514 .26939 .84708 .2695 .84632 .26837 Mtetra
.845 .448 0 r
.84632 .26837 .84708 .2695 .84974 .27651 .84898 .27538 Mtetra
.971 .656 .295 r
.84898 .27538 .84974 .27651 .8734 .48245 .8726 .48136 Mtetra
0 0 .444 r
.8726 .48136 .8734 .48245 .87579 .48555 .875 .4845 Mtetra
.979 .789 .578 r
.875 .4845 .87579 .48555 .87714 .47873 .8764 .47821 Mtetra
.974 .667 .31 r
.8764 .47821 .87714 .47873 .85678 .26976 .8561 .26933 Mtetra
.995 .838 .571 r
.8561 .26933 .85678 .26976 .85818 .26481 .85747 .26406 Mtetra
.887 .457 .11 r
.25395 .46496 .25495 .46588 .25619 .46869 .25518 .46778 Mtetra
.937 .682 .526 r
.25518 .46778 .25619 .46869 .24177 .66433 .24069 .66351 Mtetra
.938 .614 .395 r
.24069 .66351 .24177 .66433 .24273 .67163 .24166 .67076 Mtetra
0 .362 .803 r
.24166 .67076 .24273 .67163 .24423 .67239 .24316 .67153 Mtetra
.625 .759 .943 r
.24316 .67153 .24423 .67239 .24583 .672 .24475 .67113 Mtetra
.809 .779 .825 r
.24475 .67113 .24583 .672 .24751 .67053 .24644 .66961 Mtetra
.91 .732 .649 r
.24644 .66961 .24751 .67053 .2495 .66502 .24848 .6636 Mtetra
.937 .686 .533 r
.24848 .6636 .2495 .66502 .26657 .46757 .26565 .46568 Mtetra
.866 .68 .649 r
.26565 .46568 .26657 .46757 .2685 .46172 .26754 .46033 Mtetra
.731 .683 .804 r
.26754 .46033 .2685 .46172 .27006 .46057 .26909 .4593 Mtetra
.595 .654 .879 r
.26909 .4593 .27006 .46057 .27157 .46022 .27059 .45907 Mtetra
.44 .61 .92 r
.27059 .45907 .27157 .46022 .27304 .46027 .27205 .45925 Mtetra
.618 .71 .911 r
.27205 .45925 .27304 .46027 .27455 .45988 .27355 .45892 Mtetra
.641 .729 .912 r
.27355 .45892 .27455 .45988 .27606 .45943 .27506 .45849 Mtetra
.653 .739 .912 r
.27506 .45849 .27606 .45943 .27757 .45895 .27658 .45803 Mtetra
.665 .745 .91 r
.27658 .45803 .27757 .45895 .2791 .45838 .2781 .45751 Mtetra
.677 .76 .913 r
.2781 .45751 .2791 .45838 .28062 .45778 .27962 .45695 Mtetra
.689 .77 .913 r
.27962 .45695 .28062 .45778 .28215 .45719 .28115 .45633 Mtetra
.76 .775 .865 r
.28115 .45633 .28215 .45719 .2837 .45624 .28271 .45532 Mtetra
.727 .759 .878 r
.28271 .45532 .2837 .45624 .28524 .45558 .28426 .4545 Mtetra
.627 .703 .9 r
.28426 .4545 .28524 .45558 .28672 .45555 .28577 .45413 Mtetra
0 0 .552 r
.28577 .45413 .28672 .45555 .28796 .45905 .28714 .4558 Mtetra
.81 .519 0 r
.28714 .4558 .28796 .45905 .27539 .65495 .28824 .46112 Mtetra
0 0 .224 r
.28824 .46112 .27539 .65495 .27654 .66104 .27594 .65368 Mtetra
.485 .342 .611 r
.27594 .65368 .27654 .66104 .27809 .66158 .27744 .65484 Mtetra
.6 .432 .626 r
.27744 .65484 .27809 .66158 .27971 .66105 .27909 .65402 Mtetra
.601 .431 .623 r
.27909 .65402 .27971 .66105 .28136 .6601 .28073 .65313 Mtetra
.385 .271 .6 r
.28073 .65313 .28136 .6601 .28298 .65967 .28216 .65544 Mtetra
.303 .267 .651 r
.28216 .65544 .28298 .65967 .28459 .65935 .28362 .65732 Mtetra
.214 .353 .789 r
.28362 .65732 .28459 .65935 .28621 .65902 .28513 .65842 Mtetra
.423 .752 .995 r
.28513 .65842 .28621 .65902 .28783 .6586 .28673 .65835 Mtetra
.55 .885 .987 r
.28673 .65835 .28783 .6586 .28945 .65813 .28835 .65787 Mtetra
.623 .906 .984 r
.28835 .65787 .28945 .65813 .29108 .65763 .28999 .65726 Mtetra
.535 .854 .997 r
.28999 .65726 .29108 .65763 .29271 .65714 .29161 .65688 Mtetra
.444 .84 .979 r
.29161 .65688 .29271 .65714 .29434 .65665 .29323 .65658 Mtetra
.353 .819 .913 r
.29323 .65658 .29434 .65665 .29597 .65616 .29485 .65625 Mtetra
.313 .804 .84 r
.29485 .65625 .29597 .65616 .2976 .65569 .29648 .65584 Mtetra
.322 .809 .82 r
.29648 .65584 .2976 .65569 .29923 .65524 .29811 .65538 Mtetra
.368 .837 .843 r
.29811 .65538 .29923 .65524 .30086 .65478 .29975 .65487 Mtetra
.463 .888 .895 r
.29975 .65487 .30086 .65478 .30249 .65431 .30139 .65428 Mtetra
.549 .917 .948 r
.30139 .65428 .30249 .65431 .30413 .65383 .30303 .65365 Mtetra
.605 .916 .977 r
.30303 .65365 .30413 .65383 .30576 .65333 .30468 .65302 Mtetra
.456 .836 .987 r
.30468 .65302 .30576 .65333 .30738 .65321 .3063 .65273 Mtetra
.55 .834 .998 r
.3063 .65273 .30738 .65321 .309 .65293 .30793 .65238 Mtetra
.707 .855 .953 r
.30793 .65238 .309 .65293 .31067 .65202 .30959 .65162 Mtetra
.901 .84 .776 r
.30959 .65162 .31067 .65202 .31252 .64812 .31136 .6491 Mtetra
.987 .865 .627 r
.31136 .6491 .31252 .64812 .32601 .45242 .31331 .64358 Mtetra
0 0 .226 r
.31331 .64358 .32601 .45242 .32811 .44288 .32668 .44937 Mtetra
.189 0 .317 r
.32668 .44937 .32811 .44288 .32974 .44096 .32843 .44564 Mtetra
.495 .203 .398 r
.32843 .44564 .32974 .44096 .33129 .44041 .32997 .4453 Mtetra
.52 .229 .413 r
.32997 .4453 .33129 .44041 .33282 .44028 .33149 .44523 Mtetra
.183 0 .278 r
.33149 .44523 .33282 .44028 .33437 .43982 .33319 .44236 Mtetra
0 0 0 r
.33319 .44236 .33437 .43982 .33592 .43917 .33488 .43951 Mtetra
.906 .974 .8 r
.33488 .43951 .33592 .43917 .33748 .43854 .33652 .43746 Mtetra
.751 .739 .841 r
.33652 .43746 .33748 .43854 .33904 .438 .3381 .43642 Mtetra
.652 .636 .821 r
.3381 .43642 .33904 .438 .34059 .43751 .33966 .43589 Mtetra
.616 .615 .826 r
.33966 .43589 .34059 .43751 .34214 .43705 .3412 .43556 Mtetra
.618 .634 .844 r
.3412 .43556 .34214 .43705 .3437 .43656 .34275 .43522 Mtetra
.624 .658 .863 r
.34275 .43522 .3437 .43656 .34525 .43606 .3443 .43486 Mtetra
.626 .684 .885 r
.3443 .43486 .34525 .43606 .34681 .43554 .34585 .43449 Mtetra
.647 .72 .902 r
.34585 .43449 .34681 .43554 .34837 .43498 .3474 .43404 Mtetra
.666 .748 .911 r
.3474 .43404 .34837 .43498 .34994 .4344 .34896 .4335 Mtetra
.679 .761 .913 r
.34896 .4335 .34994 .4344 .3515 .43382 .35053 .43291 Mtetra
.738 .77 .878 r
.35053 .43291 .3515 .43382 .35308 .43298 .35211 .43202 Mtetra
.733 .759 .874 r
.35211 .43202 .35308 .43298 .35465 .43223 .35369 .43115 Mtetra
.654 .716 .894 r
.35369 .43115 .35465 .43223 .3562 .43201 .35525 .43066 Mtetra
.037 .337 .817 r
.35525 .43066 .3562 .43201 .35762 .43418 .35674 .43167 Mtetra
0 0 .238 r
.35674 .43167 .35762 .43418 .34934 .62726 .35808 .43547 Mtetra
0 0 .262 r
.35808 .43547 .34934 .62726 .35042 .63817 .34982 .62888 Mtetra
.331 .214 .566 r
.34982 .62888 .35042 .63817 .35199 .63962 .35125 .63279 Mtetra
.589 .424 .626 r
.35125 .63279 .35199 .63962 .35365 .63924 .35292 .63218 Mtetra
.605 .434 .623 r
.35292 .63218 .35365 .63924 .35533 .63836 .35461 .63118 Mtetra
.459 .326 .612 r
.35461 .63118 .35533 .63836 .35701 .63775 .35618 .63272 Mtetra
.334 .269 .634 r
.35618 .63272 .35701 .63775 .35867 .63743 .35772 .63483 Mtetra
.277 .337 .745 r
.35772 .63483 .35867 .63743 .36033 .6371 .35931 .63611 Mtetra
.364 .628 .954 r
.35931 .63611 .36033 .6371 .362 .63667 .36094 .63635 Mtetra
.518 .863 .992 r
.36094 .63635 .362 .63667 .36367 .63615 .36261 .63595 Mtetra
.588 .91 .978 r
.36261 .63595 .36367 .63615 .36535 .6356 .36429 .63535 Mtetra
.473 .856 .981 r
.36429 .63535 .36535 .6356 .36701 .63538 .36596 .63498 Mtetra
.478 .828 .997 r
.36596 .63498 .36701 .63538 .36867 .6352 .36763 .6347 Mtetra
.671 .866 .973 r
.36763 .6347 .36867 .6352 .37036 .63447 .36931 .63404 Mtetra
.871 .867 .831 r
.36931 .63404 .37036 .63447 .37214 .63156 .37105 .63215 Mtetra
.978 .893 .669 r
.37105 .63215 .37214 .63156 .37442 .61739 .37289 .62793 Mtetra
.965 .706 .492 r
.37289 .62793 .37442 .61739 .38439 .42505 .38283 .4378 Mtetra
0 0 .209 r
.38283 .4378 .38439 .42505 .38607 .4222 .38495 .42499 Mtetra
0 0 0 r
.38495 .42499 .38607 .4222 .38766 .42134 .38664 .42196 Mtetra
.795 .989 .741 r
.38664 .42196 .38766 .42134 .38924 .42098 .38828 .42015 Mtetra
.755 .792 .883 r
.38828 .42015 .38924 .42098 .39082 .42065 .38988 .41918 Mtetra
.633 .644 .843 r
.38988 .41918 .39082 .42065 .3924 .4202 .39146 .41876 Mtetra
.585 .628 .861 r
.39146 .41876 .3924 .4202 .39398 .41978 .39304 .41857 Mtetra
.603 .675 .891 r
.39304 .41857 .39398 .41978 .39556 .41932 .39461 .41828 Mtetra
.651 .725 .903 r
.39461 .41828 .39556 .41932 .39715 .41882 .3962 .4178 Mtetra
.659 .732 .904 r
.3962 .4178 .39715 .41882 .39874 .41831 .39779 .41729 Mtetra
.661 .734 .904 r
.39779 .41729 .39874 .41831 .40033 .41778 .39938 .41677 Mtetra
.39938 .41677 .40033 .41778 .40192 .41725 .40097 .41624 Mtetra
.663 .737 .905 r
.40097 .41624 .40192 .41725 .40351 .41671 .40256 .41571 Mtetra
.664 .739 .906 r
.40256 .41571 .40351 .41671 .4051 .41617 .40415 .41517 Mtetra
.665 .74 .906 r
.40415 .41517 .4051 .41617 .40669 .41563 .40575 .41463 Mtetra
.666 .741 .906 r
.40575 .41463 .40669 .41563 .40829 .41509 .40734 .41409 Mtetra
.665 .739 .905 r
.40734 .41409 .40829 .41509 .40988 .41454 .40894 .41354 Mtetra
.40894 .41354 .40988 .41454 .41148 .414 .41054 .413 Mtetra
.672 .741 .902 r
.41054 .413 .41148 .414 .41308 .41345 .41214 .41243 Mtetra
.687 .741 .892 r
.41214 .41243 .41308 .41345 .41468 .41289 .41374 .41178 Mtetra
.699 .727 .872 r
.41374 .41178 .41468 .41289 .41628 .41232 .41534 .41106 Mtetra
.692 .7 .852 r
.41534 .41106 .41628 .41232 .41788 .41175 .41695 .41034 Mtetra
.691 .678 .833 r
.41695 .41034 .41788 .41175 .41948 .41116 .41856 .4096 Mtetra
.681 .655 .817 r
.41856 .4096 .41948 .41116 .42109 .41056 .42017 .40888 Mtetra
.644 .625 .816 r
.42017 .40888 .42109 .41056 .42269 .40999 .42177 .40838 Mtetra
.519 .574 .85 r
.42177 .40838 .42269 .40999 .42429 .40948 .42335 .40846 Mtetra
0 .273 .764 r
.42335 .40846 .42429 .40948 .42589 .40906 .42491 .40953 Mtetra
.77 .323 .19 r
.42491 .40953 .42589 .40906 .42749 .40866 .42644 .41143 Mtetra
.657 .317 .385 r
.42644 .41143 .42749 .40866 .4291 .408 .42799 .41299 Mtetra
.439 .157 .386 r
.42799 .41299 .4291 .408 .43072 .40708 .42961 .41196 Mtetra
.472 .184 .395 r
.42961 .41196 .43072 .40708 .43233 .40663 .43123 .41132 Mtetra
.721 .417 .463 r
.43123 .41132 .43233 .40663 .43389 .4078 .43271 .41527 Mtetra
.945 .673 .491 r
.43271 .41527 .43389 .4078 .43518 .41902 .42887 .60985 Mtetra
.554 .332 .533 r
.42887 .60985 .43518 .41902 .4315 .61321 .43045 .61402 Mtetra
.681 .226 .165 r
.43045 .61402 .4315 .61321 .43313 .61575 .43212 .61533 Mtetra
.48 .828 .997 r
.43212 .61533 .43313 .61575 .43484 .61563 .43383 .61504 Mtetra
.682 .854 .965 r
.43383 .61504 .43484 .61563 .43656 .61491 .43556 .61434 Mtetra
.676 .858 .969 r
.43556 .61434 .43656 .61491 .43829 .6141 .43728 .61366 Mtetra
.524 .842 .999 r
.43728 .61366 .43829 .6141 .44001 .61361 .439 .6133 Mtetra
.58 .891 .989 r
.439 .6133 .44001 .61361 .44173 .61308 .44072 .61275 Mtetra
.771 .923 .937 r
.44072 .61275 .44173 .61308 .44346 .6125 .44246 .61165 Mtetra
.862 .801 .789 r
.44246 .61165 .44346 .6125 .44518 .61184 .44422 .60947 Mtetra
.802 .651 .694 r
.44422 .60947 .44518 .61184 .44691 .61117 .446 .6065 Mtetra
.717 .54 .649 r
.446 .6065 .44691 .61117 .44864 .61072 .44778 .60365 Mtetra
.562 .403 .624 r
.44778 .60365 .44864 .61072 .45035 .61062 .4495 .60355 Mtetra
.575 .413 .624 r
.4495 .60355 .45035 .61062 .45208 .61004 .45122 .60319 Mtetra
.7 .504 .619 r
.45122 .60319 .45208 .61004 .45385 .60795 .45301 .59957 Mtetra
.949 .68 .493 r
.45301 .59957 .45385 .60795 .45576 .59841 .45876 .40266 Mtetra
.558 .34 .54 r
.45876 .40266 .45576 .59841 .46138 .39992 .46049 .39717 Mtetra
.762 .609 .688 r
.46049 .39717 .46138 .39992 .46307 .39618 .46216 .39474 Mtetra
.696 .678 .828 r
.46216 .39474 .46307 .39618 .46471 .39526 .46379 .39394 Mtetra
.631 .673 .872 r
.46379 .39394 .46471 .39526 .46633 .3949 .46542 .39354 Mtetra
.609 .655 .87 r
.46542 .39354 .46633 .3949 .46796 .39471 .46704 .39323 Mtetra
.654 .656 .839 r
.46704 .39323 .46796 .39471 .46959 .3942 .46867 .39269 Mtetra
.649 .649 .836 r
.46867 .39269 .46959 .3942 .47122 .3937 .4703 .39216 Mtetra
.64 .643 .837 r
.4703 .39216 .47122 .3937 .47285 .39318 .47194 .3917 Mtetra
.623 .642 .849 r
.47194 .3917 .47285 .39318 .47448 .39263 .47357 .39132 Mtetra
.625 .672 .875 r
.47357 .39132 .47448 .39263 .47612 .39206 .4752 .39094 Mtetra
.646 .713 .897 r
.4752 .39094 .47612 .39206 .47775 .39149 .47683 .39047 Mtetra
.69 .747 .895 r
.47683 .39047 .47775 .39149 .47939 .39094 .47847 .3898 Mtetra
.694 .726 .875 r
.47847 .3898 .47939 .39094 .48103 .39038 .48011 .38909 Mtetra
.684 .696 .855 r
.48011 .38909 .48103 .39038 .48267 .38983 .48175 .3884 Mtetra
.662 .668 .845 r
.48175 .3884 .48267 .38983 .48431 .38928 .48339 .38782 Mtetra
.657 .662 .843 r
.48339 .38782 .48431 .38928 .48595 .38873 .48504 .38726 Mtetra
.655 .66 .843 r
.48504 .38726 .48595 .38873 .48759 .38817 .48668 .38671 Mtetra
.657 .662 .843 r
.48668 .38671 .48759 .38817 .48923 .38762 .48832 .38615 Mtetra
.657 .661 .843 r
.48832 .38615 .48923 .38762 .49087 .38706 .48996 .3856 Mtetra
.656 .661 .843 r
.48996 .3856 .49087 .38706 .49252 .3865 .49161 .38504 Mtetra
.49161 .38504 .49252 .3865 .49416 .38595 .49325 .38449 Mtetra
.49325 .38449 .49416 .38595 .49581 .38539 .4949 .38393 Mtetra
.4949 .38393 .49581 .38539 .49746 .38484 .49655 .38338 Mtetra
.656 .662 .844 r
.49655 .38338 .49746 .38484 .49911 .38429 .4982 .38283 Mtetra
.4982 .38283 .49911 .38429 .50076 .38373 .49985 .38227 Mtetra
.49985 .38227 .50076 .38373 .50241 .38318 .5015 .38172 Mtetra
.5015 .38172 .50241 .38318 .50406 .38262 .50315 .38116 Mtetra
.50315 .38116 .50406 .38262 .50571 .38207 .5048 .38061 Mtetra
.5048 .38061 .50571 .38207 .50736 .38152 .50646 .38006 Mtetra
.50646 .38006 .50736 .38152 .50902 .38096 .50811 .3795 Mtetra
.50811 .3795 .50902 .38096 .51067 .38041 .50977 .37895 Mtetra
.50977 .37895 .51067 .38041 .51233 .37985 .51142 .37839 Mtetra
.51142 .37839 .51233 .37985 .51399 .3793 .51308 .37784 Mtetra
.51308 .37784 .51399 .3793 .51564 .37874 .51474 .37728 Mtetra
.51474 .37728 .51564 .37874 .5173 .37819 .5164 .37673 Mtetra
.5164 .37673 .5173 .37819 .51896 .37764 .51806 .37617 Mtetra
.51806 .37617 .51896 .37764 .52063 .37708 .51972 .37561 Mtetra
.51972 .37561 .52063 .37708 .52229 .37653 .52138 .37506 Mtetra
.656 .661 .844 r
.52138 .37506 .52229 .37653 .52395 .37597 .52305 .3745 Mtetra
.655 .661 .844 r
.52305 .3745 .52395 .37597 .52562 .37542 .52471 .37394 Mtetra
.655 .661 .843 r
.52471 .37394 .52562 .37542 .52728 .37487 .52638 .37339 Mtetra
.52638 .37339 .52728 .37487 .52895 .37431 .52805 .37283 Mtetra
.655 .66 .843 r
.52805 .37283 .52895 .37431 .53061 .37376 .52971 .37227 Mtetra
.52971 .37227 .53061 .37376 .53228 .3732 .53138 .37172 Mtetra
.53138 .37172 .53228 .3732 .53395 .37265 .53305 .37116 Mtetra
.53305 .37116 .53395 .37265 .53562 .37209 .53472 .37061 Mtetra
.654 .66 .843 r
.53472 .37061 .53562 .37209 .53729 .37154 .5364 .37005 Mtetra
.657 .661 .843 r
.5364 .37005 .53729 .37154 .53897 .37098 .53807 .36949 Mtetra
.654 .659 .842 r
.53807 .36949 .53897 .37098 .54064 .37042 .53974 .36893 Mtetra
.65 .658 .845 r
.53974 .36893 .54064 .37042 .54231 .36986 .54142 .36841 Mtetra
.628 .654 .856 r
.54142 .36841 .54231 .36986 .54399 .36929 .54309 .36799 Mtetra
.629 .679 .878 r
.54309 .36799 .54399 .36929 .54567 .36873 .54477 .36758 Mtetra
.641 .712 .899 r
.54477 .36758 .54567 .36873 .54734 .36816 .54645 .36712 Mtetra
.694 .75 .895 r
.54645 .36712 .54734 .36816 .54902 .36759 .54813 .36641 Mtetra
.699 .725 .871 r
.54813 .36641 .54902 .36759 .5507 .36703 .54981 .36566 Mtetra
.69 .692 .847 r
.54981 .36566 .5507 .36703 .55238 .36646 .55149 .36491 Mtetra
.704 .672 .816 r
.55149 .36491 .55238 .36646 .55406 .36546 .55317 .36402 Mtetra
.672 .674 .843 r
.55317 .36402 .55406 .36546 .55574 .36477 .55485 .36336 Mtetra
.582 .641 .874 r
.55485 .36336 .55574 .36477 .55743 .36472 .55654 .36316 Mtetra
0 .136 .683 r
.55654 .36316 .55743 .36472 .55916 .36846 .55825 .36499 Mtetra
0 0 .322 r
.55825 .36499 .55916 .36846 .56312 .5696 .56 .37053 Mtetra
0 0 .374 r
.56 .37053 .56312 .5696 .565 .57564 .56397 .56795 Mtetra
.513 .365 .617 r
.56397 .56795 .565 .57564 .56681 .57601 .56579 .5688 Mtetra
.598 .429 .623 r
.56579 .5688 .56681 .57601 .56861 .5754 .56759 .5679 Mtetra
.597 .425 .62 r
.56759 .5679 .56861 .5754 .57041 .57438 .56938 .567 Mtetra
.398 .287 .609 r
.56938 .567 .57041 .57438 .57221 .57394 .57123 .56961 Mtetra
.354 .309 .669 r
.57123 .56961 .57221 .57394 .57402 .57358 .57307 .57148 Mtetra
.298 .406 .804 r
.57307 .57148 .57402 .57358 .57583 .5732 .5749 .57254 Mtetra
.465 .77 .996 r
.5749 .57254 .57583 .5732 .57764 .57273 .57671 .57239 Mtetra
.557 .886 .988 r
.57671 .57239 .57764 .57273 .57945 .57221 .57852 .57186 Mtetra
.636 .908 .983 r
.57852 .57186 .57945 .57221 .58126 .57166 .58033 .57115 Mtetra
.473 .811 .999 r
.58033 .57115 .58126 .57166 .58308 .57152 .58215 .57089 Mtetra
.573 .825 .993 r
.58215 .57089 .58308 .57152 .5849 .5711 .58397 .57048 Mtetra
.719 .869 .952 r
.58397 .57048 .5849 .5711 .5867 .56999 .58578 .5696 Mtetra
.938 .875 .748 r
.58578 .5696 .5867 .56999 .58844 .56517 .58755 .56663 Mtetra
.977 .867 .484 r
.58755 .56663 .58844 .56517 .58636 .36274 .58925 .56006 Mtetra
0 0 .371 r
.58925 .56006 .58636 .36274 .58793 .35542 .58718 .36089 Mtetra
.322 .069 .366 r
.58718 .36089 .58793 .35542 .58961 .35382 .58885 .35838 Mtetra
.503 .206 .394 r
.58885 .35838 .58961 .35382 .59132 .35329 .59056 .35813 Mtetra
.516 .222 .405 r
.59056 .35813 .59132 .35329 .59303 .35316 .59228 .35801 Mtetra
.194 0 .309 r
.59228 .35801 .59303 .35316 .59474 .35259 .59393 .35477 Mtetra
0 0 0 r
.59393 .35477 .59474 .35259 .59644 .35189 .59559 .35196 Mtetra
.896 .981 .804 r
.59559 .35196 .59644 .35189 .59815 .3512 .59727 .34994 Mtetra
.713 .721 .855 r
.59727 .34994 .59815 .3512 .59986 .35062 .59898 .34907 Mtetra
.626 .641 .845 r
.59898 .34907 .59986 .35062 .60157 .3501 .60069 .34866 Mtetra
.591 .642 .87 r
.60069 .34866 .60157 .3501 .60328 .34957 .60241 .34841 Mtetra
.636 .711 .901 r
.60241 .34841 .60328 .34957 .605 .34898 .60413 .34796 Mtetra
.662 .749 .915 r
.60413 .34796 .605 .34898 .60671 .34837 .60584 .34739 Mtetra
.675 .763 .917 r
.60584 .34739 .60671 .34837 .60842 .34776 .60756 .34677 Mtetra
.746 .781 .881 r
.60756 .34677 .60842 .34776 .61013 .34682 .60926 .34577 Mtetra
.728 .764 .881 r
.60926 .34577 .61013 .34682 .61184 .34607 .61097 .34487 Mtetra
.642 .706 .893 r
.61097 .34487 .61184 .34607 .61357 .3459 .61269 .34439 Mtetra
.151 .38 .831 r
.61269 .34439 .61357 .3459 .61538 .34864 .61446 .34549 Mtetra
0 0 .536 r
.61446 .34549 .61538 .34864 .62295 .54896 .61631 .34935 Mtetra
0 0 .395 r
.61631 .34935 .62295 .54896 .62504 .55722 .62389 .54831 Mtetra
.247 .168 .567 r
.62389 .54831 .62504 .55722 .62693 .55836 .62591 .55382 Mtetra
.385 .326 .668 r
.62591 .55382 .62693 .55836 .62878 .55806 .62782 .55559 Mtetra
.429 .451 .781 r
.62782 .55559 .62878 .55806 .63062 .55727 .62971 .55631 Mtetra
.501 .713 .966 r
.62971 .55631 .63062 .55727 .63246 .55661 .63157 .55622 Mtetra
.549 .876 .992 r
.63157 .55622 .63246 .55661 .63431 .556 .63341 .55571 Mtetra
.607 .917 .977 r
.63341 .55571 .63431 .556 .63615 .55537 .63526 .555 Mtetra
.47 .845 .988 r
.63526 .555 .63615 .55537 .63801 .55516 .63711 .55464 Mtetra
.532 .838 .999 r
.63711 .55464 .63801 .55516 .63987 .55486 .63897 .55425 Mtetra
.695 .872 .965 r
.63897 .55425 .63987 .55486 .64171 .55395 .64081 .55344 Mtetra
.907 .889 .802 r
.64081 .55344 .64171 .55395 .64345 .55022 .6426 .55112 Mtetra
.971 .9 .54 r
.6426 .55112 .64345 .55022 .6382 .35097 .6443 .54612 Mtetra
0 0 .387 r
.6443 .54612 .6382 .35097 .63953 .33894 .63898 .34649 Mtetra
0 0 .293 r
.63898 .34649 .63953 .33894 .6412 .33658 .64047 .33887 Mtetra
0 0 .01 r
.64047 .33887 .6412 .33658 .64293 .33576 .64212 .33605 Mtetra
.787 .993 .766 r
.64212 .33605 .64293 .33576 .64467 .3354 .64382 .33431 Mtetra
.727 .759 .878 r
.64382 .33431 .64467 .3354 .64642 .33497 .64554 .33339 Mtetra
.629 .642 .844 r
.64554 .33339 .64642 .33497 .64816 .33445 .64729 .33296 Mtetra
.591 .636 .864 r
.64729 .33296 .64816 .33445 .6499 .33394 .64904 .33271 Mtetra
.625 .696 .896 r
.64904 .33271 .6499 .33394 .65164 .33336 .65079 .3323 Mtetra
.664 .745 .91 r
.65079 .3323 .65164 .33336 .65338 .33273 .65254 .33171 Mtetra
.678 .76 .913 r
.65254 .33171 .65338 .33273 .65512 .33209 .65428 .33106 Mtetra
.757 .781 .873 r
.65428 .33106 .65512 .33209 .65685 .33116 .656 .32998 Mtetra
.745 .751 .857 r
.656 .32998 .65685 .33116 .65859 .33029 .65773 .32893 Mtetra
.637 .679 .873 r
.65773 .32893 .65859 .33029 .66035 .32997 .65948 .32846 Mtetra
0 .117 .668 r
.65948 .32846 .66035 .32997 .66221 .33209 .66134 .33049 Mtetra
.975 .679 .393 r
.66134 .33049 .66221 .33209 .67277 .53115 .67187 .53003 Mtetra
.951 .598 .24 r
.67187 .53003 .67277 .53115 .67515 .5422 .67427 .54163 Mtetra
.536 0 0 r
.67427 .54163 .67515 .5422 .67713 .54401 .67625 .5433 Mtetra
.559 .805 .991 r
.67625 .5433 .67713 .54401 .67902 .54385 .67813 .54294 Mtetra
.783 .824 .884 r
.67813 .54294 .67902 .54385 .68087 .54265 .67998 .54166 Mtetra
.885 .814 .774 r
.67998 .54166 .68087 .54265 .68261 .53908 .68177 .53917 Mtetra
.991 .871 .61 r
.68177 .53917 .68261 .53908 .67526 .34425 .68344 .53422 Mtetra
0 0 .392 r
.68344 .53422 .67526 .34425 .67622 .3268 .67579 .33444 Mtetra
0 0 .303 r
.67579 .33444 .67622 .3268 .67787 .32405 .67721 .32656 Mtetra
0 0 .075 r
.67721 .32656 .67787 .32405 .67961 .32312 .67885 .32365 Mtetra
.694 .94 .646 r
.67885 .32365 .67961 .32312 .68138 .32268 .68055 .32179 Mtetra
.796 .82 .871 r
.68055 .32179 .68138 .32268 .68314 .32202 .68228 .32049 Mtetra
.697 .681 .831 r
.68228 .32049 .68314 .32202 .68489 .32121 .68403 .31964 Mtetra
.611 .637 .852 r
.68403 .31964 .68489 .32121 .68666 .32091 .6858 .3193 Mtetra
.339 .481 .856 r
.6858 .3193 .68666 .32091 .68854 .32251 .68763 .32001 Mtetra
0 .116 .65 r
.68763 .32001 .68854 .32251 .69097 .33449 .68958 .32277 Mtetra
.98 .686 .347 r
.68958 .32277 .69097 .33449 .70331 .53258 .70158 .51553 Mtetra
.142 .067 .504 r
.70158 .51553 .70331 .53258 .70535 .53483 .70423 .52936 Mtetra
.367 .296 .644 r
.70423 .52936 .70535 .53483 .70727 .53475 .70629 .53176 Mtetra
.418 .411 .744 r
.70629 .53176 .70727 .53475 .70916 .53408 .70827 .53275 Mtetra
.422 .596 .916 r
.70827 .53275 .70916 .53408 .71106 .5336 .71021 .53305 Mtetra
.454 .799 .998 r
.71021 .53305 .71106 .5336 .71298 .53333 .71213 .53283 Mtetra
.674 .899 .977 r
.71213 .53283 .71298 .53333 .71486 .53249 .71402 .53202 Mtetra
.883 .922 .845 r
.71402 .53202 .71486 .53249 .71663 .52964 .71584 .53007 Mtetra
.973 .919 .599 r
.71584 .53007 .71663 .52964 .71786 .51747 .71753 .52586 Mtetra
.932 .709 .227 r
.71753 .52586 .71786 .51747 .70809 .31702 .71743 .49078 Mtetra
.021 0 .417 r
.71743 .49078 .70809 .31702 .70972 .31376 .70913 .31671 Mtetra
0 0 .143 r
.70913 .31671 .70972 .31376 .71147 .31276 .71075 .31342 Mtetra
.631 .887 .554 r
.71075 .31342 .71147 .31276 .71326 .31228 .71245 .31145 Mtetra
.776 .835 .898 r
.71245 .31145 .71326 .31228 .71505 .31185 .7142 .31031 Mtetra
.649 .66 .847 r
.7142 .31031 .71505 .31185 .71683 .31124 .71598 .30975 Mtetra
.611 .65 .864 r
.71598 .30975 .71683 .31124 .71861 .31067 .71778 .3094 Mtetra
.665 .711 .882 r
.71778 .3094 .71861 .31067 .72039 .30991 .71957 .30879 Mtetra
.733 .763 .877 r
.71957 .30879 .72039 .30991 .72215 .30901 .72133 .30782 Mtetra
.674 .728 .891 r
.72133 .30782 .72215 .30901 .72395 .30858 .72311 .30717 Mtetra
.398 .55 .89 r
.72311 .30717 .72395 .30858 .72586 .3098 .72497 .30761 Mtetra
0 .058 .619 r
.72497 .30761 .72586 .3098 .72829 .31915 .72698 .31053 Mtetra
.978 .679 .337 r
.72698 .31053 .72829 .31915 .74326 .52029 .74143 .5043 Mtetra
.222 .128 .531 r
.74143 .5043 .74326 .52029 .74539 .52286 .74411 .51554 Mtetra
.574 .413 .625 r
.74411 .51554 .74539 .52286 .74733 .5226 .74604 .51515 Mtetra
.603 .431 .622 r
.74604 .51515 .74733 .5226 .74923 .52173 .74793 .51407 Mtetra
.52 .373 .621 r
.74793 .51407 .74923 .52173 .75114 .52089 .74994 .51483 Mtetra
.391 .304 .636 r
.74994 .51483 .75114 .52089 .75308 .52054 .75206 .51725 Mtetra
.367 .364 .724 r
.75206 .51725 .75308 .52054 .75502 .52016 .75413 .5187 Mtetra
.347 .53 .893 r
.75413 .5187 .75502 .52016 .75696 .51988 .75614 .51931 Mtetra
.43 .784 .997 r
.75614 .51931 .75696 .51988 .75892 .51964 .7581 .51914 Mtetra
.647 .895 .984 r
.7581 .51914 .75892 .51964 .76083 .51888 .76002 .5184 Mtetra
.869 .929 .862 r
.76002 .5184 .76083 .51888 .76263 .51648 .76186 .51657 Mtetra
.986 .902 .619 r
.76186 .51657 .76263 .51648 .76392 .50685 .76353 .51226 Mtetra
.837 .682 .143 r
.76353 .51226 .76392 .50685 .75114 .3032 .76423 .49467 Mtetra
.048 0 .432 r
.76423 .49467 .75114 .3032 .75272 .29946 .75233 .30409 Mtetra
.459 .17 .386 r
.75233 .30409 .75272 .29946 .75451 .29855 .75413 .30326 Mtetra
.525 .225 .4 r
.75413 .30326 .75451 .29855 .75633 .29824 .75598 .30329 Mtetra
.433 .156 .392 r
.75598 .30329 .75633 .29824 .75817 .29799 .75775 .30201 Mtetra
.157 0 .287 r
.75775 .30201 .75817 .29799 .75997 .2973 .75936 .29876 Mtetra
0 0 0 r
.75936 .29876 .75997 .2973 .76178 .29661 .76104 .29634 Mtetra
.843 .972 .879 r
.76104 .29634 .76178 .29661 .76358 .29596 .76278 .29478 Mtetra
.68 .735 .892 r
.76278 .29478 .76358 .29596 .7654 .2954 .76458 .29408 Mtetra
.633 .691 .886 r
.76458 .29408 .7654 .2954 .76722 .29485 .76641 .29362 Mtetra
.626 .704 .901 r
.76641 .29362 .76722 .29485 .76904 .29428 .76824 .29318 Mtetra
.663 .747 .913 r
.76824 .29318 .76904 .29428 .77085 .29365 .77006 .29257 Mtetra
.67 .753 .913 r
.77006 .29257 .77085 .29365 .77267 .293 .77187 .29194 Mtetra
.676 .759 .914 r
.77187 .29194 .77267 .293 .77448 .29231 .77369 .29127 Mtetra
.681 .766 .915 r
.77369 .29127 .77448 .29231 .77629 .29159 .7755 .29058 Mtetra
.694 .778 .916 r
.7755 .29058 .77629 .29159 .7781 .29086 .77731 .28983 Mtetra
.74 .79 .893 r
.77731 .28983 .7781 .29086 .7799 .29001 .7791 .28884 Mtetra
.791 .776 .839 r
.7791 .28884 .7799 .29001 .78168 .28892 .78086 .28743 Mtetra
.708 .697 .837 r
.78086 .28743 .78168 .28892 .7835 .28827 .78266 .2865 Mtetra
.491 .55 .844 r
.78266 .2865 .7835 .28827 .78542 .28879 .78456 .28674 Mtetra
0 0 .382 r
.78456 .28674 .78542 .28879 .78778 .29444 .78682 .29139 Mtetra
.975 .667 .324 r
.78682 .29139 .78778 .29444 .80712 .49992 .80623 .49816 Mtetra
0 0 .32 r
.80623 .49816 .80712 .49992 .80947 .50395 .80864 .50293 Mtetra
.303 .596 .947 r
.80864 .50293 .80947 .50395 .81152 .50433 .8107 .50338 Mtetra
.688 .804 .937 r
.8107 .50338 .81152 .50433 .81347 .50357 .81265 .5026 Mtetra
.89 .838 .788 r
.81265 .5026 .81347 .50357 .81529 .50128 .81446 .5002 Mtetra
.982 .754 .515 r
.81446 .5002 .81529 .50128 .81657 .49287 .81563 .49054 Mtetra
.977 .674 .348 r
.81563 .49054 .81657 .49287 .80035 .28705 .79949 .28511 Mtetra
.888 .714 .66 r
.79949 .28511 .80035 .28705 .80185 .28268 .80102 .28103 Mtetra
.691 .67 .824 r
.80102 .28103 .80185 .28268 .80365 .28165 .80284 .28017 Mtetra
.582 .642 .875 r
.80284 .28017 .80365 .28165 .80551 .28125 .80471 .27994 Mtetra
.526 .644 .908 r
.80471 .27994 .80551 .28125 .80739 .28107 .8066 .27992 Mtetra
.686 .748 .898 r
.8066 .27992 .80739 .28107 .80923 .28045 .80844 .27919 Mtetra
.663 .718 .889 r
.80844 .27919 .80923 .28045 .81107 .27984 .81028 .27856 Mtetra
.6 .687 .903 r
.81028 .27856 .81107 .27984 .81291 .27918 .81215 .27824 Mtetra
.321 .609 .951 r
.81215 .27824 .81291 .27918 .81472 .27823 .81408 .27861 Mtetra
.606 .055 0 r
.81408 .27861 .81472 .27823 .81657 .27769 .8161 .27982 Mtetra
.78 .388 .312 r
.8161 .27982 .81657 .27769 .81852 .27813 .81836 .28351 Mtetra
.971 .657 .336 r
.81836 .28351 .81852 .27813 .821 .28416 .83946 .48526 Mtetra
.555 .332 .532 r
.83946 .48526 .821 .28416 .84262 .48954 .84201 .4906 Mtetra
.697 .226 .128 r
.84201 .4906 .84262 .48954 .84505 .49357 .84423 .49247 Mtetra
.387 .63 .95 r
.84423 .49247 .84505 .49357 .84714 .49402 .8463 .49276 Mtetra
.651 .73 .907 r
.8463 .49276 .84714 .49402 .84912 .49337 .84829 .49215 Mtetra
.823 .795 .826 r
.84829 .49215 .84912 .49337 .85098 .49146 .85017 .49037 Mtetra
.977 .78 .571 r
.85017 .49037 .85098 .49146 .85237 .48476 .85156 .48367 Mtetra
.976 .67 .326 r
.85156 .48367 .85237 .48476 .83374 .2772 .83297 .27606 Mtetra
.965 .781 .604 r
.83297 .27606 .83374 .2772 .83512 .27181 .83435 .27067 Mtetra
.76 .778 .868 r
.83435 .27067 .83512 .27181 .83692 .27065 .83616 .26951 Mtetra
.628 .727 .919 r
.83616 .26951 .83692 .27065 .8388 .27019 .83803 .26904 Mtetra
.548 .689 .932 r
.83803 .26904 .8388 .27019 .84071 .27003 .83994 .26888 Mtetra
.748 .775 .875 r
.83994 .26888 .84071 .27003 .84252 .26895 .84176 .2678 Mtetra
.679 .749 .904 r
.84176 .2678 .84252 .26895 .84438 .26825 .84361 .26711 Mtetra
.463 .644 .936 r
.84361 .26711 .84438 .26825 .84632 .26837 .84555 .26723 Mtetra
.847 .45 0 r
.84555 .26723 .84632 .26837 .84898 .27538 .84822 .2743 Mtetra
.971 .656 .295 r
.84822 .2743 .84898 .27538 .8726 .48136 .8718 .4803 Mtetra
0 0 .44 r
.8718 .4803 .8726 .48136 .875 .4845 .8742 .48342 Mtetra
.978 .788 .58 r
.8742 .48342 .875 .4845 .8764 .47821 .87561 .47717 Mtetra
.974 .667 .312 r
.87561 .47717 .8764 .47821 .8561 .26933 .85534 .26822 Mtetra
.968 .786 .603 r
.85534 .26822 .8561 .26933 .85747 .26406 .85671 .26291 Mtetra
.888 .46 .116 r
.25295 .46405 .25395 .46496 .25518 .46778 .25418 .46689 Mtetra
.937 .682 .526 r
.25418 .46689 .25518 .46778 .24069 .66351 .23962 .6627 Mtetra
.938 .613 .394 r
.23962 .6627 .24069 .66351 .24166 .67076 .24059 .66989 Mtetra
0 .375 .814 r
.24059 .66989 .24166 .67076 .24316 .67153 .24209 .67064 Mtetra
.631 .756 .937 r
.24209 .67064 .24316 .67153 .24475 .67113 .24368 .67022 Mtetra
.809 .774 .821 r
.24368 .67022 .24475 .67113 .24644 .66961 .24537 .66868 Mtetra
.91 .731 .647 r
.24537 .66868 .24644 .66961 .24848 .6636 .24742 .66255 Mtetra
.937 .686 .533 r
.24742 .66255 .24848 .6636 .26565 .46568 .26466 .46458 Mtetra
.897 .722 .656 r
.26466 .46458 .26565 .46568 .26754 .46033 .26655 .45933 Mtetra
.754 .746 .845 r
.26655 .45933 .26754 .46033 .26909 .4593 .2681 .4583 Mtetra
.587 .704 .924 r
.2681 .4583 .26909 .4593 .27059 .45907 .2696 .45806 Mtetra
.413 .631 .944 r
.2696 .45806 .27059 .45907 .27205 .45925 .27106 .45823 Mtetra
.614 .711 .914 r
.27106 .45823 .27205 .45925 .27355 .45892 .27256 .45791 Mtetra
.636 .72 .908 r
.27256 .45791 .27355 .45892 .27506 .45849 .27407 .45751 Mtetra
.646 .728 .908 r
.27407 .45751 .27506 .45849 .27658 .45803 .27559 .45707 Mtetra
.656 .736 .908 r
.27559 .45707 .27658 .45803 .2781 .45751 .2771 .45659 Mtetra
.668 .746 .909 r
.2771 .45659 .2781 .45751 .27962 .45695 .27863 .45606 Mtetra
.681 .757 .909 r
.27863 .45606 .27962 .45695 .28115 .45633 .28015 .45547 Mtetra
.734 .773 .884 r
.28015 .45547 .28115 .45633 .28271 .45532 .2817 .45463 Mtetra
.724 .81 .918 r
.2817 .45463 .28271 .45532 .28426 .4545 .28324 .45387 Mtetra
.66 .816 .958 r
.28324 .45387 .28426 .4545 .28577 .45413 .28477 .45335 Mtetra
.16 .554 .929 r
.28477 .45335 .28577 .45413 .28714 .4558 .28622 .45376 Mtetra
.253 .361 .78 r
.28622 .45376 .28714 .4558 .28824 .46112 .28764 .45476 Mtetra
.442 .316 .613 r
.28764 .45476 .28824 .46112 .27594 .65368 .28902 .45628 Mtetra
.548 .332 .538 r
.28902 .45628 .27594 .65368 .27744 .65484 .29055 .45572 Mtetra
.549 .332 .538 r
.29055 .45572 .27744 .65484 .27909 .65402 .29211 .45484 Mtetra
.547 .331 .538 r
.29211 .45484 .27909 .65402 .28073 .65313 .29361 .45478 Mtetra
0 0 .27 r
.29361 .45478 .28073 .65313 .28216 .65544 .2823 .63745 Mtetra
0 0 .309 r
.2823 .63745 .28216 .65544 .28362 .65732 .2827 .65435 Mtetra
0 0 .49 r
.2827 .65435 .28362 .65732 .28513 .65842 .28408 .65739 Mtetra
.33 .602 .946 r
.28408 .65739 .28513 .65842 .28673 .65835 .28565 .6577 Mtetra
.63 .815 .971 r
.28565 .6577 .28673 .65835 .28835 .65787 .28728 .65723 Mtetra
.712 .831 .938 r
.28728 .65723 .28835 .65787 .28999 .65726 .28893 .65647 Mtetra
.63 .782 .954 r
.28893 .65647 .28999 .65726 .29161 .65688 .29055 .65603 Mtetra
.604 .759 .953 r
.29055 .65603 .29161 .65688 .29323 .65658 .29218 .65568 Mtetra
.612 .752 .944 r
.29218 .65568 .29323 .65658 .29485 .65625 .2938 .65531 Mtetra
.633 .748 .931 r
.2938 .65531 .29485 .65625 .29648 .65584 .29543 .65488 Mtetra
.647 .746 .922 r
.29543 .65488 .29648 .65584 .29811 .65538 .29706 .65439 Mtetra
.658 .746 .915 r
.29706 .65439 .29811 .65538 .29975 .65487 .2987 .65387 Mtetra
.676 .748 .905 r
.2987 .65387 .29975 .65487 .30139 .65428 .30034 .65326 Mtetra
.684 .747 .899 r
.30034 .65326 .30139 .65428 .30303 .65365 .30199 .65262 Mtetra
.683 .743 .897 r
.30199 .65262 .30303 .65365 .30468 .65302 .30364 .65198 Mtetra
.632 .727 .916 r
.30364 .65198 .30468 .65302 .3063 .65273 .30527 .65156 Mtetra
.633 .702 .896 r
.30527 .65156 .3063 .65273 .30793 .65238 .30691 .65114 Mtetra
.672 .703 .871 r
.30691 .65114 .30793 .65238 .30959 .65162 .30856 .65053 Mtetra
.785 .75 .821 r
.30856 .65053 .30959 .65162 .31136 .6491 .31025 .64912 Mtetra
.902 .929 .824 r
.31025 .64912 .31136 .6491 .31331 .64358 .31199 .64705 Mtetra
.037 0 .131 r
.31199 .64705 .31331 .64358 .32668 .44937 .31376 .64451 Mtetra
.545 .325 .531 r
.31376 .64451 .32668 .44937 .32843 .44564 .31543 .64363 Mtetra
.546 .326 .532 r
.31543 .64363 .32843 .44564 .32997 .4453 .31705 .64351 Mtetra
.545 .325 .531 r
.31705 .64351 .32997 .4453 .33149 .44523 .31871 .64268 Mtetra
.53 .312 .529 r
.31871 .64268 .33149 .44523 .33319 .44236 .32083 .63419 Mtetra
0 0 .236 r
.32083 .63419 .33319 .44236 .33488 .43951 .33376 .44102 Mtetra
.959 .926 .585 r
.33376 .44102 .33488 .43951 .33652 .43746 .33553 .43678 Mtetra
.83 .814 .835 r
.33553 .43678 .33652 .43746 .3381 .43642 .33714 .43525 Mtetra
.67 .703 .872 r
.33714 .43525 .3381 .43642 .33966 .43589 .3387 .43468 Mtetra
.589 .668 .894 r
.3387 .43468 .33966 .43589 .3412 .43556 .34024 .43446 Mtetra
.602 .694 .908 r
.34024 .43446 .3412 .43556 .34275 .43522 .34178 .43418 Mtetra
.618 .711 .912 r
.34178 .43418 .34275 .43522 .3443 .43486 .34333 .43383 Mtetra
.619 .714 .914 r
.34333 .43383 .3443 .43486 .34585 .43449 .34488 .43349 Mtetra
.64 .726 .91 r
.34488 .43349 .34585 .43449 .3474 .43404 .34643 .43306 Mtetra
.66 .737 .907 r
.34643 .43306 .3474 .43404 .34896 .4335 .34799 .43255 Mtetra
.673 .746 .906 r
.34799 .43255 .34896 .4335 .35053 .43291 .34956 .43199 Mtetra
.713 .761 .89 r
.34956 .43199 .35053 .43291 .35211 .43202 .35113 .43123 Mtetra
.72 .793 .909 r
.35113 .43123 .35211 .43202 .35369 .43115 .35271 .43047 Mtetra
.672 .81 .949 r
.35271 .43047 .35369 .43115 .35525 .43066 .35428 .42989 Mtetra
.359 .669 .974 r
.35428 .42989 .35525 .43066 .35674 .43167 .35581 .43004 Mtetra
.227 .405 .83 r
.35581 .43004 .35674 .43167 .35808 .43547 .3573 .43091 Mtetra
.409 .325 .65 r
.3573 .43091 .35808 .43547 .34982 .62888 .35877 .4323 Mtetra
.547 .331 .538 r
.35877 .4323 .34982 .62888 .35125 .63279 .36031 .43242 Mtetra
.549 .332 .538 r
.36031 .43242 .35125 .63279 .35292 .63218 .3619 .43146 Mtetra
.548 .331 .538 r
.3619 .43146 .35292 .63218 .35461 .63118 .36346 .4311 Mtetra
.536 .322 .536 r
.36346 .4311 .35461 .63118 .35618 .63272 .36475 .4365 Mtetra
0 0 .276 r
.36475 .4365 .35618 .63272 .35772 .63483 .35685 .63071 Mtetra
0 0 .497 r
.35685 .63071 .35772 .63483 .35931 .63611 .3583 .63466 Mtetra
.154 .411 .854 r
.3583 .63466 .35931 .63611 .36094 .63635 .35991 .63555 Mtetra
.606 .777 .962 r
.35991 .63555 .36094 .63635 .36261 .63595 .36158 .63517 Mtetra
.708 .805 .926 r
.36158 .63517 .36261 .63595 .36429 .63535 .36326 .63441 Mtetra
.663 .763 .924 r
.36326 .63441 .36429 .63535 .36596 .63498 .36494 .63385 Mtetra
.621 .71 .909 r
.36494 .63385 .36596 .63498 .36763 .6347 .36661 .63346 Mtetra
.664 .706 .878 r
.36661 .63346 .36763 .6347 .36931 .63404 .36829 .63288 Mtetra
.736 .739 .853 r
.36829 .63288 .36931 .63404 .37105 .63215 .37 .63188 Mtetra
.856 .913 .87 r
.37 .63188 .37105 .63215 .37289 .62793 .37173 .63026 Mtetra
0 0 0 r
.37173 .63026 .37289 .62793 .38283 .4378 .3735 .62766 Mtetra
.532 .314 .529 r
.3735 .62766 .38283 .4378 .38495 .42499 .37548 .62016 Mtetra
0 0 .271 r
.37548 .62016 .38495 .42499 .38664 .42196 .38555 .42428 Mtetra
.819 .855 .401 r
.38555 .42428 .38664 .42196 .38828 .42015 .3873 .41978 Mtetra
.872 .877 .837 r
.3873 .41978 .38828 .42015 .38988 .41918 .38894 .41803 Mtetra
.656 .706 .884 r
.38894 .41803 .38988 .41918 .39146 .41876 .39052 .41752 Mtetra
.557 .652 .898 r
.39052 .41752 .39146 .41876 .39304 .41857 .39209 .41741 Mtetra
.579 .676 .906 r
.39209 .41741 .39304 .41857 .39461 .41828 .39366 .4172 Mtetra
.648 .717 .898 r
.39366 .4172 .39461 .41828 .3962 .4178 .39525 .41673 Mtetra
.655 .721 .898 r
.39525 .41673 .3962 .4178 .39779 .41729 .39684 .41624 Mtetra
.657 .726 .899 r
.39684 .41624 .39779 .41729 .39938 .41677 .39843 .41573 Mtetra
.659 .729 .901 r
.39843 .41573 .39938 .41677 .40097 .41624 .40002 .41521 Mtetra
.661 .731 .902 r
.40002 .41521 .40097 .41624 .40256 .41571 .40161 .41469 Mtetra
.663 .733 .902 r
.40161 .41469 .40256 .41571 .40415 .41517 .40321 .41415 Mtetra
.665 .734 .901 r
.40321 .41415 .40415 .41517 .40575 .41463 .4048 .41361 Mtetra
.667 .735 .901 r
.4048 .41361 .40575 .41463 .40734 .41409 .4064 .41306 Mtetra
.667 .734 .9 r
.4064 .41306 .40734 .41409 .40894 .41354 .40799 .41251 Mtetra
.668 .733 .899 r
.40799 .41251 .40894 .41354 .41054 .413 .40959 .41195 Mtetra
.674 .732 .894 r
.40959 .41195 .41054 .413 .41214 .41243 .41119 .41137 Mtetra
.689 .734 .885 r
.41119 .41137 .41214 .41243 .41374 .41178 .41279 .41071 Mtetra
.702 .736 .877 r
.41279 .41071 .41374 .41178 .41534 .41106 .4144 .40998 Mtetra
.7 .733 .876 r
.4144 .40998 .41534 .41106 .41695 .41034 .41601 .40925 Mtetra
.714 .735 .868 r
.41601 .40925 .41695 .41034 .41856 .4096 .41762 .40844 Mtetra
.713 .724 .858 r
.41762 .40844 .41856 .4096 .42017 .40888 .41923 .40763 Mtetra
.642 .684 .874 r
.41923 .40763 .42017 .40888 .42177 .40838 .42083 .40718 Mtetra
.203 .474 .89 r
.42083 .40718 .42177 .40838 .42335 .40846 .4224 .40785 Mtetra
.894 .472 .156 r
.4224 .40785 .42335 .40846 .42491 .40953 .42388 .41139 Mtetra
.952 .681 .486 r
.42388 .41139 .42491 .40953 .42644 .41143 .41947 .60658 Mtetra
.557 .334 .533 r
.41947 .60658 .42644 .41143 .42799 .41299 .42098 .61234 Mtetra
.546 .326 .532 r
.42098 .61234 .42799 .41299 .42961 .41196 .42269 .61207 Mtetra
.545 .325 .531 r
.42269 .61207 .42961 .41196 .43123 .41132 .42441 .61118 Mtetra
.547 .326 .532 r
.42441 .61118 .43123 .41132 .43271 .41527 .4261 .61132 Mtetra
.549 .328 .532 r
.4261 .61132 .43271 .41527 .42887 .60985 .42776 .61285 Mtetra
.61 .269 .367 r
.42776 .61285 .42887 .60985 .43045 .61402 .42943 .61389 Mtetra
.19 0 0 r
.42943 .61389 .43045 .61402 .43212 .61533 .43112 .61423 Mtetra
.613 .718 .92 r
.43112 .61423 .43212 .61533 .43383 .61504 .43284 .61386 Mtetra
.662 .72 .892 r
.43284 .61386 .43383 .61504 .43556 .61434 .43456 .61329 Mtetra
.641 .737 .918 r
.43456 .61329 .43556 .61434 .43728 .61366 .43628 .61281 Mtetra
.55 .75 .97 r
.43628 .61281 .43728 .61366 .439 .6133 .43799 .61258 Mtetra
.656 .816 .96 r
.43799 .61258 .439 .6133 .44072 .61275 .43972 .612 Mtetra
.832 .826 .842 r
.43972 .612 .44072 .61275 .44246 .61165 .44147 .61037 Mtetra
.899 .738 .673 r
.44147 .61037 .44246 .61165 .44422 .60947 .44329 .60588 Mtetra
.954 .687 .49 r
.44329 .60588 .44422 .60947 .446 .6065 .44951 .41221 Mtetra
.567 .347 .541 r
.44951 .41221 .446 .6065 .44778 .60365 .45137 .40195 Mtetra
.549 .332 .538 r
.45137 .40195 .44778 .60365 .4495 .60355 .453 .40108 Mtetra
.547 .331 .538 r
.453 .40108 .4495 .60355 .45122 .60319 .45462 .40092 Mtetra
.549 .332 .538 r
.45462 .40092 .45122 .60319 .45301 .59957 .45625 .39997 Mtetra
.552 .335 .539 r
.45625 .39997 .45301 .59957 .45876 .40266 .45792 .39741 Mtetra
.672 .497 .64 r
.45792 .39741 .45876 .40266 .46049 .39717 .45958 .39536 Mtetra
.744 .655 .762 r
.45958 .39536 .46049 .39717 .46216 .39474 .46122 .39396 Mtetra
.691 .8 .933 r
.46122 .39396 .46216 .39474 .46379 .39394 .46286 .3933 Mtetra
.624 .817 .974 r
.46286 .3933 .46379 .39394 .46542 .39354 .46448 .39284 Mtetra
.615 .8 .97 r
.46448 .39284 .46542 .39354 .46704 .39323 .46611 .39242 Mtetra
.663 .786 .939 r
.46611 .39242 .46704 .39323 .46867 .39269 .46774 .39186 Mtetra
.66 .782 .939 r
.46774 .39186 .46867 .39269 .4703 .39216 .46938 .39132 Mtetra
.649 .774 .94 r
.46938 .39132 .4703 .39216 .47194 .3917 .47101 .39082 Mtetra
.626 .76 .943 r
.47101 .39082 .47194 .3917 .47357 .39132 .47264 .3904 Mtetra
.632 .752 .934 r
.47264 .3904 .47357 .39132 .4752 .39094 .47428 .38997 Mtetra
.655 .749 .919 r
.47428 .38997 .4752 .39094 .47683 .39047 .47591 .38946 Mtetra
.694 .752 .896 r
.47591 .38946 .47683 .39047 .47847 .3898 .47755 .38877 Mtetra
.7 .749 .89 r
.47755 .38877 .47847 .3898 .48011 .38909 .47919 .38805 Mtetra
.694 .745 .891 r
.47919 .38805 .48011 .38909 .48175 .3884 .48083 .38735 Mtetra
.673 .738 .899 r
.48083 .38735 .48175 .3884 .48339 .38782 .48248 .38676 Mtetra
.667 .734 .9 r
.48248 .38676 .48339 .38782 .48504 .38726 .48412 .38619 Mtetra
.664 .731 .899 r
.48412 .38619 .48504 .38726 .48668 .38671 .48576 .38564 Mtetra
.665 .73 .898 r
.48576 .38564 .48668 .38671 .48832 .38615 .4874 .38508 Mtetra
.665 .729 .898 r
.4874 .38508 .48832 .38615 .48996 .3856 .48905 .38452 Mtetra
.664 .729 .898 r
.48905 .38452 .48996 .3856 .49161 .38504 .49069 .38396 Mtetra
.49069 .38396 .49161 .38504 .49325 .38449 .49234 .38341 Mtetra
.663 .729 .898 r
.49234 .38341 .49325 .38449 .4949 .38393 .49399 .38285 Mtetra
.49399 .38285 .4949 .38393 .49655 .38338 .49564 .3823 Mtetra
.663 .729 .899 r
.49564 .3823 .49655 .38338 .4982 .38283 .49729 .38175 Mtetra
.49729 .38175 .4982 .38283 .49985 .38227 .49894 .38119 Mtetra
.663 .73 .899 r
.49894 .38119 .49985 .38227 .5015 .38172 .50059 .38064 Mtetra
.50059 .38064 .5015 .38172 .50315 .38116 .50224 .38009 Mtetra
.50224 .38009 .50315 .38116 .5048 .38061 .50389 .37953 Mtetra
.50389 .37953 .5048 .38061 .50646 .38006 .50555 .37898 Mtetra
.50555 .37898 .50646 .38006 .50811 .3795 .5072 .37842 Mtetra
.5072 .37842 .50811 .3795 .50977 .37895 .50886 .37787 Mtetra
.50886 .37787 .50977 .37895 .51142 .37839 .51052 .37731 Mtetra
.51052 .37731 .51142 .37839 .51308 .37784 .51217 .37675 Mtetra
.51217 .37675 .51308 .37784 .51474 .37728 .51383 .3762 Mtetra
.51383 .3762 .51474 .37728 .5164 .37673 .51549 .37564 Mtetra
.51549 .37564 .5164 .37673 .51806 .37617 .51716 .37508 Mtetra
.51716 .37508 .51806 .37617 .51972 .37561 .51882 .37453 Mtetra
.51882 .37453 .51972 .37561 .52138 .37506 .52048 .37397 Mtetra
.663 .729 .899 r
.52048 .37397 .52138 .37506 .52305 .3745 .52215 .37341 Mtetra
.52215 .37341 .52305 .3745 .52471 .37394 .52381 .37285 Mtetra
.663 .729 .898 r
.52381 .37285 .52471 .37394 .52638 .37339 .52548 .37229 Mtetra
.52548 .37229 .52638 .37339 .52805 .37283 .52714 .37173 Mtetra
.663 .728 .898 r
.52714 .37173 .52805 .37283 .52971 .37227 .52881 .37118 Mtetra
.52881 .37118 .52971 .37227 .53138 .37172 .53048 .37062 Mtetra
.662 .728 .898 r
.53048 .37062 .53138 .37172 .53305 .37116 .53215 .37006 Mtetra
.662 .727 .898 r
.53215 .37006 .53305 .37116 .53472 .37061 .53382 .36951 Mtetra
.661 .727 .899 r
.53382 .36951 .53472 .37061 .5364 .37005 .5355 .36895 Mtetra
.663 .729 .898 r
.5355 .36895 .5364 .37005 .53807 .36949 .53717 .36839 Mtetra
.659 .729 .901 r
.53717 .36839 .53807 .36949 .53974 .36893 .53885 .36785 Mtetra
.653 .728 .905 r
.53885 .36785 .53974 .36893 .54142 .36841 .54052 .36733 Mtetra
.625 .721 .915 r
.54052 .36733 .54142 .36841 .54309 .36799 .5422 .36693 Mtetra
.624 .722 .917 r
.5422 .36693 .54309 .36799 .54477 .36758 .54388 .36653 Mtetra
.635 .729 .916 r
.54388 .36653 .54477 .36758 .54645 .36712 .54556 .36608 Mtetra
.684 .75 .901 r
.54556 .36608 .54645 .36712 .54813 .36641 .54724 .36543 Mtetra
.695 .763 .904 r
.54724 .36543 .54813 .36641 .54981 .36566 .54892 .36472 Mtetra
.697 .774 .911 r
.54892 .36472 .54981 .36566 .55149 .36491 .5506 .36401 Mtetra
.706 .784 .913 r
.5506 .36401 .55149 .36491 .55317 .36402 .55228 .36326 Mtetra
.673 .811 .949 r
.55228 .36326 .55317 .36402 .55485 .36336 .55396 .36264 Mtetra
.597 .795 .975 r
.55396 .36264 .55485 .36336 .55654 .36316 .55565 .36225 Mtetra
.223 .559 .935 r
.55565 .36225 .55654 .36316 .55825 .36499 .55734 .36273 Mtetra
.338 .399 .778 r
.55734 .36273 .55825 .36499 .56 .37053 .55905 .36373 Mtetra
.467 .336 .619 r
.55905 .36373 .56 .37053 .56397 .56795 .56076 .36519 Mtetra
.549 .332 .538 r
.56076 .36519 .56397 .56795 .56579 .5688 .56245 .36447 Mtetra
.56245 .36447 .56579 .5688 .56759 .5679 .56414 .3636 Mtetra
.547 .331 .538 r
.56414 .3636 .56759 .5679 .56938 .567 .56584 .36358 Mtetra
0 0 .393 r
.56584 .36358 .56938 .567 .57123 .56961 .57009 .55421 Mtetra
0 0 .448 r
.57009 .55421 .57123 .56961 .57307 .57148 .5721 .56847 Mtetra
0 .093 .625 r
.5721 .56847 .57307 .57148 .5749 .57254 .57395 .57145 Mtetra
.424 .642 .948 r
.57395 .57145 .5749 .57254 .57671 .57239 .57578 .57162 Mtetra
.64 .811 .965 r
.57578 .57162 .57671 .57239 .57852 .57186 .57759 .57107 Mtetra
.72 .829 .932 r
.57759 .57107 .57852 .57186 .58033 .57115 .57939 .5702 Mtetra
.624 .764 .947 r
.57939 .5702 .58033 .57115 .58215 .57089 .58121 .56974 Mtetra
.641 .728 .911 r
.58121 .56974 .58215 .57089 .58397 .57048 .58303 .56924 Mtetra
.687 .727 .881 r
.58303 .56924 .58397 .57048 .58578 .5696 .58484 .5685 Mtetra
.811 .78 .824 r
.58484 .5685 .58578 .5696 .58755 .56663 .58664 .56686 Mtetra
.894 .988 .776 r
.58664 .56686 .58755 .56663 .58925 .56006 .58842 .5646 Mtetra
.229 0 .299 r
.58842 .5646 .58925 .56006 .58718 .36089 .5902 .56184 Mtetra
.545 .325 .531 r
.5902 .56184 .58718 .36089 .58885 .35838 .59202 .56122 Mtetra
.546 .326 .532 r
.59202 .56122 .58885 .35838 .59056 .35813 .59384 .56107 Mtetra
.545 .325 .531 r
.59384 .56107 .59056 .35813 .59228 .35801 .59565 .56008 Mtetra
.523 .308 .529 r
.59565 .56008 .59228 .35801 .59393 .35477 .5972 .54673 Mtetra
0 0 .373 r
.5972 .54673 .59393 .35477 .59559 .35196 .59477 .35304 Mtetra
.916 .914 .523 r
.59477 .35304 .59559 .35196 .59727 .34994 .5964 .34907 Mtetra
.791 .813 .869 r
.5964 .34907 .59727 .34994 .59898 .34907 .5981 .34782 Mtetra
.63 .691 .888 r
.5981 .34782 .59898 .34907 .60069 .34866 .59981 .34739 Mtetra
.55 .653 .903 r
.59981 .34739 .60069 .34866 .60241 .34841 .60154 .34728 Mtetra
.62 .711 .91 r
.60154 .34728 .60241 .34841 .60413 .34796 .60326 .34689 Mtetra
.654 .736 .91 r
.60326 .34689 .60413 .34796 .60584 .34739 .60497 .34636 Mtetra
.667 .748 .911 r
.60497 .34636 .60584 .34739 .60756 .34677 .60669 .34576 Mtetra
.719 .771 .894 r
.60669 .34576 .60756 .34677 .60926 .34577 .6084 .34492 Mtetra
.72 .805 .918 r
.6084 .34492 .60926 .34577 .61097 .34487 .61011 .3441 Mtetra
.666 .81 .952 r
.61011 .3441 .61097 .34487 .61269 .34439 .61183 .34349 Mtetra
.49 .709 .968 r
.61183 .34349 .61269 .34439 .61446 .34549 .61356 .34344 Mtetra
.422 .472 .806 r
.61356 .34344 .61446 .34549 .61631 .34935 .61532 .34404 Mtetra
.41 .319 .641 r
.61532 .34404 .61631 .34935 .62389 .54831 .61711 .34584 Mtetra
.034 0 .418 r
.61711 .34584 .62389 .54831 .62591 .55382 .62432 .53005 Mtetra
.032 0 .448 r
.62432 .53005 .62591 .55382 .62782 .55559 .62682 .55188 Mtetra
.111 .17 .645 r
.62682 .55188 .62782 .55559 .62971 .55631 .62878 .5549 Mtetra
.388 .559 .901 r
.62878 .5549 .62971 .55631 .63157 .55622 .63065 .55533 Mtetra
.636 .785 .953 r
.63065 .55533 .63157 .55622 .63341 .55571 .6325 .5548 Mtetra
.718 .807 .92 r
.6325 .5548 .63341 .55571 .63526 .555 .63434 .55392 Mtetra
.651 .749 .922 r
.63434 .55392 .63526 .555 .63711 .55464 .63619 .55336 Mtetra
.633 .705 .898 r
.63619 .55336 .63711 .55464 .63897 .55425 .63804 .55289 Mtetra
.673 .706 .872 r
.63804 .55289 .63897 .55425 .64081 .55344 .63989 .5522 Mtetra
.751 .752 .852 r
.63989 .5522 .64081 .55344 .6426 .55112 .64172 .55102 Mtetra
.865 .979 .851 r
.64172 .55102 .6426 .55112 .6443 .54612 .64353 .54919 Mtetra
0 0 .139 r
.64353 .54919 .6443 .54612 .63898 .34649 .6453 .54619 Mtetra
.526 .31 .53 r
.6453 .54619 .63898 .34649 .64047 .33887 .64675 .53438 Mtetra
0 0 .393 r
.64675 .53438 .64047 .33887 .64212 .33605 .64137 .33765 Mtetra
.752 .818 .347 r
.64137 .33765 .64212 .33605 .64382 .33431 .64298 .33363 Mtetra
.835 .864 .867 r
.64298 .33363 .64382 .33431 .64554 .33339 .64468 .33213 Mtetra
.641 .697 .887 r
.64468 .33213 .64554 .33339 .64729 .33296 .64643 .33165 Mtetra
.558 .652 .898 r
.64643 .33165 .64729 .33296 .64904 .33271 .64819 .33152 Mtetra
.605 .695 .907 r
.64819 .33152 .64904 .33271 .65079 .3323 .64994 .33118 Mtetra
.657 .732 .905 r
.64994 .33118 .65079 .3323 .65254 .33171 .65168 .33063 Mtetra
.669 .742 .905 r
.65168 .33063 .65254 .33171 .65428 .33106 .65343 .33002 Mtetra
.749 .775 .874 r
.65343 .33002 .65428 .33106 .656 .32998 .65516 .32898 Mtetra
.749 .784 .881 r
.65516 .32898 .656 .32998 .65773 .32893 .65689 .32796 Mtetra
.624 .751 .938 r
.65689 .32796 .65773 .32893 .65948 .32846 .65864 .32752 Mtetra
.54 .057 0 r
.65864 .32752 .65948 .32846 .66134 .33049 .66051 .32964 Mtetra
.974 .678 .395 r
.66051 .32964 .66134 .33049 .67187 .53003 .67103 .53026 Mtetra
.937 .579 .307 r
.67103 .53026 .67187 .53003 .67427 .54163 .67338 .54072 Mtetra
0 .176 .67 r
.67338 .54072 .67427 .54163 .67625 .5433 .67535 .54223 Mtetra
.623 .745 .934 r
.67535 .54223 .67625 .5433 .67813 .54294 .67723 .54177 Mtetra
.758 .771 .863 r
.67723 .54177 .67813 .54294 .67998 .54166 .67908 .54058 Mtetra
.793 .793 .853 r
.67908 .54058 .67998 .54166 .68177 .53917 .68092 .53915 Mtetra
.834 .994 .851 r
.68092 .53915 .68177 .53917 .68344 .53422 .68275 .53742 Mtetra
.082 0 .188 r
.68275 .53742 .68344 .53422 .67579 .33444 .68452 .53462 Mtetra
.531 .314 .53 r
.68452 .53462 .67579 .33444 .67721 .32656 .68597 .52511 Mtetra
.001 0 .406 r
.68597 .52511 .67721 .32656 .67885 .32365 .67816 .32564 Mtetra
0 0 0 r
.67816 .32564 .67885 .32365 .68055 .32179 .67974 .32131 Mtetra
.889 .906 .833 r
.67974 .32131 .68055 .32179 .68228 .32049 .68144 .3194 Mtetra
.706 .755 .89 r
.68144 .3194 .68228 .32049 .68403 .31964 .68319 .31859 Mtetra
.59 .721 .934 r
.68319 .31859 .68403 .31964 .6858 .3193 .68497 .31829 Mtetra
.476 .677 .953 r
.68497 .31829 .6858 .3193 .68763 .32001 .68677 .31832 Mtetra
.436 .526 .851 r
.68677 .31832 .68763 .32001 .68958 .32277 .68859 .31875 Mtetra
.419 .358 .682 r
.68859 .31875 .68958 .32277 .70158 .51553 .69046 .32009 Mtetra
.536 .323 .537 r
.69046 .32009 .70158 .51553 .70423 .52936 .69257 .32584 Mtetra
.022 0 .423 r
.69257 .32584 .70423 .52936 .70629 .53176 .70519 .52678 Mtetra
.133 .147 .608 r
.70519 .52678 .70629 .53176 .70827 .53275 .70734 .53089 Mtetra
.26 .414 .827 r
.70734 .53089 .70827 .53275 .71021 .53305 .70933 .532 Mtetra
.568 .729 .95 r
.70933 .532 .71021 .53305 .71213 .53283 .71125 .53173 Mtetra
.708 .772 .903 r
.71125 .53173 .71213 .53283 .71402 .53202 .71313 .53087 Mtetra
.766 .779 .863 r
.71313 .53087 .71402 .53202 .71584 .53007 .715 .52962 Mtetra
.853 .933 .877 r
.715 .52962 .71584 .53007 .71753 .52586 .71683 .52794 Mtetra
0 0 0 r
.71683 .52794 .71753 .52586 .71743 .49078 .71862 .52527 Mtetra
.469 .256 .507 r
.71862 .52527 .71743 .49078 .70913 .31671 .72015 .51829 Mtetra
.02 0 .417 r
.72015 .51829 .70913 .31671 .71075 .31342 .71015 .31606 Mtetra
0 0 0 r
.71015 .31606 .71075 .31342 .71245 .31145 .71167 .31112 Mtetra
.904 .938 .822 r
.71167 .31112 .71245 .31145 .7142 .31031 .71337 .3091 Mtetra
.671 .723 .888 r
.71337 .3091 .7142 .31031 .71598 .30975 .71515 .30846 Mtetra
.586 .671 .898 r
.71515 .30846 .71598 .30975 .71778 .3094 .71695 .3082 Mtetra
.624 .706 .904 r
.71695 .3082 .71778 .3094 .71957 .30879 .71875 .30778 Mtetra
.71 .779 .906 r
.71875 .30778 .71957 .30879 .72133 .30782 .72052 .30696 Mtetra
.679 .803 .941 r
.72052 .30696 .72133 .30782 .72311 .30717 .72231 .30629 Mtetra
.512 .729 .972 r
.72231 .30629 .72311 .30717 .72497 .30761 .72413 .30616 Mtetra
.313 .493 .875 r
.72413 .30616 .72497 .30761 .72698 .31053 .726 .30687 Mtetra
.42 .371 .698 r
.726 .30687 .72698 .31053 .74143 .5043 .72791 .3081 Mtetra
.546 .33 .538 r
.72791 .3081 .74143 .5043 .74411 .51554 .72979 .30877 Mtetra
.549 .332 .538 r
.72979 .30877 .74411 .51554 .74604 .51515 .73156 .30773 Mtetra
.548 .332 .538 r
.73156 .30773 .74604 .51515 .74793 .51407 .73335 .30711 Mtetra
.543 .328 .538 r
.73335 .30711 .74793 .51407 .74994 .51483 .73536 .3097 Mtetra
.047 0 .437 r
.73536 .3097 .74994 .51483 .75206 .51725 .75088 .51143 Mtetra
.098 .108 .58 r
.75088 .51143 .75206 .51725 .75413 .5187 .75321 .51671 Mtetra
.17 .339 .791 r
.75321 .51671 .75413 .5187 .75614 .51931 .75528 .51826 Mtetra
.548 .722 .954 r
.75528 .51826 .75614 .51931 .7581 .51914 .75724 .51805 Mtetra
.697 .774 .911 r
.75724 .51805 .7581 .51914 .76002 .5184 .75915 .51724 Mtetra
.782 .785 .855 r
.75915 .51724 .76002 .5184 .76186 .51657 .76103 .51585 Mtetra
.878 .879 .831 r
.76103 .51585 .76186 .51657 .76353 .51226 .76286 .51382 Mtetra
0 0 0 r
.76286 .51382 .76353 .51226 .76423 .49467 .76465 .51125 Mtetra
.496 .262 .489 r
.76465 .51125 .76423 .49467 .75233 .30409 .76647 .50913 Mtetra
.546 .326 .532 r
.76647 .50913 .75233 .30409 .75413 .30326 .76844 .50903 Mtetra
.546 .325 .532 r
.76844 .50903 .75413 .30326 .75598 .30329 .77039 .50863 Mtetra
.542 .323 .531 r
.77039 .50863 .75598 .30329 .75775 .30201 .77216 .50574 Mtetra
.054 0 .435 r
.77216 .50574 .75775 .30201 .75936 .29876 .75903 .30396 Mtetra
0 0 .189 r
.75903 .30396 .75936 .29876 .76104 .29634 .76032 .29633 Mtetra
.948 .956 .718 r
.76032 .29633 .76104 .29634 .76278 .29478 .76197 .29357 Mtetra
.704 .741 .88 r
.76197 .29357 .76278 .29478 .76458 .29408 .76377 .29274 Mtetra
.615 .679 .887 r
.76377 .29274 .76458 .29408 .76641 .29362 .7656 .29236 Mtetra
.592 .684 .905 r
.7656 .29236 .76641 .29362 .76824 .29318 .76744 .29207 Mtetra
.659 .743 .912 r
.76744 .29207 .76824 .29318 .77006 .29257 .76926 .29148 Mtetra
.665 .749 .912 r
.76926 .29148 .77006 .29257 .77187 .29194 .77108 .29086 Mtetra
.673 .756 .913 r
.77108 .29086 .77187 .29194 .77369 .29127 .77289 .2902 Mtetra
.682 .761 .911 r
.77289 .2902 .77369 .29127 .7755 .29058 .77471 .28951 Mtetra
.694 .765 .906 r
.77471 .28951 .7755 .29058 .77731 .28983 .77652 .28875 Mtetra
.737 .779 .886 r
.77652 .28875 .77731 .28983 .7791 .28884 .77831 .28776 Mtetra
.796 .796 .851 r
.77831 .28776 .7791 .28884 .78086 .28743 .78007 .28637 Mtetra
.725 .779 .895 r
.78007 .28637 .78086 .28743 .78266 .2865 .78187 .28546 Mtetra
.389 .625 .947 r
.78187 .28546 .78266 .2865 .78456 .28674 .78377 .28572 Mtetra
.802 .374 0 r
.78377 .28572 .78456 .28674 .78682 .29139 .78605 .2905 Mtetra
.974 .666 .332 r
.78605 .2905 .78682 .29139 .80623 .49816 .80541 .49725 Mtetra
.798 .355 0 r
.80541 .49725 .80623 .49816 .80864 .50293 .80781 .5019 Mtetra
.311 .597 .947 r
.80781 .5019 .80864 .50293 .8107 .50338 .80987 .50233 Mtetra
.687 .785 .925 r
.80987 .50233 .8107 .50338 .81265 .5026 .81182 .50156 Mtetra
.882 .826 .788 r
.81182 .50156 .81265 .5026 .81446 .5002 .81363 .49919 Mtetra
.984 .76 .52 r
.81363 .49919 .81446 .5002 .81563 .49054 .81485 .48999 Mtetra
.977 .675 .343 r
.81485 .48999 .81563 .49054 .79949 .28511 .79872 .28418 Mtetra
.957 .81 .656 r
.79872 .28418 .79949 .28511 .80102 .28103 .80025 .28001 Mtetra
.723 .788 .904 r
.80025 .28001 .80102 .28103 .80284 .28017 .80206 .27911 Mtetra
.572 .718 .941 r
.80206 .27911 .80284 .28017 .80471 .27994 .80393 .27885 Mtetra
.523 .686 .941 r
.80393 .27885 .80471 .27994 .8066 .27992 .80582 .27876 Mtetra
.715 .759 .887 r
.80582 .27876 .8066 .27992 .80844 .27919 .80764 .27788 Mtetra
.663 .709 .882 r
.80764 .27788 .80844 .27919 .81028 .27856 .80948 .27726 Mtetra
.502 .631 .909 r
.80948 .27726 .81028 .27856 .81215 .27824 .81139 .27731 Mtetra
0 0 .466 r
.81139 .27731 .81215 .27824 .81408 .27861 .81353 .27984 Mtetra
.973 .66 .324 r
.81353 .27984 .81408 .27861 .8161 .27982 .83256 .46268 Mtetra
.587 .355 .532 r
.83256 .46268 .8161 .27982 .81836 .28351 .83701 .48848 Mtetra
.549 .328 .532 r
.83701 .48848 .81836 .28351 .83946 .48526 .83924 .49049 Mtetra
.566 .26 .408 r
.83924 .49049 .83946 .48526 .84201 .4906 .84135 .49123 Mtetra
.354 0 0 r
.84135 .49123 .84201 .4906 .84423 .49247 .84341 .49139 Mtetra
.454 .669 .956 r
.84341 .49139 .84423 .49247 .8463 .49276 .84547 .49148 Mtetra
.642 .723 .906 r
.84547 .49148 .8463 .49276 .84829 .49215 .84746 .49091 Mtetra
.807 .789 .836 r
.84746 .49091 .84829 .49215 .85017 .49037 .84936 .48928 Mtetra
.977 .78 .571 r
.84936 .48928 .85017 .49037 .85156 .48367 .85075 .48258 Mtetra
.976 .67 .326 r
.85075 .48258 .85156 .48367 .83297 .27606 .8322 .27492 Mtetra
.966 .781 .604 r
.8322 .27492 .83297 .27606 .83435 .27067 .83358 .26953 Mtetra
.76 .779 .869 r
.83358 .26953 .83435 .27067 .83616 .26951 .83539 .26836 Mtetra
.628 .727 .919 r
.83539 .26836 .83616 .26951 .83803 .26904 .83726 .2679 Mtetra
.548 .689 .932 r
.83726 .2679 .83803 .26904 .83994 .26888 .83917 .26774 Mtetra
.748 .775 .875 r
.83917 .26774 .83994 .26888 .84176 .2678 .84099 .26666 Mtetra
.679 .749 .904 r
.84099 .26666 .84176 .2678 .84361 .26711 .84285 .26596 Mtetra
.462 .643 .936 r
.84285 .26596 .84361 .26711 .84555 .26723 .84479 .26608 Mtetra
.848 .451 0 r
.84479 .26608 .84555 .26723 .84822 .2743 .84746 .2732 Mtetra
.971 .656 .295 r
.84746 .2732 .84822 .2743 .8718 .4803 .871 .47923 Mtetra
0 0 .445 r
.871 .47923 .8718 .4803 .8742 .48342 .8734 .48234 Mtetra
.977 .788 .581 r
.8734 .48234 .8742 .48342 .87561 .47717 .87481 .47613 Mtetra
.974 .667 .312 r
.87481 .47613 .87561 .47717 .85534 .26822 .85458 .26712 Mtetra
.97 .787 .601 r
.85458 .26712 .85534 .26822 .85671 .26291 .85595 .26178 Mtetra
.89 .464 .125 r
.25194 .46315 .25295 .46405 .25418 .46689 .25317 .46603 Mtetra
.937 .682 .526 r
.25317 .46603 .25418 .46689 .23962 .6627 .23853 .66198 Mtetra
.935 .609 .395 r
.23853 .66198 .23962 .6627 .24059 .66989 .23951 .66905 Mtetra
0 .407 .834 r
.23951 .66905 .24059 .66989 .24209 .67064 .24102 .66974 Mtetra
.64 .755 .932 r
.24102 .66974 .24209 .67064 .24368 .67022 .24261 .66929 Mtetra
.805 .769 .82 r
.24261 .66929 .24368 .67022 .24537 .66868 .2443 .66776 Mtetra
.906 .736 .661 r
.2443 .66776 .24537 .66868 .24742 .66255 .2463 .66239 Mtetra
.938 .687 .532 r
.2463 .66239 .24742 .66255 .26466 .46458 .26353 .46522 Mtetra
.971 .816 .631 r
.26353 .46522 .26466 .46458 .26655 .45933 .26549 .45917 Mtetra
.833 .923 .894 r
.26549 .45917 .26655 .45933 .2681 .4583 .26707 .45786 Mtetra
.639 .86 .983 r
.26707 .45786 .2681 .4583 .2696 .45806 .26858 .45734 Mtetra
.507 .747 .982 r
.26858 .45734 .2696 .45806 .27106 .45823 .27007 .45722 Mtetra
.633 .717 .908 r
.27007 .45722 .27106 .45823 .27256 .45791 .27158 .45683 Mtetra
.631 .703 .897 r
.27158 .45683 .27256 .45791 .27407 .45751 .27309 .45645 Mtetra
.63 .707 .901 r
.27309 .45645 .27407 .45751 .27559 .45707 .27459 .45607 Mtetra
.65 .726 .904 r
.27459 .45607 .27559 .45707 .2771 .45659 .27611 .45561 Mtetra
.66 .734 .905 r
.27611 .45561 .2771 .45659 .27863 .45606 .27763 .45512 Mtetra
.667 .743 .907 r
.27763 .45512 .27863 .45606 .28015 .45547 .27915 .45459 Mtetra
.677 .758 .911 r
.27915 .45459 .28015 .45547 .2817 .45463 .28068 .45402 Mtetra
.678 .823 .953 r
.28068 .45402 .2817 .45463 .28324 .45387 .28221 .45344 Mtetra
.666 .866 .975 r
.28221 .45344 .28324 .45387 .28477 .45335 .28374 .45285 Mtetra
.663 .85 .972 r
.28374 .45285 .28477 .45335 .28622 .45376 .28527 .45229 Mtetra
.66 .65 .83 r
.28527 .45229 .28622 .45376 .28764 .45476 .2868 .45174 Mtetra
.621 .513 .71 r
.2868 .45174 .28764 .45476 .28902 .45628 .28833 .4512 Mtetra
.621 .463 .646 r
.28833 .4512 .28902 .45628 .29055 .45572 .28989 .45026 Mtetra
.603 .444 .64 r
.28989 .45026 .29055 .45572 .29211 .45484 .29143 .44956 Mtetra
.563 .419 .643 r
.29143 .44956 .29211 .45484 .29361 .45478 .29293 .44948 Mtetra
.154 .124 .569 r
.29293 .44948 .29361 .45478 .2823 .63745 .29419 .45271 Mtetra
0 0 .185 r
.29419 .45271 .2823 .63745 .2827 .65435 .28197 .6488 Mtetra
0 0 .247 r
.28197 .6488 .2827 .65435 .28408 .65739 .2831 .65543 Mtetra
.349 .444 .817 r
.2831 .65543 .28408 .65739 .28565 .6577 .28464 .65614 Mtetra
.639 .644 .838 r
.28464 .65614 .28565 .6577 .28728 .65723 .28627 .65568 Mtetra
.707 .67 .811 r
.28627 .65568 .28728 .65723 .28893 .65647 .28793 .65476 Mtetra
.656 .632 .814 r
.28793 .65476 .28893 .65647 .29055 .65603 .28956 .65417 Mtetra
.639 .609 .804 r
.28956 .65417 .29055 .65603 .29218 .65568 .29119 .65367 Mtetra
.637 .594 .79 r
.29119 .65367 .29218 .65568 .2938 .65531 .29283 .65317 Mtetra
.636 .583 .777 r
.29283 .65317 .2938 .65531 .29543 .65488 .29446 .65264 Mtetra
.633 .574 .77 r
.29446 .65264 .29543 .65488 .29706 .65439 .2961 .65212 Mtetra
.628 .569 .768 r
.2961 .65212 .29706 .65439 .2987 .65387 .29773 .65164 Mtetra
.614 .564 .775 r
.29773 .65164 .2987 .65387 .30034 .65326 .29936 .65126 Mtetra
.61 .582 .797 r
.29936 .65126 .30034 .65326 .30199 .65262 .30099 .65093 Mtetra
.615 .617 .83 r
.30099 .65093 .30199 .65262 .30364 .65198 .30262 .65058 Mtetra
.635 .666 .863 r
.30262 .65058 .30364 .65198 .30527 .65156 .30425 .65015 Mtetra
.644 .668 .858 r
.30425 .65015 .30527 .65156 .30691 .65114 .30589 .64967 Mtetra
.647 .66 .849 r
.30589 .64967 .30691 .65114 .30856 .65053 .30753 .64917 Mtetra
.647 .677 .864 r
.30753 .64917 .30856 .65053 .31025 .64912 .30918 .64868 Mtetra
.605 .862 .992 r
.30918 .64868 .31025 .64912 .31199 .64705 .31082 .64819 Mtetra
.21 0 0 r
.31082 .64819 .31199 .64705 .31376 .64451 .31246 .64769 Mtetra
.492 .16 .331 r
.31246 .64769 .31376 .64451 .31543 .64363 .31409 .64756 Mtetra
.49 .178 .364 r
.31409 .64756 .31543 .64363 .31705 .64351 .31572 .6473 Mtetra
.411 .1 .324 r
.31572 .6473 .31705 .64351 .31871 .64268 .31739 .64643 Mtetra
0 0 .01 r
.31739 .64643 .31871 .64268 .32083 .63419 .31923 .64269 Mtetra
.957 .701 .509 r
.31923 .64269 .32083 .63419 .33376 .44102 .33234 .44749 Mtetra
.777 .737 .213 r
.33234 .44749 .33376 .44102 .33553 .43678 .33448 .43701 Mtetra
.91 .96 .808 r
.33448 .43701 .33553 .43678 .33714 .43525 .33613 .43496 Mtetra
.63 .899 .986 r
.33613 .43496 .33714 .43525 .3387 .43468 .33769 .43438 Mtetra
.35 .783 .968 r
.33769 .43438 .3387 .43468 .34024 .43446 .33922 .43425 Mtetra
.524 .881 .983 r
.33922 .43425 .34024 .43446 .34178 .43418 .34077 .43381 Mtetra
.67 .89 .978 r
.34077 .43381 .34178 .43418 .34333 .43383 .34234 .43317 Mtetra
.689 .817 .944 r
.34234 .43317 .34333 .43383 .34488 .43349 .34391 .43254 Mtetra
.671 .748 .908 r
.34391 .43254 .34488 .43349 .34643 .43306 .34547 .43198 Mtetra
.658 .718 .893 r
.34547 .43198 .34643 .43306 .34799 .43255 .34703 .43148 Mtetra
.655 .718 .894 r
.34703 .43148 .34799 .43255 .34956 .43199 .34859 .43098 Mtetra
.662 .734 .903 r
.34859 .43098 .34956 .43199 .35113 .43123 .35015 .43046 Mtetra
.666 .787 .939 r
.35015 .43046 .35113 .43123 .35271 .43047 .35172 .42992 Mtetra
.655 .842 .972 r
.35172 .42992 .35271 .43047 .35428 .42989 .35328 .42938 Mtetra
.651 .848 .976 r
.35328 .42938 .35428 .42989 .35581 .43004 .35485 .42883 Mtetra
.663 .696 .87 r
.35485 .42883 .35581 .43004 .3573 .43091 .35642 .42829 Mtetra
.627 .538 .734 r
.35642 .42829 .3573 .43091 .35877 .4323 .35799 .42776 Mtetra
.621 .472 .659 r
.35799 .42776 .35877 .4323 .36031 .43242 .35957 .42691 Mtetra
.608 .448 .639 r
.35957 .42691 .36031 .43242 .3619 .43146 .36116 .4261 Mtetra
.577 .428 .642 r
.36116 .4261 .3619 .43146 .36346 .4311 .36271 .42581 Mtetra
.373 .284 .626 r
.36271 .42581 .36346 .4311 .36475 .4365 .36417 .42772 Mtetra
.961 .697 .489 r
.36417 .42772 .36475 .4365 .35685 .63071 .35645 .61687 Mtetra
0 0 .27 r
.35645 .61687 .35685 .63071 .3583 .63466 .35735 .63217 Mtetra
.083 .219 .708 r
.35735 .63217 .3583 .63466 .35991 .63555 .35891 .63394 Mtetra
.577 .613 .852 r
.35891 .63394 .35991 .63555 .36158 .63517 .36057 .63378 Mtetra
.68 .686 .849 r
.36057 .63378 .36158 .63517 .36326 .63441 .36225 .63309 Mtetra
.672 .694 .862 r
.36225 .63309 .36326 .63441 .36494 .63385 .36394 .63245 Mtetra
.642 .673 .864 r
.36394 .63245 .36494 .63385 .36661 .63346 .36561 .63198 Mtetra
.648 .662 .849 r
.36561 .63198 .36661 .63346 .36829 .63288 .36729 .63146 Mtetra
.595 .649 .874 r
.36729 .63146 .36829 .63288 .37 .63188 .36896 .6312 Mtetra
.53 .782 .99 r
.36896 .6312 .37 .63188 .37173 .63026 .37063 .63096 Mtetra
0 0 0 r
.37063 .63096 .37173 .63026 .3735 .62766 .37232 .63018 Mtetra
.37232 .63018 .3735 .62766 .37548 .62016 .37411 .62725 Mtetra
.907 .787 .303 r
.37411 .62725 .37548 .62016 .38555 .42428 .37642 .61226 Mtetra
0 0 .262 r
.37642 .61226 .38555 .42428 .3873 .41978 .38627 .42045 Mtetra
.944 .961 .704 r
.38627 .42045 .3873 .41978 .38894 .41803 .38796 .41759 Mtetra
.738 .886 .947 r
.38796 .41759 .38894 .41803 .39052 .41752 .38956 .41673 Mtetra
.605 .769 .959 r
.38956 .41673 .39052 .41752 .39209 .41741 .39114 .41638 Mtetra
.611 .716 .92 r
.39114 .41638 .39209 .41741 .39366 .4172 .39272 .41605 Mtetra
.652 .704 .885 r
.39272 .41605 .39366 .4172 .39525 .41673 .39431 .41556 Mtetra
.645 .699 .885 r
.39431 .41556 .39525 .41673 .39684 .41624 .39589 .4151 Mtetra
.65 .707 .889 r
.39589 .4151 .39684 .41624 .39843 .41573 .39748 .41462 Mtetra
.657 .716 .891 r
.39748 .41462 .39843 .41573 .40002 .41521 .39907 .41411 Mtetra
.66 .718 .891 r
.39907 .41411 .40002 .41521 .40161 .41469 .40067 .41359 Mtetra
.662 .719 .891 r
.40067 .41359 .40161 .41469 .40321 .41415 .40226 .41306 Mtetra
.664 .72 .89 r
.40226 .41306 .40321 .41415 .4048 .41361 .40386 .41251 Mtetra
.666 .72 .889 r
.40386 .41251 .4048 .41361 .4064 .41306 .40545 .41196 Mtetra
.671 .721 .887 r
.40545 .41196 .4064 .41306 .40799 .41251 .40705 .41138 Mtetra
.673 .718 .882 r
.40705 .41138 .40799 .41251 .40959 .41195 .40865 .41079 Mtetra
.669 .71 .879 r
.40865 .41079 .40959 .41195 .41119 .41137 .41025 .41022 Mtetra
.656 .708 .886 r
.41025 .41022 .41119 .41137 .41279 .41071 .41185 .40971 Mtetra
.638 .733 .917 r
.41185 .40971 .41279 .41071 .4144 .40998 .41345 .40928 Mtetra
.62 .799 .968 r
.41345 .40928 .4144 .40998 .41601 .40925 .41504 .40886 Mtetra
.681 .891 .974 r
.41504 .40886 .41601 .40925 .41762 .40844 .41665 .40817 Mtetra
.733 .926 .955 r
.41665 .40817 .41762 .40844 .41923 .40763 .41827 .40727 Mtetra
.553 .866 .996 r
.41827 .40727 .41923 .40763 .42083 .40718 .41987 .40685 Mtetra
.651 .094 0 r
.41987 .40685 .42083 .40718 .4224 .40785 .42141 .40817 Mtetra
.936 .63 .436 r
.42141 .40817 .4224 .40785 .42388 .41139 .42256 .42232 Mtetra
.939 .667 .497 r
.42256 .42232 .42388 .41139 .41947 .60658 .41821 .61373 Mtetra
.632 .348 .47 r
.41821 .61373 .41947 .60658 .42098 .61234 .41984 .61607 Mtetra
.495 .177 .357 r
.41984 .61607 .42098 .61234 .42269 .61207 .42154 .61589 Mtetra
.431 .12 .335 r
.42154 .61589 .42269 .61207 .42441 .61118 .42326 .61513 Mtetra
.43 .122 .34 r
.42326 .61513 .42441 .61118 .4261 .61132 .42498 .61432 Mtetra
.441 .103 .296 r
.42498 .61432 .4261 .61132 .42776 .61285 .4267 .61385 Mtetra
.184 0 0 r
.4267 .61385 .42776 .61285 .42943 .61389 .42842 .61335 Mtetra
.635 .856 .983 r
.42842 .61335 .42943 .61389 .43112 .61423 .43014 .61278 Mtetra
.672 .68 .849 r
.43014 .61278 .43112 .61423 .43284 .61386 .43186 .61212 Mtetra
.665 .64 .815 r
.43186 .61212 .43284 .61386 .43456 .61329 .43358 .61145 Mtetra
.627 .612 .816 r
.43358 .61145 .43456 .61329 .43628 .61281 .4353 .61101 Mtetra
.568 .588 .834 r
.4353 .61101 .43628 .61281 .43799 .61258 .43701 .61089 Mtetra
.654 .642 .826 r
.43701 .61089 .43799 .61258 .43972 .612 .43874 .6103 Mtetra
.804 .695 .744 r
.43874 .6103 .43972 .612 .44147 .61037 .44051 .60811 Mtetra
.91 .69 .592 r
.44051 .60811 .44147 .61037 .44329 .60588 .44246 .59813 Mtetra
.949 .681 .494 r
.44246 .59813 .44329 .60588 .44951 .41221 .44884 .40007 Mtetra
.644 .437 .588 r
.44884 .40007 .44951 .41221 .45137 .40195 .45054 .39648 Mtetra
.611 .452 .641 r
.45054 .39648 .45137 .40195 .453 .40108 .45217 .3956 Mtetra
.577 .428 .642 r
.45217 .3956 .453 .40108 .45462 .40092 .45379 .3953 Mtetra
.569 .42 .639 r
.45379 .3953 .45462 .40092 .45625 .39997 .4554 .39511 Mtetra
.597 .451 .654 r
.4554 .39511 .45625 .39997 .45792 .39741 .45703 .39456 Mtetra
.622 .526 .724 r
.45703 .39456 .45792 .39741 .45958 .39536 .45866 .39402 Mtetra
.656 .677 .858 r
.45866 .39402 .45958 .39536 .46122 .39396 .46029 .39348 Mtetra
.624 .861 .987 r
.46029 .39348 .46122 .39396 .46286 .3933 .46192 .39296 Mtetra
.595 .887 .991 r
.46192 .39296 .46286 .3933 .46448 .39284 .46355 .39243 Mtetra
.616 .878 .99 r
.46355 .39243 .46448 .39284 .46611 .39242 .46518 .39189 Mtetra
.647 .856 .979 r
.46518 .39189 .46611 .39242 .46774 .39186 .46681 .39133 Mtetra
.652 .855 .977 r
.46681 .39133 .46774 .39186 .46938 .39132 .46844 .39075 Mtetra
.658 .847 .972 r
.46844 .39075 .46938 .39132 .47101 .39082 .47008 .39016 Mtetra
.668 .828 .96 r
.47008 .39016 .47101 .39082 .47264 .3904 .47172 .38957 Mtetra
.669 .783 .935 r
.47172 .38957 .47264 .3904 .47428 .38997 .47335 .38899 Mtetra
.657 .747 .916 r
.47335 .38899 .47428 .38997 .47591 .38946 .47499 .38847 Mtetra
.632 .736 .923 r
.47499 .38847 .47591 .38946 .47755 .38877 .47663 .38804 Mtetra
.613 .794 .968 r
.47663 .38804 .47755 .38877 .47919 .38805 .47826 .38763 Mtetra
.576 .863 .996 r
.47826 .38763 .47919 .38805 .48083 .38735 .4799 .38718 Mtetra
.553 .906 .97 r
.4799 .38718 .48083 .38735 .48248 .38676 .48154 .38662 Mtetra
.557 .912 .963 r
.48154 .38662 .48248 .38676 .48412 .38619 .48319 .38602 Mtetra
.569 .913 .969 r
.48319 .38602 .48412 .38619 .48576 .38564 .48483 .38543 Mtetra
.568 .906 .976 r
.48483 .38543 .48576 .38564 .4874 .38508 .48648 .38486 Mtetra
.566 .905 .977 r
.48648 .38486 .4874 .38508 .48905 .38452 .48812 .3843 Mtetra
.564 .904 .977 r
.48812 .3843 .48905 .38452 .49069 .38396 .48977 .38375 Mtetra
.563 .903 .977 r
.48977 .38375 .49069 .38396 .49234 .38341 .49142 .38319 Mtetra
.562 .903 .977 r
.49142 .38319 .49234 .38341 .49399 .38285 .49306 .38264 Mtetra
.561 .903 .977 r
.49306 .38264 .49399 .38285 .49564 .3823 .49471 .38209 Mtetra
.56 .903 .976 r
.49471 .38209 .49564 .3823 .49729 .38175 .49636 .38153 Mtetra
.49636 .38153 .49729 .38175 .49894 .38119 .49802 .38098 Mtetra
.559 .903 .976 r
.49802 .38098 .49894 .38119 .50059 .38064 .49967 .38043 Mtetra
.49967 .38043 .50059 .38064 .50224 .38009 .50132 .37987 Mtetra
.50132 .37987 .50224 .38009 .50389 .37953 .50298 .37932 Mtetra
.558 .903 .976 r
.50298 .37932 .50389 .37953 .50555 .37898 .50463 .37877 Mtetra
.558 .903 .975 r
.50463 .37877 .50555 .37898 .5072 .37842 .50629 .37821 Mtetra
.50629 .37821 .5072 .37842 .50886 .37787 .50794 .37765 Mtetra
.50794 .37765 .50886 .37787 .51052 .37731 .5096 .3771 Mtetra
.559 .903 .975 r
.5096 .3771 .51052 .37731 .51217 .37675 .51126 .37654 Mtetra
.51126 .37654 .51217 .37675 .51383 .3762 .51292 .37598 Mtetra
.559 .903 .976 r
.51292 .37598 .51383 .3762 .51549 .37564 .51458 .37543 Mtetra
.51458 .37543 .51549 .37564 .51716 .37508 .51625 .37487 Mtetra
.56 .903 .976 r
.51625 .37487 .51716 .37508 .51882 .37453 .51791 .37431 Mtetra
.51791 .37431 .51882 .37453 .52048 .37397 .51957 .37375 Mtetra
.561 .903 .976 r
.51957 .37375 .52048 .37397 .52215 .37341 .52124 .37319 Mtetra
.52124 .37319 .52215 .37341 .52381 .37285 .52291 .37263 Mtetra
.562 .903 .977 r
.52291 .37263 .52381 .37285 .52548 .37229 .52457 .37207 Mtetra
.563 .903 .977 r
.52457 .37207 .52548 .37229 .52714 .37173 .52624 .37151 Mtetra
.52624 .37151 .52714 .37173 .52881 .37118 .52791 .37095 Mtetra
.562 .903 .978 r
.52791 .37095 .52881 .37118 .53048 .37062 .52958 .37039 Mtetra
.562 .902 .978 r
.52958 .37039 .53048 .37062 .53215 .37006 .53125 .36983 Mtetra
.559 .901 .978 r
.53125 .36983 .53215 .37006 .53382 .36951 .53293 .36928 Mtetra
.556 .9 .977 r
.53293 .36928 .53382 .36951 .5355 .36895 .5346 .36873 Mtetra
.535 .893 .976 r
.5346 .36873 .5355 .36895 .53717 .36839 .53628 .36821 Mtetra
.522 .895 .966 r
.53628 .36821 .53717 .36839 .53885 .36785 .53795 .36768 Mtetra
.535 .903 .963 r
.53795 .36768 .53885 .36785 .54052 .36733 .53963 .36712 Mtetra
.62 .926 .971 r
.53963 .36712 .54052 .36733 .5422 .36693 .5413 .36643 Mtetra
.684 .878 .971 r
.5413 .36643 .5422 .36693 .54388 .36653 .54298 .36572 Mtetra
.694 .802 .932 r
.54298 .36572 .54388 .36653 .54556 .36608 .54466 .36503 Mtetra
.667 .739 .904 r
.54466 .36503 .54556 .36608 .54724 .36543 .54634 .36445 Mtetra
.66 .753 .919 r
.54634 .36445 .54724 .36543 .54892 .36472 .54802 .3639 Mtetra
.653 .788 .946 r
.54802 .3639 .54892 .36472 .5506 .36401 .54971 .36336 Mtetra
.652 .831 .969 r
.54971 .36336 .5506 .36401 .55228 .36326 .55139 .36279 Mtetra
.631 .873 .987 r
.55139 .36279 .55228 .36326 .55396 .36264 .55307 .36221 Mtetra
.623 .882 .989 r
.55307 .36221 .55396 .36264 .55565 .36225 .55476 .36164 Mtetra
.65 .841 .974 r
.55476 .36164 .55565 .36225 .55734 .36273 .55645 .36107 Mtetra
.652 .637 .822 r
.55645 .36107 .55734 .36273 .55905 .36373 .55813 .3605 Mtetra
.617 .508 .707 r
.55813 .3605 .55905 .36373 .56076 .36519 .55982 .35993 Mtetra
.619 .461 .645 r
.55982 .35993 .56076 .36519 .56245 .36447 .56151 .35893 Mtetra
.601 .444 .641 r
.56151 .35893 .56245 .36447 .56414 .3636 .5632 .35822 Mtetra
.562 .42 .646 r
.5632 .35822 .56414 .3636 .56584 .36358 .56489 .35814 Mtetra
.212 .177 .6 r
.56489 .35814 .56584 .36358 .57009 .55421 .56664 .36167 Mtetra
0 0 .359 r
.56664 .36167 .57009 .55421 .5721 .56847 .57109 .56298 Mtetra
0 0 .457 r
.57109 .56298 .5721 .56847 .57395 .57145 .573 .56938 Mtetra
.447 .497 .818 r
.573 .56938 .57395 .57145 .57578 .57162 .57482 .56986 Mtetra
.647 .638 .826 r
.57482 .56986 .57578 .57162 .57759 .57107 .57663 .56929 Mtetra
.703 .659 .804 r
.57663 .56929 .57759 .57107 .57939 .5702 .57844 .56828 Mtetra
.627 .611 .814 r
.57844 .56828 .57939 .5702 .58121 .56974 .58026 .56782 Mtetra
.611 .602 .818 r
.58026 .56782 .58121 .56974 .58303 .56924 .58207 .56745 Mtetra
.617 .621 .832 r
.58207 .56745 .58303 .56924 .58484 .5685 .58389 .56706 Mtetra
.643 .679 .869 r
.58389 .56706 .58484 .5685 .58664 .56686 .58571 .56654 Mtetra
.565 .893 .986 r
.58571 .56654 .58664 .56686 .58842 .5646 .58753 .56596 Mtetra
.263 0 .003 r
.58753 .56596 .58842 .5646 .5902 .56184 .58935 .56537 Mtetra
.499 .173 .345 r
.58935 .56537 .5902 .56184 .59202 .56122 .59118 .56526 Mtetra
.486 .174 .362 r
.59118 .56526 .59202 .56122 .59384 .56107 .59301 .56492 Mtetra
.411 .104 .332 r
.59301 .56492 .59384 .56107 .59565 .56008 .59482 .56392 Mtetra
0 0 .113 r
.59482 .56392 .59565 .56008 .5972 .54673 .59657 .5595 Mtetra
.982 .704 .41 r
.59657 .5595 .5972 .54673 .59477 .35304 .59401 .35764 Mtetra
0 0 0 r
.59401 .35764 .59477 .35304 .5964 .34907 .59555 .34911 Mtetra
.883 .984 .82 r
.59555 .34911 .5964 .34907 .5981 .34782 .59723 .34722 Mtetra
.691 .859 .963 r
.59723 .34722 .5981 .34782 .59981 .34739 .59894 .34649 Mtetra
.58 .747 .957 r
.59894 .34649 .59981 .34739 .60154 .34728 .60066 .3462 Mtetra
.637 .727 .913 r
.60066 .3462 .60154 .34728 .60326 .34689 .60238 .34573 Mtetra
.649 .717 .898 r
.60238 .34573 .60326 .34689 .60497 .34636 .6041 .34522 Mtetra
.647 .721 .903 r
.6041 .34522 .60497 .34636 .60669 .34576 .60582 .34472 Mtetra
.666 .746 .91 r
.60582 .34472 .60669 .34576 .6084 .34492 .60754 .34413 Mtetra
.672 .807 .948 r
.60754 .34413 .6084 .34492 .61011 .3441 .60925 .34351 Mtetra
.659 .855 .975 r
.60925 .34351 .61011 .3441 .61183 .34349 .61097 .34288 Mtetra
.747 .87 .937 r
.61097 .34288 .61183 .34349 .61356 .34344 .61268 .34193 Mtetra
.688 .676 .833 r
.61268 .34193 .61356 .34344 .61532 .34404 .6144 .34115 Mtetra
.581 .504 .732 r
.6144 .34115 .61532 .34404 .61711 .34584 .61613 .34096 Mtetra
.295 .249 .635 r
.61613 .34096 .61711 .34584 .62432 .53005 .61795 .34361 Mtetra
0 0 .373 r
.61795 .34361 .62432 .53005 .62682 .55188 .62569 .54386 Mtetra
0 0 .469 r
.62569 .54386 .62682 .55188 .62878 .5549 .62781 .55246 Mtetra
.326 .391 .776 r
.62781 .55246 .62878 .5549 .63065 .55533 .62971 .55363 Mtetra
.606 .628 .847 r
.62971 .55363 .63065 .55533 .6325 .5548 .63157 .55329 Mtetra
.691 .691 .846 r
.63157 .55329 .6325 .5548 .63434 .55392 .63341 .55247 Mtetra
.667 .69 .862 r
.63341 .55247 .63434 .55392 .63619 .55336 .63526 .55181 Mtetra
.649 .667 .854 r
.63526 .55181 .63619 .55336 .63804 .55289 .63711 .55124 Mtetra
.652 .656 .841 r
.63711 .55124 .63804 .55289 .63989 .5522 .63896 .55063 Mtetra
.584 .637 .869 r
.63896 .55063 .63989 .5522 .64172 .55102 .64082 .5504 Mtetra
.531 .812 .998 r
.64082 .5504 .64172 .55102 .64353 .54919 .64269 .55007 Mtetra
0 0 0 r
.64269 .55007 .64353 .54919 .6453 .54619 .64453 .54913 Mtetra
0 0 .041 r
.64453 .54913 .6453 .54619 .64675 .53438 .64627 .54537 Mtetra
.983 .7 .392 r
.64627 .54537 .64675 .53438 .64137 .33765 .64083 .34523 Mtetra
0 0 .141 r
.64083 .34523 .64137 .33765 .64298 .33363 .64217 .33391 Mtetra
.9 .985 .731 r
.64217 .33391 .64298 .33363 .64468 .33213 .64385 .33156 Mtetra
.707 .875 .96 r
.64385 .33156 .64468 .33213 .64643 .33165 .64558 .33076 Mtetra
.59 .756 .957 r
.64558 .33076 .64643 .33165 .64819 .33152 .64733 .33042 Mtetra
.626 .724 .917 r
.64733 .33042 .64819 .33152 .64994 .33118 .64908 .32999 Mtetra
.653 .716 .894 r
.64908 .32999 .64994 .33118 .65168 .33063 .65083 .32945 Mtetra
.649 .717 .898 r
.65083 .32945 .65168 .33063 .65343 .33002 .65258 .32893 Mtetra
.72 .76 .884 r
.65258 .32893 .65343 .33002 .65516 .32898 .65431 .32806 Mtetra
.724 .795 .908 r
.65431 .32806 .65516 .32898 .65689 .32796 .65605 .32719 Mtetra
.573 .782 .978 r
.65605 .32719 .65689 .32796 .65864 .32752 .65781 .32686 Mtetra
.626 .105 0 r
.65781 .32686 .65864 .32752 .66051 .32964 .65967 .32889 Mtetra
.974 .678 .396 r
.65967 .32889 .66051 .32964 .67103 .53026 .67001 .5264 Mtetra
.861 .555 .029 r
.67001 .5264 .67103 .53026 .67338 .54072 .67244 .53874 Mtetra
.098 .293 .772 r
.67244 .53874 .67338 .54072 .67535 .54223 .67442 .54042 Mtetra
.589 .608 .839 r
.67442 .54042 .67535 .54223 .67723 .54177 .67631 .54017 Mtetra
.682 .678 .84 r
.67631 .54017 .67723 .54177 .67908 .54058 .67818 .53938 Mtetra
.631 .721 .912 r
.67818 .53938 .67908 .54058 .68092 .53915 .68006 .5389 Mtetra
.399 .831 .956 r
.68006 .5389 .68092 .53915 .68275 .53742 .68195 .53855 Mtetra
.076 0 0 r
.68195 .53855 .68275 .53742 .68452 .53462 .68382 .5376 Mtetra
0 0 .11 r
.68382 .5376 .68452 .53462 .68597 .52511 .68557 .53426 Mtetra
.982 .695 .378 r
.68557 .53426 .68597 .52511 .67816 .32564 .67804 .33932 Mtetra
0 0 .277 r
.67804 .33932 .67816 .32564 .67974 .32131 .67898 .32181 Mtetra
.895 .965 .641 r
.67898 .32181 .67974 .32131 .68144 .3194 .68064 .31903 Mtetra
.721 .933 .959 r
.68064 .31903 .68144 .3194 .68319 .31859 .68238 .31809 Mtetra
.567 .851 .997 r
.68238 .31809 .68319 .31859 .68497 .31829 .68416 .31764 Mtetra
.666 .849 .97 r
.68416 .31764 .68497 .31829 .68677 .31832 .68592 .31699 Mtetra
.699 .711 .858 r
.68592 .31699 .68677 .31832 .68859 .31875 .68768 .31618 Mtetra
.596 .533 .754 r
.68768 .31618 .68859 .31875 .69046 .32009 .68946 .31587 Mtetra
.399 .339 .674 r
.68946 .31587 .69046 .32009 .69257 .32584 .69134 .31745 Mtetra
0 0 .37 r
.69134 .31745 .69257 .32584 .70519 .52678 .6938 .32966 Mtetra
.01 0 .42 r
.6938 .32966 .70519 .52678 .70734 .53089 .70635 .52783 Mtetra
.187 .257 .704 r
.70635 .52783 .70734 .53089 .70933 .532 .7084 .5301 Mtetra
.563 .585 .833 r
.7084 .5301 .70933 .532 .71125 .53173 .71033 .52999 Mtetra
.662 .654 .831 r
.71033 .52999 .71125 .53173 .71313 .53087 .71222 .5293 Mtetra
.637 .664 .859 r
.71222 .5293 .71313 .53087 .715 .52962 .71413 .52878 Mtetra
.545 .768 .98 r
.71413 .52878 .715 .52962 .71683 .52794 .71605 .52851 Mtetra
0 0 0 r
.71605 .52851 .71683 .52794 .71862 .52527 .71794 .52767 Mtetra
0 0 .054 r
.71794 .52767 .71862 .52527 .72015 .51829 .71971 .52485 Mtetra
0 0 .073 r
.71971 .52485 .72015 .51829 .71015 .31606 .72094 .51276 Mtetra
.007 0 .413 r
.72094 .51276 .71015 .31606 .71167 .31112 .71096 .31192 Mtetra
.862 .921 .527 r
.71096 .31192 .71167 .31112 .71337 .3091 .71258 .30862 Mtetra
.744 .916 .95 r
.71258 .30862 .71337 .3091 .71515 .30846 .71434 .30762 Mtetra
.62 .787 .962 r
.71434 .30762 .71515 .30846 .71695 .3082 .71613 .30716 Mtetra
.613 .735 .932 r
.71613 .30716 .71695 .3082 .71875 .30778 .71793 .30676 Mtetra
.66 .759 .923 r
.71793 .30676 .71875 .30778 .72052 .30696 .71972 .30617 Mtetra
.644 .809 .962 r
.71972 .30617 .72052 .30696 .72231 .30629 .72151 .30562 Mtetra
.635 .836 .978 r
.72151 .30562 .72231 .30629 .72413 .30616 .72331 .30506 Mtetra
.66 .742 .911 r
.72331 .30506 .72413 .30616 .726 .30687 .7251 .30447 Mtetra
.634 .566 .761 r
.7251 .30447 .726 .30687 .72791 .3081 .72689 .30388 Mtetra
.619 .482 .673 r
.72689 .30388 .72791 .3081 .72979 .30877 .72867 .30308 Mtetra
.611 .451 .64 r
.72867 .30308 .72979 .30877 .73156 .30773 .73044 .30211 Mtetra
.587 .435 .643 r
.73044 .30211 .73156 .30773 .73335 .30711 .73224 .30161 Mtetra
.485 .369 .647 r
.73224 .30161 .73335 .30711 .73536 .3097 .73415 .30266 Mtetra
0 0 .497 r
.73415 .30266 .73536 .3097 .75088 .51143 .73654 .31075 Mtetra
.03 0 .432 r
.73654 .31075 .75088 .51143 .75321 .51671 .75219 .51342 Mtetra
.112 .196 .672 r
.75219 .51342 .75321 .51671 .75528 .51826 .75436 .51632 Mtetra
.551 .577 .833 r
.75436 .51632 .75528 .51826 .75724 .51805 .75633 .51629 Mtetra
.657 .651 .832 r
.75633 .51629 .75724 .51805 .75915 .51724 .75825 .51561 Mtetra
.684 .681 .841 r
.75825 .51561 .75915 .51724 .76103 .51585 .76017 .51479 Mtetra
.652 .764 .931 r
.76017 .51479 .76103 .51585 .76286 .51382 .7621 .51419 Mtetra
0 0 0 r
.7621 .51419 .76286 .51382 .76465 .51125 .76404 .51356 Mtetra
.421 .051 .228 r
.76404 .51356 .76465 .51125 .76647 .50913 .76598 .51313 Mtetra
.504 .187 .363 r
.76598 .51313 .76647 .50913 .76844 .50903 .76796 .51301 Mtetra
.46 .15 .352 r
.76796 .51301 .76844 .50903 .77039 .50863 .76989 .51239 Mtetra
.274 0 .295 r
.76989 .51239 .77039 .50863 .77216 .50574 .77172 .5102 Mtetra
0 0 .031 r
.77172 .5102 .77216 .50574 .75903 .30396 .77303 .50125 Mtetra
.021 0 .424 r
.77303 .50125 .75903 .30396 .76032 .29633 .75959 .29629 Mtetra
.986 .898 .632 r
.75959 .29629 .76032 .29633 .76197 .29357 .76115 .29233 Mtetra
.719 .74 .868 r
.76115 .29233 .76197 .29357 .76377 .29274 .76295 .2914 Mtetra
.597 .671 .891 r
.76295 .2914 .76377 .29274 .7656 .29236 .76479 .2911 Mtetra
.56 .667 .91 r
.76479 .2911 .7656 .29236 .76744 .29207 .76664 .29094 Mtetra
.656 .737 .909 r
.76664 .29094 .76744 .29207 .76926 .29148 .76846 .29036 Mtetra
.662 .743 .91 r
.76846 .29036 .76926 .29148 .77108 .29086 .77028 .28976 Mtetra
.674 .751 .909 r
.77028 .28976 .77108 .29086 .77289 .2902 .7721 .2891 Mtetra
.691 .757 .902 r
.7721 .2891 .77289 .2902 .77471 .28951 .77391 .28836 Mtetra
.69 .747 .895 r
.77391 .28836 .77471 .28951 .77652 .28875 .77572 .28761 Mtetra
.705 .755 .891 r
.77572 .28761 .77652 .28875 .77831 .28776 .77753 .28679 Mtetra
.743 .804 .901 r
.77753 .28679 .77831 .28776 .78007 .28637 .77932 .2858 Mtetra
.61 .859 .991 r
.77932 .2858 .78007 .28637 .78187 .28546 .78115 .28525 Mtetra
.251 0 0 r
.78115 .28525 .78187 .28546 .78377 .28572 .78309 .28591 Mtetra
.907 .5 .186 r
.78309 .28591 .78377 .28572 .78605 .2905 .78552 .29249 Mtetra
.973 .664 .342 r
.78552 .29249 .78605 .2905 .80541 .49725 .80466 .49719 Mtetra
.823 .344 .003 r
.80466 .49719 .80541 .49725 .80781 .5019 .80698 .50085 Mtetra
.344 .614 .951 r
.80698 .50085 .80781 .5019 .80987 .50233 .80903 .50121 Mtetra
.681 .767 .916 r
.80903 .50121 .80987 .50233 .81182 .50156 .81098 .50046 Mtetra
.869 .817 .795 r
.81098 .50046 .81182 .50156 .81363 .49919 .81281 .49821 Mtetra
.982 .769 .539 r
.81281 .49821 .81363 .49919 .81485 .48999 .81412 .49006 Mtetra
.977 .675 .341 r
.81412 .49006 .81485 .48999 .79872 .28418 .798 .28373 Mtetra
.985 .851 .625 r
.798 .28373 .79872 .28418 .80025 .28001 .7995 .27927 Mtetra
.754 .863 .929 r
.7995 .27927 .80025 .28001 .80206 .27911 .8013 .27824 Mtetra
.595 .774 .966 r
.8013 .27824 .80206 .27911 .80393 .27885 .80316 .27785 Mtetra
.559 .725 .952 r
.80316 .27785 .80393 .27885 .80582 .27876 .80503 .27761 Mtetra
.739 .768 .876 r
.80503 .27761 .80582 .27876 .80764 .27788 .80684 .27658 Mtetra
.663 .711 .884 r
.80684 .27658 .80764 .27788 .80948 .27726 .80868 .27596 Mtetra
.396 .573 .909 r
.80868 .27596 .80948 .27726 .81139 .27731 .81062 .27636 Mtetra
.845 .43 0 r
.81062 .27636 .81139 .27731 .81353 .27984 .81307 .28223 Mtetra
.973 .66 .328 r
.81307 .28223 .81353 .27984 .83256 .46268 .83421 .48805 Mtetra
.591 .342 .509 r
.83421 .48805 .83256 .46268 .83701 .48848 .83663 .49206 Mtetra
.508 .178 .343 r
.83663 .49206 .83701 .48848 .83924 .49049 .83867 .49204 Mtetra
.282 0 .065 r
.83867 .49204 .83924 .49049 .84135 .49123 .84064 .49129 Mtetra
.508 .911 .828 r
.84064 .49129 .84135 .49123 .84341 .49139 .8426 .49031 Mtetra
.505 .697 .956 r
.8426 .49031 .84341 .49139 .84547 .49148 .84464 .49023 Mtetra
.632 .725 .915 r
.84464 .49023 .84547 .49148 .84746 .49091 .84664 .48972 Mtetra
.795 .794 .851 r
.84664 .48972 .84746 .49091 .84936 .48928 .84854 .48822 Mtetra
.978 .782 .571 r
.84854 .48822 .84936 .48928 .85075 .48258 .84994 .48156 Mtetra
.976 .67 .325 r
.84994 .48156 .85075 .48258 .8322 .27492 .83143 .27382 Mtetra
.968 .784 .601 r
.83143 .27382 .8322 .27492 .83358 .26953 .83281 .26839 Mtetra
.761 .781 .869 r
.83281 .26839 .83358 .26953 .83539 .26836 .83462 .26722 Mtetra
.628 .728 .919 r
.83462 .26722 .83539 .26836 .83726 .2679 .83649 .26675 Mtetra
.549 .69 .932 r
.83649 .26675 .83726 .2679 .83917 .26774 .8384 .26659 Mtetra
.748 .775 .875 r
.8384 .26659 .83917 .26774 .84099 .26666 .84022 .2655 Mtetra
.679 .749 .904 r
.84022 .2655 .84099 .26666 .84285 .26596 .84208 .2648 Mtetra
.463 .643 .935 r
.84208 .2648 .84285 .26596 .84479 .26608 .84402 .26493 Mtetra
.847 .451 0 r
.84402 .26493 .84479 .26608 .84746 .2732 .8467 .27207 Mtetra
.971 .656 .295 r
.8467 .27207 .84746 .2732 .871 .47923 .8702 .47815 Mtetra
0 0 .449 r
.8702 .47815 .871 .47923 .8734 .48234 .8726 .48125 Mtetra
.977 .788 .583 r
.8726 .48125 .8734 .48234 .87481 .47613 .87402 .47508 Mtetra
.974 .667 .312 r
.87402 .47508 .87481 .47613 .85458 .26712 .85383 .26603 Mtetra
.971 .788 .599 r
.85383 .26603 .85458 .26712 .85595 .26178 .85519 .26065 Mtetra
.905 .495 .175 r
.25093 .46225 .25194 .46315 .25317 .46603 .25213 .46544 Mtetra
.937 .682 .526 r
.25213 .46544 .25317 .46603 .23853 .66198 .23736 .66232 Mtetra
.896 .57 .423 r
.23736 .66232 .23853 .66198 .23951 .66905 .2384 .66862 Mtetra
0 .48 .791 r
.2384 .66862 .23951 .66905 .24102 .66974 .23993 .66902 Mtetra
.68 .804 .942 r
.23993 .66902 .24102 .66974 .24261 .66929 .24154 .6684 Mtetra
.805 .778 .828 r
.24154 .6684 .24261 .66929 .2443 .66776 .24322 .66692 Mtetra
.879 .764 .731 r
.24322 .66692 .2443 .66776 .2463 .66239 .24503 .66388 Mtetra
.99 .845 .602 r
.24503 .66388 .2463 .66239 .26353 .46522 .24716 .65683 Mtetra
0 0 .185 r
.24716 .65683 .26353 .46522 .26549 .45917 .26405 .46373 Mtetra
0 0 .063 r
.26405 .46373 .26549 .45917 .26707 .45786 .26586 .45954 Mtetra
0 0 0 r
.26586 .45954 .26707 .45786 .26858 .45734 .26751 .45733 Mtetra
.844 .95 .886 r
.26751 .45733 .26858 .45734 .27007 .45722 .2691 .45593 Mtetra
.671 .68 .85 r
.2691 .45593 .27007 .45722 .27158 .45683 .27062 .45535 Mtetra
.603 .626 .847 r
.27062 .45535 .27158 .45683 .27309 .45645 .27212 .45509 Mtetra
.562 .627 .875 r
.27212 .45509 .27309 .45645 .27459 .45607 .27361 .45499 Mtetra
.633 .704 .897 r
.27361 .45499 .27459 .45607 .27611 .45561 .27512 .4546 Mtetra
.653 .724 .901 r
.27512 .4546 .27611 .45561 .27763 .45512 .27664 .45413 Mtetra
.664 .732 .901 r
.27664 .45413 .27763 .45512 .27915 .45459 .27816 .45362 Mtetra
.665 .736 .903 r
.27816 .45362 .27915 .45459 .28068 .45402 .27969 .4531 Mtetra
.674 .748 .907 r
.27969 .4531 .28068 .45402 .28221 .45344 .28121 .45254 Mtetra
.685 .757 .906 r
.28121 .45254 .28221 .45344 .28374 .45285 .28274 .45194 Mtetra
.708 .759 .892 r
.28274 .45194 .28374 .45285 .28527 .45229 .28429 .45123 Mtetra
.706 .729 .868 r
.28429 .45123 .28527 .45229 .2868 .45174 .28583 .45049 Mtetra
.694 .694 .846 r
.28583 .45049 .2868 .45174 .28833 .4512 .28737 .44978 Mtetra
.709 .675 .815 r
.28737 .44978 .28833 .4512 .28989 .45026 .28892 .44892 Mtetra
.682 .677 .839 r
.28892 .44892 .28989 .45026 .29143 .44956 .29046 .44827 Mtetra
.59 .651 .878 r
.29046 .44827 .29143 .44956 .29293 .44948 .29197 .44805 Mtetra
0 .008 .568 r
.29197 .44805 .29293 .44948 .29419 .45271 .29335 .4497 Mtetra
.837 .53 0 r
.29335 .4497 .29419 .45271 .28197 .6488 .29448 .45493 Mtetra
0 0 .225 r
.29448 .45493 .28197 .6488 .2831 .65543 .28249 .64811 Mtetra
.428 .3 .603 r
.28249 .64811 .2831 .65543 .28464 .65614 .28395 .65002 Mtetra
.586 .429 .635 r
.28395 .65002 .28464 .65614 .28627 .65568 .28557 .64952 Mtetra
.63 .46 .634 r
.28557 .64952 .28627 .65568 .28793 .65476 .28726 .64817 Mtetra
.597 .431 .628 r
.28726 .64817 .28793 .65476 .28956 .65417 .2889 .64743 Mtetra
.586 .422 .626 r
.2889 .64743 .28956 .65417 .29119 .65367 .29054 .64689 Mtetra
.585 .421 .626 r
.29054 .64689 .29119 .65367 .29283 .65317 .29217 .64634 Mtetra
.61 .439 .626 r
.29217 .64634 .29283 .65317 .29446 .65264 .29384 .64528 Mtetra
.596 .424 .619 r
.29384 .64528 .29446 .65264 .2961 .65212 .29549 .64445 Mtetra
.548 .386 .614 r
.29549 .64445 .2961 .65212 .29773 .65164 .29708 .64458 Mtetra
.389 .274 .6 r
.29708 .64458 .29773 .65164 .29936 .65126 .29854 .64688 Mtetra
.317 .272 .649 r
.29854 .64688 .29936 .65126 .30099 .65093 .30002 .64876 Mtetra
.241 .355 .78 r
.30002 .64876 .30099 .65093 .30262 .65058 .30155 .64987 Mtetra
.418 .724 .988 r
.30155 .64987 .30262 .65058 .30425 .65015 .30316 .64987 Mtetra
.555 .881 .991 r
.30316 .64987 .30425 .65015 .30589 .64967 .3048 .6494 Mtetra
.625 .903 .985 r
.3048 .6494 .30589 .64967 .30753 .64917 .30645 .64878 Mtetra
.541 .853 .998 r
.30645 .64878 .30753 .64917 .30918 .64868 .30809 .64839 Mtetra
.448 .838 .983 r
.30809 .64839 .30918 .64868 .31082 .64819 .30972 .64809 Mtetra
.378 .831 .926 r
.30972 .64809 .31082 .64819 .31246 .64769 .31136 .64775 Mtetra
.227 .748 .813 r
.31136 .64775 .31246 .64769 .31409 .64756 .31299 .64746 Mtetra
.474 .878 .952 r
.31299 .64746 .31409 .64756 .31572 .6473 .31464 .64699 Mtetra
.727 .914 .958 r
.31464 .64699 .31572 .6473 .31739 .64643 .31631 .6461 Mtetra
.906 .854 .779 r
.31631 .6461 .31739 .64643 .31923 .64269 .31808 .64359 Mtetra
.986 .865 .631 r
.31808 .64359 .31923 .64269 .33234 .44749 .32002 .63818 Mtetra
0 0 .227 r
.32002 .63818 .33234 .44749 .33448 .43701 .33306 .44373 Mtetra
.154 0 .306 r
.33306 .44373 .33448 .43701 .33613 .43496 .33483 .43959 Mtetra
.489 .196 .393 r
.33483 .43959 .33613 .43496 .33769 .43438 .33638 .4392 Mtetra
.519 .226 .409 r
.33638 .4392 .33769 .43438 .33922 .43425 .33791 .43913 Mtetra
.202 0 .284 r
.33791 .43913 .33922 .43425 .34077 .43381 .3396 .43641 Mtetra
0 0 0 r
.3396 .43641 .34077 .43381 .34234 .43317 .34129 .43355 Mtetra
.904 .979 .794 r
.34129 .43355 .34234 .43317 .34391 .43254 .34294 .43148 Mtetra
.757 .745 .841 r
.34294 .43148 .34391 .43254 .34547 .43198 .34453 .4304 Mtetra
.656 .638 .82 r
.34453 .4304 .34547 .43198 .34703 .43148 .34609 .42985 Mtetra
.62 .617 .825 r
.34609 .42985 .34703 .43148 .34859 .43098 .34765 .42949 Mtetra
.62 .634 .843 r
.34765 .42949 .34859 .43098 .35015 .43046 .3492 .42914 Mtetra
.627 .664 .866 r
.3492 .42914 .35015 .43046 .35172 .42992 .35076 .42877 Mtetra
.636 .696 .889 r
.35076 .42877 .35172 .42992 .35328 .42938 .35232 .42836 Mtetra
.677 .735 .894 r
.35232 .42836 .35328 .42938 .35485 .42883 .35389 .42777 Mtetra
.7 .733 .876 r
.35389 .42777 .35485 .42883 .35642 .42829 .35546 .42706 Mtetra
.695 .702 .852 r
.35546 .42706 .35642 .42829 .35799 .42776 .35704 .42634 Mtetra
.704 .678 .822 r
.35704 .42634 .35799 .42776 .35957 .42691 .35863 .4255 Mtetra
.691 .674 .829 r
.35863 .4255 .35957 .42691 .36116 .4261 .36021 .42476 Mtetra
.625 .66 .864 r
.36021 .42476 .36116 .4261 .36271 .42581 .36177 .42439 Mtetra
.162 .404 .848 r
.36177 .42439 .36271 .42581 .36417 .42772 .36327 .42525 Mtetra
0 0 .39 r
.36327 .42525 .36417 .42772 .35645 .61687 .36466 .42844 Mtetra
0 0 .257 r
.36466 .42844 .35645 .61687 .35735 .63217 .35679 .62145 Mtetra
.071 .013 .478 r
.35679 .62145 .35735 .63217 .35891 .63394 .35806 .6292 Mtetra
.33 .273 .642 r
.35806 .6292 .35891 .63394 .36057 .63378 .35962 .63121 Mtetra
.387 .41 .763 r
.35962 .63121 .36057 .63378 .36225 .63309 .36123 .63206 Mtetra
.459 .668 .953 r
.36123 .63206 .36225 .63309 .36394 .63245 .36288 .63213 Mtetra
.535 .868 .993 r
.36288 .63213 .36394 .63245 .36561 .63198 .36455 .6317 Mtetra
.624 .906 .984 r
.36455 .6317 .36561 .63198 .36729 .63146 .36624 .63106 Mtetra
.535 .853 .998 r
.36624 .63106 .36729 .63146 .36896 .6312 .36791 .63067 Mtetra
.51 .813 1 r
.36791 .63067 .36896 .6312 .37063 .63096 .36958 .6304 Mtetra
.671 .853 .969 r
.36958 .6304 .37063 .63096 .37232 .63018 .37127 .62975 Mtetra
.871 .87 .833 r
.37127 .62975 .37232 .63018 .37411 .62725 .37302 .62787 Mtetra
.98 .894 .664 r
.37302 .62787 .37411 .62725 .37642 .61226 .37487 .62359 Mtetra
.966 .707 .49 r
.37487 .62359 .37642 .61226 .38627 .42045 .38478 .43184 Mtetra
0 0 .197 r
.38478 .43184 .38627 .42045 .38796 .41759 .38684 .4203 Mtetra
0 0 0 r
.38684 .4203 .38796 .41759 .38956 .41673 .38854 .41733 Mtetra
.803 .992 .749 r
.38854 .41733 .38956 .41673 .39114 .41638 .39018 .41552 Mtetra
.768 .788 .87 r
.39018 .41552 .39114 .41638 .39272 .41605 .39179 .41445 Mtetra
.659 .64 .819 r
.39179 .41445 .39272 .41605 .39431 .41556 .39338 .41387 Mtetra
.623 .612 .819 r
.39338 .41387 .39431 .41556 .39589 .4151 .39496 .41348 Mtetra
.629 .624 .827 r
.39496 .41348 .39589 .4151 .39748 .41462 .39655 .41307 Mtetra
.649 .642 .829 r
.39655 .41307 .39748 .41462 .39907 .41411 .39814 .41256 Mtetra
.65 .642 .829 r
.39814 .41256 .39907 .41411 .40067 .41359 .39974 .41204 Mtetra
.652 .643 .828 r
.39974 .41204 .40067 .41359 .40226 .41306 .40133 .4115 Mtetra
.654 .644 .828 r
.40133 .4115 .40226 .41306 .40386 .41251 .40293 .41096 Mtetra
.655 .644 .827 r
.40293 .41096 .40386 .41251 .40545 .41196 .40452 .41041 Mtetra
.669 .65 .822 r
.40452 .41041 .40545 .41196 .40705 .41138 .40612 .40977 Mtetra
.673 .644 .813 r
.40612 .40977 .40705 .41138 .40865 .41079 .40773 .40908 Mtetra
.642 .619 .812 r
.40773 .40908 .40865 .41079 .41025 .41022 .40932 .40859 Mtetra
.515 .568 .847 r
.40932 .40859 .41025 .41022 .41185 .40971 .4109 .40869 Mtetra
0 .277 .766 r
.4109 .40869 .41185 .40971 .41345 .40928 .41245 .40974 Mtetra
.764 .316 .185 r
.41245 .40974 .41345 .40928 .41504 .40886 .41397 .41158 Mtetra
.64 .298 .376 r
.41397 .41158 .41504 .40886 .41665 .40817 .41551 .4129 Mtetra
.433 .146 .376 r
.41551 .4129 .41665 .40817 .41827 .40727 .41713 .4119 Mtetra
.472 .18 .387 r
.41713 .4119 .41827 .40727 .41987 .40685 .41874 .41132 Mtetra
.734 .428 .462 r
.41874 .41132 .41987 .40685 .42141 .40817 .4202 .41555 Mtetra
.944 .673 .493 r
.4202 .41555 .42141 .40817 .42256 .42232 .41559 .61022 Mtetra
.554 .331 .532 r
.41559 .61022 .42256 .42232 .41821 .61373 .41716 .61437 Mtetra
.688 .22 .135 r
.41716 .61437 .41821 .61373 .41984 .61607 .41881 .61571 Mtetra
.355 .781 .973 r
.41881 .61571 .41984 .61607 .42154 .61589 .42051 .61557 Mtetra
.582 .89 .99 r
.42051 .61557 .42154 .61589 .42326 .61513 .42223 .61503 Mtetra
.545 .912 .954 r
.42223 .61503 .42326 .61513 .42498 .61432 .42395 .6144 Mtetra
.369 .838 .854 r
.42395 .6144 .42498 .61432 .4267 .61385 .42567 .61388 Mtetra
.544 .925 .916 r
.42567 .61388 .4267 .61385 .42842 .61335 .42739 .61315 Mtetra
.799 .947 .919 r
.42739 .61315 .42842 .61335 .43014 .61278 .42913 .61188 Mtetra
.86 .792 .783 r
.42913 .61188 .43014 .61278 .43186 .61212 .4309 .60966 Mtetra
.798 .644 .692 r
.4309 .60966 .43186 .61212 .43358 .61145 .43268 .60669 Mtetra
.708 .533 .649 r
.43268 .60669 .43358 .61145 .4353 .61101 .43446 .60404 Mtetra
.56 .403 .625 r
.43446 .60404 .4353 .61101 .43701 .61089 .43617 .60395 Mtetra
.576 .414 .625 r
.43617 .60395 .43701 .61089 .43874 .6103 .43789 .60357 Mtetra
.708 .511 .62 r
.43789 .60357 .43874 .6103 .44051 .60811 .43969 .59971 Mtetra
.948 .68 .495 r
.43969 .59971 .44051 .60811 .44246 .59813 .4462 .40279 Mtetra
.558 .339 .539 r
.4462 .40279 .44246 .59813 .44884 .40007 .44795 .39738 Mtetra
.761 .611 .691 r
.44795 .39738 .44884 .40007 .45054 .39648 .44961 .39502 Mtetra
.692 .673 .827 r
.44961 .39502 .45054 .39648 .45217 .3956 .45124 .39424 Mtetra
.622 .661 .867 r
.45124 .39424 .45217 .3956 .45379 .3953 .45286 .39387 Mtetra
.591 .638 .866 r
.45286 .39387 .45379 .3953 .4554 .39511 .45448 .39365 Mtetra
.621 .645 .853 r
.45448 .39365 .4554 .39511 .45703 .39456 .45611 .39328 Mtetra
.618 .673 .88 r
.45611 .39328 .45703 .39456 .45866 .39402 .45773 .39293 Mtetra
.627 .713 .908 r
.45773 .39293 .45866 .39402 .46029 .39348 .45936 .39253 Mtetra
.651 .751 .923 r
.45936 .39253 .46029 .39348 .46192 .39296 .46099 .39203 Mtetra
.667 .761 .92 r
.46099 .39203 .46192 .39296 .46355 .39243 .46262 .39147 Mtetra
.684 .757 .907 r
.46262 .39147 .46355 .39243 .46518 .39189 .46425 .39083 Mtetra
.699 .742 .884 r
.46425 .39083 .46518 .39189 .46681 .39133 .46589 .39011 Mtetra
.695 .712 .862 r
.46589 .39011 .46681 .39133 .46844 .39075 .46752 .38938 Mtetra
.689 .686 .842 r
.46752 .38938 .46844 .39075 .47008 .39016 .46916 .38865 Mtetra
.685 .665 .824 r
.46916 .38865 .47008 .39016 .47172 .38957 .4708 .3879 Mtetra
.651 .632 .818 r
.4708 .3879 .47172 .38957 .47335 .38899 .47244 .38735 Mtetra
.567 .596 .842 r
.47244 .38735 .47335 .38899 .47499 .38847 .47407 .38724 Mtetra
.079 .391 .85 r
.47407 .38724 .47499 .38847 .47663 .38804 .47569 .38816 Mtetra
.748 .251 .046 r
.47569 .38816 .47663 .38804 .47826 .38763 .47729 .38986 Mtetra
.718 .361 .371 r
.47729 .38986 .47826 .38763 .4799 .38718 .4789 .39215 Mtetra
.532 .239 .414 r
.4789 .39215 .4799 .38718 .48154 .38662 .48053 .39225 Mtetra
.462 .186 .407 r
.48053 .39225 .48154 .38662 .48319 .38602 .48218 .39134 Mtetra
.435 .158 .392 r
.48218 .39134 .48319 .38602 .48483 .38543 .48384 .39017 Mtetra
.477 .185 .391 r
.48384 .39017 .48483 .38543 .48648 .38486 .48549 .3896 Mtetra
.477 .186 .391 r
.48549 .3896 .48648 .38486 .48812 .3843 .48714 .38903 Mtetra
.48714 .38903 .48812 .3843 .48977 .38375 .48879 .38848 Mtetra
.478 .187 .392 r
.48879 .38848 .48977 .38375 .49142 .38319 .49044 .38793 Mtetra
.479 .187 .392 r
.49044 .38793 .49142 .38319 .49306 .38264 .49209 .38738 Mtetra
.479 .188 .392 r
.49209 .38738 .49306 .38264 .49471 .38209 .49374 .38684 Mtetra
.49374 .38684 .49471 .38209 .49636 .38153 .4954 .38629 Mtetra
.479 .188 .393 r
.4954 .38629 .49636 .38153 .49802 .38098 .49705 .38575 Mtetra
.49705 .38575 .49802 .38098 .49967 .38043 .49871 .3852 Mtetra
.49871 .3852 .49967 .38043 .50132 .37987 .50036 .38465 Mtetra
.50036 .38465 .50132 .37987 .50298 .37932 .50202 .3841 Mtetra
.50202 .3841 .50298 .37932 .50463 .37877 .50368 .38355 Mtetra
.50368 .38355 .50463 .37877 .50629 .37821 .50534 .383 Mtetra
.50534 .383 .50629 .37821 .50794 .37765 .507 .38244 Mtetra
.507 .38244 .50794 .37765 .5096 .3771 .50866 .38189 Mtetra
.50866 .38189 .5096 .3771 .51126 .37654 .51033 .38133 Mtetra
.51033 .38133 .51126 .37654 .51292 .37598 .51199 .38077 Mtetra
.51199 .38077 .51292 .37598 .51458 .37543 .51366 .38021 Mtetra
.51366 .38021 .51458 .37543 .51625 .37487 .51532 .37965 Mtetra
.478 .188 .393 r
.51532 .37965 .51625 .37487 .51791 .37431 .51699 .37909 Mtetra
.478 .187 .393 r
.51699 .37909 .51791 .37431 .51957 .37375 .51866 .37852 Mtetra
.51866 .37852 .51957 .37375 .52124 .37319 .52033 .37796 Mtetra
.478 .187 .392 r
.52033 .37796 .52124 .37319 .52291 .37263 .522 .37739 Mtetra
.522 .37739 .52291 .37263 .52457 .37207 .52367 .37682 Mtetra
.477 .186 .392 r
.52367 .37682 .52457 .37207 .52624 .37151 .52534 .37625 Mtetra
.52534 .37625 .52624 .37151 .52791 .37095 .52701 .37568 Mtetra
.478 .186 .391 r
.52701 .37568 .52791 .37095 .52958 .37039 .52869 .37511 Mtetra
.478 .187 .391 r
.52869 .37511 .52958 .37039 .53125 .36983 .53036 .37456 Mtetra
.479 .187 .392 r
.53036 .37456 .53125 .36983 .53293 .36928 .53204 .37401 Mtetra
.48 .188 .392 r
.53204 .37401 .53293 .36928 .5346 .36873 .53372 .37347 Mtetra
.535 .236 .408 r
.53372 .37347 .5346 .36873 .53628 .36821 .5354 .37362 Mtetra
.502 .217 .414 r
.5354 .37362 .53628 .36821 .53795 .36768 .53708 .37326 Mtetra
.42 .149 .395 r
.53708 .37326 .53795 .36768 .53963 .36712 .53875 .37182 Mtetra
.098 0 .26 r
.53875 .37182 .53963 .36712 .5413 .36643 .54042 .36817 Mtetra
0 0 0 r
.54042 .36817 .5413 .36643 .54298 .36572 .54209 .36551 Mtetra
.897 .934 .831 r
.54209 .36551 .54298 .36572 .54466 .36503 .54376 .36359 Mtetra
.7 .686 .833 r
.54376 .36359 .54466 .36503 .54634 .36445 .54544 .36276 Mtetra
.645 .631 .821 r
.54544 .36276 .54634 .36445 .54802 .3639 .54712 .36223 Mtetra
.617 .62 .831 r
.54712 .36223 .54802 .3639 .54971 .36336 .54881 .36186 Mtetra
.627 .648 .851 r
.54881 .36186 .54971 .36336 .55139 .36279 .55049 .36145 Mtetra
.628 .673 .874 r
.55049 .36145 .55139 .36279 .55307 .36221 .55218 .36104 Mtetra
.639 .707 .896 r
.55218 .36104 .55307 .36221 .55476 .36164 .55387 .36058 Mtetra
.692 .748 .894 r
.55387 .36058 .55476 .36164 .55645 .36107 .55555 .35988 Mtetra
.699 .726 .871 r
.55555 .35988 .55645 .36107 .55813 .3605 .55724 .35912 Mtetra
.69 .692 .847 r
.55724 .35912 .55813 .3605 .55982 .35993 .55893 .35837 Mtetra
.704 .672 .816 r
.55893 .35837 .55982 .35993 .56151 .35893 .56061 .35747 Mtetra
.674 .673 .841 r
.56061 .35747 .56151 .35893 .5632 .35822 .5623 .3568 Mtetra
.587 .642 .873 r
.5623 .3568 .5632 .35822 .56489 .35814 .564 .35657 Mtetra
0 .167 .706 r
.564 .35657 .56489 .35814 .56664 .36167 .56572 .35832 Mtetra
0 0 .331 r
.56572 .35832 .56664 .36167 .57109 .56298 .5675 .36368 Mtetra
0 0 .376 r
.5675 .36368 .57109 .56298 .573 .56938 .57196 .56164 Mtetra
.498 .353 .615 r
.57196 .56164 .573 .56938 .57482 .56986 .57379 .56276 Mtetra
.596 .428 .625 r
.57379 .56276 .57482 .56986 .57663 .56929 .5756 .56192 Mtetra
.597 .427 .622 r
.5756 .56192 .57663 .56929 .57844 .56828 .5774 .56101 Mtetra
.411 .297 .612 r
.5774 .56101 .57844 .56828 .58026 .56782 .57926 .56341 Mtetra
.361 .312 .667 r
.57926 .56341 .58026 .56782 .58207 .56745 .58111 .56526 Mtetra
.314 .405 .796 r
.58111 .56526 .58207 .56745 .58389 .56706 .58296 .56632 Mtetra
.462 .749 .991 r
.58296 .56632 .58389 .56706 .58571 .56654 .58479 .56622 Mtetra
.533 .881 .986 r
.58479 .56622 .58571 .56654 .58753 .56596 .58661 .56571 Mtetra
.592 .916 .975 r
.58661 .56571 .58753 .56596 .58935 .56537 .58843 .56503 Mtetra
.407 .817 .977 r
.58843 .56503 .58935 .56537 .59118 .56526 .59025 .56476 Mtetra
.537 .844 .999 r
.59025 .56476 .59118 .56526 .59301 .56492 .59208 .56436 Mtetra
.709 .882 .961 r
.59208 .56436 .59301 .56492 .59482 .56392 .5939 .5635 Mtetra
.924 .886 .776 r
.5939 .5635 .59482 .56392 .59657 .5595 .59568 .56088 Mtetra
.955 .885 .49 r
.59568 .56088 .59657 .5595 .59401 .35764 .5974 .55533 Mtetra
0 0 .372 r
.5974 .55533 .59401 .35764 .59555 .34911 .59483 .35522 Mtetra
0 0 .256 r
.59483 .35522 .59555 .34911 .59723 .34722 .59643 .34921 Mtetra
0 0 0 r
.59643 .34921 .59723 .34722 .59894 .34649 .5981 .3466 Mtetra
.827 .998 .836 r
.5981 .3466 .59894 .34649 .60066 .3462 .59979 .34497 Mtetra
.703 .723 .865 r
.59979 .34497 .60066 .3462 .60238 .34573 .6015 .34417 Mtetra
.623 .638 .845 r
.6015 .34417 .60238 .34573 .6041 .34522 .60322 .34377 Mtetra
.587 .639 .869 r
.60322 .34377 .6041 .34522 .60582 .34472 .60494 .34354 Mtetra
.634 .708 .9 r
.60494 .34354 .60582 .34472 .60754 .34413 .60667 .34309 Mtetra
.664 .747 .912 r
.60667 .34309 .60754 .34413 .60925 .34351 .60839 .34251 Mtetra
.678 .762 .914 r
.60839 .34251 .60925 .34351 .61097 .34288 .61011 .34187 Mtetra
.747 .777 .878 r
.61011 .34187 .61097 .34288 .61268 .34193 .61182 .34086 Mtetra
.73 .761 .877 r
.61182 .34086 .61268 .34193 .6144 .34115 .61353 .33993 Mtetra
.646 .704 .889 r
.61353 .33993 .6144 .34115 .61613 .34096 .61525 .33943 Mtetra
.175 .392 .835 r
.61525 .33943 .61613 .34096 .61795 .34361 .61703 .34049 Mtetra
0 0 .544 r
.61703 .34049 .61795 .34361 .62569 .54386 .61888 .34427 Mtetra
0 0 .395 r
.61888 .34427 .62569 .54386 .62781 .55246 .62665 .54335 Mtetra
.241 .163 .563 r
.62665 .54335 .62781 .55246 .62971 .55363 .62868 .54906 Mtetra
.386 .326 .667 r
.62868 .54906 .62971 .55363 .63157 .55329 .6306 .55082 Mtetra
.436 .456 .782 r
.6306 .55082 .63157 .55329 .63341 .55247 .63249 .5515 Mtetra
.549 .735 .962 r
.63249 .5515 .63341 .55247 .63526 .55181 .63436 .55128 Mtetra
.654 .882 .982 r
.63436 .55128 .63526 .55181 .63711 .55124 .6362 .55058 Mtetra
.715 .866 .953 r
.6362 .55058 .63711 .55124 .63896 .55063 .63805 .5497 Mtetra
.572 .754 .964 r
.63805 .5497 .63896 .55063 .64082 .5504 .63991 .5494 Mtetra
.543 .724 .958 r
.63991 .5494 .64082 .5504 .64269 .55007 .64178 .5492 Mtetra
.659 .8 .95 r
.64178 .5492 .64269 .55007 .64453 .54913 .64364 .54858 Mtetra
.899 .886 .81 r
.64364 .54858 .64453 .54913 .64627 .54537 .64543 .54635 Mtetra
.964 .898 .526 r
.64543 .54635 .64627 .54537 .64083 .34523 .64713 .54132 Mtetra
0 0 .388 r
.64713 .54132 .64083 .34523 .64217 .33391 .64163 .34123 Mtetra
0 0 .289 r
.64163 .34123 .64217 .33391 .64385 .33156 .64312 .33384 Mtetra
0 0 .012 r
.64312 .33384 .64385 .33156 .64558 .33076 .64478 .33107 Mtetra
.773 .99 .761 r
.64478 .33107 .64558 .33076 .64733 .33042 .64648 .32934 Mtetra
.729 .764 .88 r
.64648 .32934 .64733 .33042 .64908 .32999 .64821 .32842 Mtetra
.631 .644 .845 r
.64821 .32842 .64908 .32999 .65083 .32945 .64996 .32797 Mtetra
.593 .639 .866 r
.64996 .32797 .65083 .32945 .65258 .32893 .65172 .32771 Mtetra
.672 .718 .884 r
.65172 .32771 .65258 .32893 .65431 .32806 .65347 .32708 Mtetra
.705 .778 .908 r
.65347 .32708 .65431 .32806 .65605 .32719 .65521 .3263 Mtetra
.616 .768 .952 r
.65521 .3263 .65605 .32719 .65781 .32686 .65696 .32587 Mtetra
.042 .418 .864 r
.65696 .32587 .65781 .32686 .65967 .32889 .65878 .32677 Mtetra
0 0 .461 r
.65878 .32677 .65967 .32889 .67001 .5264 .66071 .33036 Mtetra
0 0 .406 r
.66071 .33036 .67001 .5264 .67244 .53874 .67117 .52917 Mtetra
.229 .153 .559 r
.67117 .52917 .67244 .53874 .67442 .54042 .67335 .53551 Mtetra
.39 .322 .66 r
.67335 .53551 .67442 .54042 .67631 .54017 .67533 .5374 Mtetra
.435 .435 .76 r
.67533 .5374 .67631 .54017 .67818 .53938 .67727 .5382 Mtetra
.43 .63 .938 r
.67727 .5382 .67818 .53938 .68006 .5389 .67919 .5384 Mtetra
.476 .821 .998 r
.67919 .5384 .68006 .5389 .68195 .53855 .68108 .5381 Mtetra
.694 .915 .97 r
.68108 .5381 .68195 .53855 .68382 .5376 .68295 .53722 Mtetra
.905 .925 .82 r
.68295 .53722 .68382 .5376 .68557 .53426 .68476 .53503 Mtetra
.966 .905 .544 r
.68476 .53503 .68557 .53426 .67804 .33932 .68645 .53028 Mtetra
0 0 .394 r
.68645 .53028 .67804 .33932 .67898 .32181 .67862 .33048 Mtetra
0 0 .314 r
.67862 .33048 .67898 .32181 .68064 .31903 .67997 .32153 Mtetra
0 0 .07 r
.67997 .32153 .68064 .31903 .68238 .31809 .68162 .31859 Mtetra
.7 .945 .656 r
.68162 .31859 .68238 .31809 .68416 .31764 .68333 .31675 Mtetra
.795 .82 .872 r
.68333 .31675 .68416 .31764 .68592 .31699 .68506 .31546 Mtetra
.697 .681 .831 r
.68506 .31546 .68592 .31699 .68768 .31618 .68681 .3146 Mtetra
.61 .637 .852 r
.68681 .3146 .68768 .31618 .68946 .31587 .6886 .31426 Mtetra
.339 .482 .856 r
.6886 .31426 .68946 .31587 .69134 .31745 .69044 .31497 Mtetra
0 .103 .643 r
.69044 .31497 .69134 .31745 .6938 .32966 .69239 .31778 Mtetra
.98 .685 .344 r
.69239 .31778 .6938 .32966 .70635 .52783 .70468 .51229 Mtetra
.15 .076 .511 r
.70468 .51229 .70635 .52783 .7084 .5301 .70728 .52469 Mtetra
.372 .3 .646 r
.70728 .52469 .7084 .5301 .71033 .52999 .70934 .527 Mtetra
.424 .415 .745 r
.70934 .527 .71033 .52999 .71222 .5293 .71132 .52795 Mtetra
.43 .597 .914 r
.71132 .52795 .71222 .5293 .71413 .52878 .71327 .52823 Mtetra
.453 .799 .998 r
.71327 .52823 .71413 .52878 .71605 .52851 .7152 .52801 Mtetra
.671 .901 .978 r
.7152 .52801 .71605 .52851 .71794 .52767 .71709 .52721 Mtetra
.882 .925 .846 r
.71709 .52721 .71794 .52767 .71971 .52485 .71892 .52526 Mtetra
.975 .917 .598 r
.71892 .52526 .71971 .52485 .72094 .51276 .72062 .52102 Mtetra
.982 .692 .362 r
.72062 .52102 .72094 .51276 .71096 .31192 .71142 .33262 Mtetra
.01 0 .381 r
.71142 .33262 .71096 .31192 .71258 .30862 .71199 .31154 Mtetra
0 0 .141 r
.71199 .31154 .71258 .30862 .71434 .30762 .71362 .3083 Mtetra
.615 .879 .547 r
.71362 .3083 .71434 .30762 .71613 .30716 .71533 .30635 Mtetra
.774 .84 .902 r
.71533 .30635 .71613 .30716 .71793 .30676 .71708 .30522 Mtetra
.646 .659 .848 r
.71708 .30522 .71793 .30676 .71972 .30617 .71887 .30468 Mtetra
.607 .648 .864 r
.71887 .30468 .71972 .30617 .72151 .30562 .72068 .30434 Mtetra
.632 .696 .891 r
.72068 .30434 .72151 .30562 .72331 .30506 .72248 .30388 Mtetra
.692 .74 .888 r
.72248 .30388 .72331 .30506 .7251 .30447 .72426 .30313 Mtetra
.692 .711 .863 r
.72426 .30313 .7251 .30447 .72689 .30388 .72604 .30236 Mtetra
.697 .686 .835 r
.72604 .30236 .72689 .30388 .72867 .30308 .72782 .3015 Mtetra
.697 .678 .828 r
.72782 .3015 .72867 .30308 .73044 .30211 .7296 .30062 Mtetra
.646 .668 .857 r
.7296 .30062 .73044 .30211 .73224 .30161 .7314 .30009 Mtetra
.429 .55 .876 r
.7314 .30009 .73224 .30161 .73415 .30266 .73326 .30048 Mtetra
0 .144 .677 r
.73326 .30048 .73415 .30266 .73654 .31075 .73527 .30299 Mtetra
0 0 .211 r
.73527 .30299 .73654 .31075 .75219 .51342 .73822 .31927 Mtetra
.046 0 .437 r
.73822 .31927 .75219 .51342 .75436 .51632 .75317 .51052 Mtetra
.374 .296 .639 r
.75317 .51052 .75436 .51632 .75633 .51629 .75531 .51303 Mtetra
.428 .405 .731 r
.75531 .51303 .75633 .51629 .75825 .51561 .75736 .51406 Mtetra
.478 .589 .887 r
.75736 .51406 .75825 .51561 .76017 .51479 .75935 .51426 Mtetra
.526 .842 .999 r
.75935 .51426 .76017 .51479 .7621 .51419 .7613 .51385 Mtetra
.574 .904 .98 r
.7613 .51385 .7621 .51419 .76404 .51356 .76323 .51319 Mtetra
.515 .874 .985 r
.76323 .51319 .76404 .51356 .76598 .51313 .76517 .51268 Mtetra
.363 .776 .98 r
.76517 .51268 .76598 .51313 .76796 .51301 .76715 .51254 Mtetra
.603 .89 .99 r
.76715 .51254 .76796 .51301 .76989 .51239 .76908 .5119 Mtetra
.906 .92 .817 r
.76908 .5119 .76989 .51239 .77172 .5102 .7709 .50967 Mtetra
.991 .775 .515 r
.7709 .50967 .77172 .5102 .77303 .50125 .77221 .5005 Mtetra
.978 .679 .364 r
.77221 .5005 .77303 .50125 .75959 .29629 .75875 .29464 Mtetra
.898 .735 .671 r
.75875 .29464 .75959 .29629 .76115 .29233 .76031 .29074 Mtetra
.686 .674 .832 r
.76031 .29074 .76115 .29233 .76295 .2914 .76212 .28993 Mtetra
.567 .634 .877 r
.76212 .28993 .76295 .2914 .76479 .2911 .76397 .28978 Mtetra
.524 .639 .905 r
.76397 .28978 .76479 .2911 .76664 .29094 .76583 .28976 Mtetra
.649 .725 .905 r
.76583 .28976 .76664 .29094 .76846 .29036 .76766 .28922 Mtetra
.66 .737 .907 r
.76766 .28922 .76846 .29036 .77028 .28976 .76948 .28862 Mtetra
.682 .747 .901 r
.76948 .28862 .77028 .28976 .7721 .2891 .77129 .28792 Mtetra
.71 .75 .883 r
.77129 .28792 .7721 .2891 .77391 .28836 .7731 .28707 Mtetra
.679 .717 .878 r
.7731 .28707 .77391 .28836 .77572 .28761 .77491 .28636 Mtetra
.606 .692 .904 r
.77491 .28636 .77572 .28761 .77753 .28679 .77676 .28601 Mtetra
.278 .626 .961 r
.77676 .28601 .77753 .28679 .77932 .2858 .77866 .28634 Mtetra
.619 .09 0 r
.77866 .28634 .77932 .2858 .78115 .28525 .78064 .28751 Mtetra
.784 .401 .33 r
.78064 .28751 .78115 .28525 .78309 .28591 .78284 .29141 Mtetra
.972 .661 .354 r
.78284 .29141 .78309 .28591 .78552 .29249 .80154 .49288 Mtetra
.554 .331 .531 r
.80154 .49288 .78552 .29249 .80466 .49719 .80398 .49802 Mtetra
.692 .203 .082 r
.80398 .49802 .80466 .49719 .80698 .50085 .80614 .49978 Mtetra
.405 .646 .956 r
.80614 .49978 .80698 .50085 .80903 .50121 .80818 .49999 Mtetra
.67 .745 .906 r
.80818 .49999 .80903 .50121 .81098 .50046 .81014 .4993 Mtetra
.855 .806 .801 r
.81014 .4993 .81098 .50046 .81281 .49821 .81198 .49718 Mtetra
.981 .767 .543 r
.81198 .49718 .81281 .49821 .81412 .49006 .8133 .48911 Mtetra
.977 .675 .344 r
.8133 .48911 .81412 .49006 .798 .28373 .79721 .28264 Mtetra
.953 .79 .643 r
.79721 .28264 .798 .28373 .7995 .27927 .79871 .27815 Mtetra
.743 .774 .879 r
.79871 .27815 .7995 .27927 .8013 .27824 .80051 .27711 Mtetra
.612 .722 .924 r
.80051 .27711 .8013 .27824 .80316 .27785 .80237 .27671 Mtetra
.572 .702 .93 r
.80237 .27671 .80316 .27785 .80503 .27761 .80425 .27646 Mtetra
.745 .771 .875 r
.80425 .27646 .80503 .27761 .80684 .27658 .80605 .2754 Mtetra
.666 .735 .901 r
.80605 .2754 .80684 .27658 .80868 .27596 .8079 .27477 Mtetra
.355 .572 .921 r
.8079 .27477 .80868 .27596 .81062 .27636 .80984 .27522 Mtetra
.858 .461 0 r
.80984 .27522 .81062 .27636 .81307 .28223 .81238 .28209 Mtetra
.973 .662 .319 r
.81238 .28209 .81307 .28223 .83421 .48805 .83348 .48794 Mtetra
.81 .325 0 r
.83348 .48794 .83421 .48805 .83663 .49206 .83586 .49157 Mtetra
.422 .803 .991 r
.83586 .49157 .83663 .49206 .83867 .49204 .83788 .49133 Mtetra
.718 .877 .955 r
.83788 .49133 .83867 .49204 .84064 .49129 .83984 .49038 Mtetra
.758 .84 .913 r
.83984 .49038 .84064 .49129 .8426 .49031 .84178 .48923 Mtetra
.462 .677 .958 r
.84178 .48923 .8426 .49031 .84464 .49023 .84383 .48929 Mtetra
.575 .764 .968 r
.84383 .48929 .84464 .49023 .84664 .48972 .84585 .48893 Mtetra
.791 .875 .909 r
.84585 .48893 .84664 .48972 .84854 .48822 .84777 .4876 Mtetra
.991 .815 .568 r
.84777 .4876 .84854 .48822 .84994 .48156 .84922 .48142 Mtetra
.976 .67 .322 r
.84922 .48142 .84994 .48156 .83143 .27382 .8307 .27314 Mtetra
.989 .807 .569 r
.8307 .27314 .83143 .27382 .83281 .26839 .83204 .26727 Mtetra
.767 .786 .869 r
.83204 .26727 .83281 .26839 .83462 .26722 .83385 .26607 Mtetra
.629 .727 .918 r
.83385 .26607 .83462 .26722 .83649 .26675 .83572 .2656 Mtetra
.547 .687 .931 r
.83572 .2656 .83649 .26675 .8384 .26659 .83764 .26544 Mtetra
.75 .775 .874 r
.83764 .26544 .8384 .26659 .84022 .2655 .83945 .26434 Mtetra
.68 .748 .902 r
.83945 .26434 .84022 .2655 .84208 .2648 .84131 .26364 Mtetra
.466 .642 .933 r
.84131 .26364 .84208 .2648 .84402 .26493 .84325 .26375 Mtetra
.845 .449 0 r
.84325 .26375 .84402 .26493 .8467 .27207 .84593 .27087 Mtetra
.971 .656 .295 r
.84593 .27087 .8467 .27207 .8702 .47815 .86939 .47704 Mtetra
0 0 .452 r
.86939 .47704 .8702 .47815 .8726 .48125 .87179 .48016 Mtetra
.977 .788 .583 r
.87179 .48016 .8726 .48125 .87402 .47508 .87322 .47398 Mtetra
.974 .667 .312 r
.87322 .47398 .87402 .47508 .85383 .26603 .85306 .26488 Mtetra
.968 .784 .602 r
.85306 .26488 .85383 .26603 .85519 .26065 .85444 .25952 Mtetra
.907 .498 .178 r
.24992 .46135 .25093 .46225 .25213 .46544 .25112 .46456 Mtetra
.937 .682 .526 r
.25112 .46456 .25213 .46544 .23736 .66232 .23627 .66153 Mtetra
.935 .599 .371 r
.23627 .66153 .23736 .66232 .2384 .66862 .23732 .66777 Mtetra
.305 .632 .963 r
.23732 .66777 .2384 .66862 .23993 .66902 .23886 .66802 Mtetra
.688 .747 .896 r
.23886 .66802 .23993 .66902 .24154 .6684 .24048 .66736 Mtetra
.776 .752 .831 r
.24048 .66736 .24154 .6684 .24322 .66692 .24215 .66608 Mtetra
.786 .787 .854 r
.24215 .66608 .24322 .66692 .24503 .66388 .24381 .66483 Mtetra
.742 .966 .69 r
.24381 .66483 .24503 .66388 .24716 .65683 .24553 .66294 Mtetra
.194 0 .296 r
.24553 .66294 .24716 .65683 .26405 .46373 .24736 .65962 Mtetra
0 0 .203 r
.24736 .65962 .26405 .46373 .26586 .45954 .26419 .46698 Mtetra
0 0 0 r
.26419 .46698 .26586 .45954 .26751 .45733 .26637 .45813 Mtetra
.959 .942 .707 r
.26637 .45813 .26751 .45733 .2691 .45593 .2681 .45503 Mtetra
.735 .762 .875 r
.2681 .45503 .2691 .45593 .27062 .45535 .26964 .45416 Mtetra
.603 .673 .89 r
.26964 .45416 .27062 .45535 .27212 .45509 .27114 .45389 Mtetra
.511 .634 .907 r
.27114 .45389 .27212 .45509 .27361 .45499 .27262 .45391 Mtetra
.628 .703 .9 r
.27262 .45391 .27361 .45499 .27512 .4546 .27413 .45354 Mtetra
.648 .714 .896 r
.27413 .45354 .27512 .4546 .27664 .45413 .27565 .45309 Mtetra
.656 .72 .896 r
.27565 .45309 .27664 .45413 .27816 .45362 .27717 .45261 Mtetra
.658 .727 .9 r
.27717 .45261 .27816 .45362 .27969 .4531 .27869 .45212 Mtetra
.666 .735 .901 r
.27869 .45212 .27969 .4531 .28121 .45254 .28022 .45159 Mtetra
.676 .744 .902 r
.28022 .45159 .28121 .45254 .28274 .45194 .28175 .45103 Mtetra
.698 .756 .897 r
.28175 .45103 .28274 .45194 .28429 .45123 .28329 .45036 Mtetra
.704 .768 .902 r
.28329 .45036 .28429 .45123 .28583 .45049 .28483 .44967 Mtetra
.702 .778 .91 r
.28483 .44967 .28583 .45049 .28737 .44978 .28637 .449 Mtetra
.715 .787 .909 r
.28637 .449 .28737 .44978 .28892 .44892 .28791 .44827 Mtetra
.686 .815 .944 r
.28791 .44827 .28892 .44892 .29046 .44827 .28945 .44766 Mtetra
.603 .808 .979 r
.28945 .44766 .29046 .44827 .29197 .44805 .29097 .44728 Mtetra
.104 .524 .91 r
.29097 .44728 .29197 .44805 .29335 .4497 .29243 .44774 Mtetra
.2 .339 .781 r
.29243 .44774 .29335 .4497 .29448 .45493 .29385 .44882 Mtetra
.425 .307 .615 r
.29385 .44882 .29448 .45493 .28249 .64811 .29523 .45045 Mtetra
.546 .329 .537 r
.29523 .45045 .28249 .64811 .28395 .65002 .29671 .45084 Mtetra
.548 .331 .537 r
.29671 .45084 .28395 .65002 .28557 .64952 .29825 .45026 Mtetra
.549 .332 .538 r
.29825 .45026 .28557 .64952 .28726 .64817 .29982 .44927 Mtetra
.548 .331 .537 r
.29982 .44927 .28726 .64817 .2889 .64743 .30137 .4486 Mtetra
.30137 .4486 .2889 .64743 .29054 .64689 .30292 .44802 Mtetra
.30292 .44802 .29054 .64689 .29217 .64634 .30446 .44747 Mtetra
.549 .332 .538 r
.30446 .44747 .29217 .64634 .29384 .64528 .30605 .44627 Mtetra
.548 .331 .537 r
.30605 .44627 .29384 .64528 .29549 .64445 .30761 .44545 Mtetra
.546 .33 .537 r
.30761 .44545 .29549 .64445 .29708 .64458 .3091 .44565 Mtetra
.514 .303 .531 r
.3091 .44565 .29708 .64458 .29854 .64688 .30963 .46065 Mtetra
0 0 .238 r
.30963 .46065 .29854 .64688 .30002 .64876 .29911 .64554 Mtetra
0 0 .498 r
.29911 .64554 .30002 .64876 .30155 .64987 .30051 .64875 Mtetra
.281 .554 .927 r
.30051 .64875 .30155 .64987 .30316 .64987 .30209 .64919 Mtetra
.622 .809 .972 r
.30209 .64919 .30316 .64987 .3048 .6494 .30373 .64874 Mtetra
.709 .83 .94 r
.30373 .64874 .3048 .6494 .30645 .64878 .30539 .64799 Mtetra
.635 .784 .953 r
.30539 .64799 .30645 .64878 .30809 .64839 .30703 .64752 Mtetra
.603 .757 .952 r
.30703 .64752 .30809 .64839 .30972 .64809 .30867 .64717 Mtetra
.618 .75 .94 r
.30867 .64717 .30972 .64809 .31136 .64775 .31031 .64678 Mtetra
.631 .745 .93 r
.31031 .64678 .31136 .64775 .31299 .64746 .31195 .64636 Mtetra
.662 .726 .897 r
.31195 .64636 .31299 .64746 .31464 .64699 .3136 .6458 Mtetra
.701 .722 .865 r
.3136 .6458 .31464 .64699 .31631 .6461 .31527 .64503 Mtetra
.792 .756 .82 r
.31527 .64503 .31631 .6461 .31808 .64359 .31698 .64357 Mtetra
.903 .923 .822 r
.31698 .64357 .31808 .64359 .32002 .63818 .31872 .64148 Mtetra
0 0 .099 r
.31872 .64148 .32002 .63818 .33306 .44373 .32049 .63892 Mtetra
.544 .323 .531 r
.32049 .63892 .33306 .44373 .33483 .43959 .32217 .63792 Mtetra
.545 .325 .531 r
.32217 .63792 .33483 .43959 .33638 .4392 .3238 .63779 Mtetra
.544 .324 .531 r
.3238 .63779 .33638 .4392 .33791 .43913 .32548 .63699 Mtetra
.531 .313 .528 r
.32548 .63699 .33791 .43913 .3396 .43641 .32755 .62913 Mtetra
0 0 .24 r
.32755 .62913 .3396 .43641 .34129 .43355 .34017 .43517 Mtetra
.951 .923 .566 r
.34017 .43517 .34129 .43355 .34294 .43148 .34195 .43083 Mtetra
.839 .819 .83 r
.34195 .43083 .34294 .43148 .34453 .4304 .34357 .42922 Mtetra
.674 .704 .87 r
.34357 .42922 .34453 .4304 .34609 .42985 .34514 .42863 Mtetra
.595 .669 .891 r
.34514 .42863 .34609 .42985 .34765 .42949 .34668 .42838 Mtetra
.6 .693 .908 r
.34668 .42838 .34765 .42949 .3492 .42914 .34823 .4281 Mtetra
.62 .713 .913 r
.34823 .4281 .3492 .42914 .35076 .42877 .34979 .42775 Mtetra
.625 .72 .915 r
.34979 .42775 .35076 .42877 .35232 .42836 .35135 .42737 Mtetra
.666 .74 .905 r
.35135 .42737 .35232 .42836 .35389 .42777 .35292 .42683 Mtetra
.693 .757 .901 r
.35292 .42683 .35389 .42777 .35546 .42706 .35449 .42618 Mtetra
.699 .77 .906 r
.35449 .42618 .35546 .42706 .35704 .42634 .35607 .4255 Mtetra
.71 .781 .908 r
.35607 .4255 .35704 .42634 .35863 .4255 .35765 .42477 Mtetra
.697 .804 .932 r
.35765 .42477 .35863 .4255 .36021 .42476 .35923 .42411 Mtetra
.633 .81 .968 r
.35923 .42411 .36021 .42476 .36177 .42439 .36079 .42364 Mtetra
.46 .724 .982 r
.36079 .42364 .36177 .42439 .36327 .42525 .36234 .42361 Mtetra
.363 .484 .848 r
.36234 .42361 .36327 .42525 .36466 .42844 .36386 .42417 Mtetra
.365 .303 .654 r
.36386 .42417 .36466 .42844 .35679 .62145 .36533 .42576 Mtetra
.529 .315 .534 r
.36533 .42576 .35679 .62145 .35806 .6292 .36648 .43415 Mtetra
0 0 .276 r
.36648 .43415 .35806 .6292 .35962 .63121 .35874 .62712 Mtetra
0 .026 .554 r
.35874 .62712 .35962 .63121 .36123 .63206 .36022 .63057 Mtetra
.212 .439 .862 r
.36022 .63057 .36123 .63206 .36288 .63213 .36184 .63138 Mtetra
.596 .789 .972 r
.36184 .63138 .36288 .63213 .36455 .6317 .36351 .63101 Mtetra
.705 .827 .94 r
.36351 .63101 .36455 .6317 .36624 .63106 .3652 .63025 Mtetra
.666 .793 .942 r
.3652 .63025 .36624 .63106 .36791 .63067 .36689 .62967 Mtetra
.624 .738 .929 r
.36689 .62967 .36791 .63067 .36958 .6304 .36857 .62926 Mtetra
.671 .725 .89 r
.36857 .62926 .36958 .6304 .37127 .62975 .37025 .62865 Mtetra
.743 .75 .858 r
.37025 .62865 .37127 .62975 .37302 .62787 .37196 .62762 Mtetra
.861 .914 .865 r
.37196 .62762 .37302 .62787 .37487 .62359 .3737 .62595 Mtetra
0 0 0 r
.3737 .62595 .37487 .62359 .38478 .43184 .37548 .62325 Mtetra
.53 .312 .528 r
.37548 .62325 .38478 .43184 .38684 .4203 .37748 .61538 Mtetra
0 0 .271 r
.37748 .61538 .38684 .4203 .38854 .41733 .38744 .41954 Mtetra
.836 .867 .422 r
.38744 .41954 .38854 .41733 .39018 .41552 .3892 .4151 Mtetra
.876 .865 .824 r
.3892 .4151 .39018 .41552 .39179 .41445 .39084 .41325 Mtetra
.687 .707 .863 r
.39084 .41325 .39179 .41445 .39338 .41387 .39244 .41258 Mtetra
.612 .666 .878 r
.39244 .41258 .39338 .41387 .39496 .41348 .39402 .41226 Mtetra
.618 .68 .886 r
.39402 .41226 .39496 .41348 .39655 .41307 .3956 .41192 Mtetra
.658 .706 .883 r
.3956 .41192 .39655 .41307 .39814 .41256 .3972 .4114 Mtetra
.658 .705 .882 r
.3972 .4114 .39814 .41256 .39974 .41204 .39879 .41088 Mtetra
.661 .707 .881 r
.39879 .41088 .39974 .41204 .40133 .4115 .40038 .41034 Mtetra
.664 .708 .88 r
.40038 .41034 .40133 .4115 .40293 .41096 .40198 .40979 Mtetra
.664 .707 .879 r
.40198 .40979 .40293 .41096 .40452 .41041 .40358 .40924 Mtetra
.693 .717 .867 r
.40358 .40924 .40452 .41041 .40612 .40977 .40518 .40854 Mtetra
.702 .709 .854 r
.40518 .40854 .40612 .40977 .40773 .40908 .40679 .40778 Mtetra
.637 .673 .868 r
.40679 .40778 .40773 .40908 .40932 .40859 .40838 .40735 Mtetra
.184 .455 .88 r
.40838 .40735 .40932 .40859 .4109 .40869 .40994 .40807 Mtetra
.894 .474 .159 r
.40994 .40807 .4109 .40869 .41245 .40974 .4114 .41159 Mtetra
.951 .681 .489 r
.4114 .41159 .41245 .40974 .41397 .41158 .40624 .60657 Mtetra
.556 .333 .533 r
.40624 .60657 .41397 .41158 .41551 .4129 .40773 .6123 Mtetra
.545 .325 .531 r
.40773 .6123 .41551 .4129 .41713 .4119 .40943 .61202 Mtetra
.544 .324 .531 r
.40943 .61202 .41713 .4119 .41874 .41132 .41115 .61111 Mtetra
.546 .325 .531 r
.41115 .61111 .41874 .41132 .4202 .41555 .41283 .61142 Mtetra
.549 .327 .531 r
.41283 .61142 .4202 .41555 .41559 .61022 .41447 .61304 Mtetra
.618 .272 .361 r
.41447 .61304 .41559 .61022 .41716 .61437 .41613 .61415 Mtetra
.194 0 0 r
.41613 .61415 .41716 .61437 .41881 .61571 .41781 .61457 Mtetra
.574 .696 .924 r
.41781 .61457 .41881 .61571 .42051 .61557 .41951 .61435 Mtetra
.634 .702 .895 r
.41951 .61435 .42051 .61557 .42223 .61503 .42123 .6139 Mtetra
.632 .72 .911 r
.42123 .6139 .42223 .61503 .42395 .6144 .42294 .61346 Mtetra
.605 .75 .947 r
.42294 .61346 .42395 .6144 .42567 .61388 .42466 .6131 Mtetra
.698 .81 .934 r
.42466 .6131 .42567 .61388 .42739 .61315 .42638 .61236 Mtetra
.844 .817 .823 r
.42638 .61236 .42739 .61315 .42913 .61188 .42814 .61056 Mtetra
.898 .734 .67 r
.42814 .61056 .42913 .61188 .4309 .60966 .42997 .60597 Mtetra
.953 .687 .492 r
.42997 .60597 .4309 .60966 .43268 .60669 .43696 .41163 Mtetra
.565 .345 .54 r
.43696 .41163 .43268 .60669 .43446 .60404 .43882 .40229 Mtetra
.548 .331 .537 r
.43882 .40229 .43446 .60404 .43617 .60395 .44045 .40146 Mtetra
.547 .33 .537 r
.44045 .40146 .43617 .60395 .43789 .60357 .44206 .40133 Mtetra
.549 .332 .537 r
.44206 .40133 .43789 .60357 .43969 .59971 .44369 .40027 Mtetra
.552 .334 .538 r
.44369 .40027 .43969 .59971 .4462 .40279 .44537 .39767 Mtetra
.675 .5 .641 r
.44537 .39767 .4462 .40279 .44795 .39738 .44703 .39561 Mtetra
.744 .659 .766 r
.44703 .39561 .44795 .39738 .44961 .39502 .44867 .39423 Mtetra
.688 .798 .933 r
.44867 .39423 .44961 .39502 .45124 .39424 .4503 .39358 Mtetra
.615 .81 .975 r
.4503 .39358 .45124 .39424 .45286 .39387 .45192 .39315 Mtetra
.591 .786 .973 r
.45192 .39315 .45286 .39387 .45448 .39365 .45355 .3928 Mtetra
.62 .765 .949 r
.45355 .3928 .45448 .39365 .45611 .39328 .45517 .3924 Mtetra
.621 .757 .944 r
.45517 .3924 .45611 .39328 .45773 .39293 .4568 .392 Mtetra
.635 .751 .932 r
.4568 .392 .45773 .39293 .45936 .39253 .45842 .39156 Mtetra
.659 .749 .917 r
.45842 .39156 .45936 .39253 .46099 .39203 .46006 .39103 Mtetra
.672 .747 .907 r
.46006 .39103 .46099 .39203 .46262 .39147 .46169 .39045 Mtetra
.687 .747 .897 r
.46169 .39045 .46262 .39147 .46425 .39083 .46332 .38979 Mtetra
.704 .747 .886 r
.46332 .38979 .46425 .39083 .46589 .39011 .46496 .38905 Mtetra
.703 .743 .883 r
.46496 .38905 .46589 .39011 .46752 .38938 .4666 .3883 Mtetra
.708 .742 .878 r
.4666 .3883 .46752 .38938 .46916 .38865 .46824 .38752 Mtetra
.721 .737 .864 r
.46824 .38752 .46916 .38865 .4708 .3879 .46988 .38666 Mtetra
.658 .695 .873 r
.46988 .38666 .4708 .3879 .47244 .38735 .47152 .38612 Mtetra
.416 .589 .913 r
.47152 .38612 .47244 .38735 .47407 .38724 .47314 .38639 Mtetra
.827 .364 0 r
.47314 .38639 .47407 .38724 .47569 .38816 .47473 .38926 Mtetra
.958 .682 .469 r
.47473 .38926 .47569 .38816 .47729 .38986 .47347 .58051 Mtetra
.566 .342 .534 r
.47347 .58051 .47729 .38986 .4789 .39215 .47503 .59229 Mtetra
.546 .325 .531 r
.47503 .59229 .4789 .39215 .48053 .39225 .47677 .59256 Mtetra
.544 .324 .531 r
.47677 .59256 .48053 .39225 .48218 .39134 .47852 .59173 Mtetra
.544 .323 .531 r
.47852 .59173 .48218 .39134 .48384 .39017 .48028 .59049 Mtetra
.545 .324 .531 r
.48028 .59049 .48384 .39017 .48549 .3896 .48204 .58998 Mtetra
.48204 .58998 .48549 .3896 .48714 .38903 .48379 .58945 Mtetra
.48379 .58945 .48714 .38903 .48879 .38848 .48554 .58892 Mtetra
.48554 .58892 .48879 .38848 .49044 .38793 .4873 .58841 Mtetra
.4873 .58841 .49044 .38793 .49209 .38738 .48905 .5879 Mtetra
.48905 .5879 .49209 .38738 .49374 .38684 .49081 .58739 Mtetra
.49081 .58739 .49374 .38684 .4954 .38629 .49257 .58688 Mtetra
.49257 .58688 .4954 .38629 .49705 .38575 .49433 .58636 Mtetra
.49433 .58636 .49705 .38575 .49871 .3852 .49609 .58585 Mtetra
.49609 .58585 .49871 .3852 .50036 .38465 .49785 .58533 Mtetra
.49785 .58533 .50036 .38465 .50202 .3841 .49961 .58481 Mtetra
.49961 .58481 .50202 .3841 .50368 .38355 .50137 .58428 Mtetra
.50137 .58428 .50368 .38355 .50534 .383 .50314 .58376 Mtetra
.50314 .58376 .50534 .383 .507 .38244 .5049 .58323 Mtetra
.5049 .58323 .507 .38244 .50866 .38189 .50667 .58271 Mtetra
.50667 .58271 .50866 .38189 .51033 .38133 .50844 .58218 Mtetra
.50844 .58218 .51033 .38133 .51199 .38077 .51021 .58165 Mtetra
.51021 .58165 .51199 .38077 .51366 .38021 .51198 .58112 Mtetra
.51198 .58112 .51366 .38021 .51532 .37965 .51375 .58059 Mtetra
.51375 .58059 .51532 .37965 .51699 .37909 .51552 .58005 Mtetra
.51552 .58005 .51699 .37909 .51866 .37852 .5173 .57951 Mtetra
.5173 .57951 .51866 .37852 .52033 .37796 .51907 .57898 Mtetra
.51907 .57898 .52033 .37796 .522 .37739 .52085 .57843 Mtetra
.52085 .57843 .522 .37739 .52367 .37682 .52263 .57789 Mtetra
.52263 .57789 .52367 .37682 .52534 .37625 .5244 .57735 Mtetra
.5244 .57735 .52534 .37625 .52701 .37568 .52618 .5768 Mtetra
.52618 .5768 .52701 .37568 .52869 .37511 .52797 .57626 Mtetra
.52797 .57626 .52869 .37511 .53036 .37456 .52975 .57573 Mtetra
.52975 .57573 .53036 .37456 .53204 .37401 .53153 .5752 Mtetra
.53153 .5752 .53204 .37401 .53372 .37347 .53331 .57467 Mtetra
.546 .325 .531 r
.53331 .57467 .53372 .37347 .5354 .37362 .5351 .57495 Mtetra
.545 .325 .531 r
.5351 .57495 .5354 .37362 .53708 .37326 .53689 .57457 Mtetra
.543 .323 .531 r
.53689 .57457 .53708 .37326 .53875 .37182 .53867 .57291 Mtetra
0 0 .362 r
.53867 .57291 .53875 .37182 .54042 .36817 .53957 .37719 Mtetra
0 0 .175 r
.53957 .37719 .54042 .36817 .54209 .36551 .5412 .36603 Mtetra
.969 .934 .655 r
.5412 .36603 .54209 .36551 .54376 .36359 .54287 .36253 Mtetra
.751 .763 .862 r
.54287 .36253 .54376 .36359 .54544 .36276 .54454 .36148 Mtetra
.65 .692 .876 r
.54454 .36148 .54544 .36276 .54712 .36223 .54623 .36097 Mtetra
.583 .668 .897 r
.54623 .36097 .54712 .36223 .54881 .36186 .54791 .36074 Mtetra
.622 .712 .91 r
.54791 .36074 .54881 .36186 .55049 .36145 .5496 .36035 Mtetra
.621 .715 .913 r
.5496 .36035 .55049 .36145 .55218 .36104 .55129 .35996 Mtetra
.631 .723 .914 r
.55129 .35996 .55218 .36104 .55387 .36058 .55297 .35953 Mtetra
.682 .748 .901 r
.55297 .35953 .55387 .36058 .55555 .35988 .55466 .35888 Mtetra
.695 .762 .903 r
.55466 .35888 .55555 .35988 .55724 .35912 .55635 .35817 Mtetra
.697 .773 .91 r
.55635 .35817 .55724 .35912 .55893 .35837 .55804 .35745 Mtetra
.706 .783 .912 r
.55804 .35745 .55893 .35837 .56061 .35747 .55973 .3567 Mtetra
.676 .809 .947 r
.55973 .3567 .56061 .35747 .5623 .3568 .56142 .35607 Mtetra
.601 .795 .974 r
.56142 .35607 .5623 .3568 .564 .35657 .56311 .35567 Mtetra
.233 .566 .938 r
.56311 .35567 .564 .35657 .56572 .35832 .56482 .35613 Mtetra
.326 .398 .783 r
.56482 .35613 .56572 .35832 .5675 .36368 .56654 .35714 Mtetra
.459 .334 .622 r
.56654 .35714 .5675 .36368 .57196 .56164 .56826 .35865 Mtetra
.548 .331 .537 r
.56826 .35865 .57196 .56164 .57379 .56276 .56996 .35804 Mtetra
.56996 .35804 .57379 .56276 .5756 .56192 .57166 .35715 Mtetra
.547 .33 .537 r
.57166 .35715 .5756 .56192 .5774 .56101 .57337 .35709 Mtetra
0 0 .398 r
.57337 .35709 .5774 .56101 .57926 .56341 .57806 .54604 Mtetra
.001 0 .444 r
.57806 .54604 .57926 .56341 .58111 .56526 .58014 .5621 Mtetra
0 .1 .625 r
.58014 .5621 .58111 .56526 .58296 .56632 .58202 .56514 Mtetra
.416 .622 .937 r
.58202 .56514 .58296 .56632 .58479 .56622 .58385 .56537 Mtetra
.643 .796 .956 r
.58385 .56537 .58479 .56622 .58661 .56571 .58567 .56482 Mtetra
.718 .808 .921 r
.58567 .56482 .58661 .56571 .58843 .56503 .58749 .56396 Mtetra
.625 .74 .93 r
.58749 .56396 .58843 .56503 .59025 .56476 .58931 .56351 Mtetra
.632 .707 .9 r
.58931 .56351 .59025 .56476 .59208 .56436 .59114 .56304 Mtetra
.678 .714 .875 r
.59114 .56304 .59208 .56436 .5939 .5635 .59296 .56234 Mtetra
.766 .766 .853 r
.59296 .56234 .5939 .5635 .59568 .56088 .59477 .56109 Mtetra
.846 .999 .803 r
.59477 .56109 .59568 .56088 .5974 .55533 .59657 .55916 Mtetra
.068 0 .207 r
.59657 .55916 .5974 .55533 .59483 .35522 .59834 .55593 Mtetra
.028 0 .404 r
.59834 .55593 .59483 .35522 .59643 .34921 .59611 .37332 Mtetra
0 0 .329 r
.59611 .37332 .59643 .34921 .5981 .3466 .59727 .34779 Mtetra
.858 .903 .488 r
.59727 .34779 .5981 .3466 .59979 .34497 .59892 .34414 Mtetra
.791 .822 .877 r
.59892 .34414 .59979 .34497 .6015 .34417 .60062 .3429 Mtetra
.628 .689 .888 r
.60062 .3429 .6015 .34417 .60322 .34377 .60234 .34248 Mtetra
.548 .649 .901 r
.60234 .34248 .60322 .34377 .60494 .34354 .60407 .34238 Mtetra
.619 .706 .907 r
.60407 .34238 .60494 .34354 .60667 .34309 .60579 .34199 Mtetra
.656 .733 .906 r
.60579 .34199 .60667 .34309 .60839 .34251 .60752 .34145 Mtetra
.67 .744 .906 r
.60752 .34145 .60839 .34251 .61011 .34187 .60924 .34084 Mtetra
.72 .768 .89 r
.60924 .34084 .61011 .34187 .61182 .34086 .61095 .33998 Mtetra
.722 .801 .914 r
.61095 .33998 .61182 .34086 .61353 .33993 .61267 .33914 Mtetra
.67 .807 .948 r
.61267 .33914 .61353 .33993 .61525 .33943 .61439 .33852 Mtetra
.497 .709 .965 r
.61439 .33852 .61525 .33943 .61703 .34049 .61613 .33845 Mtetra
.422 .473 .808 r
.61613 .33845 .61703 .34049 .61888 .34427 .61789 .33905 Mtetra
.409 .32 .643 r
.61789 .33905 .61888 .34427 .62665 .54335 .61969 .34082 Mtetra
.51 .302 .534 r
.61969 .34082 .62665 .54335 .62868 .54906 .62201 .35951 Mtetra
0 0 .398 r
.62201 .35951 .62868 .54906 .6306 .55082 .6296 .54703 Mtetra
.118 .171 .643 r
.6296 .54703 .6306 .55082 .63249 .5515 .63156 .55008 Mtetra
.415 .573 .901 r
.63156 .55008 .63249 .5515 .63436 .55128 .63344 .55043 Mtetra
.672 .809 .949 r
.63344 .55043 .63436 .55128 .6362 .55058 .63529 .54976 Mtetra
.747 .834 .918 r
.63529 .54976 .6362 .55058 .63805 .5497 .63713 .54873 Mtetra
.638 .77 .943 r
.63713 .54873 .63805 .5497 .63991 .5494 .63899 .54821 Mtetra
.592 .705 .922 r
.63899 .54821 .63991 .5494 .64178 .5492 .64086 .54789 Mtetra
.643 .704 .891 r
.64086 .54789 .64178 .5492 .64364 .54858 .64271 .54737 Mtetra
.743 .756 .863 r
.64271 .54737 .64364 .54858 .64543 .54635 .64456 .54626 Mtetra
.863 .982 .849 r
.64456 .54626 .64543 .54635 .64713 .54132 .64637 .54443 Mtetra
0 0 .141 r
.64637 .54443 .64713 .54132 .64163 .34123 .64814 .54139 Mtetra
.526 .31 .529 r
.64814 .54139 .64163 .34123 .64312 .33384 .64958 .52956 Mtetra
0 0 .393 r
.64958 .52956 .64312 .33384 .64478 .33107 .64403 .33272 Mtetra
.731 .804 .328 r
.64403 .33272 .64478 .33107 .64648 .32934 .64564 .32869 Mtetra
.839 .871 .866 r
.64564 .32869 .64648 .32934 .64821 .32842 .64735 .32717 Mtetra
.642 .7 .888 r
.64735 .32717 .64821 .32842 .64996 .32797 .6491 .32667 Mtetra
.558 .655 .9 r
.6491 .32667 .64996 .32797 .65172 .32771 .65086 .32653 Mtetra
.633 .711 .903 r
.65086 .32653 .65172 .32771 .65347 .32708 .65262 .32608 Mtetra
.683 .767 .915 r
.65262 .32608 .65347 .32708 .65521 .3263 .65436 .32541 Mtetra
.643 .777 .945 r
.65436 .32541 .65521 .3263 .65696 .32587 .65612 .32489 Mtetra
.528 .708 .953 r
.65612 .32489 .65696 .32587 .65878 .32677 .65789 .32476 Mtetra
.456 .498 .814 r
.65789 .32476 .65878 .32677 .66071 .33036 .65969 .32521 Mtetra
.438 .342 .649 r
.65969 .32521 .66071 .33036 .67117 .52917 .66153 .3267 Mtetra
.529 .317 .536 r
.66153 .3267 .67117 .52917 .67335 .53551 .66372 .33605 Mtetra
.003 0 .413 r
.66372 .33605 .67335 .53551 .67533 .5374 .67429 .53313 Mtetra
.136 .167 .63 r
.67429 .53313 .67533 .5374 .67727 .5382 .67635 .53656 Mtetra
.292 .467 .861 r
.67635 .53656 .67727 .5382 .67919 .5384 .67829 .53741 Mtetra
.591 .75 .953 r
.67829 .53741 .67919 .5384 .68108 .5381 .68019 .53705 Mtetra
.722 .784 .901 r
.68019 .53705 .68108 .5381 .68295 .53722 .68205 .53612 Mtetra
.778 .789 .862 r
.68205 .53612 .68295 .53722 .68476 .53503 .68391 .5348 Mtetra
.869 .965 .858 r
.68391 .5348 .68476 .53503 .68645 .53028 .68573 .53297 Mtetra
0 0 .086 r
.68573 .53297 .68645 .53028 .67862 .33048 .6875 .53 Mtetra
.53 .313 .53 r
.6875 .53 .67862 .33048 .67997 .32153 .68895 .52048 Mtetra
.001 0 .406 r
.68895 .52048 .67997 .32153 .68162 .31859 .68094 .32063 Mtetra
0 0 0 r
.68094 .32063 .68162 .31859 .68333 .31675 .68252 .3163 Mtetra
.892 .912 .832 r
.68252 .3163 .68333 .31675 .68506 .31546 .68422 .31436 Mtetra
.707 .756 .891 r
.68422 .31436 .68506 .31546 .68681 .3146 .68598 .31355 Mtetra
.588 .721 .935 r
.68598 .31355 .68681 .3146 .6886 .31426 .68776 .31325 Mtetra
.468 .674 .954 r
.68776 .31325 .6886 .31426 .69044 .31497 .68957 .31329 Mtetra
.426 .523 .854 r
.68957 .31329 .69044 .31497 .69239 .31778 .6914 .31375 Mtetra
.413 .353 .682 r
.6914 .31375 .69239 .31778 .70468 .51229 .69328 .31514 Mtetra
.535 .322 .537 r
.69328 .31514 .70468 .51229 .70728 .52469 .69541 .32111 Mtetra
.022 0 .424 r
.69541 .32111 .70728 .52469 .70934 .527 .70824 .52204 Mtetra
.14 .153 .611 r
.70824 .52204 .70934 .527 .71132 .52795 .71039 .52608 Mtetra
.261 .414 .826 r
.71039 .52608 .71132 .52795 .71327 .52823 .71239 .52719 Mtetra
.567 .731 .952 r
.71239 .52719 .71327 .52823 .7152 .52801 .71432 .52692 Mtetra
.707 .775 .905 r
.71432 .52692 .7152 .52801 .71709 .52721 .71621 .52606 Mtetra
.769 .782 .863 r
.71621 .52606 .71709 .52721 .71892 .52526 .71808 .52479 Mtetra
.857 .929 .874 r
.71808 .52479 .71892 .52526 .72062 .52102 .71992 .52307 Mtetra
0 0 0 r
.71992 .52307 .72062 .52102 .71142 .33262 .7217 .52035 Mtetra
.533 .316 .53 r
.7217 .52035 .71142 .33262 .71199 .31154 .72323 .51331 Mtetra
.02 0 .417 r
.72323 .51331 .71199 .31154 .71362 .3083 .71302 .31096 Mtetra
0 0 0 r
.71302 .31096 .71362 .3083 .71533 .30635 .71455 .30603 Mtetra
.905 .941 .821 r
.71455 .30603 .71533 .30635 .71708 .30522 .71625 .30399 Mtetra
.668 .721 .888 r
.71625 .30399 .71708 .30522 .71887 .30468 .71804 .30336 Mtetra
.583 .667 .897 r
.71804 .30336 .71887 .30468 .72068 .30434 .71985 .30312 Mtetra
.6 .693 .908 r
.71985 .30312 .72068 .30434 .72248 .30388 .72166 .3028 Mtetra
.683 .755 .906 r
.72166 .3028 .72248 .30388 .72426 .30313 .72345 .30211 Mtetra
.69 .769 .912 r
.72345 .30211 .72426 .30313 .72604 .30236 .72523 .30138 Mtetra
.7 .784 .916 r
.72523 .30138 .72604 .30236 .72782 .3015 .72702 .30061 Mtetra
.7 .805 .93 r
.72702 .30061 .72782 .3015 .7296 .30062 .7288 .29985 Mtetra
.651 .815 .962 r
.7288 .29985 .7296 .30062 .7314 .30009 .7306 .29926 Mtetra
.539 .756 .977 r
.7306 .29926 .7314 .30009 .73326 .30048 .73242 .29903 Mtetra
.429 .563 .887 r
.73242 .29903 .73326 .30048 .73527 .30299 .73429 .29938 Mtetra
.419 .374 .701 r
.73429 .29938 .73527 .30299 .73822 .31927 .73621 .3006 Mtetra
.456 .286 .562 r
.73621 .3006 .73822 .31927 .75317 .51052 .73837 .3052 Mtetra
.046 0 .437 r
.73837 .3052 .75317 .51052 .75531 .51303 .75413 .50729 Mtetra
.161 .153 .6 r
.75413 .50729 .75531 .51303 .75736 .51406 .75642 .51192 Mtetra
.259 .38 .797 r
.75642 .51192 .75736 .51406 .75935 .51426 .75849 .51326 Mtetra
.58 .747 .956 r
.75849 .51326 .75935 .51426 .7613 .51385 .76045 .51292 Mtetra
.692 .808 .937 r
.76045 .51292 .7613 .51385 .76323 .51319 .76237 .51213 Mtetra
.666 .771 .928 r
.76237 .51213 .76323 .51319 .76517 .51268 .7643 .51147 Mtetra
.545 .686 .932 r
.7643 .51147 .76517 .51268 .76715 .51254 .76628 .51132 Mtetra
.666 .738 .904 r
.76628 .51132 .76715 .51254 .76908 .5119 .76821 .51065 Mtetra
.858 .788 .781 r
.76821 .51065 .76908 .5119 .7709 .50967 .77003 .50837 Mtetra
.973 .743 .529 r
.77003 .50837 .7709 .50967 .77221 .5005 .77129 .4985 Mtetra
.977 .678 .367 r
.77129 .4985 .77221 .5005 .75875 .29464 .75792 .29329 Mtetra
.916 .765 .679 r
.75792 .29329 .75875 .29464 .76031 .29074 .7595 .28952 Mtetra
.697 .736 .881 r
.7595 .28952 .76031 .29074 .76212 .28993 .7613 .28873 Mtetra
.552 .675 .92 r
.7613 .28873 .76212 .28993 .76397 .28978 .76316 .28858 Mtetra
.512 .657 .925 r
.76316 .28858 .76397 .28978 .76583 .28976 .76502 .28856 Mtetra
.646 .721 .903 r
.76502 .28856 .76583 .28976 .76766 .28922 .76685 .28803 Mtetra
.657 .727 .901 r
.76685 .28803 .76766 .28922 .76948 .28862 .76867 .28745 Mtetra
.687 .742 .893 r
.76867 .28745 .76948 .28862 .77129 .28792 .77049 .28672 Mtetra
.729 .752 .871 r
.77049 .28672 .77129 .28792 .7731 .28707 .77228 .28574 Mtetra
.67 .708 .876 r
.77228 .28574 .7731 .28707 .77491 .28636 .7741 .28508 Mtetra
.46 .613 .914 r
.7741 .28508 .77491 .28636 .77676 .28601 .77599 .28527 Mtetra
.654 .163 0 r
.77599 .28527 .77676 .28601 .77866 .28634 .77809 .28797 Mtetra
.974 .665 .343 r
.77809 .28797 .77866 .28634 .78064 .28751 .79594 .48275 Mtetra
.566 .34 .531 r
.79594 .48275 .78064 .28751 .78284 .29141 .79903 .49587 Mtetra
.549 .327 .531 r
.79903 .49587 .78284 .29141 .80154 .49288 .8012 .49779 Mtetra
.565 .255 .401 r
.8012 .49779 .80154 .49288 .80398 .49802 .80327 .49851 Mtetra
.331 0 0 r
.80327 .49851 .80398 .49802 .80614 .49978 .80531 .49871 Mtetra
.467 .679 .957 r
.80531 .49871 .80614 .49978 .80818 .49999 .80733 .49875 Mtetra
.659 .735 .906 r
.80733 .49875 .80818 .49999 .81014 .4993 .80929 .49811 Mtetra
.842 .8 .811 r
.80929 .49811 .81014 .4993 .81198 .49718 .81115 .49613 Mtetra
.98 .767 .545 r
.81115 .49613 .81198 .49718 .8133 .48911 .81248 .48815 Mtetra
.977 .675 .344 r
.81248 .48815 .8133 .48911 .79721 .28264 .79643 .28156 Mtetra
.954 .792 .642 r
.79643 .28156 .79721 .28264 .79871 .27815 .79792 .27704 Mtetra
.745 .778 .88 r
.79792 .27704 .79871 .27815 .80051 .27711 .79973 .27599 Mtetra
.614 .725 .925 r
.79973 .27599 .80051 .27711 .80237 .27671 .80159 .27558 Mtetra
.575 .705 .93 r
.80159 .27558 .80237 .27671 .80425 .27646 .80346 .27532 Mtetra
.747 .772 .874 r
.80346 .27532 .80425 .27646 .80605 .2754 .80527 .27425 Mtetra
.669 .742 .905 r
.80527 .27425 .80605 .2754 .8079 .27477 .80711 .2736 Mtetra
.359 .58 .926 r
.80711 .2736 .8079 .27477 .80984 .27522 .80905 .27403 Mtetra
.844 .445 0 r
.80905 .27403 .80984 .27522 .81238 .28209 .81156 .28059 Mtetra
.973 .662 .314 r
.81156 .28059 .81238 .28209 .83348 .48794 .83264 .48663 Mtetra
.598 .176 0 r
.83264 .48663 .83348 .48794 .83586 .49157 .83503 .49036 Mtetra
.555 .696 .934 r
.83503 .49036 .83586 .49157 .83788 .49133 .83705 .49016 Mtetra
.711 .771 .899 r
.83705 .49016 .83788 .49133 .83984 .49038 .83901 .48924 Mtetra
.744 .79 .89 r
.83901 .48924 .83984 .49038 .84178 .48923 .84096 .48814 Mtetra
.459 .671 .955 r
.84096 .48814 .84178 .48923 .84383 .48929 .84302 .48821 Mtetra
.583 .738 .95 r
.84302 .48821 .84383 .48929 .84585 .48893 .84503 .48786 Mtetra
.779 .814 .881 r
.84503 .48786 .84585 .48893 .84777 .4876 .84696 .48655 Mtetra
.976 .788 .588 r
.84696 .48655 .84777 .4876 .84922 .48142 .84842 .48043 Mtetra
.976 .67 .325 r
.84842 .48043 .84922 .48142 .8307 .27314 .82994 .2721 Mtetra
.975 .782 .581 r
.82994 .2721 .8307 .27314 .83204 .26727 .83127 .26615 Mtetra
.769 .786 .867 r
.83127 .26615 .83204 .26727 .83385 .26607 .83308 .26493 Mtetra
.631 .732 .92 r
.83308 .26493 .83385 .26607 .83572 .2656 .83495 .26445 Mtetra
.548 .69 .933 r
.83495 .26445 .83572 .2656 .83764 .26544 .83686 .26429 Mtetra
.751 .775 .873 r
.83686 .26429 .83764 .26544 .83945 .26434 .83868 .26318 Mtetra
.681 .748 .902 r
.83868 .26318 .83945 .26434 .84131 .26364 .84054 .26247 Mtetra
.467 .643 .933 r
.84054 .26247 .84131 .26364 .84325 .26375 .84248 .26258 Mtetra
.845 .449 0 r
.84248 .26258 .84325 .26375 .84593 .27087 .84515 .26968 Mtetra
.971 .656 .295 r
.84515 .26968 .84593 .27087 .86939 .47704 .86859 .47594 Mtetra
0 0 .451 r
.86859 .47594 .86939 .47704 .87179 .48016 .87099 .47907 Mtetra
.977 .788 .584 r
.87099 .47907 .87179 .48016 .87322 .47398 .87242 .47292 Mtetra
.974 .667 .312 r
.87242 .47292 .87322 .47398 .85306 .26488 .85231 .26378 Mtetra
.971 .787 .599 r
.85231 .26378 .85306 .26488 .85444 .25952 .85368 .25839 Mtetra
.874 .434 .075 r
.24892 .46043 .24992 .46135 .25112 .46456 .25016 .46308 Mtetra
.938 .683 .525 r
.25016 .46308 .25112 .46456 .23627 .66153 .23541 .65815 Mtetra
.958 .653 .232 r
.23541 .65815 .23627 .66153 .23732 .66777 .23631 .66599 Mtetra
.42 .508 .843 r
.23631 .66599 .23732 .66777 .23886 .66802 .23784 .66642 Mtetra
.628 .632 .836 r
.23784 .66642 .23886 .66802 .24048 .66736 .23944 .66602 Mtetra
.703 .693 .838 r
.23944 .66602 .24048 .66736 .24215 .66608 .24107 .66521 Mtetra
.485 .711 .97 r
.24107 .66521 .24215 .66608 .24381 .66483 .24264 .66516 Mtetra
0 0 0 r
.24264 .66516 .24381 .66483 .24553 .66294 .24424 .66475 Mtetra
.09 0 0 r
.24424 .66475 .24553 .66294 .24736 .65962 .2459 .66361 Mtetra
0 0 0 r
.2459 .66361 .24736 .65962 .26419 .46698 .24789 .65833 Mtetra
0 0 .168 r
.24789 .65833 .26419 .46698 .26637 .45813 .26506 .46107 Mtetra
.939 .885 .476 r
.26506 .46107 .26637 .45813 .2681 .45503 .26703 .45492 Mtetra
.841 .933 .889 r
.26703 .45492 .2681 .45503 .26964 .45416 .26862 .45355 Mtetra
.666 .821 .958 r
.26862 .45355 .26964 .45416 .27114 .45389 .27014 .45301 Mtetra
.55 .721 .953 r
.27014 .45301 .27114 .45389 .27262 .45391 .27163 .45284 Mtetra
.644 .711 .896 r
.27163 .45284 .27262 .45391 .27413 .45354 .27315 .45241 Mtetra
.645 .699 .885 r
.27315 .45241 .27413 .45354 .27565 .45309 .27466 .45197 Mtetra
.642 .7 .888 r
.27466 .45197 .27565 .45309 .27717 .45261 .27618 .45154 Mtetra
.654 .714 .893 r
.27618 .45154 .27717 .45261 .27869 .45212 .2777 .45107 Mtetra
.659 .719 .893 r
.2777 .45107 .27869 .45212 .28022 .45159 .27923 .45057 Mtetra
.662 .726 .897 r
.27923 .45057 .28022 .45159 .28175 .45103 .28075 .45006 Mtetra
.663 .738 .906 r
.28075 .45006 .28175 .45103 .28329 .45036 .28228 .44955 Mtetra
.665 .772 .93 r
.28228 .44955 .28329 .45036 .28483 .44967 .28381 .44903 Mtetra
.663 .813 .955 r
.28381 .44903 .28483 .44967 .28637 .449 .28534 .44849 Mtetra
.661 .849 .972 r
.28534 .44849 .28637 .449 .28791 .44827 .28687 .44794 Mtetra
.638 .888 .986 r
.28687 .44794 .28791 .44827 .28945 .44766 .28841 .44737 Mtetra
.624 .896 .987 r
.28841 .44737 .28945 .44766 .29097 .44728 .28994 .44682 Mtetra
.639 .856 .982 r
.28994 .44682 .29097 .44728 .29243 .44774 .29147 .4463 Mtetra
.652 .652 .838 r
.29147 .4463 .29243 .44774 .29385 .44882 .29301 .4458 Mtetra
.617 .511 .711 r
.29301 .4458 .29385 .44882 .29523 .45045 .29454 .44529 Mtetra
.595 .443 .645 r
.29454 .44529 .29523 .45045 .29671 .45084 .29608 .44475 Mtetra
.589 .427 .63 r
.29608 .44475 .29671 .45084 .29825 .45026 .29761 .4442 Mtetra
.59 .428 .63 r
.29761 .4442 .29825 .45026 .29982 .44927 .29915 .44363 Mtetra
.592 .435 .637 r
.29915 .44363 .29982 .44927 .30137 .4486 .30069 .44308 Mtetra
.593 .436 .639 r
.30069 .44308 .30137 .4486 .30292 .44802 .30224 .44253 Mtetra
.592 .436 .639 r
.30224 .44253 .30292 .44802 .30446 .44747 .30378 .442 Mtetra
.613 .451 .639 r
.30378 .442 .30446 .44747 .30605 .44627 .30534 .44112 Mtetra
.604 .45 .645 r
.30534 .44112 .30605 .44627 .30761 .44545 .30689 .44043 Mtetra
.565 .424 .648 r
.30689 .44043 .30761 .44545 .3091 .44565 .30841 .44033 Mtetra
.22 .172 .588 r
.30841 .44033 .3091 .44565 .30963 .46065 .30972 .44323 Mtetra
.966 .709 .493 r
.30972 .44323 .30963 .46065 .29911 .64554 .29841 .63925 Mtetra
0 0 .247 r
.29841 .63925 .29911 .64554 .30051 .64875 .29953 .64672 Mtetra
.28 .396 .803 r
.29953 .64672 .30051 .64875 .30209 .64919 .30108 .64765 Mtetra
.633 .645 .844 r
.30108 .64765 .30209 .64919 .30373 .64874 .30272 .64722 Mtetra
.706 .675 .817 r
.30272 .64722 .30373 .64874 .30539 .64799 .30439 .64631 Mtetra
.666 .642 .816 r
.30439 .64631 .30539 .64799 .30703 .64752 .30604 .64566 Mtetra
.641 .611 .804 r
.30604 .64566 .30703 .64752 .30867 .64717 .30769 .64514 Mtetra
.634 .591 .789 r
.30769 .64514 .30867 .64717 .31031 .64678 .30933 .64464 Mtetra
.616 .573 .784 r
.30933 .64464 .31031 .64678 .31195 .64636 .31097 .64426 Mtetra
.609 .574 .789 r
.31097 .64426 .31195 .64636 .3136 .6458 .31261 .64392 Mtetra
.613 .597 .81 r
.31261 .64392 .3136 .6458 .31527 .64503 .31425 .64357 Mtetra
.636 .658 .855 r
.31425 .64357 .31527 .64503 .31698 .64357 .3159 .64312 Mtetra
.611 .863 .991 r
.3159 .64312 .31698 .64357 .31872 .64148 .31755 .64262 Mtetra
.192 0 0 r
.31755 .64262 .31872 .64148 .32049 .63892 .31921 .64208 Mtetra
.486 .153 .326 r
.31921 .64208 .32049 .63892 .32217 .63792 .32084 .64192 Mtetra
.49 .179 .365 r
.32084 .64192 .32217 .63792 .3238 .63779 .32248 .64165 Mtetra
.416 .106 .329 r
.32248 .64165 .3238 .63779 .32548 .63699 .32416 .6408 Mtetra
0 0 .048 r
.32416 .6408 .32548 .63699 .32755 .62913 .32599 .63721 Mtetra
.957 .701 .506 r
.32599 .63721 .32755 .62913 .34017 .43517 .33871 .44265 Mtetra
.735 .702 .165 r
.33871 .44265 .34017 .43517 .34195 .43083 .34091 .43106 Mtetra
.92 .954 .796 r
.34091 .43106 .34195 .43083 .34357 .42922 .34256 .42889 Mtetra
.651 .895 .983 r
.34256 .42889 .34357 .42922 .34514 .42863 .34413 .42828 Mtetra
.392 .795 .984 r
.34413 .42828 .34514 .42863 .34668 .42838 .34567 .42812 Mtetra
.526 .872 .989 r
.34567 .42812 .34668 .42838 .34823 .4281 .34723 .42771 Mtetra
.668 .884 .978 r
.34723 .42771 .34823 .4281 .34979 .42775 .3488 .42708 Mtetra
.685 .817 .946 r
.3488 .42708 .34979 .42775 .35135 .42737 .35037 .42646 Mtetra
.67 .756 .915 r
.35037 .42646 .35135 .42737 .35292 .42683 .35194 .42591 Mtetra
.658 .749 .918 r
.35194 .42591 .35292 .42683 .35449 .42618 .35351 .4254 Mtetra
.653 .783 .944 r
.35351 .4254 .35449 .42618 .35607 .4255 .35508 .4249 Mtetra
.657 .83 .966 r
.35508 .4249 .35607 .4255 .35765 .42477 .35665 .42436 Mtetra
.648 .875 .983 r
.35665 .42436 .35765 .42477 .35923 .42411 .35822 .42378 Mtetra
.628 .893 .987 r
.35822 .42378 .35923 .42411 .36079 .42364 .3598 .42321 Mtetra
.728 .884 .952 r
.3598 .42321 .36079 .42364 .36234 .42361 .36139 .4224 Mtetra
.703 .71 .853 r
.36139 .4224 .36234 .42361 .36386 .42417 .36297 .42164 Mtetra
.591 .523 .747 r
.36297 .42164 .36386 .42417 .36533 .42576 .36453 .4214 Mtetra
.305 .259 .641 r
.36453 .4214 .36533 .42576 .36648 .43415 .36599 .42339 Mtetra
.964 .7 .485 r
.36599 .42339 .36648 .43415 .35874 .62712 .35822 .61553 Mtetra
0 0 .296 r
.35822 .61553 .35874 .62712 .36022 .63057 .35927 .62809 Mtetra
.129 .252 .724 r
.35927 .62809 .36022 .63057 .36184 .63138 .36084 .62973 Mtetra
.613 .625 .84 r
.36084 .62973 .36184 .63138 .36351 .63101 .36251 .62939 Mtetra
.695 .664 .815 r
.36251 .62939 .36351 .63101 .3652 .63025 .36421 .62854 Mtetra
.665 .64 .815 r
.36421 .62854 .3652 .63025 .36689 .62967 .3659 .62787 Mtetra
.613 .608 .822 r
.3659 .62787 .36689 .62967 .36857 .62926 .36757 .62752 Mtetra
.618 .618 .828 r
.36757 .62752 .36857 .62926 .37025 .62865 .36925 .62715 Mtetra
.582 .633 .867 r
.36925 .62715 .37025 .62865 .37196 .62762 .37092 .62695 Mtetra
.535 .788 .991 r
.37092 .62695 .37196 .62762 .3737 .62595 .3726 .6267 Mtetra
0 0 0 r
.3726 .6267 .3737 .62595 .37548 .62325 .3743 .62587 Mtetra
.3743 .62587 .37548 .62325 .37748 .61538 .37609 .62287 Mtetra
.971 .799 .373 r
.37609 .62287 .37748 .61538 .38744 .41954 .37861 .60305 Mtetra
0 0 .261 r
.37861 .60305 .38744 .41954 .3892 .4151 .38818 .41561 Mtetra
.947 .955 .727 r
.38818 .41561 .3892 .4151 .39084 .41325 .38986 .41285 Mtetra
.705 .892 .965 r
.38986 .41285 .39084 .41325 .39244 .41258 .39146 .41209 Mtetra
.5 .813 1 r
.39146 .41209 .39244 .41258 .39402 .41226 .39304 .41185 Mtetra
.493 .828 .999 r
.39304 .41185 .39402 .41226 .3956 .41192 .39462 .41157 Mtetra
.606 .884 .991 r
.39462 .41157 .3956 .41192 .3972 .4114 .39622 .41105 Mtetra
.605 .883 .991 r
.39622 .41105 .3972 .4114 .39879 .41088 .39781 .41053 Mtetra
.611 .885 .99 r
.39781 .41053 .39879 .41088 .40038 .41034 .39941 .40999 Mtetra
.619 .888 .989 r
.39941 .40999 .40038 .41034 .40198 .40979 .401 .40944 Mtetra
.618 .887 .989 r
.401 .40944 .40198 .40979 .40358 .40924 .4026 .40889 Mtetra
.701 .904 .968 r
.4026 .40889 .40358 .40924 .40518 .40854 .40421 .40813 Mtetra
.733 .893 .952 r
.40421 .40813 .40518 .40854 .40679 .40778 .40582 .40728 Mtetra
.564 .834 .996 r
.40582 .40728 .40679 .40778 .40838 .40735 .40741 .40691 Mtetra
.659 .108 0 r
.40741 .40691 .40838 .40735 .40994 .40807 .40895 .40833 Mtetra
.935 .628 .435 r
.40895 .40833 .40994 .40807 .4114 .41159 .41005 .42184 Mtetra
.939 .668 .498 r
.41005 .42184 .4114 .41159 .40624 .60657 .40494 .61394 Mtetra
.627 .345 .471 r
.40494 .61394 .40624 .60657 .40773 .6123 .40655 .61622 Mtetra
.494 .18 .362 r
.40655 .61622 .40773 .6123 .40943 .61202 .40825 .61601 Mtetra
.432 .124 .341 r
.40825 .61601 .40943 .61202 .41115 .61111 .40997 .61522 Mtetra
.436 .13 .347 r
.40997 .61522 .41115 .61111 .41283 .61142 .41168 .61443 Mtetra
.445 .107 .297 r
.41168 .61443 .41283 .61142 .41447 .61304 .41339 .61399 Mtetra
.183 0 0 r
.41339 .61399 .41447 .61304 .41613 .61415 .4151 .61354 Mtetra
.632 .835 .978 r
.4151 .61354 .41613 .61415 .41781 .61457 .41682 .61301 Mtetra
.662 .66 .837 r
.41682 .61301 .41781 .61457 .41951 .61435 .41854 .61239 Mtetra
.653 .612 .796 r
.41854 .61239 .41951 .61435 .42123 .6139 .42026 .61175 Mtetra
.615 .576 .787 r
.42026 .61175 .42123 .6139 .42294 .61346 .42197 .61136 Mtetra
.573 .559 .8 r
.42197 .61136 .42294 .61346 .42466 .6131 .42368 .61123 Mtetra
.653 .621 .805 r
.42368 .61123 .42466 .6131 .42638 .61236 .4254 .61061 Mtetra
.806 .69 .736 r
.4254 .61061 .42638 .61236 .42814 .61056 .42717 .6083 Mtetra
.911 .689 .589 r
.42717 .6083 .42814 .61056 .42997 .60597 .42917 .59782 Mtetra
.948 .681 .497 r
.42917 .59782 .42997 .60597 .43696 .41163 .4363 .40019 Mtetra
.646 .44 .59 r
.4363 .40019 .43696 .41163 .43882 .40229 .438 .39673 Mtetra
.609 .449 .639 r
.438 .39673 .43882 .40229 .44045 .40146 .43963 .39587 Mtetra
.575 .425 .639 r
.43963 .39587 .44045 .40146 .44206 .40133 .44124 .39558 Mtetra
.569 .418 .637 r
.44124 .39558 .44206 .40133 .44369 .40027 .44286 .39538 Mtetra
.596 .45 .653 r
.44286 .39538 .44369 .40027 .44537 .39767 .44448 .39484 Mtetra
.622 .527 .725 r
.44448 .39484 .44537 .39767 .44703 .39561 .4461 .39429 Mtetra
.655 .682 .863 r
.4461 .39429 .44703 .39561 .44867 .39423 .44773 .39377 Mtetra
.615 .863 .99 r
.44773 .39377 .44867 .39423 .4503 .39358 .44935 .39326 Mtetra
.582 .886 .991 r
.44935 .39326 .4503 .39358 .45192 .39315 .45098 .39275 Mtetra
.608 .877 .991 r
.45098 .39275 .45192 .39315 .45355 .3928 .4526 .39223 Mtetra
.648 .843 .975 r
.4526 .39223 .45355 .3928 .45517 .3924 .45423 .39168 Mtetra
.663 .809 .953 r
.45423 .39168 .45517 .3924 .4568 .392 .45586 .39111 Mtetra
.671 .771 .925 r
.45586 .39111 .4568 .392 .45842 .39156 .45749 .39053 Mtetra
.675 .741 .9 r
.45749 .39053 .45842 .39156 .46006 .39103 .45913 .38993 Mtetra
.672 .725 .89 r
.45913 .38993 .46006 .39103 .46169 .39045 .46076 .38934 Mtetra
.663 .721 .892 r
.46076 .38934 .46169 .39045 .46332 .38979 .46239 .38878 Mtetra
.645 .738 .916 r
.46239 .38878 .46332 .38979 .46496 .38905 .46403 .38831 Mtetra
.631 .797 .962 r
.46403 .38831 .46496 .38905 .4666 .3883 .46566 .38785 Mtetra
.651 .876 .982 r
.46566 .38785 .4666 .3883 .46824 .38752 .4673 .38724 Mtetra
.747 .932 .949 r
.4673 .38724 .46824 .38752 .46988 .38666 .46894 .38628 Mtetra
.612 .883 .99 r
.46894 .38628 .46988 .38666 .47152 .38612 .47058 .38573 Mtetra
0 .317 .656 r
.47058 .38573 .47152 .38612 .47314 .38639 .4722 .38639 Mtetra
.925 .574 .347 r
.4722 .38639 .47314 .38639 .47473 .38926 .47372 .39347 Mtetra
.954 .678 .473 r
.47372 .39347 .47473 .38926 .47347 .58051 .47229 .59272 Mtetra
.623 .359 .496 r
.47229 .59272 .47347 .58051 .47503 .59229 .47398 .59607 Mtetra
.51 .19 .361 r
.47398 .59607 .47503 .59229 .47677 .59256 .47572 .59603 Mtetra
.428 .107 .317 r
.47572 .59603 .47677 .59256 .47852 .59173 .47748 .59534 Mtetra
.404 .09 .315 r
.47748 .59534 .47852 .59173 .48028 .59049 .47924 .59442 Mtetra
.464 .152 .351 r
.47924 .59442 .48028 .59049 .48204 .58998 .48099 .59391 Mtetra
.48099 .59391 .48204 .58998 .48379 .58945 .48275 .5934 Mtetra
.464 .152 .352 r
.48275 .5934 .48379 .58945 .48554 .58892 .4845 .59288 Mtetra
.465 .153 .352 r
.4845 .59288 .48554 .58892 .4873 .58841 .48626 .59237 Mtetra
.464 .153 .352 r
.48626 .59237 .4873 .58841 .48905 .5879 .48802 .59186 Mtetra
.48802 .59186 .48905 .5879 .49081 .58739 .48978 .59134 Mtetra
.464 .152 .352 r
.48978 .59134 .49081 .58739 .49257 .58688 .49154 .59083 Mtetra
.49154 .59083 .49257 .58688 .49433 .58636 .4933 .59031 Mtetra
.464 .152 .351 r
.4933 .59031 .49433 .58636 .49609 .58585 .49507 .58979 Mtetra
.463 .152 .351 r
.49507 .58979 .49609 .58585 .49785 .58533 .49683 .58927 Mtetra
.463 .151 .351 r
.49683 .58927 .49785 .58533 .49961 .58481 .4986 .58874 Mtetra
.4986 .58874 .49961 .58481 .50137 .58428 .50036 .58822 Mtetra
.50036 .58822 .50137 .58428 .50314 .58376 .50213 .58769 Mtetra
.50213 .58769 .50314 .58376 .5049 .58323 .5039 .58717 Mtetra
.5039 .58717 .5049 .58323 .50667 .58271 .50567 .58664 Mtetra
.50567 .58664 .50667 .58271 .50844 .58218 .50744 .58611 Mtetra
.50744 .58611 .50844 .58218 .51021 .58165 .50922 .58559 Mtetra
.50922 .58559 .51021 .58165 .51198 .58112 .51099 .58506 Mtetra
.462 .151 .351 r
.51099 .58506 .51198 .58112 .51375 .58059 .51276 .58453 Mtetra
.51276 .58453 .51375 .58059 .51552 .58005 .51454 .58399 Mtetra
.51454 .58399 .51552 .58005 .5173 .57951 .51632 .58346 Mtetra
.51632 .58346 .5173 .57951 .51907 .57898 .5181 .58292 Mtetra
.5181 .58292 .51907 .57898 .52085 .57843 .51988 .58239 Mtetra
.51988 .58239 .52085 .57843 .52263 .57789 .52166 .58185 Mtetra
.52166 .58185 .52263 .57789 .5244 .57735 .52344 .58131 Mtetra
.462 .151 .352 r
.52344 .58131 .5244 .57735 .52618 .5768 .52522 .58077 Mtetra
.52522 .58077 .52618 .5768 .52797 .57626 .52701 .58023 Mtetra
.463 .151 .352 r
.52701 .58023 .52797 .57626 .52975 .57573 .52879 .57969 Mtetra
.462 .151 .351 r
.52879 .57969 .52975 .57573 .53153 .5752 .53058 .57914 Mtetra
.461 .15 .351 r
.53058 .57914 .53153 .5752 .53331 .57467 .53236 .5786 Mtetra
.508 .191 .365 r
.53236 .5786 .53331 .57467 .5351 .57495 .53415 .57853 Mtetra
.462 .141 .334 r
.53415 .57853 .5351 .57495 .53689 .57457 .53595 .57807 Mtetra
.363 .05 .295 r
.53595 .57807 .53689 .57457 .53867 .57291 .53773 .57687 Mtetra
0 0 0 r
.53773 .57687 .53867 .57291 .53957 .37719 .5395 .57114 Mtetra
0 0 .334 r
.5395 .57114 .53957 .37719 .5412 .36603 .54032 .36839 Mtetra
.874 .831 .36 r
.54032 .36839 .5412 .36603 .54287 .36253 .54197 .3623 Mtetra
.801 .953 .917 r
.54197 .3623 .54287 .36253 .54454 .36148 .54365 .36106 Mtetra
.581 .868 .995 r
.54365 .36106 .54454 .36148 .54623 .36097 .54533 .36058 Mtetra
.364 .777 .98 r
.54533 .36058 .54623 .36097 .54791 .36074 .54702 .36045 Mtetra
.618 .911 .982 r
.54702 .36045 .54791 .36074 .5496 .36035 .54871 .35981 Mtetra
.675 .867 .972 r
.54871 .35981 .5496 .36035 .55129 .35996 .55039 .35914 Mtetra
.684 .798 .935 r
.55039 .35914 .55129 .35996 .55297 .35953 .55208 .35848 Mtetra
.666 .741 .907 r
.55208 .35848 .55297 .35953 .55466 .35888 .55377 .3579 Mtetra
.66 .755 .921 r
.55377 .3579 .55466 .35888 .55635 .35817 .55546 .35735 Mtetra
.654 .791 .947 r
.55546 .35735 .55635 .35817 .55804 .35745 .55715 .3568 Mtetra
.652 .834 .97 r
.55715 .3568 .55804 .35745 .55973 .3567 .55884 .35623 Mtetra
.631 .875 .987 r
.55884 .35623 .55973 .3567 .56142 .35607 .56053 .35565 Mtetra
.621 .884 .989 r
.56053 .35565 .56142 .35607 .56311 .35567 .56223 .35507 Mtetra
.646 .845 .976 r
.56223 .35507 .56311 .35567 .56482 .35613 .56392 .35449 Mtetra
.652 .642 .827 r
.56392 .35449 .56482 .35613 .56654 .35714 .56562 .35393 Mtetra
.617 .509 .709 r
.56562 .35393 .56654 .35714 .56826 .35865 .56732 .35336 Mtetra
.618 .46 .645 r
.56732 .35336 .56826 .35865 .56996 .35804 .56901 .35237 Mtetra
.6 .442 .639 r
.56901 .35237 .56996 .35804 .57166 .35715 .57071 .35164 Mtetra
.564 .419 .643 r
.57071 .35164 .57166 .35715 .57337 .35709 .57241 .35152 Mtetra
.253 .204 .607 r
.57241 .35152 .57337 .35709 .57806 .54604 .57417 .35481 Mtetra
0 0 .359 r
.57417 .35481 .57806 .54604 .58014 .5621 .57912 .55612 Mtetra
0 0 .453 r
.57912 .55612 .58014 .5621 .58202 .56514 .58106 .56303 Mtetra
.387 .458 .812 r
.58106 .56303 .58202 .56514 .58385 .56537 .5829 .56378 Mtetra
.619 .646 .855 r
.5829 .56378 .58385 .56537 .58567 .56482 .58472 .56338 Mtetra
.697 .7 .849 r
.58472 .56338 .58567 .56482 .58749 .56396 .58654 .56253 Mtetra
.651 .686 .87 r
.58654 .56253 .58749 .56396 .58931 .56351 .58836 .56197 Mtetra
.643 .665 .856 r
.58836 .56197 .58931 .56351 .59114 .56304 .59019 .56144 Mtetra
.648 .658 .846 r
.59019 .56144 .59114 .56304 .59296 .56234 .59202 .56087 Mtetra
.568 .643 .884 r
.59202 .56087 .59296 .56234 .59477 .56109 .59385 .5607 Mtetra
.498 .852 .992 r
.59385 .5607 .59477 .56109 .59657 .55916 .59568 .5603 Mtetra
.01 0 0 r
.59568 .5603 .59657 .55916 .59834 .55593 .5975 .55925 Mtetra
0 0 .024 r
.5975 .55925 .59834 .55593 .59611 .37332 .59925 .55483 Mtetra
0 0 .336 r
.59925 .55483 .59611 .37332 .59727 .34779 .59653 .35267 Mtetra
0 0 0 r
.59653 .35267 .59727 .34779 .59892 .34414 .59807 .34419 Mtetra
.884 .985 .816 r
.59807 .34419 .59892 .34414 .60062 .3429 .59975 .34227 Mtetra
.688 .852 .961 r
.59975 .34227 .60062 .3429 .60234 .34248 .60147 .34156 Mtetra
.576 .741 .954 r
.60147 .34156 .60234 .34248 .60407 .34238 .6032 .34128 Mtetra
.636 .724 .911 r
.6032 .34128 .60407 .34238 .60579 .34199 .60492 .34082 Mtetra
.651 .715 .895 r
.60492 .34082 .60579 .34199 .60752 .34145 .60664 .34029 Mtetra
.65 .719 .899 r
.60664 .34029 .60752 .34145 .60924 .34084 .60836 .33977 Mtetra
.668 .744 .907 r
.60836 .33977 .60924 .34084 .61095 .33998 .61009 .33917 Mtetra
.675 .804 .944 r
.61009 .33917 .61095 .33998 .61267 .33914 .61181 .33853 Mtetra
.663 .853 .973 r
.61181 .33853 .61267 .33914 .61439 .33852 .61353 .33789 Mtetra
.746 .868 .936 r
.61353 .33789 .61439 .33852 .61613 .33845 .61525 .33695 Mtetra
.69 .678 .834 r
.61525 .33695 .61613 .33845 .61789 .33905 .61697 .33616 Mtetra
.583 .505 .732 r
.61697 .33616 .61789 .33905 .61969 .34082 .61871 .33595 Mtetra
.308 .258 .638 r
.61871 .33595 .61969 .34082 .62201 .35951 .62054 .33848 Mtetra
.984 .7 .354 r
.62054 .33848 .62201 .35951 .6296 .54703 .62845 .53843 Mtetra
0 0 .463 r
.62845 .53843 .6296 .54703 .63156 .55008 .6306 .54764 Mtetra
.31 .382 .774 r
.6306 .54764 .63156 .55008 .63344 .55043 .63251 .54887 Mtetra
.607 .648 .865 r
.63251 .54887 .63344 .55043 .63529 .54976 .63437 .54852 Mtetra
.703 .739 .879 r
.63437 .54852 .63529 .54976 .63713 .54873 .63621 .54768 Mtetra
.675 .764 .918 r
.63621 .54768 .63713 .54873 .63899 .54821 .63807 .547 Mtetra
.649 .726 .905 r
.63807 .547 .63899 .54821 .64086 .54789 .63993 .54645 Mtetra
.653 .686 .869 r
.63993 .54645 .64086 .54789 .64271 .54737 .64178 .54586 Mtetra
.581 .645 .879 r
.64178 .54586 .64271 .54737 .64456 .54626 .64366 .54564 Mtetra
.523 .809 .998 r
.64366 .54564 .64456 .54626 .64637 .54443 .64553 .54533 Mtetra
0 0 0 r
.64553 .54533 .64637 .54443 .64814 .54139 .64738 .5444 Mtetra
0 0 .064 r
.64738 .5444 .64814 .54139 .64958 .52956 .64912 .54072 Mtetra
.983 .699 .389 r
.64912 .54072 .64958 .52956 .64403 .33272 .64352 .3409 Mtetra
0 0 .161 r
.64352 .3409 .64403 .33272 .64564 .32869 .64484 .32899 Mtetra
.902 .984 .725 r
.64484 .32899 .64564 .32869 .64735 .32717 .64651 .32659 Mtetra
.702 .875 .962 r
.64651 .32659 .64735 .32717 .6491 .32667 .64825 .3258 Mtetra
.583 .759 .962 r
.64825 .3258 .6491 .32667 .65086 .32653 .65001 .32548 Mtetra
.628 .734 .923 r
.65001 .32548 .65086 .32653 .65262 .32608 .65177 .32503 Mtetra
.664 .75 .914 r
.65177 .32503 .65262 .32608 .65436 .32541 .65352 .32444 Mtetra
.657 .766 .93 r
.65352 .32444 .65436 .32541 .65612 .32489 .65527 .32388 Mtetra
.72 .776 .897 r
.65527 .32388 .65612 .32489 .65789 .32476 .65701 .32302 Mtetra
.685 .649 .808 r
.65701 .32302 .65789 .32476 .65969 .32521 .65875 .32219 Mtetra
.591 .504 .725 r
.65875 .32219 .65969 .32521 .66153 .3267 .66052 .32189 Mtetra
.373 .305 .651 r
.66052 .32189 .66153 .3267 .66372 .33605 .66239 .32389 Mtetra
.981 .689 .359 r
.66239 .32389 .66372 .33605 .67429 .53313 .67291 .52131 Mtetra
0 0 .456 r
.67291 .52131 .67429 .53313 .67635 .53656 .67538 .53389 Mtetra
.234 .315 .743 r
.67538 .53389 .67635 .53656 .67829 .53741 .67736 .53562 Mtetra
.586 .61 .843 r
.67736 .53562 .67829 .53741 .68019 .53705 .67926 .53538 Mtetra
.678 .669 .834 r
.67926 .53538 .68019 .53705 .68205 .53612 .68114 .5346 Mtetra
.633 .669 .867 r
.68114 .5346 .68205 .53612 .68391 .5348 .68303 .53411 Mtetra
.545 .805 .993 r
.68303 .53411 .68391 .5348 .68573 .53297 .68492 .53377 Mtetra
0 0 0 r
.68492 .53377 .68573 .53297 .6875 .53 .6868 .53283 Mtetra
0 0 .088 r
.6868 .53283 .6875 .53 .68895 .52048 .68855 .52956 Mtetra
.982 .695 .375 r
.68855 .52956 .68895 .52048 .68094 .32063 .68103 .33845 Mtetra
0 0 .31 r
.68103 .33845 .68094 .32063 .68252 .3163 .68176 .31682 Mtetra
.893 .962 .632 r
.68176 .31682 .68252 .3163 .68422 .31436 .68342 .31398 Mtetra
.715 .931 .961 r
.68342 .31398 .68422 .31436 .68598 .31355 .68517 .31306 Mtetra
.551 .849 .998 r
.68517 .31306 .68598 .31355 .68776 .31325 .68695 .31264 Mtetra
.654 .856 .977 r
.68695 .31264 .68776 .31325 .68957 .31329 .68872 .31201 Mtetra
.703 .721 .863 r
.68872 .31201 .68957 .31329 .6914 .31375 .69048 .31118 Mtetra
.598 .534 .754 r
.69048 .31118 .6914 .31375 .69328 .31514 .69227 .31085 Mtetra
.405 .341 .672 r
.69227 .31085 .69328 .31514 .69541 .32111 .69416 .3124 Mtetra
0 0 .369 r
.69416 .3124 .69541 .32111 .70824 .52204 .69666 .32506 Mtetra
.01 0 .42 r
.69666 .32506 .70824 .52204 .71039 .52608 .7094 .52305 Mtetra
.18 .255 .705 r
.7094 .52305 .71039 .52608 .71239 .52719 .71146 .52532 Mtetra
.566 .591 .838 r
.71146 .52532 .71239 .52719 .71432 .52692 .7134 .52519 Mtetra
.666 .658 .832 r
.7134 .52519 .71432 .52692 .71621 .52606 .7153 .52447 Mtetra
.643 .665 .857 r
.7153 .52447 .71621 .52606 .71808 .52479 .71721 .52392 Mtetra
.551 .763 .976 r
.71721 .52392 .71808 .52479 .71992 .52307 .71913 .52363 Mtetra
0 0 0 r
.71913 .52363 .71992 .52307 .7217 .52035 .72103 .52279 Mtetra
0 0 .066 r
.72103 .52279 .7217 .52035 .72323 .51331 .72281 .52001 Mtetra
0 0 .091 r
.72281 .52001 .72323 .51331 .71302 .31096 .72404 .508 Mtetra
.007 0 .413 r
.72404 .508 .71302 .31096 .71455 .30603 .71384 .30681 Mtetra
.869 .922 .53 r
.71384 .30681 .71455 .30603 .71625 .30399 .71546 .30348 Mtetra
.741 .907 .951 r
.71546 .30348 .71625 .30399 .71804 .30336 .71723 .3025 Mtetra
.611 .778 .961 r
.71723 .3025 .71804 .30336 .71985 .30312 .71903 .30207 Mtetra
.6 .728 .934 r
.71903 .30207 .71985 .30312 .72166 .3028 .72084 .30172 Mtetra
.652 .743 .916 r
.72084 .30172 .72166 .3028 .72345 .30211 .72263 .30116 Mtetra
.645 .772 .941 r
.72263 .30116 .72345 .30211 .72523 .30138 .72443 .30063 Mtetra
.645 .82 .967 r
.72443 .30063 .72523 .30138 .72702 .30061 .72623 .30005 Mtetra
.644 .871 .983 r
.72623 .30005 .72702 .30061 .7288 .29985 .72803 .29941 Mtetra
.622 .896 .987 r
.72803 .29941 .7288 .29985 .7306 .29926 .72982 .29877 Mtetra
.691 .903 .972 r
.72982 .29877 .7306 .29926 .73242 .29903 .73161 .29795 Mtetra
.731 .774 .888 r
.73161 .29795 .73242 .29903 .73429 .29938 .73338 .29701 Mtetra
.621 .562 .767 r
.73338 .29701 .73429 .29938 .73621 .3006 .73519 .29652 Mtetra
.457 .383 .685 r
.73519 .29652 .73621 .3006 .73837 .3052 .73711 .29756 Mtetra
0 .008 .511 r
.73711 .29756 .73837 .3052 .75413 .50729 .73951 .30566 Mtetra
.033 0 .433 r
.73951 .30566 .75413 .50729 .75642 .51192 .75539 .50845 Mtetra
.138 .205 .67 r
.75539 .50845 .75642 .51192 .75849 .51326 .75757 .51137 Mtetra
.557 .586 .839 r
.75757 .51137 .75849 .51326 .76045 .51292 .75955 .51129 Mtetra
.667 .673 .846 r
.75955 .51129 .76045 .51292 .76237 .51213 .76148 .51057 Mtetra
.662 .68 .857 r
.76148 .51057 .76237 .51213 .7643 .51147 .76341 .50989 Mtetra
.566 .633 .877 r
.76341 .50989 .7643 .51147 .76628 .51132 .76538 .50973 Mtetra
.663 .678 .854 r
.76538 .50973 .76628 .51132 .76821 .51065 .76732 .50905 Mtetra
.827 .736 .764 r
.76732 .50905 .76821 .51065 .77003 .50837 .76914 .50681 Mtetra
.963 .737 .549 r
.76914 .50681 .77003 .50837 .77129 .4985 .77047 .49786 Mtetra
.978 .679 .364 r
.77047 .49786 .77129 .4985 .75792 .29329 .75718 .29306 Mtetra
.984 .88 .645 r
.75718 .29306 .75792 .29329 .7595 .28952 .75875 .28906 Mtetra
.743 .927 .951 r
.75875 .28906 .7595 .28952 .7613 .28873 .76053 .28804 Mtetra
.584 .816 .987 r
.76053 .28804 .7613 .28873 .76316 .28858 .76236 .28761 Mtetra
.564 .736 .956 r
.76236 .28761 .76316 .28858 .76502 .28856 .76421 .28735 Mtetra
.653 .722 .899 r
.76421 .28735 .76502 .28856 .76685 .28803 .76604 .28679 Mtetra
.651 .714 .894 r
.76604 .28679 .76685 .28803 .76867 .28745 .76786 .28623 Mtetra
.685 .733 .887 r
.76786 .28623 .76867 .28745 .77049 .28672 .76968 .2855 Mtetra
.743 .755 .863 r
.76968 .2855 .77049 .28672 .77228 .28574 .77147 .28444 Mtetra
.664 .708 .881 r
.77147 .28444 .77228 .28574 .7741 .28508 .77329 .28381 Mtetra
.29 .515 .899 r
.77329 .28381 .7741 .28508 .77599 .28527 .77522 .28448 Mtetra
.901 .503 .085 r
.77522 .28448 .77599 .28527 .77809 .28797 .77768 .29168 Mtetra
.973 .663 .35 r
.77768 .29168 .77809 .28797 .79594 .48275 .79628 .49609 Mtetra
.612 .344 .487 r
.79628 .49609 .79594 .48275 .79903 .49587 .79857 .49943 Mtetra
.498 .169 .34 r
.79857 .49943 .79903 .49587 .8012 .49779 .80057 .49931 Mtetra
.258 0 .047 r
.80057 .49931 .8012 .49779 .80327 .49851 .80252 .49852 Mtetra
.505 .911 .864 r
.80252 .49852 .80327 .49851 .80531 .49871 .80447 .49763 Mtetra
.513 .703 .956 r
.80447 .49763 .80531 .49871 .80733 .49875 .80648 .49753 Mtetra
.646 .735 .914 r
.80648 .49753 .80733 .49875 .80929 .49811 .80845 .49695 Mtetra
.833 .804 .823 r
.80845 .49695 .80929 .49811 .81115 .49613 .81032 .49511 Mtetra
.98 .77 .547 r
.81032 .49511 .81115 .49613 .81248 .48815 .81166 .48726 Mtetra
.977 .675 .344 r
.81166 .48726 .81248 .48815 .79643 .28156 .79564 .28051 Mtetra
.956 .793 .639 r
.79564 .28051 .79643 .28156 .79792 .27704 .79714 .27594 Mtetra
.748 .78 .879 r
.79714 .27594 .79792 .27704 .79973 .27599 .79894 .27487 Mtetra
.617 .727 .924 r
.79894 .27487 .79973 .27599 .80159 .27558 .8008 .27445 Mtetra
.578 .706 .93 r
.8008 .27445 .80159 .27558 .80346 .27532 .80268 .27418 Mtetra
.746 .773 .874 r
.80268 .27418 .80346 .27532 .80527 .27425 .80448 .27311 Mtetra
.672 .745 .906 r
.80448 .27311 .80527 .27425 .80711 .2736 .80632 .27245 Mtetra
.378 .594 .93 r
.80632 .27245 .80711 .2736 .80905 .27403 .80826 .27281 Mtetra
.809 .403 0 r
.80826 .27281 .80905 .27403 .81156 .28059 .8107 .27856 Mtetra
.973 .662 .312 r
.8107 .27856 .81156 .28059 .83264 .48663 .83174 .48475 Mtetra
0 0 .465 r
.83174 .48475 .83264 .48663 .83503 .49036 .83416 .48882 Mtetra
.53 .623 .889 r
.83416 .48882 .83503 .49036 .83705 .49016 .83621 .4888 Mtetra
.679 .725 .884 r
.83621 .4888 .83705 .49016 .83901 .48924 .83818 .48804 Mtetra
.731 .772 .886 r
.83818 .48804 .83901 .48924 .84096 .48814 .84013 .487 Mtetra
.549 .708 .945 r
.84013 .487 .84096 .48814 .84302 .48821 .84216 .48679 Mtetra
.655 .706 .884 r
.84216 .48679 .84302 .48821 .84503 .48786 .84416 .48616 Mtetra
.773 .714 .797 r
.84416 .48616 .84503 .48786 .84696 .48655 .84605 .48454 Mtetra
.941 .727 .584 r
.84605 .48454 .84696 .48655 .84842 .48043 .84743 .47757 Mtetra
.975 .669 .331 r
.84743 .47757 .84842 .48043 .82994 .2721 .82909 .27023 Mtetra
.924 .728 .621 r
.82909 .27023 .82994 .2721 .83127 .26615 .8305 .26501 Mtetra
.763 .782 .869 r
.8305 .26501 .83127 .26615 .83308 .26493 .83231 .26384 Mtetra
.634 .741 .925 r
.83231 .26384 .83308 .26493 .83495 .26445 .83418 .26334 Mtetra
.558 .702 .937 r
.83418 .26334 .83495 .26445 .83686 .26429 .83609 .26313 Mtetra
.752 .775 .872 r
.83609 .26313 .83686 .26429 .83868 .26318 .83791 .26201 Mtetra
.683 .747 .9 r
.83791 .26201 .83868 .26318 .84054 .26247 .83977 .26129 Mtetra
.472 .643 .931 r
.83977 .26129 .84054 .26247 .84248 .26258 .84171 .26139 Mtetra
.841 .445 0 r
.84171 .26139 .84248 .26258 .84515 .26968 .84437 .26842 Mtetra
.971 .656 .294 r
.84437 .26842 .84515 .26968 .86859 .47594 .86778 .47481 Mtetra
0 0 .452 r
.86778 .47481 .86859 .47594 .87099 .47907 .87018 .47797 Mtetra
.975 .789 .589 r
.87018 .47797 .87099 .47907 .87242 .47292 .87163 .47196 Mtetra
.974 .667 .312 r
.87163 .47196 .87242 .47292 .85231 .26378 .85156 .26278 Mtetra
.977 .793 .59 r
.85156 .26278 .85231 .26378 .85368 .25839 .85291 .25724 Mtetra
0 .295 .772 r
.24791 .45946 .24892 .46043 .25016 .46308 .2493 .46034 Mtetra
.77 .458 0 r
.2493 .46034 .25016 .46308 .23541 .65815 .25043 .46446 Mtetra
0 0 .188 r
.25043 .46446 .23541 .65815 .23631 .66599 .23577 .65873 Mtetra
.258 .172 .564 r
.23577 .65873 .23631 .66599 .23784 .66642 .23703 .66224 Mtetra
.376 .317 .664 r
.23703 .66224 .23784 .66642 .23944 .66602 .23848 .66364 Mtetra
.429 .448 .777 r
.23848 .66364 .23944 .66602 .24107 .66521 .24 .66423 Mtetra
.333 .615 .953 r
.24 .66423 .24107 .66521 .24264 .66516 .24154 .6645 Mtetra
.543 .786 .988 r
.24154 .6645 .24264 .66516 .24424 .66475 .24313 .66425 Mtetra
.742 .864 .937 r
.24313 .66425 .24424 .66475 .2459 .66361 .24477 .66336 Mtetra
.915 .839 .756 r
.24477 .66336 .2459 .66361 .24789 .65833 .24657 .66051 Mtetra
.99 .886 .569 r
.24657 .66051 .24789 .65833 .26506 .46107 .24865 .65404 Mtetra
0 0 .185 r
.24865 .65404 .26506 .46107 .26703 .45492 .26559 .45956 Mtetra
0 0 .05 r
.26559 .45956 .26703 .45492 .26862 .45355 .26741 .45518 Mtetra
0 0 0 r
.26741 .45518 .26862 .45355 .27014 .45301 .26907 .45295 Mtetra
.85 .939 .881 r
.26907 .45295 .27014 .45301 .27163 .45284 .27066 .45152 Mtetra
.696 .683 .833 r
.27066 .45152 .27163 .45284 .27315 .45241 .2722 .45078 Mtetra
.638 .621 .817 r
.2722 .45078 .27315 .45241 .27466 .45197 .27372 .45033 Mtetra
.61 .608 .824 r
.27372 .45033 .27466 .45197 .27618 .45154 .27523 .45003 Mtetra
.644 .639 .83 r
.27523 .45003 .27618 .45154 .2777 .45107 .27675 .44956 Mtetra
.647 .641 .83 r
.27675 .44956 .2777 .45107 .27923 .45057 .27827 .44908 Mtetra
.644 .642 .833 r
.27827 .44908 .27923 .45057 .28075 .45006 .27979 .44862 Mtetra
.629 .642 .844 r
.27979 .44862 .28075 .45006 .28228 .44955 .28131 .44823 Mtetra
.627 .661 .864 r
.28131 .44823 .28228 .44955 .28381 .44903 .28283 .44787 Mtetra
.631 .69 .886 r
.28283 .44787 .28381 .44903 .28534 .44849 .28435 .44748 Mtetra
.652 .725 .903 r
.28435 .44748 .28534 .44849 .28687 .44794 .28588 .44701 Mtetra
.667 .748 .911 r
.28588 .44701 .28687 .44794 .28841 .44737 .28741 .44648 Mtetra
.68 .758 .91 r
.28741 .44648 .28841 .44737 .28994 .44682 .28894 .4459 Mtetra
.7 .756 .895 r
.28894 .4459 .28994 .44682 .29147 .4463 .29049 .44522 Mtetra
.7 .724 .869 r
.29049 .44522 .29147 .4463 .29301 .4458 .29204 .44451 Mtetra
.689 .688 .844 r
.29204 .44451 .29301 .4458 .29454 .44529 .29358 .44382 Mtetra
.666 .654 .828 r
.29358 .44382 .29454 .44529 .29608 .44475 .29512 .44323 Mtetra
.657 .644 .825 r
.29512 .44323 .29608 .44475 .29761 .4442 .29666 .44268 Mtetra
.654 .644 .828 r
.29666 .44268 .29761 .4442 .29915 .44363 .2982 .44216 Mtetra
.656 .649 .831 r
.2982 .44216 .29915 .44363 .30069 .44308 .29974 .44162 Mtetra
.657 .652 .834 r
.29974 .44162 .30069 .44308 .30224 .44253 .30128 .44109 Mtetra
.656 .654 .836 r
.30128 .44109 .30224 .44253 .30378 .442 .30282 .44056 Mtetra
.694 .669 .821 r
.30282 .44056 .30378 .442 .30534 .44112 .30438 .43979 Mtetra
.68 .679 .843 r
.30438 .43979 .30534 .44112 .30689 .44043 .30593 .43915 Mtetra
.596 .656 .879 r
.30593 .43915 .30689 .44043 .30841 .44033 .30745 .4389 Mtetra
0 .096 .646 r
.30745 .4389 .30841 .44033 .30972 .44323 .30886 .4404 Mtetra
.815 .5 0 r
.30886 .4404 .30972 .44323 .29841 .63925 .31005 .44526 Mtetra
0 0 .233 r
.31005 .44526 .29841 .63925 .29953 .64672 .29891 .63916 Mtetra
.394 .273 .595 r
.29891 .63916 .29953 .64672 .30108 .64765 .30036 .64155 Mtetra
.583 .427 .635 r
.30036 .64155 .30108 .64765 .30272 .64722 .302 .64112 Mtetra
.629 .46 .635 r
.302 .64112 .30272 .64722 .30439 .64631 .30369 .6398 Mtetra
.622 .451 .629 r
.30369 .6398 .30439 .64631 .30604 .64566 .30538 .63852 Mtetra
.597 .427 .622 r
.30538 .63852 .30604 .64566 .30769 .64514 .30705 .63768 Mtetra
.553 .391 .617 r
.30705 .63768 .30769 .64514 .30933 .64464 .30866 .63772 Mtetra
.407 .29 .606 r
.30866 .63772 .30933 .64464 .31097 .64426 .31014 .63978 Mtetra
.33 .279 .648 r
.31014 .63978 .31097 .64426 .31261 .64392 .31165 .64163 Mtetra
.256 .351 .77 r
.31165 .64163 .31261 .64392 .31425 .64357 .3132 .64277 Mtetra
.323 .656 .971 r
.3132 .64277 .31425 .64357 .3159 .64312 .3148 .64296 Mtetra
.364 .816 .939 r
.3148 .64296 .3159 .64312 .31755 .64262 .31644 .64268 Mtetra
.389 .848 .876 r
.31644 .64268 .31755 .64262 .31921 .64208 .3181 .64219 Mtetra
.244 .759 .798 r
.3181 .64219 .31921 .64208 .32084 .64192 .31974 .64184 Mtetra
.459 .874 .942 r
.31974 .64184 .32084 .64192 .32248 .64165 .3214 .64137 Mtetra
.722 .919 .96 r
.3214 .64137 .32248 .64165 .32416 .6408 .32308 .64049 Mtetra
.905 .859 .785 r
.32308 .64049 .32416 .6408 .32599 .63721 .32485 .63803 Mtetra
.985 .864 .635 r
.32485 .63803 .32599 .63721 .33871 .44265 .32678 .6327 Mtetra
0 0 .227 r
.32678 .6327 .33871 .44265 .34091 .43106 .33948 .4379 Mtetra
.117 0 .292 r
.33948 .4379 .34091 .43106 .34256 .42889 .34128 .4334 Mtetra
.481 .186 .386 r
.34128 .4334 .34256 .42889 .34413 .42828 .34284 .43296 Mtetra
.517 .221 .404 r
.34284 .43296 .34413 .42828 .34567 .42812 .34438 .43288 Mtetra
.219 0 .287 r
.34438 .43288 .34567 .42812 .34723 .42771 .34606 .43033 Mtetra
0 0 0 r
.34606 .43033 .34723 .42771 .3488 .42708 .34775 .4275 Mtetra
.896 .985 .79 r
.34775 .4275 .3488 .42708 .35037 .42646 .3494 .42546 Mtetra
.752 .755 .855 r
.3494 .42546 .35037 .42646 .35194 .42591 .351 .42444 Mtetra
.636 .646 .843 r
.351 .42444 .35194 .42591 .35351 .4254 .35256 .42401 Mtetra
.596 .641 .865 r
.35256 .42401 .35351 .4254 .35508 .4249 .35412 .42377 Mtetra
.626 .697 .896 r
.35412 .42377 .35508 .4249 .35665 .42436 .35568 .42339 Mtetra
.663 .744 .91 r
.35568 .42339 .35665 .42436 .35822 .42378 .35725 .42287 Mtetra
.675 .758 .913 r
.35725 .42287 .35822 .42378 .3598 .42321 .35883 .42229 Mtetra
.732 .768 .881 r
.35883 .42229 .3598 .42321 .36139 .4224 .36042 .42143 Mtetra
.734 .758 .872 r
.36042 .42143 .36139 .4224 .36297 .42164 .36201 .42054 Mtetra
.657 .716 .891 r
.36201 .42054 .36297 .42164 .36453 .4214 .36358 .42003 Mtetra
.105 .379 .839 r
.36358 .42003 .36453 .4214 .36599 .42339 .36509 .42095 Mtetra
0 0 .247 r
.36509 .42095 .36599 .42339 .35822 .61553 .36646 .42467 Mtetra
0 0 .261 r
.36646 .42467 .35822 .61553 .35927 .62809 .35864 .61875 Mtetra
.295 .187 .557 r
.35864 .61875 .35927 .62809 .36084 .62973 .36008 .62313 Mtetra
.585 .423 .629 r
.36008 .62313 .36084 .62973 .36251 .62939 .36176 .6226 Mtetra
.605 .436 .626 r
.36176 .6226 .36251 .62939 .36421 .62854 .36346 .62162 Mtetra
.478 .343 .618 r
.36346 .62162 .36421 .62854 .3659 .62787 .36506 .62283 Mtetra
.347 .278 .636 r
.36506 .62283 .3659 .62787 .36757 .62752 .36662 .62484 Mtetra
.299 .346 .743 r
.36662 .62484 .36757 .62752 .36925 .62715 .36823 .62608 Mtetra
.272 .562 .933 r
.36823 .62608 .36925 .62715 .37092 .62695 .36987 .62652 Mtetra
.44 .808 .995 r
.36987 .62652 .37092 .62695 .3726 .6267 .37154 .62631 Mtetra
.695 .9 .97 r
.37154 .62631 .3726 .6267 .3743 .62587 .37324 .62553 Mtetra
.892 .877 .813 r
.37324 .62553 .3743 .62587 .37609 .62287 .375 .62339 Mtetra
.981 .863 .647 r
.375 .62339 .37609 .62287 .37861 .60305 .37688 .61845 Mtetra
.971 .712 .483 r
.37688 .61845 .37861 .60305 .38818 .41561 .38685 .42324 Mtetra
0 0 .234 r
.38685 .42324 .38818 .41561 .38986 .41285 .3887 .41665 Mtetra
.405 .1 .332 r
.3887 .41665 .38986 .41285 .39146 .41209 .39031 .4157 Mtetra
.514 .197 .367 r
.39031 .4157 .39146 .41209 .39304 .41185 .39189 .4157 Mtetra
.514 .203 .377 r
.39189 .4157 .39304 .41185 .39462 .41157 .39346 .41567 Mtetra
.468 .165 .368 r
.39346 .41567 .39462 .41157 .39622 .41105 .39506 .41516 Mtetra
.469 .167 .369 r
.39506 .41516 .39622 .41105 .39781 .41053 .39665 .41466 Mtetra
.466 .164 .369 r
.39665 .41466 .39781 .41053 .39941 .40999 .39825 .41413 Mtetra
.462 .161 .367 r
.39825 .41413 .39941 .40999 .401 .40944 .39985 .41356 Mtetra
.463 .161 .367 r
.39985 .41356 .401 .40944 .4026 .40889 .40146 .413 Mtetra
.413 .115 .347 r
.40146 .413 .4026 .40889 .40421 .40813 .40307 .41201 Mtetra
.384 .084 .328 r
.40307 .41201 .40421 .40813 .40582 .40728 .4047 .41088 Mtetra
.49 .174 .357 r
.4047 .41088 .40582 .40728 .40741 .40691 .40629 .41066 Mtetra
.752 .438 .453 r
.40629 .41066 .40741 .40691 .40895 .40833 .40772 .4149 Mtetra
.944 .674 .495 r
.40772 .4149 .40895 .40833 .41005 .42184 .40234 .61025 Mtetra
.553 .331 .532 r
.40234 .61025 .41005 .42184 .40494 .61394 .40387 .61454 Mtetra
.675 .199 .113 r
.40387 .61454 .40494 .61394 .40655 .61622 .40552 .61579 Mtetra
.483 .827 .998 r
.40552 .61579 .40655 .61622 .40825 .61601 .40722 .6155 Mtetra
.675 .87 .973 r
.40722 .6155 .40825 .61601 .40997 .61522 .40893 .6148 Mtetra
.646 .887 .984 r
.40893 .6148 .40997 .61522 .41168 .61443 .41065 .61416 Mtetra
.473 .857 .98 r
.41065 .61416 .41168 .61443 .41339 .61399 .41236 .61378 Mtetra
.565 .903 .978 r
.41236 .61378 .41339 .61399 .4151 .61354 .41407 .6132 Mtetra
.786 .92 .928 r
.41407 .6132 .4151 .61354 .41682 .61301 .41581 .61203 Mtetra
.851 .782 .783 r
.41581 .61203 .41682 .61301 .41854 .61239 .41758 .60987 Mtetra
.792 .639 .692 r
.41758 .60987 .41854 .61239 .42026 .61175 .41936 .60698 Mtetra
.699 .526 .65 r
.41936 .60698 .42026 .61175 .42197 .61136 .42114 .60454 Mtetra
.56 .404 .626 r
.42114 .60454 .42197 .61136 .42368 .61123 .42284 .60446 Mtetra
.578 .418 .627 r
.42284 .60446 .42368 .61123 .4254 .61061 .42455 .60403 Mtetra
.718 .519 .62 r
.42455 .60403 .4254 .61061 .42717 .6083 .42638 .59991 Mtetra
.947 .68 .498 r
.42638 .59991 .42717 .6083 .42917 .59782 .43365 .4029 Mtetra
.557 .338 .538 r
.43365 .4029 .42917 .59782 .4363 .40019 .43541 .39756 Mtetra
.761 .613 .694 r
.43541 .39756 .4363 .40019 .438 .39673 .43707 .39525 Mtetra
.689 .671 .827 r
.43707 .39525 .438 .39673 .43963 .39587 .4387 .3945 Mtetra
.619 .657 .865 r
.4387 .3945 .43963 .39587 .44124 .39558 .44032 .39414 Mtetra
.591 .635 .864 r
.44032 .39414 .44124 .39558 .44286 .39538 .44193 .39391 Mtetra
.62 .643 .852 r
.44193 .39391 .44286 .39538 .44448 .39484 .44355 .39355 Mtetra
.617 .672 .88 r
.44355 .39355 .44448 .39484 .4461 .39429 .44517 .39321 Mtetra
.625 .712 .909 r
.44517 .39321 .4461 .39429 .44773 .39377 .44679 .39281 Mtetra
.649 .749 .923 r
.44679 .39281 .44773 .39377 .44935 .39326 .44841 .39232 Mtetra
.664 .758 .92 r
.44841 .39232 .44935 .39326 .45098 .39275 .45004 .39177 Mtetra
.681 .753 .906 r
.45004 .39177 .45098 .39275 .4526 .39223 .45167 .39115 Mtetra
.696 .737 .883 r
.45167 .39115 .4526 .39223 .45423 .39168 .4533 .39044 Mtetra
.692 .708 .86 r
.4533 .39044 .45423 .39168 .45586 .39111 .45494 .38972 Mtetra
.688 .683 .839 r
.45494 .38972 .45586 .39111 .45749 .39053 .45657 .38899 Mtetra
.685 .661 .821 r
.45657 .38899 .45749 .39053 .45913 .38993 .45821 .38824 Mtetra
.651 .629 .815 r
.45821 .38824 .45913 .38993 .46076 .38934 .45984 .38768 Mtetra
.565 .593 .84 r
.45984 .38768 .46076 .38934 .46239 .38878 .46147 .38758 Mtetra
.078 .396 .853 r
.46147 .38758 .46239 .38878 .46403 .38831 .46307 .38848 Mtetra
.741 .245 .053 r
.46307 .38848 .46403 .38831 .46566 .38785 .46467 .39011 Mtetra
.685 .325 .359 r
.46467 .39011 .46566 .38785 .4673 .38724 .46627 .3919 Mtetra
.434 .146 .374 r
.46627 .3919 .4673 .38724 .46894 .38628 .46791 .39092 Mtetra
.456 .165 .381 r
.46791 .39092 .46894 .38628 .47058 .38573 .46956 .39016 Mtetra
.644 .334 .432 r
.46956 .39016 .47058 .38573 .4722 .38639 .47116 .39204 Mtetra
.952 .675 .476 r
.47116 .39204 .4722 .38639 .47372 .39347 .46961 .58877 Mtetra
.554 .332 .532 r
.46961 .58877 .47372 .39347 .47229 .59272 .47127 .59391 Mtetra
.713 .295 .251 r
.47127 .59391 .47229 .59272 .47398 .59607 .47298 .59566 Mtetra
.414 .805 .988 r
.47298 .59566 .47398 .59607 .47572 .59603 .47473 .59545 Mtetra
.657 .857 .976 r
.47473 .59545 .47572 .59603 .47748 .59534 .47648 .59482 Mtetra
.683 .876 .971 r
.47648 .59482 .47748 .59534 .47924 .59442 .47824 .59408 Mtetra
.487 .851 .99 r
.47824 .59408 .47924 .59442 .48099 .59391 .48 .5937 Mtetra
.423 .845 .958 r
.48 .5937 .48099 .59391 .48275 .5934 .48175 .59333 Mtetra
.362 .828 .901 r
.48175 .59333 .48275 .5934 .4845 .59288 .48351 .59293 Mtetra
.349 .826 .854 r
.48351 .59293 .4845 .59288 .48626 .59237 .48527 .59245 Mtetra
.351 .827 .844 r
.48527 .59245 .48626 .59237 .48802 .59186 .48703 .59193 Mtetra
.359 .832 .847 r
.48703 .59193 .48802 .59186 .48978 .59134 .48879 .59141 Mtetra
.358 .831 .851 r
.48879 .59141 .48978 .59134 .49154 .59083 .49055 .59089 Mtetra
.358 .831 .85 r
.49055 .59089 .49154 .59083 .4933 .59031 .49231 .59037 Mtetra
.359 .832 .85 r
.49231 .59037 .4933 .59031 .49507 .58979 .49408 .58985 Mtetra
.36 .832 .85 r
.49408 .58985 .49507 .58979 .49683 .58927 .49584 .58933 Mtetra
.36 .833 .85 r
.49584 .58933 .49683 .58927 .4986 .58874 .49761 .58881 Mtetra
.361 .833 .85 r
.49761 .58881 .4986 .58874 .50036 .58822 .49938 .58829 Mtetra
.49938 .58829 .50036 .58822 .50213 .58769 .50115 .58776 Mtetra
.362 .834 .85 r
.50115 .58776 .50213 .58769 .5039 .58717 .50292 .58723 Mtetra
.50292 .58723 .5039 .58717 .50567 .58664 .50469 .58671 Mtetra
.363 .834 .851 r
.50469 .58671 .50567 .58664 .50744 .58611 .50646 .58618 Mtetra
.50646 .58618 .50744 .58611 .50922 .58559 .50824 .58565 Mtetra
.364 .835 .851 r
.50824 .58565 .50922 .58559 .51099 .58506 .51001 .58512 Mtetra
.51001 .58512 .51099 .58506 .51276 .58453 .51179 .58459 Mtetra
.365 .836 .852 r
.51179 .58459 .51276 .58453 .51454 .58399 .51357 .58405 Mtetra
.366 .836 .852 r
.51357 .58405 .51454 .58399 .51632 .58346 .51534 .58352 Mtetra
.368 .837 .853 r
.51534 .58352 .51632 .58346 .5181 .58292 .51712 .58298 Mtetra
.369 .838 .854 r
.51712 .58298 .5181 .58292 .51988 .58239 .51891 .58245 Mtetra
.372 .839 .855 r
.51891 .58245 .51988 .58239 .52166 .58185 .52069 .5819 Mtetra
.365 .835 .854 r
.52069 .5819 .52166 .58185 .52344 .58131 .52247 .58137 Mtetra
.369 .838 .85 r
.52247 .58137 .52344 .58131 .52522 .58077 .52425 .58083 Mtetra
.393 .851 .859 r
.52425 .58083 .52522 .58077 .52701 .58023 .52604 .58025 Mtetra
.474 .893 .893 r
.52604 .58025 .52701 .58023 .52879 .57969 .52783 .57958 Mtetra
.551 .918 .946 r
.52783 .57958 .52879 .57969 .53058 .57914 .52961 .57889 Mtetra
.6 .916 .976 r
.52961 .57889 .53058 .57914 .53236 .5786 .5314 .57822 Mtetra
.423 .816 .986 r
.5314 .57822 .53236 .5786 .53415 .57853 .53319 .57797 Mtetra
.591 .845 .993 r
.53319 .57797 .53415 .57853 .53595 .57807 .53498 .57749 Mtetra
.74 .876 .943 r
.53498 .57749 .53595 .57807 .53773 .57687 .53678 .57652 Mtetra
.947 .859 .72 r
.53678 .57652 .53773 .57687 .5395 .57114 .53856 .57312 Mtetra
.979 .851 .46 r
.53856 .57312 .5395 .57114 .54032 .36839 .54032 .56528 Mtetra
0 0 .349 r
.54032 .56528 .54032 .36839 .54197 .3623 .5411 .36697 Mtetra
.381 .102 .359 r
.5411 .36697 .54197 .3623 .54365 .36106 .54278 .36544 Mtetra
.498 .197 .386 r
.54278 .36544 .54365 .36106 .54533 .36058 .54447 .36517 Mtetra
.5 .203 .393 r
.54447 .36517 .54533 .36058 .54702 .36045 .54616 .3649 Mtetra
.118 0 .259 r
.54616 .3649 .54702 .36045 .54871 .35981 .54783 .36156 Mtetra
0 0 0 r
.54783 .36156 .54871 .35981 .55039 .35914 .5495 .35897 Mtetra
.895 .944 .834 r
.5495 .35897 .55039 .35914 .55208 .35848 .55118 .35707 Mtetra
.705 .693 .836 r
.55118 .35707 .55208 .35848 .55377 .3579 .55287 .35621 Mtetra
.646 .632 .822 r
.55287 .35621 .55377 .3579 .55546 .35735 .55456 .35567 Mtetra
.618 .62 .83 r
.55456 .35567 .55546 .35735 .55715 .3568 .55625 .35529 Mtetra
.626 .646 .85 r
.55625 .35529 .55715 .3568 .55884 .35623 .55795 .35488 Mtetra
.629 .673 .873 r
.55795 .35488 .55884 .35623 .56053 .35565 .55964 .35446 Mtetra
.639 .706 .895 r
.55964 .35446 .56053 .35565 .56223 .35507 .56134 .354 Mtetra
.69 .747 .895 r
.56134 .354 .56223 .35507 .56392 .35449 .56303 .3533 Mtetra
.698 .727 .872 r
.56303 .3533 .56392 .35449 .56562 .35393 .56473 .35254 Mtetra
.69 .692 .847 r
.56473 .35254 .56562 .35393 .56732 .35336 .56642 .35178 Mtetra
.704 .671 .816 r
.56642 .35178 .56732 .35336 .56901 .35237 .56811 .35088 Mtetra
.675 .671 .838 r
.56811 .35088 .56901 .35237 .57071 .35164 .56981 .35019 Mtetra
.592 .641 .868 r
.56981 .35019 .57071 .35164 .57241 .35152 .57152 .34994 Mtetra
.007 .272 .773 r
.57152 .34994 .57241 .35152 .57417 .35481 .57325 .35139 Mtetra
0 0 .459 r
.57325 .35139 .57417 .35481 .57912 .55612 .57503 .35591 Mtetra
0 0 .377 r
.57503 .35591 .57912 .55612 .58106 .56303 .58 .55518 Mtetra
.27 .192 .58 r
.58 .55518 .58106 .56303 .5829 .56378 .5819 .55961 Mtetra
.385 .336 .68 r
.5819 .55961 .5829 .56378 .58472 .56338 .58376 .56118 Mtetra
.428 .475 .806 r
.58376 .56118 .58472 .56338 .58654 .56253 .5856 .56179 Mtetra
.496 .764 .991 r
.5856 .56179 .58654 .56253 .58836 .56197 .58744 .56161 Mtetra
.558 .884 .989 r
.58744 .56161 .58836 .56197 .59019 .56144 .58926 .56107 Mtetra
.633 .909 .983 r
.58926 .56107 .59019 .56144 .59202 .56087 .59109 .56036 Mtetra
.478 .816 .999 r
.59109 .56036 .59202 .56087 .59385 .5607 .59292 .56009 Mtetra
.558 .824 .995 r
.59292 .56009 .59385 .5607 .59568 .5603 .59476 .5597 Mtetra
.707 .872 .959 r
.59476 .5597 .59568 .5603 .5975 .55925 .59658 .55885 Mtetra
.925 .892 .778 r
.59658 .55885 .5975 .55925 .59925 .55483 .59837 .55625 Mtetra
.95 .883 .481 r
.59837 .55625 .59925 .55483 .59653 .35267 .60009 .55069 Mtetra
0 0 .372 r
.60009 .55069 .59653 .35267 .59807 .34419 .59735 .35025 Mtetra
0 0 .254 r
.59735 .35025 .59807 .34419 .59975 .34227 .59895 .34426 Mtetra
0 0 0 r
.59895 .34426 .59975 .34227 .60147 .34156 .60062 .34167 Mtetra
.823 .999 .835 r
.60062 .34167 .60147 .34156 .6032 .34128 .60232 .34004 Mtetra
.705 .725 .865 r
.60232 .34004 .6032 .34128 .60492 .34082 .60403 .33923 Mtetra
.625 .638 .843 r
.60403 .33923 .60492 .34082 .60664 .34029 .60576 .33881 Mtetra
.591 .638 .866 r
.60576 .33881 .60664 .34029 .60836 .33977 .60749 .33857 Mtetra
.637 .705 .896 r
.60749 .33857 .60836 .33977 .61009 .33917 .60922 .3381 Mtetra
.668 .744 .908 r
.60922 .3381 .61009 .33917 .61181 .33853 .61094 .33751 Mtetra
.681 .757 .909 r
.61094 .33751 .61181 .33853 .61353 .33789 .61267 .33685 Mtetra
.744 .771 .875 r
.61267 .33685 .61353 .33789 .61525 .33695 .61438 .33584 Mtetra
.729 .756 .874 r
.61438 .33584 .61525 .33695 .61697 .33616 .6161 .33491 Mtetra
.647 .702 .887 r
.6161 .33491 .61697 .33616 .61871 .33595 .61783 .3344 Mtetra
.195 .404 .839 r
.61783 .3344 .61871 .33595 .62054 .33848 .61961 .33543 Mtetra
0 0 .552 r
.61961 .33543 .62054 .33848 .62845 .53843 .62147 .3391 Mtetra
0 0 .394 r
.62147 .3391 .62845 .53843 .6306 .54764 .62942 .53828 Mtetra
.233 .156 .559 r
.62942 .53828 .6306 .54764 .63251 .54887 .63147 .54424 Mtetra
.386 .325 .666 r
.63147 .54424 .63251 .54887 .63437 .54852 .6334 .54602 Mtetra
.437 .454 .78 r
.6334 .54602 .63437 .54852 .63621 .54768 .6353 .5467 Mtetra
.543 .73 .961 r
.6353 .5467 .63621 .54768 .63807 .547 .63717 .54649 Mtetra
.644 .883 .984 r
.63717 .54649 .63807 .547 .63993 .54645 .63902 .54581 Mtetra
.708 .869 .958 r
.63902 .54581 .63993 .54645 .64178 .54586 .64087 .54495 Mtetra
.567 .757 .967 r
.64087 .54495 .64178 .54586 .64366 .54564 .64274 .54465 Mtetra
.534 .725 .962 r
.64274 .54465 .64366 .54564 .64553 .54533 .64462 .54447 Mtetra
.652 .803 .956 r
.64462 .54447 .64553 .54533 .64738 .5444 .64648 .54387 Mtetra
.898 .891 .815 r
.64648 .54387 .64738 .5444 .64912 .54072 .64829 .54167 Mtetra
.964 .9 .529 r
.64829 .54167 .64912 .54072 .64352 .3409 .64999 .53668 Mtetra
0 0 .387 r
.64999 .53668 .64352 .3409 .64484 .32899 .64431 .33664 Mtetra
0 0 .302 r
.64431 .33664 .64484 .32899 .64651 .32659 .6458 .32915 Mtetra
0 0 .093 r
.6458 .32915 .64651 .32659 .64825 .3258 .64747 .32649 Mtetra
.544 .856 .555 r
.64747 .32649 .64825 .3258 .65001 .32548 .64917 .32482 Mtetra
.753 .866 .931 r
.64917 .32482 .65001 .32548 .65177 .32503 .65091 .32383 Mtetra
.666 .719 .889 r
.65091 .32383 .65177 .32503 .65352 .32444 .65266 .32322 Mtetra
.634 .704 .896 r
.65266 .32322 .65352 .32444 .65527 .32388 .65442 .32277 Mtetra
.715 .754 .883 r
.65442 .32277 .65527 .32388 .65701 .32302 .65616 .32191 Mtetra
.735 .762 .875 r
.65616 .32191 .65701 .32302 .65875 .32219 .6579 .32095 Mtetra
.659 .711 .886 r
.6579 .32095 .65875 .32219 .66052 .32189 .65965 .32037 Mtetra
.299 .473 .864 r
.65965 .32037 .66052 .32189 .66239 .32389 .66147 .32113 Mtetra
0 .033 .59 r
.66147 .32113 .66239 .32389 .67291 .52131 .6634 .32445 Mtetra
0 0 .407 r
.6634 .32445 .67291 .52131 .67538 .53389 .67405 .52343 Mtetra
.207 .133 .547 r
.67405 .52343 .67538 .53389 .67736 .53562 .67629 .53071 Mtetra
.386 .319 .659 r
.67629 .53071 .67736 .53562 .67926 .53538 .67828 .53263 Mtetra
.436 .437 .762 r
.67828 .53263 .67926 .53538 .68114 .5346 .68023 .53341 Mtetra
.433 .631 .938 r
.68023 .53341 .68114 .5346 .68303 .53411 .68215 .53361 Mtetra
.473 .82 .998 r
.68215 .53361 .68303 .53411 .68492 .53377 .68406 .53331 Mtetra
.692 .913 .971 r
.68406 .53331 .68492 .53377 .6868 .53283 .68593 .53243 Mtetra
.903 .924 .821 r
.68593 .53243 .6868 .53283 .68855 .52956 .68774 .53026 Mtetra
.971 .905 .553 r
.68774 .53026 .68855 .52956 .68103 .33845 .68943 .52551 Mtetra
0 0 .388 r
.68943 .52551 .68103 .33845 .68176 .31682 .68142 .32574 Mtetra
0 0 .322 r
.68142 .32574 .68176 .31682 .68342 .31398 .68277 .31671 Mtetra
0 0 .129 r
.68277 .31671 .68342 .31398 .68517 .31306 .68443 .31391 Mtetra
0 0 0 r
.68443 .31391 .68517 .31306 .68695 .31264 .68614 .31214 Mtetra
.818 .915 .903 r
.68614 .31214 .68695 .31264 .68872 .31201 .68788 .31079 Mtetra
.734 .745 .861 r
.68788 .31079 .68872 .31201 .69048 .31118 .68963 .30979 Mtetra
.639 .679 .872 r
.68963 .30979 .69048 .31118 .69227 .31085 .69141 .3093 Mtetra
.358 .503 .867 r
.69141 .3093 .69227 .31085 .69416 .3124 .69325 .30992 Mtetra
0 .103 .643 r
.69325 .30992 .69416 .3124 .69666 .32506 .69521 .31274 Mtetra
.98 .685 .34 r
.69521 .31274 .69666 .32506 .7094 .52305 .70777 .50831 Mtetra
.155 .082 .515 r
.70777 .50831 .7094 .52305 .71146 .52532 .71034 .51996 Mtetra
.377 .305 .648 r
.71034 .51996 .71146 .52532 .7134 .52519 .7124 .52218 Mtetra
.43 .419 .745 r
.7124 .52218 .7134 .52519 .7153 .52447 .71439 .52309 Mtetra
.44 .598 .911 r
.71439 .52309 .7153 .52447 .71721 .52392 .71635 .52336 Mtetra
.455 .798 .998 r
.71635 .52336 .71721 .52392 .71913 .52363 .71828 .52313 Mtetra
.67 .9 .978 r
.71828 .52313 .71913 .52363 .72103 .52279 .72019 .52233 Mtetra
.881 .925 .848 r
.72019 .52233 .72103 .52279 .72281 .52001 .72202 .52039 Mtetra
.977 .916 .6 r
.72202 .52039 .72281 .52001 .72404 .508 .72371 .51612 Mtetra
.981 .691 .36 r
.72371 .51612 .72404 .508 .71384 .30681 .71417 .32494 Mtetra
.006 0 .374 r
.71417 .32494 .71384 .30681 .71546 .30348 .71488 .30638 Mtetra
0 0 .141 r
.71488 .30638 .71546 .30348 .71723 .3025 .71651 .30319 Mtetra
.594 .867 .536 r
.71651 .30319 .71723 .3025 .71903 .30207 .71822 .30127 Mtetra
.773 .844 .906 r
.71822 .30127 .71903 .30207 .72084 .30172 .71999 .30015 Mtetra
.643 .655 .847 r
.71999 .30015 .72084 .30172 .72263 .30116 .72178 .29962 Mtetra
.6 .638 .86 r
.72178 .29962 .72263 .30116 .72443 .30063 .7236 .29932 Mtetra
.606 .68 .893 r
.7236 .29932 .72443 .30063 .72623 .30005 .72541 .29897 Mtetra
.657 .747 .916 r
.72541 .29897 .72623 .30005 .72803 .29941 .72721 .2984 Mtetra
.672 .766 .921 r
.72721 .2984 .72803 .29941 .72982 .29877 .72901 .29776 Mtetra
.719 .783 .903 r
.72901 .29776 .72982 .29877 .73161 .29795 .73079 .29688 Mtetra
.751 .781 .878 r
.73079 .29688 .73161 .29795 .73338 .29701 .73256 .29582 Mtetra
.688 .737 .888 r
.73256 .29582 .73338 .29701 .73519 .29652 .73435 .29509 Mtetra
.463 .585 .89 r
.73435 .29509 .73519 .29652 .73711 .29756 .73621 .29532 Mtetra
0 .164 .687 r
.73621 .29532 .73711 .29756 .73951 .30566 .73823 .29777 Mtetra
0 0 .323 r
.73823 .29777 .73951 .30566 .75539 .50845 .74101 .31133 Mtetra
.047 0 .437 r
.74101 .31133 .75539 .50845 .75757 .51137 .75636 .50525 Mtetra
.396 .306 .636 r
.75636 .50525 .75757 .51137 .75955 .51129 .7585 .50761 Mtetra
.459 .406 .712 r
.7585 .50761 .75955 .51129 .76148 .51057 .76055 .50853 Mtetra
.496 .536 .827 r
.76055 .50853 .76148 .51057 .76341 .50989 .76255 .50879 Mtetra
.535 .706 .949 r
.76255 .50879 .76341 .50989 .76538 .50973 .76452 .50863 Mtetra
.678 .768 .919 r
.76452 .50863 .76538 .50973 .76732 .50905 .76646 .50791 Mtetra
.822 .801 .832 r
.76646 .50791 .76732 .50905 .76914 .50681 .76832 .50618 Mtetra
.966 .849 .674 r
.76832 .50618 .76914 .50681 .77047 .49786 .77001 .50214 Mtetra
.869 .709 .186 r
.77001 .50214 .77047 .49786 .75718 .29306 .77085 .48668 Mtetra
.043 0 .431 r
.77085 .48668 .75718 .29306 .75875 .28906 .75829 .29257 Mtetra
.088 0 .237 r
.75829 .29257 .75875 .28906 .76053 .28804 .75991 .28933 Mtetra
0 0 0 r
.75991 .28933 .76053 .28804 .76236 .28761 .76163 .28739 Mtetra
.767 .978 .916 r
.76163 .28739 .76236 .28761 .76421 .28735 .7634 .28614 Mtetra
.682 .733 .889 r
.7634 .28614 .76421 .28735 .76604 .28679 .76521 .28543 Mtetra
.638 .688 .88 r
.76521 .28543 .76604 .28679 .76786 .28623 .76705 .28493 Mtetra
.662 .709 .883 r
.76705 .28493 .76786 .28623 .76968 .2855 .76887 .28432 Mtetra
.747 .761 .865 r
.76887 .28432 .76968 .2855 .77147 .28444 .77066 .28323 Mtetra
.663 .727 .897 r
.77066 .28323 .77147 .28444 .77329 .28381 .77248 .28261 Mtetra
.227 .492 .897 r
.77248 .28261 .77329 .28381 .77522 .28448 .77442 .28338 Mtetra
.913 .535 .107 r
.77442 .28338 .77522 .28448 .77768 .29168 .77703 .29242 Mtetra
.974 .666 .341 r
.77703 .29242 .77768 .29168 .79628 .49609 .79552 .49597 Mtetra
.779 .274 0 r
.79552 .49597 .79628 .49609 .79857 .49943 .79778 .49896 Mtetra
.464 .83 .993 r
.79778 .49896 .79857 .49943 .80057 .49931 .79977 .49863 Mtetra
.732 .882 .95 r
.79977 .49863 .80057 .49931 .80252 .49852 .8017 .49762 Mtetra
.736 .834 .925 r
.8017 .49762 .80252 .49852 .80447 .49763 .80363 .4966 Mtetra
.463 .687 .963 r
.80363 .4966 .80447 .49763 .80648 .49753 .80566 .49663 Mtetra
.591 .781 .97 r
.80566 .49663 .80648 .49753 .80845 .49695 .80764 .49621 Mtetra
.84 .886 .873 r
.80764 .49621 .80845 .49695 .81032 .49511 .80952 .49455 Mtetra
.992 .8 .546 r
.80952 .49455 .81032 .49511 .81166 .48726 .81093 .48742 Mtetra
.977 .675 .341 r
.81093 .48742 .81166 .48726 .79564 .28051 .79488 .27975 Mtetra
.976 .814 .617 r
.79488 .27975 .79564 .28051 .79714 .27594 .79635 .27483 Mtetra
.753 .781 .877 r
.79635 .27483 .79714 .27594 .79894 .27487 .79815 .27373 Mtetra
.619 .724 .921 r
.79815 .27373 .79894 .27487 .8008 .27445 .80001 .2733 Mtetra
.579 .704 .927 r
.80001 .2733 .8008 .27445 .80268 .27418 .80189 .27303 Mtetra
.749 .773 .873 r
.80189 .27303 .80268 .27418 .80448 .27311 .80369 .27195 Mtetra
.674 .743 .902 r
.80369 .27195 .80448 .27311 .80632 .27245 .80554 .27127 Mtetra
.386 .594 .928 r
.80554 .27127 .80632 .27245 .80826 .27281 .80747 .27162 Mtetra
.811 .402 0 r
.80747 .27162 .80826 .27281 .8107 .27856 .8099 .27732 Mtetra
.973 .662 .315 r
.8099 .27732 .8107 .27856 .83174 .48475 .83091 .48363 Mtetra
.698 .258 0 r
.83091 .48363 .83174 .48475 .83416 .48882 .83334 .48774 Mtetra
.44 .665 .957 r
.83334 .48774 .83416 .48882 .83621 .4888 .8354 .48786 Mtetra
.68 .809 .944 r
.8354 .48786 .83621 .4888 .83818 .48804 .83737 .4871 Mtetra
.793 .843 .889 r
.83737 .4871 .83818 .48804 .84013 .487 .83929 .48572 Mtetra
.803 .783 .834 r
.83929 .48572 .84013 .487 .84216 .48679 .84119 .4841 Mtetra
.776 .637 .708 r
.84119 .4841 .84216 .48679 .84416 .48616 .84301 .48164 Mtetra
.787 .585 .627 r
.84301 .48164 .84416 .48616 .84605 .48454 .84461 .47703 Mtetra
.974 .667 .347 r
.84461 .47703 .84605 .48454 .84743 .47757 .82686 .2739 Mtetra
.558 .338 .537 r
.82686 .2739 .84743 .47757 .82909 .27023 .82809 .2668 Mtetra
.767 .594 .664 r
.82809 .2668 .82909 .27023 .8305 .26501 .82972 .26383 Mtetra
.729 .763 .88 r
.82972 .26383 .8305 .26501 .83231 .26384 .83155 .26285 Mtetra
.638 .77 .943 r
.83155 .26285 .83231 .26384 .83418 .26334 .83343 .26232 Mtetra
.599 .745 .947 r
.83343 .26232 .83418 .26334 .83609 .26313 .83532 .26194 Mtetra
.771 .776 .858 r
.83532 .26194 .83609 .26313 .83791 .26201 .83712 .26069 Mtetra
.702 .727 .869 r
.83712 .26069 .83791 .26201 .83977 .26129 .83897 .25983 Mtetra
.536 .625 .887 r
.83897 .25983 .83977 .26129 .84171 .26139 .8409 .2598 Mtetra
.748 .368 0 r
.8409 .2598 .84171 .26139 .84437 .26842 .84347 .26596 Mtetra
.97 .657 .29 r
.84347 .26596 .84437 .26842 .86778 .47481 .86694 .47337 Mtetra
0 0 .483 r
.86694 .47337 .86778 .47481 .87018 .47797 .86937 .47685 Mtetra
.971 .794 .606 r
.86937 .47685 .87018 .47797 .87163 .47196 .87087 .47129 Mtetra
.974 .667 .311 r
.87087 .47129 .87163 .47196 .85156 .26278 .85085 .26214 Mtetra
.993 .808 .554 r
.85085 .26214 .85156 .26278 .85291 .25724 .85215 .25604 Mtetra
.667 .735 .901 r
.24691 .45849 .24791 .45946 .2493 .46034 .24842 .45796 Mtetra
.406 .421 .763 r
.24842 .45796 .2493 .46034 .25043 .46446 .24983 .45863 Mtetra
.3 .218 .593 r
.24983 .45863 .25043 .46446 .23577 .65873 .25109 .46116 Mtetra
0 0 .219 r
.25109 .46116 .23577 .65873 .23703 .66224 .23692 .64972 Mtetra
0 0 .349 r
.23692 .64972 .23703 .66224 .23848 .66364 .23758 .66058 Mtetra
0 0 .56 r
.23758 .66058 .23848 .66364 .24 .66423 .23893 .66323 Mtetra
.278 .581 .942 r
.23893 .66323 .24 .66423 .24154 .6645 .24047 .6636 Mtetra
.602 .745 .945 r
.24047 .6636 .24154 .6645 .24313 .66425 .24206 .66326 Mtetra
.725 .757 .878 r
.24206 .66326 .24313 .66425 .24477 .66336 .2437 .66241 Mtetra
.78 .767 .841 r
.2437 .66241 .24477 .66336 .24657 .66051 .24537 .66113 Mtetra
.866 .996 .785 r
.24537 .66113 .24657 .66051 .24865 .65404 .2471 .65912 Mtetra
.027 0 .19 r
.2471 .65912 .24865 .65404 .26559 .45956 .24896 .65551 Mtetra
0 0 .201 r
.24896 .65551 .26559 .45956 .26741 .45518 .26577 .4624 Mtetra
0 0 0 r
.26577 .4624 .26741 .45518 .26907 .45295 .26793 .45369 Mtetra
.961 .937 .71 r
.26793 .45369 .26907 .45295 .27066 .45152 .26966 .45057 Mtetra
.757 .758 .854 r
.26966 .45057 .27066 .45152 .2722 .45078 .27122 .44954 Mtetra
.647 .682 .869 r
.27122 .44954 .2722 .45078 .27372 .45033 .27274 .44909 Mtetra
.58 .656 .889 r
.27274 .44909 .27372 .45033 .27523 .45003 .27424 .44891 Mtetra
.646 .701 .886 r
.27424 .44891 .27523 .45003 .27675 .44956 .27576 .44846 Mtetra
.651 .707 .888 r
.27576 .44846 .27675 .44956 .27827 .44908 .27728 .44799 Mtetra
.646 .708 .892 r
.27728 .44799 .27827 .44908 .27979 .44862 .2788 .44755 Mtetra
.626 .705 .903 r
.2788 .44755 .27979 .44862 .28131 .44823 .28032 .44718 Mtetra
.62 .707 .908 r
.28032 .44718 .28131 .44823 .28283 .44787 .28184 .44684 Mtetra
.624 .713 .91 r
.28184 .44684 .28283 .44787 .28435 .44748 .28336 .44647 Mtetra
.646 .725 .906 r
.28336 .44647 .28435 .44748 .28588 .44701 .28488 .44603 Mtetra
.661 .734 .904 r
.28488 .44603 .28588 .44701 .28741 .44648 .28641 .44552 Mtetra
.674 .742 .902 r
.28641 .44552 .28741 .44648 .28894 .4459 .28795 .44496 Mtetra
.693 .752 .897 r
.28795 .44496 .28894 .4459 .29049 .44522 .28949 .44431 Mtetra
.699 .76 .899 r
.28949 .44431 .29049 .44522 .29204 .44451 .29104 .44364 Mtetra
.698 .767 .905 r
.29104 .44364 .29204 .44451 .29358 .44382 .29258 .44298 Mtetra
.678 .77 .92 r
.29258 .44298 .29358 .44382 .29512 .44323 .29412 .4424 Mtetra
.667 .772 .928 r
.29412 .4424 .29512 .44323 .29666 .44268 .29566 .44187 Mtetra
.662 .773 .932 r
.29566 .44187 .29666 .44268 .2982 .44216 .2972 .44135 Mtetra
.664 .776 .933 r
.2972 .44135 .2982 .44216 .29974 .44162 .29874 .44083 Mtetra
.664 .779 .935 r
.29874 .44083 .29974 .44162 .30128 .44109 .30028 .44031 Mtetra
.663 .781 .937 r
.30028 .44031 .30128 .44109 .30282 .44056 .30182 .43978 Mtetra
.697 .789 .922 r
.30182 .43978 .30282 .44056 .30438 .43979 .30337 .43913 Mtetra
.681 .813 .946 r
.30337 .43913 .30438 .43979 .30593 .43915 .30492 .43853 Mtetra
.607 .808 .977 r
.30492 .43853 .30593 .43915 .30745 .4389 .30645 .43814 Mtetra
.143 .551 .925 r
.30645 .43814 .30745 .4389 .30886 .4404 .30793 .43856 Mtetra
.17 .336 .789 r
.30793 .43856 .30886 .4404 .31005 .44526 .30937 .43964 Mtetra
.407 .301 .622 r
.30937 .43964 .31005 .44526 .29891 .63916 .31077 .4413 Mtetra
.545 .328 .536 r
.31077 .4413 .29891 .63916 .30036 .64155 .31225 .44185 Mtetra
.547 .33 .537 r
.31225 .44185 .30036 .64155 .302 .64112 .31381 .44127 Mtetra
.548 .331 .537 r
.31381 .44127 .302 .64112 .30369 .6398 .31539 .44027 Mtetra
.549 .331 .537 r
.31539 .44027 .30369 .6398 .30538 .63852 .31699 .43895 Mtetra
.548 .331 .537 r
.31699 .43895 .30538 .63852 .30705 .63768 .31857 .43807 Mtetra
.546 .329 .536 r
.31857 .43807 .30705 .63768 .30866 .63772 .32008 .43823 Mtetra
.52 .308 .532 r
.32008 .43823 .30866 .63772 .31014 .63978 .32085 .45022 Mtetra
0 0 .245 r
.32085 .45022 .31014 .63978 .31165 .64163 .31075 .63824 Mtetra
0 0 .501 r
.31075 .63824 .31165 .64163 .3132 .64277 .31216 .64156 Mtetra
.179 .477 .895 r
.31216 .64156 .3132 .64277 .3148 .64296 .31374 .64222 Mtetra
.566 .778 .978 r
.31374 .64222 .3148 .64296 .31644 .64268 .31538 .64193 Mtetra
.682 .806 .942 r
.31538 .64193 .31644 .64268 .3181 .64219 .31705 .64129 Mtetra
.657 .767 .93 r
.31705 .64129 .3181 .64219 .31974 .64184 .3187 .64076 Mtetra
.664 .732 .9 r
.3187 .64076 .31974 .64184 .3214 .64137 .32036 .64019 Mtetra
.704 .726 .867 r
.32036 .64019 .3214 .64137 .32308 .64049 .32204 .63941 Mtetra
.792 .757 .821 r
.32204 .63941 .32308 .64049 .32485 .63803 .32375 .63795 Mtetra
.902 .913 .819 r
.32375 .63795 .32485 .63803 .32678 .6327 .3255 .63583 Mtetra
0 0 .058 r
.3255 .63583 .32678 .6327 .33948 .4379 .32728 .63321 Mtetra
.543 .322 .53 r
.32728 .63321 .33948 .4379 .34128 .4334 .32898 .63207 Mtetra
.545 .324 .53 r
.32898 .63207 .34128 .4334 .34284 .43296 .33062 .63195 Mtetra
.544 .323 .53 r
.33062 .63195 .34284 .43296 .34438 .43288 .33229 .63119 Mtetra
.531 .313 .528 r
.33229 .63119 .34438 .43288 .34606 .43033 .33434 .62376 Mtetra
0 0 .243 r
.33434 .62376 .34606 .43033 .34775 .4275 .34663 .42926 Mtetra
.936 .918 .541 r
.34663 .42926 .34775 .4275 .3494 .42546 .34841 .42486 Mtetra
.841 .833 .838 r
.34841 .42486 .3494 .42546 .351 .42444 .35004 .42328 Mtetra
.649 .701 .884 r
.35004 .42328 .351 .42444 .35256 .42401 .3516 .4228 Mtetra
.559 .658 .902 r
.3516 .4228 .35256 .42401 .35412 .42377 .35315 .42268 Mtetra
.602 .698 .911 r
.35315 .42268 .35412 .42377 .35568 .42339 .35471 .42239 Mtetra
.656 .733 .907 r
.35471 .42239 .35568 .42339 .35725 .42287 .35628 .42189 Mtetra
.667 .743 .906 r
.35628 .42189 .35725 .42287 .35883 .42229 .35786 .42134 Mtetra
.708 .759 .892 r
.35786 .42134 .35883 .42229 .36042 .42143 .35944 .42061 Mtetra
.72 .789 .906 r
.35944 .42061 .36042 .42143 .36201 .42054 .36103 .41983 Mtetra
.674 .806 .946 r
.36103 .41983 .36201 .42054 .36358 .42003 .36261 .41925 Mtetra
.379 .677 .975 r
.36261 .41925 .36358 .42003 .36509 .42095 .36415 .41936 Mtetra
.193 .393 .831 r
.36415 .41936 .36509 .42095 .36646 .42467 .36566 .42027 Mtetra
.386 .314 .653 r
.36566 .42027 .36646 .42467 .35864 .61875 .36714 .42176 Mtetra
.545 .328 .536 r
.36714 .42176 .35864 .61875 .36008 .62313 .36868 .42212 Mtetra
.548 .331 .537 r
.36868 .42212 .36008 .62313 .36176 .6226 .37028 .42114 Mtetra
.547 .33 .537 r
.37028 .42114 .36176 .6226 .36346 .62162 .37186 .42073 Mtetra
.536 .321 .535 r
.37186 .42073 .36346 .62162 .36506 .62283 .37319 .4258 Mtetra
0 0 .279 r
.37319 .4258 .36506 .62283 .36662 .62484 .36575 .62054 Mtetra
0 0 .505 r
.36575 .62054 .36662 .62484 .36823 .62608 .36722 .62456 Mtetra
.084 .353 .823 r
.36722 .62456 .36823 .62608 .36987 .62652 .36884 .62562 Mtetra
.575 .746 .958 r
.36884 .62562 .36987 .62652 .37154 .62631 .37052 .62535 Mtetra
.719 .772 .895 r
.37052 .62535 .37154 .62631 .37324 .62553 .37222 .62451 Mtetra
.796 .771 .83 r
.37222 .62451 .37324 .62553 .375 .62339 .37395 .62305 Mtetra
.893 .877 .812 r
.37395 .62305 .375 .62339 .37688 .61845 .37571 .6209 Mtetra
0 0 0 r
.37571 .6209 .37688 .61845 .38685 .42324 .3775 .6181 Mtetra
.541 .32 .53 r
.3775 .6181 .38685 .42324 .3887 .41665 .37927 .61571 Mtetra
.544 .323 .53 r
.37927 .61571 .3887 .41665 .39031 .4157 .38097 .61491 Mtetra
.545 .324 .53 r
.38097 .61491 .39031 .4157 .39189 .4157 .38265 .61476 Mtetra
.38265 .61476 .39189 .4157 .39346 .41567 .38433 .61454 Mtetra
.544 .323 .53 r
.38433 .61454 .39346 .41567 .39506 .41516 .38602 .61405 Mtetra
.38602 .61405 .39506 .41516 .39665 .41466 .38772 .61356 Mtetra
.38772 .61356 .39665 .41466 .39825 .41413 .38941 .61306 Mtetra
.38941 .61306 .39825 .41413 .39985 .41356 .39111 .61253 Mtetra
.39111 .61253 .39985 .41356 .40146 .413 .39281 .61201 Mtetra
.39281 .61201 .40146 .413 .40307 .41201 .39452 .61124 Mtetra
.543 .323 .53 r
.39452 .61124 .40307 .41201 .4047 .41088 .39623 .61032 Mtetra
.545 .324 .53 r
.39623 .61032 .4047 .41088 .40629 .41066 .39793 .61001 Mtetra
.547 .326 .531 r
.39793 .61001 .40629 .41066 .40772 .4149 .39956 .61122 Mtetra
.548 .327 .531 r
.39956 .61122 .40772 .4149 .40234 .61025 .40118 .61307 Mtetra
.625 .279 .364 r
.40118 .61307 .40234 .61025 .40387 .61454 .40283 .61426 Mtetra
0 .477 .742 r
.40283 .61426 .40387 .61454 .40552 .61579 .40451 .61461 Mtetra
.618 .706 .908 r
.40451 .61461 .40552 .61579 .40722 .6155 .40621 .61423 Mtetra
.664 .706 .878 r
.40621 .61423 .40722 .6155 .40893 .6148 .40793 .61365 Mtetra
.633 .714 .905 r
.40793 .61365 .40893 .6148 .41065 .61416 .40964 .6132 Mtetra
.56 .729 .954 r
.40964 .6132 .41065 .61416 .41236 .61378 .41134 .61298 Mtetra
.662 .798 .948 r
.41134 .61298 .41236 .61378 .41407 .6132 .41306 .61239 Mtetra
.838 .812 .825 r
.41306 .61239 .41407 .6132 .41581 .61203 .41481 .61063 Mtetra
.894 .727 .668 r
.41481 .61063 .41581 .61203 .41758 .60987 .41666 .606 Mtetra
.952 .686 .495 r
.41666 .606 .41758 .60987 .41936 .60698 .42441 .41123 Mtetra
.563 .343 .539 r
.42441 .41123 .41936 .60698 .42114 .60454 .42627 .40264 Mtetra
.547 .33 .537 r
.42627 .40264 .42114 .60454 .42284 .60446 .4279 .40187 Mtetra
.546 .329 .537 r
.4279 .40187 .42284 .60446 .42455 .60403 .4295 .40176 Mtetra
.548 .331 .537 r
.4295 .40176 .42455 .60403 .42638 .59991 .43114 .40056 Mtetra
.551 .333 .537 r
.43114 .40056 .42638 .59991 .43365 .4029 .43282 .3979 Mtetra
.678 .504 .643 r
.43282 .3979 .43365 .4029 .43541 .39756 .43449 .39583 Mtetra
.745 .663 .77 r
.43449 .39583 .43541 .39756 .43707 .39525 .43613 .39447 Mtetra
.686 .797 .934 r
.43613 .39447 .43707 .39525 .4387 .3945 .43775 .39383 Mtetra
.613 .807 .975 r
.43775 .39383 .4387 .3945 .44032 .39414 .43937 .3934 Mtetra
.591 .783 .971 r
.43937 .3934 .44032 .39414 .44193 .39391 .44099 .39306 Mtetra
.618 .762 .948 r
.44099 .39306 .44193 .39391 .44355 .39355 .44261 .39266 Mtetra
.619 .755 .943 r
.44261 .39266 .44355 .39355 .44517 .39321 .44423 .39227 Mtetra
.633 .749 .932 r
.44423 .39227 .44517 .39321 .44679 .39281 .44585 .39184 Mtetra
.657 .747 .917 r
.44585 .39184 .44679 .39281 .44841 .39232 .44748 .39132 Mtetra
.671 .745 .906 r
.44748 .39132 .44841 .39232 .45004 .39177 .44911 .39074 Mtetra
.686 .744 .895 r
.44911 .39074 .45004 .39177 .45167 .39115 .45074 .39009 Mtetra
.702 .743 .884 r
.45074 .39009 .45167 .39115 .4533 .39044 .45237 .38935 Mtetra
.701 .738 .88 r
.45237 .38935 .4533 .39044 .45494 .38972 .45401 .38861 Mtetra
.708 .736 .873 r
.45401 .38861 .45494 .38972 .45657 .38899 .45564 .38783 Mtetra
.72 .73 .859 r
.45564 .38783 .45657 .38899 .45821 .38824 .45728 .38696 Mtetra
.657 .69 .869 r
.45728 .38696 .45821 .38824 .45984 .38768 .45891 .38643 Mtetra
.394 .574 .911 r
.45891 .38643 .45984 .38768 .46147 .38758 .46053 .38676 Mtetra
.84 .381 0 r
.46053 .38676 .46147 .38758 .46307 .38848 .4621 .38969 Mtetra
.957 .682 .472 r
.4621 .38969 .46307 .38848 .46467 .39011 .46007 .58177 Mtetra
.564 .339 .533 r
.46007 .58177 .46467 .39011 .46627 .3919 .4616 .59231 Mtetra
.545 .324 .53 r
.4616 .59231 .46627 .3919 .46791 .39092 .46334 .5922 Mtetra
.544 .323 .53 r
.46334 .5922 .46791 .39092 .46956 .39016 .46509 .59131 Mtetra
.545 .324 .53 r
.46509 .59131 .46956 .39016 .47116 .39204 .46683 .59108 Mtetra
.548 .327 .531 r
.46683 .59108 .47116 .39204 .46961 .58877 .46854 .59282 Mtetra
.607 .288 .403 r
.46854 .59282 .46961 .58877 .47127 .59391 .47026 .59401 Mtetra
.401 0 0 r
.47026 .59401 .47127 .59391 .47298 .59566 .472 .59454 Mtetra
.612 .716 .919 r
.472 .59454 .47298 .59566 .47473 .59545 .47375 .59416 Mtetra
.659 .703 .879 r
.47375 .59416 .47473 .59545 .47648 .59482 .4755 .59358 Mtetra
.664 .715 .886 r
.4755 .59358 .47648 .59482 .47824 .59408 .47726 .59298 Mtetra
.607 .72 .925 r
.47726 .59298 .47824 .59408 .48 .5937 .47901 .59262 Mtetra
.604 .723 .929 r
.47901 .59262 .48 .5937 .48175 .59333 .48077 .59227 Mtetra
.612 .73 .929 r
.48077 .59227 .48175 .59333 .48351 .59293 .48252 .59189 Mtetra
.636 .742 .925 r
.48252 .59189 .48351 .59293 .48527 .59245 .48428 .59141 Mtetra
.643 .747 .924 r
.48428 .59141 .48527 .59245 .48703 .59193 .48604 .5909 Mtetra
.646 .749 .924 r
.48604 .5909 .48703 .59193 .48879 .59141 .4878 .59038 Mtetra
.644 .749 .926 r
.4878 .59038 .48879 .59141 .49055 .59089 .48957 .58987 Mtetra
.645 .75 .926 r
.48957 .58987 .49055 .59089 .49231 .59037 .49133 .58935 Mtetra
.645 .751 .926 r
.49133 .58935 .49231 .59037 .49408 .58985 .4931 .58883 Mtetra
.646 .751 .926 r
.4931 .58883 .49408 .58985 .49584 .58933 .49486 .58831 Mtetra
.646 .752 .926 r
.49486 .58831 .49584 .58933 .49761 .58881 .49663 .58779 Mtetra
.647 .752 .926 r
.49663 .58779 .49761 .58881 .49938 .58829 .4984 .58726 Mtetra
.4984 .58726 .49938 .58829 .50115 .58776 .50017 .58674 Mtetra
.50017 .58674 .50115 .58776 .50292 .58723 .50194 .58621 Mtetra
.50194 .58621 .50292 .58723 .50469 .58671 .50371 .58568 Mtetra
.50371 .58568 .50469 .58671 .50646 .58618 .50549 .58515 Mtetra
.50549 .58515 .50646 .58618 .50824 .58565 .50726 .58462 Mtetra
.648 .752 .926 r
.50726 .58462 .50824 .58565 .51001 .58512 .50904 .58409 Mtetra
.50904 .58409 .51001 .58512 .51179 .58459 .51082 .58356 Mtetra
.648 .752 .925 r
.51082 .58356 .51179 .58459 .51357 .58405 .51259 .58303 Mtetra
.649 .752 .925 r
.51259 .58303 .51357 .58405 .51534 .58352 .51437 .58249 Mtetra
.51437 .58249 .51534 .58352 .51712 .58298 .51615 .58195 Mtetra
.65 .752 .924 r
.51615 .58195 .51712 .58298 .51891 .58245 .51794 .58141 Mtetra
.651 .752 .924 r
.51794 .58141 .51891 .58245 .52069 .5819 .51972 .58086 Mtetra
.648 .75 .924 r
.51972 .58086 .52069 .5819 .52247 .58137 .5215 .58033 Mtetra
.653 .75 .921 r
.5215 .58033 .52247 .58137 .52425 .58083 .52329 .57977 Mtetra
.66 .751 .918 r
.52329 .57977 .52425 .58083 .52604 .58025 .52507 .57919 Mtetra
.682 .756 .907 r
.52507 .57919 .52604 .58025 .52783 .57958 .52686 .57849 Mtetra
.686 .753 .903 r
.52686 .57849 .52783 .57958 .52961 .57889 .52865 .57779 Mtetra
.682 .748 .901 r
.52865 .57779 .52961 .57889 .5314 .57822 .53044 .57709 Mtetra
.618 .723 .921 r
.53044 .57709 .5314 .57822 .53319 .57797 .53223 .57668 Mtetra
.642 .702 .89 r
.53223 .57668 .53319 .57797 .53498 .57749 .53402 .57618 Mtetra
.686 .714 .87 r
.53402 .57618 .53498 .57749 .53678 .57652 .53581 .57544 Mtetra
.825 .781 .811 r
.53581 .57544 .53678 .57652 .53856 .57312 .5376 .57363 Mtetra
.871 .988 .723 r
.5376 .57363 .53856 .57312 .54032 .56528 .53939 .57124 Mtetra
.293 .044 .354 r
.53939 .57124 .54032 .56528 .5411 .36697 .54117 .56831 Mtetra
.545 .324 .53 r
.54117 .56831 .5411 .36697 .54278 .36544 .54297 .56802 Mtetra
.54297 .56802 .54278 .36544 .54447 .36517 .54477 .56777 Mtetra
.543 .322 .53 r
.54477 .56777 .54447 .36517 .54616 .3649 .54656 .56651 Mtetra
0 0 .365 r
.54656 .56651 .54616 .3649 .54783 .36156 .547 .37084 Mtetra
0 0 .191 r
.547 .37084 .54783 .36156 .5495 .35897 .54862 .35956 Mtetra
.965 .937 .642 r
.54862 .35956 .5495 .35897 .55118 .35707 .55029 .35603 Mtetra
.761 .771 .861 r
.55029 .35603 .55118 .35707 .55287 .35621 .55197 .35493 Mtetra
.652 .693 .875 r
.55197 .35493 .55287 .35621 .55456 .35567 .55366 .3544 Mtetra
.586 .668 .895 r
.55366 .3544 .55456 .35567 .55625 .35529 .55536 .35416 Mtetra
.62 .709 .909 r
.55536 .35416 .55625 .35529 .55795 .35488 .55705 .35377 Mtetra
.621 .714 .913 r
.55705 .35377 .55795 .35488 .55964 .35446 .55875 .35338 Mtetra
.63 .723 .914 r
.55875 .35338 .55964 .35446 .56134 .354 .56045 .35295 Mtetra
.68 .747 .902 r
.56045 .35295 .56134 .354 .56303 .3533 .56214 .3523 Mtetra
.696 .762 .903 r
.56214 .3523 .56303 .3533 .56473 .35254 .56384 .35158 Mtetra
.698 .772 .909 r
.56384 .35158 .56473 .35254 .56642 .35178 .56553 .35085 Mtetra
.709 .782 .909 r
.56553 .35085 .56642 .35178 .56811 .35088 .56723 .35008 Mtetra
.68 .805 .942 r
.56723 .35008 .56811 .35088 .56981 .35019 .56893 .34943 Mtetra
.605 .792 .97 r
.56893 .34943 .56981 .35019 .57152 .34994 .57063 .34902 Mtetra
.417 .667 .964 r
.57063 .34902 .57152 .34994 .57325 .35139 .57234 .34914 Mtetra
.393 .435 .785 r
.57234 .34914 .57325 .35139 .57503 .35591 .57407 .34992 Mtetra
.395 .296 .624 r
.57407 .34992 .57503 .35591 .58 .55518 .57582 .35206 Mtetra
0 0 .387 r
.57582 .35206 .58 .55518 .5819 .55961 .58078 .54765 Mtetra
.051 .009 .484 r
.58078 .54765 .5819 .55961 .58376 .56118 .58278 .55797 Mtetra
.08 .173 .661 r
.58278 .55797 .58376 .56118 .5856 .56179 .58466 .56062 Mtetra
.419 .625 .938 r
.58466 .56062 .5856 .56179 .58744 .56161 .5865 .56084 Mtetra
.635 .811 .968 r
.5865 .56084 .58744 .56161 .58926 .56107 .58833 .56029 Mtetra
.716 .833 .937 r
.58833 .56029 .58926 .56107 .59109 .56036 .59015 .55943 Mtetra
.625 .772 .951 r
.59015 .55943 .59109 .56036 .59292 .56009 .59198 .55896 Mtetra
.635 .733 .919 r
.59198 .55896 .59292 .56009 .59476 .5597 .59381 .55847 Mtetra
.684 .731 .887 r
.59381 .55847 .59476 .5597 .59658 .55885 .59564 .55774 Mtetra
.772 .777 .857 r
.59564 .55774 .59658 .55885 .59837 .55625 .59746 .55647 Mtetra
.848 .998 .799 r
.59746 .55647 .59837 .55625 .60009 .55069 .59926 .55451 Mtetra
.06 0 .203 r
.59926 .55451 .60009 .55069 .59735 .35025 .60104 .55124 Mtetra
.061 0 .416 r
.60104 .55124 .59735 .35025 .59895 .34426 .59885 .37668 Mtetra
0 0 .343 r
.59885 .37668 .59895 .34426 .60062 .34167 .5998 .34289 Mtetra
.851 .898 .48 r
.5998 .34289 .60062 .34167 .60232 .34004 .60145 .33921 Mtetra
.795 .824 .874 r
.60145 .33921 .60232 .34004 .60403 .33923 .60315 .33794 Mtetra
.632 .688 .884 r
.60315 .33794 .60403 .33923 .60576 .33881 .60488 .3375 Mtetra
.554 .649 .898 r
.60488 .3375 .60576 .33881 .60749 .33857 .60661 .33738 Mtetra
.622 .703 .903 r
.60661 .33738 .60749 .33857 .60922 .3381 .60834 .33698 Mtetra
.66 .731 .901 r
.60834 .33698 .60922 .3381 .61094 .33751 .61007 .33642 Mtetra
.673 .741 .902 r
.61007 .33642 .61094 .33751 .61267 .33685 .61179 .33579 Mtetra
.719 .763 .887 r
.61179 .33579 .61267 .33685 .61438 .33584 .61351 .33494 Mtetra
.721 .795 .911 r
.61351 .33494 .61438 .33584 .6161 .33491 .61524 .33409 Mtetra
.669 .802 .946 r
.61524 .33409 .6161 .33491 .61783 .3344 .61697 .33348 Mtetra
.498 .706 .964 r
.61697 .33348 .61783 .3344 .61961 .33543 .61871 .33341 Mtetra
.418 .475 .812 r
.61871 .33341 .61961 .33543 .62147 .3391 .62048 .33401 Mtetra
.405 .32 .646 r
.62048 .33401 .62147 .3391 .62942 .53828 .62229 .33577 Mtetra
.519 .308 .534 r
.62229 .33577 .62942 .53828 .63147 .54424 .62449 .35005 Mtetra
0 0 .398 r
.62449 .35005 .63147 .54424 .6334 .54602 .63239 .54215 Mtetra
.116 .167 .64 r
.63239 .54215 .6334 .54602 .6353 .5467 .63437 .54526 Mtetra
.4 .564 .9 r
.63437 .54526 .6353 .5467 .63717 .54649 .63626 .54567 Mtetra
.666 .813 .954 r
.63626 .54567 .63717 .54649 .63902 .54581 .63811 .54501 Mtetra
.744 .839 .923 r
.63811 .54501 .63902 .54581 .64087 .54495 .63996 .544 Mtetra
.636 .774 .947 r
.63996 .544 .64087 .54495 .64274 .54465 .64182 .54347 Mtetra
.585 .707 .927 r
.64182 .54347 .64274 .54465 .64462 .54447 .64369 .54318 Mtetra
.638 .706 .896 r
.64369 .54318 .64462 .54447 .64648 .54387 .64556 .54267 Mtetra
.743 .76 .866 r
.64556 .54267 .64648 .54387 .64829 .54167 .64741 .54157 Mtetra
.862 .981 .851 r
.64741 .54157 .64829 .54167 .64999 .53668 .64923 .53974 Mtetra
.005 0 .14 r
.64923 .53974 .64999 .53668 .64431 .33664 .651 .53678 Mtetra
.529 .312 .529 r
.651 .53678 .64431 .33664 .6458 .32915 .65254 .52746 Mtetra
0 0 .394 r
.65254 .52746 .6458 .32915 .64747 .32649 .64673 .32859 Mtetra
0 0 0 r
.64673 .32859 .64747 .32649 .64917 .32482 .64834 .32428 Mtetra
.862 .894 .856 r
.64834 .32428 .64917 .32482 .65091 .32383 .65005 .32259 Mtetra
.673 .716 .882 r
.65005 .32259 .65091 .32383 .65266 .32322 .6518 .32195 Mtetra
.604 .681 .896 r
.6518 .32195 .65266 .32322 .65442 .32277 .65356 .32162 Mtetra
.676 .735 .895 r
.65356 .32162 .65442 .32277 .65616 .32191 .65531 .32097 Mtetra
.721 .791 .907 r
.65531 .32097 .65616 .32191 .6579 .32095 .65705 .32011 Mtetra
.676 .803 .943 r
.65705 .32011 .6579 .32095 .65965 .32037 .65881 .31946 Mtetra
.525 .725 .965 r
.65881 .31946 .65965 .32037 .66147 .32113 .66058 .31931 Mtetra
.418 .499 .835 r
.66058 .31931 .66147 .32113 .6634 .32445 .66239 .31984 Mtetra
.405 .332 .661 r
.66239 .31984 .6634 .32445 .67405 .52343 .66425 .32147 Mtetra
.529 .316 .535 r
.66425 .32147 .67405 .52343 .67629 .53071 .66645 .33065 Mtetra
.003 0 .413 r
.66645 .33065 .67629 .53071 .67828 .53263 .67723 .52829 Mtetra
.141 .169 .63 r
.67723 .52829 .67828 .53263 .68023 .53341 .6793 .53174 Mtetra
.293 .462 .857 r
.6793 .53174 .68023 .53341 .68215 .53361 .68126 .5326 Mtetra
.589 .747 .953 r
.68126 .5326 .68215 .53361 .68406 .53331 .68316 .53225 Mtetra
.72 .782 .901 r
.68316 .53225 .68406 .53331 .68593 .53243 .68503 .53132 Mtetra
.779 .789 .861 r
.68503 .53132 .68593 .53243 .68774 .53026 .68689 .52999 Mtetra
.871 .96 .858 r
.68689 .52999 .68774 .53026 .68943 .52551 .68872 .52815 Mtetra
0 0 .081 r
.68872 .52815 .68943 .52551 .68142 .32574 .6905 .52523 Mtetra
.532 .314 .529 r
.6905 .52523 .68142 .32574 .68277 .31671 .69201 .51708 Mtetra
.003 0 .407 r
.69201 .51708 .68277 .31671 .68443 .31391 .68377 .31642 Mtetra
0 0 0 r
.68377 .31642 .68443 .31391 .68614 .31214 .68534 .31181 Mtetra
.909 .931 .815 r
.68534 .31181 .68614 .31214 .68788 .31079 .68704 .30971 Mtetra
.735 .77 .881 r
.68704 .30971 .68788 .31079 .68963 .30979 .68879 .30875 Mtetra
.627 .741 .929 r
.68879 .30875 .68963 .30979 .69141 .3093 .69058 .3083 Mtetra
.497 .691 .955 r
.69058 .3083 .69141 .3093 .69325 .30992 .69238 .30826 Mtetra
.424 .525 .856 r
.69238 .30826 .69325 .30992 .69521 .31274 .69422 .30871 Mtetra
.407 .35 .682 r
.69422 .30871 .69521 .31274 .70777 .50831 .69611 .31014 Mtetra
.535 .321 .536 r
.69611 .31014 .70777 .50831 .71034 .51996 .69826 .31623 Mtetra
.022 0 .424 r
.69826 .31623 .71034 .51996 .7124 .52218 .7113 .51718 Mtetra
.149 .158 .612 r
.7113 .51718 .7124 .52218 .71439 .52309 .71346 .52119 Mtetra
.265 .412 .824 r
.71346 .52119 .71439 .52309 .71635 .52336 .71547 .52231 Mtetra
.567 .73 .952 r
.71547 .52231 .71635 .52336 .71828 .52313 .7174 .52204 Mtetra
.708 .775 .905 r
.7174 .52204 .71828 .52313 .72019 .52233 .7193 .52117 Mtetra
.77 .781 .862 r
.7193 .52117 .72019 .52233 .72202 .52039 .72117 .51989 Mtetra
.859 .923 .871 r
.72117 .51989 .72202 .52039 .72371 .51612 .72302 .51815 Mtetra
0 0 0 r
.72302 .51815 .72371 .51612 .71417 .32494 .72481 .5154 Mtetra
.533 .315 .529 r
.72481 .5154 .71417 .32494 .71488 .30638 .72633 .50838 Mtetra
.02 0 .418 r
.72633 .50838 .71488 .30638 .71651 .30319 .71592 .30591 Mtetra
0 0 0 r
.71592 .30591 .71651 .30319 .71822 .30127 .71745 .30097 Mtetra
.907 .945 .818 r
.71745 .30097 .71822 .30127 .71999 .30015 .71915 .29891 Mtetra
.666 .719 .889 r
.71915 .29891 .71999 .30015 .72178 .29962 .72095 .29829 Mtetra
.574 .662 .897 r
.72095 .29829 .72178 .29962 .7236 .29932 .72277 .29808 Mtetra
.573 .679 .912 r
.72277 .29808 .7236 .29932 .72541 .29897 .72459 .29786 Mtetra
.65 .738 .914 r
.72459 .29786 .72541 .29897 .72721 .2984 .72639 .29732 Mtetra
.665 .75 .914 r
.72639 .29732 .72721 .2984 .72901 .29776 .72819 .2967 Mtetra
.701 .77 .905 r
.72819 .2967 .72901 .29776 .73079 .29688 .72998 .29592 Mtetra
.734 .799 .904 r
.72998 .29592 .73079 .29688 .73256 .29582 .73176 .29498 Mtetra
.7 .818 .938 r
.73176 .29498 .73256 .29582 .73435 .29509 .73355 .29421 Mtetra
.591 .767 .964 r
.73355 .29421 .73435 .29509 .73621 .29532 .73537 .29384 Mtetra
.447 .569 .884 r
.73537 .29384 .73621 .29532 .73823 .29777 .73724 .29415 Mtetra
.431 .381 .702 r
.73724 .29415 .73823 .29777 .74101 .31133 .73916 .29527 Mtetra
.457 .291 .568 r
.73916 .29527 .74101 .31133 .75636 .50525 .74129 .29917 Mtetra
.05 0 .438 r
.74129 .29917 .75636 .50525 .7585 .50761 .75724 .50086 Mtetra
.177 .148 .585 r
.75724 .50086 .7585 .50761 .76055 .50853 .75959 .50613 Mtetra
.25 .35 .771 r
.75959 .50613 .76055 .50853 .76255 .50879 .76168 .50768 Mtetra
.534 .703 .948 r
.76168 .50768 .76255 .50879 .76452 .50863 .76366 .50753 Mtetra
.686 .77 .915 r
.76366 .50753 .76452 .50863 .76646 .50791 .76559 .50677 Mtetra
.758 .785 .875 r
.76559 .50677 .76646 .50791 .76832 .50618 .76749 .50557 Mtetra
.827 .908 .895 r
.76749 .50557 .76832 .50618 .77001 .50214 .76937 .50405 Mtetra
0 0 0 r
.76937 .50405 .77001 .50214 .77085 .48668 .77119 .50169 Mtetra
.409 .193 .471 r
.77119 .50169 .77085 .48668 .75829 .29257 .7728 .49665 Mtetra
.049 0 .433 r
.7728 .49665 .75829 .29257 .75991 .28933 .75952 .29379 Mtetra
0 0 .177 r
.75952 .29379 .75991 .28933 .76163 .28739 .76091 .28749 Mtetra
.923 .975 .718 r
.76091 .28749 .76163 .28739 .7634 .28614 .76259 .28492 Mtetra
.71 .743 .878 r
.76259 .28492 .7634 .28614 .76521 .28543 .76439 .28406 Mtetra
.625 .681 .883 r
.76439 .28406 .76521 .28543 .76705 .28493 .76623 .28362 Mtetra
.637 .697 .889 r
.76623 .28362 .76705 .28493 .76887 .28432 .76806 .28313 Mtetra
.746 .762 .866 r
.76806 .28313 .76887 .28432 .77066 .28323 .76985 .28205 Mtetra
.663 .733 .902 r
.76985 .28205 .77066 .28323 .77248 .28261 .77168 .28144 Mtetra
.226 .496 .9 r
.77168 .28144 .77248 .28261 .77442 .28338 .77362 .28219 Mtetra
.903 .523 .081 r
.77362 .28219 .77442 .28338 .77703 .29242 .77619 .29075 Mtetra
.975 .667 .332 r
.77619 .29075 .77703 .29242 .79552 .49597 .79466 .49474 Mtetra
0 0 .45 r
.79466 .49474 .79552 .49597 .79778 .49896 .79693 .49779 Mtetra
.58 .715 .935 r
.79693 .49779 .79778 .49896 .79977 .49863 .79892 .49749 Mtetra
.723 .779 .897 r
.79892 .49749 .79977 .49863 .8017 .49762 .80086 .49652 Mtetra
.725 .787 .902 r
.80086 .49652 .8017 .49762 .80363 .4966 .80279 .49554 Mtetra
.462 .679 .959 r
.80279 .49554 .80363 .4966 .80566 .49663 .80482 .49558 Mtetra
.599 .751 .95 r
.80482 .49558 .80566 .49663 .80764 .49621 .80681 .49518 Mtetra
.822 .825 .852 r
.80681 .49518 .80764 .49621 .80952 .49455 .80869 .49353 Mtetra
.978 .778 .567 r
.80869 .49353 .80952 .49455 .81093 .48742 .81011 .48652 Mtetra
.977 .675 .344 r
.81011 .48652 .81093 .48742 .79488 .27975 .7941 .27872 Mtetra
.963 .79 .621 r
.7941 .27872 .79488 .27975 .79635 .27483 .79556 .27372 Mtetra
.755 .782 .875 r
.79556 .27372 .79635 .27483 .79815 .27373 .79736 .27261 Mtetra
.622 .728 .923 r
.79736 .27261 .79815 .27373 .80001 .2733 .79922 .27217 Mtetra
.582 .707 .929 r
.79922 .27217 .80001 .2733 .80189 .27303 .8011 .27188 Mtetra
.75 .773 .872 r
.8011 .27188 .80189 .27303 .80369 .27195 .8029 .27079 Mtetra
.675 .744 .902 r
.8029 .27079 .80369 .27195 .80554 .27127 .80475 .2701 Mtetra
.388 .597 .929 r
.80475 .2701 .80554 .27127 .80747 .27162 .80668 .27045 Mtetra
.809 .4 0 r
.80668 .27045 .80747 .27162 .8099 .27732 .80911 .27609 Mtetra
.973 .662 .315 r
.80911 .27609 .8099 .27732 .83091 .48363 .83008 .48249 Mtetra
.7 .261 0 r
.83008 .48249 .83091 .48363 .83334 .48774 .83251 .48665 Mtetra
.39 .634 .952 r
.83251 .48665 .83334 .48774 .8354 .48786 .83458 .48691 Mtetra
.677 .808 .946 r
.83458 .48691 .8354 .48786 .83737 .4871 .83656 .48617 Mtetra
.839 .852 .854 r
.83656 .48617 .83737 .4871 .83929 .48572 .83845 .48443 Mtetra
.928 .79 .688 r
.83845 .48443 .83929 .48572 .84119 .4841 .84014 .48058 Mtetra
.931 .676 .53 r
.84014 .48058 .84119 .4841 .84301 .48164 .84105 .46873 Mtetra
.971 .663 .363 r
.84105 .46873 .84301 .48164 .84461 .47703 .82379 .26903 Mtetra
.551 .333 .537 r
.82379 .26903 .84461 .47703 .82686 .2739 .8254 .26583 Mtetra
.626 .438 .608 r
.8254 .26583 .82686 .2739 .82809 .2668 .82714 .26393 Mtetra
.685 .57 .72 r
.82714 .26393 .82809 .2668 .82972 .26383 .82894 .26265 Mtetra
.692 .748 .894 r
.82894 .26265 .82972 .26383 .83155 .26285 .83079 .26187 Mtetra
.647 .774 .941 r
.83079 .26187 .83155 .26285 .83343 .26232 .83267 .26131 Mtetra
.64 .763 .937 r
.83267 .26131 .83343 .26232 .83532 .26194 .83454 .26077 Mtetra
.772 .779 .859 r
.83454 .26077 .83532 .26194 .83712 .26069 .83635 .25951 Mtetra
.709 .756 .889 r
.83635 .25951 .83712 .26069 .83897 .25983 .83819 .25865 Mtetra
.518 .666 .929 r
.83819 .25865 .83897 .25983 .8409 .2598 .84012 .2586 Mtetra
.808 .404 0 r
.84012 .2586 .8409 .2598 .84347 .26596 .84269 .26471 Mtetra
.971 .656 .294 r
.84269 .26471 .84347 .26596 .86694 .47337 .86612 .47223 Mtetra
.591 .151 0 r
.86612 .47223 .86694 .47337 .86937 .47685 .86857 .47574 Mtetra
.967 .799 .622 r
.86857 .47574 .86937 .47685 .87087 .47129 .8701 .47058 Mtetra
.974 .667 .311 r
.8701 .47058 .87087 .47129 .85085 .26214 .85014 .26154 Mtetra
.995 .801 .532 r
.85014 .26154 .85085 .26214 .85215 .25604 .85138 .25484 Mtetra
.803 .755 .809 r
.2459 .45752 .24691 .45849 .24842 .45796 .24749 .45604 Mtetra
.641 .592 .783 r
.24749 .45604 .24842 .45796 .24983 .45863 .249 .45553 Mtetra
.49 .427 .713 r
.249 .45553 .24983 .45863 .25109 .46116 .25043 .45598 Mtetra
0 0 .486 r
.25043 .45598 .25109 .46116 .23692 .64972 .25156 .46006 Mtetra
0 0 .165 r
.25156 .46006 .23692 .64972 .23758 .66058 .23674 .65683 Mtetra
.75 .484 0 r
.23674 .65683 .23758 .66058 .23893 .66323 .23786 .66226 Mtetra
.293 .598 .949 r
.23786 .66226 .23893 .66323 .24047 .6636 .2394 .66259 Mtetra
.66 .739 .909 r
.2394 .66259 .24047 .6636 .24206 .66326 .24101 .66206 Mtetra
.728 .721 .843 r
.24101 .66206 .24206 .66326 .2437 .66241 .24265 .66111 Mtetra
.548 .647 .899 r
.24265 .66111 .2437 .66241 .24537 .66113 .24423 .66102 Mtetra
.455 .866 .955 r
.24423 .66102 .24537 .66113 .2471 .65912 .24584 .66061 Mtetra
0 0 0 r
.24584 .66061 .2471 .65912 .24896 .65551 .2475 .65947 Mtetra
.2475 .65947 .24896 .65551 .26577 .4624 .2495 .65409 Mtetra
0 0 .168 r
.2495 .65409 .26577 .4624 .26793 .45369 .26665 .45636 Mtetra
.955 .892 .503 r
.26665 .45636 .26793 .45369 .26966 .45057 .2686 .4504 Mtetra
.832 .922 .894 r
.2686 .4504 .26966 .45057 .27122 .44954 .27018 .44908 Mtetra
.614 .85 .988 r
.27018 .44908 .27122 .44954 .27274 .44909 .2717 .44863 Mtetra
.378 .761 .99 r
.2717 .44863 .27274 .44909 .27424 .44891 .27319 .44857 Mtetra
.555 .863 .996 r
.27319 .44857 .27424 .44891 .27576 .44846 .27471 .44817 Mtetra
.566 .879 .993 r
.27471 .44817 .27576 .44846 .27728 .44799 .27623 .44773 Mtetra
.571 .886 .99 r
.27623 .44773 .27728 .44799 .2788 .44755 .27776 .44727 Mtetra
.634 .898 .985 r
.27776 .44727 .2788 .44755 .28032 .44718 .27929 .44669 Mtetra
.677 .855 .967 r
.27929 .44669 .28032 .44718 .28184 .44684 .28083 .44608 Mtetra
.685 .791 .93 r
.28083 .44608 .28184 .44684 .28336 .44647 .28236 .44548 Mtetra
.665 .733 .9 r
.28236 .44548 .28336 .44647 .28488 .44603 .28389 .44495 Mtetra
.657 .715 .891 r
.28389 .44495 .28488 .44603 .28641 .44552 .28542 .44446 Mtetra
.656 .717 .894 r
.28542 .44446 .28641 .44552 .28795 .44496 .28696 .44397 Mtetra
.662 .734 .903 r
.28696 .44397 .28795 .44496 .28949 .44431 .28849 .44346 Mtetra
.664 .764 .924 r
.28849 .44346 .28949 .44431 .29104 .44364 .29002 .44294 Mtetra
.662 .799 .948 r
.29002 .44294 .29104 .44364 .29258 .44298 .29156 .44241 Mtetra
.652 .832 .969 r
.29156 .44241 .29258 .44298 .29412 .4424 .2931 .44189 Mtetra
.646 .845 .977 r
.2931 .44189 .29412 .4424 .29566 .44187 .29464 .44137 Mtetra
.643 .849 .979 r
.29464 .44137 .29566 .44187 .2972 .44135 .29617 .44085 Mtetra
.64 .848 .98 r
.29617 .44085 .2972 .44135 .29874 .44083 .29771 .44034 Mtetra
.638 .851 .981 r
.29771 .44034 .29874 .44083 .30028 .44031 .29925 .43984 Mtetra
.637 .855 .982 r
.29925 .43984 .30028 .44031 .30182 .43978 .30079 .43932 Mtetra
.646 .859 .981 r
.30079 .43932 .30182 .43978 .30337 .43913 .30234 .43879 Mtetra
.628 .885 .988 r
.30234 .43879 .30337 .43913 .30492 .43853 .30388 .43824 Mtetra
.614 .894 .988 r
.30388 .43824 .30492 .43853 .30645 .43814 .30543 .4377 Mtetra
.629 .861 .986 r
.30543 .4377 .30645 .43814 .30793 .43856 .30697 .43719 Mtetra
.651 .665 .85 r
.30697 .43719 .30793 .43856 .30937 .43964 .30851 .4367 Mtetra
.617 .516 .716 r
.30851 .4367 .30937 .43964 .31077 .4413 .31006 .4362 Mtetra
.596 .445 .647 r
.31006 .4362 .31077 .4413 .31225 .44185 .31161 .43564 Mtetra
.589 .426 .628 r
.31161 .43564 .31225 .44185 .31381 .44127 .31316 .43507 Mtetra
.31316 .43507 .31381 .44127 .31539 .44027 .31471 .4345 Mtetra
.609 .445 .635 r
.31471 .4345 .31539 .44027 .31699 .43895 .31629 .43362 Mtetra
.604 .447 .642 r
.31629 .43362 .31699 .43895 .31857 .43807 .31785 .43289 Mtetra
.567 .423 .645 r
.31785 .43289 .31857 .43807 .32008 .43823 .31938 .43275 Mtetra
.268 .204 .598 r
.31938 .43275 .32008 .43823 .32085 .45022 .32073 .43543 Mtetra
.964 .705 .493 r
.32073 .43543 .32085 .45022 .31075 .63824 .31006 .63141 Mtetra
0 0 .25 r
.31006 .63141 .31075 .63824 .31216 .64156 .31118 .63948 Mtetra
.235 .362 .789 r
.31118 .63948 .31216 .64156 .31374 .64222 .31274 .64056 Mtetra
.627 .628 .832 r
.31274 .64056 .31374 .64222 .31538 .64193 .31438 .64014 Mtetra
.691 .641 .795 r
.31438 .64014 .31538 .64193 .31705 .64129 .31606 .63926 Mtetra
.644 .598 .788 r
.31606 .63926 .31705 .64129 .3187 .64076 .31772 .63869 Mtetra
.615 .581 .792 r
.31772 .63869 .3187 .64076 .32036 .64019 .31937 .63831 Mtetra
.621 .601 .809 r
.31937 .63831 .32036 .64019 .32204 .63941 .32102 .63791 Mtetra
.64 .656 .85 r
.32102 .63791 .32204 .63941 .32375 .63795 .32268 .63744 Mtetra
.626 .854 .986 r
.32268 .63744 .32375 .63795 .3255 .63583 .32434 .63692 Mtetra
.169 0 0 r
.32434 .63692 .3255 .63583 .32728 .63321 .326 .63637 Mtetra
.483 .148 .323 r
.326 .63637 .32728 .63321 .32898 .63207 .32764 .63619 Mtetra
.493 .183 .369 r
.32764 .63619 .32898 .63207 .33062 .63195 .32929 .63594 Mtetra
.423 .115 .336 r
.32929 .63594 .33062 .63195 .33229 .63119 .33097 .63512 Mtetra
0 0 .094 r
.33097 .63512 .33229 .63119 .33434 .62376 .3328 .6317 Mtetra
.958 .701 .504 r
.3328 .6317 .33434 .62376 .34663 .42926 .34506 .43908 Mtetra
0 0 0 r
.34506 .43908 .34663 .42926 .34841 .42486 .34737 .42514 Mtetra
.933 .947 .774 r
.34737 .42514 .34841 .42486 .35004 .42328 .34904 .42275 Mtetra
.719 .857 .947 r
.34904 .42275 .35004 .42328 .3516 .4228 .35062 .42198 Mtetra
.587 .755 .958 r
.35062 .42198 .3516 .4228 .35315 .42268 .35218 .42169 Mtetra
.622 .727 .922 r
.35218 .42169 .35315 .42268 .35471 .42239 .35374 .42132 Mtetra
.655 .721 .897 r
.35374 .42132 .35471 .42239 .35628 .42189 .35531 .42082 Mtetra
.651 .72 .898 r
.35531 .42082 .35628 .42189 .35786 .42134 .35689 .42034 Mtetra
.659 .735 .906 r
.35689 .42034 .35786 .42134 .35944 .42061 .35846 .41982 Mtetra
.665 .787 .939 r
.35846 .41982 .35944 .42061 .36103 .41983 .36004 .41928 Mtetra
.653 .843 .973 r
.36004 .41928 .36103 .41983 .36261 .41925 .36161 .41873 Mtetra
.645 .851 .979 r
.36161 .41873 .36261 .41925 .36415 .41936 .36319 .4182 Mtetra
.66 .704 .88 r
.36319 .4182 .36415 .41936 .36566 .42027 .36477 .41767 Mtetra
.626 .539 .737 r
.36477 .41767 .36566 .42027 .36714 .42176 .36635 .41715 Mtetra
.618 .469 .657 r
.36635 .41715 .36714 .42176 .36868 .42212 .36794 .41633 Mtetra
.606 .443 .635 r
.36794 .41633 .36868 .42212 .37028 .42114 .36954 .41549 Mtetra
.577 .424 .637 r
.36954 .41549 .37028 .42114 .37186 .42073 .37111 .41516 Mtetra
.4 .299 .624 r
.37111 .41516 .37186 .42073 .37319 .4258 .37259 .41692 Mtetra
.963 .697 .484 r
.37259 .41692 .37319 .4258 .36575 .62054 .36551 .60255 Mtetra
0 0 .273 r
.36551 .60255 .36575 .62054 .36722 .62456 .36627 .62203 Mtetra
.032 .184 .69 r
.36627 .62203 .36722 .62456 .36884 .62562 .36784 .62396 Mtetra
.578 .609 .847 r
.36784 .62396 .36884 .62562 .37052 .62535 .36951 .62379 Mtetra
.679 .665 .83 r
.36951 .62379 .37052 .62535 .37222 .62451 .37121 .62306 Mtetra
.687 .683 .841 r
.37121 .62306 .37222 .62451 .37395 .62305 .37291 .62231 Mtetra
.666 .81 .953 r
.37291 .62231 .37395 .62305 .37571 .6209 .37461 .62171 Mtetra
.014 0 0 r
.37461 .62171 .37571 .6209 .3775 .6181 .3763 .62109 Mtetra
.419 .08 .283 r
.3763 .62109 .3775 .6181 .37927 .61571 .378 .6205 Mtetra
.477 .181 .383 r
.378 .6205 .37927 .61571 .38097 .61491 .37969 .61998 Mtetra
.482 .19 .392 r
.37969 .61998 .38097 .61491 .38265 .61476 .38139 .61948 Mtetra
.477 .18 .381 r
.38139 .61948 .38265 .61476 .38433 .61454 .38308 .61897 Mtetra
.472 .17 .371 r
.38308 .61897 .38433 .61454 .38602 .61405 .38478 .61846 Mtetra
.472 .169 .37 r
.38478 .61846 .38602 .61405 .38772 .61356 .38648 .61796 Mtetra
.38648 .61796 .38772 .61356 .38941 .61306 .38818 .61745 Mtetra
.38818 .61745 .38941 .61306 .39111 .61253 .38988 .61694 Mtetra
.38988 .61694 .39111 .61253 .39281 .61201 .39158 .61644 Mtetra
.471 .169 .371 r
.39158 .61644 .39281 .61201 .39452 .61124 .39328 .61592 Mtetra
.475 .177 .38 r
.39328 .61592 .39452 .61124 .39623 .61032 .39499 .6154 Mtetra
.482 .19 .393 r
.39499 .6154 .39623 .61032 .39793 .61001 .39669 .61488 Mtetra
.483 .187 .387 r
.39669 .61488 .39793 .61001 .39956 .61122 .39839 .61441 Mtetra
.45 .117 .309 r
.39839 .61441 .39956 .61122 .40118 .61307 .4001 .61398 Mtetra
.181 0 0 r
.4001 .61398 .40118 .61307 .40283 .61426 .4018 .61355 Mtetra
.609 .805 .975 r
.4018 .61355 .40283 .61426 .40451 .61461 .40351 .61312 Mtetra
.635 .658 .856 r
.40351 .61312 .40451 .61461 .40621 .61423 .40522 .61266 Mtetra
.639 .65 .844 r
.40522 .61266 .40621 .61423 .40793 .61365 .40693 .61217 Mtetra
.611 .652 .866 r
.40693 .61217 .40793 .61365 .40964 .6132 .40863 .61183 Mtetra
.588 .659 .887 r
.40863 .61183 .40964 .6132 .41134 .61298 .41034 .61159 Mtetra
.689 .695 .85 r
.41034 .61159 .41134 .61298 .41306 .61239 .41206 .61083 Mtetra
.829 .712 .735 r
.41206 .61083 .41306 .61239 .41481 .61063 .41384 .60829 Mtetra
.915 .688 .58 r
.41384 .60829 .41481 .61063 .41666 .606 .41593 .59625 Mtetra
.945 .678 .501 r
.41593 .59625 .41666 .606 .42441 .41123 .42377 .40019 Mtetra
.644 .44 .592 r
.42377 .40019 .42441 .41123 .42627 .40264 .42547 .39694 Mtetra
.605 .444 .637 r
.42547 .39694 .42627 .40264 .4279 .40187 .4271 .39612 Mtetra
.573 .421 .636 r
.4271 .39612 .4279 .40187 .4295 .40176 .4287 .39585 Mtetra
.569 .416 .634 r
.4287 .39585 .4295 .40176 .43114 .40056 .43031 .39564 Mtetra
.596 .449 .652 r
.43031 .39564 .43114 .40056 .43282 .3979 .43193 .3951 Mtetra
.623 .528 .726 r
.43193 .3951 .43282 .3979 .43449 .39583 .43355 .39455 Mtetra
.656 .688 .868 r
.43355 .39455 .43449 .39583 .43613 .39447 .43517 .39402 Mtetra
.613 .865 .99 r
.43517 .39402 .43613 .39447 .43775 .39383 .43679 .39351 Mtetra
.579 .887 .991 r
.43679 .39351 .43775 .39383 .43937 .3934 .43841 .39301 Mtetra
.607 .877 .992 r
.43841 .39301 .43937 .3934 .44099 .39306 .44004 .39249 Mtetra
.645 .843 .976 r
.44004 .39249 .44099 .39306 .44261 .39266 .44166 .39194 Mtetra
.661 .808 .954 r
.44166 .39194 .44261 .39266 .44423 .39227 .44329 .39139 Mtetra
.67 .77 .925 r
.44329 .39139 .44423 .39227 .44585 .39184 .44491 .39081 Mtetra
.674 .741 .901 r
.44491 .39081 .44585 .39184 .44748 .39132 .44654 .39022 Mtetra
.671 .726 .891 r
.44654 .39022 .44748 .39132 .44911 .39074 .44817 .38963 Mtetra
.663 .722 .893 r
.44817 .38963 .44911 .39074 .45074 .39009 .4498 .38908 Mtetra
.648 .738 .915 r
.4498 .38908 .45074 .39009 .45237 .38935 .45143 .3886 Mtetra
.637 .793 .958 r
.45143 .3886 .45237 .38935 .45401 .38861 .45306 .38812 Mtetra
.668 .869 .975 r
.45306 .38812 .45401 .38861 .45564 .38783 .45469 .38748 Mtetra
.751 .917 .947 r
.45469 .38748 .45564 .38783 .45728 .38696 .45634 .38652 Mtetra
.617 .87 .99 r
.45634 .38652 .45728 .38696 .45891 .38643 .45797 .38599 Mtetra
.32 0 0 r
.45797 .38599 .45891 .38643 .46053 .38676 .45958 .38677 Mtetra
.928 .584 .361 r
.45958 .38677 .46053 .38676 .4621 .38969 .46105 .39444 Mtetra
.953 .677 .477 r
.46105 .39444 .4621 .38969 .46007 .58177 .45884 .59318 Mtetra
.623 .356 .493 r
.45884 .59318 .46007 .58177 .4616 .59231 .46051 .59633 Mtetra
.507 .193 .369 r
.46051 .59633 .4616 .59231 .46334 .5922 .46225 .59625 Mtetra
.441 .133 .346 r
.46225 .59625 .46334 .5922 .46509 .59131 .464 .59552 Mtetra
.425 .122 .346 r
.464 .59552 .46509 .59131 .46683 .59108 .46576 .5946 Mtetra
.453 .13 .327 r
.46576 .5946 .46683 .59108 .46854 .59282 .46751 .5941 Mtetra
.26 0 0 r
.46751 .5941 .46854 .59282 .47026 .59401 .46926 .59359 Mtetra
.581 .871 .994 r
.46926 .59359 .47026 .59401 .472 .59454 .47101 .59308 Mtetra
.643 .672 .863 r
.47101 .59308 .472 .59454 .47375 .59416 .47277 .59258 Mtetra
.644 .654 .845 r
.47277 .59258 .47375 .59416 .4755 .59358 .47452 .59205 Mtetra
.65 .664 .85 r
.47452 .59205 .4755 .59358 .47726 .59298 .47628 .59149 Mtetra
.662 .675 .852 r
.47628 .59149 .47726 .59298 .47901 .59262 .47803 .59087 Mtetra
.656 .639 .821 r
.47803 .59087 .47901 .59262 .48077 .59227 .47979 .59025 Mtetra
.645 .606 .796 r
.47979 .59025 .48077 .59227 .48252 .59189 .48155 .58965 Mtetra
.628 .579 .78 r
.48155 .58965 .48252 .59189 .48428 .59141 .48331 .58914 Mtetra
.625 .575 .779 r
.48331 .58914 .48428 .59141 .48604 .5909 .48507 .58866 Mtetra
.624 .577 .781 r
.48507 .58866 .48604 .5909 .4878 .59038 .48683 .58818 Mtetra
.629 .582 .783 r
.48683 .58818 .4878 .59038 .48957 .58987 .4886 .58767 Mtetra
.629 .583 .784 r
.4886 .58767 .48957 .58987 .49133 .58935 .49036 .58716 Mtetra
.63 .584 .784 r
.49036 .58716 .49133 .58935 .4931 .58883 .49213 .58664 Mtetra
.63 .585 .784 r
.49213 .58664 .4931 .58883 .49486 .58831 .49389 .58612 Mtetra
.631 .585 .784 r
.49389 .58612 .49486 .58831 .49663 .58779 .49566 .5856 Mtetra
.49566 .5856 .49663 .58779 .4984 .58726 .49743 .58507 Mtetra
.49743 .58507 .4984 .58726 .50017 .58674 .4992 .58455 Mtetra
.4992 .58455 .50017 .58674 .50194 .58621 .50097 .58402 Mtetra
.632 .585 .784 r
.50097 .58402 .50194 .58621 .50371 .58568 .50275 .58349 Mtetra
.50275 .58349 .50371 .58568 .50549 .58515 .50452 .58296 Mtetra
.632 .586 .784 r
.50452 .58296 .50549 .58515 .50726 .58462 .50629 .58243 Mtetra
.50629 .58243 .50726 .58462 .50904 .58409 .50807 .5819 Mtetra
.632 .585 .784 r
.50807 .5819 .50904 .58409 .51082 .58356 .50985 .58136 Mtetra
.632 .586 .784 r
.50985 .58136 .51082 .58356 .51259 .58303 .51162 .58082 Mtetra
.633 .586 .783 r
.51162 .58082 .51259 .58303 .51437 .58249 .5134 .58028 Mtetra
.633 .585 .783 r
.5134 .58028 .51437 .58249 .51615 .58195 .51518 .57974 Mtetra
.633 .585 .782 r
.51518 .57974 .51615 .58195 .51794 .58141 .51697 .57919 Mtetra
.634 .585 .782 r
.51697 .57919 .51794 .58141 .51972 .58086 .51875 .57864 Mtetra
.637 .586 .78 r
.51875 .57864 .51972 .58086 .5215 .58033 .52053 .57805 Mtetra
.635 .581 .777 r
.52053 .57805 .5215 .58033 .52329 .57977 .52232 .57748 Mtetra
.631 .578 .776 r
.52232 .57748 .52329 .57977 .52507 .57919 .52411 .57694 Mtetra
.619 .575 .783 r
.52411 .57694 .52507 .57919 .52686 .57849 .52589 .57649 Mtetra
.621 .598 .806 r
.52589 .57649 .52686 .57849 .52865 .57779 .52768 .57606 Mtetra
.626 .631 .836 r
.52768 .57606 .52865 .57779 .53044 .57709 .52947 .57562 Mtetra
.642 .672 .864 r
.52947 .57562 .53044 .57709 .53223 .57668 .53126 .57511 Mtetra
.645 .659 .849 r
.53126 .57511 .53223 .57668 .53402 .57618 .53305 .57457 Mtetra
.647 .655 .844 r
.53305 .57457 .53402 .57618 .53581 .57544 .53485 .57402 Mtetra
.65 .684 .868 r
.53485 .57402 .53581 .57544 .5376 .57363 .53664 .57346 Mtetra
.504 .891 .957 r
.53664 .57346 .5376 .57363 .53939 .57124 .53844 .5729 Mtetra
.318 0 .088 r
.53844 .5729 .53939 .57124 .54117 .56831 .54023 .57234 Mtetra
.509 .194 .368 r
.54023 .57234 .54117 .56831 .54297 .56802 .54204 .57228 Mtetra
.479 .172 .367 r
.54204 .57228 .54297 .56802 .54477 .56777 .54384 .57186 Mtetra
.397 .096 .333 r
.54384 .57186 .54477 .56777 .54656 .56651 .54563 .5707 Mtetra
0 0 .035 r
.54563 .5707 .54656 .56651 .547 .37084 .5474 .56515 Mtetra
0 0 .337 r
.5474 .56515 .547 .37084 .54862 .35956 .54775 .36208 Mtetra
.855 .816 .333 r
.54775 .36208 .54862 .35956 .55029 .35603 .5494 .35579 Mtetra
.819 .951 .905 r
.5494 .35579 .55029 .35603 .55197 .35493 .55108 .35445 Mtetra
.601 .864 .993 r
.55108 .35445 .55197 .35493 .55366 .3544 .55277 .35395 Mtetra
.398 .782 .99 r
.55277 .35395 .55366 .3544 .55536 .35416 .55447 .35381 Mtetra
.615 .9 .987 r
.55447 .35381 .55536 .35416 .55705 .35377 .55616 .3532 Mtetra
.671 .861 .972 r
.55616 .3532 .55705 .35377 .55875 .35338 .55786 .35255 Mtetra
.68 .797 .937 r
.55786 .35255 .55875 .35338 .56045 .35295 .55955 .3519 Mtetra
.665 .744 .909 r
.55955 .3519 .56045 .35295 .56214 .3523 .56125 .35132 Mtetra
.66 .757 .922 r
.56125 .35132 .56214 .3523 .56384 .35158 .56295 .35076 Mtetra
.655 .793 .948 r
.56295 .35076 .56384 .35158 .56553 .35085 .56465 .35021 Mtetra
.657 .837 .969 r
.56465 .35021 .56553 .35085 .56723 .35008 .56635 .34961 Mtetra
.636 .877 .986 r
.56635 .34961 .56723 .35008 .56893 .34943 .56805 .34901 Mtetra
.62 .885 .989 r
.56805 .34901 .56893 .34943 .57063 .34902 .56975 .34842 Mtetra
.745 .87 .938 r
.56975 .34842 .57063 .34902 .57234 .34914 .57145 .34749 Mtetra
.668 .648 .821 r
.57145 .34749 .57234 .34914 .57407 .34992 .57315 .34681 Mtetra
.563 .481 .721 r
.57315 .34681 .57407 .34992 .57582 .35206 .57486 .34676 Mtetra
.211 .18 .604 r
.57486 .34676 .57582 .35206 .58078 .54765 .57663 .3502 Mtetra
0 0 .369 r
.57663 .3502 .58078 .54765 .58278 .55797 .58176 .55212 Mtetra
0 0 .477 r
.58176 .55212 .58278 .55797 .58466 .56062 .5837 .55855 Mtetra
.413 .48 .82 r
.5837 .55855 .58466 .56062 .5865 .56084 .58555 .55917 Mtetra
.645 .65 .84 r
.58555 .55917 .5865 .56084 .58833 .56029 .58737 .55862 Mtetra
.706 .674 .816 r
.58737 .55862 .58833 .56029 .59015 .55943 .58919 .55763 Mtetra
.638 .629 .826 r
.58919 .55763 .59015 .55943 .59198 .55896 .59103 .5571 Mtetra
.617 .614 .825 r
.59103 .5571 .59198 .55896 .59381 .55847 .59286 .55669 Mtetra
.623 .626 .833 r
.59286 .55669 .59381 .55847 .59564 .55774 .59469 .55625 Mtetra
.564 .638 .883 r
.59469 .55625 .59564 .55774 .59746 .55647 .59654 .5561 Mtetra
.493 .855 .99 r
.59654 .5561 .59746 .55647 .59926 .55451 .59837 .55569 Mtetra
.017 0 0 r
.59837 .55569 .59926 .55451 .60104 .55124 .6002 .55462 Mtetra
0 0 .039 r
.6002 .55462 .60104 .55124 .59885 .37668 .60195 .55025 Mtetra
0 0 .316 r
.60195 .55025 .59885 .37668 .5998 .34289 .59906 .34786 Mtetra
0 0 0 r
.59906 .34786 .5998 .34289 .60145 .33921 .6006 .33923 Mtetra
.892 .98 .815 r
.6006 .33923 .60145 .33921 .60315 .33794 .60229 .33727 Mtetra
.691 .843 .956 r
.60229 .33727 .60315 .33794 .60488 .3375 .60401 .33655 Mtetra
.58 .736 .949 r
.60401 .33655 .60488 .3375 .60661 .33738 .60574 .33626 Mtetra
.638 .722 .909 r
.60574 .33626 .60661 .33738 .60834 .33698 .60747 .33579 Mtetra
.656 .715 .892 r
.60747 .33579 .60834 .33698 .61007 .33642 .60919 .33524 Mtetra
.655 .718 .895 r
.60919 .33524 .61007 .33642 .61179 .33579 .61092 .33469 Mtetra
.667 .738 .903 r
.61092 .33469 .61179 .33579 .61351 .33494 .61265 .33409 Mtetra
.672 .796 .941 r
.61265 .33409 .61351 .33494 .61524 .33409 .61438 .33346 Mtetra
.659 .846 .972 r
.61438 .33346 .61524 .33409 .61697 .33348 .61611 .33284 Mtetra
.74 .865 .938 r
.61611 .33284 .61697 .33348 .61871 .33341 .61783 .33192 Mtetra
.689 .68 .836 r
.61783 .33192 .61871 .33341 .62048 .33401 .61956 .33113 Mtetra
.583 .506 .733 r
.61956 .33113 .62048 .33401 .62229 .33577 .6213 .33091 Mtetra
.316 .264 .64 r
.6213 .33091 .62229 .33577 .62449 .35005 .62313 .33336 Mtetra
.983 .696 .365 r
.62313 .33336 .62449 .35005 .63239 .54215 .63122 .53315 Mtetra
0 0 .457 r
.63122 .53315 .63239 .54215 .63437 .54526 .6334 .54286 Mtetra
.291 .372 .775 r
.6334 .54286 .63437 .54526 .63626 .54567 .63532 .54414 Mtetra
.606 .655 .872 r
.63532 .54414 .63626 .54567 .63811 .54501 .63719 .5438 Mtetra
.704 .746 .884 r
.63719 .5438 .63811 .54501 .63996 .544 .63904 .54295 Mtetra
.674 .767 .92 r
.63904 .54295 .63996 .544 .64182 .54347 .6409 .54227 Mtetra
.645 .725 .907 r
.6409 .54227 .64182 .54347 .64369 .54318 .64276 .54173 Mtetra
.648 .685 .871 r
.64276 .54173 .64369 .54318 .64556 .54267 .64463 .54117 Mtetra
.575 .644 .881 r
.64463 .54117 .64556 .54267 .64741 .54157 .64651 .54096 Mtetra
.502 .805 .999 r
.64651 .54096 .64741 .54157 .64923 .53974 .64839 .54069 Mtetra
.006 0 0 r
.64839 .54069 .64923 .53974 .651 .53678 .65024 .53978 Mtetra
0 0 .061 r
.65024 .53978 .651 .53678 .65254 .52746 .65199 .53608 Mtetra
.981 .697 .393 r
.65199 .53608 .65254 .52746 .64673 .32859 .64616 .335 Mtetra
0 0 .042 r
.64616 .335 .64673 .32859 .64834 .32428 .6475 .32369 Mtetra
.91 .869 .785 r
.6475 .32369 .64834 .32428 .65005 .32259 .64918 .32135 Mtetra
.68 .718 .878 r
.64918 .32135 .65005 .32259 .6518 .32195 .65093 .32067 Mtetra
.573 .666 .901 r
.65093 .32067 .6518 .32195 .65356 .32162 .6527 .32046 Mtetra
.616 .709 .911 r
.6527 .32046 .65356 .32162 .65531 .32097 .65447 .32007 Mtetra
.669 .788 .937 r
.65447 .32007 .65531 .32097 .65705 .32011 .65622 .31945 Mtetra
.655 .843 .972 r
.65622 .31945 .65705 .32011 .65881 .31946 .65798 .31884 Mtetra
.726 .872 .949 r
.65798 .31884 .65881 .31946 .66058 .31931 .65972 .31796 Mtetra
.704 .71 .853 r
.65972 .31796 .66058 .31931 .66239 .31984 .66147 .31711 Mtetra
.595 .522 .743 r
.66147 .31711 .66239 .31984 .66425 .32147 .66324 .3168 Mtetra
.374 .309 .655 r
.66324 .3168 .66425 .32147 .66645 .33065 .66512 .31873 Mtetra
.981 .688 .357 r
.66512 .31873 .66645 .33065 .67723 .52829 .6758 .51543 Mtetra
0 0 .453 r
.6758 .51543 .67723 .52829 .6793 .53174 .67833 .52903 Mtetra
.226 .308 .739 r
.67833 .52903 .6793 .53174 .68126 .5326 .68032 .53081 Mtetra
.587 .611 .843 r
.68032 .53081 .68126 .5326 .68316 .53225 .68223 .53056 Mtetra
.679 .668 .832 r
.68223 .53056 .68316 .53225 .68503 .53132 .68411 .52976 Mtetra
.632 .664 .863 r
.68411 .52976 .68503 .53132 .68689 .52999 .68601 .52927 Mtetra
.531 .792 .993 r
.68601 .52927 .68689 .52999 .68872 .52815 .68791 .52898 Mtetra
0 0 0 r
.68791 .52898 .68872 .52815 .6905 .52523 .68979 .52808 Mtetra
0 0 .091 r
.68979 .52808 .6905 .52523 .69201 .51708 .69156 .52481 Mtetra
.982 .693 .377 r
.69156 .52481 .69201 .51708 .68377 .31642 .68358 .32831 Mtetra
0 0 .228 r
.68358 .32831 .68377 .31642 .68534 .31181 .68454 .31146 Mtetra
.947 .901 .746 r
.68454 .31146 .68534 .31181 .68704 .30971 .6862 .30868 Mtetra
.71 .773 .901 r
.6862 .30868 .68704 .30971 .68879 .30875 .68797 .30786 Mtetra
.575 .756 .964 r
.68797 .30786 .68879 .30875 .69058 .3083 .68976 .30756 Mtetra
.64 .819 .969 r
.68976 .30756 .69058 .3083 .69238 .30826 .69154 .307 Mtetra
.707 .73 .868 r
.69154 .307 .69238 .30826 .69422 .30871 .6933 .30616 Mtetra
.602 .538 .755 r
.6933 .30616 .69422 .30871 .69611 .31014 .6951 .3058 Mtetra
.413 .345 .671 r
.6951 .3058 .69611 .31014 .69826 .31623 .69699 .30729 Mtetra
0 0 .392 r
.69699 .30729 .69826 .31623 .7113 .51718 .69949 .31961 Mtetra
.01 0 .42 r
.69949 .31961 .7113 .51718 .71346 .52119 .71247 .51814 Mtetra
.174 .251 .703 r
.71247 .51814 .71346 .52119 .71547 .52231 .71454 .52045 Mtetra
.57 .596 .839 r
.71454 .52045 .71547 .52231 .7174 .52204 .71648 .52029 Mtetra
.67 .659 .83 r
.71648 .52029 .7174 .52204 .7193 .52117 .71838 .51954 Mtetra
.647 .663 .851 r
.71838 .51954 .7193 .52117 .72117 .51989 .7203 .51895 Mtetra
.552 .75 .97 r
.7203 .51895 .72117 .51989 .72302 .51815 .72223 .51869 Mtetra
0 0 0 r
.72223 .51869 .72302 .51815 .72481 .5154 .72414 .51787 Mtetra
0 0 .08 r
.72414 .51787 .72481 .5154 .72633 .50838 .72593 .51516 Mtetra
0 0 .115 r
.72593 .51516 .72633 .50838 .71592 .30591 .72718 .50355 Mtetra
.007 0 .413 r
.72718 .50355 .71592 .30591 .71745 .30097 .71674 .30176 Mtetra
.869 .92 .524 r
.71674 .30176 .71745 .30097 .71915 .29891 .71836 .29838 Mtetra
.734 .902 .954 r
.71836 .29838 .71915 .29891 .72095 .29829 .72014 .29743 Mtetra
.598 .774 .964 r
.72014 .29743 .72095 .29829 .72277 .29808 .72195 .29704 Mtetra
.589 .726 .938 r
.72195 .29704 .72277 .29808 .72459 .29786 .72376 .29672 Mtetra
.653 .732 .907 r
.72376 .29672 .72459 .29786 .72639 .29732 .72557 .29616 Mtetra
.652 .729 .905 r
.72557 .29616 .72639 .29732 .72819 .2967 .72737 .2956 Mtetra
.664 .745 .911 r
.72737 .2956 .72819 .2967 .72998 .29592 .72917 .29499 Mtetra
.681 .79 .932 r
.72917 .29499 .72998 .29592 .73176 .29498 .73097 .2943 Mtetra
.675 .851 .967 r
.73097 .2943 .73176 .29498 .73355 .29421 .73277 .2936 Mtetra
.716 .881 .958 r
.73277 .2936 .73355 .29421 .73537 .29384 .73455 .29274 Mtetra
.74 .772 .878 r
.73455 .29274 .73537 .29384 .73724 .29415 .73633 .29172 Mtetra
.626 .562 .762 r
.73633 .29172 .73724 .29415 .73916 .29527 .73814 .29118 Mtetra
.466 .388 .684 r
.73814 .29118 .73916 .29527 .74129 .29917 .74006 .29213 Mtetra
0 0 .508 r
.74006 .29213 .74129 .29917 .75724 .50086 .74246 .29993 Mtetra
.028 0 .431 r
.74246 .29993 .75724 .50086 .75959 .50613 .75863 .50359 Mtetra
0 .119 .656 r
.75863 .50359 .75959 .50613 .76168 .50768 .76082 .50657 Mtetra
.532 .703 .949 r
.76082 .50657 .76168 .50768 .76366 .50753 .7628 .50642 Mtetra
.694 .773 .912 r
.7628 .50642 .76366 .50753 .76559 .50677 .76473 .50562 Mtetra
.683 .761 .91 r
.76473 .50562 .76559 .50677 .76749 .50557 .76666 .50487 Mtetra
.453 .763 .996 r
.76666 .50487 .76749 .50557 .76937 .50405 .76864 .50473 Mtetra
.042 0 0 r
.76864 .50473 .76937 .50405 .77119 .50169 .77059 .50409 Mtetra
.087 0 .126 r
.77059 .50409 .77119 .50169 .7728 .49665 .77242 .5019 Mtetra
0 0 .117 r
.77242 .5019 .7728 .49665 .75952 .29379 .77374 .49287 Mtetra
.024 0 .425 r
.77374 .49287 .75952 .29379 .76091 .28749 .76021 .28773 Mtetra
.978 .913 .597 r
.76021 .28773 .76091 .28749 .76259 .28492 .76177 .28371 Mtetra
.731 .752 .869 r
.76177 .28371 .76259 .28492 .76439 .28406 .76357 .28272 Mtetra
.614 .682 .89 r
.76357 .28272 .76439 .28406 .76623 .28362 .76541 .28234 Mtetra
.614 .69 .898 r
.76541 .28234 .76623 .28362 .76806 .28313 .76725 .28195 Mtetra
.744 .762 .868 r
.76725 .28195 .76806 .28313 .76985 .28205 .76905 .28089 Mtetra
.662 .736 .904 r
.76905 .28089 .76985 .28205 .77168 .28144 .77087 .28028 Mtetra
.249 .514 .908 r
.77087 .28028 .77168 .28144 .77362 .28219 .77281 .28096 Mtetra
.876 .486 .02 r
.77281 .28096 .77362 .28219 .77619 .29075 .77527 .28818 Mtetra
.975 .668 .329 r
.77527 .28818 .77619 .29075 .79466 .49474 .79376 .49296 Mtetra
0 0 .534 r
.79376 .49296 .79466 .49474 .79693 .49779 .79605 .49629 Mtetra
.553 .641 .891 r
.79605 .49629 .79693 .49779 .79892 .49749 .79805 .49616 Mtetra
.691 .734 .883 r
.79805 .49616 .79892 .49749 .80086 .49652 .80001 .49534 Mtetra
.717 .771 .895 r
.80001 .49534 .80086 .49652 .80279 .49554 .80195 .4944 Mtetra
.554 .709 .943 r
.80195 .4944 .80279 .49554 .80482 .49558 .80395 .49418 Mtetra
.665 .71 .881 r
.80395 .49418 .80482 .49558 .80681 .49518 .80592 .4935 Mtetra
.802 .725 .779 r
.80592 .4935 .80681 .49518 .80869 .49353 .80778 .49156 Mtetra
.949 .725 .565 r
.80778 .49156 .80869 .49353 .81011 .48652 .80911 .48345 Mtetra
.976 .673 .35 r
.80911 .48345 .81011 .48652 .7941 .27872 .79327 .2771 Mtetra
.92 .744 .647 r
.79327 .2771 .7941 .27872 .79556 .27372 .79477 .27261 Mtetra
.751 .78 .877 r
.79477 .27261 .79556 .27372 .79736 .27261 .79658 .27152 Mtetra
.626 .738 .927 r
.79658 .27152 .79736 .27261 .79922 .27217 .79844 .27106 Mtetra
.591 .718 .931 r
.79844 .27106 .79922 .27217 .8011 .27188 .80031 .27073 Mtetra
.751 .773 .871 r
.80031 .27073 .8011 .27188 .8029 .27079 .80211 .26962 Mtetra
.677 .744 .901 r
.80211 .26962 .8029 .27079 .80475 .2701 .80396 .26893 Mtetra
.393 .599 .929 r
.80396 .26893 .80475 .2701 .80668 .27045 .80589 .26926 Mtetra
.805 .395 0 r
.80589 .26926 .80668 .27045 .80911 .27609 .80831 .27483 Mtetra
.973 .662 .315 r
.80831 .27483 .80911 .27609 .83008 .48249 .82925 .48133 Mtetra
.701 .265 0 r
.82925 .48133 .83008 .48249 .83251 .48665 .83168 .48555 Mtetra
.343 .604 .945 r
.83168 .48555 .83251 .48665 .83458 .48691 .83377 .48594 Mtetra
.674 .801 .943 r
.83377 .48594 .83458 .48691 .83656 .48617 .83575 .48521 Mtetra
.867 .848 .823 r
.83575 .48521 .83656 .48617 .83845 .48443 .83761 .48316 Mtetra
.972 .766 .567 r
.83761 .48316 .83845 .48443 .84014 .48058 .83899 .47608 Mtetra
.975 .669 .339 r
.83899 .47608 .84014 .48058 .84105 .46873 .82114 .26838 Mtetra
.555 .335 .537 r
.82114 .26838 .84105 .46873 .82379 .26903 .82256 .26325 Mtetra
.618 .455 .638 r
.82256 .26325 .82379 .26903 .8254 .26583 .82438 .2621 Mtetra
.599 .485 .695 r
.82438 .2621 .8254 .26583 .82714 .26393 .82625 .26162 Mtetra
.576 .546 .784 r
.82625 .26162 .82714 .26393 .82894 .26265 .82816 .26146 Mtetra
.662 .736 .904 r
.82816 .26146 .82894 .26265 .83079 .26187 .83003 .26084 Mtetra
.658 .766 .929 r
.83003 .26084 .83079 .26187 .83267 .26131 .8319 .26023 Mtetra
.659 .758 .923 r
.8319 .26023 .83267 .26131 .83454 .26077 .83377 .25962 Mtetra
.732 .771 .884 r
.83377 .25962 .83454 .26077 .83635 .25951 .8356 .25863 Mtetra
.652 .802 .955 r
.8356 .25863 .83635 .25951 .83819 .25865 .83748 .25803 Mtetra
.26 .662 .966 r
.83748 .25803 .83819 .25865 .84012 .2586 .83943 .25825 Mtetra
.906 .504 .111 r
.83943 .25825 .84012 .2586 .84269 .26471 .84219 .26619 Mtetra
.971 .655 .305 r
.84219 .26619 .84269 .26471 .86612 .47223 .86538 .47172 Mtetra
.686 .174 0 r
.86538 .47172 .86612 .47223 .86857 .47574 .86776 .47464 Mtetra
.965 .802 .631 r
.86776 .47464 .86857 .47574 .8701 .47058 .86932 .4697 Mtetra
.974 .667 .312 r
.86932 .4697 .8701 .47058 .85014 .26154 .84942 .26082 Mtetra
.993 .788 .525 r
.84942 .26082 .85014 .26154 .85138 .25484 .85061 .25364 Mtetra
.82 .762 .798 r
.24489 .4566 .2459 .45752 .24749 .45604 .24649 .45493 Mtetra
.695 .717 .866 r
.24649 .45493 .24749 .45604 .249 .45553 .24802 .45425 Mtetra
.412 .573 .903 r
.24802 .45425 .249 .45553 .25043 .45598 .24947 .45453 Mtetra
.929 .548 .174 r
.24947 .45453 .25043 .45598 .25156 .46006 .2506 .45854 Mtetra
.939 .683 .525 r
.2506 .45854 .25156 .46006 .23674 .65683 .23563 .6563 Mtetra
.923 .578 .363 r
.23563 .6563 .23674 .65683 .23786 .66226 .23673 .66186 Mtetra
.107 .621 .89 r
.23673 .66186 .23786 .66226 .2394 .66259 .23829 .66204 Mtetra
.693 .85 .958 r
.23829 .66204 .2394 .66259 .24101 .66206 .23991 .66135 Mtetra
.774 .817 .886 r
.23991 .66135 .24101 .66206 .24265 .66111 .24157 .66025 Mtetra
.487 .718 .973 r
.24157 .66025 .24265 .66111 .24423 .66102 .24315 .66019 Mtetra
.56 .752 .967 r
.24315 .66019 .24423 .66102 .24584 .66061 .24474 .65996 Mtetra
.708 .827 .939 r
.24474 .65996 .24584 .66061 .2475 .65947 .24637 .65922 Mtetra
.92 .828 .738 r
.24637 .65922 .2475 .65947 .2495 .65409 .2482 .65606 Mtetra
.996 .851 .578 r
.2482 .65606 .2495 .65409 .26665 .45636 .25038 .64832 Mtetra
0 0 .185 r
.25038 .64832 .26665 .45636 .2686 .4504 .26718 .45478 Mtetra
.249 0 .28 r
.26718 .45478 .2686 .4504 .27018 .44908 .26882 .45271 Mtetra
.471 .157 .351 r
.26882 .45271 .27018 .44908 .2717 .44863 .27034 .45234 Mtetra
.555 .241 .391 r
.27034 .45234 .2717 .44863 .27319 .44857 .2718 .45274 Mtetra
.542 .237 .4 r
.2718 .45274 .27319 .44857 .27471 .44817 .27327 .45298 Mtetra
.511 .218 .405 r
.27327 .45298 .27471 .44817 .27623 .44773 .27477 .45284 Mtetra
.429 .146 .38 r
.27477 .45284 .27623 .44773 .27776 .44727 .27634 .45178 Mtetra
.045 0 .19 r
.27634 .45178 .27776 .44727 .27929 .44669 .27807 .44863 Mtetra
0 0 0 r
.27807 .44863 .27929 .44669 .28083 .44608 .27976 .44606 Mtetra
.895 .921 .83 r
.27976 .44606 .28083 .44608 .28236 .44548 .28139 .44419 Mtetra
.714 .695 .83 r
.28139 .44419 .28236 .44548 .28389 .44495 .28295 .44333 Mtetra
.647 .627 .817 r
.28295 .44333 .28389 .44495 .28542 .44446 .28448 .44283 Mtetra
.62 .615 .824 r
.28448 .44283 .28542 .44446 .28696 .44397 .286 .44248 Mtetra
.647 .644 .833 r
.286 .44248 .28696 .44397 .28849 .44346 .28753 .44199 Mtetra
.653 .65 .834 r
.28753 .44199 .28849 .44346 .29002 .44294 .28907 .44148 Mtetra
.653 .651 .835 r
.28907 .44148 .29002 .44294 .29156 .44241 .2906 .44096 Mtetra
.655 .653 .836 r
.2906 .44096 .29156 .44241 .2931 .44189 .29214 .44044 Mtetra
.653 .652 .837 r
.29214 .44044 .2931 .44189 .29464 .44137 .29368 .43993 Mtetra
.648 .652 .84 r
.29368 .43993 .29464 .44137 .29617 .44085 .29521 .43945 Mtetra
.631 .65 .851 r
.29521 .43945 .29617 .44085 .29771 .44034 .29674 .43905 Mtetra
.624 .666 .87 r
.29674 .43905 .29771 .44034 .29925 .43984 .29827 .43869 Mtetra
.626 .693 .892 r
.29827 .43869 .29925 .43984 .30079 .43932 .2998 .43832 Mtetra
.646 .728 .908 r
.2998 .43832 .30079 .43932 .30234 .43879 .30134 .43787 Mtetra
.662 .751 .916 r
.30134 .43787 .30234 .43879 .30388 .43824 .30288 .43736 Mtetra
.676 .761 .915 r
.30288 .43736 .30388 .43824 .30543 .4377 .30443 .43678 Mtetra
.697 .759 .9 r
.30443 .43678 .30543 .4377 .30697 .43719 .30599 .43612 Mtetra
.699 .728 .873 r
.30599 .43612 .30697 .43719 .30851 .4367 .30755 .43541 Mtetra
.689 .69 .846 r
.30755 .43541 .30851 .4367 .31006 .4362 .3091 .43472 Mtetra
.668 .656 .828 r
.3091 .43472 .31006 .4362 .31161 .43564 .31066 .43411 Mtetra
.658 .644 .825 r
.31066 .43411 .31161 .43564 .31316 .43507 .31221 .43355 Mtetra
.654 .645 .828 r
.31221 .43355 .31316 .43507 .31471 .4345 .31376 .43302 Mtetra
.692 .664 .818 r
.31376 .43302 .31471 .4345 .31629 .43362 .31533 .43225 Mtetra
.682 .676 .838 r
.31533 .43225 .31629 .43362 .31785 .43289 .31689 .43158 Mtetra
.604 .655 .874 r
.31689 .43158 .31785 .43289 .31938 .43275 .31842 .4313 Mtetra
0 .165 .703 r
.31842 .4313 .31938 .43275 .32073 .43543 .31986 .43268 Mtetra
.792 .474 0 r
.31986 .43268 .32073 .43543 .31006 .63141 .32109 .43732 Mtetra
0 0 .238 r
.32109 .43732 .31006 .63141 .31118 .63948 .31055 .63174 Mtetra
.394 .272 .593 r
.31055 .63174 .31118 .63948 .31274 .64056 .31202 .63417 Mtetra
.589 .428 .631 r
.31202 .63417 .31274 .64056 .31438 .64014 .31367 .63359 Mtetra
.602 .436 .629 r
.31367 .63359 .31438 .64014 .31606 .63926 .31535 .63273 Mtetra
.448 .324 .618 r
.31535 .63273 .31606 .63926 .31772 .63869 .31688 .63421 Mtetra
.345 .29 .652 r
.31688 .63421 .31772 .63869 .31937 .63831 .3184 .63597 Mtetra
.28 .363 .77 r
.3184 .63597 .31937 .63831 .32102 .63791 .31997 .63706 Mtetra
.335 .651 .969 r
.31997 .63706 .32102 .63791 .32268 .63744 .32158 .63727 Mtetra
.371 .819 .944 r
.32158 .63727 .32268 .63744 .32434 .63692 .32323 .63698 Mtetra
.385 .846 .874 r
.32323 .63698 .32434 .63692 .326 .63637 .32489 .6365 Mtetra
.239 .756 .79 r
.32489 .6365 .326 .63637 .32764 .63619 .32655 .63613 Mtetra
.433 .864 .929 r
.32655 .63613 .32764 .63619 .32929 .63594 .32821 .63568 Mtetra
.713 .924 .963 r
.32821 .63568 .32929 .63594 .33097 .63512 .32989 .63481 Mtetra
.897 .871 .804 r
.32989 .63481 .33097 .63512 .3328 .6317 .33166 .63258 Mtetra
.985 .887 .644 r
.33166 .63258 .3328 .6317 .34506 .43908 .33356 .62779 Mtetra
0 0 .225 r
.33356 .62779 .34506 .43908 .34737 .42514 .34592 .43275 Mtetra
0 0 .135 r
.34592 .43275 .34737 .42514 .34904 .42275 .34788 .42509 Mtetra
0 0 0 r
.34788 .42509 .34904 .42275 .35062 .42198 .34957 .42239 Mtetra
.833 .999 .814 r
.34957 .42239 .35062 .42198 .35218 .42169 .35121 .42071 Mtetra
.748 .761 .863 r
.35121 .42071 .35218 .42169 .35374 .42132 .3528 .41973 Mtetra
.656 .639 .822 r
.3528 .41973 .35374 .42132 .35531 .42082 .35438 .41918 Mtetra
.619 .616 .826 r
.35438 .41918 .35531 .42082 .35689 .42034 .35594 .41882 Mtetra
.617 .631 .843 r
.35594 .41882 .35689 .42034 .35846 .41982 .35751 .41848 Mtetra
.625 .661 .865 r
.35751 .41848 .35846 .41982 .36004 .41928 .35908 .4181 Mtetra
.633 .693 .888 r
.35908 .4181 .36004 .41928 .36161 .41873 .36065 .4177 Mtetra
.672 .733 .895 r
.36065 .4177 .36161 .41873 .36319 .4182 .36223 .41712 Mtetra
.698 .733 .878 r
.36223 .41712 .36319 .4182 .36477 .41767 .36382 .41642 Mtetra
.694 .701 .852 r
.36382 .41642 .36477 .41767 .36635 .41715 .3654 .4157 Mtetra
.702 .675 .821 r
.3654 .4157 .36635 .41715 .36794 .41633 .367 .41487 Mtetra
.692 .67 .824 r
.367 .41487 .36794 .41633 .36954 .41549 .36859 .4141 Mtetra
.628 .656 .858 r
.36859 .4141 .36954 .41549 .37111 .41516 .37017 .41371 Mtetra
.213 .43 .856 r
.37017 .41371 .37111 .41516 .37259 .41692 .37169 .4145 Mtetra
0 0 .396 r
.37169 .4145 .37259 .41692 .36551 .60255 .3731 .41764 Mtetra
0 0 .249 r
.3731 .41764 .36551 .60255 .36627 .62203 .3657 .6111 Mtetra
.06 .004 .473 r
.3657 .6111 .36627 .62203 .36784 .62396 .36699 .61914 Mtetra
.34 .279 .642 r
.36699 .61914 .36784 .62396 .36951 .62379 .36856 .6211 Mtetra
.404 .413 .755 r
.36856 .6211 .36951 .62379 .37121 .62306 .37019 .62192 Mtetra
.478 .653 .936 r
.37019 .62192 .37121 .62306 .37291 .62231 .37185 .62198 Mtetra
.539 .869 .993 r
.37185 .62198 .37291 .62231 .37461 .62171 .37354 .62153 Mtetra
.6 .919 .973 r
.37354 .62153 .37461 .62171 .3763 .62109 .37524 .62088 Mtetra
.6 .914 .978 r
.37524 .62088 .3763 .62109 .378 .6205 .37694 .62024 Mtetra
.569 .894 .986 r
.37694 .62024 .378 .6205 .37969 .61998 .37864 .6197 Mtetra
.574 .892 .988 r
.37864 .6197 .37969 .61998 .38139 .61948 .38034 .61916 Mtetra
.58 .887 .991 r
.38034 .61916 .38139 .61948 .38308 .61897 .38203 .61862 Mtetra
.581 .882 .992 r
.38203 .61862 .38308 .61897 .38478 .61846 .38373 .6181 Mtetra
.58 .879 .993 r
.38373 .6181 .38478 .61846 .38648 .61796 .38543 .61759 Mtetra
.577 .877 .993 r
.38543 .61759 .38648 .61796 .38818 .61745 .38713 .61709 Mtetra
.573 .877 .994 r
.38713 .61709 .38818 .61745 .38988 .61694 .38883 .61659 Mtetra
.568 .877 .993 r
.38883 .61659 .38988 .61694 .39158 .61644 .39053 .6161 Mtetra
.564 .879 .992 r
.39053 .6161 .39158 .61644 .39328 .61592 .39224 .61561 Mtetra
.558 .881 .991 r
.39224 .61561 .39328 .61592 .39499 .6154 .39394 .61511 Mtetra
.549 .884 .988 r
.39394 .61511 .39499 .6154 .39669 .61488 .39564 .61461 Mtetra
.544 .885 .986 r
.39564 .61461 .39669 .61488 .39839 .61441 .39735 .61412 Mtetra
.552 .883 .989 r
.39735 .61412 .39839 .61441 .4001 .61398 .39906 .61362 Mtetra
.571 .877 .994 r
.39906 .61362 .4001 .61398 .4018 .61355 .40077 .61312 Mtetra
.544 .851 .998 r
.40077 .61312 .4018 .61355 .40351 .61312 .40247 .61272 Mtetra
.497 .841 .997 r
.40247 .61272 .40351 .61312 .40522 .61266 .40418 .61238 Mtetra
.565 .891 .987 r
.40418 .61238 .40522 .61266 .40693 .61217 .40589 .61185 Mtetra
.746 .922 .95 r
.40589 .61185 .40693 .61217 .40863 .61183 .40762 .61085 Mtetra
.824 .782 .813 r
.40762 .61085 .40863 .61183 .41034 .61159 .40937 .6091 Mtetra
.79 .64 .695 r
.40937 .6091 .41034 .61159 .41206 .61083 .41117 .60629 Mtetra
.824 .611 .613 r
.41117 .60629 .41206 .61083 .41384 .60829 .4131 .59898 Mtetra
.945 .679 .501 r
.4131 .59898 .41384 .60829 .41593 .59625 .42113 .40215 Mtetra
.555 .336 .538 r
.42113 .40215 .41593 .59625 .42377 .40019 .42288 .39751 Mtetra
.746 .603 .698 r
.42288 .39751 .42377 .40019 .42547 .39694 .42454 .39545 Mtetra
.684 .667 .827 r
.42454 .39545 .42547 .39694 .4271 .39612 .42616 .39472 Mtetra
.614 .651 .863 r
.42616 .39472 .4271 .39612 .4287 .39585 .42777 .39438 Mtetra
.59 .63 .86 r
.42777 .39438 .4287 .39585 .43031 .39564 .42938 .39416 Mtetra
.619 .641 .851 r
.42938 .39416 .43031 .39564 .43193 .3951 .43099 .39381 Mtetra
.616 .671 .88 r
.43099 .39381 .43193 .3951 .43355 .39455 .43261 .39346 Mtetra
.626 .713 .908 r
.43261 .39346 .43355 .39455 .43517 .39402 .43423 .39307 Mtetra
.649 .749 .923 r
.43423 .39307 .43517 .39402 .43679 .39351 .43585 .39258 Mtetra
.664 .757 .919 r
.43585 .39258 .43679 .39351 .43841 .39301 .43747 .39202 Mtetra
.682 .752 .905 r
.43747 .39202 .43841 .39301 .44004 .39249 .4391 .3914 Mtetra
.695 .735 .882 r
.4391 .3914 .44004 .39249 .44166 .39194 .44073 .39069 Mtetra
.691 .706 .859 r
.44073 .39069 .44166 .39194 .44329 .39139 .44236 .38998 Mtetra
.687 .681 .838 r
.44236 .38998 .44329 .39139 .44491 .39081 .44399 .38925 Mtetra
.683 .658 .82 r
.44399 .38925 .44491 .39081 .44654 .39022 .44562 .38851 Mtetra
.649 .627 .814 r
.44562 .38851 .44654 .39022 .44817 .38963 .44725 .38797 Mtetra
.557 .588 .841 r
.44725 .38797 .44817 .38963 .4498 .38908 .44887 .3879 Mtetra
.053 .386 .848 r
.44887 .3879 .4498 .38908 .45143 .3886 .45046 .38881 Mtetra
.743 .252 .072 r
.45046 .38881 .45143 .3886 .45306 .38812 .45205 .39045 Mtetra
.673 .315 .358 r
.45205 .39045 .45306 .38812 .45469 .38748 .45363 .39209 Mtetra
.43 .14 .37 r
.45363 .39209 .45469 .38748 .45634 .38652 .45528 .3911 Mtetra
.457 .164 .378 r
.45528 .3911 .45634 .38652 .45797 .38599 .45692 .39038 Mtetra
.66 .349 .435 r
.45692 .39038 .45797 .38599 .45958 .38677 .4585 .39259 Mtetra
.951 .675 .479 r
.4585 .39259 .45958 .38677 .46105 .39444 .45617 .5893 Mtetra
.554 .331 .531 r
.45617 .5893 .46105 .39444 .45884 .59318 .4578 .59428 Mtetra
.714 .289 .238 r
.4578 .59428 .45884 .59318 .46051 .59633 .45951 .596 Mtetra
.287 .75 .948 r
.45951 .596 .46051 .59633 .46225 .59625 .46125 .59592 Mtetra
.565 .886 .99 r
.46125 .59592 .46225 .59625 .464 .59552 .463 .59539 Mtetra
.597 .931 .958 r
.463 .59539 .464 .59552 .46576 .5946 .46475 .59466 Mtetra
.469 .892 .886 r
.46475 .59466 .46576 .5946 .46751 .5941 .4665 .59399 Mtetra
.576 .926 .952 r
.4665 .59399 .46751 .5941 .46926 .59359 .46826 .59328 Mtetra
.613 .906 .984 r
.46826 .59328 .46926 .59359 .47101 .59308 .47001 .59264 Mtetra
.532 .848 .998 r
.47001 .59264 .47101 .59308 .47277 .59258 .47176 .59225 Mtetra
.562 .885 .99 r
.47176 .59225 .47277 .59258 .47452 .59205 .47352 .59172 Mtetra
.721 .926 .96 r
.47352 .59172 .47452 .59205 .47628 .59149 .47528 .59079 Mtetra
.868 .835 .812 r
.47528 .59079 .47628 .59149 .47803 .59087 .47706 .58874 Mtetra
.808 .668 .709 r
.47706 .58874 .47803 .59087 .47979 .59025 .47885 .58599 Mtetra
.741 .563 .652 r
.47885 .58599 .47979 .59025 .48155 .58965 .48064 .5828 Mtetra
.61 .44 .626 r
.48064 .5828 .48155 .58965 .48331 .58914 .48241 .58169 Mtetra
.566 .403 .619 r
.48241 .58169 .48331 .58914 .48507 .58866 .48416 .58145 Mtetra
.553 .395 .622 r
.48416 .58145 .48507 .58866 .48683 .58818 .48592 .58149 Mtetra
.581 .42 .629 r
.48592 .58149 .48683 .58818 .4886 .58767 .48768 .58101 Mtetra
.581 .421 .629 r
.48768 .58101 .4886 .58767 .49036 .58716 .48944 .58053 Mtetra
.581 .421 .63 r
.48944 .58053 .49036 .58716 .49213 .58664 .4912 .58005 Mtetra
.583 .423 .63 r
.4912 .58005 .49213 .58664 .49389 .58612 .49296 .57954 Mtetra
.583 .423 .631 r
.49296 .57954 .49389 .58612 .49566 .5856 .49473 .57902 Mtetra
.583 .424 .631 r
.49473 .57902 .49566 .5856 .49743 .58507 .4965 .5785 Mtetra
.584 .424 .631 r
.4965 .5785 .49743 .58507 .4992 .58455 .49827 .57797 Mtetra
.49827 .57797 .4992 .58455 .50097 .58402 .50003 .57744 Mtetra
.50003 .57744 .50097 .58402 .50275 .58349 .5018 .57691 Mtetra
.5018 .57691 .50275 .58349 .50452 .58296 .50358 .57638 Mtetra
.50358 .57638 .50452 .58296 .50629 .58243 .50535 .57584 Mtetra
.50535 .57584 .50629 .58243 .50807 .5819 .50712 .5753 Mtetra
.584 .424 .63 r
.50712 .5753 .50807 .5819 .50985 .58136 .5089 .57475 Mtetra
.585 .424 .63 r
.5089 .57475 .50985 .58136 .51162 .58082 .51067 .5742 Mtetra
.51067 .5742 .51162 .58082 .5134 .58028 .51245 .57364 Mtetra
.586 .425 .63 r
.51245 .57364 .5134 .58028 .51518 .57974 .51423 .57305 Mtetra
.586 .425 .629 r
.51423 .57305 .51518 .57974 .51697 .57919 .51601 .57246 Mtetra
.587 .425 .629 r
.51601 .57246 .51697 .57919 .51875 .57864 .51779 .57184 Mtetra
.613 .442 .627 r
.51779 .57184 .51875 .57864 .52053 .57805 .51957 .57067 Mtetra
.588 .419 .621 r
.51957 .57067 .52053 .57805 .52232 .57748 .52136 .56997 Mtetra
.538 .383 .619 r
.52136 .56997 .52232 .57748 .52411 .57694 .52314 .57028 Mtetra
.391 .288 .616 r
.52314 .57028 .52411 .57694 .52589 .57649 .52492 .57264 Mtetra
.359 .328 .687 r
.52492 .57264 .52589 .57649 .52768 .57606 .52671 .57421 Mtetra
.302 .44 .834 r
.52671 .57421 .52768 .57606 .52947 .57562 .5285 .57508 Mtetra
.509 .82 1 r
.5285 .57508 .52947 .57562 .53126 .57511 .5303 .57478 Mtetra
.574 .892 .988 r
.5303 .57478 .53126 .57511 .53305 .57457 .53209 .5742 Mtetra
.629 .903 .985 r
.53209 .5742 .53305 .57457 .53485 .57402 .53388 .57353 Mtetra
.515 .834 .999 r
.53388 .57353 .53485 .57402 .53664 .57346 .53568 .57317 Mtetra
.44 .843 .974 r
.53568 .57317 .53664 .57346 .53844 .5729 .53748 .57282 Mtetra
.364 .829 .904 r
.53748 .57282 .53844 .5729 .54023 .57234 .53928 .57241 Mtetra
.195 .725 .779 r
.53928 .57241 .54023 .57234 .54204 .57228 .54108 .57209 Mtetra
.534 .902 .964 r
.54108 .57209 .54204 .57228 .54384 .57186 .54288 .57149 Mtetra
.759 .93 .943 r
.54288 .57149 .54384 .57186 .54563 .5707 .54468 .57039 Mtetra
.95 .868 .722 r
.54468 .57039 .54563 .5707 .5474 .56515 .54646 .56702 Mtetra
.981 .852 .465 r
.54646 .56702 .5474 .56515 .54775 .36208 .54821 .55929 Mtetra
0 0 .351 r
.54821 .55929 .54775 .36208 .5494 .35579 .54854 .36047 Mtetra
.356 .08 .35 r
.54854 .36047 .5494 .35579 .55108 .35445 .55023 .35871 Mtetra
.491 .188 .379 r
.55023 .35871 .55108 .35445 .55277 .35395 .55192 .3584 Mtetra
.498 .198 .387 r
.55192 .3584 .55277 .35395 .55447 .35381 .55362 .35814 Mtetra
.134 0 .26 r
.55362 .35814 .55447 .35381 .55616 .3532 .55529 .35498 Mtetra
0 0 0 r
.55529 .35498 .55616 .3532 .55786 .35255 .55697 .35241 Mtetra
.894 .952 .833 r
.55697 .35241 .55786 .35255 .55955 .3519 .55865 .35051 Mtetra
.71 .699 .838 r
.55865 .35051 .55955 .3519 .56125 .35132 .56035 .34962 Mtetra
.648 .633 .821 r
.56035 .34962 .56125 .35132 .56295 .35076 .56205 .34907 Mtetra
.62 .62 .83 r
.56205 .34907 .56295 .35076 .56465 .35021 .56375 .34868 Mtetra
.628 .646 .849 r
.56375 .34868 .56465 .35021 .56635 .34961 .56545 .34825 Mtetra
.631 .674 .873 r
.56545 .34825 .56635 .34961 .56805 .34901 .56715 .34782 Mtetra
.639 .707 .896 r
.56715 .34782 .56805 .34901 .56975 .34842 .56886 .34736 Mtetra
.736 .762 .874 r
.56886 .34736 .56975 .34842 .57145 .34749 .57056 .3464 Mtetra
.714 .752 .882 r
.57056 .3464 .57145 .34749 .57315 .34681 .57226 .34557 Mtetra
.623 .691 .893 r
.57226 .34557 .57315 .34681 .57486 .34676 .57397 .34517 Mtetra
0 .211 .736 r
.57397 .34517 .57486 .34676 .57663 .3502 .57571 .34681 Mtetra
0 0 .335 r
.57571 .34681 .57663 .3502 .58176 .55212 .57752 .35226 Mtetra
0 0 .377 r
.57752 .35226 .58176 .55212 .5837 .55855 .58265 .55106 Mtetra
.48 .343 .617 r
.58265 .55106 .5837 .55855 .58555 .55917 .5845 .55244 Mtetra
.595 .431 .629 r
.5845 .55244 .58555 .55917 .58737 .55862 .58632 .55166 Mtetra
.6 .432 .626 r
.58632 .55166 .58737 .55862 .58919 .55763 .58814 .55074 Mtetra
.432 .316 .621 r
.58814 .55074 .58919 .55763 .59103 .5571 .59002 .5527 Mtetra
.375 .322 .671 r
.59002 .5527 .59103 .5571 .59286 .55669 .5919 .55443 Mtetra
.334 .414 .794 r
.5919 .55443 .59286 .55669 .59469 .55625 .59376 .55544 Mtetra
.331 .665 .974 r
.59376 .55544 .59469 .55625 .59654 .5561 .59561 .55564 Mtetra
.513 .844 .998 r
.59561 .55564 .59654 .5561 .59837 .55569 .59745 .55526 Mtetra
.731 .917 .956 r
.59745 .55526 .59837 .55569 .6002 .55462 .59928 .55427 Mtetra
.929 .899 .776 r
.59928 .55427 .6002 .55462 .60195 .55025 .60107 .55163 Mtetra
.953 .883 .484 r
.60107 .55163 .60195 .55025 .59906 .34786 .60279 .54603 Mtetra
0 0 .371 r
.60279 .54603 .59906 .34786 .6006 .33923 .59989 .34515 Mtetra
0 0 .246 r
.59989 .34515 .6006 .33923 .60229 .33727 .60148 .33923 Mtetra
0 0 0 r
.60148 .33923 .60229 .33727 .60401 .33655 .60316 .33666 Mtetra
.825 .999 .834 r
.60316 .33666 .60401 .33655 .60574 .33626 .60486 .33502 Mtetra
.725 .73 .855 r
.60486 .33502 .60574 .33626 .60747 .33579 .60657 .33407 Mtetra
.65 .634 .82 r
.60657 .33407 .60747 .33579 .60919 .33524 .6083 .33349 Mtetra
.619 .616 .825 r
.6083 .33349 .60919 .33524 .61092 .33469 .61003 .33309 Mtetra
.626 .637 .842 r
.61003 .33309 .61092 .33469 .61265 .33409 .61177 .33267 Mtetra
.633 .667 .865 r
.61177 .33267 .61265 .33409 .61438 .33346 .6135 .33222 Mtetra
.642 .7 .888 r
.6135 .33222 .61438 .33346 .61611 .33284 .61524 .33172 Mtetra
.727 .755 .874 r
.61524 .33172 .61611 .33284 .61783 .33192 .61696 .3308 Mtetra
.726 .755 .876 r
.61696 .3308 .61783 .33192 .61956 .33113 .61868 .32989 Mtetra
.648 .704 .888 r
.61868 .32989 .61956 .33113 .6213 .33091 .62042 .32937 Mtetra
.206 .411 .843 r
.62042 .32937 .6213 .33091 .62313 .33336 .6222 .33036 Mtetra
0 0 .552 r
.6222 .33036 .62313 .33336 .63122 .53315 .62407 .33401 Mtetra
0 0 .394 r
.62407 .33401 .63122 .53315 .6334 .54286 .63221 .53345 Mtetra
.228 .151 .558 r
.63221 .53345 .6334 .54286 .63532 .54414 .63428 .53951 Mtetra
.386 .325 .666 r
.63428 .53951 .63532 .54414 .63719 .5438 .63622 .54128 Mtetra
.438 .455 .779 r
.63622 .54128 .63719 .5438 .63904 .54295 .63812 .54196 Mtetra
.537 .726 .961 r
.63812 .54196 .63904 .54295 .6409 .54227 .64 .54177 Mtetra
.633 .883 .987 r
.64 .54177 .6409 .54227 .64276 .54173 .64186 .54111 Mtetra
.701 .873 .962 r
.64186 .54111 .64276 .54173 .64463 .54117 .64372 .54027 Mtetra
.518 .74 .975 r
.64372 .54027 .64463 .54117 .64651 .54096 .6456 .5401 Mtetra
.475 .728 .981 r
.6456 .5401 .64651 .54096 .64839 .54069 .64748 .54002 Mtetra
.67 .856 .97 r
.64748 .54002 .64839 .54069 .65024 .53978 .64935 .53931 Mtetra
.955 .858 .705 r
.64935 .53931 .65024 .53978 .65199 .53608 .65111 .5357 Mtetra
.975 .688 .414 r
.65111 .5357 .65199 .53608 .64616 .335 .6453 .33394 Mtetra
.97 .733 .523 r
.6453 .33394 .64616 .335 .6475 .32369 .64663 .32214 Mtetra
.831 .724 .746 r
.64663 .32214 .6475 .32369 .64918 .32135 .64831 .31985 Mtetra
.651 .665 .851 r
.64831 .31985 .64918 .32135 .65093 .32067 .65007 .31929 Mtetra
.535 .631 .893 r
.65007 .31929 .65093 .32067 .6527 .32046 .65184 .31925 Mtetra
.584 .685 .911 r
.65184 .31925 .6527 .32046 .65447 .32007 .65361 .319 Mtetra
.657 .742 .912 r
.65361 .319 .65447 .32007 .65622 .31945 .65537 .31843 Mtetra
.671 .759 .916 r
.65537 .31843 .65622 .31945 .65798 .31884 .65713 .3178 Mtetra
.734 .777 .887 r
.65713 .3178 .65798 .31884 .65972 .31796 .65887 .31686 Mtetra
.737 .765 .875 r
.65887 .31686 .65972 .31796 .66147 .31711 .66061 .31587 Mtetra
.663 .714 .886 r
.66061 .31587 .66147 .31711 .66324 .3168 .66237 .31528 Mtetra
.308 .48 .866 r
.66237 .31528 .66324 .3168 .66512 .31873 .66419 .31601 Mtetra
0 .032 .591 r
.66419 .31601 .66512 .31873 .6758 .51543 .66613 .3193 Mtetra
0 0 .406 r
.66613 .3193 .6758 .51543 .67833 .52903 .67698 .51831 Mtetra
.214 .136 .547 r
.67698 .51831 .67833 .52903 .68032 .53081 .67923 .52564 Mtetra
.41 .33 .655 r
.67923 .52564 .68032 .53081 .68223 .53056 .68123 .52742 Mtetra
.466 .433 .737 r
.68123 .52742 .68223 .53056 .68411 .52976 .68318 .52811 Mtetra
.438 .552 .874 r
.68318 .52811 .68411 .52976 .68601 .52927 .68512 .52849 Mtetra
.427 .726 .988 r
.68512 .52849 .68601 .52927 .68791 .52898 .68704 .52847 Mtetra
.671 .898 .977 r
.68704 .52847 .68791 .52898 .68979 .52808 .68893 .52768 Mtetra
.953 .888 .73 r
.68893 .52768 .68979 .52808 .69156 .52481 .6907 .52448 Mtetra
.977 .686 .398 r
.6907 .52448 .69156 .52481 .68358 .32831 .6833 .33846 Mtetra
.825 .659 .112 r
.6833 .33846 .68358 .32831 .68454 .31146 .68368 .30999 Mtetra
.864 .741 .726 r
.68368 .30999 .68454 .31146 .6862 .30868 .68534 .30723 Mtetra
.673 .684 .852 r
.68534 .30723 .6862 .30868 .68797 .30786 .68712 .30654 Mtetra
.565 .657 .898 r
.68712 .30654 .68797 .30786 .68976 .30756 .68892 .30637 Mtetra
.642 .718 .903 r
.68892 .30637 .68976 .30756 .69154 .307 .6907 .30587 Mtetra
.729 .759 .877 r
.6907 .30587 .69154 .307 .6933 .30616 .69246 .30492 Mtetra
.665 .717 .887 r
.69246 .30492 .6933 .30616 .6951 .3058 .69424 .30431 Mtetra
.383 .529 .878 r
.69424 .30431 .6951 .3058 .69699 .30729 .69608 .30482 Mtetra
0 .101 .642 r
.69608 .30482 .69699 .30729 .69949 .31961 .69805 .30765 Mtetra
.979 .684 .338 r
.69805 .30765 .69949 .31961 .71247 .51814 .7108 .50316 Mtetra
.162 .086 .516 r
.7108 .50316 .71247 .51814 .71454 .52045 .7134 .51483 Mtetra
.402 .317 .645 r
.7134 .51483 .71454 .52045 .71648 .52029 .71546 .51688 Mtetra
.461 .417 .723 r
.71546 .51688 .71648 .52029 .71838 .51954 .71745 .51769 Mtetra
.473 .545 .849 r
.71745 .51769 .71838 .51954 .7203 .51895 .71942 .518 Mtetra
.48 .712 .972 r
.71942 .518 .7203 .51895 .72223 .51869 .72137 .51795 Mtetra
.645 .835 .974 r
.72137 .51795 .72223 .51869 .72414 .51787 .72329 .51732 Mtetra
.865 .911 .861 r
.72329 .51732 .72414 .51787 .72593 .51516 .72514 .5155 Mtetra
.977 .917 .605 r
.72514 .5155 .72593 .51516 .72718 .50355 .72684 .51127 Mtetra
.936 .71 .232 r
.72684 .51127 .72718 .50355 .71674 .30176 .7267 .47709 Mtetra
.021 0 .417 r
.7267 .47709 .71674 .30176 .71836 .29838 .7178 .30151 Mtetra
.039 0 .187 r
.7178 .30151 .71836 .29838 .72014 .29743 .71944 .29847 Mtetra
0 0 0 r
.71944 .29847 .72014 .29743 .72195 .29704 .72117 .29664 Mtetra
.769 .941 .937 r
.72117 .29664 .72195 .29704 .72376 .29672 .72293 .2955 Mtetra
.672 .726 .89 r
.72293 .2955 .72376 .29672 .72557 .29616 .72473 .29485 Mtetra
.631 .692 .888 r
.72473 .29485 .72557 .29616 .72737 .2956 .72654 .29439 Mtetra
.636 .712 .902 r
.72654 .29439 .72737 .2956 .72917 .29499 .72835 .29391 Mtetra
.674 .753 .91 r
.72835 .29391 .72917 .29499 .73097 .2943 .73015 .29325 Mtetra
.684 .764 .912 r
.73015 .29325 .73097 .2943 .73277 .2936 .73195 .29255 Mtetra
.736 .781 .889 r
.73195 .29255 .73277 .2936 .73455 .29274 .73373 .29157 Mtetra
.768 .769 .854 r
.73373 .29157 .73455 .29274 .73633 .29172 .7355 .29035 Mtetra
.683 .704 .863 r
.7355 .29035 .73633 .29172 .73814 .29118 .73729 .28961 Mtetra
.324 .482 .863 r
.73729 .28961 .73814 .29118 .74006 .29213 .7392 .29036 Mtetra
.809 .436 0 r
.7392 .29036 .74006 .29213 .74246 .29993 .7415 .29681 Mtetra
.976 .672 .346 r
.7415 .29681 .74246 .29993 .75863 .50359 .75774 .5022 Mtetra
0 0 .419 r
.75774 .5022 .75863 .50359 .76082 .50657 .75996 .5055 Mtetra
.533 .712 .954 r
.75996 .5055 .76082 .50657 .7628 .50642 .76193 .50533 Mtetra
.699 .778 .912 r
.76193 .50533 .7628 .50642 .76473 .50562 .76386 .5045 Mtetra
.668 .761 .92 r
.76386 .5045 .76473 .50562 .76666 .50487 .7658 .50383 Mtetra
.438 .671 .961 r
.7658 .50383 .76666 .50487 .76864 .50473 .7678 .50393 Mtetra
.585 .8 .981 r
.7678 .50393 .76864 .50473 .77059 .50409 .76977 .5035 Mtetra
.879 .909 .845 r
.76977 .5035 .77059 .50409 .77242 .5019 .77162 .50153 Mtetra
.994 .795 .528 r
.77162 .50153 .77242 .5019 .77374 .49287 .77302 .49355 Mtetra
.978 .68 .357 r
.77302 .49355 .77374 .49287 .76021 .28773 .75942 .28683 Mtetra
.958 .807 .652 r
.75942 .28683 .76021 .28773 .76177 .28371 .76096 .28252 Mtetra
.734 .755 .87 r
.76096 .28252 .76177 .28371 .76357 .28272 .76276 .28151 Mtetra
.608 .702 .91 r
.76276 .28151 .76357 .28272 .76541 .28234 .7646 .28114 Mtetra
.605 .704 .914 r
.7646 .28114 .76541 .28234 .76725 .28195 .76645 .28078 Mtetra
.743 .764 .87 r
.76645 .28078 .76725 .28195 .76905 .28089 .76824 .27972 Mtetra
.661 .735 .904 r
.76824 .27972 .76905 .28089 .77087 .28028 .77007 .27912 Mtetra
.248 .513 .907 r
.77007 .27912 .77087 .28028 .77281 .28096 .772 .2798 Mtetra
.881 .489 .031 r
.772 .2798 .77281 .28096 .77527 .28818 .77446 .28702 Mtetra
.975 .667 .334 r
.77446 .28702 .77527 .28818 .79376 .49296 .79292 .49188 Mtetra
.646 .191 0 r
.79292 .49188 .79376 .49296 .79605 .49629 .79521 .49526 Mtetra
.474 .693 .963 r
.79521 .49526 .79605 .49629 .79805 .49616 .79722 .49525 Mtetra
.698 .819 .94 r
.79722 .49525 .79805 .49616 .80001 .49534 .79917 .49442 Mtetra
.797 .842 .885 r
.79917 .49442 .80001 .49534 .80195 .4944 .80108 .49302 Mtetra
.799 .763 .82 r
.80108 .49302 .80195 .4944 .80395 .49418 .80296 .49136 Mtetra
.773 .628 .7 r
.80296 .49136 .80395 .49418 .80592 .4935 .80477 .48881 Mtetra
.796 .588 .619 r
.80477 .48881 .80592 .4935 .80778 .49156 .80636 .48364 Mtetra
.974 .67 .365 r
.80636 .48364 .80778 .49156 .80911 .48345 .79096 .28042 Mtetra
.556 .337 .537 r
.79096 .28042 .80911 .48345 .79327 .2771 .79232 .27418 Mtetra
.776 .617 .682 r
.79232 .27418 .79327 .2771 .79477 .27261 .79398 .27148 Mtetra
.723 .769 .889 r
.79398 .27148 .79477 .27261 .79658 .27152 .7958 .27055 Mtetra
.634 .77 .945 r
.7958 .27055 .79658 .27152 .79844 .27106 .79766 .27004 Mtetra
.633 .758 .938 r
.79766 .27004 .79844 .27106 .80031 .27073 .79951 .26954 Mtetra
.77 .772 .855 r
.79951 .26954 .80031 .27073 .80211 .26962 .80131 .26829 Mtetra
.697 .721 .868 r
.80131 .26829 .80211 .26962 .80396 .26893 .80314 .26746 Mtetra
.479 .592 .888 r
.80314 .26746 .80396 .26893 .80589 .26926 .80506 .26765 Mtetra
.681 .299 0 r
.80506 .26765 .80589 .26926 .80831 .27483 .80743 .27262 Mtetra
.973 .663 .311 r
.80743 .27262 .80831 .27483 .82925 .48133 .82838 .47981 Mtetra
.656 .256 0 r
.82838 .47981 .82925 .48133 .83168 .48555 .83085 .48443 Mtetra
.324 .589 .94 r
.83085 .48443 .83168 .48555 .83377 .48594 .83295 .48489 Mtetra
.673 .782 .932 r
.83295 .48489 .83377 .48594 .83575 .48521 .83493 .48417 Mtetra
.866 .832 .811 r
.83493 .48417 .83575 .48521 .83761 .48316 .83678 .48204 Mtetra
.981 .767 .54 r
.83678 .48204 .83761 .48316 .83899 .47608 .83808 .47403 Mtetra
.976 .67 .332 r
.83808 .47403 .83899 .47608 .82114 .26838 .82026 .26621 Mtetra
.894 .704 .637 r
.82026 .26621 .82114 .26838 .82256 .26325 .82173 .26151 Mtetra
.7 .666 .813 r
.82173 .26151 .82256 .26325 .82438 .2621 .82356 .26055 Mtetra
.592 .639 .866 r
.82356 .26055 .82438 .2621 .82625 .26162 .82546 .26027 Mtetra
.51 .629 .904 r
.82546 .26027 .82625 .26162 .82816 .26146 .82739 .2603 Mtetra
.683 .75 .902 r
.82739 .2603 .82816 .26146 .83003 .26084 .82924 .25957 Mtetra
.663 .721 .893 r
.82924 .25957 .83003 .26084 .8319 .26023 .83111 .25894 Mtetra
.607 .692 .903 r
.83111 .25894 .8319 .26023 .83377 .25962 .83301 .25857 Mtetra
.37 .616 .946 r
.83301 .25857 .83377 .25962 .8356 .25863 .83497 .25889 Mtetra
.562 0 0 r
.83497 .25889 .8356 .25863 .83748 .25803 .83702 .26001 Mtetra
.77 .366 .287 r
.83702 .26001 .83748 .25803 .83943 .25825 .8393 .26337 Mtetra
.971 .654 .32 r
.8393 .26337 .83943 .25825 .84219 .26619 .86223 .46803 Mtetra
.552 .328 .53 r
.86223 .46803 .84219 .26619 .86538 .47172 .86477 .47263 Mtetra
.571 .065 .011 r
.86477 .47263 .86538 .47172 .86776 .47464 .86695 .47357 Mtetra
.971 .801 .615 r
.86695 .47357 .86776 .47464 .86932 .4697 .86848 .46829 Mtetra
.974 .667 .313 r
.86848 .46829 .86932 .4697 .84942 .26082 .84862 .25936 Mtetra
.967 .752 .562 r
.84862 .25936 .84942 .26082 .85061 .25364 .84984 .2525 Mtetra
.82 .764 .8 r
.24387 .4557 .24489 .4566 .24649 .45493 .24548 .45405 Mtetra
.697 .761 .901 r
.24548 .45405 .24649 .45493 .24802 .45425 .247 .45339 Mtetra
.261 .595 .95 r
.247 .45339 .24802 .45425 .24947 .45453 .24844 .45371 Mtetra
.926 .554 .286 r
.24844 .45371 .24947 .45453 .2506 .45854 .24956 .45791 Mtetra
.937 .682 .525 r
.24956 .45791 .2506 .45854 .23563 .6563 .23452 .65579 Mtetra
.921 .571 .355 r
.23452 .65579 .23563 .6563 .23673 .66186 .23564 .66108 Mtetra
.346 .673 .976 r
.23564 .66108 .23673 .66186 .23829 .66204 .2372 .66122 Mtetra
.704 .788 .917 r
.2372 .66122 .23829 .66204 .23991 .66135 .23883 .66051 Mtetra
.771 .788 .867 r
.23883 .66051 .23991 .66135 .24157 .66025 .24049 .65937 Mtetra
.575 .744 .956 r
.24049 .65937 .24157 .66025 .24315 .66019 .24208 .65911 Mtetra
.602 .709 .92 r
.24208 .65911 .24315 .66019 .24474 .65996 .24368 .65881 Mtetra
.665 .716 .886 r
.24368 .65881 .24474 .65996 .24637 .65922 .2453 .65825 Mtetra
.815 .765 .806 r
.2453 .65825 .24637 .65922 .2482 .65606 .24701 .65656 Mtetra
.921 .968 .781 r
.24701 .65656 .2482 .65606 .25038 .64832 .24877 .65418 Mtetra
.212 0 .298 r
.24877 .65418 .25038 .64832 .26718 .45478 .25059 .65114 Mtetra
.542 .321 .529 r
.25059 .65114 .26718 .45478 .26882 .45271 .25227 .64985 Mtetra
.544 .323 .53 r
.25227 .64985 .26882 .45271 .27034 .45234 .25387 .64955 Mtetra
.545 .323 .53 r
.25387 .64955 .27034 .45234 .2718 .45274 .25544 .64965 Mtetra
.545 .324 .53 r
.25544 .64965 .2718 .45274 .27327 .45298 .25698 .65011 Mtetra
.544 .323 .53 r
.25698 .65011 .27327 .45298 .27477 .45284 .25857 .64995 Mtetra
.542 .321 .529 r
.25857 .64995 .27477 .45284 .27634 .45178 .26026 .64857 Mtetra
0 0 .232 r
.26026 .64857 .27634 .45178 .27807 .44863 .27601 .4617 Mtetra
0 0 .046 r
.27601 .4617 .27807 .44863 .27976 .44606 .27862 .44686 Mtetra
.972 .917 .686 r
.27862 .44686 .27976 .44606 .28139 .44419 .28039 .44326 Mtetra
.776 .766 .844 r
.28039 .44326 .28139 .44419 .28295 .44333 .28197 .44209 Mtetra
.657 .686 .866 r
.28197 .44209 .28295 .44333 .28448 .44283 .2835 .44159 Mtetra
.593 .662 .886 r
.2835 .44159 .28448 .44283 .286 .44248 .28501 .44135 Mtetra
.648 .703 .887 r
.28501 .44135 .286 .44248 .28753 .44199 .28654 .44089 Mtetra
.659 .712 .887 r
.28654 .44089 .28753 .44199 .28907 .44148 .28808 .44039 Mtetra
.658 .713 .889 r
.28808 .44039 .28907 .44148 .2906 .44096 .28961 .43989 Mtetra
.661 .717 .89 r
.28961 .43989 .2906 .44096 .29214 .44044 .29115 .43938 Mtetra
.658 .718 .893 r
.29115 .43938 .29214 .44044 .29368 .43993 .29269 .43888 Mtetra
.652 .719 .898 r
.29269 .43888 .29368 .43993 .29521 .43945 .29422 .4384 Mtetra
.628 .714 .909 r
.29422 .4384 .29521 .43945 .29674 .43905 .29575 .43802 Mtetra
.618 .714 .914 r
.29575 .43802 .29674 .43905 .29827 .43869 .29728 .43768 Mtetra
.619 .718 .917 r
.29728 .43768 .29827 .43869 .2998 .43832 .29881 .43733 Mtetra
.641 .729 .912 r
.29881 .43733 .2998 .43832 .30134 .43787 .30035 .4369 Mtetra
.658 .737 .908 r
.30035 .4369 .30134 .43787 .30288 .43736 .30189 .4364 Mtetra
.671 .744 .906 r
.30189 .4364 .30288 .43736 .30443 .43678 .30344 .43585 Mtetra
.69 .753 .9 r
.30344 .43585 .30443 .43678 .30599 .43612 .30499 .43521 Mtetra
.698 .761 .901 r
.30499 .43521 .30599 .43612 .30755 .43541 .30655 .43454 Mtetra
.697 .768 .906 r
.30655 .43454 .30755 .43541 .3091 .43472 .30811 .43387 Mtetra
.679 .771 .92 r
.30811 .43387 .3091 .43472 .31066 .43411 .30966 .43329 Mtetra
.668 .774 .929 r
.30966 .43329 .31066 .43411 .31221 .43355 .31121 .43274 Mtetra
.663 .777 .934 r
.31121 .43274 .31221 .43355 .31376 .43302 .31276 .43222 Mtetra
.697 .786 .919 r
.31276 .43222 .31376 .43302 .31533 .43225 .31432 .43156 Mtetra
.686 .809 .941 r
.31432 .43156 .31533 .43225 .31689 .43158 .31588 .43094 Mtetra
.615 .807 .973 r
.31588 .43094 .31689 .43158 .31842 .4313 .31742 .43053 Mtetra
.196 .58 .941 r
.31742 .43053 .31842 .4313 .31986 .43268 .31892 .43089 Mtetra
.166 .342 .796 r
.31892 .43089 .31986 .43268 .32109 .43732 .32038 .43195 Mtetra
.397 .299 .626 r
.32038 .43195 .32109 .43732 .31055 .63174 .3218 .43363 Mtetra
.545 .328 .536 r
.3218 .43363 .31055 .63174 .31202 .63417 .32332 .43366 Mtetra
.547 .33 .536 r
.32332 .43366 .31202 .63417 .31367 .63359 .3249 .43275 Mtetra
.546 .328 .536 r
.3249 .43275 .31367 .63359 .31535 .63273 .32644 .43256 Mtetra
.519 .307 .531 r
.32644 .43256 .31535 .63273 .31688 .63421 .32724 .44465 Mtetra
0 0 .249 r
.32724 .44465 .31688 .63421 .3184 .63597 .31751 .63248 Mtetra
0 0 .513 r
.31751 .63248 .3184 .63597 .31997 .63706 .31893 .63581 Mtetra
.167 .46 .886 r
.31893 .63581 .31997 .63706 .32158 .63727 .32052 .63652 Mtetra
.562 .777 .979 r
.32052 .63652 .32158 .63727 .32323 .63698 .32217 .63624 Mtetra
.679 .809 .945 r
.32217 .63624 .32323 .63698 .32489 .6365 .32384 .63561 Mtetra
.657 .771 .933 r
.32384 .63561 .32489 .6365 .32655 .63613 .32551 .63506 Mtetra
.661 .735 .904 r
.32551 .63506 .32655 .63613 .32821 .63568 .32717 .63451 Mtetra
.703 .728 .87 r
.32717 .63451 .32821 .63568 .32989 .63481 .32885 .63373 Mtetra
.765 .755 .843 r
.32885 .63373 .32989 .63481 .33166 .63258 .33056 .63252 Mtetra
.88 .938 .851 r
.33056 .63252 .33166 .63258 .33356 .62779 .3323 .6307 Mtetra
0 0 0 r
.3323 .6307 .33356 .62779 .34592 .43275 .3341 .62774 Mtetra
.523 .306 .526 r
.3341 .62774 .34592 .43275 .34788 .42509 .33634 .61682 Mtetra
0 0 .243 r
.33634 .61682 .34788 .42509 .34957 .42239 .34845 .42411 Mtetra
.903 .921 .533 r
.34845 .42411 .34957 .42239 .35121 .42071 .35021 .42014 Mtetra
.845 .839 .839 r
.35021 .42014 .35121 .42071 .3528 .41973 .35184 .41854 Mtetra
.676 .704 .868 r
.35184 .41854 .3528 .41973 .35438 .41918 .35342 .41793 Mtetra
.596 .667 .888 r
.35342 .41793 .35438 .41918 .35594 .41882 .35498 .41767 Mtetra
.595 .686 .905 r
.35498 .41767 .35594 .41882 .35751 .41848 .35654 .41741 Mtetra
.617 .708 .911 r
.35654 .41741 .35751 .41848 .35908 .4181 .35811 .41706 Mtetra
.622 .716 .914 r
.35811 .41706 .35908 .4181 .36065 .4177 .35968 .41669 Mtetra
.661 .737 .906 r
.35968 .41669 .36065 .4177 .36223 .41712 .36126 .41617 Mtetra
.691 .755 .9 r
.36126 .41617 .36223 .41712 .36382 .41642 .36284 .41551 Mtetra
.698 .767 .905 r
.36284 .41551 .36382 .41642 .3654 .4157 .36443 .41483 Mtetra
.709 .778 .906 r
.36443 .41483 .3654 .4157 .367 .41487 .36602 .4141 Mtetra
.699 .799 .927 r
.36602 .4141 .367 .41487 .36859 .4141 .36761 .41342 Mtetra
.638 .807 .964 r
.36761 .41342 .36859 .4141 .37017 .41371 .36919 .41295 Mtetra
.466 .724 .981 r
.36919 .41295 .37017 .41371 .37169 .4145 .37075 .4129 Mtetra
.348 .484 .855 r
.37075 .4129 .37169 .4145 .3731 .41764 .37228 .41348 Mtetra
.357 .301 .657 r
.37228 .41348 .3731 .41764 .3657 .6111 .37377 .41507 Mtetra
.529 .315 .533 r
.37377 .41507 .3657 .6111 .36699 .61914 .37498 .42276 Mtetra
0 0 .28 r
.37498 .42276 .36699 .61914 .36856 .6211 .36768 .61675 Mtetra
0 .04 .557 r
.36768 .61675 .36856 .6211 .37019 .62192 .36919 .6203 Mtetra
.219 .422 .847 r
.36919 .6203 .37019 .62192 .37185 .62198 .37082 .62117 Mtetra
.609 .781 .963 r
.37082 .62117 .37185 .62198 .37354 .62153 .3725 .62077 Mtetra
.715 .814 .927 r
.3725 .62077 .37354 .62153 .37524 .62088 .37421 .61997 Mtetra
.706 .781 .911 r
.37421 .61997 .37524 .62088 .37694 .62024 .37592 .6192 Mtetra
.663 .745 .912 r
.37592 .6192 .37694 .62024 .37864 .6197 .37761 .61863 Mtetra
.662 .74 .908 r
.37761 .61863 .37864 .6197 .38034 .61916 .37931 .61807 Mtetra
.658 .734 .906 r
.37931 .61807 .38034 .61916 .38203 .61862 .38101 .61751 Mtetra
.653 .729 .905 r
.38101 .61751 .38203 .61862 .38373 .6181 .38271 .61698 Mtetra
.65 .726 .904 r
.38271 .61698 .38373 .6181 .38543 .61759 .38441 .61647 Mtetra
.647 .724 .905 r
.38441 .61647 .38543 .61759 .38713 .61709 .38611 .61597 Mtetra
.644 .723 .906 r
.38611 .61597 .38713 .61709 .38883 .61659 .38781 .61548 Mtetra
.642 .724 .908 r
.38781 .61548 .38883 .61659 .39053 .6161 .38951 .615 Mtetra
.641 .727 .91 r
.38951 .615 .39053 .6161 .39224 .61561 .39122 .61452 Mtetra
.641 .73 .913 r
.39122 .61452 .39224 .61561 .39394 .61511 .39292 .61404 Mtetra
.639 .733 .916 r
.39292 .61404 .39394 .61511 .39564 .61461 .39463 .61357 Mtetra
.635 .736 .921 r
.39463 .61357 .39564 .61461 .39735 .61412 .39633 .61311 Mtetra
.63 .743 .929 r
.39633 .61311 .39735 .61412 .39906 .61362 .39804 .61266 Mtetra
.629 .755 .937 r
.39804 .61266 .39906 .61362 .40077 .61312 .39974 .61222 Mtetra
.581 .75 .958 r
.39974 .61222 .40077 .61312 .40247 .61272 .40145 .61192 Mtetra
.536 .758 .978 r
.40145 .61192 .40247 .61272 .40418 .61238 .40315 .6117 Mtetra
.656 .825 .965 r
.40315 .6117 .40418 .61238 .40589 .61185 .40486 .61111 Mtetra
.837 .826 .837 r
.40486 .61111 .40589 .61185 .40762 .61085 .40662 .60942 Mtetra
.885 .726 .68 r
.40662 .60942 .40762 .61085 .40937 .6091 .40846 .60521 Mtetra
.952 .686 .497 r
.40846 .60521 .40937 .6091 .41117 .60629 .41656 .41381 Mtetra
.572 .35 .54 r
.41656 .41381 .41117 .60629 .4131 .59898 .41861 .40036 Mtetra
.551 .333 .537 r
.41861 .40036 .4131 .59898 .42113 .40215 .4203 .39748 Mtetra
.669 .503 .651 r
.4203 .39748 .42113 .40215 .42288 .39751 .42195 .39574 Mtetra
.717 .648 .78 r
.42195 .39574 .42288 .39751 .42454 .39545 .42359 .39465 Mtetra
.682 .793 .934 r
.42359 .39465 .42454 .39545 .42616 .39472 .42521 .39403 Mtetra
.607 .8 .974 r
.42521 .39403 .42616 .39472 .42777 .39438 .42682 .39363 Mtetra
.588 .776 .969 r
.42682 .39363 .42777 .39438 .42938 .39416 .42843 .3933 Mtetra
.616 .759 .947 r
.42843 .3933 .42938 .39416 .43099 .39381 .43005 .39291 Mtetra
.618 .752 .942 r
.43005 .39291 .43099 .39381 .43261 .39346 .43166 .39252 Mtetra
.633 .748 .931 r
.43166 .39252 .43261 .39346 .43423 .39307 .43328 .39209 Mtetra
.657 .747 .916 r
.43328 .39209 .43423 .39307 .43585 .39258 .4349 .39157 Mtetra
.671 .745 .906 r
.4349 .39157 .43585 .39258 .43747 .39202 .43653 .39099 Mtetra
.687 .744 .895 r
.43653 .39099 .43747 .39202 .4391 .3914 .43816 .39033 Mtetra
.701 .742 .883 r
.43816 .39033 .4391 .3914 .44073 .39069 .43979 .3896 Mtetra
.7 .736 .879 r
.43979 .3896 .44073 .39069 .44236 .38998 .44142 .38886 Mtetra
.709 .734 .871 r
.44142 .38886 .44236 .38998 .44399 .38925 .44305 .38807 Mtetra
.717 .726 .858 r
.44305 .38807 .44399 .38925 .44562 .38851 .44469 .38722 Mtetra
.653 .686 .868 r
.44469 .38722 .44562 .38851 .44725 .38797 .44632 .3867 Mtetra
.363 .556 .908 r
.44632 .3867 .44725 .38797 .44887 .3879 .44792 .3871 Mtetra
.853 .401 .016 r
.44792 .3871 .44887 .3879 .45046 .38881 .44947 .39013 Mtetra
.956 .682 .475 r
.44947 .39013 .45046 .38881 .45205 .39045 .44666 .58325 Mtetra
.561 .337 .532 r
.44666 .58325 .45205 .39045 .45363 .39209 .44817 .59254 Mtetra
.544 .323 .53 r
.44817 .59254 .45363 .39209 .45528 .3911 .4499 .59239 Mtetra
.543 .322 .529 r
.4499 .59239 .45528 .3911 .45692 .39038 .45165 .5915 Mtetra
.544 .323 .53 r
.45165 .5915 .45692 .39038 .4585 .39259 .45338 .5914 Mtetra
.548 .326 .53 r
.45338 .5914 .4585 .39259 .45617 .5893 .45508 .59314 Mtetra
.61 .287 .397 r
.45508 .59314 .45617 .5893 .4578 .59428 .45679 .59435 Mtetra
.409 0 0 r
.45679 .59435 .4578 .59428 .45951 .596 .45851 .59491 Mtetra
.564 .705 .935 r
.45851 .59491 .45951 .596 .46125 .59592 .46025 .5947 Mtetra
.632 .705 .899 r
.46025 .5947 .46125 .59592 .463 .59539 .462 .59425 Mtetra
.662 .731 .901 r
.462 .59425 .463 .59539 .46475 .59466 .46375 .59366 Mtetra
.671 .763 .92 r
.46375 .59366 .46475 .59466 .4665 .59399 .46551 .59304 Mtetra
.68 .774 .922 r
.46551 .59304 .4665 .59399 .46826 .59328 .46726 .59237 Mtetra
.659 .777 .936 r
.46726 .59237 .46826 .59328 .47001 .59264 .46902 .59179 Mtetra
.551 .756 .973 r
.46902 .59179 .47001 .59264 .47176 .59225 .47077 .59154 Mtetra
.635 .82 .971 r
.47077 .59154 .47176 .59225 .47352 .59172 .47253 .59101 Mtetra
.802 .844 .882 r
.47253 .59101 .47352 .59172 .47528 .59079 .47429 .58968 Mtetra
.906 .76 .689 r
.47429 .58968 .47528 .59079 .47706 .58874 .4761 .58566 Mtetra
.914 .676 .565 r
.4761 .58566 .47706 .58874 .47885 .58599 .47805 .57163 Mtetra
.945 .672 .49 r
.47805 .57163 .47885 .58599 .48064 .5828 .48234 .38 Mtetra
.548 .33 .536 r
.48234 .38 .48064 .5828 .48241 .58169 .484 .37858 Mtetra
.546 .329 .536 r
.484 .37858 .48241 .58169 .48416 .58145 .48565 .37831 Mtetra
.545 .328 .536 r
.48565 .37831 .48416 .58145 .48592 .58149 .4873 .37852 Mtetra
.546 .329 .536 r
.4873 .37852 .48592 .58149 .48768 .58101 .48896 .378 Mtetra
.48896 .378 .48768 .58101 .48944 .58053 .49062 .37749 Mtetra
.49062 .37749 .48944 .58053 .4912 .58005 .49228 .37699 Mtetra
.49228 .37699 .4912 .58005 .49296 .57954 .49394 .37645 Mtetra
.49394 .37645 .49296 .57954 .49473 .57902 .4956 .3759 Mtetra
.4956 .3759 .49473 .57902 .4965 .5785 .49726 .37534 Mtetra
.49726 .37534 .4965 .5785 .49827 .57797 .49893 .37479 Mtetra
.49893 .37479 .49827 .57797 .50003 .57744 .50059 .37422 Mtetra
.50059 .37422 .50003 .57744 .5018 .57691 .50226 .37366 Mtetra
.50226 .37366 .5018 .57691 .50358 .57638 .50393 .37309 Mtetra
.50393 .37309 .50358 .57638 .50535 .57584 .50559 .37253 Mtetra
.50559 .37253 .50535 .57584 .50712 .5753 .50726 .37195 Mtetra
.50726 .37195 .50712 .5753 .5089 .57475 .50893 .37138 Mtetra
.50893 .37138 .5089 .57475 .51067 .5742 .51061 .37079 Mtetra
.547 .329 .536 r
.51061 .37079 .51067 .5742 .51245 .57364 .51228 .3702 Mtetra
.51228 .3702 .51245 .57364 .51423 .57305 .51395 .36957 Mtetra
.51395 .36957 .51423 .57305 .51601 .57246 .51563 .36895 Mtetra
.51563 .36895 .51601 .57246 .51779 .57184 .5173 .3683 Mtetra
.548 .33 .536 r
.5173 .3683 .51779 .57184 .51957 .57067 .51898 .36691 Mtetra
.547 .329 .536 r
.51898 .36691 .51957 .57067 .52136 .56997 .52066 .36621 Mtetra
.544 .327 .536 r
.52066 .36621 .52136 .56997 .52314 .57028 .52233 .36691 Mtetra
0 0 .363 r
.52233 .36691 .52314 .57028 .52492 .57264 .52396 .56352 Mtetra
0 0 .48 r
.52396 .56352 .52492 .57264 .52671 .57421 .52574 .57163 Mtetra
0 .112 .649 r
.52574 .57163 .52671 .57421 .5285 .57508 .52754 .57414 Mtetra
.499 .715 .968 r
.52754 .57414 .5285 .57508 .5303 .57478 .52933 .57406 Mtetra
.651 .826 .967 r
.52933 .57406 .5303 .57478 .53209 .5742 .53112 .57346 Mtetra
.715 .835 .939 r
.53112 .57346 .53209 .5742 .53388 .57353 .53292 .57262 Mtetra
.601 .765 .957 r
.53292 .57262 .53388 .57353 .53568 .57317 .53472 .57223 Mtetra
.606 .757 .951 r
.53472 .57223 .53568 .57317 .53748 .57282 .53651 .57183 Mtetra
.623 .754 .94 r
.53651 .57183 .53748 .57282 .53928 .57241 .53831 .57138 Mtetra
.634 .75 .931 r
.53831 .57138 .53928 .57241 .54108 .57209 .54011 .57089 Mtetra
.672 .729 .893 r
.54011 .57089 .54108 .57209 .54288 .57149 .54191 .57024 Mtetra
.715 .734 .866 r
.54191 .57024 .54288 .57149 .54468 .57039 .54371 .56933 Mtetra
.83 .787 .811 r
.54371 .56933 .54468 .57039 .54646 .56702 .54551 .56749 Mtetra
.882 .988 .728 r
.54551 .56749 .54646 .56702 .54821 .55929 .5473 .56506 Mtetra
.277 .028 .344 r
.5473 .56506 .54821 .55929 .54854 .36047 .54909 .56208 Mtetra
.544 .323 .53 r
.54909 .56208 .54854 .36047 .55023 .35871 .55089 .56165 Mtetra
.55089 .56165 .55023 .35871 .55192 .3584 .5527 .5614 Mtetra
.542 .322 .529 r
.5527 .5614 .55192 .3584 .55362 .35814 .5545 .56017 Mtetra
0 0 .369 r
.5545 .56017 .55362 .35814 .55529 .35498 .5545 .36481 Mtetra
0 0 .207 r
.5545 .36481 .55529 .35498 .55697 .35241 .55609 .35306 Mtetra
.961 .938 .629 r
.55609 .35306 .55697 .35241 .55865 .35051 .55776 .34949 Mtetra
.769 .777 .859 r
.55776 .34949 .55865 .35051 .56035 .34962 .55945 .34832 Mtetra
.655 .692 .873 r
.55945 .34832 .56035 .34962 .56205 .34907 .56115 .34778 Mtetra
.588 .667 .893 r
.56115 .34778 .56205 .34907 .56375 .34868 .56285 .34753 Mtetra
.619 .706 .907 r
.56285 .34753 .56375 .34868 .56545 .34825 .56456 .34714 Mtetra
.621 .715 .913 r
.56456 .34714 .56545 .34825 .56715 .34782 .56626 .34674 Mtetra
.629 .725 .916 r
.56626 .34674 .56715 .34782 .56886 .34736 .56797 .34631 Mtetra
.707 .759 .892 r
.56797 .34631 .56886 .34736 .57056 .3464 .56967 .34553 Mtetra
.706 .795 .92 r
.56967 .34553 .57056 .3464 .57226 .34557 .57137 .34477 Mtetra
.651 .796 .952 r
.57137 .34477 .57226 .34557 .57397 .34517 .57308 .34422 Mtetra
.274 .581 .942 r
.57308 .34422 .57397 .34517 .57571 .34681 .5748 .34464 Mtetra
.301 .386 .783 r
.5748 .34464 .57571 .34681 .57752 .35226 .57654 .34572 Mtetra
.443 .322 .62 r
.57654 .34572 .57752 .35226 .58265 .55106 .57829 .34744 Mtetra
.546 .329 .536 r
.57829 .34744 .58265 .55106 .5845 .55244 .58001 .34702 Mtetra
.547 .33 .536 r
.58001 .34702 .5845 .55244 .58632 .55166 .58171 .34608 Mtetra
.546 .328 .536 r
.58171 .34608 .58632 .55166 .58814 .55074 .58344 .34597 Mtetra
0 0 .398 r
.58344 .34597 .58814 .55074 .59002 .5527 .58879 .53669 Mtetra
.019 0 .455 r
.58879 .53669 .59002 .5527 .5919 .55443 .59091 .55119 Mtetra
0 .115 .631 r
.59091 .55119 .5919 .55443 .59376 .55544 .59282 .55422 Mtetra
.335 .568 .925 r
.59282 .55422 .59376 .55544 .59561 .55564 .59467 .55467 Mtetra
.623 .763 .946 r
.59467 .55467 .59561 .55564 .59745 .55526 .59651 .5542 Mtetra
.737 .781 .888 r
.59651 .5542 .59745 .55526 .59928 .55427 .59834 .5532 Mtetra
.786 .788 .854 r
.59834 .5532 .59928 .55427 .60107 .55163 .60016 .55182 Mtetra
.86 .997 .8 r
.60016 .55182 .60107 .55163 .60279 .54603 .60197 .54981 Mtetra
.034 0 .19 r
.60197 .54981 .60279 .54603 .59989 .34515 .60374 .54644 Mtetra
.001 0 .394 r
.60374 .54644 .59989 .34515 .60148 .33923 .60105 .35674 Mtetra
0 0 .31 r
.60105 .35674 .60148 .33923 .60316 .33666 .60234 .33784 Mtetra
.86 .903 .489 r
.60234 .33784 .60316 .33666 .60486 .33502 .60399 .33416 Mtetra
.812 .822 .858 r
.60399 .33416 .60486 .33502 .60657 .33407 .60569 .33275 Mtetra
.664 .697 .87 r
.60569 .33275 .60657 .33407 .6083 .33349 .60742 .33215 Mtetra
.595 .664 .887 r
.60742 .33215 .6083 .33349 .61003 .33309 .60916 .33187 Mtetra
.612 .693 .901 r
.60916 .33187 .61003 .33309 .61177 .33267 .61089 .33151 Mtetra
.625 .711 .907 r
.61089 .33151 .61177 .33267 .6135 .33222 .61263 .33109 Mtetra
.632 .721 .911 r
.61263 .33109 .6135 .33222 .61524 .33172 .61436 .33064 Mtetra
.701 .753 .893 r
.61436 .33064 .61524 .33172 .61696 .3308 .61609 .32987 Mtetra
.715 .79 .91 r
.61609 .32987 .61696 .3308 .61868 .32989 .61782 .32905 Mtetra
.669 .799 .944 r
.61782 .32905 .61868 .32989 .62042 .32937 .61955 .32843 Mtetra
.495 .704 .963 r
.61955 .32843 .62042 .32937 .6222 .33036 .62131 .32837 Mtetra
.408 .473 .815 r
.62131 .32837 .6222 .33036 .62407 .33401 .62308 .329 Mtetra
.398 .317 .648 r
.62308 .329 .62407 .33401 .63221 .53345 .6249 .33079 Mtetra
.518 .307 .533 r
.6249 .33079 .63221 .53345 .63428 .53951 .62712 .34507 Mtetra
0 0 .398 r
.62712 .34507 .63428 .53951 .63622 .54128 .6352 .53739 Mtetra
.117 .168 .639 r
.6352 .53739 .63622 .54128 .63812 .54196 .63719 .54052 Mtetra
.387 .556 .899 r
.63719 .54052 .63812 .54196 .64 .54177 .63909 .54096 Mtetra
.658 .815 .959 r
.63909 .54096 .64 .54177 .64186 .54111 .64095 .54032 Mtetra
.74 .843 .928 r
.64095 .54032 .64186 .54111 .64372 .54027 .6428 .53933 Mtetra
.562 .749 .965 r
.6428 .53933 .64372 .54027 .6456 .5401 .64468 .53905 Mtetra
.522 .706 .955 r
.64468 .53905 .6456 .5401 .64748 .54002 .64657 .53893 Mtetra
.691 .765 .908 r
.64657 .53893 .64748 .54002 .64935 .53931 .64843 .53817 Mtetra
.915 .782 .699 r
.64843 .53817 .64935 .53931 .65111 .5357 .65018 .53445 Mtetra
.974 .687 .416 r
.65018 .53445 .65111 .5357 .6453 .33394 .64439 .33159 Mtetra
.934 .696 .553 r
.64439 .33159 .6453 .33394 .64663 .32214 .64576 .32092 Mtetra
.853 .766 .765 r
.64576 .32092 .64663 .32214 .64831 .31985 .64745 .31867 Mtetra
.652 .72 .899 r
.64745 .31867 .64831 .31985 .65007 .31929 .64921 .31813 Mtetra
.513 .662 .928 r
.64921 .31813 .65007 .31929 .65184 .31925 .65098 .31811 Mtetra
.573 .693 .923 r
.65098 .31811 .65184 .31925 .65361 .319 .65275 .31788 Mtetra
.65 .731 .909 r
.65275 .31788 .65361 .319 .65537 .31843 .65451 .31734 Mtetra
.664 .743 .909 r
.65451 .31734 .65537 .31843 .65713 .3178 .65627 .31675 Mtetra
.71 .765 .896 r
.65627 .31675 .65713 .3178 .65887 .31686 .65802 .31593 Mtetra
.726 .797 .908 r
.65802 .31593 .65887 .31686 .66061 .31587 .65977 .31504 Mtetra
.682 .808 .942 r
.65977 .31504 .66061 .31587 .66237 .31528 .66153 .31436 Mtetra
.529 .727 .965 r
.66153 .31436 .66237 .31528 .66419 .31601 .66331 .3142 Mtetra
.415 .5 .838 r
.66331 .3142 .66419 .31601 .66613 .3193 .66512 .31474 Mtetra
.408 .335 .663 r
.66512 .31474 .66613 .3193 .67698 .51831 .66699 .31632 Mtetra
.532 .318 .535 r
.66699 .31632 .67698 .51831 .67923 .52564 .66912 .32366 Mtetra
.005 0 .414 r
.66912 .32366 .67923 .52564 .68123 .52742 .68016 .52261 Mtetra
.158 .167 .619 r
.68016 .52261 .68123 .52742 .68318 .52811 .68225 .5263 Mtetra
.2 .384 .821 r
.68225 .5263 .68318 .52811 .68512 .52849 .68423 .52754 Mtetra
.454 .698 .972 r
.68423 .52754 .68512 .52849 .68704 .52847 .68615 .52755 Mtetra
.723 .814 .922 r
.68615 .52755 .68704 .52847 .68893 .52768 .68803 .52663 Mtetra
.916 .801 .719 r
.68803 .52663 .68893 .52768 .6907 .52448 .68979 .52329 Mtetra
.976 .685 .4 r
.68979 .52329 .6907 .52448 .6833 .33846 .68191 .32654 Mtetra
.823 .564 .548 r
.68191 .32654 .6833 .33846 .68368 .30999 .68283 .30879 Mtetra
.883 .776 .738 r
.68283 .30879 .68368 .30999 .68534 .30723 .6845 .30607 Mtetra
.676 .737 .896 r
.6845 .30607 .68534 .30723 .68712 .30654 .68627 .30541 Mtetra
.546 .686 .931 r
.68627 .30541 .68712 .30654 .68892 .30637 .68807 .30526 Mtetra
.615 .722 .922 r
.68807 .30526 .68892 .30637 .6907 .30587 .68986 .30487 Mtetra
.712 .781 .906 r
.68986 .30487 .6907 .30587 .69246 .30492 .69163 .30404 Mtetra
.677 .797 .939 r
.69163 .30404 .69246 .30492 .69424 .30431 .69341 .30337 Mtetra
.549 .734 .961 r
.69341 .30337 .69424 .30431 .69608 .30482 .69521 .30316 Mtetra
.423 .526 .858 r
.69521 .30316 .69608 .30482 .69805 .30765 .69706 .30361 Mtetra
.413 .354 .682 r
.69706 .30361 .69805 .30765 .7108 .50316 .69895 .30499 Mtetra
.536 .321 .535 r
.69895 .30499 .7108 .50316 .7134 .51483 .70107 .31021 Mtetra
.025 0 .424 r
.70107 .31021 .7134 .51483 .71546 .51688 .71432 .51124 Mtetra
.166 .156 .601 r
.71432 .51124 .71546 .51688 .71745 .51769 .71651 .51561 Mtetra
.247 .38 .801 r
.71651 .51561 .71745 .51769 .71942 .518 .71854 .51691 Mtetra
.513 .696 .952 r
.71854 .51691 .71942 .518 .72137 .51795 .72049 .51682 Mtetra
.671 .757 .915 r
.72049 .51682 .72137 .51795 .72329 .51732 .7224 .51613 Mtetra
.753 .774 .87 r
.7224 .51613 .72329 .51732 .72514 .5155 .72429 .51496 Mtetra
.854 .918 .873 r
.72429 .51496 .72514 .5155 .72684 .51127 .72614 .51325 Mtetra
0 0 0 r
.72614 .51325 .72684 .51127 .7267 .47709 .72794 .51055 Mtetra
.472 .257 .505 r
.72794 .51055 .7267 .47709 .7178 .30151 .72951 .50427 Mtetra
.023 0 .418 r
.72951 .50427 .7178 .30151 .71944 .29847 .7189 .30185 Mtetra
0 0 .058 r
.7189 .30185 .71944 .29847 .72117 .29664 .7204 .29649 Mtetra
.917 .963 .793 r
.7204 .29649 .72117 .29664 .72293 .2955 .7221 .29427 Mtetra
.692 .731 .881 r
.7221 .29427 .72293 .2955 .72473 .29485 .72389 .29351 Mtetra
.61 .678 .889 r
.72389 .29351 .72473 .29485 .72654 .29439 .72571 .29315 Mtetra
.608 .694 .905 r
.72571 .29315 .72654 .29439 .72835 .29391 .72753 .29279 Mtetra
.67 .745 .906 r
.72753 .29279 .72835 .29391 .73015 .29325 .72933 .29215 Mtetra
.679 .752 .906 r
.72933 .29215 .73015 .29325 .73195 .29255 .73113 .29147 Mtetra
.732 .774 .887 r
.73113 .29147 .73195 .29255 .73373 .29157 .73291 .29051 Mtetra
.772 .79 .867 r
.73291 .29051 .73373 .29157 .7355 .29035 .73468 .2893 Mtetra
.688 .767 .912 r
.73468 .2893 .7355 .29035 .73729 .28961 .73648 .28858 Mtetra
.157 .484 .9 r
.73648 .28858 .73729 .28961 .7392 .29036 .73839 .28934 Mtetra
.891 .493 .056 r
.73839 .28934 .7392 .29036 .7415 .29681 .7407 .29601 Mtetra
.975 .671 .353 r
.7407 .29601 .7415 .29681 .75774 .5022 .75688 .50121 Mtetra
.672 .204 0 r
.75688 .50121 .75774 .5022 .75996 .5055 .75909 .50443 Mtetra
.538 .716 .955 r
.75909 .50443 .75996 .5055 .76193 .50533 .76107 .50425 Mtetra
.703 .78 .911 r
.76107 .50425 .76193 .50533 .76386 .5045 .763 .50339 Mtetra
.673 .766 .92 r
.763 .50339 .76386 .5045 .7658 .50383 .76494 .50269 Mtetra
.463 .663 .949 r
.76494 .50269 .7658 .50383 .7678 .50393 .76694 .50277 Mtetra
.618 .733 .928 r
.76694 .50277 .7678 .50393 .76977 .5035 .7689 .50231 Mtetra
.843 .797 .807 r
.7689 .50231 .76977 .5035 .77162 .50153 .77075 .50031 Mtetra
.972 .755 .552 r
.77075 .50031 .77162 .50153 .77302 .49355 .77213 .49202 Mtetra
.977 .678 .363 r
.77213 .49202 .77302 .49355 .75942 .28683 .7586 .28554 Mtetra
.931 .77 .66 r
.7586 .28554 .75942 .28683 .76096 .28252 .76015 .28132 Mtetra
.732 .756 .872 r
.76015 .28132 .76096 .28252 .76276 .28151 .76194 .28033 Mtetra
.606 .708 .917 r
.76194 .28033 .76276 .28151 .7646 .28114 .76379 .27997 Mtetra
.603 .709 .918 r
.76379 .27997 .7646 .28114 .76645 .28078 .76564 .27961 Mtetra
.742 .764 .871 r
.76564 .27961 .76645 .28078 .76824 .27972 .76743 .27856 Mtetra
.66 .736 .906 r
.76743 .27856 .76824 .27972 .77007 .27912 .76926 .27796 Mtetra
.245 .513 .908 r
.76926 .27796 .77007 .27912 .772 .2798 .7712 .27864 Mtetra
.881 .489 .031 r
.7712 .27864 .772 .2798 .77446 .28702 .77365 .28585 Mtetra
.975 .667 .334 r
.77365 .28585 .77446 .28702 .79292 .49188 .79207 .4908 Mtetra
.649 .195 0 r
.79207 .4908 .79292 .49188 .79521 .49526 .79436 .49421 Mtetra
.428 .666 .961 r
.79436 .49421 .79521 .49526 .79722 .49525 .79639 .49434 Mtetra
.7 .821 .94 r
.79639 .49434 .79722 .49525 .79917 .49442 .79834 .4935 Mtetra
.855 .85 .837 r
.79834 .4935 .79917 .49442 .80108 .49302 .80021 .4916 Mtetra
.922 .771 .677 r
.80021 .4916 .80108 .49302 .80296 .49136 .80189 .48752 Mtetra
.942 .675 .502 r
.80189 .48752 .80296 .49136 .80477 .48881 .80253 .47111 Mtetra
.966 .661 .391 r
.80253 .47111 .80477 .48881 .80636 .48364 .78802 .2765 Mtetra
.551 .332 .536 r
.78802 .2765 .80636 .48364 .79096 .28042 .78966 .27344 Mtetra
.636 .453 .618 r
.78966 .27344 .79096 .28042 .79232 .27418 .7914 .27159 Mtetra
.692 .589 .735 r
.7914 .27159 .79232 .27418 .79398 .27148 .79319 .27035 Mtetra
.691 .755 .901 r
.79319 .27035 .79398 .27148 .7958 .27055 .79502 .26959 Mtetra
.649 .776 .941 r
.79502 .26959 .7958 .27055 .79766 .27004 .79688 .26902 Mtetra
.668 .771 .927 r
.79688 .26902 .79766 .27004 .79951 .26954 .79872 .26837 Mtetra
.773 .777 .857 r
.79872 .26837 .79951 .26954 .80131 .26829 .80051 .26711 Mtetra
.705 .752 .889 r
.80051 .26711 .80131 .26829 .80314 .26746 .80235 .26627 Mtetra
.452 .628 .929 r
.80235 .26627 .80314 .26746 .80506 .26765 .80427 .26643 Mtetra
.759 .343 0 r
.80427 .26643 .80506 .26765 .80743 .27262 .80662 .27132 Mtetra
.973 .662 .315 r
.80662 .27132 .80743 .27262 .82838 .47981 .82754 .47861 Mtetra
.737 .309 0 r
.82754 .47861 .82838 .47981 .83085 .48443 .83002 .48331 Mtetra
.318 .585 .939 r
.83002 .48331 .83085 .48443 .83295 .48489 .83212 .48378 Mtetra
.67 .771 .925 r
.83212 .48378 .83295 .48489 .83493 .48417 .8341 .48308 Mtetra
.861 .824 .811 r
.8341 .48308 .83493 .48417 .83678 .48204 .83596 .48098 Mtetra
.982 .771 .543 r
.83596 .48098 .83678 .48204 .83808 .47403 .83728 .47317 Mtetra
.976 .671 .328 r
.83728 .47317 .83808 .47403 .82026 .26621 .81949 .26522 Mtetra
.967 .801 .626 r
.81949 .26522 .82026 .26621 .82173 .26151 .82096 .26044 Mtetra
.735 .787 .894 r
.82096 .26044 .82173 .26151 .82356 .26055 .82278 .25945 Mtetra
.583 .719 .937 r
.82278 .25945 .82356 .26055 .82546 .26027 .82468 .25915 Mtetra
.495 .67 .941 r
.82468 .25915 .82546 .26027 .82739 .2603 .82661 .25915 Mtetra
.714 .763 .891 r
.82661 .25915 .82739 .2603 .82924 .25957 .82845 .25826 Mtetra
.665 .714 .884 r
.82845 .25826 .82924 .25957 .83111 .25894 .83032 .25761 Mtetra
.538 .649 .906 r
.83032 .25761 .83111 .25894 .83301 .25857 .83224 .25753 Mtetra
0 .019 .56 r
.83224 .25753 .83301 .25857 .83497 .25889 .83442 .25991 Mtetra
.938 .571 .272 r
.83442 .25991 .83497 .25889 .83702 .26001 .83773 .2735 Mtetra
.966 .647 .35 r
.83773 .2735 .83702 .26001 .8393 .26337 .8596 .4695 Mtetra
.549 .326 .53 r
.8596 .4695 .8393 .26337 .86223 .46803 .86197 .47238 Mtetra
.568 .244 .379 r
.86197 .47238 .86223 .46803 .86477 .47263 .86413 .47317 Mtetra
0 0 0 r
.86413 .47317 .86477 .47263 .86695 .47357 .86615 .47251 Mtetra
.976 .795 .596 r
.86615 .47251 .86695 .47357 .86848 .46829 .86763 .46674 Mtetra
.974 .666 .314 r
.86763 .46674 .86848 .46829 .84862 .25936 .8478 .25777 Mtetra
.957 .747 .578 r
.8478 .25777 .84862 .25936 .84984 .2525 .84908 .25137 Mtetra
.81 .767 .813 r
.24285 .45481 .24387 .4557 .24548 .45405 .24445 .4533 Mtetra
.665 .785 .938 r
.24445 .4533 .24548 .45405 .247 .45339 .24596 .45277 Mtetra
.005 .497 .867 r
.24596 .45277 .247 .45339 .24844 .45371 .2474 .45322 Mtetra
.912 .54 .311 r
.2474 .45322 .24844 .45371 .24956 .45791 .24853 .45726 Mtetra
.937 .682 .525 r
.24853 .45726 .24956 .45791 .23452 .65579 .23351 .65402 Mtetra
.952 .6 .252 r
.23351 .65402 .23452 .65579 .23564 .66108 .23462 .6595 Mtetra
.418 .538 .87 r
.23462 .6595 .23564 .66108 .2372 .66122 .23615 .65986 Mtetra
.647 .673 .861 r
.23615 .65986 .2372 .66122 .23883 .66051 .23776 .65937 Mtetra
.724 .732 .857 r
.23776 .65937 .23883 .66051 .24049 .65937 .23941 .65848 Mtetra
.653 .762 .93 r
.23941 .65848 .24049 .65937 .24208 .65911 .24102 .65797 Mtetra
.654 .713 .892 r
.24102 .65797 .24208 .65911 .24368 .65881 .24264 .65747 Mtetra
.655 .68 .862 r
.24264 .65747 .24368 .65881 .2453 .65825 .24425 .65694 Mtetra
.658 .686 .865 r
.24425 .65694 .2453 .65825 .24701 .65656 .24587 .6564 Mtetra
.56 .902 .977 r
.24587 .6564 .24701 .65656 .24877 .65418 .24749 .65586 Mtetra
.308 0 .076 r
.24749 .65586 .24877 .65418 .25059 .65114 .24911 .65534 Mtetra
.471 .164 .363 r
.24911 .65534 .25059 .65114 .25227 .64985 .25072 .65489 Mtetra
.486 .193 .393 r
.25072 .65489 .25227 .64985 .25387 .64955 .25234 .65446 Mtetra
.484 .19 .389 r
.25234 .65446 .25387 .64955 .25544 .64965 .25395 .65403 Mtetra
.517 .212 .388 r
.25395 .65403 .25544 .64965 .25698 .65011 .25553 .65401 Mtetra
.479 .165 .356 r
.25553 .65401 .25698 .65011 .25857 .64995 .25714 .65369 Mtetra
.378 .065 .303 r
.25714 .65369 .25857 .64995 .26026 .64857 .25881 .65266 Mtetra
0 0 0 r
.25881 .65266 .26026 .64857 .27601 .4617 .26076 .64778 Mtetra
0 0 .151 r
.26076 .64778 .27601 .4617 .27862 .44686 .27733 .44978 Mtetra
.961 .881 .489 r
.27733 .44978 .27862 .44686 .28039 .44326 .27933 .44309 Mtetra
.855 .915 .872 r
.27933 .44309 .28039 .44326 .28197 .44209 .28093 .4416 Mtetra
.642 .848 .979 r
.28093 .4416 .28197 .44209 .2835 .44159 .28247 .44108 Mtetra
.433 .776 .997 r
.28247 .44108 .2835 .44159 .28501 .44135 .28397 .44097 Mtetra
.584 .862 .995 r
.28397 .44097 .28501 .44135 .28654 .44089 .2855 .44054 Mtetra
.608 .876 .991 r
.2855 .44054 .28654 .44089 .28808 .44039 .28704 .44005 Mtetra
.6 .877 .992 r
.28704 .44005 .28808 .44039 .28961 .43989 .28857 .43956 Mtetra
.59 .878 .993 r
.28857 .43956 .28961 .43989 .29115 .43938 .29011 .43909 Mtetra
.581 .884 .991 r
.29011 .43909 .29115 .43938 .29269 .43888 .29164 .43861 Mtetra
.585 .891 .989 r
.29164 .43861 .29269 .43888 .29422 .4384 .29318 .43812 Mtetra
.628 .897 .986 r
.29318 .43812 .29422 .4384 .29575 .43802 .29472 .43755 Mtetra
.668 .86 .973 r
.29472 .43755 .29575 .43802 .29728 .43768 .29627 .43696 Mtetra
.679 .799 .939 r
.29627 .43696 .29728 .43768 .29881 .43733 .29782 .43637 Mtetra
.664 .742 .908 r
.29782 .43637 .29881 .43733 .30035 .4369 .29936 .43584 Mtetra
.656 .721 .897 r
.29936 .43584 .30035 .4369 .30189 .4364 .30091 .43535 Mtetra
.654 .721 .898 r
.30091 .43535 .30189 .4364 .30344 .43585 .30245 .43486 Mtetra
.659 .737 .907 r
.30245 .43486 .30344 .43585 .30499 .43521 .30399 .43436 Mtetra
.661 .766 .927 r
.30399 .43436 .30499 .43521 .30655 .43454 .30554 .43384 Mtetra
.658 .803 .952 r
.30554 .43384 .30655 .43454 .30811 .43387 .30709 .43332 Mtetra
.647 .837 .973 r
.30709 .43332 .30811 .43387 .30966 .43329 .30864 .4328 Mtetra
.64 .853 .981 r
.30864 .4328 .30966 .43329 .31121 .43274 .31019 .43228 Mtetra
.64 .859 .982 r
.31019 .43228 .31121 .43274 .31276 .43222 .31174 .43175 Mtetra
.648 .86 .98 r
.31174 .43175 .31276 .43222 .31432 .43156 .31329 .4312 Mtetra
.633 .885 .987 r
.31329 .4312 .31432 .43156 .31588 .43094 .31485 .43065 Mtetra
.618 .895 .988 r
.31485 .43065 .31588 .43094 .31742 .43053 .3164 .43009 Mtetra
.635 .865 .985 r
.3164 .43009 .31742 .43053 .31892 .43089 .31796 .42957 Mtetra
.655 .674 .856 r
.31796 .42957 .31892 .43089 .32038 .43195 .31951 .42906 Mtetra
.618 .519 .719 r
.31951 .42906 .32038 .43195 .3218 .43363 .32107 .42855 Mtetra
.615 .459 .647 r
.32107 .42855 .3218 .43363 .32332 .43366 .32265 .42768 Mtetra
.6 .437 .632 r
.32265 .42768 .32332 .43366 .3249 .43275 .32422 .42692 Mtetra
.568 .415 .633 r
.32422 .42692 .3249 .43275 .32644 .43256 .32576 .42673 Mtetra
.309 .228 .6 r
.32576 .42673 .32644 .43256 .32724 .44465 .32713 .42928 Mtetra
.966 .706 .489 r
.32713 .42928 .32724 .44465 .31751 .63248 .31683 .6253 Mtetra
0 0 .255 r
.31683 .6253 .31751 .63248 .31893 .63581 .31795 .63371 Mtetra
.198 .338 .781 r
.31795 .63371 .31893 .63581 .32052 .63652 .31951 .63489 Mtetra
.624 .632 .838 r
.31951 .63489 .32052 .63652 .32217 .63624 .32117 .63449 Mtetra
.692 .647 .8 r
.32117 .63449 .32217 .63624 .32384 .63561 .32285 .63361 Mtetra
.649 .605 .791 r
.32285 .63361 .32384 .63561 .32551 .63506 .32452 .63301 Mtetra
.618 .584 .793 r
.32452 .63301 .32551 .63506 .32717 .63451 .32618 .63261 Mtetra
.625 .602 .807 r
.32618 .63261 .32717 .63451 .32885 .63373 .32784 .63219 Mtetra
.58 .626 .862 r
.32784 .63219 .32885 .63373 .33056 .63252 .32949 .632 Mtetra
.532 .821 .999 r
.32949 .632 .33056 .63252 .3323 .6307 .33115 .63168 Mtetra
0 0 0 r
.33115 .63168 .3323 .6307 .3341 .62774 .33284 .63077 Mtetra
.33284 .63077 .3341 .62774 .33634 .61682 .33467 .62723 Mtetra
.962 .705 .5 r
.33467 .62723 .33634 .61682 .34845 .42411 .34699 .43188 Mtetra
0 0 0 r
.34699 .43188 .34845 .42411 .35021 .42014 .34917 .42039 Mtetra
.927 .95 .785 r
.34917 .42039 .35021 .42014 .35184 .41854 .35084 .4181 Mtetra
.674 .875 .974 r
.35084 .4181 .35184 .41854 .35342 .41793 .35242 .41746 Mtetra
.451 .795 .998 r
.35242 .41746 .35342 .41793 .35498 .41767 .35397 .41729 Mtetra
.53 .848 .998 r
.35397 .41729 .35498 .41767 .35654 .41741 .35554 .41694 Mtetra
.657 .864 .978 r
.35554 .41694 .35654 .41741 .35811 .41706 .35712 .41635 Mtetra
.672 .807 .948 r
.35712 .41635 .35811 .41706 .35968 .41669 .3587 .41578 Mtetra
.664 .756 .919 r
.3587 .41578 .35968 .41669 .36126 .41617 .36028 .41524 Mtetra
.656 .751 .92 r
.36028 .41524 .36126 .41617 .36284 .41551 .36186 .41474 Mtetra
.653 .786 .945 r
.36186 .41474 .36284 .41551 .36443 .41483 .36344 .41423 Mtetra
.655 .832 .968 r
.36344 .41423 .36443 .41483 .36602 .4141 .36502 .41369 Mtetra
.646 .876 .984 r
.36502 .41369 .36602 .4141 .36761 .41342 .36661 .41311 Mtetra
.623 .895 .987 r
.36661 .41311 .36761 .41342 .36919 .41295 .36819 .41254 Mtetra
.721 .89 .958 r
.36819 .41254 .36919 .41295 .37075 .4129 .36979 .41174 Mtetra
.709 .72 .859 r
.36979 .41174 .37075 .4129 .37228 .41348 .37139 .41094 Mtetra
.596 .527 .747 r
.37139 .41094 .37228 .41348 .37377 .41507 .37296 .41066 Mtetra
.345 .286 .647 r
.37296 .41066 .37377 .41507 .37498 .42276 .37445 .41242 Mtetra
.965 .699 .481 r
.37445 .41242 .37498 .42276 .36768 .61675 .3674 .59957 Mtetra
0 0 .291 r
.3674 .59957 .36768 .61675 .36919 .6203 .36823 .6177 Mtetra
.057 .194 .692 r
.36823 .6177 .36919 .6203 .37082 .62117 .36981 .61962 Mtetra
.588 .63 .861 r
.36981 .61962 .37082 .62117 .3725 .62077 .37149 .61939 Mtetra
.695 .697 .848 r
.37149 .61939 .3725 .62077 .37421 .61997 .3732 .61861 Mtetra
.696 .699 .849 r
.3732 .61861 .37421 .61997 .37592 .6192 .3749 .61781 Mtetra
.661 .684 .861 r
.3749 .61781 .37592 .6192 .37761 .61863 .3766 .61723 Mtetra
.664 .682 .857 r
.3766 .61723 .37761 .61863 .37931 .61807 .37831 .61662 Mtetra
.659 .675 .854 r
.37831 .61662 .37931 .61807 .38101 .61751 .38001 .61604 Mtetra
.651 .667 .853 r
.38001 .61604 .38101 .61751 .38271 .61698 .38171 .6155 Mtetra
.647 .664 .853 r
.38171 .6155 .38271 .61698 .38441 .61647 .38341 .61498 Mtetra
.643 .662 .853 r
.38341 .61498 .38441 .61647 .38611 .61597 .38511 .61448 Mtetra
.639 .661 .855 r
.38511 .61448 .38611 .61597 .38781 .61548 .38681 .614 Mtetra
.637 .661 .857 r
.38681 .614 .38781 .61548 .38951 .615 .38851 .61353 Mtetra
.634 .662 .86 r
.38851 .61353 .38951 .615 .39122 .61452 .39021 .61308 Mtetra
.633 .666 .864 r
.39021 .61308 .39122 .61452 .39292 .61404 .39191 .61263 Mtetra
.636 .672 .868 r
.39191 .61263 .39292 .61404 .39463 .61357 .39362 .61218 Mtetra
.644 .678 .867 r
.39362 .61218 .39463 .61357 .39633 .61311 .39533 .61167 Mtetra
.653 .675 .859 r
.39533 .61167 .39633 .61311 .39804 .61266 .39704 .61112 Mtetra
.652 .66 .845 r
.39704 .61112 .39804 .61266 .39974 .61222 .39875 .61057 Mtetra
.601 .624 .846 r
.39875 .61057 .39974 .61222 .40145 .61192 .40045 .61027 Mtetra
.56 .606 .856 r
.40045 .61027 .40145 .61192 .40315 .6117 .40215 .61017 Mtetra
.663 .666 .843 r
.40215 .61017 .40315 .6117 .40486 .61111 .40387 .60955 Mtetra
.825 .711 .739 r
.40387 .60955 .40486 .61111 .40662 .60942 .40565 .6071 Mtetra
.911 .688 .587 r
.40565 .6071 .40662 .60942 .40846 .60521 .40772 .59602 Mtetra
.945 .679 .502 r
.40772 .59602 .40846 .60521 .41656 .41381 .41607 .39897 Mtetra
.624 .415 .579 r
.41607 .39897 .41656 .41381 .41861 .40036 .41778 .39565 Mtetra
.619 .469 .656 r
.41778 .39565 .41861 .40036 .4203 .39748 .41941 .39477 Mtetra
.599 .519 .736 r
.41941 .39477 .4203 .39748 .42195 .39574 .42101 .39445 Mtetra
.59 .659 .886 r
.42101 .39445 .42195 .39574 .42359 .39465 .42262 .39421 Mtetra
.607 .866 .992 r
.42262 .39421 .42359 .39465 .42521 .39403 .42424 .39371 Mtetra
.569 .883 .991 r
.42424 .39371 .42521 .39403 .42682 .39363 .42585 .39323 Mtetra
.6 .874 .993 r
.42585 .39323 .42682 .39363 .42843 .3933 .42747 .39273 Mtetra
.643 .843 .977 r
.42747 .39273 .42843 .3933 .43005 .39291 .42909 .39219 Mtetra
.659 .808 .955 r
.42909 .39219 .43005 .39291 .43166 .39252 .43071 .39164 Mtetra
.669 .771 .926 r
.43071 .39164 .43166 .39252 .43328 .39209 .43234 .39107 Mtetra
.673 .742 .902 r
.43234 .39107 .43328 .39209 .4349 .39157 .43396 .39047 Mtetra
.671 .727 .892 r
.43396 .39047 .4349 .39157 .43653 .39099 .43559 .38989 Mtetra
.664 .724 .894 r
.43559 .38989 .43653 .39099 .43816 .39033 .43721 .38933 Mtetra
.652 .741 .915 r
.43721 .38933 .43816 .39033 .43979 .3896 .43884 .38883 Mtetra
.643 .793 .954 r
.43884 .38883 .43979 .3896 .44142 .38886 .44046 .38834 Mtetra
.681 .864 .968 r
.44046 .38834 .44142 .38886 .44305 .38807 .4421 .38767 Mtetra
.751 .903 .945 r
.4421 .38767 .44305 .38807 .44469 .38722 .44373 .38673 Mtetra
.617 .856 .988 r
.44373 .38673 .44469 .38722 .44632 .3867 .44536 .38623 Mtetra
.374 0 0 r
.44536 .38623 .44632 .3867 .44792 .3871 .44696 .38711 Mtetra
.93 .593 .374 r
.44696 .38711 .44792 .3871 .44947 .39013 .44838 .39544 Mtetra
.951 .676 .481 r
.44838 .39544 .44947 .39013 .44666 .58325 .44539 .59365 Mtetra
.624 .354 .488 r
.44539 .59365 .44666 .58325 .44817 .59254 .44705 .59662 Mtetra
.505 .192 .369 r
.44705 .59662 .44817 .59254 .4499 .59239 .44879 .59651 Mtetra
.441 .134 .348 r
.44879 .59651 .4499 .59239 .45165 .5915 .45054 .59577 Mtetra
.429 .127 .349 r
.45054 .59577 .45165 .5915 .45338 .5914 .45229 .59488 Mtetra
.454 .13 .325 r
.45229 .59488 .45338 .5914 .45508 .59314 .45403 .59441 Mtetra
.262 0 0 r
.45403 .59441 .45508 .59314 .45679 .59435 .45578 .59393 Mtetra
.595 .875 .993 r
.45578 .59393 .45679 .59435 .45851 .59491 .45752 .59339 Mtetra
.662 .67 .847 r
.45752 .59339 .45851 .59491 .46025 .5947 .45928 .59277 Mtetra
.653 .618 .802 r
.45928 .59277 .46025 .5947 .462 .59425 .46103 .59213 Mtetra
.644 .597 .787 r
.46103 .59213 .462 .59425 .46375 .59366 .46278 .59152 Mtetra
.631 .589 .788 r
.46278 .59152 .46375 .59366 .46551 .59304 .46453 .59101 Mtetra
.631 .599 .799 r
.46453 .59101 .46551 .59304 .46726 .59237 .46628 .59051 Mtetra
.617 .609 .821 r
.46628 .59051 .46726 .59237 .46902 .59179 .46804 .59012 Mtetra
.557 .603 .856 r
.46804 .59012 .46902 .59179 .47077 .59154 .46978 .59004 Mtetra
.648 .667 .854 r
.46978 .59004 .47077 .59154 .47253 .59101 .47154 .58949 Mtetra
.789 .713 .78 r
.47154 .58949 .47253 .59101 .47429 .58968 .47332 .58774 Mtetra
.909 .702 .611 r
.47332 .58774 .47429 .58968 .4761 .58566 .47518 .58015 Mtetra
.956 .685 .48 r
.47518 .58015 .4761 .58566 .47805 .57163 .47977 .37864 Mtetra
.554 .335 .537 r
.47977 .37864 .47805 .57163 .48234 .38 .48147 .37419 Mtetra
.615 .45 .635 r
.48147 .37419 .48234 .38 .484 .37858 .48313 .37315 Mtetra
.583 .432 .643 r
.48313 .37315 .484 .37858 .48565 .37831 .48479 .37274 Mtetra
.566 .419 .641 r
.48479 .37274 .48565 .37831 .4873 .37852 .48644 .37257 Mtetra
.588 .429 .634 r
.48644 .37257 .4873 .37852 .48896 .378 .48809 .37203 Mtetra
.587 .428 .634 r
.48809 .37203 .48896 .378 .49062 .37749 .48975 .37149 Mtetra
.587 .428 .633 r
.48975 .37149 .49062 .37749 .49228 .37699 .49141 .37095 Mtetra
.49141 .37095 .49228 .37699 .49394 .37645 .49307 .37039 Mtetra
.588 .428 .632 r
.49307 .37039 .49394 .37645 .4956 .3759 .49473 .36983 Mtetra
.49473 .36983 .4956 .3759 .49726 .37534 .49639 .36927 Mtetra
.49639 .36927 .49726 .37534 .49893 .37479 .49805 .36871 Mtetra
.49805 .36871 .49893 .37479 .50059 .37422 .49971 .36815 Mtetra
.49971 .36815 .50059 .37422 .50226 .37366 .50138 .36758 Mtetra
.50138 .36758 .50226 .37366 .50393 .37309 .50304 .36702 Mtetra
.50304 .36702 .50393 .37309 .50559 .37253 .50471 .36645 Mtetra
.50471 .36645 .50559 .37253 .50726 .37195 .50638 .36589 Mtetra
.50638 .36589 .50726 .37195 .50893 .37138 .50804 .36532 Mtetra
.50804 .36532 .50893 .37138 .51061 .37079 .50971 .36475 Mtetra
.588 .429 .633 r
.50971 .36475 .51061 .37079 .51228 .3702 .51138 .36417 Mtetra
.589 .43 .633 r
.51138 .36417 .51228 .3702 .51395 .36957 .51305 .36358 Mtetra
.51305 .36358 .51395 .36957 .51563 .36895 .51473 .36299 Mtetra
.59 .431 .634 r
.51473 .36299 .51563 .36895 .5173 .3683 .5164 .36239 Mtetra
.612 .447 .634 r
.5164 .36239 .5173 .3683 .51898 .36691 .51808 .3614 Mtetra
.595 .44 .641 r
.51808 .3614 .51898 .36691 .52066 .36621 .51975 .36077 Mtetra
.547 .408 .644 r
.51975 .36077 .52066 .36621 .52233 .36691 .52143 .36089 Mtetra
.103 .088 .554 r
.52143 .36089 .52233 .36691 .52396 .56352 .5231 .36548 Mtetra
0 0 .345 r
.5231 .36548 .52396 .56352 .52574 .57163 .52478 .5674 Mtetra
0 0 .467 r
.52478 .5674 .52574 .57163 .52754 .57414 .52657 .57238 Mtetra
.504 .566 .852 r
.52657 .57238 .52754 .57414 .52933 .57406 .52836 .57252 Mtetra
.66 .672 .85 r
.52836 .57252 .52933 .57406 .53112 .57346 .53016 .5719 Mtetra
.717 .69 .823 r
.53016 .5719 .53112 .57346 .53292 .57262 .53195 .57087 Mtetra
.646 .638 .828 r
.53195 .57087 .53292 .57262 .53472 .57223 .53375 .57029 Mtetra
.641 .616 .809 r
.53375 .57029 .53472 .57223 .53651 .57183 .53554 .56973 Mtetra
.635 .597 .794 r
.53554 .56973 .53651 .57183 .53831 .57138 .53734 .56918 Mtetra
.618 .58 .789 r
.53734 .56918 .53831 .57138 .54011 .57089 .53914 .56875 Mtetra
.617 .584 .794 r
.53914 .56875 .54011 .57089 .54191 .57024 .54095 .56832 Mtetra
.623 .609 .816 r
.54095 .56832 .54191 .57024 .54371 .56933 .54275 .56788 Mtetra
.648 .68 .866 r
.54275 .56788 .54371 .56933 .54551 .56749 .54455 .56732 Mtetra
.515 .897 .957 r
.54455 .56732 .54551 .56749 .5473 .56506 .54636 .56674 Mtetra
.307 0 .083 r
.54636 .56674 .5473 .56506 .54909 .56208 .54816 .56613 Mtetra
.506 .19 .366 r
.54816 .56613 .54909 .56208 .55089 .56165 .54998 .56604 Mtetra
.481 .176 .371 r
.54998 .56604 .55089 .56165 .5527 .5614 .55178 .56563 Mtetra
.404 .105 .34 r
.55178 .56563 .5527 .5614 .5545 .56017 .55359 .56448 Mtetra
0 0 .074 r
.55359 .56448 .5545 .56017 .5545 .36481 .55536 .55911 Mtetra
0 0 .339 r
.55536 .55911 .5545 .36481 .55609 .35306 .55523 .3557 Mtetra
.843 .804 .313 r
.55523 .3557 .55609 .35306 .55776 .34949 .55687 .34922 Mtetra
.835 .946 .894 r
.55687 .34922 .55776 .34949 .55945 .34832 .55856 .34779 Mtetra
.617 .856 .989 r
.55856 .34779 .55945 .34832 .56115 .34778 .56026 .34727 Mtetra
.423 .781 .996 r
.56026 .34727 .56115 .34778 .56285 .34753 .56197 .34713 Mtetra
.608 .886 .99 r
.56197 .34713 .56285 .34753 .56456 .34714 .56367 .34656 Mtetra
.663 .856 .974 r
.56367 .34656 .56456 .34714 .56626 .34674 .56537 .34592 Mtetra
.674 .799 .942 r
.56537 .34592 .56626 .34674 .56797 .34631 .56708 .34529 Mtetra
.666 .752 .914 r
.56708 .34529 .56797 .34631 .56967 .34553 .56878 .34471 Mtetra
.658 .795 .948 r
.56878 .34471 .56967 .34553 .57137 .34477 .57049 .34414 Mtetra
.641 .839 .976 r
.57049 .34414 .57137 .34477 .57308 .34422 .5722 .34358 Mtetra
.64 .836 .976 r
.5722 .34358 .57308 .34422 .5748 .34464 .57391 .34303 Mtetra
.649 .645 .833 r
.57391 .34303 .5748 .34464 .57654 .34572 .57562 .34248 Mtetra
.614 .507 .709 r
.57562 .34248 .57654 .34572 .57829 .34744 .57733 .34193 Mtetra
.614 .454 .641 r
.57733 .34193 .57829 .34744 .58001 .34702 .57903 .34095 Mtetra
.598 .435 .633 r
.57903 .34095 .58001 .34702 .58171 .34608 .58074 .34018 Mtetra
.564 .414 .636 r
.58074 .34018 .58171 .34608 .58344 .34597 .58246 .34003 Mtetra
.291 .224 .608 r
.58246 .34003 .58344 .34597 .58879 .53669 .58425 .34319 Mtetra
0 0 .365 r
.58425 .34319 .58879 .53669 .59091 .55119 .58987 .54511 Mtetra
0 0 .454 r
.58987 .54511 .59091 .55119 .59282 .55422 .59185 .55213 Mtetra
.351 .442 .814 r
.59185 .55213 .59282 .55422 .59467 .55467 .59372 .55299 Mtetra
.617 .637 .848 r
.59372 .55299 .59467 .55467 .59651 .5542 .59556 .55259 Mtetra
.694 .679 .831 r
.59556 .55259 .59651 .5542 .59834 .5532 .59739 .55172 Mtetra
.594 .655 .88 r
.59739 .55172 .59834 .5532 .60016 .55182 .59924 .55143 Mtetra
.514 .859 .993 r
.59924 .55143 .60016 .55182 .60197 .54981 .60108 .551 Mtetra
.002 0 0 r
.60108 .551 .60197 .54981 .60374 .54644 .60291 .54989 Mtetra
0 0 .047 r
.60291 .54989 .60374 .54644 .60105 .35674 .60466 .54544 Mtetra
0 0 .35 r
.60466 .54544 .60105 .35674 .60234 .33784 .60159 .34233 Mtetra
0 0 0 r
.60159 .34233 .60234 .33784 .60399 .33416 .60314 .3341 Mtetra
.888 .973 .83 r
.60314 .3341 .60399 .33416 .60569 .33275 .60483 .33221 Mtetra
.645 .866 .982 r
.60483 .33221 .60569 .33275 .60742 .33215 .60656 .3316 Mtetra
.457 .79 .999 r
.60656 .3316 .60742 .33215 .60916 .33187 .6083 .33142 Mtetra
.58 .867 .995 r
.6083 .33142 .60916 .33187 .61089 .33151 .61003 .33093 Mtetra
.664 .861 .975 r
.61003 .33093 .61089 .33151 .61263 .33109 .61176 .33027 Mtetra
.677 .805 .944 r
.61176 .33027 .61263 .33109 .61436 .33064 .61349 .32962 Mtetra
.674 .758 .914 r
.61349 .32962 .61436 .33064 .61609 .32987 .61523 .32899 Mtetra
.667 .787 .938 r
.61523 .32899 .61609 .32987 .61782 .32905 .61696 .32838 Mtetra
.651 .835 .971 r
.61696 .32838 .61782 .32905 .61955 .32843 .6187 .32779 Mtetra
.733 .864 .942 r
.6187 .32779 .61955 .32843 .62131 .32837 .62042 .3269 Mtetra
.688 .683 .84 r
.62042 .3269 .62131 .32837 .62308 .329 .62216 .32612 Mtetra
.582 .506 .734 r
.62216 .32612 .62308 .329 .6249 .33079 .62391 .3259 Mtetra
.321 .267 .64 r
.62391 .3259 .6249 .33079 .62712 .34507 .62574 .32832 Mtetra
.983 .696 .363 r
.62574 .32832 .62712 .34507 .6352 .53739 .63402 .52837 Mtetra
0 0 .456 r
.63402 .52837 .6352 .53739 .63719 .54052 .63622 .53814 Mtetra
.273 .365 .775 r
.63622 .53814 .63719 .54052 .63909 .54096 .63815 .53947 Mtetra
.604 .661 .879 r
.63815 .53947 .63909 .54096 .64095 .54032 .64002 .53914 Mtetra
.705 .751 .888 r
.64002 .53914 .64095 .54032 .6428 .53933 .64188 .53828 Mtetra
.594 .738 .944 r
.64188 .53828 .6428 .53933 .64468 .53905 .64376 .53792 Mtetra
.581 .716 .935 r
.64376 .53792 .64468 .53905 .64657 .53893 .64564 .53763 Mtetra
.713 .735 .868 r
.64564 .53763 .64657 .53893 .64843 .53817 .6475 .5367 Mtetra
.893 .75 .696 r
.6475 .5367 .64843 .53817 .65018 .53445 .64926 .53303 Mtetra
.974 .686 .416 r
.64926 .53303 .65018 .53445 .64439 .33159 .6436 .33245 Mtetra
.998 .78 .463 r
.6436 .33245 .64439 .33159 .64576 .32092 .64493 .32052 Mtetra
.926 .901 .781 r
.64493 .32052 .64576 .32092 .64745 .31867 .64661 .31811 Mtetra
.691 .876 .968 r
.64661 .31811 .64745 .31867 .64921 .31813 .64836 .31735 Mtetra
.552 .771 .979 r
.64836 .31735 .64921 .31813 .65098 .31811 .65013 .31707 Mtetra
.605 .732 .935 r
.65013 .31707 .65098 .31811 .65275 .31788 .65189 .31671 Mtetra
.649 .721 .902 r
.65189 .31671 .65275 .31788 .65451 .31734 .65366 .31618 Mtetra
.649 .723 .903 r
.65366 .31618 .65451 .31734 .65627 .31675 .65542 .31565 Mtetra
.664 .742 .908 r
.65542 .31565 .65627 .31675 .65802 .31593 .65718 .31506 Mtetra
.675 .796 .939 r
.65718 .31506 .65802 .31593 .65977 .31504 .65894 .31441 Mtetra
.664 .851 .972 r
.65894 .31441 .65977 .31504 .66153 .31436 .6607 .31375 Mtetra
.732 .877 .948 r
.6607 .31375 .66153 .31436 .66331 .3142 .66245 .31284 Mtetra
.708 .711 .851 r
.66245 .31284 .66331 .3142 .66512 .31474 .6642 .31196 Mtetra
.597 .521 .74 r
.6642 .31196 .66512 .31474 .66699 .31632 .66597 .31163 Mtetra
.373 .309 .655 r
.66597 .31163 .66699 .31632 .66912 .32366 .66786 .31356 Mtetra
.98 .686 .361 r
.66786 .31356 .66912 .32366 .68016 .52261 .67881 .51191 Mtetra
0 0 .431 r
.67881 .51191 .68016 .52261 .68225 .5263 .68131 .5245 Mtetra
0 .202 .728 r
.68131 .5245 .68225 .5263 .68423 .52754 .68333 .52649 Mtetra
.509 .702 .957 r
.68333 .52649 .68423 .52754 .68615 .52755 .68525 .52639 Mtetra
.751 .774 .872 r
.68525 .52639 .68615 .52755 .68803 .52663 .68712 .52525 Mtetra
.894 .763 .71 r
.68712 .52525 .68803 .52663 .68979 .52329 .68888 .52186 Mtetra
.974 .712 .474 r
.68888 .52186 .68979 .52329 .68191 .32654 .68978 .50108 Mtetra
0 0 .376 r
.68978 .50108 .68191 .32654 .68283 .30879 .68202 .30843 Mtetra
.95 .895 .737 r
.68202 .30843 .68283 .30879 .6845 .30607 .68369 .30554 Mtetra
.717 .894 .96 r
.68369 .30554 .6845 .30607 .68627 .30541 .68545 .30466 Mtetra
.579 .794 .981 r
.68545 .30466 .68627 .30541 .68807 .30526 .68724 .30429 Mtetra
.607 .75 .945 r
.68724 .30429 .68807 .30526 .68986 .30487 .68903 .3039 Mtetra
.664 .772 .93 r
.68903 .3039 .68986 .30487 .69163 .30404 .69081 .30329 Mtetra
.649 .821 .966 r
.69081 .30329 .69163 .30404 .69341 .30337 .6926 .30271 Mtetra
.707 .859 .955 r
.6926 .30271 .69341 .30337 .69521 .30316 .69437 .3019 Mtetra
.714 .732 .865 r
.69437 .3019 .69521 .30316 .69706 .30361 .69614 .30101 Mtetra
.606 .538 .751 r
.69614 .30101 .69706 .30361 .69895 .30499 .69793 .3006 Mtetra
.418 .347 .67 r
.69793 .3006 .69895 .30499 .70107 .31021 .69983 .30205 Mtetra
0 0 .329 r
.69983 .30205 .70107 .31021 .71432 .51124 .7024 .3151 Mtetra
.006 0 .418 r
.7024 .3151 .71432 .51124 .71651 .51561 .71557 .51348 Mtetra
0 .188 .71 r
.71557 .51348 .71651 .51561 .71854 .51691 .71765 .51576 Mtetra
.568 .71 .937 r
.71765 .51576 .71854 .51691 .72049 .51682 .71959 .5155 Mtetra
.7 .734 .877 r
.71959 .5155 .72049 .51682 .7224 .51613 .72149 .51464 Mtetra
.66 .69 .867 r
.72149 .51464 .7224 .51613 .72429 .51496 .72341 .51399 Mtetra
.539 .736 .966 r
.72341 .51399 .72429 .51496 .72614 .51325 .72536 .51377 Mtetra
0 0 0 r
.72536 .51377 .72614 .51325 .72794 .51055 .72727 .51301 Mtetra
0 0 .082 r
.72727 .51301 .72794 .51055 .72951 .50427 .72907 .51035 Mtetra
0 0 .041 r
.72907 .51035 .72951 .50427 .7189 .30185 .73029 .49838 Mtetra
.002 0 .411 r
.73029 .49838 .7189 .30185 .7204 .29649 .71964 .29639 Mtetra
.973 .915 .685 r
.71964 .29639 .7204 .29649 .7221 .29427 .72127 .29304 Mtetra
.708 .737 .874 r
.72127 .29304 .7221 .29427 .72389 .29351 .72305 .29219 Mtetra
.592 .672 .895 r
.72305 .29219 .72389 .29351 .72571 .29315 .72488 .2919 Mtetra
.583 .682 .909 r
.72488 .2919 .72571 .29315 .72753 .29279 .7267 .29164 Mtetra
.668 .739 .903 r
.7267 .29164 .72753 .29279 .72933 .29215 .72851 .29101 Mtetra
.672 .742 .903 r
.72851 .29101 .72933 .29215 .73113 .29147 .73031 .29036 Mtetra
.716 .765 .891 r
.73031 .29036 .73113 .29147 .73291 .29051 .7321 .28949 Mtetra
.755 .794 .884 r
.7321 .28949 .73291 .29051 .73468 .2893 .73388 .28841 Mtetra
.659 .793 .946 r
.73388 .28841 .73468 .2893 .73648 .28858 .73569 .2878 Mtetra
0 .4 .836 r
.73569 .2878 .73648 .28858 .73839 .28934 .7376 .28871 Mtetra
.921 .531 .15 r
.7376 .28871 .73839 .28934 .7407 .29601 .73999 .29647 Mtetra
.975 .67 .357 r
.73999 .29647 .7407 .29601 .75688 .50121 .75604 .5004 Mtetra
.683 .194 0 r
.75604 .5004 .75688 .50121 .75909 .50443 .75823 .50337 Mtetra
.544 .72 .955 r
.75823 .50337 .75909 .50443 .76107 .50425 .7602 .50316 Mtetra
.706 .782 .911 r
.7602 .50316 .76107 .50425 .763 .50339 .76213 .50229 Mtetra
.689 .773 .915 r
.76213 .50229 .763 .50339 .76494 .50269 .76407 .50151 Mtetra
.519 .683 .941 r
.76407 .50151 .76494 .50269 .76694 .50277 .76606 .50143 Mtetra
.652 .714 .894 r
.76606 .50143 .76694 .50277 .7689 .50231 .76801 .50083 Mtetra
.833 .754 .776 r
.76801 .50083 .7689 .50231 .77075 .50031 .76984 .49865 Mtetra
.963 .732 .542 r
.76984 .49865 .77075 .50031 .77213 .49202 .77114 .48921 Mtetra
.977 .677 .367 r
.77114 .48921 .77213 .49202 .7586 .28554 .75776 .28408 Mtetra
.914 .755 .671 r
.75776 .28408 .7586 .28554 .76015 .28132 .75934 .28014 Mtetra
.728 .757 .876 r
.75934 .28014 .76015 .28132 .76194 .28033 .76113 .27918 Mtetra
.605 .713 .921 r
.76113 .27918 .76194 .28033 .76379 .27997 .76298 .27881 Mtetra
.604 .713 .921 r
.76298 .27881 .76379 .27997 .76564 .27961 .76483 .27845 Mtetra
.741 .765 .872 r
.76483 .27845 .76564 .27961 .76743 .27856 .76662 .2774 Mtetra
.66 .736 .907 r
.76662 .2774 .76743 .27856 .76926 .27796 .76846 .2768 Mtetra
.243 .513 .908 r
.76846 .2768 .76926 .27796 .7712 .27864 .77039 .27749 Mtetra
.881 .488 .031 r
.77039 .27749 .7712 .27864 .77365 .28585 .77285 .28468 Mtetra
.975 .667 .334 r
.77285 .28468 .77365 .28585 .79207 .4908 .79122 .4897 Mtetra
.653 .2 0 r
.79122 .4897 .79207 .4908 .79436 .49421 .79352 .49316 Mtetra
.386 .641 .957 r
.79352 .49316 .79436 .49421 .79639 .49434 .79556 .4934 Mtetra
.701 .815 .936 r
.79556 .4934 .79639 .49434 .79834 .4935 .79751 .49256 Mtetra
.889 .845 .795 r
.79751 .49256 .79834 .4935 .80021 .4916 .79934 .49021 Mtetra
.969 .751 .554 r
.79934 .49021 .80021 .4916 .80189 .48752 .80069 .48209 Mtetra
.975 .672 .359 r
.80069 .48209 .80189 .48752 .80253 .47111 .78533 .2754 Mtetra
.553 .334 .536 r
.78533 .2754 .80253 .47111 .78802 .2765 .78685 .27094 Mtetra
.617 .456 .642 r
.78685 .27094 .78802 .2765 .78966 .27344 .78865 .26987 Mtetra
.598 .489 .701 r
.78865 .26987 .78966 .27344 .7914 .27159 .79051 .26942 Mtetra
.585 .562 .795 r
.79051 .26942 .7914 .27159 .79319 .27035 .79239 .2692 Mtetra
.665 .744 .908 r
.79239 .2692 .79319 .27035 .79502 .26959 .79424 .26857 Mtetra
.663 .769 .929 r
.79424 .26857 .79502 .26959 .79688 .26902 .79609 .26794 Mtetra
.678 .764 .916 r
.79609 .26794 .79688 .26902 .79872 .26837 .79793 .26725 Mtetra
.739 .777 .884 r
.79793 .26725 .79872 .26837 .80051 .26711 .79975 .26623 Mtetra
.656 .802 .953 r
.79975 .26623 .80051 .26711 .80235 .26627 .8016 .26562 Mtetra
.174 .598 .939 r
.8016 .26562 .80235 .26627 .80427 .26643 .80355 .26602 Mtetra
.881 .455 .057 r
.80355 .26602 .80427 .26643 .80662 .27132 .80598 .27182 Mtetra
.973 .661 .321 r
.80598 .27182 .80662 .27132 .82754 .47861 .82676 .47808 Mtetra
.801 .331 0 r
.82676 .47808 .82754 .47861 .83002 .48331 .82919 .48219 Mtetra
.332 .594 .941 r
.82919 .48219 .83002 .48331 .83212 .48378 .83128 .48262 Mtetra
.666 .759 .919 r
.83128 .48262 .83212 .48378 .8341 .48308 .83327 .48194 Mtetra
.85 .815 .815 r
.83327 .48194 .8341 .48308 .83596 .48098 .83514 .47993 Mtetra
.98 .779 .56 r
.83514 .47993 .83596 .48098 .83728 .47317 .83652 .47284 Mtetra
.976 .671 .326 r
.83652 .47284 .83728 .47317 .81949 .26522 .81878 .26485 Mtetra
.994 .843 .583 r
.81878 .26485 .81949 .26522 .82096 .26044 .82021 .25971 Mtetra
.77 .875 .924 r
.82021 .25971 .82096 .26044 .82278 .25945 .82203 .25858 Mtetra
.604 .784 .967 r
.82203 .25858 .82278 .25945 .82468 .25915 .82391 .25814 Mtetra
.528 .714 .957 r
.82391 .25814 .82468 .25915 .82661 .25915 .82583 .25799 Mtetra
.741 .774 .879 r
.82583 .25799 .82661 .25915 .82845 .25826 .82766 .25695 Mtetra
.667 .715 .884 r
.82766 .25695 .82845 .25826 .83032 .25761 .82952 .25629 Mtetra
.463 .609 .91 r
.82952 .25629 .83032 .25761 .83224 .25753 .83148 .25648 Mtetra
.801 .383 0 r
.83148 .25648 .83224 .25753 .83442 .25991 .83396 .26195 Mtetra
.971 .656 .31 r
.83396 .26195 .83442 .25991 .83773 .2735 .85677 .46889 Mtetra
.551 .328 .529 r
.85677 .46889 .83773 .2735 .8596 .4695 .85929 .47331 Mtetra
.549 .215 .355 r
.85929 .47331 .8596 .4695 .86197 .47238 .86142 .47382 Mtetra
.294 0 .04 r
.86142 .47382 .86197 .47238 .86413 .47317 .86344 .47321 Mtetra
.771 .995 .8 r
.86344 .47321 .86413 .47317 .86615 .47251 .86534 .47144 Mtetra
.979 .789 .579 r
.86534 .47144 .86615 .47251 .86763 .46674 .86677 .46517 Mtetra
.974 .666 .314 r
.86677 .46517 .86763 .46674 .8478 .25777 .84699 .25622 Mtetra
.955 .752 .59 r
.84699 .25622 .8478 .25777 .84908 .25137 .84831 .25024 Mtetra
.8 .766 .822 r
.24184 .4539 .24285 .45481 .24445 .4533 .24342 .4525 Mtetra
.659 .774 .934 r
.24342 .4525 .24445 .4533 .24596 .45277 .24494 .452 Mtetra
.244 .609 .954 r
.24494 .452 .24596 .45277 .2474 .45322 .24638 .45229 Mtetra
.752 .257 0 r
.24638 .45229 .2474 .45322 .24853 .45726 .24769 .45416 Mtetra
.928 .618 .15 r
.24769 .45416 .24853 .45726 .23351 .65402 .24864 .46041 Mtetra
0 0 .189 r
.24864 .46041 .23351 .65402 .23462 .6595 .23399 .65308 Mtetra
.25 .178 .576 r
.23399 .65308 .23462 .6595 .23615 .65986 .2353 .65622 Mtetra
.361 .327 .686 r
.2353 .65622 .23615 .65986 .23776 .65937 .23676 .6575 Mtetra
.407 .49 .832 r
.23676 .6575 .23776 .65937 .23941 .65848 .23829 .65799 Mtetra
.489 .81 1 r
.23829 .65799 .23941 .65848 .24102 .65797 .23988 .65775 Mtetra
.573 .897 .985 r
.23988 .65775 .24102 .65797 .24264 .65747 .2415 .65723 Mtetra
.649 .913 .98 r
.2415 .65723 .24264 .65747 .24425 .65694 .24313 .65655 Mtetra
.6 .87 .993 r
.24313 .65655 .24425 .65694 .24587 .6564 .24474 .65606 Mtetra
.578 .875 .994 r
.24474 .65606 .24587 .6564 .24749 .65586 .24636 .65559 Mtetra
.554 .881 .99 r
.24636 .65559 .24749 .65586 .24911 .65534 .24797 .65512 Mtetra
.528 .882 .983 r
.24797 .65512 .24911 .65534 .25072 .65489 .24959 .65466 Mtetra
.53 .881 .984 r
.24959 .65466 .25072 .65489 .25234 .65446 .25121 .65421 Mtetra
.543 .881 .988 r
.25121 .65421 .25234 .65446 .25395 .65403 .25282 .65375 Mtetra
.348 .789 .961 r
.25282 .65375 .25395 .65403 .25553 .65401 .25442 .65358 Mtetra
.546 .845 .998 r
.25442 .65358 .25553 .65401 .25714 .65369 .25603 .65321 Mtetra
.729 .872 .947 r
.25603 .65321 .25714 .65369 .25881 .65266 .25768 .65236 Mtetra
.917 .831 .746 r
.25768 .65236 .25881 .65266 .26076 .64778 .2595 .64934 Mtetra
.992 .849 .595 r
.2595 .64934 .26076 .64778 .27733 .44978 .26163 .64223 Mtetra
0 0 .19 r
.26163 .64223 .27733 .44978 .27933 .44309 .2779 .44774 Mtetra
.198 0 .266 r
.2779 .44774 .27933 .44309 .28093 .4416 .27959 .44525 Mtetra
.455 .142 .344 r
.27959 .44525 .28093 .4416 .28247 .44108 .28112 .44476 Mtetra
.544 .228 .383 r
.28112 .44476 .28247 .44108 .28397 .44097 .2826 .44505 Mtetra
.485 .18 .373 r
.2826 .44505 .28397 .44097 .2855 .44054 .28412 .44473 Mtetra
.472 .17 .371 r
.28412 .44473 .2855 .44054 .28704 .44005 .28566 .44428 Mtetra
.474 .172 .373 r
.28566 .44428 .28704 .44005 .28857 .43956 .28719 .44384 Mtetra
.522 .219 .394 r
.28719 .44384 .28857 .43956 .29011 .43909 .28869 .44387 Mtetra
.505 .211 .401 r
.28869 .44387 .29011 .43909 .29164 .43861 .29021 .44367 Mtetra
.427 .143 .377 r
.29021 .44367 .29164 .43861 .29318 .43812 .29179 .44261 Mtetra
.082 0 .208 r
.29179 .44261 .29318 .43812 .29472 .43755 .29351 .43961 Mtetra
0 0 0 r
.29351 .43961 .29472 .43755 .29627 .43696 .2952 .43704 Mtetra
.899 .942 .829 r
.2952 .43704 .29627 .43696 .29782 .43637 .29684 .43514 Mtetra
.726 .71 .835 r
.29684 .43514 .29782 .43637 .29936 .43584 .29841 .43423 Mtetra
.648 .63 .818 r
.29841 .43423 .29936 .43584 .30091 .43535 .29996 .43371 Mtetra
.62 .615 .824 r
.29996 .43371 .30091 .43535 .30245 .43486 .30149 .43335 Mtetra
.645 .642 .833 r
.30149 .43335 .30245 .43486 .30399 .43436 .30304 .43288 Mtetra
.651 .649 .834 r
.30304 .43288 .30399 .43436 .30554 .43384 .30458 .43236 Mtetra
.647 .647 .837 r
.30458 .43236 .30554 .43384 .30709 .43332 .30613 .43188 Mtetra
.632 .646 .846 r
.30613 .43188 .30709 .43332 .30864 .4328 .30767 .43147 Mtetra
.625 .661 .865 r
.30767 .43147 .30864 .4328 .31019 .43228 .30921 .4311 Mtetra
.627 .689 .888 r
.30921 .4311 .31019 .43228 .31174 .43175 .31075 .43073 Mtetra
.646 .725 .906 r
.31075 .43073 .31174 .43175 .31329 .4312 .3123 .43027 Mtetra
.663 .749 .915 r
.3123 .43027 .31329 .4312 .31485 .43065 .31385 .42975 Mtetra
.677 .761 .914 r
.31385 .42975 .31485 .43065 .3164 .43009 .31541 .42917 Mtetra
.699 .759 .898 r
.31541 .42917 .3164 .43009 .31796 .42957 .31698 .42849 Mtetra
.702 .73 .872 r
.31698 .42849 .31796 .42957 .31951 .42906 .31854 .42776 Mtetra
.69 .691 .846 r
.31854 .42776 .31951 .42906 .32107 .42855 .32011 .42706 Mtetra
.701 .667 .814 r
.32011 .42706 .32107 .42855 .32265 .42768 .32169 .42622 Mtetra
.682 .665 .826 r
.32169 .42622 .32265 .42768 .32422 .42692 .32326 .42552 Mtetra
.606 .644 .862 r
.32326 .42552 .32422 .42692 .32576 .42673 .3248 .42524 Mtetra
0 .208 .735 r
.3248 .42524 .32576 .42673 .32713 .42928 .32625 .42655 Mtetra
.778 .461 0 r
.32625 .42655 .32713 .42928 .31683 .6253 .32751 .4311 Mtetra
0 0 .241 r
.32751 .4311 .31683 .6253 .31795 .63371 .31731 .62593 Mtetra
.376 .258 .589 r
.31731 .62593 .31795 .63371 .31951 .63489 .31878 .62859 Mtetra
.588 .428 .632 r
.31878 .62859 .31951 .63489 .32117 .63449 .32044 .62802 Mtetra
.604 .438 .63 r
.32044 .62802 .32117 .63449 .32285 .63361 .32213 .62713 Mtetra
.458 .332 .621 r
.32213 .62713 .32285 .63361 .32452 .63301 .32368 .62847 Mtetra
.351 .293 .651 r
.32368 .62847 .32452 .63301 .32618 .63261 .32521 .6302 Mtetra
.302 .371 .768 r
.32521 .6302 .32618 .63261 .32784 .63219 .32679 .63126 Mtetra
.285 .607 .954 r
.32679 .63126 .32784 .63219 .32949 .632 .32841 .63159 Mtetra
.472 .825 .997 r
.32841 .63159 .32949 .632 .33115 .63168 .33007 .63131 Mtetra
.715 .903 .962 r
.33007 .63131 .33115 .63168 .33284 .63077 .33175 .63047 Mtetra
.905 .867 .791 r
.33175 .63047 .33284 .63077 .33467 .62723 .33353 .62807 Mtetra
.986 .864 .63 r
.33353 .62807 .33467 .62723 .34699 .43188 .33547 .62263 Mtetra
0 0 .229 r
.33547 .62263 .34699 .43188 .34917 .42039 .34779 .42668 Mtetra
.059 0 .256 r
.34779 .42668 .34917 .42039 .35084 .4181 .34959 .42216 Mtetra
.467 .162 .364 r
.34959 .42216 .35084 .4181 .35242 .41746 .35116 .42167 Mtetra
.512 .208 .387 r
.35116 .42167 .35242 .41746 .35397 .41729 .35272 .4216 Mtetra
.249 0 .284 r
.35272 .4216 .35397 .41729 .35554 .41694 .35438 .41948 Mtetra
0 0 0 r
.35438 .41948 .35554 .41694 .35712 .41635 .35607 .41679 Mtetra
.884 .991 .789 r
.35607 .41679 .35712 .41635 .3587 .41578 .35773 .4148 Mtetra
.757 .764 .858 r
.35773 .4148 .3587 .41578 .36028 .41524 .35933 .41376 Mtetra
.636 .645 .842 r
.35933 .41376 .36028 .41524 .36186 .41474 .36091 .41332 Mtetra
.596 .639 .864 r
.36091 .41332 .36186 .41474 .36344 .41423 .36248 .41307 Mtetra
.62 .692 .896 r
.36248 .41307 .36344 .41423 .36502 .41369 .36405 .41272 Mtetra
.659 .744 .913 r
.36405 .41272 .36502 .41369 .36661 .41311 .36563 .4122 Mtetra
.673 .761 .917 r
.36563 .4122 .36661 .41311 .36819 .41254 .36722 .41162 Mtetra
.732 .773 .886 r
.36722 .41162 .36819 .41254 .36979 .41174 .36882 .41076 Mtetra
.74 .762 .871 r
.36882 .41076 .36979 .41174 .37139 .41094 .37043 .40983 Mtetra
.666 .718 .887 r
.37043 .40983 .37139 .41094 .37296 .41066 .37202 .40928 Mtetra
.249 .466 .874 r
.37202 .40928 .37296 .41066 .37445 .41242 .37355 .40995 Mtetra
0 0 .416 r
.37355 .40995 .37445 .41242 .3674 .59957 .37497 .41307 Mtetra
0 0 .253 r
.37497 .41307 .3674 .59957 .36823 .6177 .36766 .60673 Mtetra
.058 .003 .472 r
.36766 .60673 .36823 .6177 .36981 .61962 .36895 .61481 Mtetra
.344 .283 .643 r
.36895 .61481 .36981 .61962 .37149 .61939 .37054 .61673 Mtetra
.414 .421 .758 r
.37054 .61673 .37149 .61939 .3732 .61861 .37217 .61749 Mtetra
.518 .677 .937 r
.37217 .61749 .3732 .61861 .3749 .61781 .37385 .61743 Mtetra
.639 .89 .985 r
.37385 .61743 .3749 .61781 .3766 .61723 .37555 .6168 Mtetra
.722 .894 .958 r
.37555 .6168 .3766 .61723 .37831 .61662 .37726 .61593 Mtetra
.711 .832 .94 r
.37726 .61593 .37831 .61662 .38001 .61604 .37897 .61514 Mtetra
.662 .776 .934 r
.37897 .61514 .38001 .61604 .38171 .6155 .38068 .61457 Mtetra
.644 .764 .936 r
.38068 .61457 .38171 .6155 .38341 .61498 .38238 .61407 Mtetra
.613 .76 .949 r
.38238 .61407 .38341 .61498 .38511 .61448 .38407 .61367 Mtetra
.576 .771 .972 r
.38407 .61367 .38511 .61448 .38681 .614 .38577 .61336 Mtetra
.547 .803 .993 r
.38577 .61336 .38681 .614 .38851 .61353 .38746 .61305 Mtetra
.492 .82 1 r
.38746 .61305 .38851 .61353 .39021 .61308 .38916 .61277 Mtetra
.446 .838 .982 r
.38916 .61277 .39021 .61308 .39191 .61263 .39086 .61246 Mtetra
.531 .896 .97 r
.39086 .61246 .39191 .61263 .39362 .61218 .39257 .61192 Mtetra
.787 .934 .928 r
.39257 .61192 .39362 .61218 .39533 .61167 .3943 .61072 Mtetra
.853 .784 .784 r
.3943 .61072 .39533 .61167 .39704 .61112 .39607 .60856 Mtetra
.789 .636 .691 r
.39607 .60856 .39704 .61112 .39875 .61057 .39787 .60567 Mtetra
.685 .515 .65 r
.39787 .60567 .39875 .61057 .40045 .61027 .39964 .6035 Mtetra
.553 .399 .626 r
.39964 .6035 .40045 .61027 .40215 .61017 .40133 .60352 Mtetra
.577 .417 .628 r
.40133 .60352 .40215 .61017 .40387 .60955 .40304 .60312 Mtetra
.73 .529 .619 r
.40304 .60312 .40387 .60955 .40565 .6071 .40489 .59863 Mtetra
.946 .68 .501 r
.40489 .59863 .40565 .6071 .40772 .59602 .4134 .40155 Mtetra
.556 .336 .537 r
.4134 .40155 .40772 .59602 .41607 .39897 .41517 .39635 Mtetra
.752 .609 .699 r
.41517 .39635 .41607 .39897 .41778 .39565 .41684 .39422 Mtetra
.662 .667 .844 r
.41684 .39422 .41778 .39565 .41941 .39477 .41846 .39364 Mtetra
.567 .681 .916 r
.41846 .39364 .41941 .39477 .42101 .39445 .42006 .39346 Mtetra
.553 .707 .942 r
.42006 .39346 .42101 .39445 .42262 .39421 .42167 .39329 Mtetra
.648 .755 .928 r
.42167 .39329 .42262 .39421 .42424 .39371 .42328 .3928 Mtetra
.662 .762 .924 r
.42328 .3928 .42424 .39371 .42585 .39323 .4249 .39226 Mtetra
.68 .755 .908 r
.4249 .39226 .42585 .39323 .42747 .39273 .42653 .39164 Mtetra
.694 .735 .882 r
.42653 .39164 .42747 .39273 .42909 .39219 .42815 .39094 Mtetra
.69 .705 .859 r
.42815 .39094 .42909 .39219 .43071 .39164 .42978 .39023 Mtetra
.688 .68 .837 r
.42978 .39023 .43071 .39164 .43234 .39107 .43141 .3895 Mtetra
.681 .656 .819 r
.43141 .3895 .43234 .39107 .43396 .39047 .43304 .38876 Mtetra
.647 .625 .814 r
.43304 .38876 .43396 .39047 .43559 .38989 .43466 .38822 Mtetra
.551 .585 .842 r
.43466 .38822 .43559 .38989 .43721 .38933 .43627 .38818 Mtetra
.038 .383 .846 r
.43627 .38818 .43721 .38933 .43884 .38883 .43786 .38908 Mtetra
.739 .251 .081 r
.43786 .38908 .43884 .38883 .44046 .38834 .43943 .39068 Mtetra
.658 .299 .353 r
.43943 .39068 .44046 .38834 .4421 .38767 .44101 .39214 Mtetra
.425 .133 .363 r
.44101 .39214 .4421 .38767 .44373 .38673 .44265 .39116 Mtetra
.458 .161 .373 r
.44265 .39116 .44373 .38673 .44536 .38623 .44429 .39049 Mtetra
.676 .363 .437 r
.44429 .39049 .44536 .38623 .44696 .38711 .44585 .393 Mtetra
.95 .675 .482 r
.44585 .393 .44696 .38711 .44838 .39544 .44274 .58978 Mtetra
.553 .33 .53 r
.44274 .58978 .44838 .39544 .44539 .59365 .44435 .59465 Mtetra
.711 .278 .221 r
.44435 .59465 .44539 .59365 .44705 .59662 .44604 .5963 Mtetra
.289 .753 .947 r
.44604 .5963 .44705 .59662 .44879 .59651 .44777 .59621 Mtetra
.56 .888 .988 r
.44777 .59621 .44879 .59651 .45054 .59577 .44951 .59567 Mtetra
.56 .921 .951 r
.44951 .59567 .45054 .59577 .45229 .59488 .45126 .59499 Mtetra
.337 .818 .827 r
.45126 .59499 .45229 .59488 .45403 .59441 .45301 .59448 Mtetra
.504 .909 .894 r
.45301 .59448 .45403 .59441 .45578 .59393 .45476 .59376 Mtetra
.761 .958 .935 r
.45476 .59376 .45578 .59393 .45752 .59339 .45652 .59261 Mtetra
.864 .82 .804 r
.45652 .59261 .45752 .59339 .45928 .59277 .4583 .59052 Mtetra
.801 .659 .706 r
.4583 .59052 .45928 .59277 .46103 .59213 .46009 .58779 Mtetra
.732 .555 .652 r
.46009 .58779 .46103 .59213 .46278 .59152 .46189 .58479 Mtetra
.608 .439 .628 r
.46189 .58479 .46278 .59152 .46453 .59101 .46365 .58373 Mtetra
.566 .404 .621 r
.46365 .58373 .46453 .59101 .46628 .59051 .46539 .58348 Mtetra
.544 .391 .623 r
.46539 .58348 .46628 .59051 .46804 .59012 .46713 .58366 Mtetra
.536 .391 .631 r
.46713 .58366 .46804 .59012 .46978 .59004 .46887 .58397 Mtetra
.585 .431 .638 r
.46887 .58397 .46978 .59004 .47154 .58949 .47063 .58346 Mtetra
.689 .503 .63 r
.47063 .58346 .47154 .58949 .47332 .58774 .47242 .58061 Mtetra
.954 .682 .483 r
.47242 .58061 .47332 .58774 .47518 .58015 .47712 .38223 Mtetra
.558 .338 .537 r
.47712 .38223 .47518 .58015 .47977 .37864 .47887 .37544 Mtetra
.762 .594 .67 r
.47887 .37544 .47977 .37864 .48147 .37419 .48056 .37263 Mtetra
.701 .668 .815 r
.48056 .37263 .48147 .37419 .48313 .37315 .48221 .37175 Mtetra
.636 .665 .86 r
.48221 .37175 .48313 .37315 .48479 .37274 .48387 .3713 Mtetra
.602 .644 .864 r
.48387 .3713 .48479 .37274 .48644 .37257 .48552 .37101 Mtetra
.652 .648 .833 r
.48552 .37101 .48644 .37257 .48809 .37203 .48717 .37045 Mtetra
.652 .647 .832 r
.48717 .37045 .48809 .37203 .48975 .37149 .48883 .3699 Mtetra
.651 .645 .831 r
.48883 .3699 .48975 .37149 .49141 .37095 .49049 .36935 Mtetra
.652 .644 .829 r
.49049 .36935 .49141 .37095 .49307 .37039 .49215 .36879 Mtetra
.652 .643 .828 r
.49215 .36879 .49307 .37039 .49473 .36983 .49381 .36823 Mtetra
.49381 .36823 .49473 .36983 .49639 .36927 .49547 .36766 Mtetra
.49547 .36766 .49639 .36927 .49805 .36871 .49713 .3671 Mtetra
.49713 .3671 .49805 .36871 .49971 .36815 .4988 .36653 Mtetra
.652 .642 .827 r
.4988 .36653 .49971 .36815 .50138 .36758 .50046 .36597 Mtetra
.50046 .36597 .50138 .36758 .50304 .36702 .50213 .3654 Mtetra
.50213 .3654 .50304 .36702 .50471 .36645 .50379 .36484 Mtetra
.653 .643 .827 r
.50379 .36484 .50471 .36645 .50638 .36589 .50546 .36427 Mtetra
.653 .643 .828 r
.50546 .36427 .50638 .36589 .50804 .36532 .50713 .3637 Mtetra
.50713 .3637 .50804 .36532 .50971 .36475 .5088 .36313 Mtetra
.654 .644 .828 r
.5088 .36313 .50971 .36475 .51138 .36417 .51047 .36256 Mtetra
.655 .645 .828 r
.51047 .36256 .51138 .36417 .51305 .36358 .51214 .36197 Mtetra
.655 .646 .829 r
.51214 .36197 .51305 .36358 .51473 .36299 .51381 .36139 Mtetra
.657 .647 .829 r
.51381 .36139 .51473 .36299 .5164 .36239 .51549 .3608 Mtetra
.697 .665 .815 r
.51549 .3608 .5164 .36239 .51808 .3614 .51716 .35994 Mtetra
.664 .67 .846 r
.51716 .35994 .51808 .3614 .51975 .36077 .51884 .35933 Mtetra
.558 .626 .875 r
.51884 .35933 .51975 .36077 .52143 .36089 .52052 .35922 Mtetra
0 .009 .581 r
.52052 .35922 .52143 .36089 .5231 .36548 .52219 .36143 Mtetra
.72 .46 0 r
.52219 .36143 .5231 .36548 .52478 .5674 .52387 .36921 Mtetra
0 0 .355 r
.52387 .36921 .52478 .5674 .52657 .57238 .5256 .56573 Mtetra
.514 .374 .629 r
.5256 .56573 .52657 .57238 .52836 .57252 .52739 .56641 Mtetra
.597 .439 .637 r
.52739 .56641 .52836 .57252 .53016 .5719 .52918 .56566 Mtetra
.633 .462 .634 r
.52918 .56566 .53016 .5719 .53195 .57087 .53097 .56416 Mtetra
.612 .442 .628 r
.53097 .56416 .53195 .57087 .53375 .57029 .53277 .56301 Mtetra
.588 .42 .622 r
.53277 .56301 .53375 .57029 .53554 .56973 .53456 .5623 Mtetra
.544 .388 .62 r
.53456 .5623 .53554 .56973 .53734 .56918 .53636 .5625 Mtetra
.4 .294 .618 r
.53636 .5625 .53734 .56918 .53914 .56875 .53817 .56475 Mtetra
.366 .328 .683 r
.53817 .56475 .53914 .56875 .54095 .56832 .53998 .56634 Mtetra
.306 .426 .82 r
.53998 .56634 .54095 .56832 .54275 .56788 .54179 .56727 Mtetra
.406 .758 .994 r
.54179 .56727 .54275 .56788 .54455 .56732 .5436 .5672 Mtetra
.374 .831 .921 r
.5436 .5672 .54455 .56732 .54636 .56674 .5454 .56681 Mtetra
.38 .844 .849 r
.5454 .56681 .54636 .56674 .54816 .56613 .54721 .56623 Mtetra
.192 .723 .766 r
.54721 .56623 .54816 .56613 .54998 .56604 .54902 .56589 Mtetra
.519 .9 .955 r
.54902 .56589 .54998 .56604 .55178 .56563 .55083 .56528 Mtetra
.756 .935 .944 r
.55083 .56528 .55178 .56563 .55359 .56448 .55264 .56418 Mtetra
.95 .871 .725 r
.55264 .56418 .55359 .56448 .55536 .55911 .55442 .56085 Mtetra
.985 .851 .472 r
.55442 .56085 .55536 .55911 .55523 .3557 .55617 .55311 Mtetra
0 0 .353 r
.55617 .55311 .55523 .3557 .55687 .34922 .55603 .35379 Mtetra
.33 .056 .338 r
.55603 .35379 .55687 .34922 .55856 .34779 .55772 .35187 Mtetra
.487 .18 .37 r
.55772 .35187 .55856 .34779 .56026 .34727 .55943 .35155 Mtetra
.501 .196 .381 r
.55943 .35155 .56026 .34727 .56197 .34713 .56113 .35135 Mtetra
.152 0 .262 r
.56113 .35135 .56197 .34713 .56367 .34656 .56281 .34837 Mtetra
0 0 0 r
.56281 .34837 .56367 .34656 .56537 .34592 .56449 .34583 Mtetra
.889 .963 .835 r
.56449 .34583 .56537 .34592 .56708 .34529 .56618 .34396 Mtetra
.695 .704 .854 r
.56618 .34396 .56708 .34529 .56878 .34471 .56788 .34318 Mtetra
.627 .647 .851 r
.56788 .34318 .56878 .34471 .57049 .34414 .56959 .34276 Mtetra
.603 .659 .878 r
.56959 .34276 .57049 .34414 .5722 .34358 .5713 .34246 Mtetra
.677 .735 .894 r
.5713 .34246 .5722 .34358 .57391 .34303 .57301 .34181 Mtetra
.694 .723 .873 r
.57301 .34181 .57391 .34303 .57562 .34248 .57472 .34107 Mtetra
.687 .689 .847 r
.57472 .34107 .57562 .34248 .57733 .34193 .57643 .34032 Mtetra
.703 .67 .814 r
.57643 .34032 .57733 .34193 .57903 .34095 .57814 .33941 Mtetra
.678 .668 .833 r
.57814 .33941 .57903 .34095 .58074 .34018 .57985 .33869 Mtetra
.597 .639 .863 r
.57985 .33869 .58074 .34018 .58246 .34003 .58157 .33841 Mtetra
.043 .292 .783 r
.58157 .33841 .58246 .34003 .58425 .34319 .58332 .33982 Mtetra
0 0 .445 r
.58332 .33982 .58425 .34319 .58987 .54511 .58513 .34445 Mtetra
0 0 .379 r
.58513 .34445 .58987 .54511 .59185 .55213 .59078 .54447 Mtetra
.269 .193 .583 r
.59078 .54447 .59185 .55213 .59372 .55299 .59271 .5488 Mtetra
.395 .342 .681 r
.59271 .5488 .59372 .55299 .59556 .55259 .59459 .55029 Mtetra
.444 .476 .798 r
.59459 .55029 .59556 .55259 .59739 .55172 .59645 .55086 Mtetra
.396 .688 .978 r
.59645 .55086 .59739 .55172 .59924 .55143 .59831 .55096 Mtetra
.523 .846 .998 r
.59831 .55096 .59924 .55143 .60108 .551 .60015 .55056 Mtetra
.736 .917 .954 r
.60015 .55056 .60108 .551 .60291 .54989 .60199 .54954 Mtetra
.939 .891 .756 r
.60199 .54954 .60291 .54989 .60466 .54544 .60378 .54667 Mtetra
.984 .868 .501 r
.60378 .54667 .60466 .54544 .60159 .34233 .60548 .54022 Mtetra
0 0 .371 r
.60548 .54022 .60159 .34233 .60314 .3341 .60241 .33941 Mtetra
.243 .001 .334 r
.60241 .33941 .60314 .3341 .60483 .33221 .60408 .33629 Mtetra
.477 .171 .367 r
.60408 .33629 .60483 .33221 .60656 .3316 .60582 .33586 Mtetra
.505 .199 .381 r
.60582 .33586 .60656 .3316 .6083 .33142 .60756 .33571 Mtetra
.227 0 .297 r
.60756 .33571 .6083 .33142 .61003 .33093 .60924 .33309 Mtetra
0 0 0 r
.60924 .33309 .61003 .33093 .61176 .33027 .61092 .33041 Mtetra
.879 .992 .795 r
.61092 .33041 .61176 .33027 .61349 .32962 .61262 .32842 Mtetra
.73 .741 .86 r
.61262 .32842 .61349 .32962 .61523 .32899 .61434 .32746 Mtetra
.636 .652 .849 r
.61434 .32746 .61523 .32899 .61696 .32838 .61608 .32698 Mtetra
.609 .66 .875 r
.61608 .32698 .61696 .32838 .6187 .32779 .61782 .32664 Mtetra
.713 .744 .876 r
.61782 .32664 .6187 .32779 .62042 .3269 .61955 .32579 Mtetra
.726 .758 .878 r
.61955 .32579 .62042 .3269 .62216 .32612 .62128 .32488 Mtetra
.647 .705 .888 r
.62128 .32488 .62216 .32612 .62391 .3259 .62302 .32436 Mtetra
.208 .413 .843 r
.62302 .32436 .62391 .3259 .62574 .32832 .62481 .32535 Mtetra
0 0 .543 r
.62481 .32535 .62574 .32832 .63402 .52837 .6267 .32905 Mtetra
0 0 .393 r
.6267 .32905 .63402 .52837 .63622 .53814 .63503 .52897 Mtetra
.226 .152 .559 r
.63503 .52897 .63622 .53814 .63815 .53947 .63711 .53489 Mtetra
.388 .328 .668 r
.63711 .53489 .63815 .53947 .64002 .53914 .63905 .53662 Mtetra
.442 .458 .78 r
.63905 .53662 .64002 .53914 .64188 .53828 .64096 .53727 Mtetra
.455 .683 .963 r
.64096 .53727 .64188 .53828 .64376 .53792 .64285 .53731 Mtetra
.584 .84 .993 r
.64285 .53731 .64376 .53792 .64564 .53763 .64473 .53684 Mtetra
.756 .845 .918 r
.64473 .53684 .64564 .53763 .6475 .5367 .64658 .53576 Mtetra
.887 .818 .775 r
.64658 .53576 .6475 .5367 .64926 .53303 .64839 .53325 Mtetra
.994 .864 .592 r
.64839 .53325 .64926 .53303 .6436 .33245 .65008 .52784 Mtetra
0 0 .383 r
.65008 .52784 .6436 .33245 .64493 .32052 .64435 .32687 Mtetra
0 0 .265 r
.64435 .32687 .64493 .32052 .64661 .31811 .64588 .32036 Mtetra
0 0 .016 r
.64588 .32036 .64661 .31811 .64836 .31735 .64756 .31771 Mtetra
.734 .977 .739 r
.64756 .31771 .64836 .31735 .65013 .31707 .64927 .31603 Mtetra
.73 .773 .888 r
.64927 .31603 .65013 .31707 .65189 .31671 .65102 .3151 Mtetra
.63 .642 .843 r
.65102 .3151 .65189 .31671 .65366 .31618 .65278 .31465 Mtetra
.594 .635 .862 r
.65278 .31465 .65366 .31618 .65542 .31565 .65455 .31438 Mtetra
.623 .691 .893 r
.65455 .31438 .65542 .31565 .65718 .31506 .65632 .31396 Mtetra
.664 .743 .909 r
.65632 .31396 .65718 .31506 .65894 .31441 .65808 .31337 Mtetra
.678 .759 .912 r
.65808 .31337 .65894 .31441 .6607 .31375 .65984 .31271 Mtetra
.752 .78 .876 r
.65984 .31271 .6607 .31375 .66245 .31284 .66159 .31164 Mtetra
.748 .751 .855 r
.66159 .31164 .66245 .31284 .6642 .31196 .66333 .31055 Mtetra
.644 .677 .867 r
.66333 .31055 .6642 .31196 .66597 .31163 .6651 .31003 Mtetra
0 .198 .727 r
.6651 .31003 .66597 .31163 .66786 .31356 .66698 .31184 Mtetra
.975 .678 .386 r
.66698 .31184 .66786 .31356 .67881 .51191 .67787 .5099 Mtetra
.95 .611 .21 r
.67787 .5099 .67881 .51191 .68131 .5245 .68043 .52391 Mtetra
.577 .035 0 r
.68043 .52391 .68131 .5245 .68333 .52649 .68244 .52578 Mtetra
.531 .797 .994 r
.68244 .52578 .68333 .52649 .68525 .52639 .68435 .52547 Mtetra
.775 .826 .892 r
.68435 .52547 .68525 .52639 .68712 .52525 .68622 .52424 Mtetra
.883 .815 .777 r
.68622 .52424 .68712 .52525 .68888 .52186 .68803 .52178 Mtetra
.989 .862 .618 r
.68803 .52178 .68888 .52186 .68978 .50108 .68971 .51681 Mtetra
.983 .698 .354 r
.68971 .51681 .68978 .50108 .68202 .30843 .68161 .316 Mtetra
0 0 .293 r
.68161 .316 .68202 .30843 .68369 .30554 .68302 .30802 Mtetra
0 0 .073 r
.68302 .30802 .68369 .30554 .68545 .30466 .68469 .30519 Mtetra
.659 .927 .638 r
.68469 .30519 .68545 .30466 .68724 .30429 .68641 .30341 Mtetra
.757 .819 .901 r
.68641 .30341 .68724 .30429 .68903 .3039 .68817 .30236 Mtetra
.646 .66 .85 r
.68817 .30236 .68903 .3039 .69081 .30329 .68995 .30182 Mtetra
.612 .654 .867 r
.68995 .30182 .69081 .30329 .6926 .30271 .69175 .30145 Mtetra
.693 .726 .875 r
.69175 .30145 .6926 .30271 .69437 .3019 .69352 .30068 Mtetra
.746 .751 .857 r
.69352 .30068 .69437 .3019 .69614 .30101 .69528 .2996 Mtetra
.656 .685 .866 r
.69528 .2996 .69614 .30101 .69793 .3006 .69707 .29901 Mtetra
.116 .345 .812 r
.69707 .29901 .69793 .3006 .69983 .30205 .69896 .30033 Mtetra
.937 .588 .169 r
.69896 .30033 .69983 .30205 .7024 .3151 .70144 .31196 Mtetra
.977 .677 .365 r
.70144 .31196 .7024 .3151 .71557 .51348 .71471 .51285 Mtetra
.635 .111 0 r
.71471 .51285 .71557 .51348 .71765 .51576 .71679 .51511 Mtetra
.557 .826 .996 r
.71679 .51511 .71765 .51576 .71959 .5155 .71872 .5147 Mtetra
.743 .849 .929 r
.71872 .5147 .71959 .5155 .72149 .51464 .72061 .51367 Mtetra
.663 .787 .94 r
.72061 .51367 .72149 .51464 .72341 .51399 .72253 .51301 Mtetra
.463 .698 .969 r
.72253 .51301 .72341 .51399 .72536 .51377 .72449 .51301 Mtetra
.623 .823 .978 r
.72449 .51301 .72536 .51377 .72727 .51301 .72642 .51246 Mtetra
.92 .894 .786 r
.72642 .51246 .72727 .51301 .72907 .51035 .72823 .50992 Mtetra
.99 .758 .491 r
.72823 .50992 .72907 .51035 .73029 .49838 .72947 .49824 Mtetra
.978 .683 .379 r
.72947 .49824 .73029 .49838 .71964 .29639 .71878 .29481 Mtetra
.883 .738 .696 r
.71878 .29481 .71964 .29639 .72127 .29304 .72041 .29147 Mtetra
.675 .671 .838 r
.72041 .29147 .72127 .29304 .72305 .29219 .7222 .29074 Mtetra
.559 .634 .882 r
.7222 .29074 .72305 .29219 .72488 .2919 .72404 .29061 Mtetra
.549 .657 .907 r
.72404 .29061 .72488 .2919 .7267 .29164 .72587 .29049 Mtetra
.66 .735 .905 r
.72587 .29049 .7267 .29164 .72851 .29101 .72768 .28989 Mtetra
.67 .746 .907 r
.72768 .28989 .72851 .29101 .73031 .29036 .72949 .28925 Mtetra
.716 .764 .89 r
.72949 .28925 .73031 .29036 .7321 .28949 .73128 .28837 Mtetra
.75 .774 .873 r
.73128 .28837 .7321 .28949 .73388 .28841 .73305 .28729 Mtetra
.663 .744 .911 r
.73305 .28729 .73388 .28841 .73569 .2878 .73486 .28668 Mtetra
.122 .442 .878 r
.73486 .28668 .73569 .2878 .7376 .28871 .73678 .28759 Mtetra
.906 .522 .092 r
.73678 .28759 .7376 .28871 .73999 .29647 .73917 .2954 Mtetra
.975 .671 .352 r
.73917 .2954 .73999 .29647 .75604 .5004 .75517 .49933 Mtetra
.608 .144 0 r
.75517 .49933 .75604 .5004 .75823 .50337 .75736 .50229 Mtetra
.548 .72 .953 r
.75736 .50229 .75823 .50337 .7602 .50316 .75934 .50207 Mtetra
.708 .783 .91 r
.75934 .50207 .7602 .50316 .76213 .50229 .76127 .5012 Mtetra
.691 .774 .915 r
.76127 .5012 .76213 .50229 .76407 .50151 .7632 .50041 Mtetra
.51 .694 .952 r
.7632 .50041 .76407 .50151 .76606 .50143 .76519 .50032 Mtetra
.651 .758 .928 r
.76519 .50032 .76606 .50143 .76801 .50083 .76714 .49972 Mtetra
.863 .812 .798 r
.76714 .49972 .76801 .50083 .76984 .49865 .76898 .49753 Mtetra
.978 .752 .527 r
.76898 .49753 .76984 .49865 .77114 .48921 .77027 .48794 Mtetra
.977 .678 .362 r
.77027 .48794 .77114 .48921 .75776 .28408 .75694 .28288 Mtetra
.931 .782 .674 r
.75694 .28288 .75776 .28408 .75934 .28014 .75852 .27897 Mtetra
.728 .759 .878 r
.75852 .27897 .75934 .28014 .76113 .27918 .76032 .27801 Mtetra
.604 .711 .92 r
.76032 .27801 .76113 .27918 .76298 .27881 .76217 .27765 Mtetra
.603 .711 .92 r
.76217 .27765 .76298 .27881 .76483 .27845 .76402 .27729 Mtetra
.741 .766 .873 r
.76402 .27729 .76483 .27845 .76662 .2774 .76582 .27625 Mtetra
.659 .737 .907 r
.76582 .27625 .76662 .2774 .76846 .2768 .76765 .27565 Mtetra
.241 .512 .908 r
.76765 .27565 .76846 .2768 .77039 .27749 .76958 .27634 Mtetra
.881 .489 .032 r
.76958 .27634 .77039 .27749 .77285 .28468 .77204 .28353 Mtetra
.975 .667 .334 r
.77204 .28353 .77285 .28468 .79122 .4897 .79037 .48862 Mtetra
.659 .204 0 r
.79037 .48862 .79122 .4897 .79352 .49316 .79267 .49209 Mtetra
.379 .633 .954 r
.79267 .49209 .79352 .49316 .79556 .4934 .79471 .49236 Mtetra
.699 .792 .922 r
.79471 .49236 .79556 .4934 .79751 .49256 .79667 .49152 Mtetra
.886 .828 .784 r
.79667 .49152 .79751 .49256 .79934 .49021 .79849 .48909 Mtetra
.981 .754 .522 r
.79849 .48909 .79934 .49021 .80069 .48209 .79973 .47962 Mtetra
.977 .674 .351 r
.79973 .47962 .80069 .48209 .78533 .2754 .78445 .27332 Mtetra
.881 .704 .659 r
.78445 .27332 .78533 .2754 .78685 .27094 .786 .26922 Mtetra
.69 .663 .818 r
.786 .26922 .78685 .27094 .78865 .26987 .78783 .26834 Mtetra
.584 .638 .87 r
.78783 .26834 .78865 .26987 .79051 .26942 .7897 .2681 Mtetra
.532 .646 .907 r
.7897 .2681 .79051 .26942 .79239 .2692 .7916 .26804 Mtetra
.686 .749 .899 r
.7916 .26804 .79239 .2692 .79424 .26857 .79344 .26731 Mtetra
.664 .721 .891 r
.79344 .26731 .79424 .26857 .79609 .26794 .79528 .26667 Mtetra
.604 .692 .905 r
.79528 .26667 .79609 .26794 .79793 .26725 .79716 .26632 Mtetra
.36 .639 .961 r
.79716 .26632 .79793 .26725 .79975 .26623 .79909 .26658 Mtetra
.559 0 0 r
.79909 .26658 .79975 .26623 .8016 .26562 .80109 .2676 Mtetra
.763 .363 .293 r
.80109 .2676 .8016 .26562 .80355 .26602 .80329 .27079 Mtetra
.972 .659 .337 r
.80329 .27079 .80355 .26602 .80598 .27182 .82354 .47317 Mtetra
.553 .329 .529 r
.82354 .47317 .80598 .27182 .82676 .47808 .82613 .47912 Mtetra
.706 .233 .125 r
.82613 .47912 .82676 .47808 .82919 .48219 .82836 .48109 Mtetra
.387 .632 .951 r
.82836 .48109 .82919 .48219 .83128 .48262 .83044 .48136 Mtetra
.657 .735 .908 r
.83044 .48136 .83128 .48262 .83327 .48194 .83243 .48073 Mtetra
.832 .8 .821 r
.83243 .48073 .83327 .48194 .83514 .47993 .83431 .47885 Mtetra
.979 .778 .562 r
.83431 .47885 .83514 .47993 .83652 .47284 .83571 .47181 Mtetra
.976 .671 .329 r
.83571 .47181 .83652 .47284 .81878 .26485 .818 .26373 Mtetra
.964 .786 .613 r
.818 .26373 .81878 .26485 .82021 .25971 .81943 .25856 Mtetra
.755 .779 .873 r
.81943 .25856 .82021 .25971 .82203 .25858 .82125 .25743 Mtetra
.62 .725 .922 r
.82125 .25743 .82203 .25858 .82391 .25814 .82313 .25699 Mtetra
.545 .689 .933 r
.82313 .25699 .82391 .25814 .82583 .25799 .82505 .25683 Mtetra
.747 .774 .875 r
.82505 .25683 .82583 .25799 .82766 .25695 .82687 .25575 Mtetra
.672 .739 .9 r
.82687 .25575 .82766 .25695 .82952 .25629 .82874 .25507 Mtetra
.434 .616 .927 r
.82874 .25507 .82952 .25629 .83148 .25648 .8307 .2553 Mtetra
.825 .422 0 r
.8307 .2553 .83148 .25648 .83396 .26195 .83327 .26168 Mtetra
.971 .657 .302 r
.83327 .26168 .83396 .26195 .85677 .46889 .85606 .46883 Mtetra
.823 .345 0 r
.85606 .46883 .85677 .46889 .85929 .47331 .85854 .47284 Mtetra
.145 .632 .918 r
.85854 .47284 .85929 .47331 .86142 .47382 .86064 .47311 Mtetra
.677 .868 .971 r
.86064 .47311 .86142 .47382 .86344 .47321 .86264 .47229 Mtetra
.864 .862 .836 r
.86264 .47229 .86344 .47321 .86534 .47144 .86452 .47032 Mtetra
.977 .785 .579 r
.86452 .47032 .86534 .47144 .86677 .46517 .86595 .46398 Mtetra
.974 .667 .313 r
.86595 .46398 .86677 .46517 .84699 .25622 .84622 .25504 Mtetra
.972 .777 .582 r
.84622 .25504 .84699 .25622 .84831 .25024 .84755 .24911 Mtetra
.787 .766 .834 r
.24082 .453 .24184 .4539 .24342 .4525 .24239 .45173 Mtetra
.649 .778 .942 r
.24239 .45173 .24342 .4525 .24494 .452 .2439 .45126 Mtetra
.366 .682 .978 r
.2439 .45126 .24494 .452 .24638 .45229 .24537 .45137 Mtetra
.345 .624 .955 r
.24537 .45137 .24638 .45229 .24769 .45416 .24682 .4516 Mtetra
.355 .375 .744 r
.24682 .4516 .24769 .45416 .24864 .46041 .24821 .45251 Mtetra
.385 .257 .58 r
.24821 .45251 .24864 .46041 .23399 .65308 .24948 .455 Mtetra
0 0 .203 r
.24948 .455 .23399 .65308 .2353 .65622 .23484 .64786 Mtetra
0 0 .402 r
.23484 .64786 .2353 .65622 .23676 .6575 .23582 .65485 Mtetra
0 .04 .598 r
.23582 .65485 .23676 .6575 .23829 .65799 .23721 .65712 Mtetra
.443 .696 .973 r
.23721 .65712 .23829 .65799 .23988 .65775 .23878 .65715 Mtetra
.653 .83 .968 r
.23878 .65715 .23988 .65775 .2415 .65723 .24039 .6566 Mtetra
.729 .834 .93 r
.24039 .6566 .2415 .65723 .24313 .65655 .24204 .65576 Mtetra
.662 .789 .942 r
.24204 .65576 .24313 .65655 .24474 .65606 .24366 .65521 Mtetra
.657 .775 .936 r
.24366 .65521 .24474 .65606 .24636 .65559 .24528 .65468 Mtetra
.657 .763 .928 r
.24528 .65468 .24636 .65559 .24797 .65512 .2469 .65416 Mtetra
.649 .749 .923 r
.2469 .65416 .24797 .65512 .24959 .65466 .24852 .65367 Mtetra
.646 .741 .918 r
.24852 .65367 .24959 .65466 .25121 .65421 .25014 .65319 Mtetra
.645 .736 .916 r
.25014 .65319 .25121 .65421 .25282 .65375 .25176 .65272 Mtetra
.6 .72 .929 r
.25176 .65272 .25282 .65375 .25442 .65358 .25336 .65241 Mtetra
.631 .702 .897 r
.25336 .65241 .25442 .65358 .25603 .65321 .25498 .652 Mtetra
.682 .71 .87 r
.25498 .652 .25603 .65321 .25768 .65236 .25662 .65133 Mtetra
.809 .759 .806 r
.25662 .65133 .25768 .65236 .2595 .64934 .25833 .64968 Mtetra
.922 .952 .793 r
.25833 .64968 .2595 .64934 .26163 .64223 .2601 .64733 Mtetra
.152 0 .249 r
.2601 .64733 .26163 .64223 .2779 .44774 .26191 .64434 Mtetra
.541 .32 .528 r
.26191 .64434 .2779 .44774 .27959 .44525 .26361 .64285 Mtetra
.543 .322 .529 r
.26361 .64285 .27959 .44525 .28112 .44476 .26523 .64244 Mtetra
.544 .322 .529 r
.26523 .64244 .28112 .44476 .2826 .44505 .26682 .64248 Mtetra
.543 .322 .529 r
.26682 .64248 .2826 .44505 .28412 .44473 .26844 .64213 Mtetra
.26844 .64213 .28412 .44473 .28566 .44428 .27006 .64169 Mtetra
.27006 .64169 .28566 .44428 .28719 .44384 .27169 .64124 Mtetra
.544 .323 .529 r
.27169 .64124 .28719 .44384 .28869 .44387 .27326 .64153 Mtetra
.544 .322 .529 r
.27326 .64153 .28869 .44387 .29021 .44367 .27487 .64137 Mtetra
.541 .32 .529 r
.27487 .64137 .29021 .44367 .29179 .44261 .27657 .64004 Mtetra
.501 .287 .52 r
.27657 .64004 .29179 .44261 .29351 .43961 .27964 .61929 Mtetra
0 0 .202 r
.27964 .61929 .29351 .43961 .2952 .43704 .29407 .43803 Mtetra
.973 .926 .663 r
.29407 .43803 .2952 .43704 .29684 .43514 .29584 .43428 Mtetra
.794 .78 .84 r
.29584 .43428 .29684 .43514 .29841 .43423 .29744 .43298 Mtetra
.662 .689 .865 r
.29744 .43298 .29841 .43423 .29996 .43371 .29898 .43245 Mtetra
.595 .661 .884 r
.29898 .43245 .29996 .43371 .30149 .43335 .30051 .43221 Mtetra
.642 .699 .887 r
.30051 .43221 .30149 .43335 .30304 .43288 .30205 .43177 Mtetra
.656 .711 .888 r
.30205 .43177 .30304 .43288 .30458 .43236 .3036 .43127 Mtetra
.649 .712 .893 r
.3036 .43127 .30458 .43236 .30613 .43188 .30514 .4308 Mtetra
.628 .709 .904 r
.30514 .4308 .30613 .43188 .30767 .43147 .30668 .43042 Mtetra
.618 .71 .911 r
.30668 .43042 .30767 .43147 .30921 .4311 .30822 .43007 Mtetra
.619 .715 .914 r
.30822 .43007 .30921 .4311 .31075 .43073 .30976 .42972 Mtetra
.641 .727 .911 r
.30976 .42972 .31075 .43073 .3123 .43027 .31131 .42928 Mtetra
.658 .736 .907 r
.31131 .42928 .3123 .43027 .31385 .42975 .31286 .42878 Mtetra
.672 .744 .905 r
.31286 .42878 .31385 .42975 .31541 .42917 .31442 .42822 Mtetra
.692 .753 .898 r
.31442 .42822 .31541 .42917 .31698 .42849 .31598 .42757 Mtetra
.701 .762 .899 r
.31598 .42757 .31698 .42849 .31854 .42776 .31755 .42688 Mtetra
.7 .768 .905 r
.31755 .42688 .31854 .42776 .32011 .42706 .31912 .42619 Mtetra
.709 .775 .904 r
.31912 .42619 .32011 .42706 .32169 .42622 .32069 .42547 Mtetra
.689 .798 .932 r
.32069 .42547 .32169 .42622 .32326 .42552 .32225 .42484 Mtetra
.617 .798 .968 r
.32225 .42484 .32326 .42552 .3248 .42524 .32381 .42443 Mtetra
.223 .59 .947 r
.32381 .42443 .3248 .42524 .32625 .42655 .32531 .42478 Mtetra
.155 .339 .796 r
.32531 .42478 .32625 .42655 .32751 .4311 .32678 .42585 Mtetra
.387 .294 .627 r
.32678 .42585 .32751 .4311 .31731 .62593 .32821 .42757 Mtetra
.544 .327 .535 r
.32821 .42757 .31731 .62593 .31878 .62859 .32973 .42772 Mtetra
.547 .329 .536 r
.32973 .42772 .31878 .62859 .32044 .62802 .33132 .42677 Mtetra
.545 .328 .535 r
.33132 .42677 .32044 .62802 .32213 .62713 .33288 .42651 Mtetra
.523 .31 .531 r
.33288 .42651 .32213 .62713 .32368 .62847 .33382 .43657 Mtetra
0 0 .252 r
.33382 .43657 .32368 .62847 .32521 .6302 .32432 .62654 Mtetra
0 0 .522 r
.32432 .62654 .32521 .6302 .32679 .63126 .32576 .62993 Mtetra
.163 .441 .874 r
.32576 .62993 .32679 .63126 .32841 .63159 .32736 .6307 Mtetra
.597 .756 .954 r
.32736 .6307 .32841 .63159 .33007 .63131 .32902 .63036 Mtetra
.728 .773 .889 r
.32902 .63036 .33007 .63131 .33175 .63047 .33071 .62948 Mtetra
.804 .773 .824 r
.33071 .62948 .33175 .63047 .33353 .62807 .33244 .62794 Mtetra
.906 .903 .81 r
.33244 .62794 .33353 .62807 .33547 .62263 .3342 .62572 Mtetra
0 0 .007 r
.3342 .62572 .33547 .62263 .34779 .42668 .336 .62285 Mtetra
.541 .32 .528 r
.336 .62285 .34779 .42668 .34959 .42216 .33773 .62139 Mtetra
.544 .322 .529 r
.33773 .62139 .34959 .42216 .35116 .42167 .33938 .62133 Mtetra
.543 .321 .529 r
.33938 .62133 .35116 .42167 .35272 .4216 .34106 .62065 Mtetra
.53 .311 .526 r
.34106 .62065 .35272 .4216 .35438 .41948 .3431 .61317 Mtetra
0 0 .247 r
.3431 .61317 .35438 .41948 .35607 .41679 .35495 .41861 Mtetra
.923 .914 .526 r
.35495 .41861 .35607 .41679 .35773 .4148 .35673 .41422 Mtetra
.849 .838 .834 r
.35673 .41422 .35773 .4148 .35933 .41376 .35837 .41257 Mtetra
.65 .699 .882 r
.35837 .41257 .35933 .41376 .36091 .41332 .35995 .41209 Mtetra
.558 .655 .9 r
.35995 .41209 .36091 .41332 .36248 .41307 .36151 .41196 Mtetra
.59 .692 .913 r
.36151 .41196 .36248 .41307 .36405 .41272 .36308 .41171 Mtetra
.651 .734 .91 r
.36308 .41171 .36405 .41272 .36563 .4122 .36466 .41122 Mtetra
.665 .745 .91 r
.36466 .41122 .36563 .4122 .36722 .41162 .36625 .41068 Mtetra
.71 .763 .894 r
.36625 .41068 .36722 .41162 .36882 .41076 .36784 .40994 Mtetra
.728 .791 .902 r
.36784 .40994 .36882 .41076 .37043 .40983 .36944 .40911 Mtetra
.685 .808 .941 r
.36944 .40911 .37043 .40983 .37202 .40928 .37104 .40848 Mtetra
.514 .737 .975 r
.37104 .40848 .37202 .40928 .37355 .40995 .37261 .40835 Mtetra
.353 .487 .855 r
.37261 .40835 .37355 .40995 .37497 .41307 .37415 .40891 Mtetra
.353 .299 .657 r
.37415 .40891 .37497 .41307 .36766 .60673 .37564 .41052 Mtetra
.528 .314 .533 r
.37564 .41052 .36766 .60673 .36895 .61481 .37686 .41816 Mtetra
0 0 .28 r
.37686 .41816 .36895 .61481 .37054 .61673 .36966 .61235 Mtetra
0 .045 .559 r
.36966 .61235 .37054 .61673 .37217 .61749 .37117 .61589 Mtetra
.243 .44 .855 r
.37117 .61589 .37217 .61749 .37385 .61743 .37281 .6167 Mtetra
.649 .809 .96 r
.37281 .6167 .37385 .61743 .37555 .6168 .3745 .61615 Mtetra
.75 .846 .923 r
.3745 .61615 .37555 .6168 .37726 .61593 .37622 .61518 Mtetra
.732 .821 .92 r
.37622 .61518 .37726 .61593 .37897 .61514 .37794 .61429 Mtetra
.661 .786 .941 r
.37794 .61429 .37897 .61514 .38068 .61457 .37964 .61372 Mtetra
.642 .78 .948 r
.37964 .61372 .38068 .61457 .38238 .61407 .38134 .61322 Mtetra
.607 .77 .958 r
.38134 .61322 .38238 .61407 .38407 .61367 .38304 .61282 Mtetra
.574 .761 .967 r
.38304 .61282 .38407 .61367 .38577 .61336 .38473 .61253 Mtetra
.571 .764 .97 r
.38473 .61253 .38577 .61336 .38746 .61305 .38643 .61224 Mtetra
.529 .752 .978 r
.38643 .61224 .38746 .61305 .38916 .61277 .38812 .61204 Mtetra
.52 .769 .988 r
.38812 .61204 .38916 .61277 .39086 .61246 .38982 .61183 Mtetra
.66 .84 .969 r
.38982 .61183 .39086 .61246 .39257 .61192 .39153 .61122 Mtetra
.855 .829 .821 r
.39153 .61122 .39257 .61192 .3943 .61072 .39329 .60934 Mtetra
.896 .727 .664 r
.39329 .60934 .3943 .61072 .39607 .60856 .39517 .60451 Mtetra
.95 .686 .499 r
.39517 .60451 .39607 .60856 .39787 .60567 .40417 .40876 Mtetra
.559 .339 .538 r
.40417 .40876 .39787 .60567 .39964 .6035 .40603 .40156 Mtetra
.546 .328 .535 r
.40603 .40156 .39964 .6035 .40133 .60352 .40765 .40091 Mtetra
.545 .327 .535 r
.40765 .40091 .40133 .60352 .40304 .60312 .40924 .40086 Mtetra
.548 .33 .536 r
.40924 .40086 .40304 .60312 .40489 .59863 .41089 .39947 Mtetra
.55 .332 .536 r
.41089 .39947 .40489 .59863 .4134 .40155 .41258 .39674 Mtetra
.682 .51 .646 r
.41258 .39674 .4134 .40155 .41517 .39635 .41424 .39466 Mtetra
.738 .664 .778 r
.41424 .39466 .41517 .39635 .41684 .39422 .41588 .3934 Mtetra
.644 .778 .945 r
.41588 .3934 .41684 .39422 .41846 .39364 .4175 .39291 Mtetra
.561 .776 .979 r
.4175 .39291 .41846 .39364 .42006 .39346 .41911 .39264 Mtetra
.584 .76 .962 r
.41911 .39264 .42006 .39346 .42167 .39329 .42072 .39234 Mtetra
.656 .752 .921 r
.42072 .39234 .42167 .39329 .42328 .3928 .42233 .39182 Mtetra
.67 .75 .91 r
.42233 .39182 .42328 .3928 .4249 .39226 .42395 .39124 Mtetra
.688 .748 .897 r
.42395 .39124 .4249 .39226 .42653 .39164 .42558 .39058 Mtetra
.703 .744 .884 r
.42558 .39058 .42653 .39164 .42815 .39094 .42721 .38984 Mtetra
.701 .736 .878 r
.42721 .38984 .42815 .39094 .42978 .39023 .42883 .3891 Mtetra
.711 .734 .869 r
.42883 .3891 .42978 .39023 .43141 .3895 .43047 .3883 Mtetra
.715 .723 .856 r
.43047 .3883 .43141 .3895 .43304 .38876 .4321 .38746 Mtetra
.65 .683 .867 r
.4321 .38746 .43304 .38876 .43466 .38822 .43372 .38695 Mtetra
.336 .54 .904 r
.43372 .38695 .43466 .38822 .43627 .38818 .43532 .38741 Mtetra
.861 .412 .039 r
.43532 .38741 .43627 .38818 .43786 .38908 .43685 .39048 Mtetra
.955 .682 .478 r
.43685 .39048 .43786 .38908 .43943 .39068 .43326 .58384 Mtetra
.56 .335 .531 r
.43326 .58384 .43943 .39068 .44101 .39214 .43475 .59264 Mtetra
.544 .322 .529 r
.43475 .59264 .44101 .39214 .44265 .39116 .43647 .59246 Mtetra
.542 .321 .529 r
.43647 .59246 .44265 .39116 .44429 .39049 .43822 .59157 Mtetra
.544 .322 .529 r
.43822 .59157 .44429 .39049 .44585 .393 .43994 .59162 Mtetra
.547 .325 .529 r
.43994 .59162 .44585 .393 .44274 .58978 .44162 .59342 Mtetra
.614 .286 .391 r
.44162 .59342 .44274 .58978 .44435 .59465 .44332 .59465 Mtetra
.384 0 0 r
.44332 .59465 .44435 .59465 .44604 .5963 .44503 .5952 Mtetra
.561 .703 .936 r
.44503 .5952 .44604 .5963 .44777 .59621 .44677 .595 Mtetra
.63 .708 .903 r
.44677 .595 .44777 .59621 .44951 .59567 .44851 .59456 Mtetra
.643 .73 .912 r
.44851 .59456 .44951 .59567 .45126 .59499 .45026 .59406 Mtetra
.599 .754 .952 r
.45026 .59406 .45126 .59499 .45301 .59448 .452 .5937 Mtetra
.687 .815 .944 r
.452 .5937 .45301 .59448 .45476 .59376 .45376 .59299 Mtetra
.825 .83 .852 r
.45376 .59299 .45476 .59376 .45652 .59261 .45553 .59143 Mtetra
.902 .752 .685 r
.45553 .59143 .45652 .59261 .4583 .59052 .45735 .58731 Mtetra
.916 .675 .559 r
.45735 .58731 .4583 .59052 .46009 .58779 .45939 .57143 Mtetra
.941 .669 .496 r
.45939 .57143 .46009 .58779 .46189 .58479 .46468 .38203 Mtetra
.547 .329 .536 r
.46468 .38203 .46189 .58479 .46365 .58373 .46635 .38065 Mtetra
.545 .328 .535 r
.46635 .38065 .46365 .58373 .46539 .58348 .46799 .38043 Mtetra
.544 .327 .535 r
.46799 .38043 .46539 .58348 .46713 .58366 .46962 .38074 Mtetra
.545 .327 .535 r
.46962 .38074 .46713 .58366 .46887 .58397 .47127 .38073 Mtetra
.546 .328 .535 r
.47127 .38073 .46887 .58397 .47063 .58346 .47292 .38028 Mtetra
.548 .33 .536 r
.47292 .38028 .47063 .58346 .47242 .58061 .47459 .37866 Mtetra
.551 .332 .536 r
.47459 .37866 .47242 .58061 .47712 .38223 .47628 .37567 Mtetra
.661 .475 .622 r
.47628 .37567 .47712 .38223 .47887 .37544 .47796 .37337 Mtetra
.747 .639 .74 r
.47796 .37337 .47887 .37544 .48056 .37263 .47962 .37175 Mtetra
.7 .787 .918 r
.47962 .37175 .48056 .37263 .48221 .37175 .48128 .37104 Mtetra
.634 .808 .966 r
.48128 .37104 .48221 .37175 .48387 .3713 .48294 .37055 Mtetra
.61 .791 .968 r
.48294 .37055 .48387 .3713 .48552 .37101 .48459 .37014 Mtetra
.662 .778 .935 r
.48459 .37014 .48552 .37101 .48717 .37045 .48625 .36958 Mtetra
.663 .777 .934 r
.48625 .36958 .48717 .37045 .48883 .3699 .4879 .36902 Mtetra
.663 .774 .932 r
.4879 .36902 .48883 .3699 .49049 .36935 .48956 .36845 Mtetra
.664 .772 .93 r
.48956 .36845 .49049 .36935 .49215 .36879 .49122 .36788 Mtetra
.664 .771 .929 r
.49122 .36788 .49215 .36879 .49381 .36823 .49289 .36732 Mtetra
.664 .77 .928 r
.49289 .36732 .49381 .36823 .49547 .36766 .49455 .36675 Mtetra
.664 .769 .928 r
.49455 .36675 .49547 .36766 .49713 .3671 .49621 .36618 Mtetra
.664 .768 .928 r
.49621 .36618 .49713 .3671 .4988 .36653 .49788 .36562 Mtetra
.49788 .36562 .4988 .36653 .50046 .36597 .49954 .36505 Mtetra
.663 .768 .928 r
.49954 .36505 .50046 .36597 .50213 .3654 .50121 .36449 Mtetra
.50121 .36449 .50213 .3654 .50379 .36484 .50287 .36392 Mtetra
.50287 .36392 .50379 .36484 .50546 .36427 .50454 .36335 Mtetra
.664 .768 .928 r
.50454 .36335 .50546 .36427 .50713 .3637 .50621 .36279 Mtetra
.664 .769 .928 r
.50621 .36279 .50713 .3637 .5088 .36313 .50788 .36222 Mtetra
.50788 .36222 .5088 .36313 .51047 .36256 .50955 .36165 Mtetra
.666 .771 .928 r
.50955 .36165 .51047 .36256 .51214 .36197 .51123 .36107 Mtetra
.666 .772 .929 r
.51123 .36107 .51214 .36197 .51381 .36139 .5129 .36049 Mtetra
.667 .774 .93 r
.5129 .36049 .51381 .36139 .51549 .3608 .51457 .35991 Mtetra
.701 .785 .917 r
.51457 .35991 .51549 .3608 .51716 .35994 .51625 .35918 Mtetra
.667 .807 .95 r
.51625 .35918 .51716 .35994 .51884 .35933 .51793 .35858 Mtetra
.58 .783 .975 r
.51793 .35858 .51884 .35933 .52052 .35922 .5196 .35825 Mtetra
.121 .48 .898 r
.5196 .35825 .52052 .35922 .52219 .36143 .52128 .35892 Mtetra
.288 .346 .749 r
.52128 .35892 .52219 .36143 .52387 .36921 .52296 .36019 Mtetra
.462 .313 .593 r
.52296 .36019 .52387 .36921 .5256 .56573 .52464 .36211 Mtetra
.545 .327 .535 r
.52464 .36211 .5256 .56573 .52739 .56641 .52633 .36213 Mtetra
.546 .329 .536 r
.52633 .36213 .52739 .56641 .52918 .56566 .52801 .36135 Mtetra
.547 .329 .536 r
.52801 .36135 .52918 .56566 .53097 .56416 .5297 .36022 Mtetra
.547 .33 .536 r
.5297 .36022 .53097 .56416 .53277 .56301 .53138 .35879 Mtetra
.546 .328 .535 r
.53138 .35879 .53277 .56301 .53456 .5623 .53307 .35805 Mtetra
.544 .327 .535 r
.53307 .35805 .53456 .5623 .53636 .5625 .53476 .35859 Mtetra
0 0 .369 r
.53476 .35859 .53636 .5625 .53817 .56475 .53717 .55478 Mtetra
.007 0 .477 r
.53717 .55478 .53817 .56475 .53998 .56634 .53901 .56361 Mtetra
0 .106 .641 r
.53901 .56361 .53998 .56634 .54179 .56727 .54082 .56626 Mtetra
.412 .657 .96 r
.54082 .56626 .54179 .56727 .5436 .5672 .54263 .56641 Mtetra
.605 .797 .973 r
.54263 .56641 .5436 .5672 .5454 .56681 .54444 .56597 Mtetra
.694 .812 .938 r
.54444 .56597 .5454 .56681 .54721 .56623 .54625 .56522 Mtetra
.64 .758 .934 r
.54625 .56522 .54721 .56623 .54902 .56589 .54806 .5647 Mtetra
.674 .735 .896 r
.54806 .5647 .54902 .56589 .55083 .56528 .54987 .56403 Mtetra
.718 .737 .866 r
.54987 .56403 .55083 .56528 .55264 .56418 .55168 .5631 Mtetra
.83 .786 .81 r
.55168 .5631 .55264 .56418 .55442 .56085 .55348 .56124 Mtetra
.901 .985 .737 r
.55348 .56124 .55442 .56085 .55617 .55311 .55527 .55875 Mtetra
.254 .007 .333 r
.55527 .55875 .55617 .55311 .55603 .35379 .55706 .55563 Mtetra
.543 .322 .529 r
.55706 .55563 .55603 .35379 .55772 .35187 .55888 .55509 Mtetra
.544 .322 .529 r
.55888 .55509 .55772 .35187 .55943 .35155 .56069 .55491 Mtetra
.542 .321 .529 r
.56069 .55491 .55943 .35155 .56113 .35135 .5625 .55378 Mtetra
0 0 .373 r
.5625 .55378 .56113 .35135 .56281 .34837 .56205 .3592 Mtetra
0 0 .23 r
.56205 .3592 .56281 .34837 .56449 .34583 .56362 .3466 Mtetra
.949 .939 .606 r
.56362 .3466 .56449 .34583 .56618 .34396 .56529 .34299 Mtetra
.761 .787 .875 r
.56529 .34299 .56618 .34396 .56788 .34318 .56699 .3419 Mtetra
.624 .686 .887 r
.56699 .3419 .56788 .34318 .56959 .34276 .5687 .3415 Mtetra
.557 .659 .904 r
.5687 .3415 .56959 .34276 .5713 .34246 .57041 .34136 Mtetra
.662 .735 .903 r
.57041 .34136 .5713 .34246 .57301 .34181 .57212 .34078 Mtetra
.69 .758 .904 r
.57212 .34078 .57301 .34181 .57472 .34107 .57383 .34008 Mtetra
.693 .769 .91 r
.57383 .34008 .57472 .34107 .57643 .34032 .57554 .33937 Mtetra
.709 .781 .908 r
.57554 .33937 .57643 .34032 .57814 .33941 .57725 .33859 Mtetra
.684 .804 .939 r
.57725 .33859 .57814 .33941 .57985 .33869 .57896 .33792 Mtetra
.612 .793 .968 r
.57896 .33792 .57985 .33869 .58157 .33841 .58068 .33748 Mtetra
.413 .665 .964 r
.58068 .33748 .58157 .33841 .58332 .33982 .58241 .33761 Mtetra
.377 .431 .79 r
.58241 .33761 .58332 .33982 .58513 .34445 .58415 .33843 Mtetra
.386 .29 .622 r
.58415 .33843 .58513 .34445 .59078 .54447 .58593 .34066 Mtetra
0 0 .389 r
.58593 .34066 .59078 .54447 .59271 .5488 .59155 .53685 Mtetra
.068 .021 .49 r
.59155 .53685 .59271 .5488 .59459 .55029 .5936 .54693 Mtetra
.112 .187 .663 r
.5936 .54693 .59459 .55029 .59645 .55086 .59551 .54957 Mtetra
.367 .575 .92 r
.59551 .54957 .59645 .55086 .59831 .55096 .59737 .54997 Mtetra
.627 .764 .944 r
.59737 .54997 .59831 .55096 .60015 .55056 .59921 .54949 Mtetra
.739 .781 .886 r
.59921 .54949 .60015 .55056 .60199 .54954 .60105 .54846 Mtetra
.822 .792 .824 r
.60105 .54846 .60199 .54954 .60378 .54667 .60287 .54673 Mtetra
.918 .971 .781 r
.60287 .54673 .60378 .54667 .60548 .54022 .60467 .54433 Mtetra
.133 0 .244 r
.60467 .54433 .60548 .54022 .60241 .33941 .60645 .54126 Mtetra
.542 .321 .529 r
.60645 .54126 .60241 .33941 .60408 .33629 .60829 .54019 Mtetra
.544 .322 .529 r
.60829 .54019 .60408 .33629 .60582 .33586 .61014 .54005 Mtetra
.542 .321 .529 r
.61014 .54005 .60582 .33586 .60756 .33571 .61198 .53913 Mtetra
.522 .305 .527 r
.61198 .53913 .60756 .33571 .60924 .33309 .61351 .52627 Mtetra
0 0 .376 r
.61351 .52627 .60924 .33309 .61092 .33041 .61011 .33165 Mtetra
.881 .896 .476 r
.61011 .33165 .61092 .33041 .61262 .32842 .61175 .3276 Mtetra
.814 .831 .863 r
.61175 .3276 .61262 .32842 .61434 .32746 .61346 .32619 Mtetra
.64 .697 .887 r
.61346 .32619 .61434 .32746 .61608 .32698 .6152 .3257 Mtetra
.569 .665 .903 r
.6152 .3257 .61608 .32698 .61782 .32664 .61695 .32551 Mtetra
.677 .738 .897 r
.61695 .32551 .61782 .32664 .61955 .32579 .61869 .32486 Mtetra
.715 .791 .911 r
.61869 .32486 .61955 .32579 .62128 .32488 .62042 .32404 Mtetra
.667 .799 .945 r
.62042 .32404 .62128 .32488 .62302 .32436 .62216 .32342 Mtetra
.489 .703 .964 r
.62216 .32342 .62302 .32436 .62481 .32535 .62392 .32338 Mtetra
.396 .469 .817 r
.62392 .32338 .62481 .32535 .6267 .32905 .6257 .32404 Mtetra
.39 .311 .647 r
.6257 .32404 .6267 .32905 .63503 .52897 .62752 .3259 Mtetra
.509 .3 .532 r
.62752 .3259 .63503 .52897 .63711 .53489 .62991 .34447 Mtetra
0 0 .398 r
.62991 .34447 .63711 .53489 .63905 .53662 .63804 .53274 Mtetra
.126 .174 .643 r
.63804 .53274 .63905 .53662 .64096 .53727 .64003 .53581 Mtetra
.343 .528 .893 r
.64003 .53581 .64096 .53727 .64285 .53731 .64194 .53638 Mtetra
.636 .781 .951 r
.64194 .53638 .64285 .53731 .64473 .53684 .64381 .53585 Mtetra
.753 .803 .893 r
.64381 .53585 .64473 .53684 .64658 .53576 .64567 .53475 Mtetra
.792 .807 .864 r
.64567 .53475 .64658 .53576 .64839 .53325 .64751 .53336 Mtetra
.837 .999 .821 r
.64751 .53336 .64839 .53325 .65008 .52784 .64934 .5315 Mtetra
.098 0 .214 r
.64934 .5315 .65008 .52784 .64435 .32687 .65112 .52848 Mtetra
.523 .307 .527 r
.65112 .52848 .64435 .32687 .64588 .32036 .65256 .51647 Mtetra
0 0 .391 r
.65256 .51647 .64588 .32036 .64756 .31771 .64681 .31943 Mtetra
.703 .785 .304 r
.64681 .31943 .64756 .31771 .64927 .31603 .64843 .31539 Mtetra
.846 .878 .864 r
.64843 .31539 .64927 .31603 .65102 .3151 .65015 .31381 Mtetra
.644 .697 .884 r
.65015 .31381 .65102 .3151 .65278 .31465 .65191 .3133 Mtetra
.562 .651 .895 r
.65191 .3133 .65278 .31465 .65455 .31438 .65369 .31315 Mtetra
.6 .69 .906 r
.65369 .31315 .65455 .31438 .65632 .31396 .65546 .31283 Mtetra
.657 .732 .905 r
.65546 .31283 .65632 .31396 .65808 .31337 .65723 .31226 Mtetra
.669 .743 .905 r
.65723 .31226 .65808 .31337 .65984 .31271 .65899 .31164 Mtetra
.746 .774 .876 r
.65899 .31164 .65984 .31271 .66159 .31164 .66074 .3106 Mtetra
.753 .783 .877 r
.66074 .3106 .66159 .31164 .66333 .31055 .66248 .30953 Mtetra
.637 .75 .93 r
.66248 .30953 .66333 .31055 .6651 .31003 .66425 .30904 Mtetra
0 .039 .563 r
.66425 .30904 .6651 .31003 .66698 .31184 .66613 .31093 Mtetra
.974 .677 .388 r
.66613 .31093 .66698 .31184 .67787 .5099 .67705 .51078 Mtetra
.934 .584 .338 r
.67705 .51078 .67787 .5099 .68043 .52391 .67953 .52301 Mtetra
0 .102 .599 r
.67953 .52301 .68043 .52391 .68244 .52578 .68154 .52473 Mtetra
.61 .747 .943 r
.68154 .52473 .68244 .52578 .68435 .52547 .68344 .5243 Mtetra
.755 .774 .868 r
.68344 .5243 .68435 .52547 .68622 .52424 .68532 .52313 Mtetra
.798 .793 .848 r
.68532 .52313 .68622 .52424 .68803 .52178 .68717 .52163 Mtetra
.859 .98 .856 r
.68717 .52163 .68803 .52178 .68971 .51681 .68901 .51982 Mtetra
.021 0 .146 r
.68901 .51982 .68971 .51681 .68161 .316 .6908 .51691 Mtetra
.529 .311 .528 r
.6908 .51691 .68161 .316 .68302 .30802 .69227 .50771 Mtetra
0 0 .405 r
.69227 .50771 .68302 .30802 .68469 .30519 .68401 .30734 Mtetra
0 0 0 r
.68401 .30734 .68469 .30519 .68641 .30341 .6856 .30296 Mtetra
.883 .919 .844 r
.6856 .30296 .68641 .30341 .68817 .30236 .68732 .30111 Mtetra
.663 .716 .887 r
.68732 .30111 .68817 .30236 .68995 .30182 .6891 .3005 Mtetra
.585 .669 .897 r
.6891 .3005 .68995 .30182 .69175 .30145 .6909 .30025 Mtetra
.673 .728 .891 r
.6909 .30025 .69175 .30145 .69352 .30068 .69268 .29959 Mtetra
.749 .775 .874 r
.69268 .29959 .69352 .30068 .69528 .2996 .69444 .29854 Mtetra
.652 .748 .92 r
.69444 .29854 .69528 .2996 .69707 .29901 .69623 .29798 Mtetra
0 .256 .756 r
.69623 .29798 .69707 .29901 .69896 .30033 .69813 .29935 Mtetra
.953 .605 .247 r
.69813 .29935 .69896 .30033 .70144 .31196 .7007 .3127 Mtetra
.974 .673 .377 r
.7007 .3127 .70144 .31196 .71471 .51285 .71383 .51193 Mtetra
.515 .022 0 r
.71383 .51193 .71471 .51285 .71679 .51511 .7159 .51412 Mtetra
.611 .762 .952 r
.7159 .51412 .71679 .51511 .71872 .5147 .71783 .51367 Mtetra
.744 .801 .898 r
.71783 .51367 .71872 .5147 .72061 .51367 .71973 .5126 Mtetra
.674 .772 .924 r
.71973 .5126 .72061 .51367 .72253 .51301 .72165 .5119 Mtetra
.496 .685 .951 r
.72165 .5119 .72253 .51301 .72449 .51301 .7236 .51187 Mtetra
.65 .747 .92 r
.7236 .51187 .72449 .51301 .72642 .51246 .72553 .51128 Mtetra
.88 .795 .762 r
.72553 .51128 .72642 .51246 .72823 .50992 .72734 .50867 Mtetra
.976 .731 .502 r
.72734 .50867 .72823 .50992 .72947 .49824 .72851 .49572 Mtetra
.976 .681 .384 r
.72851 .49572 .72947 .49824 .71878 .29481 .71794 .29349 Mtetra
.899 .766 .706 r
.71794 .29349 .71878 .29481 .72041 .29147 .71958 .29025 Mtetra
.682 .729 .886 r
.71958 .29025 .72041 .29147 .7222 .29074 .72137 .28954 Mtetra
.541 .671 .922 r
.72137 .28954 .7222 .29074 .72404 .29061 .72321 .28942 Mtetra
.536 .672 .925 r
.72321 .28942 .72404 .29061 .72587 .29049 .72504 .28931 Mtetra
.656 .729 .903 r
.72504 .28931 .72587 .29049 .72768 .28989 .72685 .28874 Mtetra
.667 .738 .903 r
.72685 .28874 .72768 .28989 .72949 .28925 .72866 .28811 Mtetra
.713 .758 .888 r
.72866 .28811 .72949 .28925 .73128 .28837 .73045 .28725 Mtetra
.748 .772 .872 r
.73045 .28725 .73128 .28837 .73305 .28729 .73223 .28617 Mtetra
.662 .743 .91 r
.73223 .28617 .73305 .28729 .73486 .28668 .73404 .28557 Mtetra
.119 .44 .877 r
.73404 .28557 .73486 .28668 .73678 .28759 .73596 .28648 Mtetra
.908 .524 .095 r
.73596 .28648 .73678 .28759 .73917 .2954 .73835 .29435 Mtetra
.975 .671 .352 r
.73835 .29435 .73917 .2954 .75517 .49933 .7543 .49827 Mtetra
.605 .141 0 r
.7543 .49827 .75517 .49933 .75736 .50229 .7565 .50121 Mtetra
.551 .721 .952 r
.7565 .50121 .75736 .50229 .75934 .50207 .75847 .50099 Mtetra
.71 .784 .909 r
.75847 .50099 .75934 .50207 .76127 .5012 .7604 .5001 Mtetra
.692 .776 .915 r
.7604 .5001 .76127 .5012 .7632 .50041 .76234 .4993 Mtetra
.511 .696 .952 r
.76234 .4993 .7632 .50041 .76519 .50032 .76433 .49921 Mtetra
.652 .758 .928 r
.76433 .49921 .76519 .50032 .76714 .49972 .76628 .49861 Mtetra
.864 .811 .796 r
.76628 .49861 .76714 .49972 .76898 .49753 .76812 .4964 Mtetra
.978 .75 .525 r
.76812 .4964 .76898 .49753 .77027 .48794 .7694 .48664 Mtetra
.977 .678 .362 r
.7694 .48664 .77027 .48794 .75694 .28288 .75613 .28169 Mtetra
.931 .783 .675 r
.75613 .28169 .75694 .28288 .75852 .27897 .75771 .27781 Mtetra
.727 .761 .879 r
.75771 .27781 .75852 .27897 .76032 .27801 .75951 .27685 Mtetra
.603 .712 .921 r
.75951 .27685 .76032 .27801 .76217 .27765 .76136 .27649 Mtetra
.602 .712 .921 r
.76136 .27649 .76217 .27765 .76402 .27729 .76321 .27613 Mtetra
.74 .767 .874 r
.76321 .27613 .76402 .27729 .76582 .27625 .76501 .2751 Mtetra
.658 .737 .908 r
.76501 .2751 .76582 .27625 .76765 .27565 .76684 .2745 Mtetra
.239 .512 .908 r
.76684 .2745 .76765 .27565 .76958 .27634 .76878 .27519 Mtetra
.882 .489 .033 r
.76878 .27519 .76958 .27634 .77204 .28353 .77123 .28239 Mtetra
.975 .667 .334 r
.77123 .28239 .77204 .28353 .79037 .48862 .78952 .48754 Mtetra
.659 .205 0 r
.78952 .48754 .79037 .48862 .79267 .49209 .79182 .49101 Mtetra
.379 .631 .953 r
.79182 .49101 .79267 .49209 .79471 .49236 .79386 .49129 Mtetra
.697 .785 .919 r
.79386 .49129 .79471 .49236 .79667 .49152 .79582 .49045 Mtetra
.882 .824 .785 r
.79582 .49045 .79667 .49152 .79849 .48909 .79765 .48804 Mtetra
.982 .759 .524 r
.79765 .48804 .79849 .48909 .79973 .47962 .79891 .47889 Mtetra
.977 .675 .346 r
.79891 .47889 .79973 .47962 .78445 .27332 .78366 .27232 Mtetra
.952 .803 .658 r
.78366 .27232 .78445 .27332 .786 .26922 .78521 .26815 Mtetra
.721 .78 .899 r
.78521 .26815 .786 .26922 .78783 .26834 .78703 .26725 Mtetra
.572 .713 .938 r
.78703 .26725 .78783 .26834 .7897 .2681 .78891 .26698 Mtetra
.527 .687 .94 r
.78891 .26698 .7897 .2681 .7916 .26804 .7908 .26688 Mtetra
.714 .759 .888 r
.7908 .26688 .7916 .26804 .79344 .26731 .79263 .26599 Mtetra
.662 .711 .884 r
.79263 .26599 .79344 .26731 .79528 .26667 .79448 .26536 Mtetra
.5 .632 .911 r
.79448 .26536 .79528 .26667 .79716 .26632 .79639 .26542 Mtetra
0 0 .484 r
.79639 .26542 .79716 .26632 .79909 .26658 .7985 .2678 Mtetra
.934 .571 .297 r
.7985 .2678 .79909 .26658 .80109 .2676 .80157 .28074 Mtetra
.966 .651 .365 r
.80157 .28074 .80109 .2676 .80329 .27079 .82107 .47659 Mtetra
.547 .325 .529 r
.82107 .47659 .80329 .27079 .82354 .47317 .82332 .47887 Mtetra
.57 .267 .415 r
.82332 .47887 .82354 .47317 .82613 .47912 .82545 .47975 Mtetra
.379 0 0 r
.82545 .47975 .82613 .47912 .82836 .48109 .82753 .48 Mtetra
.452 .67 .956 r
.82753 .48 .82836 .48109 .83044 .48136 .82959 .48008 Mtetra
.647 .727 .907 r
.82959 .48008 .83044 .48136 .83243 .48073 .83159 .47949 Mtetra
.816 .794 .831 r
.83159 .47949 .83243 .48073 .83431 .47885 .83348 .47777 Mtetra
.979 .778 .564 r
.83348 .47777 .83431 .47885 .83571 .47181 .83489 .47078 Mtetra
.976 .671 .329 r
.83489 .47078 .83571 .47181 .818 .26373 .81722 .26263 Mtetra
.966 .787 .611 r
.81722 .26263 .818 .26373 .81943 .25856 .81865 .25743 Mtetra
.757 .783 .874 r
.81865 .25743 .81943 .25856 .82125 .25743 .82047 .25629 Mtetra
.622 .728 .923 r
.82047 .25629 .82125 .25743 .82313 .25699 .82235 .25584 Mtetra
.547 .691 .934 r
.82235 .25584 .82313 .25699 .82505 .25683 .82427 .25567 Mtetra
.749 .775 .875 r
.82427 .25567 .82505 .25683 .82687 .25575 .82609 .25458 Mtetra
.675 .745 .904 r
.82609 .25458 .82687 .25575 .82874 .25507 .82796 .25389 Mtetra
.437 .624 .931 r
.82796 .25389 .82874 .25507 .8307 .2553 .82991 .25409 Mtetra
.812 .409 0 r
.82991 .25409 .8307 .2553 .83327 .26168 .83246 .26025 Mtetra
.971 .658 .297 r
.83246 .26025 .83327 .26168 .85606 .46883 .85522 .46753 Mtetra
.631 .209 0 r
.85522 .46753 .85606 .46883 .85854 .47284 .85771 .47163 Mtetra
.401 .616 .938 r
.85771 .47163 .85854 .47284 .86064 .47311 .85982 .47192 Mtetra
.685 .765 .912 r
.85982 .47192 .86064 .47311 .86264 .47229 .86182 .47114 Mtetra
.844 .816 .822 r
.86182 .47114 .86264 .47229 .86452 .47032 .86371 .46919 Mtetra
.976 .785 .581 r
.86371 .46919 .86452 .47032 .86595 .46398 .86514 .46289 Mtetra
.974 .667 .312 r
.86514 .46289 .86595 .46398 .84622 .25504 .84545 .25395 Mtetra
.976 .782 .578 r
.84545 .25395 .84622 .25504 .84755 .24911 .84678 .24797 Mtetra
.773 .766 .847 r
.2398 .45209 .24082 .453 .24239 .45173 .24136 .45096 Mtetra
.638 .774 .946 r
.24136 .45096 .24239 .45173 .2439 .45126 .24287 .45052 Mtetra
.469 .728 .982 r
.24287 .45052 .2439 .45126 .24537 .45137 .24435 .45047 Mtetra
.736 .764 .875 r
.24435 .45047 .24537 .45137 .24682 .4516 .24589 .4496 Mtetra
.643 .586 .776 r
.24589 .4496 .24682 .4516 .24821 .45251 .24741 .44906 Mtetra
.541 .445 .696 r
.24741 .44906 .24821 .45251 .24948 .455 .24888 .44918 Mtetra
0 0 .486 r
.24888 .44918 .24948 .455 .23484 .64786 .24998 .45356 Mtetra
0 0 .177 r
.24998 .45356 .23484 .64786 .23582 .65485 .23503 .65047 Mtetra
0 0 .281 r
.23503 .65047 .23582 .65485 .23721 .65712 .23618 .65549 Mtetra
.454 .549 .863 r
.23618 .65549 .23721 .65712 .23878 .65715 .23773 .65576 Mtetra
.664 .677 .852 r
.23773 .65576 .23878 .65715 .24039 .6566 .23935 .65518 Mtetra
.721 .69 .82 r
.23935 .65518 .24039 .6566 .24204 .65576 .24101 .6542 Mtetra
.643 .645 .837 r
.24101 .6542 .24204 .65576 .24366 .65521 .24262 .65371 Mtetra
.636 .65 .847 r
.24262 .65371 .24366 .65521 .24528 .65468 .24424 .65326 Mtetra
.638 .663 .858 r
.24424 .65326 .24528 .65468 .2469 .65416 .24585 .65281 Mtetra
.647 .678 .865 r
.24585 .65281 .2469 .65416 .24852 .65367 .24747 .65232 Mtetra
.649 .678 .864 r
.24747 .65232 .24852 .65367 .25014 .65319 .24909 .65182 Mtetra
.649 .675 .861 r
.24909 .65182 .25014 .65319 .25176 .65272 .25071 .65132 Mtetra
.641 .668 .86 r
.25071 .65132 .25176 .65272 .25336 .65241 .25233 .65085 Mtetra
.637 .645 .841 r
.25233 .65085 .25336 .65241 .25498 .652 .25395 .6504 Mtetra
.638 .639 .835 r
.25395 .6504 .25498 .652 .25662 .65133 .25558 .64993 Mtetra
.65 .671 .857 r
.25558 .64993 .25662 .65133 .25833 .64968 .2572 .64942 Mtetra
.579 .892 .988 r
.2572 .64942 .25833 .64968 .2601 .64733 .25883 .64889 Mtetra
.289 0 .044 r
.25883 .64889 .2601 .64733 .26191 .64434 .26046 .64838 Mtetra
.464 .153 .353 r
.26046 .64838 .26191 .64434 .26361 .64285 .26209 .6479 Mtetra
.483 .19 .391 r
.26209 .6479 .26361 .64285 .26523 .64244 .26371 .64744 Mtetra
.483 .189 .39 r
.26371 .64744 .26523 .64244 .26682 .64248 .26534 .64699 Mtetra
.475 .173 .373 r
.26534 .64699 .26682 .64248 .26844 .64213 .26697 .64653 Mtetra
.472 .168 .368 r
.26697 .64653 .26844 .64213 .27006 .64169 .2686 .64606 Mtetra
.469 .165 .366 r
.2686 .64606 .27006 .64169 .27169 .64124 .27023 .64557 Mtetra
.51 .203 .382 r
.27023 .64557 .27169 .64124 .27326 .64153 .27184 .64549 Mtetra
.48 .167 .357 r
.27184 .64549 .27326 .64153 .27487 .64137 .27346 .64517 Mtetra
.388 .075 .309 r
.27346 .64517 .27487 .64137 .27657 .64004 .27513 .64419 Mtetra
0 0 0 r
.27513 .64419 .27657 .64004 .27964 .61929 .27706 .63969 Mtetra
.967 .717 .504 r
.27706 .63969 .27964 .61929 .29407 .43803 .29275 .44153 Mtetra
.937 .863 .436 r
.29275 .44153 .29407 .43803 .29584 .43428 .29478 .43414 Mtetra
.876 .913 .85 r
.29478 .43414 .29584 .43428 .29744 .43298 .29641 .43244 Mtetra
.658 .842 .971 r
.29641 .43244 .29744 .43298 .29898 .43245 .29796 .43189 Mtetra
.458 .774 .997 r
.29796 .43189 .29898 .43245 .30051 .43221 .29948 .43176 Mtetra
.564 .843 .997 r
.29948 .43176 .30051 .43221 .30205 .43177 .30102 .43139 Mtetra
.597 .87 .993 r
.30102 .43139 .30205 .43177 .3036 .43127 .30256 .43092 Mtetra
.593 .876 .993 r
.30256 .43092 .3036 .43127 .30514 .4308 .30411 .43045 Mtetra
.627 .883 .988 r
.30411 .43045 .30514 .4308 .30668 .43042 .30566 .42991 Mtetra
.662 .851 .972 r
.30566 .42991 .30668 .43042 .30822 .43007 .30721 .42933 Mtetra
.674 .796 .94 r
.30721 .42933 .30822 .43007 .30976 .42972 .30877 .42876 Mtetra
.663 .744 .91 r
.30877 .42876 .30976 .42972 .31131 .42928 .31032 .42823 Mtetra
.657 .723 .898 r
.31032 .42823 .31131 .42928 .31286 .42878 .31188 .42773 Mtetra
.656 .724 .899 r
.31188 .42773 .31286 .42878 .31442 .42822 .31343 .42723 Mtetra
.661 .738 .907 r
.31343 .42723 .31442 .42822 .31598 .42757 .31499 .42672 Mtetra
.664 .769 .928 r
.31499 .42672 .31598 .42757 .31755 .42688 .31654 .42619 Mtetra
.662 .807 .953 r
.31654 .42619 .31755 .42688 .31912 .42619 .3181 .42565 Mtetra
.657 .842 .971 r
.3181 .42565 .31912 .42619 .32069 .42547 .31966 .4251 Mtetra
.636 .881 .986 r
.31966 .4251 .32069 .42547 .32225 .42484 .32122 .42454 Mtetra
.617 .893 .988 r
.32122 .42454 .32225 .42484 .32381 .42443 .32279 .42399 Mtetra
.632 .863 .986 r
.32279 .42399 .32381 .42443 .32531 .42478 .32435 .42347 Mtetra
.653 .676 .859 r
.32435 .42347 .32531 .42478 .32678 .42585 .32591 .42296 Mtetra
.617 .519 .72 r
.32591 .42296 .32678 .42585 .32821 .42757 .32747 .42246 Mtetra
.614 .458 .646 r
.32747 .42246 .32821 .42757 .32973 .42772 .32906 .4216 Mtetra
.6 .435 .629 r
.32906 .4216 .32973 .42772 .33132 .42677 .33064 .42081 Mtetra
.569 .414 .631 r
.33064 .42081 .33132 .42677 .33288 .42651 .33218 .42058 Mtetra
.342 .25 .605 r
.33218 .42058 .33288 .42651 .33382 .43657 .33358 .42291 Mtetra
.965 .703 .489 r
.33358 .42291 .33382 .43657 .32432 .62654 .3237 .61817 Mtetra
0 0 .261 r
.3237 .61817 .32432 .62654 .32576 .62993 .32478 .62774 Mtetra
.132 .286 .755 r
.32478 .62774 .32576 .62993 .32736 .6307 .32634 .62913 Mtetra
.602 .632 .853 r
.32634 .62913 .32736 .6307 .32902 .63036 .328 .62884 Mtetra
.691 .674 .828 r
.328 .62884 .32902 .63036 .33071 .62948 .32969 .62804 Mtetra
.68 .682 .845 r
.32969 .62804 .33071 .62948 .33244 .62794 .33137 .62734 Mtetra
.65 .839 .973 r
.33137 .62734 .33244 .62794 .3342 .62572 .33304 .62677 Mtetra
.13 0 0 r
.33304 .62677 .3342 .62572 .336 .62285 .33472 .62618 Mtetra
.48 .15 .328 r
.33472 .62618 .336 .62285 .33773 .62139 .33638 .62596 Mtetra
.5 .197 .384 r
.33638 .62596 .33773 .62139 .33938 .62133 .33804 .62575 Mtetra
.439 .138 .356 r
.33804 .62575 .33938 .62133 .34106 .62065 .33973 .62497 Mtetra
.015 0 .165 r
.33973 .62497 .34106 .62065 .3431 .61317 .34156 .62167 Mtetra
.96 .702 .5 r
.34156 .62167 .3431 .61317 .35495 .41861 .35339 .42875 Mtetra
0 0 0 r
.35339 .42875 .35495 .41861 .35673 .41422 .35569 .41445 Mtetra
.937 .937 .769 r
.35569 .41445 .35673 .41422 .35837 .41257 .35738 .41197 Mtetra
.712 .841 .944 r
.35738 .41197 .35837 .41257 .35995 .41209 .35897 .41123 Mtetra
.574 .743 .956 r
.35897 .41123 .35995 .41209 .36151 .41196 .36054 .41097 Mtetra
.602 .723 .929 r
.36054 .41097 .36151 .41196 .36308 .41171 .36211 .41066 Mtetra
.651 .726 .904 r
.36211 .41066 .36308 .41171 .36466 .41122 .36369 .41018 Mtetra
.65 .726 .904 r
.36369 .41018 .36466 .41122 .36625 .41068 .36527 .4097 Mtetra
.663 .742 .909 r
.36527 .4097 .36625 .41068 .36784 .40994 .36686 .40916 Mtetra
.674 .793 .938 r
.36686 .40916 .36784 .40994 .36944 .40911 .36845 .40858 Mtetra
.661 .851 .973 r
.36845 .40858 .36944 .40911 .37104 .40848 .37004 .408 Mtetra
.725 .873 .95 r
.37004 .408 .37104 .40848 .37261 .40835 .37165 .40719 Mtetra
.711 .723 .859 r
.37165 .40719 .37261 .40835 .37415 .40891 .37325 .40638 Mtetra
.598 .528 .747 r
.37325 .40638 .37415 .40891 .37564 .41052 .37483 .40608 Mtetra
.354 .291 .648 r
.37483 .40608 .37564 .41052 .37686 .41816 .37632 .40779 Mtetra
.965 .699 .479 r
.37632 .40779 .37686 .41816 .36966 .61235 .36947 .59283 Mtetra
0 0 .288 r
.36947 .59283 .36966 .61235 .37117 .61589 .37021 .61333 Mtetra
.026 .177 .685 r
.37021 .61333 .37117 .61589 .37281 .6167 .37179 .61529 Mtetra
.585 .652 .883 r
.37179 .61529 .37281 .6167 .3745 .61615 .37348 .61506 Mtetra
.705 .748 .885 r
.37348 .61506 .3745 .61615 .37622 .61518 .37519 .61427 Mtetra
.707 .784 .912 r
.37519 .61427 .37622 .61518 .37794 .61429 .3769 .6135 Mtetra
.646 .795 .954 r
.3769 .6135 .37794 .61429 .37964 .61372 .3786 .61297 Mtetra
.649 .807 .959 r
.3786 .61297 .37964 .61372 .38134 .61322 .3803 .61243 Mtetra
.654 .799 .952 r
.3803 .61243 .38134 .61322 .38304 .61282 .38201 .61187 Mtetra
.659 .763 .927 r
.38201 .61187 .38304 .61282 .38473 .61253 .38372 .61131 Mtetra
.657 .711 .888 r
.38372 .61131 .38473 .61253 .38643 .61224 .38542 .61076 Mtetra
.595 .645 .87 r
.38542 .61076 .38643 .61224 .38812 .61204 .38712 .61049 Mtetra
.561 .619 .868 r
.38712 .61049 .38812 .61204 .38982 .61183 .38881 .61037 Mtetra
.67 .678 .849 r
.38881 .61037 .38982 .61183 .39153 .61122 .39053 .60972 Mtetra
.836 .717 .733 r
.39053 .60972 .39153 .61122 .39329 .60934 .39232 .60707 Mtetra
.92 .69 .573 r
.39232 .60707 .39329 .60934 .39517 .60451 .39453 .59332 Mtetra
.941 .676 .506 r
.39453 .59332 .39517 .60451 .40417 .40876 .40354 .39883 Mtetra
.648 .446 .596 r
.40354 .39883 .40417 .40876 .40603 .40156 .40525 .39576 Mtetra
.602 .44 .635 r
.40525 .39576 .40603 .40156 .40765 .40091 .40687 .39499 Mtetra
.57 .416 .633 r
.40687 .39499 .40765 .40091 .40924 .40086 .40847 .39475 Mtetra
.568 .412 .63 r
.40847 .39475 .40924 .40086 .41089 .39947 .41007 .39452 Mtetra
.595 .448 .651 r
.41007 .39452 .41089 .39947 .41258 .39674 .41168 .39397 Mtetra
.624 .531 .729 r
.41168 .39397 .41258 .39674 .41424 .39466 .4133 .39342 Mtetra
.657 .696 .875 r
.4133 .39342 .41424 .39466 .41588 .3934 .41491 .3929 Mtetra
.623 .853 .986 r
.41491 .3929 .41588 .3934 .4175 .39291 .41653 .39239 Mtetra
.627 .849 .984 r
.41653 .39239 .4175 .39291 .41911 .39264 .41814 .39188 Mtetra
.657 .797 .95 r
.41814 .39188 .41911 .39264 .42072 .39234 .41976 .39134 Mtetra
.671 .747 .908 r
.41976 .39134 .42072 .39234 .42233 .39182 .42138 .39076 Mtetra
.671 .734 .897 r
.42138 .39076 .42233 .39182 .42395 .39124 .42301 .39018 Mtetra
.667 .731 .898 r
.42301 .39018 .42395 .39124 .42558 .39058 .42463 .38961 Mtetra
.659 .748 .916 r
.42463 .38961 .42558 .39058 .42721 .38984 .42625 .38908 Mtetra
.652 .796 .951 r
.42625 .38908 .42721 .38984 .42883 .3891 .42787 .38856 Mtetra
.696 .86 .96 r
.42787 .38856 .42883 .3891 .43047 .3883 .4295 .38785 Mtetra
.753 .89 .94 r
.4295 .38785 .43047 .3883 .4321 .38746 .43114 .38691 Mtetra
.62 .842 .985 r
.43114 .38691 .4321 .38746 .43372 .38695 .43276 .38642 Mtetra
.41 0 0 r
.43276 .38642 .43372 .38695 .43532 .38741 .43435 .3874 Mtetra
.932 .599 .382 r
.43435 .3874 .43532 .38741 .43685 .39048 .43572 .39615 Mtetra
.949 .675 .484 r
.43572 .39615 .43685 .39048 .43326 .58384 .43195 .59401 Mtetra
.622 .351 .486 r
.43195 .59401 .43326 .58384 .43475 .59264 .4336 .59685 Mtetra
.503 .192 .372 r
.4336 .59685 .43475 .59264 .43647 .59246 .43533 .59672 Mtetra
.442 .137 .352 r
.43533 .59672 .43647 .59246 .43822 .59157 .43707 .59596 Mtetra
.433 .132 .353 r
.43707 .59596 .43822 .59157 .43994 .59162 .43882 .5951 Mtetra
.454 .129 .324 r
.43882 .5951 .43994 .59162 .44162 .59342 .44056 .59464 Mtetra
.254 0 0 r
.44056 .59464 .44162 .59342 .44332 .59465 .4423 .59417 Mtetra
.597 .861 .993 r
.4423 .59417 .44332 .59465 .44503 .5952 .44404 .59366 Mtetra
.653 .663 .847 r
.44404 .59366 .44503 .5952 .44677 .595 .44579 .59308 Mtetra
.647 .617 .805 r
.44579 .59308 .44677 .595 .44851 .59456 .44753 .59249 Mtetra
.623 .59 .796 r
.44753 .59249 .44851 .59456 .45026 .59406 .44928 .59204 Mtetra
.568 .567 .813 r
.44928 .59204 .45026 .59406 .452 .5937 .45102 .59192 Mtetra
.647 .632 .822 r
.45102 .59192 .452 .5937 .45376 .59299 .45277 .59136 Mtetra
.791 .7 .764 r
.45277 .59136 .45376 .59299 .45553 .59143 .45454 .58946 Mtetra
.91 .7 .607 r
.45454 .58946 .45553 .59143 .45735 .58731 .45645 .58145 Mtetra
.954 .684 .485 r
.45645 .58145 .45735 .58731 .45939 .57143 .46212 .38031 Mtetra
.553 .334 .536 r
.46212 .38031 .45939 .57143 .46468 .38203 .46384 .37611 Mtetra
.612 .446 .633 r
.46384 .37611 .46468 .38203 .46635 .38065 .4655 .37511 Mtetra
.58 .429 .641 r
.4655 .37511 .46635 .38065 .46799 .38043 .46714 .37473 Mtetra
.565 .416 .638 r
.46714 .37473 .46799 .38043 .46962 .38074 .46878 .37456 Mtetra
.584 .423 .63 r
.46878 .37456 .46962 .38074 .47127 .38073 .47043 .37405 Mtetra
.581 .416 .623 r
.47043 .37405 .47127 .38073 .47292 .38028 .47208 .37355 Mtetra
.582 .416 .623 r
.47208 .37355 .47292 .38028 .47459 .37866 .47373 .37302 Mtetra
.592 .436 .639 r
.47373 .37302 .47459 .37866 .47628 .37567 .47538 .37243 Mtetra
.62 .509 .706 r
.47538 .37243 .47628 .37567 .47796 .37337 .47703 .37183 Mtetra
.659 .655 .835 r
.47703 .37183 .47796 .37337 .47962 .37175 .47869 .37124 Mtetra
.63 .859 .985 r
.47869 .37124 .47962 .37175 .48128 .37104 .48034 .3707 Mtetra
.59 .889 .99 r
.48034 .3707 .48128 .37104 .48294 .37055 .482 .37016 Mtetra
.604 .883 .991 r
.482 .37016 .48294 .37055 .48459 .37014 .48366 .36962 Mtetra
.639 .861 .983 r
.48366 .36962 .48459 .37014 .48625 .36958 .48531 .36906 Mtetra
.642 .861 .982 r
.48531 .36906 .48625 .36958 .4879 .36902 .48697 .36849 Mtetra
.644 .859 .981 r
.48697 .36849 .4879 .36902 .48956 .36845 .48863 .36791 Mtetra
.645 .857 .98 r
.48863 .36791 .48956 .36845 .49122 .36788 .49029 .36734 Mtetra
.645 .855 .98 r
.49029 .36734 .49122 .36788 .49289 .36732 .49196 .36676 Mtetra
.646 .853 .979 r
.49196 .36676 .49289 .36732 .49455 .36675 .49362 .36619 Mtetra
.645 .852 .979 r
.49362 .36619 .49455 .36675 .49621 .36618 .49528 .36562 Mtetra
.645 .851 .979 r
.49528 .36562 .49621 .36618 .49788 .36562 .49695 .36505 Mtetra
.644 .851 .979 r
.49695 .36505 .49788 .36562 .49954 .36505 .49862 .36448 Mtetra
.644 .85 .979 r
.49862 .36448 .49954 .36505 .50121 .36449 .50028 .36392 Mtetra
.50028 .36392 .50121 .36449 .50287 .36392 .50195 .36335 Mtetra
.643 .85 .979 r
.50195 .36335 .50287 .36392 .50454 .36335 .50362 .36279 Mtetra
.643 .851 .979 r
.50362 .36279 .50454 .36335 .50621 .36279 .50529 .36222 Mtetra
.643 .851 .98 r
.50529 .36222 .50621 .36279 .50788 .36222 .50696 .36166 Mtetra
.643 .852 .98 r
.50696 .36166 .50788 .36222 .50955 .36165 .50863 .36109 Mtetra
.642 .853 .98 r
.50863 .36109 .50955 .36165 .51123 .36107 .51031 .36052 Mtetra
.642 .855 .981 r
.51031 .36052 .51123 .36107 .5129 .36049 .51198 .35995 Mtetra
.643 .857 .981 r
.51198 .35995 .5129 .36049 .51457 .35991 .51366 .35937 Mtetra
.647 .861 .981 r
.51366 .35937 .51457 .35991 .51625 .35918 .51533 .35878 Mtetra
.622 .888 .988 r
.51533 .35878 .51625 .35918 .51793 .35858 .51701 .3582 Mtetra
.614 .889 .989 r
.51701 .3582 .51793 .35858 .5196 .35825 .51869 .35762 Mtetra
.636 .834 .977 r
.51869 .35762 .5196 .35825 .52128 .35892 .52037 .35709 Mtetra
.64 .614 .807 r
.52037 .35709 .52128 .35892 .52296 .36019 .52205 .35656 Mtetra
.608 .489 .691 r
.52205 .35656 .52296 .36019 .52464 .36211 .52373 .35602 Mtetra
.59 .429 .632 r
.52373 .35602 .52464 .36211 .52633 .36213 .52541 .35541 Mtetra
.586 .42 .623 r
.52541 .35541 .52633 .36213 .52801 .36135 .5271 .35479 Mtetra
.587 .422 .625 r
.5271 .35479 .52801 .36135 .5297 .36022 .52878 .35417 Mtetra
.611 .445 .632 r
.52878 .35417 .5297 .36022 .53138 .35879 .53047 .35316 Mtetra
.596 .439 .639 r
.53047 .35316 .53138 .35879 .53307 .35805 .53215 .35249 Mtetra
.553 .411 .642 r
.53215 .35249 .53307 .35805 .53476 .35859 .53384 .35252 Mtetra
.155 .124 .569 r
.53384 .35252 .53476 .35859 .53717 .55478 .53555 .35679 Mtetra
0 0 .349 r
.53555 .35679 .53717 .55478 .53901 .56361 .53803 .55911 Mtetra
0 0 .459 r
.53803 .55911 .53901 .56361 .54082 .56626 .53985 .56445 Mtetra
.479 .547 .849 r
.53985 .56445 .54082 .56626 .54263 .56641 .54166 .56471 Mtetra
.653 .648 .832 r
.54166 .56471 .54263 .56641 .54444 .56597 .54347 .5641 Mtetra
.701 .65 .796 r
.54347 .5641 .54444 .56597 .54625 .56522 .54528 .56308 Mtetra
.628 .591 .793 r
.54528 .56308 .54625 .56522 .54806 .5647 .54709 .56257 Mtetra
.624 .59 .795 r
.54709 .56257 .54806 .5647 .54987 .56403 .5489 .56209 Mtetra
.631 .612 .813 r
.5489 .56209 .54987 .56403 .55168 .5631 .55071 .56159 Mtetra
.652 .675 .859 r
.55071 .56159 .55168 .5631 .55348 .56124 .55252 .56101 Mtetra
.551 .903 .972 r
.55252 .56101 .55348 .56124 .55527 .55875 .55434 .5604 Mtetra
.3 0 .075 r
.55434 .5604 .55527 .55875 .55706 .55563 .55615 .55979 Mtetra
.506 .192 .369 r
.55615 .55979 .55706 .55563 .55888 .55509 .55797 .5597 Mtetra
.487 .184 .378 r
.55797 .5597 .55888 .55509 .56069 .55491 .55979 .55932 Mtetra
.415 .118 .349 r
.55979 .55932 .56069 .55491 .5625 .55378 .56161 .55823 Mtetra
0 0 .121 r
.56161 .55823 .5625 .55378 .56205 .3592 .56338 .55315 Mtetra
0 0 .341 r
.56338 .55315 .56205 .3592 .56362 .3466 .56277 .34968 Mtetra
.791 .762 .25 r
.56277 .34968 .56362 .3466 .56529 .34299 .5644 .34275 Mtetra
.86 .948 .872 r
.5644 .34275 .56529 .34299 .56699 .3419 .5661 .34115 Mtetra
.669 .814 .953 r
.5661 .34115 .56699 .3419 .5687 .3415 .56781 .34053 Mtetra
.559 .722 .95 r
.56781 .34053 .5687 .3415 .57041 .34136 .56952 .34031 Mtetra
.642 .738 .918 r
.56952 .34031 .57041 .34136 .57212 .34078 .57123 .33982 Mtetra
.652 .76 .929 r
.57123 .33982 .57212 .34078 .57383 .34008 .57294 .33928 Mtetra
.646 .797 .955 r
.57294 .33928 .57383 .34008 .57554 .33937 .57466 .33875 Mtetra
.654 .845 .974 r
.57466 .33875 .57554 .33937 .57725 .33859 .57637 .33815 Mtetra
.634 .886 .987 r
.57637 .33815 .57725 .33859 .57896 .33792 .57809 .33753 Mtetra
.617 .894 .988 r
.57809 .33753 .57896 .33792 .58068 .33748 .5798 .33692 Mtetra
.743 .881 .943 r
.5798 .33692 .58068 .33748 .58241 .33761 .58151 .33599 Mtetra
.673 .656 .824 r
.58151 .33599 .58241 .33761 .58415 .33843 .58323 .33527 Mtetra
.567 .482 .719 r
.58323 .33527 .58415 .33843 .58593 .34066 .58495 .33518 Mtetra
.255 .208 .61 r
.58495 .33518 .58593 .34066 .59155 .53685 .58675 .33839 Mtetra
0 0 .372 r
.58675 .33839 .59155 .53685 .5936 .54693 .59255 .54063 Mtetra
0 0 .476 r
.59255 .54063 .5936 .54693 .59551 .54957 .59454 .54746 Mtetra
.357 .443 .813 r
.59454 .54746 .59551 .54957 .59737 .54997 .59641 .54831 Mtetra
.624 .642 .848 r
.59641 .54831 .59737 .54997 .59921 .54949 .59826 .54786 Mtetra
.698 .68 .829 r
.59826 .54786 .59921 .54949 .60105 .54846 .6001 .54695 Mtetra
.671 .685 .854 r
.6001 .54695 .60105 .54846 .60287 .54673 .60194 .54625 Mtetra
.621 .881 .989 r
.60194 .54625 .60287 .54673 .60467 .54433 .60378 .54562 Mtetra
.225 0 0 r
.60378 .54562 .60467 .54433 .60645 .54126 .60563 .54498 Mtetra
.492 .169 .346 r
.60563 .54498 .60645 .54126 .60829 .54019 .60749 .5448 Mtetra
.492 .188 .379 r
.60749 .5448 .60829 .54019 .61014 .54005 .60935 .54448 Mtetra
.431 .132 .356 r
.60935 .54448 .61014 .54005 .61198 .53913 .61119 .54352 Mtetra
0 0 .205 r
.61119 .54352 .61198 .53913 .61351 .52627 .61295 .53937 Mtetra
.983 .703 .398 r
.61295 .53937 .61351 .52627 .61011 .33165 .6094 .33678 Mtetra
0 0 0 r
.6094 .33678 .61011 .33165 .61175 .3276 .6109 .32756 Mtetra
.907 .969 .806 r
.6109 .32756 .61175 .3276 .61346 .32619 .6126 .32547 Mtetra
.691 .836 .953 r
.6126 .32547 .61346 .32619 .6152 .3257 .61433 .32475 Mtetra
.576 .738 .952 r
.61433 .32475 .6152 .3257 .61695 .32551 .61608 .32447 Mtetra
.638 .741 .923 r
.61608 .32447 .61695 .32551 .61869 .32486 .61782 .32399 Mtetra
.665 .789 .941 r
.61782 .32399 .61869 .32486 .62042 .32404 .61956 .32338 Mtetra
.645 .838 .974 r
.61956 .32338 .62042 .32404 .62216 .32342 .6213 .3228 Mtetra
.729 .869 .947 r
.6213 .3228 .62216 .32342 .62392 .32338 .62303 .32192 Mtetra
.689 .687 .843 r
.62303 .32192 .62392 .32338 .6257 .32404 .62477 .32114 Mtetra
.582 .505 .734 r
.62477 .32114 .6257 .32404 .62752 .3259 .62653 .32092 Mtetra
.327 .269 .639 r
.62653 .32092 .62752 .3259 .62991 .34447 .62837 .32333 Mtetra
.983 .698 .346 r
.62837 .32333 .62991 .34447 .63804 .53274 .63685 .52394 Mtetra
0 0 .459 r
.63685 .52394 .63804 .53274 .64003 .53581 .63906 .53346 Mtetra
.261 .36 .776 r
.63906 .53346 .64003 .53581 .64194 .53638 .641 .53482 Mtetra
.603 .649 .869 r
.641 .53482 .64194 .53638 .64381 .53585 .64288 .53448 Mtetra
.7 .72 .865 r
.64288 .53448 .64381 .53585 .64567 .53475 .64474 .53362 Mtetra
.616 .732 .928 r
.64474 .53362 .64567 .53475 .64751 .53336 .64662 .53319 Mtetra
.357 .818 .923 r
.64662 .53319 .64751 .53336 .64934 .5315 .64851 .53283 Mtetra
.121 0 0 r
.64851 .53283 .64934 .5315 .65112 .52848 .65037 .53185 Mtetra
0 0 .129 r
.65037 .53185 .65112 .52848 .65256 .51647 .65213 .52823 Mtetra
.983 .699 .383 r
.65213 .52823 .65256 .51647 .64681 .31943 .64633 .32821 Mtetra
0 0 .173 r
.64633 .32821 .64681 .31943 .64843 .31539 .64762 .3156 Mtetra
.92 .978 .734 r
.64762 .3156 .64843 .31539 .65015 .31381 .64931 .31312 Mtetra
.703 .848 .952 r
.64931 .31312 .65015 .31381 .65191 .3133 .65106 .31234 Mtetra
.579 .738 .951 r
.65106 .31234 .65191 .3133 .65369 .31315 .65283 .31204 Mtetra
.614 .721 .922 r
.65283 .31204 .65369 .31315 .65546 .31283 .6546 .31165 Mtetra
.656 .724 .899 r
.6546 .31165 .65546 .31283 .65723 .31226 .65637 .31109 Mtetra
.654 .724 .9 r
.65637 .31109 .65723 .31226 .65899 .31164 .65814 .31053 Mtetra
.719 .761 .885 r
.65814 .31053 .65899 .31164 .66074 .3106 .65989 .30965 Mtetra
.729 .795 .904 r
.65989 .30965 .66074 .3106 .66248 .30953 .66164 .30874 Mtetra
.586 .785 .975 r
.66164 .30874 .66248 .30953 .66425 .30904 .66342 .30837 Mtetra
.577 .051 0 r
.66342 .30837 .66425 .30904 .66613 .31093 .6653 .31026 Mtetra
.974 .677 .389 r
.6653 .31026 .66613 .31093 .67705 .51078 .67608 .50808 Mtetra
.929 .596 .146 r
.67608 .50808 .67705 .51078 .67953 .52301 .6786 .52125 Mtetra
0 .25 .758 r
.6786 .52125 .67953 .52301 .68154 .52473 .6806 .52302 Mtetra
.596 .629 .854 r
.6806 .52302 .68154 .52473 .68344 .5243 .68252 .52272 Mtetra
.692 .689 .842 r
.68252 .52272 .68344 .5243 .68532 .52313 .6844 .52186 Mtetra
.65 .721 .9 r
.6844 .52186 .68532 .52313 .68717 .52163 .68631 .52128 Mtetra
.431 .833 .978 r
.68631 .52128 .68717 .52163 .68901 .51982 .68822 .52094 Mtetra
.087 0 0 r
.68822 .52094 .68901 .51982 .6908 .51691 .69011 .52003 Mtetra
0 0 .144 r
.69011 .52003 .6908 .51691 .69227 .50771 .69189 .51688 Mtetra
0 0 0 r
.69189 .51688 .69227 .50771 .68401 .30734 .69278 .49626 Mtetra
0 0 .4 r
.69278 .49626 .68401 .30734 .6856 .30296 .68484 .30341 Mtetra
.915 .962 .644 r
.68484 .30341 .6856 .30296 .68732 .30111 .6865 .30047 Mtetra
.728 .871 .948 r
.6865 .30047 .68732 .30111 .6891 .3005 .68827 .29957 Mtetra
.602 .758 .953 r
.68827 .29957 .6891 .3005 .6909 .30025 .69006 .29918 Mtetra
.667 .753 .915 r
.69006 .29918 .6909 .30025 .69268 .29959 .69185 .29856 Mtetra
.727 .781 .895 r
.69185 .29856 .69268 .29959 .69444 .29854 .69362 .29765 Mtetra
.607 .771 .959 r
.69362 .29765 .69444 .29854 .69623 .29798 .69541 .29723 Mtetra
0 .169 .645 r
.69541 .29723 .69623 .29798 .69813 .29935 .69731 .29863 Mtetra
.948 .59 .239 r
.69731 .29863 .69813 .29935 .7007 .3127 .69977 .31 Mtetra
.976 .676 .367 r
.69977 .31 .7007 .3127 .71383 .51193 .71289 .51006 Mtetra
0 .133 .68 r
.71289 .51006 .71383 .51193 .7159 .51412 .71498 .51242 Mtetra
.58 .623 .859 r
.71498 .51242 .7159 .51412 .71783 .51367 .71692 .51219 Mtetra
.69 .705 .859 r
.71692 .51219 .71783 .51367 .71973 .5126 .71883 .51136 Mtetra
.659 .732 .904 r
.71883 .51136 .71973 .5126 .72165 .5119 .72076 .51073 Mtetra
.554 .7 .937 r
.72076 .51073 .72165 .5119 .7236 .51187 .7227 .51053 Mtetra
.681 .723 .882 r
.7227 .51053 .7236 .51187 .72553 .51128 .72462 .50977 Mtetra
.858 .752 .745 r
.72462 .50977 .72553 .51128 .72734 .50867 .72643 .50711 Mtetra
.968 .726 .518 r
.72643 .50711 .72734 .50867 .72851 .49572 .72766 .49516 Mtetra
.977 .682 .38 r
.72766 .49516 .72851 .49572 .71794 .29349 .71715 .29304 Mtetra
.963 .873 .7 r
.71715 .29304 .71794 .29349 .71958 .29025 .71878 .28966 Mtetra
.724 .889 .956 r
.71878 .28966 .71958 .29025 .72137 .28954 .72056 .28876 Mtetra
.571 .786 .98 r
.72056 .28876 .72137 .28954 .72321 .28942 .72239 .28841 Mtetra
.575 .731 .948 r
.72239 .28841 .72321 .28942 .72504 .28931 .72421 .28812 Mtetra
.659 .727 .9 r
.72421 .28812 .72504 .28931 .72685 .28874 .72602 .28753 Mtetra
.66 .725 .898 r
.72602 .28753 .72685 .28874 .72866 .28811 .72783 .28694 Mtetra
.705 .749 .886 r
.72783 .28694 .72866 .28811 .73045 .28725 .72963 .28611 Mtetra
.746 .769 .872 r
.72963 .28611 .73045 .28725 .73223 .28617 .73141 .28504 Mtetra
.66 .741 .91 r
.73141 .28504 .73223 .28617 .73404 .28557 .73322 .28445 Mtetra
.116 .438 .876 r
.73322 .28445 .73404 .28557 .73596 .28648 .73514 .28537 Mtetra
.909 .525 .098 r
.73514 .28537 .73596 .28648 .73835 .29435 .73754 .2933 Mtetra
.975 .671 .352 r
.73754 .2933 .73835 .29435 .7543 .49827 .75344 .4972 Mtetra
.602 .138 0 r
.75344 .4972 .7543 .49827 .7565 .50121 .75563 .50013 Mtetra
.552 .721 .952 r
.75563 .50013 .7565 .50121 .75847 .50099 .7576 .4999 Mtetra
.711 .784 .909 r
.7576 .4999 .75847 .50099 .7604 .5001 .75953 .49901 Mtetra
.694 .777 .915 r
.75953 .49901 .7604 .5001 .76234 .4993 .76147 .4982 Mtetra
.513 .697 .953 r
.76147 .4982 .76234 .4993 .76433 .49921 .76346 .49811 Mtetra
.653 .759 .927 r
.76346 .49811 .76433 .49921 .76628 .49861 .76541 .49749 Mtetra
.864 .811 .795 r
.76541 .49749 .76628 .49861 .76812 .4964 .76725 .49527 Mtetra
.979 .75 .522 r
.76725 .49527 .76812 .4964 .7694 .48664 .76852 .48535 Mtetra
.977 .678 .362 r
.76852 .48535 .7694 .48664 .75613 .28169 .75531 .28051 Mtetra
.931 .784 .676 r
.75531 .28051 .75613 .28169 .75771 .27781 .75689 .27665 Mtetra
.727 .762 .88 r
.75689 .27665 .75771 .27781 .75951 .27685 .7587 .27569 Mtetra
.603 .713 .922 r
.7587 .27569 .75951 .27685 .76136 .27649 .76055 .27533 Mtetra
.602 .713 .922 r
.76055 .27533 .76136 .27649 .76321 .27613 .7624 .27498 Mtetra
.74 .767 .875 r
.7624 .27498 .76321 .27613 .76501 .2751 .7642 .27394 Mtetra
.657 .738 .909 r
.7642 .27394 .76501 .2751 .76684 .2745 .76603 .27335 Mtetra
.237 .511 .908 r
.76603 .27335 .76684 .2745 .76878 .27519 .76797 .27404 Mtetra
.882 .489 .033 r
.76797 .27404 .76878 .27519 .77123 .28239 .77042 .28125 Mtetra
.975 .667 .334 r
.77042 .28125 .77123 .28239 .78952 .48754 .78867 .48646 Mtetra
.659 .204 0 r
.78867 .48646 .78952 .48754 .79182 .49101 .79097 .48993 Mtetra
.383 .633 .953 r
.79097 .48993 .79182 .49101 .79386 .49129 .79301 .49019 Mtetra
.695 .781 .917 r
.79301 .49019 .79386 .49129 .79582 .49045 .79497 .48937 Mtetra
.876 .821 .79 r
.79497 .48937 .79582 .49045 .79765 .48804 .79681 .48704 Mtetra
.981 .769 .543 r
.79681 .48704 .79765 .48804 .79891 .47889 .79816 .47893 Mtetra
.977 .676 .344 r
.79816 .47893 .79891 .47889 .78366 .27232 .78292 .27188 Mtetra
.985 .852 .625 r
.78292 .27188 .78366 .27232 .78521 .26815 .78445 .26742 Mtetra
.755 .867 .93 r
.78445 .26742 .78521 .26815 .78703 .26725 .78626 .26637 Mtetra
.594 .777 .967 r
.78626 .26637 .78703 .26725 .78891 .26698 .78812 .26597 Mtetra
.565 .729 .952 r
.78812 .26597 .78891 .26698 .7908 .26688 .79 .26571 Mtetra
.739 .767 .876 r
.79 .26571 .7908 .26688 .79263 .26599 .79182 .26468 Mtetra
.661 .71 .884 r
.79182 .26468 .79263 .26599 .79448 .26536 .79367 .26405 Mtetra
.379 .565 .908 r
.79367 .26405 .79448 .26536 .79639 .26542 .79561 .26449 Mtetra
.854 .439 0 r
.79561 .26449 .79639 .26542 .7985 .2678 .79805 .27046 Mtetra
.973 .661 .332 r
.79805 .27046 .7985 .2678 .80157 .28074 .8183 .47669 Mtetra
.55 .326 .529 r
.8183 .47669 .80157 .28074 .82107 .47659 .8207 .48063 Mtetra
.51 .189 .358 r
.8207 .48063 .82107 .47659 .82332 .47887 .82275 .48061 Mtetra
.306 0 .103 r
.82275 .48061 .82332 .47887 .82545 .47975 .82473 .47987 Mtetra
.462 .885 .796 r
.82473 .47987 .82545 .47975 .82753 .48 .82669 .47891 Mtetra
.509 .701 .956 r
.82669 .47891 .82753 .48 .82959 .48008 .82874 .47881 Mtetra
.637 .726 .912 r
.82874 .47881 .82959 .48008 .83159 .47949 .83075 .47826 Mtetra
.802 .792 .843 r
.83075 .47826 .83159 .47949 .83348 .47777 .83266 .47667 Mtetra
.978 .778 .566 r
.83266 .47667 .83348 .47777 .83489 .47078 .83406 .46974 Mtetra
.976 .671 .329 r
.83406 .46974 .83489 .47078 .81722 .26263 .81644 .26155 Mtetra
.967 .788 .609 r
.81644 .26155 .81722 .26263 .81865 .25743 .81787 .25631 Mtetra
.759 .785 .875 r
.81787 .25631 .81865 .25743 .82047 .25629 .81969 .25516 Mtetra
.624 .731 .924 r
.81969 .25516 .82047 .25629 .82235 .25584 .82157 .2547 Mtetra
.551 .694 .934 r
.82157 .2547 .82235 .25584 .82427 .25567 .82349 .25451 Mtetra
.749 .775 .875 r
.82349 .25451 .82427 .25567 .82609 .25458 .82531 .25342 Mtetra
.677 .749 .905 r
.82531 .25342 .82609 .25458 .82796 .25389 .82718 .25272 Mtetra
.451 .635 .934 r
.82718 .25272 .82796 .25389 .82991 .25409 .82913 .25287 Mtetra
.774 .364 0 r
.82913 .25287 .82991 .25409 .83246 .26025 .83161 .25829 Mtetra
.971 .658 .295 r
.83161 .25829 .83246 .26025 .85522 .46753 .85432 .46558 Mtetra
0 0 .443 r
.85432 .46558 .85522 .46753 .85771 .47163 .85684 .47003 Mtetra
.41 .551 .886 r
.85684 .47003 .85771 .47163 .85982 .47192 .85897 .4705 Mtetra
.655 .709 .887 r
.85897 .4705 .85982 .47192 .86182 .47114 .86099 .46986 Mtetra
.821 .791 .824 r
.86099 .46986 .86182 .47114 .86371 .46919 .86289 .46805 Mtetra
.976 .786 .584 r
.86289 .46805 .86371 .46919 .86514 .46289 .86434 .46185 Mtetra
.974 .667 .312 r
.86434 .46185 .86514 .46289 .84545 .25395 .84469 .2529 Mtetra
.979 .784 .573 r
.84469 .2529 .84545 .25395 .84678 .24797 .84601 .24684 Mtetra
.768 .766 .851 r
.23878 .45119 .2398 .45209 .24136 .45096 .24034 .45009 Mtetra
.634 .753 .933 r
.24034 .45009 .24136 .45096 .24287 .45052 .24185 .44968 Mtetra
.5 .714 .967 r
.24185 .44968 .24287 .45052 .24435 .45047 .24332 .44961 Mtetra
.753 .775 .871 r
.24332 .44961 .24435 .45047 .24589 .4496 .24488 .44864 Mtetra
.71 .751 .883 r
.24488 .44864 .24589 .4496 .24741 .44906 .24641 .44791 Mtetra
.596 .681 .9 r
.24641 .44791 .24741 .44906 .24888 .44918 .24791 .44766 Mtetra
.604 .185 0 r
.24791 .44766 .24888 .44918 .24998 .45356 .24921 .44973 Mtetra
.921 .635 .151 r
.24921 .44973 .24998 .45356 .23503 .65047 .25007 .4571 Mtetra
0 0 .191 r
.25007 .4571 .23503 .65047 .23618 .65549 .23555 .64916 Mtetra
.522 .378 .627 r
.23555 .64916 .23618 .65549 .23773 .65576 .23708 .64963 Mtetra
.603 .44 .634 r
.23708 .64963 .23773 .65576 .23935 .65518 .23872 .64881 Mtetra
.605 .439 .631 r
.23872 .64881 .23935 .65518 .24101 .6542 .24036 .64792 Mtetra
.386 .28 .61 r
.24036 .64792 .24101 .6542 .24262 .65371 .24178 .6499 Mtetra
.323 .295 .672 r
.24178 .6499 .24262 .65371 .24424 .65326 .24323 .65143 Mtetra
.236 .397 .821 r
.24323 .65143 .24424 .65326 .24585 .65281 .24474 .65232 Mtetra
.453 .796 .998 r
.24474 .65232 .24585 .65281 .24747 .65232 .24633 .65214 Mtetra
.547 .895 .978 r
.24633 .65214 .24747 .65232 .24909 .65182 .24795 .65163 Mtetra
.628 .918 .978 r
.24795 .65163 .24909 .65182 .25071 .65132 .24959 .65097 Mtetra
.6 .88 .992 r
.24959 .65097 .25071 .65132 .25233 .65085 .25121 .65045 Mtetra
.595 .867 .994 r
.25121 .65045 .25233 .65085 .25395 .6504 .25284 .64997 Mtetra
.583 .858 .995 r
.25284 .64997 .25395 .6504 .25558 .64993 .25446 .64953 Mtetra
.516 .84 .999 r
.25446 .64953 .25558 .64993 .2572 .64942 .25607 .64919 Mtetra
.424 .837 .969 r
.25607 .64919 .2572 .64942 .25883 .64889 .25768 .64889 Mtetra
.308 .797 .875 r
.25768 .64889 .25883 .64889 .26046 .64838 .2593 .64857 Mtetra
.251 .762 .773 r
.2593 .64857 .26046 .64838 .26209 .6479 .26092 .64815 Mtetra
.257 .764 .749 r
.26092 .64815 .26209 .6479 .26371 .64744 .26255 .64768 Mtetra
.307 .797 .779 r
.26255 .64768 .26371 .64744 .26534 .64699 .26418 .64717 Mtetra
.412 .862 .848 r
.26418 .64717 .26534 .64699 .26697 .64653 .26582 .64658 Mtetra
.511 .908 .921 r
.26582 .64658 .26697 .64653 .2686 .64606 .26747 .64595 Mtetra
.58 .919 .967 r
.26747 .64595 .2686 .64606 .27023 .64557 .26911 .64533 Mtetra
.399 .821 .967 r
.26911 .64533 .27023 .64557 .27184 .64549 .27073 .64507 Mtetra
.544 .847 .998 r
.27073 .64507 .27184 .64549 .27346 .64517 .27236 .64469 Mtetra
.72 .872 .953 r
.27236 .64469 .27346 .64517 .27513 .64419 .27402 .64388 Mtetra
.914 .838 .756 r
.27402 .64388 .27513 .64419 .27706 .63969 .27582 .64101 Mtetra
.991 .85 .603 r
.27582 .64101 .27706 .63969 .29275 .44153 .27791 .63431 Mtetra
0 0 .198 r
.27791 .63431 .29275 .44153 .29478 .43414 .29338 .43894 Mtetra
.137 0 .244 r
.29338 .43894 .29478 .43414 .29641 .43244 .29509 .43602 Mtetra
.443 .127 .334 r
.29509 .43602 .29641 .43244 .29796 .43189 .29664 .43546 Mtetra
.538 .219 .375 r
.29664 .43546 .29796 .43189 .29948 .43176 .29814 .4357 Mtetra
.534 .223 .387 r
.29814 .4357 .29948 .43176 .30102 .43139 .29964 .43589 Mtetra
.505 .206 .392 r
.29964 .43589 .30102 .43139 .30256 .43092 .30117 .43573 Mtetra
.435 .146 .373 r
.30117 .43573 .30256 .43092 .30411 .43045 .30275 .43481 Mtetra
.111 0 .217 r
.30275 .43481 .30411 .43045 .30566 .42991 .30446 .43202 Mtetra
0 0 0 r
.30446 .43202 .30566 .42991 .30721 .42933 .30615 .42948 Mtetra
.899 .954 .827 r
.30615 .42948 .30721 .42933 .30877 .42876 .30779 .42757 Mtetra
.734 .719 .837 r
.30779 .42757 .30877 .42876 .31032 .42823 .30937 .42661 Mtetra
.65 .631 .818 r
.30937 .42661 .31032 .42823 .31188 .42773 .31093 .42608 Mtetra
.622 .615 .823 r
.31093 .42608 .31188 .42773 .31343 .42723 .31247 .4257 Mtetra
.643 .64 .832 r
.31247 .4257 .31343 .42723 .31499 .42672 .31403 .42523 Mtetra
.653 .649 .834 r
.31403 .42523 .31499 .42672 .31654 .42619 .31559 .4247 Mtetra
.649 .649 .837 r
.31559 .4247 .31654 .42619 .3181 .42565 .31714 .4242 Mtetra
.633 .648 .847 r
.31714 .4242 .3181 .42565 .31966 .4251 .31869 .42379 Mtetra
.628 .667 .869 r
.31869 .42379 .31966 .4251 .32122 .42454 .32025 .4234 Mtetra
.637 .701 .892 r
.32025 .4234 .32122 .42454 .32279 .42399 .3218 .42298 Mtetra
.679 .739 .896 r
.3218 .42298 .32279 .42399 .32435 .42347 .32337 .42238 Mtetra
.698 .729 .874 r
.32337 .42238 .32435 .42347 .32591 .42296 .32494 .42167 Mtetra
.691 .693 .847 r
.32494 .42167 .32591 .42296 .32747 .42246 .32652 .42096 Mtetra
.702 .668 .814 r
.32652 .42096 .32747 .42246 .32906 .4216 .3281 .42011 Mtetra
.685 .664 .823 r
.3281 .42011 .32906 .4216 .33064 .42081 .32968 .41939 Mtetra
.614 .644 .857 r
.32968 .41939 .33064 .42081 .33218 .42058 .33123 .41906 Mtetra
.059 .323 .805 r
.33123 .41906 .33218 .42058 .33358 .42291 .3327 .42013 Mtetra
0 0 .288 r
.3327 .42013 .33358 .42291 .3237 .61817 .33402 .42391 Mtetra
0 0 .243 r
.33402 .42391 .3237 .61817 .32478 .62774 .32417 .61916 Mtetra
.124 .065 .512 r
.32417 .61916 .32478 .62774 .32634 .62913 .32549 .62474 Mtetra
.353 .299 .657 r
.32549 .62474 .32634 .62913 .328 .62884 .32703 .6264 Mtetra
.415 .438 .776 r
.32703 .6264 .328 .62884 .32969 .62804 .32864 .62706 Mtetra
.486 .693 .96 r
.32864 .62706 .32969 .62804 .33137 .62734 .33028 .62704 Mtetra
.531 .872 .991 r
.33028 .62704 .33137 .62734 .33304 .62677 .33195 .6266 Mtetra
.59 .916 .974 r
.33195 .6266 .33304 .62677 .33472 .62618 .33363 .62597 Mtetra
.438 .848 .967 r
.33363 .62597 .33472 .62618 .33638 .62596 .3353 .62561 Mtetra
.469 .837 .992 r
.3353 .62561 .33638 .62596 .33804 .62575 .33696 .62531 Mtetra
.681 .882 .973 r
.33696 .62531 .33804 .62575 .33973 .62497 .33865 .62459 Mtetra
.888 .869 .813 r
.33865 .62459 .33973 .62497 .34156 .62167 .34042 .62247 Mtetra
.985 .882 .644 r
.34042 .62247 .34156 .62167 .35339 .42875 .34233 .61761 Mtetra
0 0 .226 r
.34233 .61761 .35339 .42875 .35569 .41445 .35429 .42162 Mtetra
0 0 .119 r
.35429 .42162 .35569 .41445 .35738 .41197 .35623 .41425 Mtetra
0 0 0 r
.35623 .41425 .35738 .41197 .35897 .41123 .35792 .41165 Mtetra
.808 1 .812 r
.35792 .41165 .35897 .41123 .36054 .41097 .35956 .41004 Mtetra
.735 .77 .881 r
.35956 .41004 .36054 .41097 .36211 .41066 .36116 .40916 Mtetra
.631 .642 .843 r
.36116 .40916 .36211 .41066 .36369 .41018 .36274 .40875 Mtetra
.59 .635 .864 r
.36274 .40875 .36369 .41018 .36527 .4097 .36431 .40852 Mtetra
.615 .689 .896 r
.36431 .40852 .36527 .4097 .36686 .40916 .36589 .40818 Mtetra
.66 .743 .912 r
.36589 .40818 .36686 .40916 .36845 .40858 .36748 .40766 Mtetra
.675 .76 .915 r
.36748 .40766 .36845 .40858 .37004 .408 .36907 .40707 Mtetra
.732 .772 .885 r
.36907 .40707 .37004 .408 .37165 .40719 .37067 .4062 Mtetra
.741 .761 .869 r
.37067 .4062 .37165 .40719 .37325 .40638 .37228 .40526 Mtetra
.668 .718 .886 r
.37228 .40526 .37325 .40638 .37483 .40608 .37388 .40469 Mtetra
.26 .472 .875 r
.37388 .40469 .37483 .40608 .37632 .40779 .37542 .40535 Mtetra
0 0 .404 r
.37542 .40535 .37632 .40779 .36947 .59283 .37684 .40849 Mtetra
0 0 .245 r
.37684 .40849 .36947 .59283 .37021 .61333 .36961 .60267 Mtetra
.053 .001 .472 r
.36961 .60267 .37021 .61333 .37179 .61529 .37093 .61056 Mtetra
.345 .285 .646 r
.37093 .61056 .37179 .61529 .37348 .61506 .37252 .61244 Mtetra
.408 .421 .762 r
.37252 .61244 .37348 .61506 .37519 .61427 .37416 .61321 Mtetra
.428 .649 .951 r
.37416 .61321 .37519 .61427 .3769 .6135 .37583 .61335 Mtetra
.375 .825 .937 r
.37583 .61335 .3769 .6135 .3786 .61297 .37753 .61302 Mtetra
.535 .921 .913 r
.37753 .61302 .3786 .61297 .3803 .61243 .37924 .61231 Mtetra
.813 .957 .908 r
.37924 .61231 .3803 .61243 .38201 .61187 .38098 .61095 Mtetra
.855 .787 .784 r
.38098 .61095 .38201 .61187 .38372 .61131 .38275 .60876 Mtetra
.79 .637 .691 r
.38275 .60876 .38372 .61131 .38542 .61076 .38455 .60586 Mtetra
.68 .512 .651 r
.38455 .60586 .38542 .61076 .38712 .61049 .38632 .6038 Mtetra
.554 .4 .627 r
.38632 .6038 .38712 .61049 .38881 .61037 .38801 .6038 Mtetra
.581 .421 .629 r
.38801 .6038 .38881 .61037 .39053 .60972 .38971 .60332 Mtetra
.744 .539 .617 r
.38971 .60332 .39053 .60972 .39232 .60707 .3916 .59826 Mtetra
.944 .679 .504 r
.3916 .59826 .39232 .60707 .39453 .59332 .40086 .40139 Mtetra
.555 .335 .537 r
.40086 .40139 .39453 .59332 .40354 .39883 .40264 .39639 Mtetra
.76 .621 .706 r
.40264 .39639 .40354 .39883 .40525 .39576 .40431 .39428 Mtetra
.681 .666 .829 r
.40431 .39428 .40525 .39576 .40687 .39499 .40593 .39357 Mtetra
.61 .648 .862 r
.40593 .39357 .40687 .39499 .40847 .39475 .40753 .39325 Mtetra
.591 .628 .856 r
.40753 .39325 .40847 .39475 .41007 .39452 .40913 .39302 Mtetra
.618 .639 .849 r
.40913 .39302 .41007 .39452 .41168 .39397 .41074 .39267 Mtetra
.616 .669 .878 r
.41074 .39267 .41168 .39397 .4133 .39342 .41235 .39232 Mtetra
.627 .711 .906 r
.41235 .39232 .4133 .39342 .41491 .3929 .41396 .39192 Mtetra
.65 .746 .919 r
.41396 .39192 .41491 .3929 .41653 .39239 .41557 .39143 Mtetra
.666 .752 .915 r
.41557 .39143 .41653 .39239 .41814 .39188 .41719 .39087 Mtetra
.698 .751 .893 r
.41719 .39087 .41814 .39188 .41976 .39134 .41882 .39016 Mtetra
.717 .724 .856 r
.41882 .39016 .41976 .39134 .42138 .39076 .42045 .38931 Mtetra
.677 .67 .836 r
.42045 .38931 .42138 .39076 .42301 .39018 .42207 .38863 Mtetra
.566 .609 .855 r
.42207 .38863 .42301 .39018 .42463 .38961 .42368 .3885 Mtetra
.031 .39 .85 r
.42368 .3885 .42463 .38961 .42625 .38908 .42526 .38937 Mtetra
.732 .246 .087 r
.42526 .38937 .42625 .38908 .42787 .38856 .42682 .39092 Mtetra
.64 .281 .346 r
.42682 .39092 .42787 .38856 .4295 .38785 .42839 .39217 Mtetra
.414 .119 .352 r
.42839 .39217 .4295 .38785 .43114 .38691 .43003 .39114 Mtetra
.453 .152 .364 r
.43003 .39114 .43114 .38691 .43276 .38642 .43167 .39048 Mtetra
.686 .37 .435 r
.43167 .39048 .43276 .38642 .43435 .3874 .43321 .39312 Mtetra
.949 .675 .484 r
.43321 .39312 .43435 .3874 .43572 .39615 .42931 .59006 Mtetra
.552 .329 .53 r
.42931 .59006 .43572 .39615 .43195 .59401 .43089 .59493 Mtetra
.709 .27 .207 r
.43089 .59493 .43195 .59401 .4336 .59685 .43257 .59654 Mtetra
.292 .756 .946 r
.43257 .59654 .4336 .59685 .43533 .59672 .4343 .59644 Mtetra
.559 .891 .986 r
.4343 .59644 .43533 .59672 .43707 .59596 .43604 .59589 Mtetra
.546 .917 .944 r
.43604 .59589 .43707 .59596 .43882 .5951 .43778 .59523 Mtetra
.329 .814 .818 r
.43778 .59523 .43882 .5951 .44056 .59464 .43952 .59471 Mtetra
.504 .909 .894 r
.43952 .59471 .44056 .59464 .4423 .59417 .44127 .59399 Mtetra
.765 .956 .934 r
.44127 .59399 .4423 .59417 .44404 .59366 .44303 .59284 Mtetra
.858 .813 .805 r
.44303 .59284 .44404 .59366 .44579 .59308 .44481 .5908 Mtetra
.794 .654 .707 r
.44481 .5908 .44579 .59308 .44753 .59249 .44661 .58816 Mtetra
.713 .543 .658 r
.44661 .58816 .44753 .59249 .44928 .59204 .4484 .58566 Mtetra
.564 .411 .633 r
.4484 .58566 .44928 .59204 .45102 .59192 .45013 .5855 Mtetra
.577 .42 .632 r
.45013 .5855 .45102 .59192 .45277 .59136 .45188 .58509 Mtetra
.685 .498 .628 r
.45188 .58509 .45277 .59136 .45454 .58946 .45367 .58225 Mtetra
.953 .682 .487 r
.45367 .58225 .45454 .58946 .45645 .58145 .45946 .38374 Mtetra
.557 .337 .537 r
.45946 .38374 .45645 .58145 .46212 .38031 .46123 .37724 Mtetra
.761 .598 .675 r
.46123 .37724 .46212 .38031 .46384 .37611 .46292 .37454 Mtetra
.697 .666 .816 r
.46292 .37454 .46384 .37611 .4655 .37511 .46457 .3737 Mtetra
.632 .661 .86 r
.46457 .3737 .4655 .37511 .46714 .37473 .46621 .37327 Mtetra
.603 .641 .861 r
.46621 .37327 .46714 .37473 .46878 .37456 .46786 .37298 Mtetra
.651 .645 .831 r
.46786 .37298 .46878 .37456 .47043 .37405 .4695 .37243 Mtetra
.646 .637 .827 r
.4695 .37243 .47043 .37405 .47208 .37355 .47115 .3719 Mtetra
.637 .631 .828 r
.47115 .3719 .47208 .37355 .47373 .37302 .4728 .37143 Mtetra
.622 .631 .838 r
.4728 .37143 .47373 .37302 .47538 .37243 .47445 .37104 Mtetra
.621 .66 .866 r
.47445 .37104 .47538 .37243 .47703 .37183 .47611 .37066 Mtetra
.628 .701 .898 r
.47611 .37066 .47703 .37183 .47869 .37124 .47776 .37025 Mtetra
.65 .746 .92 r
.47776 .37025 .47869 .37124 .48034 .3707 .47941 .36974 Mtetra
.664 .758 .921 r
.47941 .36974 .48034 .3707 .482 .37016 .48107 .36918 Mtetra
.679 .757 .91 r
.48107 .36918 .482 .37016 .48366 .36962 .48273 .36855 Mtetra
.695 .744 .889 r
.48273 .36855 .48366 .36962 .48531 .36906 .48439 .36784 Mtetra
.692 .716 .867 r
.48439 .36784 .48531 .36906 .48697 .36849 .48605 .36711 Mtetra
.682 .688 .849 r
.48605 .36711 .48697 .36849 .48863 .36791 .48771 .36642 Mtetra
.662 .663 .84 r
.48771 .36642 .48863 .36791 .49029 .36734 .48937 .36581 Mtetra
.657 .656 .838 r
.48937 .36581 .49029 .36734 .49196 .36676 .49104 .36523 Mtetra
.654 .655 .838 r
.49104 .36523 .49196 .36676 .49362 .36619 .4927 .36467 Mtetra
.656 .657 .839 r
.4927 .36467 .49362 .36619 .49528 .36562 .49437 .3641 Mtetra
.655 .656 .839 r
.49437 .3641 .49528 .36562 .49695 .36505 .49603 .36353 Mtetra
.49603 .36353 .49695 .36505 .49862 .36448 .4977 .36296 Mtetra
.4977 .36296 .49862 .36448 .50028 .36392 .49936 .36239 Mtetra
.654 .656 .839 r
.49936 .36239 .50028 .36392 .50195 .36335 .50103 .36183 Mtetra
.50103 .36183 .50195 .36335 .50362 .36279 .5027 .36126 Mtetra
.5027 .36126 .50362 .36279 .50529 .36222 .50437 .3607 Mtetra
.654 .656 .84 r
.50437 .3607 .50529 .36222 .50696 .36166 .50605 .36013 Mtetra
.654 .657 .84 r
.50605 .36013 .50696 .36166 .50863 .36109 .50772 .35957 Mtetra
.656 .658 .84 r
.50772 .35957 .50863 .36109 .51031 .36052 .50939 .359 Mtetra
.654 .656 .84 r
.50939 .359 .51031 .36052 .51198 .35995 .51107 .35844 Mtetra
.649 .656 .843 r
.51107 .35844 .51198 .35995 .51366 .35937 .51274 .3579 Mtetra
.629 .653 .855 r
.51274 .3579 .51366 .35937 .51533 .35878 .51442 .35748 Mtetra
.631 .681 .878 r
.51442 .35748 .51533 .35878 .51701 .3582 .5161 .35705 Mtetra
.644 .715 .899 r
.5161 .35705 .51701 .3582 .51869 .35762 .51777 .35656 Mtetra
.692 .749 .895 r
.51777 .35656 .51869 .35762 .52037 .35709 .51945 .35586 Mtetra
.695 .718 .867 r
.51945 .35586 .52037 .35709 .52205 .35656 .52114 .35511 Mtetra
.686 .68 .839 r
.52114 .35511 .52205 .35656 .52373 .35602 .52282 .35437 Mtetra
.662 .643 .821 r
.52282 .35437 .52373 .35602 .52541 .35541 .5245 .35373 Mtetra
.656 .638 .82 r
.5245 .35373 .52541 .35541 .5271 .35479 .52618 .35313 Mtetra
.653 .639 .824 r
.52618 .35313 .5271 .35479 .52878 .35417 .52787 .35255 Mtetra
.697 .663 .812 r
.52787 .35255 .52878 .35417 .53047 .35316 .52956 .35167 Mtetra
.667 .668 .842 r
.52956 .35167 .53047 .35316 .53215 .35249 .53124 .35103 Mtetra
.574 .631 .87 r
.53124 .35103 .53215 .35249 .53384 .35252 .53293 .35086 Mtetra
0 .058 .622 r
.53293 .35086 .53384 .35252 .53555 .35679 .53463 .35294 Mtetra
0 0 .18 r
.53463 .35294 .53555 .35679 .53803 .55911 .53635 .36 Mtetra
0 0 .359 r
.53635 .36 .53803 .55911 .53985 .56445 .53886 .55766 Mtetra
.523 .379 .627 r
.53886 .55766 .53985 .56445 .54166 .56471 .54067 .5582 Mtetra
.597 .434 .632 r
.54067 .5582 .54166 .56471 .54347 .5641 .54248 .55739 Mtetra
.599 .433 .629 r
.54248 .55739 .54347 .5641 .54528 .56308 .54428 .55652 Mtetra
.416 .307 .622 r
.54428 .55652 .54528 .56308 .54709 .56257 .5461 .55854 Mtetra
.378 .335 .683 r
.5461 .55854 .54709 .56257 .5489 .56209 .54793 .56005 Mtetra
.335 .437 .817 r
.54793 .56005 .5489 .56209 .55071 .56159 .54975 .56092 Mtetra
.491 .782 .996 r
.54975 .56092 .55071 .56159 .55252 .56101 .55157 .56072 Mtetra
.538 .887 .983 r
.55157 .56072 .55252 .56101 .55434 .5604 .55338 .56018 Mtetra
.586 .918 .97 r
.55338 .56018 .55434 .5604 .55615 .55979 .5552 .55949 Mtetra
.362 .802 .96 r
.5552 .55949 .55615 .55979 .55797 .5597 .55702 .55926 Mtetra
.534 .856 .997 r
.55702 .55926 .55797 .5597 .55979 .55932 .55884 .55882 Mtetra
.722 .9 .959 r
.55884 .55882 .55979 .55932 .56161 .55823 .56066 .5579 Mtetra
.939 .885 .753 r
.56066 .5579 .56161 .55823 .56338 .55315 .56245 .55497 Mtetra
.954 .865 .452 r
.56245 .55497 .56338 .55315 .56277 .34968 .5642 .5484 Mtetra
0 0 .355 r
.5642 .5484 .56277 .34968 .5644 .34275 .56358 .34751 Mtetra
0 0 .198 r
.56358 .34751 .5644 .34275 .5661 .34115 .56524 .3428 Mtetra
0 0 0 r
.56524 .3428 .5661 .34115 .56781 .34053 .56692 .34048 Mtetra
.825 .985 .878 r
.56692 .34048 .56781 .34053 .56952 .34031 .56862 .33899 Mtetra
.69 .706 .86 r
.56862 .33899 .56952 .34031 .57123 .33982 .57033 .33825 Mtetra
.623 .64 .847 r
.57033 .33825 .57123 .33982 .57294 .33928 .57205 .33785 Mtetra
.59 .645 .873 r
.57205 .33785 .57294 .33928 .57466 .33875 .57376 .3376 Mtetra
.639 .716 .903 r
.57376 .3376 .57466 .33875 .57637 .33815 .57548 .33712 Mtetra
.662 .75 .916 r
.57548 .33712 .57637 .33815 .57809 .33753 .5772 .33654 Mtetra
.675 .764 .918 r
.5772 .33654 .57809 .33753 .5798 .33692 .57891 .33591 Mtetra
.749 .779 .877 r
.57891 .33591 .5798 .33692 .58151 .33599 .58062 .33489 Mtetra
.723 .756 .878 r
.58062 .33489 .58151 .33599 .58323 .33527 .58233 .334 Mtetra
.631 .691 .887 r
.58233 .334 .58323 .33527 .58495 .33518 .58406 .33356 Mtetra
.074 .313 .795 r
.58406 .33356 .58495 .33518 .58675 .33839 .58581 .33489 Mtetra
0 0 .458 r
.58581 .33489 .58675 .33839 .59255 .54063 .58764 .33954 Mtetra
0 0 .379 r
.58764 .33954 .59255 .54063 .59454 .54746 .59346 .53983 Mtetra
.273 .197 .584 r
.59346 .53983 .59454 .54746 .59641 .54831 .5954 .54408 Mtetra
.402 .346 .681 r
.5954 .54408 .59641 .54831 .59826 .54786 .59729 .54553 Mtetra
.45 .477 .795 r
.59729 .54553 .59826 .54786 .6001 .54695 .59916 .54607 Mtetra
.513 .74 .977 r
.59916 .54607 .6001 .54695 .60194 .54625 .60101 .54591 Mtetra
.54 .881 .987 r
.60101 .54591 .60194 .54625 .60378 .54562 .60286 .54538 Mtetra
.587 .918 .971 r
.60286 .54538 .60378 .54562 .60563 .54498 .60471 .54468 Mtetra
.414 .831 .969 r
.60471 .54468 .60563 .54498 .60749 .5448 .60657 .54435 Mtetra
.511 .847 .997 r
.60657 .54435 .60749 .5448 .60935 .54448 .60842 .54396 Mtetra
.697 .893 .968 r
.60842 .54396 .60935 .54448 .61119 .54352 .61027 .54311 Mtetra
.923 .897 .783 r
.61027 .54311 .61119 .54352 .61295 .53937 .61207 .54055 Mtetra
.97 .885 .507 r
.61207 .54055 .61295 .53937 .6094 .33678 .61379 .5349 Mtetra
0 0 .373 r
.61379 .5349 .6094 .33678 .6109 .32756 .61021 .33348 Mtetra
0 0 .254 r
.61021 .33348 .6109 .32756 .6126 .32547 .61181 .32769 Mtetra
0 0 .016 r
.61181 .32769 .6126 .32547 .61433 .32475 .6135 .32527 Mtetra
.615 .921 .667 r
.6135 .32527 .61433 .32475 .61608 .32447 .61521 .32373 Mtetra
.741 .842 .927 r
.61521 .32373 .61608 .32447 .61782 .32399 .61694 .3228 Mtetra
.666 .723 .892 r
.61694 .3228 .61782 .32399 .61956 .32338 .61868 .32219 Mtetra
.637 .712 .901 r
.61868 .32219 .61956 .32338 .6213 .3228 .62043 .32172 Mtetra
.726 .763 .882 r
.62043 .32172 .6213 .3228 .62303 .32192 .62216 .32081 Mtetra
.729 .759 .877 r
.62216 .32081 .62303 .32192 .62477 .32114 .6239 .31988 Mtetra
.647 .702 .887 r
.6239 .31988 .62477 .32114 .62653 .32092 .62564 .31936 Mtetra
.212 .414 .843 r
.62564 .31936 .62653 .32092 .62837 .32333 .62744 .32035 Mtetra
0 0 .532 r
.62744 .32035 .62837 .32333 .63685 .52394 .62934 .32416 Mtetra
0 0 .393 r
.62934 .32416 .63685 .52394 .63906 .53346 .63787 .5246 Mtetra
.231 .158 .564 r
.63787 .5246 .63906 .53346 .641 .53482 .63995 .53024 Mtetra
.394 .332 .669 r
.63995 .53024 .641 .53482 .64288 .53448 .6419 .5319 Mtetra
.446 .456 .776 r
.6419 .5319 .64288 .53448 .64474 .53362 .64382 .53255 Mtetra
.421 .653 .955 r
.64382 .53255 .64474 .53362 .64662 .53319 .64572 .5327 Mtetra
.475 .825 .997 r
.64572 .5327 .64662 .53319 .64851 .53283 .64761 .53239 Mtetra
.698 .917 .969 r
.64761 .53239 .64851 .53283 .65037 .53185 .64948 .53149 Mtetra
.914 .92 .805 r
.64948 .53149 .65037 .53185 .65213 .52823 .65129 .52915 Mtetra
.967 .898 .529 r
.65129 .52915 .65213 .52823 .64633 .32821 .653 .52407 Mtetra
0 0 .384 r
.653 .52407 .64633 .32821 .64762 .3156 .64708 .32283 Mtetra
0 0 .279 r
.64708 .32283 .64762 .3156 .64931 .31312 .64858 .31538 Mtetra
0 0 .012 r
.64858 .31538 .64931 .31312 .65106 .31234 .65026 .31268 Mtetra
.741 .981 .747 r
.65026 .31268 .65106 .31234 .65283 .31204 .65198 .31099 Mtetra
.733 .775 .887 r
.65198 .31099 .65283 .31204 .6546 .31165 .65372 .31005 Mtetra
.634 .645 .843 r
.65372 .31005 .6546 .31165 .65637 .31109 .65549 .30957 Mtetra
.597 .639 .863 r
.65549 .30957 .65637 .31109 .65814 .31053 .65727 .30928 Mtetra
.669 .714 .882 r
.65727 .30928 .65814 .31053 .65989 .30965 .65904 .30864 Mtetra
.709 .777 .905 r
.65904 .30864 .65989 .30965 .66164 .30874 .66079 .30783 Mtetra
.623 .769 .95 r
.66079 .30783 .66164 .30874 .66342 .30837 .66257 .30737 Mtetra
.068 .436 .875 r
.66257 .30737 .66342 .30837 .6653 .31026 .6644 .30823 Mtetra
0 0 .418 r
.6644 .30823 .6653 .31026 .67608 .50808 .66637 .31198 Mtetra
0 0 .402 r
.66637 .31198 .67608 .50808 .6786 .52125 .67733 .51225 Mtetra
.226 .155 .564 r
.67733 .51225 .6786 .52125 .6806 .52302 .67952 .51819 Mtetra
.402 .332 .664 r
.67952 .51819 .6806 .52302 .68252 .52272 .68153 .51991 Mtetra
.452 .444 .759 r
.68153 .51991 .68252 .52272 .6844 .52186 .68349 .5206 Mtetra
.449 .628 .93 r
.68349 .5206 .6844 .52186 .68631 .52128 .68543 .52077 Mtetra
.461 .813 .997 r
.68543 .52077 .68631 .52128 .68822 .52094 .68735 .52049 Mtetra
.677 .913 .975 r
.68735 .52049 .68822 .52094 .69011 .52003 .68924 .51965 Mtetra
.899 .932 .828 r
.68924 .51965 .69011 .52003 .69189 .51688 .69107 .51751 Mtetra
.974 .905 .56 r
.69107 .51751 .69189 .51688 .69278 .49626 .69277 .51278 Mtetra
.983 .698 .348 r
.69277 .51278 .69278 .49626 .68484 .30341 .68451 .31246 Mtetra
0 0 .316 r
.68451 .31246 .68484 .30341 .6865 .30047 .68585 .30315 Mtetra
0 0 .12 r
.68585 .30315 .6865 .30047 .68827 .29957 .68752 .30039 Mtetra
0 0 0 r
.68752 .30039 .68827 .29957 .69006 .29918 .68925 .29868 Mtetra
.8 .916 .917 r
.68925 .29868 .69006 .29918 .69185 .29856 .691 .29743 Mtetra
.721 .758 .882 r
.691 .29743 .69185 .29856 .69362 .29765 .69277 .29653 Mtetra
.613 .72 .922 r
.69277 .29653 .69362 .29765 .69541 .29723 .69457 .29613 Mtetra
.205 .503 .907 r
.69457 .29613 .69541 .29723 .69731 .29863 .69644 .29683 Mtetra
0 0 .526 r
.69644 .29683 .69731 .29863 .69977 .31 .69843 .29987 Mtetra
.979 .682 .342 r
.69843 .29987 .69977 .31 .71289 .51006 .71138 .49778 Mtetra
.185 .11 .533 r
.71138 .49778 .71289 .51006 .71498 .51242 .71384 .50686 Mtetra
.411 .324 .647 r
.71384 .50686 .71498 .51242 .71692 .51219 .7159 .50876 Mtetra
.471 .423 .723 r
.7159 .50876 .71692 .51219 .71883 .51136 .7179 .50948 Mtetra
.501 .559 .847 r
.7179 .50948 .71883 .51136 .72076 .51073 .71987 .50967 Mtetra
.547 .721 .954 r
.71987 .50967 .72076 .51073 .7227 .51053 .72182 .50945 Mtetra
.691 .778 .917 r
.72182 .50945 .7227 .51053 .72462 .50977 .72374 .50867 Mtetra
.844 .807 .814 r
.72374 .50867 .72462 .50977 .72643 .50711 .72558 .50671 Mtetra
.979 .853 .645 r
.72558 .50671 .72643 .50711 .72766 .49516 .72727 .50216 Mtetra
.981 .689 .359 r
.72727 .50216 .72766 .49516 .71715 .29304 .71702 .30338 Mtetra
0 0 .337 r
.71702 .30338 .71715 .29304 .71878 .28966 .7182 .29264 Mtetra
.048 0 .177 r
.7182 .29264 .71878 .28966 .72056 .28876 .71987 .28981 Mtetra
0 0 0 r
.71987 .28981 .72056 .28876 .72239 .28841 .72161 .28805 Mtetra
.765 .949 .937 r
.72161 .28805 .72239 .28841 .72421 .28812 .72338 .2869 Mtetra
.681 .73 .888 r
.72338 .2869 .72421 .28812 .72602 .28753 .72518 .2862 Mtetra
.642 .694 .883 r
.72518 .2862 .72602 .28753 .72783 .28694 .727 .28568 Mtetra
.684 .726 .882 r
.727 .28568 .72783 .28694 .72963 .28611 .7288 .28496 Mtetra
.745 .766 .871 r
.7288 .28496 .72963 .28611 .73141 .28504 .73058 .2839 Mtetra
.658 .737 .908 r
.73058 .2839 .73141 .28504 .73322 .28445 .7324 .28331 Mtetra
.12 .437 .875 r
.7324 .28331 .73322 .28445 .73514 .28537 .73431 .28424 Mtetra
.908 .525 .095 r
.73431 .28424 .73514 .28537 .73754 .2933 .73671 .29218 Mtetra
.975 .671 .352 r
.73671 .29218 .73754 .2933 .75344 .4972 .75257 .49612 Mtetra
.597 .135 0 r
.75257 .49612 .75344 .4972 .75563 .50013 .75476 .49905 Mtetra
.553 .721 .952 r
.75476 .49905 .75563 .50013 .7576 .4999 .75673 .49882 Mtetra
.712 .785 .909 r
.75673 .49882 .7576 .4999 .75953 .49901 .75867 .49792 Mtetra
.695 .778 .915 r
.75867 .49792 .75953 .49901 .76147 .4982 .7606 .4971 Mtetra
.512 .699 .954 r
.7606 .4971 .76147 .4982 .76346 .49811 .76259 .49701 Mtetra
.653 .762 .929 r
.76259 .49701 .76346 .49811 .76541 .49749 .76455 .49639 Mtetra
.866 .814 .796 r
.76455 .49639 .76541 .49749 .76725 .49527 .76639 .49416 Mtetra
.979 .75 .52 r
.76639 .49416 .76725 .49527 .76852 .48535 .76765 .48414 Mtetra
.977 .678 .362 r
.76765 .48414 .76852 .48535 .75531 .28051 .75449 .27934 Mtetra
.931 .785 .677 r
.75449 .27934 .75531 .28051 .75689 .27665 .75608 .27549 Mtetra
.727 .762 .881 r
.75608 .27549 .75689 .27665 .7587 .27569 .75788 .27454 Mtetra
.602 .713 .922 r
.75788 .27454 .7587 .27569 .76055 .27533 .75973 .27418 Mtetra
.601 .713 .923 r
.75973 .27418 .76055 .27533 .7624 .27498 .76158 .27382 Mtetra
.74 .768 .876 r
.76158 .27382 .7624 .27498 .7642 .27394 .76339 .27279 Mtetra
.657 .738 .909 r
.76339 .27279 .7642 .27394 .76603 .27335 .76522 .2722 Mtetra
.236 .51 .908 r
.76522 .2722 .76603 .27335 .76797 .27404 .76716 .2729 Mtetra
.882 .49 .034 r
.76716 .2729 .76797 .27404 .77042 .28125 .76961 .28011 Mtetra
.975 .667 .334 r
.76961 .28011 .77042 .28125 .78867 .48646 .78782 .48538 Mtetra
.658 .204 0 r
.78782 .48538 .78867 .48646 .79097 .48993 .79012 .48884 Mtetra
.381 .632 .953 r
.79012 .48884 .79097 .48993 .79301 .49019 .79216 .48911 Mtetra
.695 .783 .919 r
.79216 .48911 .79301 .49019 .79497 .48937 .79412 .48829 Mtetra
.876 .822 .791 r
.79412 .48829 .79497 .48937 .79681 .48704 .79596 .48597 Mtetra
.979 .766 .546 r
.79596 .48597 .79681 .48704 .79816 .47893 .79732 .47791 Mtetra
.977 .675 .347 r
.79732 .47791 .79816 .47893 .78292 .27188 .78212 .27076 Mtetra
.951 .789 .645 r
.78212 .27076 .78292 .27188 .78445 .26742 .78365 .26628 Mtetra
.742 .773 .878 r
.78365 .26628 .78445 .26742 .78626 .26637 .78546 .26523 Mtetra
.611 .721 .923 r
.78546 .26523 .78626 .26637 .78812 .26597 .78732 .26483 Mtetra
.577 .705 .929 r
.78732 .26483 .78812 .26597 .79 .26571 .7892 .26455 Mtetra
.745 .772 .875 r
.7892 .26455 .79 .26571 .79182 .26468 .79101 .26349 Mtetra
.664 .735 .902 r
.79101 .26349 .79182 .26468 .79367 .26405 .79287 .26285 Mtetra
.331 .559 .919 r
.79287 .26285 .79367 .26405 .79561 .26449 .79482 .26336 Mtetra
.871 .476 .009 r
.79482 .26336 .79561 .26449 .79805 .27046 .79736 .27055 Mtetra
.973 .662 .323 r
.79736 .27055 .79805 .27046 .8183 .47669 .81756 .47668 Mtetra
.81 .323 0 r
.81756 .47668 .8183 .47669 .8207 .48063 .81992 .48019 Mtetra
.404 .808 .982 r
.81992 .48019 .8207 .48063 .82275 .48061 .82195 .47994 Mtetra
.717 .887 .958 r
.82195 .47994 .82275 .48061 .82473 .47987 .82391 .47897 Mtetra
.755 .844 .918 r
.82391 .47897 .82473 .47987 .82669 .47891 .82586 .47783 Mtetra
.464 .682 .96 r
.82586 .47783 .82669 .47891 .82874 .47881 .82792 .47787 Mtetra
.58 .77 .969 r
.82792 .47787 .82874 .47881 .83075 .47826 .82994 .47748 Mtetra
.802 .881 .904 r
.82994 .47748 .83075 .47826 .83266 .47667 .83187 .47608 Mtetra
.992 .814 .562 r
.83187 .47608 .83266 .47667 .83406 .46974 .83333 .46971 Mtetra
.976 .671 .325 r
.83333 .46971 .83406 .46974 .81644 .26155 .8157 .26089 Mtetra
.988 .812 .577 r
.8157 .26089 .81644 .26155 .81787 .25631 .81709 .25519 Mtetra
.765 .788 .872 r
.81709 .25519 .81787 .25631 .81969 .25516 .8189 .254 Mtetra
.626 .728 .92 r
.8189 .254 .81969 .25516 .82157 .2547 .82079 .25353 Mtetra
.551 .691 .932 r
.82079 .25353 .82157 .2547 .82349 .25451 .8227 .25336 Mtetra
.751 .777 .874 r
.8227 .25336 .82349 .25451 .82531 .25342 .82453 .25225 Mtetra
.679 .748 .903 r
.82453 .25225 .82531 .25342 .82718 .25272 .82639 .25153 Mtetra
.455 .636 .933 r
.82639 .25153 .82718 .25272 .82913 .25287 .82834 .25168 Mtetra
.777 .365 0 r
.82834 .25168 .82913 .25287 .83161 .25829 .83082 .25706 Mtetra
.971 .657 .298 r
.83082 .25706 .83161 .25829 .85432 .46558 .85349 .46443 Mtetra
.708 .275 0 r
.85349 .46443 .85432 .46558 .85684 .47003 .85602 .46891 Mtetra
.32 .587 .939 r
.85602 .46891 .85684 .47003 .85897 .4705 .85815 .46938 Mtetra
.655 .764 .93 r
.85815 .46938 .85897 .4705 .86099 .46986 .86017 .46873 Mtetra
.833 .82 .837 r
.86017 .46873 .86099 .46986 .86289 .46805 .86207 .46693 Mtetra
.976 .787 .584 r
.86207 .46693 .86289 .46805 .86434 .46185 .86352 .46076 Mtetra
.974 .667 .312 r
.86352 .46076 .86434 .46185 .84469 .2529 .84392 .2518 Mtetra
.976 .78 .574 r
.84392 .2518 .84469 .2529 .84601 .24684 .84524 .2457 Mtetra
.766 .766 .852 r
.23775 .45028 .23878 .45119 .24034 .45009 .23932 .4492 Mtetra
.629 .745 .931 r
.23932 .4492 .24034 .45009 .24185 .44968 .24082 .44881 Mtetra
.493 .704 .963 r
.24082 .44881 .24185 .44968 .24332 .44961 .2423 .44876 Mtetra
.727 .775 .891 r
.2423 .44876 .24332 .44961 .24488 .44864 .24384 .44796 Mtetra
.71 .809 .927 r
.24384 .44796 .24488 .44864 .24641 .44791 .24537 .44726 Mtetra
.633 .805 .965 r
.24537 .44726 .24641 .44791 .24791 .44766 .24688 .44682 Mtetra
0 .421 .849 r
.24688 .44682 .24791 .44766 .24921 .44973 .24831 .44745 Mtetra
.166 .281 .738 r
.24831 .44745 .24921 .44973 .25007 .4571 .24968 .44875 Mtetra
.43 .287 .585 r
.24968 .44875 .25007 .4571 .23555 .64916 .25098 .45078 Mtetra
.546 .328 .535 r
.25098 .45078 .23555 .64916 .23708 .64963 .25253 .45003 Mtetra
.25253 .45003 .23708 .64963 .23872 .64881 .25409 .4491 Mtetra
.544 .326 .535 r
.25409 .4491 .23872 .64881 .24036 .64792 .25557 .44916 Mtetra
0 0 .215 r
.25557 .44916 .24036 .64792 .24178 .6499 .24143 .64003 Mtetra
0 0 .355 r
.24143 .64003 .24178 .6499 .24323 .65143 .24228 .64881 Mtetra
0 0 .508 r
.24228 .64881 .24323 .65143 .24474 .65232 .24365 .65144 Mtetra
.396 .673 .971 r
.24365 .65144 .24474 .65232 .24633 .65214 .24522 .65155 Mtetra
.64 .833 .975 r
.24522 .65155 .24633 .65214 .24795 .65163 .24685 .65103 Mtetra
.721 .843 .94 r
.24685 .65103 .24795 .65163 .24959 .65097 .24849 .65023 Mtetra
.657 .801 .952 r
.24849 .65023 .24959 .65097 .25121 .65045 .25012 .64969 Mtetra
.643 .792 .954 r
.25012 .64969 .25121 .65045 .25284 .64997 .25175 .6492 Mtetra
.635 .787 .955 r
.25175 .6492 .25284 .64997 .25446 .64953 .25337 .64873 Mtetra
.6 .774 .963 r
.25337 .64873 .25446 .64953 .25607 .64919 .25498 .64837 Mtetra
.594 .765 .961 r
.25498 .64837 .25607 .64919 .25768 .64889 .2566 .64804 Mtetra
.602 .761 .955 r
.2566 .64804 .25768 .64889 .2593 .64857 .25822 .64769 Mtetra
.629 .762 .943 r
.25822 .64769 .2593 .64857 .26092 .64815 .25984 .64726 Mtetra
.644 .763 .935 r
.25984 .64726 .26092 .64815 .26255 .64768 .26147 .64677 Mtetra
.657 .763 .927 r
.26147 .64677 .26255 .64768 .26418 .64717 .26311 .64624 Mtetra
.679 .764 .916 r
.26311 .64624 .26418 .64717 .26582 .64658 .26475 .64562 Mtetra
.686 .76 .908 r
.26475 .64562 .26582 .64658 .26747 .64595 .2664 .64496 Mtetra
.685 .754 .904 r
.2664 .64496 .26747 .64595 .26911 .64533 .26804 .64431 Mtetra
.624 .733 .925 r
.26804 .64431 .26911 .64533 .27073 .64507 .26967 .64391 Mtetra
.634 .708 .9 r
.26967 .64391 .27073 .64507 .27236 .64469 .2713 .64348 Mtetra
.68 .712 .873 r
.2713 .64348 .27236 .64469 .27402 .64388 .27295 .64282 Mtetra
.805 .758 .809 r
.27295 .64282 .27402 .64388 .27582 .64101 .27467 .64121 Mtetra
.922 .935 .796 r
.27467 .64121 .27582 .64101 .27791 .63431 .27645 .63884 Mtetra
.069 0 .191 r
.27645 .63884 .27791 .63431 .29338 .43894 .27827 .63577 Mtetra
.54 .319 .528 r
.27827 .63577 .29338 .43894 .29509 .43602 .27999 .63406 Mtetra
.542 .321 .528 r
.27999 .63406 .29509 .43602 .29664 .43546 .28163 .63359 Mtetra
.543 .322 .528 r
.28163 .63359 .29664 .43546 .29814 .4357 .28323 .63364 Mtetra
.544 .322 .529 r
.28323 .63364 .29814 .4357 .29964 .43589 .28481 .63407 Mtetra
.543 .321 .528 r
.28481 .63407 .29964 .43589 .30117 .43573 .28643 .63399 Mtetra
.541 .32 .528 r
.28643 .63399 .30117 .43573 .30275 .43481 .28812 .63274 Mtetra
.512 .296 .522 r
.28812 .63274 .30275 .43481 .30446 .43202 .29079 .61725 Mtetra
0 0 .21 r
.29079 .61725 .30446 .43202 .30615 .42948 .30501 .43058 Mtetra
.971 .931 .646 r
.30501 .43058 .30615 .42948 .30779 .42757 .30679 .42674 Mtetra
.806 .789 .836 r
.30679 .42674 .30779 .42757 .30937 .42661 .3084 .42535 Mtetra
.665 .689 .863 r
.3084 .42535 .30937 .42661 .31093 .42608 .30996 .4248 Mtetra
.598 .661 .882 r
.30996 .4248 .31093 .42608 .31247 .4257 .31149 .42453 Mtetra
.639 .695 .886 r
.31149 .42453 .31247 .4257 .31403 .42523 .31305 .42411 Mtetra
.657 .71 .887 r
.31305 .42411 .31403 .42523 .31559 .4247 .3146 .4236 Mtetra
.651 .712 .892 r
.3146 .4236 .31559 .4247 .31714 .4242 .31616 .42312 Mtetra
.628 .709 .904 r
.31616 .42312 .31714 .4242 .31869 .42379 .31771 .42273 Mtetra
.618 .712 .912 r
.31771 .42273 .31869 .42379 .32025 .4234 .31926 .42238 Mtetra
.626 .721 .915 r
.31926 .42238 .32025 .4234 .3218 .42298 .32081 .422 Mtetra
.67 .742 .904 r
.32081 .422 .3218 .42298 .32337 .42238 .32238 .42144 Mtetra
.695 .757 .9 r
.32238 .42144 .32337 .42238 .32494 .42167 .32395 .42077 Mtetra
.699 .766 .903 r
.32395 .42077 .32494 .42167 .32652 .42096 .32552 .42008 Mtetra
.711 .774 .901 r
.32552 .42008 .32652 .42096 .3281 .42011 .3271 .41934 Mtetra
.695 .795 .927 r
.3271 .41934 .3281 .42011 .32968 .41939 .32867 .41868 Mtetra
.628 .797 .963 r
.32867 .41868 .32968 .41939 .33123 .41906 .33024 .41825 Mtetra
.419 .689 .975 r
.33024 .41825 .33123 .41906 .3327 .42013 .33177 .41831 Mtetra
.322 .435 .822 r
.33177 .41831 .3327 .42013 .33402 .42391 .33326 .41903 Mtetra
.341 .27 .63 r
.33326 .41903 .33402 .42391 .32417 .61916 .33469 .42095 Mtetra
.499 .289 .526 r
.33469 .42095 .32417 .61916 .32549 .62474 .33507 .44096 Mtetra
0 0 .253 r
.33507 .44096 .32549 .62474 .32703 .6264 .32614 .62261 Mtetra
0 .051 .575 r
.32614 .62261 .32703 .6264 .32864 .62706 .32761 .62565 Mtetra
.279 .496 .888 r
.32761 .62565 .32864 .62706 .33028 .62704 .32922 .62626 Mtetra
.619 .789 .963 r
.32922 .62626 .33028 .62704 .33195 .6266 .33089 .62583 Mtetra
.714 .81 .925 r
.33089 .62583 .33195 .6266 .33363 .62597 .33258 .62504 Mtetra
.658 .765 .928 r
.33258 .62504 .33363 .62597 .3353 .62561 .33426 .62449 Mtetra
.625 .715 .911 r
.33426 .62449 .3353 .62561 .33696 .62531 .33593 .62408 Mtetra
.672 .712 .878 r
.33593 .62408 .33696 .62531 .33865 .62459 .33761 .62346 Mtetra
.754 .747 .846 r
.33761 .62346 .33865 .62459 .34042 .62247 .33933 .62232 Mtetra
.881 .922 .847 r
.33933 .62232 .34042 .62247 .34233 .61761 .34108 .62047 Mtetra
0 0 0 r
.34108 .62047 .34233 .61761 .35429 .42162 .3429 .61741 Mtetra
.521 .303 .524 r
.3429 .61741 .35429 .42162 .35623 .41425 .34515 .60601 Mtetra
0 0 .247 r
.34515 .60601 .35623 .41425 .35792 .41165 .3568 .41345 Mtetra
.877 .911 .507 r
.3568 .41345 .35792 .41165 .35956 .41004 .35856 .40953 Mtetra
.846 .854 .849 r
.35856 .40953 .35956 .41004 .36116 .40916 .3602 .40796 Mtetra
.646 .696 .882 r
.3602 .40796 .36116 .40916 .36274 .40875 .36178 .4075 Mtetra
.553 .65 .899 r
.36178 .4075 .36274 .40875 .36431 .40852 .36334 .40739 Mtetra
.584 .686 .911 r
.36334 .40739 .36431 .40852 .36589 .40818 .36492 .40715 Mtetra
.651 .73 .908 r
.36492 .40715 .36589 .40818 .36748 .40766 .3665 .40667 Mtetra
.665 .743 .908 r
.3665 .40667 .36748 .40766 .36907 .40707 .36809 .40612 Mtetra
.71 .761 .893 r
.36809 .40612 .36907 .40707 .37067 .4062 .36969 .40537 Mtetra
.729 .79 .9 r
.36969 .40537 .37067 .4062 .37228 .40526 .3713 .40453 Mtetra
.686 .807 .94 r
.3713 .40453 .37228 .40526 .37388 .40469 .3729 .4039 Mtetra
.511 .736 .975 r
.3729 .4039 .37388 .40469 .37542 .40535 .37447 .40377 Mtetra
.332 .479 .857 r
.37447 .40377 .37542 .40535 .37684 .40849 .37601 .40437 Mtetra
.334 .287 .656 r
.37601 .40437 .37684 .40849 .36961 .60267 .37751 .40607 Mtetra
.526 .312 .532 r
.37751 .40607 .36961 .60267 .37093 .61056 .3787 .4145 Mtetra
0 0 .28 r
.3787 .4145 .37093 .61056 .37252 .61244 .37163 .60821 Mtetra
0 .041 .56 r
.37163 .60821 .37252 .61244 .37416 .61321 .37315 .61168 Mtetra
.074 .349 .822 r
.37315 .61168 .37416 .61321 .37583 .61335 .37478 .61277 Mtetra
.449 .778 .998 r
.37478 .61277 .37583 .61335 .37753 .61302 .37647 .61262 Mtetra
.718 .901 .961 r
.37647 .61262 .37753 .61302 .37924 .61231 .37819 .61175 Mtetra
.88 .845 .805 r
.37819 .61175 .37924 .61231 .38098 .61095 .37996 .6096 Mtetra
.897 .728 .664 r
.37996 .6096 .38098 .61095 .38275 .60876 .38185 .60473 Mtetra
.949 .686 .502 r
.38185 .60473 .38275 .60876 .38455 .60586 .39161 .40887 Mtetra
.558 .338 .537 r
.39161 .40887 .38455 .60586 .38632 .6038 .39348 .40192 Mtetra
.545 .328 .535 r
.39348 .40192 .38632 .6038 .38801 .6038 .39509 .40126 Mtetra
.544 .327 .535 r
.39509 .40126 .38801 .6038 .38971 .60332 .39669 .40118 Mtetra
.547 .329 .535 r
.39669 .40118 .38971 .60332 .3916 .59826 .39834 .39963 Mtetra
.55 .331 .536 r
.39834 .39963 .3916 .59826 .40086 .40139 .40003 .39689 Mtetra
.69 .52 .652 r
.40003 .39689 .40086 .40139 .40264 .39639 .4017 .3948 Mtetra
.748 .677 .783 r
.4017 .3948 .40264 .39639 .40431 .39428 .40334 .39349 Mtetra
.68 .795 .936 r
.40334 .39349 .40431 .39428 .40593 .39357 .40496 .39287 Mtetra
.608 .799 .973 r
.40496 .39287 .40593 .39357 .40753 .39325 .40656 .39247 Mtetra
.593 .773 .966 r
.40656 .39247 .40753 .39325 .40913 .39302 .40817 .39213 Mtetra
.617 .755 .944 r
.40817 .39213 .40913 .39302 .41074 .39267 .40978 .39175 Mtetra
.618 .748 .939 r
.40978 .39175 .41074 .39267 .41235 .39232 .41139 .39136 Mtetra
.636 .745 .927 r
.41139 .39136 .41235 .39232 .41396 .39192 .413 .39092 Mtetra
.66 .743 .911 r
.413 .39092 .41396 .39192 .41557 .39143 .41462 .39039 Mtetra
.672 .739 .9 r
.41462 .39039 .41557 .39143 .41719 .39087 .41624 .3898 Mtetra
.712 .744 .876 r
.41624 .3898 .41719 .39087 .41882 .39016 .41787 .389 Mtetra
.737 .734 .849 r
.41787 .389 .41882 .39016 .42045 .38931 .4195 .38802 Mtetra
.677 .695 .86 r
.4195 .38802 .42045 .38931 .42207 .38863 .42113 .38738 Mtetra
.351 .553 .909 r
.42113 .38738 .42207 .38863 .42368 .3885 .42272 .38779 Mtetra
.868 .423 .066 r
.42272 .38779 .42368 .3885 .42526 .38937 .42423 .39089 Mtetra
.954 .681 .481 r
.42423 .39089 .42526 .38937 .42682 .39092 .41987 .58449 Mtetra
.558 .333 .531 r
.41987 .58449 .42682 .39092 .42839 .39217 .42133 .5927 Mtetra
.543 .321 .528 r
.42133 .5927 .42839 .39217 .43003 .39114 .42305 .59243 Mtetra
.542 .32 .528 r
.42305 .59243 .43003 .39114 .43167 .39048 .42479 .59148 Mtetra
.544 .322 .528 r
.42479 .59148 .43167 .39048 .43321 .39312 .4265 .59168 Mtetra
.547 .324 .529 r
.4265 .59168 .43321 .39312 .42931 .59006 .42817 .59359 Mtetra
.619 .288 .388 r
.42817 .59359 .42931 .59006 .43089 .59493 .42985 .59488 Mtetra
.364 0 0 r
.42985 .59488 .43089 .59493 .43257 .59654 .43156 .59543 Mtetra
.56 .702 .935 r
.43156 .59543 .43257 .59654 .4343 .59644 .43329 .59523 Mtetra
.63 .709 .903 r
.43329 .59523 .4343 .59644 .43604 .59589 .43503 .59479 Mtetra
.639 .732 .915 r
.43503 .59479 .43604 .59589 .43778 .59523 .43677 .59431 Mtetra
.6 .758 .954 r
.43677 .59431 .43778 .59523 .43952 .59471 .43851 .59394 Mtetra
.689 .818 .944 r
.43851 .59394 .43952 .59471 .44127 .59399 .44026 .59323 Mtetra
.829 .829 .848 r
.44026 .59323 .44127 .59399 .44303 .59284 .44203 .59162 Mtetra
.899 .748 .685 r
.44203 .59162 .44303 .59284 .44481 .5908 .44386 .5875 Mtetra
.912 .673 .564 r
.44386 .5875 .44481 .5908 .44661 .58816 .44594 .57235 Mtetra
.94 .67 .498 r
.44594 .57235 .44661 .58816 .4484 .58566 .45198 .38271 Mtetra
.546 .328 .535 r
.45198 .38271 .4484 .58566 .45013 .5855 .45364 .38174 Mtetra
.544 .327 .535 r
.45364 .38174 .45013 .5855 .45188 .58509 .45527 .38158 Mtetra
.546 .328 .535 r
.45527 .38158 .45188 .58509 .45367 .58225 .45693 .38055 Mtetra
.55 .331 .536 r
.45693 .38055 .45367 .58225 .45946 .38374 .45863 .37753 Mtetra
.666 .481 .626 r
.45863 .37753 .45946 .38374 .46123 .37724 .46031 .37524 Mtetra
.747 .644 .747 r
.46031 .37524 .46123 .37724 .46292 .37454 .46198 .37368 Mtetra
.697 .787 .92 r
.46198 .37368 .46292 .37454 .46457 .3737 .46362 .37298 Mtetra
.63 .805 .967 r
.46362 .37298 .46457 .3737 .46621 .37327 .46527 .37251 Mtetra
.611 .788 .966 r
.46527 .37251 .46621 .37327 .46786 .37298 .46692 .3721 Mtetra
.663 .775 .933 r
.46692 .3721 .46786 .37298 .4695 .37243 .46857 .37154 Mtetra
.658 .771 .933 r
.46857 .37154 .4695 .37243 .47115 .3719 .47022 .371 Mtetra
.647 .764 .934 r
.47022 .371 .47115 .3719 .4728 .37143 .47187 .3705 Mtetra
.624 .751 .938 r
.47187 .3705 .4728 .37143 .47445 .37104 .47352 .37008 Mtetra
.622 .745 .935 r
.47352 .37008 .47445 .37104 .47611 .37066 .47517 .36968 Mtetra
.631 .742 .928 r
.47517 .36968 .47611 .37066 .47776 .37025 .47683 .36924 Mtetra
.655 .744 .916 r
.47683 .36924 .47776 .37025 .47941 .36974 .47848 .36871 Mtetra
.668 .744 .907 r
.47848 .36871 .47941 .36974 .48107 .36918 .48014 .36813 Mtetra
.682 .745 .899 r
.48014 .36813 .48107 .36918 .48273 .36855 .4818 .36748 Mtetra
.699 .746 .888 r
.4818 .36748 .48273 .36855 .48439 .36784 .48346 .36675 Mtetra
.7 .742 .883 r
.48346 .36675 .48439 .36784 .48605 .36711 .48512 .366 Mtetra
.694 .736 .883 r
.48512 .366 .48605 .36711 .48771 .36642 .48679 .36528 Mtetra
.674 .726 .889 r
.48679 .36528 .48771 .36642 .48937 .36581 .48845 .36467 Mtetra
.667 .722 .89 r
.48845 .36467 .48937 .36581 .49104 .36523 .49011 .36408 Mtetra
.663 .72 .891 r
.49011 .36408 .49104 .36523 .4927 .36467 .49178 .36351 Mtetra
.665 .719 .889 r
.49178 .36351 .4927 .36467 .49437 .3641 .49344 .36294 Mtetra
.664 .718 .889 r
.49344 .36294 .49437 .3641 .49603 .36353 .49511 .36237 Mtetra
.663 .718 .89 r
.49511 .36237 .49603 .36353 .4977 .36296 .49678 .3618 Mtetra
.49678 .3618 .4977 .36296 .49936 .36239 .49844 .36123 Mtetra
.662 .718 .89 r
.49844 .36123 .49936 .36239 .50103 .36183 .50011 .36067 Mtetra
.50011 .36067 .50103 .36183 .5027 .36126 .50178 .3601 Mtetra
.661 .718 .891 r
.50178 .3601 .5027 .36126 .50437 .3607 .50345 .35954 Mtetra
.661 .719 .891 r
.50345 .35954 .50437 .3607 .50605 .36013 .50513 .35898 Mtetra
.661 .719 .892 r
.50513 .35898 .50605 .36013 .50772 .35957 .5068 .35842 Mtetra
.663 .721 .892 r
.5068 .35842 .50772 .35957 .50939 .359 .50847 .35785 Mtetra
.659 .721 .894 r
.50847 .35785 .50939 .359 .51107 .35844 .51015 .3573 Mtetra
.652 .72 .898 r
.51015 .3573 .51107 .35844 .51274 .3579 .51182 .35678 Mtetra
.624 .713 .91 r
.51182 .35678 .51274 .3579 .51442 .35748 .5135 .35638 Mtetra
.624 .717 .913 r
.5135 .35638 .51442 .35748 .5161 .35705 .51518 .35597 Mtetra
.636 .727 .914 r
.51518 .35597 .5161 .35705 .51777 .35656 .51686 .35552 Mtetra
.686 .75 .9 r
.51686 .35552 .51777 .35656 .51945 .35586 .51854 .35485 Mtetra
.696 .759 .901 r
.51854 .35485 .51945 .35586 .52114 .35511 .52022 .35413 Mtetra
.697 .766 .905 r
.52022 .35413 .52114 .35511 .52282 .35437 .5219 .3534 Mtetra
.674 .764 .918 r
.5219 .3534 .52282 .35437 .5245 .35373 .52359 .35279 Mtetra
.668 .767 .924 r
.52359 .35279 .5245 .35373 .52618 .35313 .52527 .3522 Mtetra
.664 .768 .928 r
.52527 .3522 .52618 .35313 .52787 .35255 .52696 .35162 Mtetra
.702 .781 .912 r
.52696 .35162 .52787 .35255 .52956 .35167 .52865 .35088 Mtetra
.672 .804 .946 r
.52865 .35088 .52956 .35167 .53124 .35103 .53033 .35026 Mtetra
.594 .784 .971 r
.53033 .35026 .53124 .35103 .53293 .35086 .53202 .34989 Mtetra
.149 .501 .908 r
.53202 .34989 .53293 .35086 .53463 .35294 .53371 .35052 Mtetra
.285 .352 .757 r
.53371 .35052 .53463 .35294 .53635 .36 .53541 .35176 Mtetra
.451 .311 .599 r
.53541 .35176 .53635 .36 .53886 .55766 .53712 .35369 Mtetra
.546 .328 .535 r
.53712 .35369 .53886 .55766 .54067 .5582 .53881 .35295 Mtetra
.53881 .35295 .54067 .5582 .54248 .55739 .54051 .35206 Mtetra
.544 .326 .535 r
.54051 .35206 .54248 .55739 .54428 .55652 .54221 .35213 Mtetra
0 0 .372 r
.54221 .35213 .54428 .55652 .5461 .55854 .54508 .54809 Mtetra
.022 0 .479 r
.54508 .54809 .5461 .55854 .54793 .56005 .54695 .55719 Mtetra
0 .123 .647 r
.54695 .55719 .54793 .56005 .54975 .56092 .54879 .55985 Mtetra
.463 .67 .953 r
.54879 .55985 .54975 .56092 .55157 .56072 .55061 .5599 Mtetra
.651 .807 .958 r
.55061 .5599 .55157 .56072 .55338 .56018 .55242 .55931 Mtetra
.72 .813 .923 r
.55242 .55931 .55338 .56018 .5552 .55949 .55424 .55843 Mtetra
.613 .739 .936 r
.55424 .55843 .5552 .55949 .55702 .55926 .55606 .55802 Mtetra
.634 .713 .904 r
.55606 .55802 .55702 .55926 .55884 .55882 .55788 .55754 Mtetra
.686 .723 .878 r
.55788 .55754 .55884 .55882 .56066 .5579 .5597 .55679 Mtetra
.787 .78 .846 r
.5597 .55679 .56066 .5579 .56245 .55497 .56151 .55539 Mtetra
.846 .994 .747 r
.56151 .55539 .56245 .55497 .5642 .5484 .56332 .55321 Mtetra
.096 0 .251 r
.56332 .55321 .5642 .5484 .56358 .34751 .5651 .54946 Mtetra
0 0 .365 r
.5651 .54946 .56358 .34751 .56524 .3428 .56446 .35116 Mtetra
0 0 .205 r
.56446 .35116 .56524 .3428 .56692 .34048 .56605 .34135 Mtetra
.907 .944 .587 r
.56605 .34135 .56692 .34048 .56862 .33899 .56773 .33805 Mtetra
.762 .794 .879 r
.56773 .33805 .56862 .33899 .57033 .33825 .56943 .33696 Mtetra
.622 .683 .887 r
.56943 .33696 .57033 .33825 .57205 .33785 .57115 .33656 Mtetra
.546 .651 .904 r
.57115 .33656 .57205 .33785 .57376 .3376 .57287 .33646 Mtetra
.626 .715 .911 r
.57287 .33646 .57376 .3376 .57548 .33712 .57459 .33604 Mtetra
.655 .738 .91 r
.57459 .33604 .57548 .33712 .5772 .33654 .57631 .3355 Mtetra
.669 .749 .91 r
.57631 .3355 .5772 .33654 .57891 .33591 .57802 .33489 Mtetra
.724 .771 .89 r
.57802 .33489 .57891 .33591 .58062 .33489 .57974 .33401 Mtetra
.72 .801 .915 r
.57974 .33401 .58062 .33489 .58233 .334 .58145 .33318 Mtetra
.661 .799 .948 r
.58145 .33318 .58233 .334 .58406 .33356 .58317 .33259 Mtetra
.447 .673 .96 r
.58317 .33259 .58406 .33356 .58581 .33489 .5849 .33266 Mtetra
.381 .431 .788 r
.5849 .33266 .58581 .33489 .58764 .33954 .58665 .33347 Mtetra
.385 .288 .621 r
.58665 .33347 .58764 .33954 .59346 .53983 .58844 .33572 Mtetra
0 0 .389 r
.58844 .33572 .59346 .53983 .5954 .54408 .59423 .53182 Mtetra
.071 .022 .489 r
.59423 .53182 .5954 .54408 .59729 .54553 .5963 .5421 Mtetra
.118 .188 .662 r
.5963 .5421 .59729 .54553 .59916 .54607 .59821 .54476 Mtetra
.412 .596 .92 r
.59821 .54476 .59916 .54607 .60101 .54591 .60008 .54505 Mtetra
.638 .798 .959 r
.60008 .54505 .60101 .54591 .60286 .54538 .60193 .5445 Mtetra
.717 .815 .926 r
.60193 .5445 .60286 .54538 .60471 .54468 .60377 .54362 Mtetra
.637 .753 .932 r
.60377 .54362 .60471 .54468 .60657 .54435 .60562 .54311 Mtetra
.63 .713 .906 r
.60562 .54311 .60657 .54435 .60842 .54396 .60748 .54264 Mtetra
.677 .717 .879 r
.60748 .54264 .60842 .54396 .61027 .54311 .60933 .54193 Mtetra
.771 .769 .851 r
.60933 .54193 .61027 .54311 .61207 .54055 .61116 .54062 Mtetra
.876 .99 .815 r
.61116 .54062 .61207 .54055 .61379 .5349 .61298 .53859 Mtetra
.028 0 .182 r
.61298 .53859 .61379 .5349 .61021 .33348 .61476 .53526 Mtetra
.518 .302 .525 r
.61476 .53526 .61021 .33348 .61181 .32769 .61624 .52082 Mtetra
0 0 .377 r
.61624 .52082 .61181 .32769 .6135 .32527 .6127 .32694 Mtetra
.724 .809 .341 r
.6127 .32694 .6135 .32527 .61521 .32373 .61435 .32307 Mtetra
.834 .867 .869 r
.61435 .32307 .61521 .32373 .61694 .3228 .61606 .32157 Mtetra
.668 .717 .885 r
.61606 .32157 .61694 .3228 .61868 .32219 .6178 .32095 Mtetra
.604 .688 .901 r
.6178 .32095 .61868 .32219 .62043 .32172 .61955 .32062 Mtetra
.691 .749 .896 r
.61955 .32062 .62043 .32172 .62216 .32081 .62129 .31989 Mtetra
.72 .797 .912 r
.62129 .31989 .62216 .32081 .6239 .31988 .62303 .31905 Mtetra
.668 .802 .947 r
.62303 .31905 .6239 .31988 .62564 .31936 .62478 .31842 Mtetra
.486 .702 .965 r
.62478 .31842 .62564 .31936 .62744 .32035 .62654 .31838 Mtetra
.387 .464 .818 r
.62654 .31838 .62744 .32035 .62934 .32416 .62833 .31907 Mtetra
.384 .306 .644 r
.62833 .31907 .62934 .32416 .63787 .5246 .63017 .32101 Mtetra
.042 0 .421 r
.63017 .32101 .63787 .5246 .63995 .53024 .63816 .50351 Mtetra
.033 0 .445 r
.63816 .50351 .63995 .53024 .6419 .5319 .64088 .52799 Mtetra
.133 .178 .644 r
.64088 .52799 .6419 .5319 .64382 .53255 .64288 .53104 Mtetra
.31 .502 .883 r
.64288 .53104 .64382 .53255 .64572 .5327 .6448 .53173 Mtetra
.596 .757 .956 r
.6448 .53173 .64572 .5327 .64761 .53239 .64669 .53134 Mtetra
.725 .785 .9 r
.64669 .53134 .64761 .53239 .64948 .53149 .64856 .53039 Mtetra
.784 .791 .858 r
.64856 .53039 .64948 .53149 .65129 .52915 .65041 .52902 Mtetra
.879 .974 .84 r
.65041 .52902 .65129 .52915 .653 .52407 .65224 .52707 Mtetra
0 0 .104 r
.65224 .52707 .653 .52407 .64708 .32283 .65402 .52389 Mtetra
.524 .306 .526 r
.65402 .52389 .64708 .32283 .64858 .31538 .65547 .51236 Mtetra
0 0 .391 r
.65547 .51236 .64858 .31538 .65026 .31268 .64951 .31445 Mtetra
.69 .774 .29 r
.64951 .31445 .65026 .31268 .65198 .31099 .65114 .31037 Mtetra
.851 .882 .861 r
.65114 .31037 .65198 .31099 .65372 .31005 .65286 .30876 Mtetra
.647 .699 .884 r
.65286 .30876 .65372 .31005 .65549 .30957 .65463 .30823 Mtetra
.564 .654 .896 r
.65463 .30823 .65549 .30957 .65727 .30928 .65641 .30806 Mtetra
.628 .706 .902 r
.65641 .30806 .65727 .30928 .65904 .30864 .65818 .30762 Mtetra
.687 .767 .913 r
.65818 .30762 .65904 .30864 .66079 .30783 .65995 .30692 Mtetra
.646 .778 .944 r
.65995 .30692 .66079 .30783 .66257 .30737 .66172 .30638 Mtetra
.518 .705 .955 r
.66172 .30638 .66257 .30737 .6644 .30823 .66351 .30627 Mtetra
.427 .49 .822 r
.66351 .30627 .6644 .30823 .66637 .31198 .66533 .30681 Mtetra
.419 .329 .648 r
.66533 .30681 .66637 .31198 .67733 .51225 .66721 .30846 Mtetra
.524 .312 .533 r
.66721 .30846 .67733 .51225 .67952 .51819 .6695 .31907 Mtetra
.001 0 .411 r
.6695 .31907 .67952 .51819 .68153 .51991 .68047 .51553 Mtetra
.156 .179 .633 r
.68047 .51553 .68153 .51991 .68349 .5206 .68256 .51888 Mtetra
.287 .455 .853 r
.68256 .51888 .68349 .5206 .68543 .52077 .68453 .51978 Mtetra
.578 .75 .959 r
.68453 .51978 .68543 .52077 .68735 .52049 .68645 .51945 Mtetra
.716 .787 .908 r
.68645 .51945 .68735 .52049 .68924 .51965 .68834 .51854 Mtetra
.782 .793 .862 r
.68834 .51854 .68924 .51965 .69107 .51751 .69021 .51719 Mtetra
.877 .95 .854 r
.69021 .51719 .69107 .51751 .69277 .51278 .69205 .51529 Mtetra
0 0 .041 r
.69205 .51529 .69277 .51278 .68451 .31246 .69384 .51229 Mtetra
.53 .311 .527 r
.69384 .51229 .68451 .31246 .68585 .30315 .69536 .5042 Mtetra
.001 0 .405 r
.69536 .5042 .68585 .30315 .68752 .30039 .68687 .30301 Mtetra
0 0 0 r
.68687 .30301 .68752 .30039 .68925 .29868 .68845 .29837 Mtetra
.907 .939 .818 r
.68845 .29837 .68925 .29868 .691 .29743 .69016 .29629 Mtetra
.717 .757 .884 r
.69016 .29629 .691 .29743 .69277 .29653 .69193 .29541 Mtetra
.606 .718 .924 r
.69193 .29541 .69277 .29653 .69457 .29613 .69373 .29504 Mtetra
.492 .67 .943 r
.69373 .29504 .69457 .29613 .69644 .29683 .69556 .29504 Mtetra
.446 .523 .843 r
.69556 .29504 .69644 .29683 .69843 .29987 .69741 .29545 Mtetra
.433 .357 .671 r
.69741 .29545 .69843 .29987 .71138 .49778 .69931 .29675 Mtetra
.535 .319 .534 r
.69931 .29675 .71138 .49778 .71384 .50686 .70143 .30192 Mtetra
.022 0 .423 r
.70143 .30192 .71384 .50686 .7159 .50876 .71475 .50304 Mtetra
.174 .16 .601 r
.71475 .50304 .7159 .50876 .7179 .50948 .71695 .50737 Mtetra
.267 .391 .803 r
.71695 .50737 .7179 .50948 .71987 .50967 .71898 .50861 Mtetra
.55 .723 .954 r
.71898 .50861 .71987 .50967 .72182 .50945 .72093 .50838 Mtetra
.698 .78 .915 r
.72093 .50838 .72182 .50945 .72374 .50867 .72285 .50756 Mtetra
.768 .793 .874 r
.72285 .50756 .72374 .50867 .72558 .50671 .72474 .50631 Mtetra
.851 .947 .881 r
.72474 .50631 .72558 .50671 .72727 .50216 .7266 .50462 Mtetra
0 0 .079 r
.7266 .50462 .72727 .50216 .71702 .30338 .72841 .50197 Mtetra
.533 .313 .527 r
.72841 .50197 .71702 .30338 .7182 .29264 .72999 .49562 Mtetra
.021 0 .417 r
.72999 .49562 .7182 .29264 .71987 .28981 .71932 .29321 Mtetra
0 0 .066 r
.71932 .29321 .71987 .28981 .72161 .28805 .72084 .28793 Mtetra
.918 .968 .785 r
.72084 .28793 .72161 .28805 .72338 .2869 .72254 .28568 Mtetra
.702 .738 .879 r
.72254 .28568 .72338 .2869 .72518 .2862 .72434 .28485 Mtetra
.625 .685 .886 r
.72434 .28485 .72518 .2862 .727 .28568 .72616 .28441 Mtetra
.662 .715 .888 r
.72616 .28441 .727 .28568 .7288 .28496 .72797 .2838 Mtetra
.743 .765 .871 r
.72797 .2838 .7288 .28496 .73058 .2839 .72976 .28275 Mtetra
.657 .735 .908 r
.72976 .28275 .73058 .2839 .7324 .28331 .73157 .28216 Mtetra
.12 .436 .875 r
.73157 .28216 .7324 .28331 .73431 .28424 .73349 .2831 Mtetra
.908 .525 .094 r
.73349 .2831 .73431 .28424 .73671 .29218 .73589 .29103 Mtetra
.975 .671 .352 r
.73589 .29103 .73671 .29218 .75257 .49612 .7517 .49504 Mtetra
.596 .134 0 r
.7517 .49504 .75257 .49612 .75476 .49905 .75389 .49797 Mtetra
.554 .721 .951 r
.75389 .49797 .75476 .49905 .75673 .49882 .75586 .49773 Mtetra
.712 .785 .909 r
.75586 .49773 .75673 .49882 .75867 .49792 .7578 .49682 Mtetra
.695 .779 .915 r
.7578 .49682 .75867 .49792 .7606 .4971 .75974 .49601 Mtetra
.512 .699 .954 r
.75974 .49601 .7606 .4971 .76259 .49701 .76173 .49591 Mtetra
.654 .763 .929 r
.76173 .49591 .76259 .49701 .76455 .49639 .76368 .49529 Mtetra
.867 .815 .796 r
.76368 .49529 .76455 .49639 .76639 .49416 .76552 .49306 Mtetra
.98 .75 .519 r
.76552 .49306 .76639 .49416 .76765 .48414 .76678 .48296 Mtetra
.977 .678 .362 r
.76678 .48296 .76765 .48414 .75449 .27934 .75367 .27818 Mtetra
.932 .786 .678 r
.75367 .27818 .75449 .27934 .75608 .27549 .75526 .27434 Mtetra
.727 .763 .882 r
.75526 .27434 .75608 .27549 .75788 .27454 .75707 .27339 Mtetra
.602 .713 .923 r
.75707 .27339 .75788 .27454 .75973 .27418 .75892 .27303 Mtetra
.601 .713 .923 r
.75892 .27303 .75973 .27418 .76158 .27382 .76077 .27267 Mtetra
.739 .768 .876 r
.76077 .27267 .76158 .27382 .76339 .27279 .76257 .27164 Mtetra
.657 .738 .91 r
.76257 .27164 .76339 .27279 .76522 .2722 .76441 .27105 Mtetra
.235 .51 .908 r
.76441 .27105 .76522 .2722 .76716 .2729 .76635 .27175 Mtetra
.882 .49 .035 r
.76635 .27175 .76716 .2729 .76961 .28011 .7688 .27898 Mtetra
.975 .667 .334 r
.7688 .27898 .76961 .28011 .78782 .48538 .78697 .48429 Mtetra
.658 .203 0 r
.78697 .48429 .78782 .48538 .79012 .48884 .78926 .48775 Mtetra
.381 .632 .953 r
.78926 .48775 .79012 .48884 .79216 .48911 .79131 .48803 Mtetra
.694 .782 .919 r
.79131 .48803 .79216 .48911 .79412 .48829 .79327 .48721 Mtetra
.875 .822 .792 r
.79327 .48721 .79412 .48829 .79596 .48597 .79511 .48489 Mtetra
.979 .767 .547 r
.79511 .48489 .79596 .48597 .79732 .47791 .79648 .4769 Mtetra
.977 .675 .347 r
.79648 .4769 .79732 .47791 .78212 .27076 .78132 .26966 Mtetra
.952 .79 .644 r
.78132 .26966 .78212 .27076 .78365 .26628 .78285 .26514 Mtetra
.744 .776 .879 r
.78285 .26514 .78365 .26628 .78546 .26523 .78466 .26409 Mtetra
.613 .723 .924 r
.78466 .26409 .78546 .26523 .78732 .26483 .78652 .26368 Mtetra
.579 .706 .929 r
.78652 .26368 .78732 .26483 .7892 .26455 .7884 .2634 Mtetra
.746 .773 .874 r
.7884 .2634 .7892 .26455 .79101 .26349 .79021 .26232 Mtetra
.666 .741 .906 r
.79021 .26232 .79101 .26349 .79287 .26285 .79207 .26168 Mtetra
.332 .565 .923 r
.79207 .26168 .79287 .26285 .79482 .26336 .79402 .26216 Mtetra
.86 .465 0 r
.79402 .26216 .79482 .26336 .79736 .27055 .79654 .26913 Mtetra
.973 .663 .317 r
.79654 .26913 .79736 .27055 .81756 .47668 .81671 .47544 Mtetra
.607 .173 0 r
.81671 .47544 .81756 .47668 .81992 .48019 .81908 .47902 Mtetra
.559 .707 .94 r
.81908 .47902 .81992 .48019 .82195 .47994 .82111 .47878 Mtetra
.715 .779 .902 r
.82111 .47878 .82195 .47994 .82391 .47897 .82307 .47784 Mtetra
.743 .793 .893 r
.82307 .47784 .82391 .47897 .82586 .47783 .82503 .47674 Mtetra
.458 .673 .957 r
.82503 .47674 .82586 .47783 .82792 .47787 .82709 .4768 Mtetra
.583 .744 .953 r
.82709 .4768 .82792 .47787 .82994 .47748 .82911 .47644 Mtetra
.787 .823 .88 r
.82911 .47644 .82994 .47748 .83187 .47608 .83105 .47507 Mtetra
.978 .79 .584 r
.83105 .47507 .83187 .47608 .83333 .46971 .83253 .46882 Mtetra
.976 .671 .328 r
.83253 .46882 .83333 .46971 .8157 .26089 .81493 .2599 Mtetra
.976 .788 .585 r
.81493 .2599 .8157 .26089 .81709 .25519 .81631 .25407 Mtetra
.767 .789 .871 r
.81631 .25407 .81709 .25519 .8189 .254 .81812 .25287 Mtetra
.628 .733 .923 r
.81812 .25287 .8189 .254 .82079 .25353 .82001 .25239 Mtetra
.552 .695 .934 r
.82001 .25239 .82079 .25353 .8227 .25336 .82192 .2522 Mtetra
.753 .778 .874 r
.82192 .2522 .8227 .25336 .82453 .25225 .82375 .25108 Mtetra
.681 .749 .903 r
.82375 .25108 .82453 .25225 .82639 .25153 .82561 .25036 Mtetra
.457 .638 .934 r
.82561 .25036 .82639 .25153 .82834 .25168 .82756 .25049 Mtetra
.775 .362 0 r
.82756 .25049 .82834 .25168 .83082 .25706 .83003 .25583 Mtetra
.971 .657 .298 r
.83003 .25583 .83082 .25706 .85349 .46443 .85267 .46326 Mtetra
.707 .275 0 r
.85267 .46326 .85349 .46443 .85602 .46891 .8552 .46777 Mtetra
.321 .585 .938 r
.8552 .46777 .85602 .46891 .85815 .46938 .85733 .46824 Mtetra
.654 .763 .929 r
.85733 .46824 .85815 .46938 .86017 .46873 .85935 .4676 Mtetra
.832 .82 .837 r
.85935 .4676 .86017 .46873 .86207 .46693 .86125 .4658 Mtetra
.976 .788 .585 r
.86125 .4658 .86207 .46693 .86352 .46076 .86271 .45966 Mtetra
.974 .667 .312 r
.86271 .45966 .86352 .46076 .84392 .2518 .84316 .25069 Mtetra
.977 .78 .573 r
.84316 .25069 .84392 .2518 .84524 .2457 .84447 .24457 Mtetra
.766 .765 .852 r
.23673 .44937 .23775 .45028 .23932 .4492 .2383 .44829 Mtetra
.624 .739 .93 r
.2383 .44829 .23932 .4492 .24082 .44881 .2398 .44792 Mtetra
.472 .69 .962 r
.2398 .44792 .24082 .44881 .2423 .44876 .24127 .44792 Mtetra
.661 .764 .926 r
.24127 .44792 .2423 .44876 .24384 .44796 .24279 .44741 Mtetra
.654 .836 .97 r
.24279 .44741 .24384 .44796 .24537 .44726 .24431 .44689 Mtetra
.631 .876 .987 r
.24431 .44689 .24537 .44726 .24688 .44682 .24583 .44636 Mtetra
.636 .856 .983 r
.24583 .44636 .24688 .44682 .24831 .44745 .24735 .44586 Mtetra
.648 .631 .819 r
.24735 .44586 .24831 .44745 .24968 .44875 .24887 .44535 Mtetra
.611 .493 .695 r
.24887 .44535 .24968 .44875 .25098 .45078 .25039 .44484 Mtetra
.613 .446 .631 r
.25039 .44484 .25098 .45078 .25253 .45003 .25195 .44385 Mtetra
.594 .429 .628 r
.25195 .44385 .25253 .45003 .25409 .4491 .25349 .44316 Mtetra
.555 .403 .63 r
.25349 .44316 .25409 .4491 .25557 .44916 .25497 .44315 Mtetra
.067 .044 .52 r
.25497 .44315 .25557 .44916 .24143 .64003 .25612 .44717 Mtetra
0 0 .175 r
.25612 .44717 .24143 .64003 .24228 .64881 .24148 .64443 Mtetra
0 0 .225 r
.24148 .64443 .24228 .64881 .24365 .65144 .24262 .64981 Mtetra
.404 .524 .865 r
.24262 .64981 .24365 .65144 .24522 .65155 .24417 .65022 Mtetra
.655 .683 .864 r
.24417 .65022 .24522 .65155 .24685 .65103 .2458 .64969 Mtetra
.72 .701 .831 r
.2458 .64969 .24685 .65103 .24849 .65023 .24746 .64874 Mtetra
.655 .66 .843 r
.24746 .64874 .24849 .65023 .25012 .64969 .24908 .64819 Mtetra
.646 .656 .845 r
.24908 .64819 .25012 .64969 .25175 .6492 .25071 .64768 Mtetra
.646 .655 .844 r
.25071 .64768 .25175 .6492 .25337 .64873 .25234 .64718 Mtetra
.643 .648 .84 r
.25234 .64718 .25337 .64873 .25498 .64837 .25396 .64669 Mtetra
.639 .63 .825 r
.25396 .64669 .25498 .64837 .2566 .64804 .25559 .6462 Mtetra
.636 .612 .809 r
.25559 .6462 .2566 .64804 .25822 .64769 .25722 .64571 Mtetra
.637 .599 .795 r
.25722 .64571 .25822 .64769 .25984 .64726 .25885 .64521 Mtetra
.635 .591 .788 r
.25885 .64521 .25984 .64726 .26147 .64677 .26048 .64469 Mtetra
.633 .588 .786 r
.26048 .64469 .26147 .64677 .26311 .64624 .26211 .64419 Mtetra
.627 .588 .79 r
.26211 .64419 .26311 .64624 .26475 .64562 .26374 .64374 Mtetra
.628 .604 .807 r
.26374 .64374 .26475 .64562 .2664 .64496 .26537 .6433 Mtetra
.632 .63 .831 r
.26537 .6433 .2664 .64496 .26804 .64431 .26701 .64286 Mtetra
.64 .662 .855 r
.26701 .64286 .26804 .64431 .26967 .64391 .26864 .64239 Mtetra
.643 .653 .845 r
.26864 .64239 .26967 .64391 .2713 .64348 .27028 .6419 Mtetra
.645 .646 .836 r
.27028 .6419 .2713 .64348 .27295 .64282 .27192 .64139 Mtetra
.656 .67 .852 r
.27192 .64139 .27295 .64282 .27467 .64121 .27356 .64084 Mtetra
.621 .882 .989 r
.27356 .64084 .27467 .64121 .27645 .63884 .2752 .64027 Mtetra
.251 0 0 r
.2752 .64027 .27645 .63884 .27827 .63577 .27685 .63972 Mtetra
.46 .146 .346 r
.27685 .63972 .27827 .63577 .27999 .63406 .27849 .63924 Mtetra
.484 .192 .393 r
.27849 .63924 .27999 .63406 .28163 .63359 .28013 .63878 Mtetra
.484 .192 .394 r
.28013 .63878 .28163 .63359 .28323 .63364 .28177 .63833 Mtetra
.512 .21 .392 r
.28177 .63833 .28323 .63364 .28481 .63407 .28339 .63825 Mtetra
.486 .177 .366 r
.28339 .63825 .28481 .63407 .28643 .63399 .28502 .63796 Mtetra
.401 .091 .321 r
.28502 .63796 .28643 .63399 .28812 .63274 .2867 .63701 Mtetra
0 0 .011 r
.2867 .63701 .28812 .63274 .29079 .61725 .2886 .63276 Mtetra
.963 .71 .506 r
.2886 .63276 .29079 .61725 .30501 .43058 .30368 .43456 Mtetra
.914 .845 .394 r
.30368 .43456 .30501 .43058 .30679 .42674 .30573 .42662 Mtetra
.889 .912 .835 r
.30573 .42662 .30679 .42674 .3084 .42535 .30738 .42478 Mtetra
.669 .838 .964 r
.30738 .42478 .3084 .42535 .30996 .4248 .30894 .4242 Mtetra
.48 .774 .996 r
.30894 .4242 .30996 .4248 .31149 .42453 .31047 .42405 Mtetra
.563 .833 .996 r
.31047 .42405 .31149 .42453 .31305 .42411 .31202 .4237 Mtetra
.604 .865 .992 r
.31202 .4237 .31305 .42411 .3146 .4236 .31357 .42322 Mtetra
.599 .872 .993 r
.31357 .42322 .3146 .4236 .31616 .42312 .31513 .42274 Mtetra
.625 .879 .989 r
.31513 .42274 .31616 .42312 .31771 .42273 .31669 .42221 Mtetra
.658 .85 .973 r
.31669 .42221 .31771 .42273 .31926 .42238 .31825 .42165 Mtetra
.671 .799 .943 r
.31825 .42165 .31926 .42238 .32081 .422 .31982 .42108 Mtetra
.664 .755 .918 r
.31982 .42108 .32081 .422 .32238 .42144 .32138 .42054 Mtetra
.659 .759 .924 r
.32138 .42054 .32238 .42144 .32395 .42077 .32294 .42003 Mtetra
.657 .795 .948 r
.32294 .42003 .32395 .42077 .32552 .42008 .32451 .41951 Mtetra
.661 .838 .968 r
.32451 .41951 .32552 .42008 .3271 .41934 .32608 .41895 Mtetra
.647 .88 .984 r
.32608 .41895 .3271 .41934 .32867 .41868 .32765 .41837 Mtetra
.626 .894 .987 r
.32765 .41837 .32867 .41868 .33024 .41825 .32922 .4178 Mtetra
.732 .879 .949 r
.32922 .4178 .33024 .41825 .33177 .41831 .3308 .41697 Mtetra
.691 .687 .841 r
.3308 .41697 .33177 .41831 .33326 .41903 .33238 .41625 Mtetra
.579 .502 .732 r
.33238 .41625 .33326 .41903 .33469 .42095 .33393 .41607 Mtetra
.278 .225 .617 r
.33393 .41607 .33469 .42095 .33507 .44096 .33534 .4184 Mtetra
.976 .717 .474 r
.33534 .4184 .33507 .44096 .32614 .62261 .32555 .61376 Mtetra
0 0 .292 r
.32555 .61376 .32614 .62261 .32761 .62565 .32663 .62339 Mtetra
.146 .287 .752 r
.32663 .62339 .32761 .62565 .32922 .62626 .3282 .62479 Mtetra
.608 .65 .866 r
.3282 .62479 .32922 .62626 .33089 .62583 .32986 .62447 Mtetra
.702 .701 .846 r
.32986 .62447 .33089 .62583 .33258 .62504 .33155 .62365 Mtetra
.678 .688 .852 r
.33155 .62365 .33258 .62504 .33426 .62449 .33324 .62296 Mtetra
.644 .657 .848 r
.33324 .62296 .33426 .62449 .33593 .62408 .33492 .62246 Mtetra
.646 .645 .834 r
.33492 .62246 .33593 .62408 .33761 .62346 .3366 .62193 Mtetra
.592 .634 .862 r
.3366 .62193 .33761 .62346 .33933 .62232 .33826 .62168 Mtetra
.539 .797 .993 r
.33826 .62168 .33933 .62232 .34108 .62047 .33993 .6214 Mtetra
0 0 0 r
.33993 .6214 .34108 .62047 .3429 .61741 .34163 .62054 Mtetra
.34163 .62054 .3429 .61741 .34515 .60601 .34346 .61718 Mtetra
.964 .706 .495 r
.34346 .61718 .34515 .60601 .3568 .41345 .35529 .4226 Mtetra
0 0 0 r
.35529 .4226 .3568 .41345 .35856 .40953 .35752 .40981 Mtetra
.937 .946 .768 r
.35752 .40981 .35856 .40953 .3602 .40796 .3592 .40733 Mtetra
.707 .835 .943 r
.3592 .40733 .3602 .40796 .36178 .4075 .3608 .40661 Mtetra
.569 .736 .955 r
.3608 .40661 .36178 .4075 .36334 .40739 .36237 .40638 Mtetra
.596 .717 .928 r
.36237 .40638 .36334 .40739 .36492 .40715 .36395 .40608 Mtetra
.649 .722 .902 r
.36395 .40608 .36492 .40715 .3665 .40667 .36553 .4056 Mtetra
.649 .723 .903 r
.36553 .4056 .3665 .40667 .36809 .40612 .36712 .40512 Mtetra
.663 .741 .908 r
.36712 .40512 .36809 .40612 .36969 .40537 .36871 .40458 Mtetra
.674 .792 .938 r
.36871 .40458 .36969 .40537 .3713 .40453 .37031 .404 Mtetra
.659 .851 .974 r
.37031 .404 .3713 .40453 .3729 .4039 .3719 .40342 Mtetra
.718 .875 .954 r
.3719 .40342 .3729 .4039 .37447 .40377 .37351 .40263 Mtetra
.709 .727 .865 r
.37351 .40263 .37447 .40377 .37601 .40437 .37511 .40184 Mtetra
.594 .527 .749 r
.37511 .40184 .37601 .40437 .37751 .40607 .3767 .40157 Mtetra
.346 .284 .644 r
.3767 .40157 .37751 .40607 .3787 .4145 .37819 .40335 Mtetra
.966 .7 .477 r
.37819 .40335 .3787 .4145 .37163 .60821 .37113 .59533 Mtetra
0 0 .293 r
.37113 .59533 .37163 .60821 .37315 .61168 .37218 .6093 Mtetra
0 .108 .652 r
.37218 .6093 .37315 .61168 .37478 .61277 .37376 .61143 Mtetra
.512 .634 .907 r
.37376 .61143 .37478 .61277 .37647 .61262 .37544 .61145 Mtetra
.734 .741 .857 r
.37544 .61145 .37647 .61262 .37819 .61175 .37717 .61044 Mtetra
.862 .737 .723 r
.37717 .61044 .37819 .61175 .37996 .6096 .37898 .60742 Mtetra
.921 .691 .574 r
.37898 .60742 .37996 .6096 .38185 .60473 .38124 .5938 Mtetra
.941 .676 .508 r
.38124 .5938 .38185 .60473 .39161 .40887 .39101 .39904 Mtetra
.648 .446 .597 r
.39101 .39904 .39161 .40887 .39348 .40192 .39272 .39604 Mtetra
.601 .438 .634 r
.39272 .39604 .39348 .40192 .39509 .40126 .39433 .39527 Mtetra
.569 .414 .632 r
.39433 .39527 .39509 .40126 .39669 .40118 .39593 .39503 Mtetra
.57 .413 .629 r
.39593 .39503 .39669 .40118 .39834 .39963 .39752 .39476 Mtetra
.597 .451 .653 r
.39752 .39476 .39834 .39963 .40003 .39689 .39914 .39419 Mtetra
.627 .536 .732 r
.39914 .39419 .40003 .39689 .4017 .3948 .40075 .39362 Mtetra
.66 .708 .883 r
.40075 .39362 .4017 .3948 .40334 .39349 .40236 .39308 Mtetra
.606 .872 .992 r
.40236 .39308 .40334 .39349 .40496 .39287 .40397 .39258 Mtetra
.574 .887 .99 r
.40397 .39258 .40496 .39287 .40656 .39247 .40558 .39207 Mtetra
.607 .875 .992 r
.40558 .39207 .40656 .39247 .40817 .39213 .40719 .39156 Mtetra
.644 .841 .976 r
.40719 .39156 .40817 .39213 .40978 .39175 .40881 .39102 Mtetra
.66 .806 .953 r
.40881 .39102 .40978 .39175 .41139 .39136 .41043 .39047 Mtetra
.671 .77 .924 r
.41043 .39047 .41139 .39136 .413 .39092 .41204 .38989 Mtetra
.677 .741 .9 r
.41204 .38989 .413 .39092 .41462 .39039 .41367 .38928 Mtetra
.673 .726 .889 r
.41367 .38928 .41462 .39039 .41624 .3898 .41529 .38868 Mtetra
.701 .732 .875 r
.41529 .38868 .41624 .3898 .41787 .389 .41691 .38794 Mtetra
.723 .749 .872 r
.41691 .38794 .41787 .389 .4195 .38802 .41854 .38708 Mtetra
.621 .745 .936 r
.41854 .38708 .4195 .38802 .42113 .38738 .42016 .38669 Mtetra
.432 0 0 r
.42016 .38669 .42113 .38738 .42272 .38779 .42173 .38784 Mtetra
.933 .609 .399 r
.42173 .38784 .42272 .38779 .42423 .39089 .42302 .39773 Mtetra
.947 .674 .488 r
.42302 .39773 .42423 .39089 .41987 .58449 .41852 .59442 Mtetra
.618 .347 .484 r
.41852 .59442 .41987 .58449 .42133 .5927 .42015 .59706 Mtetra
.5 .191 .375 r
.42015 .59706 .42133 .5927 .42305 .59243 .42187 .59688 Mtetra
.442 .14 .357 r
.42187 .59688 .42305 .59243 .42479 .59148 .42361 .59609 Mtetra
.438 .14 .361 r
.42361 .59609 .42479 .59148 .4265 .59168 .42536 .59523 Mtetra
.457 .133 .327 r
.42536 .59523 .4265 .59168 .42817 .59359 .42709 .59479 Mtetra
.254 0 0 r
.42709 .59479 .42817 .59359 .42985 .59488 .42883 .59434 Mtetra
.599 .848 .991 r
.42883 .59434 .42985 .59488 .43156 .59543 .43056 .59385 Mtetra
.649 .656 .844 r
.43056 .59385 .43156 .59543 .43329 .59523 .4323 .5933 Mtetra
.643 .613 .804 r
.4323 .5933 .43329 .59523 .43503 .59479 .43405 .59273 Mtetra
.617 .588 .798 r
.43405 .59273 .43503 .59479 .43677 .59431 .43579 .59232 Mtetra
.567 .57 .816 r
.43579 .59232 .43677 .59431 .43851 .59394 .43752 .5922 Mtetra
.649 .637 .825 r
.43752 .5922 .43851 .59394 .44026 .59323 .43926 .59162 Mtetra
.799 .705 .761 r
.43926 .59162 .44026 .59323 .44203 .59162 .44104 .58963 Mtetra
.91 .699 .606 r
.44104 .58963 .44203 .59162 .44386 .5875 .44298 .58142 Mtetra
.953 .684 .488 r
.44298 .58142 .44386 .5875 .44594 .57235 .44944 .38051 Mtetra
.552 .333 .536 r
.44944 .38051 .44594 .57235 .45198 .38271 .45116 .37644 Mtetra
.606 .438 .628 r
.45116 .37644 .45198 .38271 .45364 .38174 .45281 .37549 Mtetra
.574 .415 .629 r
.45281 .37549 .45364 .38174 .45527 .38158 .45445 .37515 Mtetra
.564 .407 .626 r
.45445 .37515 .45527 .38158 .45693 .38055 .45609 .37496 Mtetra
.593 .437 .639 r
.45609 .37496 .45693 .38055 .45863 .37753 .45773 .37436 Mtetra
.62 .512 .709 r
.45773 .37436 .45863 .37753 .46031 .37524 .45938 .37377 Mtetra
.659 .663 .843 r
.45938 .37377 .46031 .37524 .46198 .37368 .46103 .37319 Mtetra
.627 .862 .987 r
.46103 .37319 .46198 .37368 .46362 .37298 .46267 .37265 Mtetra
.587 .888 .99 r
.46267 .37265 .46362 .37298 .46527 .37251 .46432 .37212 Mtetra
.603 .881 .992 r
.46432 .37212 .46527 .37251 .46692 .3721 .46597 .37159 Mtetra
.635 .86 .984 r
.46597 .37159 .46692 .3721 .46857 .37154 .46762 .37103 Mtetra
.636 .862 .984 r
.46762 .37103 .46857 .37154 .47022 .371 .46927 .37047 Mtetra
.64 .858 .982 r
.46927 .37047 .47022 .371 .47187 .3705 .47093 .36991 Mtetra
.647 .844 .976 r
.47093 .36991 .47187 .3705 .47352 .37008 .47258 .36935 Mtetra
.659 .81 .956 r
.47258 .36935 .47352 .37008 .47517 .36968 .47424 .36878 Mtetra
.666 .774 .93 r
.47424 .36878 .47517 .36968 .47683 .36924 .47589 .36821 Mtetra
.671 .745 .906 r
.47589 .36821 .47683 .36924 .47848 .36871 .47755 .36761 Mtetra
.669 .73 .895 r
.47755 .36761 .47848 .36871 .48014 .36813 .47921 .36702 Mtetra
.665 .727 .896 r
.47921 .36702 .48014 .36813 .4818 .36748 .48087 .36644 Mtetra
.655 .738 .911 r
.48087 .36644 .4818 .36748 .48346 .36675 .48253 .36592 Mtetra
.65 .784 .946 r
.48253 .36592 .48346 .36675 .48512 .366 .48419 .36539 Mtetra
.639 .838 .977 r
.48419 .36539 .48512 .366 .48679 .36528 .48585 .36485 Mtetra
.633 .882 .987 r
.48585 .36485 .48679 .36528 .48845 .36467 .48751 .36426 Mtetra
.633 .888 .987 r
.48751 .36426 .48845 .36467 .49011 .36408 .48918 .36366 Mtetra
.636 .884 .986 r
.48918 .36366 .49011 .36408 .49178 .36351 .49084 .36306 Mtetra
.632 .876 .987 r
.49084 .36306 .49178 .36351 .49344 .36294 .49251 .36248 Mtetra
.63 .875 .987 r
.49251 .36248 .49344 .36294 .49511 .36237 .49418 .36191 Mtetra
.628 .874 .988 r
.49418 .36191 .49511 .36237 .49678 .3618 .49585 .36134 Mtetra
.627 .873 .988 r
.49585 .36134 .49678 .3618 .49844 .36123 .49751 .36077 Mtetra
.626 .873 .988 r
.49751 .36077 .49844 .36123 .50011 .36067 .49918 .36021 Mtetra
.624 .873 .989 r
.49918 .36021 .50011 .36067 .50178 .3601 .50086 .35965 Mtetra
.623 .874 .989 r
.50086 .35965 .50178 .3601 .50345 .35954 .50253 .35909 Mtetra
.621 .874 .989 r
.50253 .35909 .50345 .35954 .50513 .35898 .5042 .35853 Mtetra
.618 .874 .99 r
.5042 .35853 .50513 .35898 .5068 .35842 .50588 .35798 Mtetra
.609 .873 .991 r
.50588 .35798 .5068 .35842 .50847 .35785 .50755 .35745 Mtetra
.604 .88 .992 r
.50755 .35745 .50847 .35785 .51015 .3573 .50923 .35691 Mtetra
.609 .884 .99 r
.50923 .35691 .51015 .3573 .51182 .35678 .5109 .35635 Mtetra
.641 .885 .985 r
.5109 .35635 .51182 .35678 .5135 .35638 .51258 .35573 Mtetra
.669 .838 .965 r
.51258 .35573 .5135 .35638 .51518 .35597 .51426 .3551 Mtetra
.675 .785 .933 r
.51426 .3551 .51518 .35597 .51686 .35552 .51594 .35448 Mtetra
.663 .745 .911 r
.51594 .35448 .51686 .35552 .51854 .35485 .51762 .35391 Mtetra
.66 .766 .929 r
.51762 .35391 .51854 .35485 .52022 .35413 .51931 .35335 Mtetra
.654 .803 .954 r
.51931 .35335 .52022 .35413 .5219 .3534 .52099 .3528 Mtetra
.647 .844 .976 r
.52099 .3528 .5219 .3534 .52359 .35279 .52267 .35223 Mtetra
.643 .854 .98 r
.52267 .35223 .52359 .35279 .52527 .3522 .52436 .35165 Mtetra
.643 .858 .981 r
.52436 .35165 .52527 .3522 .52696 .35162 .52605 .35107 Mtetra
.65 .858 .979 r
.52605 .35107 .52696 .35162 .52865 .35088 .52773 .35047 Mtetra
.626 .887 .988 r
.52773 .35047 .52865 .35088 .53033 .35026 .52942 .34987 Mtetra
.617 .889 .989 r
.52942 .34987 .53033 .35026 .53202 .34989 .53111 .34928 Mtetra
.637 .841 .979 r
.53111 .34928 .53202 .34989 .53371 .35052 .5328 .34874 Mtetra
.642 .621 .814 r
.5328 .34874 .53371 .35052 .53541 .35176 .53449 .3482 Mtetra
.608 .491 .695 r
.53449 .3482 .53541 .35176 .53712 .35369 .53619 .34766 Mtetra
.611 .445 .632 r
.53619 .34766 .53712 .35369 .53881 .35295 .53788 .34664 Mtetra
.593 .429 .629 r
.53788 .34664 .53881 .35295 .54051 .35206 .53957 .34593 Mtetra
.556 .406 .632 r
.53957 .34593 .54051 .35206 .54221 .35213 .54127 .34589 Mtetra
.209 .16 .581 r
.54127 .34589 .54221 .35213 .54508 .54809 .543 .34984 Mtetra
0 0 .351 r
.543 .34984 .54508 .54809 .54695 .55719 .54596 .55228 Mtetra
0 0 .458 r
.54596 .55228 .54695 .55719 .54879 .55985 .54782 .55799 Mtetra
.437 .52 .845 r
.54782 .55799 .54879 .55985 .55061 .5599 .54964 .55842 Mtetra
.642 .675 .866 r
.54964 .55842 .55061 .5599 .55242 .55931 .55146 .5579 Mtetra
.712 .711 .847 r
.55146 .5579 .55242 .55931 .55424 .55843 .55327 .55695 Mtetra
.648 .677 .864 r
.55327 .55695 .55424 .55843 .55606 .55802 .55509 .55639 Mtetra
.642 .654 .846 r
.55509 .55639 .55606 .55802 .55788 .55754 .55691 .55585 Mtetra
.646 .649 .838 r
.55691 .55585 .55788 .55754 .5597 .55679 .55873 .55528 Mtetra
.566 .637 .88 r
.55873 .55528 .5597 .55679 .56151 .55539 .56056 .55512 Mtetra
.483 .868 .975 r
.56056 .55512 .56151 .55539 .56332 .55321 .56239 .55466 Mtetra
.061 0 0 r
.56239 .55466 .56332 .55321 .5651 .54946 .5642 .5535 Mtetra
0 0 .061 r
.5642 .5535 .5651 .54946 .56446 .35116 .56597 .54841 Mtetra
0 0 .347 r
.56597 .54841 .56446 .35116 .56605 .34135 .56521 .34472 Mtetra
.727 .721 .194 r
.56521 .34472 .56605 .34135 .56773 .33805 .56684 .33782 Mtetra
.862 .951 .87 r
.56684 .33782 .56773 .33805 .56943 .33696 .56854 .33619 Mtetra
.665 .812 .954 r
.56854 .33619 .56943 .33696 .57115 .33656 .57026 .33559 Mtetra
.552 .72 .951 r
.57026 .33559 .57115 .33656 .57287 .33646 .57198 .33539 Mtetra
.637 .732 .916 r
.57198 .33539 .57287 .33646 .57459 .33604 .57369 .33491 Mtetra
.652 .727 .904 r
.57369 .33491 .57459 .33604 .57631 .3355 .57541 .33438 Mtetra
.653 .73 .905 r
.57541 .33438 .57631 .3355 .57802 .33489 .57713 .33384 Mtetra
.671 .75 .91 r
.57713 .33384 .57802 .33489 .57974 .33401 .57885 .33323 Mtetra
.673 .811 .949 r
.57885 .33323 .57974 .33401 .58145 .33318 .58057 .33259 Mtetra
.656 .857 .976 r
.58057 .33259 .58145 .33318 .58317 .33259 .58229 .33197 Mtetra
.744 .867 .937 r
.58229 .33197 .58317 .33259 .5849 .33266 .584 .33102 Mtetra
.675 .656 .824 r
.584 .33102 .5849 .33266 .58665 .33347 .58573 .3303 Mtetra
.568 .483 .719 r
.58573 .3303 .58665 .33347 .58844 .33572 .58746 .33019 Mtetra
.271 .218 .613 r
.58746 .33019 .58844 .33572 .59423 .53182 .58926 .33329 Mtetra
0 0 .372 r
.58926 .33329 .59423 .53182 .5963 .5421 .59524 .53557 Mtetra
0 0 .473 r
.59524 .53557 .5963 .5421 .59821 .54476 .59724 .54263 Mtetra
.35 .438 .811 r
.59724 .54263 .59821 .54476 .60008 .54505 .59912 .54351 Mtetra
.628 .662 .864 r
.59912 .54351 .60008 .54505 .60193 .5445 .60098 .54305 Mtetra
.707 .708 .848 r
.60098 .54305 .60193 .5445 .60377 .54362 .60282 .54212 Mtetra
.664 .684 .859 r
.60282 .54212 .60377 .54362 .60562 .54311 .60467 .54146 Mtetra
.642 .655 .847 r
.60467 .54146 .60562 .54311 .60748 .54264 .60652 .54091 Mtetra
.645 .646 .837 r
.60652 .54091 .60748 .54264 .60933 .54193 .60838 .54034 Mtetra
.575 .633 .871 r
.60838 .54034 .60933 .54193 .61116 .54062 .61024 .54014 Mtetra
.504 .837 .998 r
.61024 .54014 .61116 .54062 .61298 .53859 .6121 .53978 Mtetra
.046 0 0 r
.6121 .53978 .61298 .53859 .61476 .53526 .61395 .53876 Mtetra
0 0 .081 r
.61395 .53876 .61476 .53526 .61624 .52082 .61571 .53456 Mtetra
.984 .703 .394 r
.61571 .53456 .61624 .52082 .6127 .32694 .61197 .33128 Mtetra
0 0 0 r
.61197 .33128 .6127 .32694 .61435 .32307 .61348 .3224 Mtetra
.884 .858 .81 r
.61348 .3224 .61435 .32307 .61606 .32157 .61518 .32035 Mtetra
.673 .719 .884 r
.61518 .32035 .61606 .32157 .6178 .32095 .61692 .3197 Mtetra
.569 .671 .908 r
.61692 .3197 .6178 .32095 .61955 .32062 .61868 .31951 Mtetra
.629 .725 .916 r
.61868 .31951 .61955 .32062 .62129 .31989 .62043 .31906 Mtetra
.668 .801 .946 r
.62043 .31906 .62129 .31989 .62303 .31905 .62217 .31844 Mtetra
.649 .853 .978 r
.62217 .31844 .62303 .31905 .62478 .31842 .62392 .31782 Mtetra
.73 .876 .949 r
.62392 .31782 .62478 .31842 .62654 .31838 .62566 .31693 Mtetra
.69 .69 .844 r
.62566 .31693 .62654 .31838 .62833 .31907 .6274 .31614 Mtetra
.582 .504 .732 r
.6274 .31614 .62833 .31907 .63017 .32101 .62916 .31592 Mtetra
.335 .272 .637 r
.62916 .31592 .63017 .32101 .63816 .50351 .63102 .3183 Mtetra
0 0 .371 r
.63102 .3183 .63816 .50351 .64088 .52799 .63969 .51918 Mtetra
0 0 .461 r
.63969 .51918 .64088 .52799 .64288 .53104 .64191 .52866 Mtetra
.257 .356 .774 r
.64191 .52866 .64288 .53104 .6448 .53173 .64386 .53005 Mtetra
.604 .635 .855 r
.64386 .53005 .6448 .53173 .64669 .53134 .64575 .52971 Mtetra
.691 .68 .834 r
.64575 .52971 .64669 .53134 .64856 .53039 .64762 .52884 Mtetra
.626 .663 .866 r
.64762 .52884 .64856 .53039 .65041 .52902 .6495 .52838 Mtetra
.542 .816 .997 r
.6495 .52838 .65041 .52902 .65224 .52707 .65139 .52802 Mtetra
0 0 0 r
.65139 .52802 .65224 .52707 .65402 .52389 .65326 .52705 Mtetra
0 0 .1 r
.65326 .52705 .65402 .52389 .65547 .51236 .65503 .52349 Mtetra
.983 .698 .382 r
.65503 .52349 .65547 .51236 .64951 .31445 .64908 .32432 Mtetra
0 0 .198 r
.64908 .32432 .64951 .31445 .65114 .31037 .65033 .3106 Mtetra
.922 .976 .725 r
.65033 .3106 .65114 .31037 .65286 .30876 .65201 .30805 Mtetra
.704 .847 .951 r
.65201 .30805 .65286 .30876 .65463 .30823 .65377 .30727 Mtetra
.579 .739 .952 r
.65377 .30727 .65463 .30823 .65641 .30806 .65555 .30697 Mtetra
.617 .725 .923 r
.65555 .30697 .65641 .30806 .65818 .30762 .65733 .30656 Mtetra
.665 .751 .914 r
.65733 .30656 .65818 .30762 .65995 .30692 .6591 .30595 Mtetra
.66 .77 .931 r
.6591 .30595 .65995 .30692 .66172 .30638 .66087 .30536 Mtetra
.715 .778 .902 r
.66087 .30536 .66172 .30638 .66351 .30627 .66263 .30452 Mtetra
.685 .651 .81 r
.66263 .30452 .66351 .30627 .66533 .30681 .66439 .30368 Mtetra
.59 .5 .721 r
.66439 .30368 .66533 .30681 .66721 .30846 .66618 .30336 Mtetra
.393 .313 .647 r
.66618 .30336 .66721 .30846 .6695 .31907 .66806 .30525 Mtetra
.981 .688 .346 r
.66806 .30525 .6695 .31907 .68047 .51553 .67904 .50309 Mtetra
0 0 .454 r
.67904 .50309 .68047 .51553 .68256 .51888 .68158 .51626 Mtetra
.2 .298 .741 r
.68158 .51626 .68256 .51888 .68453 .51978 .6836 .51808 Mtetra
.59 .627 .856 r
.6836 .51808 .68453 .51978 .68645 .51945 .68552 .5178 Mtetra
.685 .679 .838 r
.68552 .5178 .68645 .51945 .68834 .51854 .68741 .51696 Mtetra
.644 .67 .86 r
.68741 .51696 .68834 .51854 .69021 .51719 .68932 .5164 Mtetra
.545 .784 .987 r
.68932 .5164 .69021 .51719 .69205 .51529 .69124 .51609 Mtetra
0 0 0 r
.69124 .51609 .69205 .51529 .69384 .51229 .69314 .5152 Mtetra
0 0 .112 r
.69314 .5152 .69384 .51229 .69536 .5042 .69492 .51208 Mtetra
.803 .661 .11 r
.69492 .51208 .69536 .5042 .68687 .30301 .69577 .49082 Mtetra
0 0 .398 r
.69577 .49082 .68687 .30301 .68845 .29837 .68765 .29812 Mtetra
.957 .91 .729 r
.68765 .29812 .68845 .29837 .69016 .29629 .68931 .29516 Mtetra
.715 .758 .886 r
.68931 .29516 .69016 .29629 .69193 .29541 .69109 .29429 Mtetra
.6 .716 .926 r
.69109 .29429 .69193 .29541 .69373 .29504 .69289 .29395 Mtetra
.653 .743 .916 r
.69289 .29395 .69373 .29504 .69556 .29504 .69469 .29338 Mtetra
.696 .669 .82 r
.69469 .29338 .69556 .29504 .69741 .29545 .69646 .29249 Mtetra
.601 .516 .73 r
.69646 .29249 .69741 .29545 .69931 .29675 .69827 .29209 Mtetra
.432 .35 .663 r
.69827 .29209 .69931 .29675 .70143 .30192 .70018 .29347 Mtetra
0 0 .395 r
.70018 .29347 .70143 .30192 .71475 .50304 .70267 .30515 Mtetra
.003 0 .417 r
.70267 .30515 .71475 .50304 .71695 .50737 .716 .50517 Mtetra
0 .175 .701 r
.716 .50517 .71695 .50737 .71898 .50861 .7181 .50755 Mtetra
.554 .724 .953 r
.7181 .50755 .71898 .50861 .72093 .50838 .72005 .50731 Mtetra
.704 .782 .912 r
.72005 .50731 .72093 .50838 .72285 .50756 .72196 .50646 Mtetra
.667 .763 .922 r
.72196 .50646 .72285 .50756 .72474 .50631 .72389 .50579 Mtetra
.429 .796 .995 r
.72389 .50579 .72474 .50631 .7266 .50462 .72584 .50557 Mtetra
.097 0 0 r
.72584 .50557 .7266 .50462 .72841 .50197 .72777 .50482 Mtetra
.067 0 .155 r
.72777 .50482 .72841 .50197 .72999 .49562 .72958 .50221 Mtetra
0 0 .106 r
.72958 .50221 .72999 .49562 .71932 .29321 .73084 .49076 Mtetra
0 0 .41 r
.73084 .49076 .71932 .29321 .72084 .28793 .72008 .28792 Mtetra
.975 .919 .669 r
.72008 .28792 .72084 .28793 .72254 .28568 .72171 .28445 Mtetra
.72 .746 .872 r
.72171 .28445 .72254 .28568 .72434 .28485 .7235 .28353 Mtetra
.61 .682 .893 r
.7235 .28353 .72434 .28485 .72616 .28441 .72532 .28316 Mtetra
.642 .709 .896 r
.72532 .28316 .72616 .28441 .72797 .2838 .72714 .28264 Mtetra
.742 .765 .871 r
.72714 .28264 .72797 .2838 .72976 .28275 .72893 .28159 Mtetra
.655 .734 .908 r
.72893 .28159 .72976 .28275 .73157 .28216 .73074 .28102 Mtetra
.118 .434 .874 r
.73074 .28102 .73157 .28216 .73349 .2831 .73266 .28195 Mtetra
.907 .524 .093 r
.73266 .28195 .73349 .2831 .73589 .29103 .73506 .28987 Mtetra
.975 .671 .352 r
.73506 .28987 .73589 .29103 .7517 .49504 .75083 .49395 Mtetra
.596 .134 0 r
.75083 .49395 .7517 .49504 .75389 .49797 .75302 .49688 Mtetra
.554 .721 .951 r
.75302 .49688 .75389 .49797 .75586 .49773 .75499 .49664 Mtetra
.713 .785 .909 r
.75499 .49664 .75586 .49773 .7578 .49682 .75693 .49573 Mtetra
.696 .779 .916 r
.75693 .49573 .7578 .49682 .75974 .49601 .75887 .49492 Mtetra
.512 .7 .955 r
.75887 .49492 .75974 .49601 .76173 .49591 .76086 .49482 Mtetra
.654 .763 .93 r
.76086 .49482 .76173 .49591 .76368 .49529 .76281 .4942 Mtetra
.867 .815 .796 r
.76281 .4942 .76368 .49529 .76552 .49306 .76465 .49196 Mtetra
.98 .75 .518 r
.76465 .49196 .76552 .49306 .76678 .48296 .76592 .48181 Mtetra
.977 .678 .362 r
.76592 .48181 .76678 .48296 .75367 .27818 .75286 .27702 Mtetra
.932 .787 .678 r
.75286 .27702 .75367 .27818 .75526 .27434 .75445 .27319 Mtetra
.727 .764 .882 r
.75445 .27319 .75526 .27434 .75707 .27339 .75625 .27223 Mtetra
.601 .714 .923 r
.75625 .27223 .75707 .27339 .75892 .27303 .75811 .27188 Mtetra
.6 .713 .924 r
.75811 .27188 .75892 .27303 .76077 .27267 .75996 .27152 Mtetra
.739 .768 .876 r
.75996 .27152 .76077 .27267 .76257 .27164 .76176 .27049 Mtetra
.656 .738 .91 r
.76176 .27049 .76257 .27164 .76441 .27105 .7636 .2699 Mtetra
.234 .51 .907 r
.7636 .2699 .76441 .27105 .76635 .27175 .76554 .2706 Mtetra
.883 .491 .035 r
.76554 .2706 .76635 .27175 .7688 .27898 .76799 .27784 Mtetra
.975 .667 .334 r
.76799 .27784 .7688 .27898 .78697 .48429 .78611 .4832 Mtetra
.657 .203 0 r
.78611 .4832 .78697 .48429 .78926 .48775 .78841 .48666 Mtetra
.381 .631 .952 r
.78841 .48666 .78926 .48775 .79131 .48803 .79046 .48694 Mtetra
.693 .782 .919 r
.79046 .48694 .79131 .48803 .79327 .48721 .79242 .48612 Mtetra
.875 .821 .792 r
.79242 .48612 .79327 .48721 .79511 .48489 .79426 .48381 Mtetra
.979 .767 .549 r
.79426 .48381 .79511 .48489 .79648 .4769 .79564 .47588 Mtetra
.977 .675 .347 r
.79564 .47588 .79648 .4769 .78132 .26966 .78052 .26856 Mtetra
.953 .79 .642 r
.78052 .26856 .78132 .26966 .78285 .26514 .78204 .26401 Mtetra
.745 .777 .879 r
.78204 .26401 .78285 .26514 .78466 .26409 .78386 .26295 Mtetra
.615 .724 .924 r
.78386 .26295 .78466 .26409 .78652 .26368 .78572 .26253 Mtetra
.581 .707 .929 r
.78572 .26253 .78652 .26368 .7884 .2634 .7876 .26224 Mtetra
.745 .773 .875 r
.7876 .26224 .7884 .2634 .79021 .26232 .78942 .26117 Mtetra
.669 .746 .908 r
.78942 .26117 .79021 .26232 .79207 .26168 .79127 .26052 Mtetra
.351 .58 .928 r
.79127 .26052 .79207 .26168 .79402 .26216 .79321 .26094 Mtetra
.828 .424 0 r
.79321 .26094 .79402 .26216 .79654 .26913 .79565 .267 Mtetra
.973 .663 .315 r
.79565 .267 .79654 .26913 .81671 .47544 .8158 .47356 Mtetra
0 0 .48 r
.8158 .47356 .81671 .47544 .81908 .47902 .8182 .47746 Mtetra
.537 .627 .888 r
.8182 .47746 .81908 .47902 .82111 .47878 .82024 .4774 Mtetra
.682 .725 .883 r
.82024 .4774 .82111 .47878 .82307 .47784 .82223 .47661 Mtetra
.726 .77 .888 r
.82223 .47661 .82307 .47784 .82503 .47674 .82419 .47559 Mtetra
.531 .702 .949 r
.82419 .47559 .82503 .47674 .82709 .4768 .82623 .47544 Mtetra
.646 .714 .898 r
.82623 .47544 .82709 .4768 .82911 .47644 .82824 .47485 Mtetra
.78 .733 .809 r
.82824 .47485 .82911 .47644 .83105 .47507 .83015 .47324 Mtetra
.949 .738 .584 r
.83015 .47324 .83105 .47507 .83253 .46882 .83157 .46635 Mtetra
.976 .67 .333 r
.83157 .46635 .83253 .46882 .81493 .2599 .81409 .25822 Mtetra
.935 .743 .618 r
.81409 .25822 .81493 .2599 .81631 .25407 .81552 .25294 Mtetra
.763 .786 .872 r
.81552 .25294 .81631 .25407 .81812 .25287 .81734 .25176 Mtetra
.631 .741 .927 r
.81734 .25176 .81812 .25287 .82001 .25239 .81922 .25126 Mtetra
.56 .705 .938 r
.81922 .25126 .82001 .25239 .82192 .2522 .82114 .25104 Mtetra
.754 .779 .873 r
.82114 .25104 .82192 .2522 .82375 .25108 .82296 .24991 Mtetra
.683 .751 .903 r
.82296 .24991 .82375 .25108 .82561 .25036 .82483 .24918 Mtetra
.46 .64 .934 r
.82483 .24918 .82561 .25036 .82756 .25049 .82678 .2493 Mtetra
.773 .359 0 r
.82678 .2493 .82756 .25049 .83003 .25583 .82924 .25459 Mtetra
.971 .657 .298 r
.82924 .25459 .83003 .25583 .85267 .46326 .85184 .46208 Mtetra
.708 .277 0 r
.85184 .46208 .85267 .46326 .8552 .46777 .85437 .46662 Mtetra
.319 .582 .937 r
.85437 .46662 .8552 .46777 .85733 .46824 .85651 .4671 Mtetra
.652 .762 .93 r
.85651 .4671 .85733 .46824 .85935 .4676 .85853 .46647 Mtetra
.831 .819 .838 r
.85853 .46647 .85935 .4676 .86125 .4658 .86044 .46468 Mtetra
.976 .788 .586 r
.86044 .46468 .86125 .4658 .86271 .45966 .8619 .45857 Mtetra
.974 .667 .312 r
.8619 .45857 .86271 .45966 .84316 .25069 .84239 .24958 Mtetra
.977 .779 .573 r
.84239 .24958 .84316 .25069 .84447 .24457 .8437 .24342 Mtetra
.764 .764 .853 r
.23571 .44845 .23673 .44937 .2383 .44829 .23727 .44738 Mtetra
.618 .739 .933 r
.23727 .44738 .2383 .44829 .2398 .44792 .23877 .44703 Mtetra
.457 .685 .964 r
.23877 .44703 .2398 .44792 .24127 .44792 .24024 .44706 Mtetra
.647 .757 .929 r
.24024 .44706 .24127 .44792 .24279 .44741 .24176 .4466 Mtetra
.658 .772 .933 r
.24176 .4466 .24279 .44741 .24431 .44689 .24327 .4461 Mtetra
.674 .781 .93 r
.24327 .4461 .24431 .44689 .24583 .44636 .2448 .44555 Mtetra
.711 .78 .906 r
.2448 .44555 .24583 .44636 .24735 .44586 .24633 .44483 Mtetra
.709 .736 .872 r
.24633 .44483 .24735 .44586 .24887 .44535 .24788 .44408 Mtetra
.696 .692 .843 r
.24788 .44408 .24887 .44535 .25039 .44484 .24942 .44335 Mtetra
.711 .668 .806 r
.24942 .44335 .25039 .44484 .25195 .44385 .25097 .44244 Mtetra
.678 .668 .832 r
.25097 .44244 .25195 .44385 .25349 .44316 .25251 .44179 Mtetra
.578 .634 .87 r
.25251 .44179 .25349 .44316 .25497 .44315 .254 .44161 Mtetra
0 0 .407 r
.254 .44161 .25497 .44315 .25612 .44717 .25532 .44363 Mtetra
.928 .632 .159 r
.25532 .44363 .25612 .44717 .24148 .64443 .25622 .45073 Mtetra
0 0 .193 r
.25622 .45073 .24148 .64443 .24262 .64981 .24198 .6435 Mtetra
.472 .342 .623 r
.24198 .6435 .24262 .64981 .24417 .65022 .24347 .6446 Mtetra
.594 .44 .642 r
.24347 .6446 .24417 .65022 .2458 .64969 .2451 .64399 Mtetra
.635 .468 .64 r
.2451 .64399 .2458 .64969 .24746 .64874 .24679 .64264 Mtetra
.593 .433 .634 r
.24679 .64264 .24746 .64874 .24908 .64819 .24842 .64199 Mtetra
.587 .428 .633 r
.24842 .64199 .24908 .64819 .25071 .64768 .25005 .64144 Mtetra
.587 .427 .632 r
.25005 .64144 .25071 .64768 .25234 .64718 .25168 .6409 Mtetra
.585 .425 .632 r
.25168 .6409 .25234 .64718 .25396 .64669 .2533 .64038 Mtetra
.584 .424 .631 r
.2533 .64038 .25396 .64669 .25559 .6462 .25493 .63988 Mtetra
.583 .424 .631 r
.25493 .63988 .25559 .6462 .25722 .64571 .25656 .63938 Mtetra
.609 .442 .631 r
.25656 .63938 .25722 .64571 .25885 .64521 .25822 .63841 Mtetra
.592 .426 .625 r
.25822 .63841 .25885 .64521 .26048 .64469 .25987 .6377 Mtetra
.549 .392 .62 r
.25987 .6377 .26048 .64469 .26211 .64419 .26146 .63776 Mtetra
.396 .286 .61 r
.26146 .63776 .26211 .64419 .26374 .64374 .2629 .6397 Mtetra
.334 .295 .665 r
.2629 .6397 .26374 .64374 .26537 .6433 .26438 .64128 Mtetra
.263 .388 .802 r
.26438 .64128 .26537 .6433 .26701 .64286 .26591 .64222 Mtetra
.455 .761 .995 r
.26591 .64222 .26701 .64286 .26864 .64239 .26752 .64211 Mtetra
.566 .885 .99 r
.26752 .64211 .26864 .64239 .27028 .6419 .26915 .64161 Mtetra
.63 .902 .985 r
.26915 .64161 .27028 .6419 .27192 .64139 .2708 .64099 Mtetra
.541 .852 .998 r
.2708 .64099 .27192 .64139 .27356 .64084 .27243 .6406 Mtetra
.442 .844 .974 r
.27243 .6406 .27356 .64084 .2752 .64027 .27406 .64027 Mtetra
.337 .815 .883 r
.27406 .64027 .2752 .64027 .27685 .63972 .27569 .63991 Mtetra
.351 .827 .82 r
.27569 .63991 .27685 .63972 .27849 .63924 .27734 .63938 Mtetra
.445 .88 .872 r
.27734 .63938 .27849 .63924 .28013 .63878 .27899 .63877 Mtetra
.542 .916 .943 r
.27899 .63877 .28013 .63878 .28177 .63833 .28065 .63813 Mtetra
.377 .819 .951 r
.28065 .63813 .28177 .63833 .28339 .63825 .28228 .63786 Mtetra
.518 .847 .997 r
.28228 .63786 .28339 .63825 .28502 .63796 .28391 .6375 Mtetra
.71 .88 .96 r
.28391 .6375 .28502 .63796 .2867 .63701 .28558 .63671 Mtetra
.913 .847 .764 r
.28558 .63671 .2867 .63701 .2886 .63276 .28739 .63397 Mtetra
.99 .851 .607 r
.28739 .63397 .2886 .63276 .30368 .43456 .28945 .62746 Mtetra
0 0 .203 r
.28945 .62746 .30368 .43456 .30573 .42662 .30434 .43148 Mtetra
.088 0 .223 r
.30434 .43148 .30573 .42662 .30738 .42478 .30608 .42826 Mtetra
.432 .113 .323 r
.30608 .42826 .30738 .42478 .30894 .4242 .30765 .42765 Mtetra
.531 .209 .366 r
.30765 .42765 .30894 .4242 .31047 .42405 .30916 .42785 Mtetra
.532 .218 .38 r
.30916 .42785 .31047 .42405 .31202 .4237 .31067 .42803 Mtetra
.504 .201 .386 r
.31067 .42803 .31202 .4237 .31357 .42322 .31221 .42788 Mtetra
.439 .146 .37 r
.31221 .42788 .31357 .42322 .31513 .42274 .31379 .42705 Mtetra
.136 0 .226 r
.31379 .42705 .31513 .42274 .31669 .42221 .31549 .4244 Mtetra
0 0 0 r
.31549 .4244 .31669 .42221 .31825 .42165 .31718 .42187 Mtetra
.894 .969 .825 r
.31718 .42187 .31825 .42165 .31982 .42108 .31883 .41997 Mtetra
.732 .734 .853 r
.31883 .41997 .31982 .42108 .32138 .42054 .32042 .41906 Mtetra
.632 .643 .843 r
.32042 .41906 .32138 .42054 .32294 .42003 .32198 .41864 Mtetra
.597 .643 .867 r
.32198 .41864 .32294 .42003 .32451 .41951 .32353 .41839 Mtetra
.632 .703 .897 r
.32353 .41839 .32451 .41951 .32608 .41895 .32509 .41798 Mtetra
.664 .745 .91 r
.32509 .41798 .32608 .41895 .32765 .41837 .32665 .41745 Mtetra
.677 .758 .912 r
.32665 .41745 .32765 .41837 .32922 .4178 .32823 .41686 Mtetra
.739 .767 .875 r
.32823 .41686 .32922 .4178 .3308 .41697 .32982 .41595 Mtetra
.731 .75 .868 r
.32982 .41595 .3308 .41697 .33238 .41625 .33141 .41507 Mtetra
.649 .699 .883 r
.33141 .41507 .33238 .41625 .33393 .41607 .33298 .41459 Mtetra
.106 .36 .825 r
.33298 .41459 .33393 .41607 .33534 .4184 .33446 .41555 Mtetra
0 0 .322 r
.33446 .41555 .33534 .4184 .32555 .61376 .33579 .41925 Mtetra
0 0 .243 r
.33579 .41925 .32555 .61376 .32663 .62339 .32603 .61468 Mtetra
.116 .058 .509 r
.32603 .61468 .32663 .62339 .3282 .62479 .32734 .6204 Mtetra
.355 .3 .657 r
.32734 .6204 .3282 .62479 .32986 .62447 .32889 .62204 Mtetra
.424 .444 .777 r
.32889 .62204 .32986 .62447 .33155 .62365 .3305 .62267 Mtetra
.536 .714 .954 r
.3305 .62267 .33155 .62365 .33324 .62296 .33216 .62252 Mtetra
.649 .876 .983 r
.33216 .62252 .33324 .62296 .33492 .62246 .33384 .62189 Mtetra
.712 .859 .952 r
.33384 .62189 .33492 .62246 .3366 .62193 .33554 .6211 Mtetra
.584 .767 .966 r
.33554 .6211 .3366 .62193 .33826 .62168 .33721 .62077 Mtetra
.518 .724 .967 r
.33721 .62077 .33826 .62168 .33993 .6214 .33887 .62064 Mtetra
.649 .803 .957 r
.33887 .62064 .33993 .6214 .34163 .62054 .34055 .62011 Mtetra
.879 .864 .82 r
.34055 .62011 .34163 .62054 .34346 .61718 .34232 .61808 Mtetra
.986 .887 .637 r
.34232 .61808 .34346 .61718 .35529 .4226 .34423 .61316 Mtetra
0 0 .23 r
.34423 .61316 .35529 .4226 .35752 .40981 .35613 .41666 Mtetra
0 0 .109 r
.35613 .41666 .35752 .40981 .3592 .40733 .35806 .40957 Mtetra
0 0 0 r
.35806 .40957 .3592 .40733 .3608 .40661 .35975 .40703 Mtetra
.799 .999 .813 r
.35975 .40703 .3608 .40661 .36237 .40638 .36139 .40545 Mtetra
.734 .772 .884 r
.36139 .40545 .36237 .40638 .36395 .40608 .363 .40457 Mtetra
.631 .641 .842 r
.363 .40457 .36395 .40608 .36553 .4056 .36458 .40416 Mtetra
.59 .634 .863 r
.36458 .40416 .36553 .4056 .36712 .40512 .36616 .40393 Mtetra
.613 .686 .895 r
.36616 .40393 .36712 .40512 .36871 .40458 .36774 .4036 Mtetra
.658 .742 .912 r
.36774 .4036 .36871 .40458 .37031 .404 .36933 .40308 Mtetra
.672 .761 .917 r
.36933 .40308 .37031 .404 .3719 .40342 .37093 .4025 Mtetra
.729 .774 .889 r
.37093 .4025 .3719 .40342 .37351 .40263 .37253 .40165 Mtetra
.739 .763 .872 r
.37253 .40165 .37351 .40263 .37511 .40184 .37415 .40072 Mtetra
.664 .717 .888 r
.37415 .40072 .37511 .40184 .3767 .40157 .37575 .40017 Mtetra
.181 .423 .858 r
.37575 .40017 .3767 .40157 .37819 .40335 .37728 .40097 Mtetra
.706 .372 0 r
.37728 .40097 .37819 .40335 .37113 .59533 .37868 .40486 Mtetra
0 0 .258 r
.37868 .40486 .37113 .59533 .37218 .6093 .37147 .6009 Mtetra
.185 .114 .538 r
.37147 .6009 .37218 .6093 .37376 .61143 .37292 .60593 Mtetra
.531 .399 .646 r
.37292 .60593 .37376 .61143 .37544 .61145 .37459 .60625 Mtetra
.637 .478 .65 r
.37459 .60625 .37544 .61145 .37717 .61044 .37633 .60495 Mtetra
.773 .567 .62 r
.37633 .60495 .37717 .61044 .37898 .60742 .37825 .59936 Mtetra
.944 .68 .506 r
.37825 .59936 .37898 .60742 .38124 .5938 .3883 .40185 Mtetra
.555 .335 .536 r
.3883 .40185 .38124 .5938 .39101 .39904 .3901 .39665 Mtetra
.761 .624 .708 r
.3901 .39665 .39101 .39904 .39272 .39604 .39177 .39455 Mtetra
.682 .665 .827 r
.39177 .39455 .39272 .39604 .39433 .39527 .39338 .39383 Mtetra
.611 .645 .86 r
.39338 .39383 .39433 .39527 .39593 .39503 .39498 .39351 Mtetra
.595 .627 .853 r
.39498 .39351 .39593 .39503 .39752 .39476 .39658 .39326 Mtetra
.619 .64 .849 r
.39658 .39326 .39752 .39476 .39914 .39419 .39818 .3929 Mtetra
.617 .672 .88 r
.39818 .3929 .39914 .39419 .40075 .39362 .39979 .39255 Mtetra
.628 .717 .91 r
.39979 .39255 .40075 .39362 .40236 .39308 .40139 .39214 Mtetra
.65 .753 .925 r
.40139 .39214 .40236 .39308 .40397 .39258 .40301 .39165 Mtetra
.665 .759 .92 r
.40301 .39165 .40397 .39258 .40558 .39207 .40462 .39109 Mtetra
.683 .753 .904 r
.40462 .39109 .40558 .39207 .40719 .39156 .40624 .39046 Mtetra
.694 .732 .88 r
.40624 .39046 .40719 .39156 .40881 .39102 .40786 .38975 Mtetra
.69 .702 .857 r
.40786 .38975 .40881 .39102 .41043 .39047 .40948 .38904 Mtetra
.688 .678 .835 r
.40948 .38904 .41043 .39047 .41204 .38989 .41111 .3883 Mtetra
.681 .654 .817 r
.41111 .3883 .41204 .38989 .41367 .38928 .41273 .38757 Mtetra
.647 .625 .814 r
.41273 .38757 .41367 .38928 .41529 .38868 .41435 .38702 Mtetra
.575 .598 .839 r
.41435 .38702 .41529 .38868 .41691 .38794 .41596 .38687 Mtetra
.253 .539 .923 r
.41596 .38687 .41691 .38794 .41854 .38708 .41755 .38736 Mtetra
.714 .218 .061 r
.41755 .38736 .41854 .38708 .42016 .38669 .4191 .38878 Mtetra
.83 .495 .421 r
.4191 .38878 .42016 .38669 .42173 .38784 .42054 .39414 Mtetra
.947 .674 .488 r
.42054 .39414 .42173 .38784 .42302 .39773 .41585 .59126 Mtetra
.55 .327 .529 r
.41585 .59126 .42302 .39773 .41852 .59442 .41743 .59543 Mtetra
.669 .227 .191 r
.41743 .59543 .41852 .59442 .42015 .59706 .41911 .59671 Mtetra
.431 .825 .984 r
.41911 .59671 .42015 .59706 .42187 .59688 .42084 .59644 Mtetra
.666 .889 .979 r
.42084 .59644 .42187 .59688 .42361 .59609 .42258 .59573 Mtetra
.66 .906 .98 r
.42258 .59573 .42361 .59609 .42536 .59523 .42432 .59501 Mtetra
.458 .859 .969 r
.42432 .59501 .42536 .59523 .42709 .59479 .42605 .5946 Mtetra
.544 .902 .97 r
.42605 .5946 .42709 .59479 .42883 .59434 .42779 .59403 Mtetra
.756 .929 .945 r
.42779 .59403 .42883 .59434 .43056 .59385 .42955 .59296 Mtetra
.85 .802 .803 r
.42955 .59296 .43056 .59385 .4323 .5933 .43133 .59096 Mtetra
.79 .649 .706 r
.43133 .59096 .4323 .5933 .43405 .59273 .43313 .58834 Mtetra
.705 .537 .658 r
.43313 .58834 .43405 .59273 .43579 .59232 .43491 .58598 Mtetra
.56 .409 .633 r
.43491 .58598 .43579 .59232 .43752 .5922 .43664 .58586 Mtetra
.577 .421 .633 r
.43664 .58586 .43752 .5922 .43926 .59162 .43838 .58546 Mtetra
.693 .504 .628 r
.43838 .58546 .43926 .59162 .44104 .58963 .44019 .58243 Mtetra
.952 .682 .49 r
.44019 .58243 .44104 .58963 .44298 .58142 .44676 .38385 Mtetra
.557 .336 .536 r
.44676 .38385 .44298 .58142 .44944 .38051 .44854 .37745 Mtetra
.759 .597 .677 r
.44854 .37745 .44944 .38051 .45116 .37644 .45023 .37483 Mtetra
.693 .659 .812 r
.45023 .37483 .45116 .37644 .45281 .37549 .45188 .374 Mtetra
.624 .646 .851 r
.45188 .374 .45281 .37549 .45445 .37515 .45352 .3736 Mtetra
.589 .622 .853 r
.45352 .3736 .45445 .37515 .45609 .37496 .45516 .37337 Mtetra
.622 .631 .839 r
.45516 .37337 .45609 .37496 .45773 .37436 .4568 .37299 Mtetra
.62 .662 .869 r
.4568 .37299 .45773 .37436 .45938 .37377 .45844 .37262 Mtetra
.627 .705 .902 r
.45844 .37262 .45938 .37377 .46103 .37319 .46009 .37221 Mtetra
.65 .749 .922 r
.46009 .37221 .46103 .37319 .46267 .37265 .46173 .37171 Mtetra
.664 .761 .922 r
.46173 .37171 .46267 .37265 .46432 .37212 .46338 .37114 Mtetra
.679 .758 .91 r
.46338 .37114 .46432 .37212 .46597 .37159 .46504 .37051 Mtetra
.694 .742 .888 r
.46504 .37051 .46597 .37159 .46762 .37103 .46669 .3698 Mtetra
.691 .713 .866 r
.46669 .3698 .46762 .37103 .46927 .37047 .46835 .36908 Mtetra
.68 .684 .847 r
.46835 .36908 .46927 .37047 .47093 .36991 .47 .36839 Mtetra
.661 .659 .837 r
.47 .36839 .47093 .36991 .47258 .36935 .47166 .36779 Mtetra
.656 .651 .834 r
.47166 .36779 .47258 .36935 .47424 .36878 .47331 .36721 Mtetra
.659 .651 .832 r
.47331 .36721 .47424 .36878 .47589 .36821 .47497 .36662 Mtetra
.679 .657 .822 r
.47497 .36662 .47589 .36821 .47755 .36761 .47663 .36589 Mtetra
.652 .63 .815 r
.47663 .36589 .47755 .36761 .47921 .36702 .47829 .3653 Mtetra
.59 .602 .832 r
.47829 .3653 .47921 .36702 .48087 .36644 .47994 .36507 Mtetra
.223 .456 .873 r
.47994 .36507 .48087 .36644 .48253 .36592 .48158 .36583 Mtetra
.675 .129 0 r
.48158 .36583 .48253 .36592 .48419 .36539 .48322 .36721 Mtetra
.702 .32 .322 r
.48322 .36721 .48419 .36539 .48585 .36485 .48486 .36906 Mtetra
.515 .206 .382 r
.48486 .36906 .48585 .36485 .48751 .36426 .48651 .36904 Mtetra
.451 .16 .379 r
.48651 .36904 .48751 .36426 .48918 .36366 .48819 .36823 Mtetra
.418 .128 .362 r
.48819 .36823 .48918 .36366 .49084 .36306 .48986 .36716 Mtetra
.458 .153 .36 r
.48986 .36716 .49084 .36306 .49251 .36248 .49153 .36657 Mtetra
.459 .154 .36 r
.49153 .36657 .49251 .36248 .49418 .36191 .4932 .366 Mtetra
.46 .154 .36 r
.4932 .366 .49418 .36191 .49585 .36134 .49487 .36543 Mtetra
.461 .155 .36 r
.49487 .36543 .49585 .36134 .49751 .36077 .49654 .36487 Mtetra
.461 .156 .361 r
.49654 .36487 .49751 .36077 .49918 .36021 .49822 .36432 Mtetra
.463 .157 .362 r
.49822 .36432 .49918 .36021 .50086 .35965 .49989 .36377 Mtetra
.464 .159 .363 r
.49989 .36377 .50086 .35965 .50253 .35909 .50157 .36324 Mtetra
.465 .161 .364 r
.50157 .36324 .50253 .35909 .5042 .35853 .50324 .36271 Mtetra
.468 .164 .366 r
.50324 .36271 .5042 .35853 .50588 .35798 .50492 .36221 Mtetra
.515 .206 .382 r
.50492 .36221 .50588 .35798 .50755 .35745 .5066 .36219 Mtetra
.482 .187 .388 r
.5066 .36219 .50755 .35745 .50923 .35691 .50828 .36173 Mtetra
.395 .112 .362 r
.50828 .36173 .50923 .35691 .5109 .35635 .50996 .36034 Mtetra
.068 0 .209 r
.50996 .36034 .5109 .35635 .51258 .35573 .51165 .3572 Mtetra
0 0 0 r
.51165 .3572 .51258 .35573 .51426 .3551 .51334 .35477 Mtetra
.88 .914 .846 r
.51334 .35477 .51426 .3551 .51594 .35448 .51503 .35298 Mtetra
.69 .675 .831 r
.51503 .35298 .51594 .35448 .51762 .35391 .51671 .3522 Mtetra
.644 .629 .82 r
.51671 .3522 .51762 .35391 .51931 .35335 .51839 .35166 Mtetra
.623 .622 .829 r
.51839 .35166 .51931 .35335 .52099 .3528 .52008 .35125 Mtetra
.655 .655 .838 r
.52008 .35125 .52099 .3528 .52267 .35223 .52176 .35068 Mtetra
.652 .653 .838 r
.52176 .35068 .52267 .35223 .52436 .35165 .52345 .35011 Mtetra
.648 .654 .842 r
.52345 .35011 .52436 .35165 .52605 .35107 .52513 .34958 Mtetra
.63 .652 .854 r
.52513 .34958 .52605 .35107 .52773 .35047 .52682 .34914 Mtetra
.632 .68 .877 r
.52682 .34914 .52773 .35047 .52942 .34987 .52851 .34871 Mtetra
.644 .714 .899 r
.52851 .34871 .52942 .34987 .53111 .34928 .5302 .34822 Mtetra
.693 .75 .895 r
.5302 .34822 .53111 .34928 .5328 .34874 .53189 .3475 Mtetra
.697 .72 .867 r
.53189 .3475 .5328 .34874 .53449 .3482 .53358 .34674 Mtetra
.687 .681 .839 r
.53358 .34674 .53449 .3482 .53619 .34766 .53528 .34599 Mtetra
.701 .659 .805 r
.53528 .34599 .53619 .34766 .53788 .34664 .53697 .34506 Mtetra
.669 .657 .829 r
.53697 .34506 .53788 .34664 .53957 .34593 .53866 .34438 Mtetra
.581 .622 .858 r
.53866 .34438 .53957 .34593 .54127 .34589 .54036 .34418 Mtetra
0 .185 .717 r
.54036 .34418 .54127 .34589 .543 .34984 .54207 .34591 Mtetra
0 0 .358 r
.54207 .34591 .543 .34984 .54596 .55228 .54381 .35157 Mtetra
0 0 .36 r
.54381 .35157 .54596 .55228 .54782 .55799 .54681 .55115 Mtetra
.302 .223 .599 r
.54681 .55115 .54782 .55799 .54964 .55842 .54865 .55456 Mtetra
.402 .358 .694 r
.54865 .55456 .54964 .55842 .55146 .5579 .55048 .55584 Mtetra
.449 .504 .823 r
.55048 .55584 .55146 .5579 .55327 .55695 .55231 .55629 Mtetra
.507 .792 .997 r
.55231 .55629 .55327 .55695 .55509 .55639 .55413 .55604 Mtetra
.567 .888 .989 r
.55413 .55604 .55509 .55639 .55691 .55585 .55596 .55548 Mtetra
.637 .907 .983 r
.55596 .55548 .55691 .55585 .55873 .55528 .55778 .55476 Mtetra
.457 .805 .998 r
.55778 .55476 .55873 .55528 .56056 .55512 .5596 .55453 Mtetra
.561 .832 .996 r
.5596 .55453 .56056 .55512 .56239 .55466 .56143 .55412 Mtetra
.718 .888 .958 r
.56143 .55412 .56239 .55466 .5642 .5535 .56325 .55321 Mtetra
.941 .893 .754 r
.56325 .55321 .5642 .5535 .56597 .54841 .56505 .5503 Mtetra
.946 .862 .441 r
.56505 .5503 .56597 .54841 .56521 .34472 .56681 .54373 Mtetra
0 0 .355 r
.56681 .54373 .56521 .34472 .56684 .33782 .56602 .34255 Mtetra
0 0 .195 r
.56602 .34255 .56684 .33782 .56854 .33619 .56768 .33784 Mtetra
0 0 0 r
.56768 .33784 .56854 .33619 .57026 .33559 .56938 .33554 Mtetra
.821 .986 .879 r
.56938 .33554 .57026 .33559 .57198 .33539 .57108 .33407 Mtetra
.689 .706 .86 r
.57108 .33407 .57198 .33539 .57369 .33491 .57279 .33332 Mtetra
.622 .637 .845 r
.57279 .33332 .57369 .33491 .57541 .33438 .57451 .33292 Mtetra
.591 .642 .87 r
.57451 .33292 .57541 .33438 .57713 .33384 .57624 .33266 Mtetra
.642 .713 .899 r
.57624 .33266 .57713 .33384 .57885 .33323 .57796 .33217 Mtetra
.668 .747 .91 r
.57796 .33217 .57885 .33323 .58057 .33259 .57968 .33157 Mtetra
.68 .759 .911 r
.57968 .33157 .58057 .33259 .58229 .33197 .5814 .33091 Mtetra
.748 .772 .873 r
.5814 .33091 .58229 .33197 .584 .33102 .58311 .32988 Mtetra
.723 .749 .873 r
.58311 .32988 .584 .33102 .58573 .3303 .58483 .32898 Mtetra
.633 .685 .881 r
.58483 .32898 .58573 .3303 .58746 .33019 .58656 .32853 Mtetra
.105 .328 .8 r
.58656 .32853 .58746 .33019 .58926 .33329 .58832 .32982 Mtetra
0 0 .47 r
.58832 .32982 .58926 .33329 .59524 .53557 .59016 .33435 Mtetra
0 0 .379 r
.59016 .33435 .59524 .53557 .59724 .54263 .59616 .5349 Mtetra
.266 .19 .582 r
.59616 .5349 .59724 .54263 .59912 .54351 .59811 .53929 Mtetra
.402 .346 .681 r
.59811 .53929 .59912 .54351 .60098 .54305 .6 .54073 Mtetra
.456 .482 .797 r
.6 .54073 .60098 .54305 .60282 .54212 .60188 .54123 Mtetra
.56 .76 .971 r
.60188 .54123 .60282 .54212 .60467 .54146 .60374 .54094 Mtetra
.65 .881 .983 r
.60374 .54094 .60467 .54146 .60652 .54091 .60559 .54024 Mtetra
.706 .861 .956 r
.60559 .54024 .60652 .54091 .60838 .54034 .60744 .5394 Mtetra
.499 .721 .971 r
.60744 .5394 .60838 .54034 .61024 .54014 .60931 .53929 Mtetra
.493 .742 .983 r
.60931 .53929 .61024 .54014 .6121 .53978 .61118 .53916 Mtetra
.692 .871 .966 r
.61118 .53916 .6121 .53978 .61395 .53876 .61303 .53835 Mtetra
.963 .849 .681 r
.61303 .53835 .61395 .53876 .61571 .53456 .61479 .53428 Mtetra
.974 .689 .424 r
.61479 .53428 .61571 .53456 .61197 .33128 .61109 .33021 Mtetra
.963 .74 .554 r
.61109 .33021 .61197 .33128 .61348 .3224 .61259 .32086 Mtetra
.812 .719 .762 r
.61259 .32086 .61348 .3224 .61518 .32035 .6143 .31887 Mtetra
.642 .664 .856 r
.6143 .31887 .61518 .32035 .61692 .3197 .61604 .31835 Mtetra
.527 .632 .898 r
.61604 .31835 .61692 .3197 .61868 .31951 .6178 .31833 Mtetra
.599 .698 .913 r
.6178 .31833 .61868 .31951 .62043 .31906 .61956 .31801 Mtetra
.659 .748 .916 r
.61956 .31801 .62043 .31906 .62217 .31844 .6213 .31743 Mtetra
.672 .764 .92 r
.6213 .31743 .62217 .31844 .62392 .31782 .62305 .3168 Mtetra
.74 .78 .885 r
.62305 .3168 .62392 .31782 .62566 .31693 .62479 .31582 Mtetra
.733 .762 .876 r
.62479 .31582 .62566 .31693 .6274 .31614 .62652 .31486 Mtetra
.651 .702 .884 r
.62652 .31486 .6274 .31614 .62916 .31592 .62828 .31432 Mtetra
.228 .419 .842 r
.62828 .31432 .62916 .31592 .63102 .3183 .63008 .31529 Mtetra
0 0 .531 r
.63008 .31529 .63102 .3183 .63969 .51918 .63199 .31914 Mtetra
0 0 .393 r
.63199 .31914 .63969 .51918 .64191 .52866 .64072 .5198 Mtetra
.245 .168 .567 r
.64072 .5198 .64191 .52866 .64386 .53005 .6428 .52524 Mtetra
.421 .344 .665 r
.6428 .52524 .64386 .53005 .64575 .52971 .64476 .52673 Mtetra
.478 .45 .748 r
.64476 .52673 .64575 .52971 .64762 .52884 .64668 .52728 Mtetra
.466 .583 .887 r
.64668 .52728 .64762 .52884 .6495 .52838 .64859 .52751 Mtetra
.503 .744 .981 r
.64859 .52751 .6495 .52838 .65139 .52802 .65049 .52736 Mtetra
.675 .861 .97 r
.65049 .52736 .65139 .52802 .65326 .52705 .65237 .52661 Mtetra
.905 .912 .815 r
.65237 .52661 .65326 .52705 .65503 .52349 .65419 .52437 Mtetra
.969 .899 .536 r
.65419 .52437 .65503 .52349 .64908 .32432 .6559 .51934 Mtetra
0 0 .382 r
.6559 .51934 .64908 .32432 .65033 .3106 .64981 .31807 Mtetra
0 0 .288 r
.64981 .31807 .65033 .3106 .65201 .30805 .6513 .31053 Mtetra
0 0 .08 r
.6513 .31053 .65201 .30805 .65377 .30727 .65298 .30796 Mtetra
.511 .838 .544 r
.65298 .30796 .65377 .30727 .65555 .30697 .65471 .30634 Mtetra
.752 .878 .937 r
.65471 .30634 .65555 .30697 .65733 .30656 .65646 .30534 Mtetra
.668 .723 .89 r
.65646 .30534 .65733 .30656 .6591 .30595 .65823 .30471 Mtetra
.638 .707 .896 r
.65823 .30471 .6591 .30595 .66087 .30536 .66001 .30423 Mtetra
.711 .753 .885 r
.66001 .30423 .66087 .30536 .66263 .30452 .66177 .30338 Mtetra
.738 .761 .872 r
.66177 .30338 .66263 .30452 .66439 .30368 .66352 .30238 Mtetra
.663 .706 .879 r
.66352 .30238 .66439 .30368 .66618 .30336 .6653 .30177 Mtetra
.328 .482 .86 r
.6653 .30177 .66618 .30336 .66806 .30525 .66713 .30247 Mtetra
0 .019 .581 r
.66713 .30247 .66806 .30525 .67904 .50309 .66909 .30588 Mtetra
0 0 .404 r
.66909 .30588 .67904 .50309 .68158 .51626 .68025 .50617 Mtetra
.213 .139 .552 r
.68025 .50617 .68158 .51626 .6836 .51808 .6825 .51301 Mtetra
.417 .337 .659 r
.6825 .51301 .6836 .51808 .68552 .5178 .68451 .51464 Mtetra
.476 .439 .738 r
.68451 .51464 .68552 .5178 .68741 .51696 .68648 .51526 Mtetra
.454 .555 .869 r
.68648 .51526 .68741 .51696 .68932 .5164 .68843 .51559 Mtetra
.424 .72 .986 r
.68843 .51559 .68932 .5164 .69124 .51609 .69037 .51558 Mtetra
.658 .896 .981 r
.69037 .51558 .69124 .51609 .69314 .5152 .69227 .51482 Mtetra
.949 .9 .743 r
.69227 .51482 .69314 .5152 .69492 .51208 .69406 .51179 Mtetra
.987 .738 .464 r
.69406 .51179 .69492 .51208 .69577 .49082 .69514 .49495 Mtetra
.98 .689 .381 r
.69514 .49495 .69577 .49082 .68765 .29812 .68678 .29661 Mtetra
.871 .741 .717 r
.68678 .29661 .68765 .29812 .68931 .29516 .68845 .29366 Mtetra
.677 .682 .847 r
.68845 .29366 .68931 .29516 .69109 .29429 .69023 .29294 Mtetra
.57 .656 .895 r
.69023 .29294 .69109 .29429 .69289 .29395 .69205 .29274 Mtetra
.657 .723 .898 r
.69205 .29274 .69289 .29395 .69469 .29338 .69384 .29216 Mtetra
.747 .752 .856 r
.69384 .29216 .69469 .29338 .69646 .29249 .69561 .29106 Mtetra
.658 .684 .863 r
.69561 .29106 .69646 .29249 .69827 .29209 .6974 .29046 Mtetra
.155 .366 .819 r
.6974 .29046 .69827 .29209 .70018 .29347 .6993 .2917 Mtetra
.925 .572 .135 r
.6993 .2917 .70018 .29347 .70267 .30515 .70173 .30222 Mtetra
.976 .676 .363 r
.70173 .30222 .70267 .30515 .716 .50517 .71514 .50455 Mtetra
.656 .134 0 r
.71514 .50455 .716 .50517 .7181 .50755 .71723 .50692 Mtetra
.545 .828 .998 r
.71723 .50692 .7181 .50755 .72005 .50731 .71917 .50652 Mtetra
.741 .854 .933 r
.71917 .50652 .72005 .50731 .72196 .50646 .72108 .50549 Mtetra
.666 .793 .942 r
.72108 .50549 .72196 .50646 .72389 .50579 .72301 .50481 Mtetra
.452 .696 .971 r
.72301 .50481 .72389 .50579 .72584 .50557 .72498 .50483 Mtetra
.606 .824 .984 r
.72498 .50483 .72584 .50557 .72777 .50482 .72692 .50432 Mtetra
.911 .911 .807 r
.72692 .50432 .72777 .50482 .72958 .50221 .72875 .50198 Mtetra
.994 .782 .509 r
.72875 .50198 .72958 .50221 .73084 .49076 .73014 .49257 Mtetra
.979 .684 .371 r
.73014 .49257 .73084 .49076 .72008 .28792 .71926 .287 Mtetra
.942 .81 .684 r
.71926 .287 .72008 .28792 .72171 .28445 .72087 .28327 Mtetra
.724 .753 .876 r
.72087 .28327 .72171 .28445 .7235 .28353 .72266 .28233 Mtetra
.603 .702 .914 r
.72266 .28233 .7235 .28353 .72532 .28316 .72449 .28198 Mtetra
.636 .721 .909 r
.72449 .28198 .72532 .28316 .72714 .28264 .72631 .28148 Mtetra
.742 .765 .872 r
.72631 .28148 .72714 .28264 .72893 .28159 .7281 .28044 Mtetra
.654 .735 .909 r
.7281 .28044 .72893 .28159 .73074 .28102 .72992 .27987 Mtetra
.116 .434 .874 r
.72992 .27987 .73074 .28102 .73266 .28195 .73184 .28081 Mtetra
.907 .524 .093 r
.73184 .28081 .73266 .28195 .73506 .28987 .73423 .28871 Mtetra
.975 .671 .352 r
.73423 .28871 .73506 .28987 .75083 .49395 .74995 .49286 Mtetra
.596 .135 0 r
.74995 .49286 .75083 .49395 .75302 .49688 .75214 .49579 Mtetra
.554 .722 .951 r
.75214 .49579 .75302 .49688 .75499 .49664 .75412 .49555 Mtetra
.713 .785 .909 r
.75412 .49555 .75499 .49664 .75693 .49573 .75606 .49464 Mtetra
.696 .779 .916 r
.75606 .49464 .75693 .49573 .75887 .49492 .758 .49382 Mtetra
.512 .7 .955 r
.758 .49382 .75887 .49492 .76086 .49482 .75999 .49372 Mtetra
.654 .764 .93 r
.75999 .49372 .76086 .49482 .76281 .4942 .76195 .4931 Mtetra
.868 .816 .796 r
.76195 .4931 .76281 .4942 .76465 .49196 .76379 .49086 Mtetra
.98 .749 .518 r
.76379 .49086 .76465 .49196 .76592 .48181 .76505 .48067 Mtetra
.977 .678 .362 r
.76505 .48067 .76592 .48181 .75286 .27702 .75204 .27586 Mtetra
.932 .788 .678 r
.75204 .27586 .75286 .27702 .75445 .27319 .75363 .27203 Mtetra
.726 .764 .882 r
.75363 .27203 .75445 .27319 .75625 .27223 .75544 .27108 Mtetra
.601 .714 .924 r
.75544 .27108 .75625 .27223 .75811 .27188 .75729 .27072 Mtetra
.6 .714 .924 r
.75729 .27072 .75811 .27188 .75996 .27152 .75914 .27037 Mtetra
.739 .769 .877 r
.75914 .27037 .75996 .27152 .76176 .27049 .76095 .26934 Mtetra
.656 .738 .91 r
.76095 .26934 .76176 .27049 .7636 .2699 .76279 .26875 Mtetra
.233 .509 .907 r
.76279 .26875 .7636 .2699 .76554 .2706 .76473 .26945 Mtetra
.883 .491 .036 r
.76473 .26945 .76554 .2706 .76799 .27784 .76718 .2767 Mtetra
.975 .667 .334 r
.76718 .2767 .76799 .27784 .78611 .4832 .78526 .48211 Mtetra
.657 .202 0 r
.78526 .48211 .78611 .4832 .78841 .48666 .78756 .48557 Mtetra
.381 .631 .952 r
.78756 .48557 .78841 .48666 .79046 .48694 .7896 .48584 Mtetra
.693 .781 .919 r
.7896 .48584 .79046 .48694 .79242 .48612 .79157 .48503 Mtetra
.874 .821 .793 r
.79157 .48503 .79242 .48612 .79426 .48381 .79341 .48272 Mtetra
.978 .767 .55 r
.79341 .48272 .79426 .48381 .79564 .47588 .79479 .47483 Mtetra
.977 .675 .347 r
.79479 .47483 .79564 .47588 .78052 .26856 .77972 .26742 Mtetra
.951 .787 .642 r
.77972 .26742 .78052 .26856 .78204 .26401 .78124 .26287 Mtetra
.745 .774 .876 r
.78124 .26287 .78204 .26401 .78386 .26295 .78305 .2618 Mtetra
.616 .723 .922 r
.78305 .2618 .78386 .26295 .78572 .26253 .78492 .26138 Mtetra
.583 .707 .928 r
.78492 .26138 .78572 .26253 .7876 .26224 .7868 .26108 Mtetra
.746 .772 .874 r
.7868 .26108 .7876 .26224 .78942 .26117 .78861 .26001 Mtetra
.669 .743 .906 r
.78861 .26001 .78942 .26117 .79127 .26052 .79047 .25935 Mtetra
.354 .58 .928 r
.79047 .25935 .79127 .26052 .79321 .26094 .79241 .25977 Mtetra
.833 .428 0 r
.79241 .25977 .79321 .26094 .79565 .267 .79485 .26583 Mtetra
.973 .663 .318 r
.79485 .26583 .79565 .267 .8158 .47356 .81496 .47246 Mtetra
.69 .244 0 r
.81496 .47246 .8158 .47356 .8182 .47746 .81736 .47638 Mtetra
.451 .674 .959 r
.81736 .47638 .8182 .47746 .82024 .4774 .81942 .47645 Mtetra
.684 .811 .944 r
.81942 .47645 .82024 .4774 .82223 .47661 .8214 .47567 Mtetra
.791 .843 .891 r
.8214 .47567 .82223 .47661 .82419 .47559 .82333 .4743 Mtetra
.79 .779 .842 r
.82333 .4743 .82419 .47559 .82623 .47544 .82525 .47278 Mtetra
.767 .636 .715 r
.82525 .47278 .82623 .47544 .82824 .47485 .8271 .47049 Mtetra
.781 .585 .635 r
.8271 .47049 .82824 .47485 .83015 .47324 .82877 .46627 Mtetra
.974 .668 .348 r
.82877 .46627 .83015 .47324 .83157 .46635 .81191 .26284 Mtetra
.558 .336 .535 r
.81191 .26284 .83157 .46635 .81409 .25822 .81309 .25485 Mtetra
.775 .601 .663 r
.81309 .25485 .81409 .25822 .81552 .25294 .81473 .25177 Mtetra
.733 .769 .882 r
.81473 .25177 .81552 .25294 .81734 .25176 .81657 .25077 Mtetra
.634 .769 .944 r
.81657 .25077 .81734 .25176 .81922 .25126 .81845 .25024 Mtetra
.59 .742 .949 r
.81845 .25024 .81922 .25126 .82114 .25104 .82035 .24989 Mtetra
.756 .78 .872 r
.82035 .24989 .82114 .25104 .82296 .24991 .82218 .24874 Mtetra
.686 .752 .902 r
.82218 .24874 .82296 .24991 .82483 .24918 .82404 .24799 Mtetra
.466 .642 .933 r
.82404 .24799 .82483 .24918 .82678 .2493 .82599 .2481 Mtetra
.768 .354 0 r
.82599 .2481 .82678 .2493 .82924 .25459 .82845 .25334 Mtetra
.971 .657 .298 r
.82845 .25334 .82924 .25459 .85184 .46208 .85101 .46091 Mtetra
.713 .282 0 r
.85101 .46091 .85184 .46208 .85437 .46662 .85355 .46549 Mtetra
.314 .582 .938 r
.85355 .46549 .85437 .46662 .85651 .4671 .85568 .46597 Mtetra
.651 .763 .931 r
.85568 .46597 .85651 .4671 .85853 .46647 .85771 .46534 Mtetra
.831 .82 .839 r
.85771 .46534 .85853 .46647 .86044 .46468 .85962 .46356 Mtetra
.976 .788 .587 r
.85962 .46356 .86044 .46468 .8619 .45857 .86108 .45746 Mtetra
.974 .667 .312 r
.86108 .45746 .8619 .45857 .84239 .24958 .84161 .24845 Mtetra
.976 .778 .572 r
.84161 .24845 .84239 .24958 .8437 .24342 .84293 .24227 Mtetra
.762 .763 .853 r
.23468 .44753 .23571 .44845 .23727 .44738 .23625 .44647 Mtetra
.613 .735 .933 r
.23625 .44647 .23727 .44738 .23877 .44703 .23775 .44613 Mtetra
.445 .677 .963 r
.23775 .44613 .23877 .44703 .24024 .44706 .23922 .44618 Mtetra
.639 .752 .931 r
.23922 .44618 .24024 .44706 .24176 .4466 .24073 .44575 Mtetra
.651 .761 .93 r
.24073 .44575 .24176 .4466 .24327 .4461 .24224 .44528 Mtetra
.667 .771 .928 r
.24224 .44528 .24327 .4461 .2448 .44555 .24376 .44475 Mtetra
.708 .784 .911 r
.24376 .44475 .2448 .44555 .24633 .44483 .2453 .44405 Mtetra
.716 .79 .91 r
.2453 .44405 .24633 .44483 .24788 .44408 .24684 .44331 Mtetra
.714 .792 .913 r
.24684 .44331 .24788 .44408 .24942 .44335 .24838 .44258 Mtetra
.727 .794 .905 r
.24838 .44258 .24942 .44335 .25097 .44244 .24993 .4418 Mtetra
.692 .819 .943 r
.24993 .4418 .25097 .44244 .25251 .44179 .25146 .44116 Mtetra
.599 .804 .978 r
.25146 .44116 .25251 .44179 .254 .44161 .25298 .4408 Mtetra
0 .415 .842 r
.25298 .4408 .254 .44161 .25532 .44363 .25441 .44144 Mtetra
.13 .267 .738 r
.25441 .44144 .25532 .44363 .25622 .45073 .25578 .44276 Mtetra
.417 .28 .586 r
.25578 .44276 .25622 .45073 .24198 .6435 .2571 .44487 Mtetra
.543 .325 .534 r
.2571 .44487 .24198 .6435 .24347 .6446 .25855 .44525 Mtetra
.545 .327 .534 r
.25855 .44525 .24347 .6446 .2451 .64399 .2601 .44454 Mtetra
.546 .328 .534 r
.2601 .44454 .2451 .64399 .24679 .64264 .26169 .44338 Mtetra
.545 .327 .534 r
.26169 .44338 .24679 .64264 .24842 .64199 .26323 .44272 Mtetra
.26323 .44272 .24842 .64199 .25005 .64144 .26477 .44213 Mtetra
.26477 .44213 .25005 .64144 .25168 .6409 .26631 .44155 Mtetra
.26631 .44155 .25168 .6409 .2533 .64038 .26785 .44098 Mtetra
.26785 .44098 .2533 .64038 .25493 .63988 .2694 .44042 Mtetra
.545 .326 .534 r
.2694 .44042 .25493 .63988 .25656 .63938 .27093 .43989 Mtetra
.546 .328 .534 r
.27093 .43989 .25656 .63938 .25822 .63841 .27253 .43861 Mtetra
.545 .327 .534 r
.27253 .43861 .25822 .63841 .25987 .6377 .27409 .43781 Mtetra
.543 .325 .534 r
.27409 .43781 .25987 .6377 .26146 .63776 .27557 .43819 Mtetra
0 0 .237 r
.27557 .43819 .26146 .63776 .2629 .6397 .26272 .62699 Mtetra
0 0 .342 r
.26272 .62699 .2629 .6397 .26438 .64128 .26345 .63834 Mtetra
0 0 .512 r
.26345 .63834 .26438 .64128 .26591 .64222 .26484 .6412 Mtetra
.34 .614 .951 r
.26484 .6412 .26591 .64222 .26752 .64211 .26642 .64147 Mtetra
.63 .822 .974 r
.26642 .64147 .26752 .64211 .26915 .64161 .26805 .64098 Mtetra
.711 .837 .942 r
.26805 .64098 .26915 .64161 .2708 .64099 .26971 .64022 Mtetra
.624 .788 .96 r
.26971 .64022 .2708 .64099 .27243 .6406 .27135 .63978 Mtetra
.601 .769 .96 r
.27135 .63978 .27243 .6406 .27406 .64027 .27298 .63942 Mtetra
.617 .766 .951 r
.27298 .63942 .27406 .64027 .27569 .63991 .27462 .63901 Mtetra
.666 .771 .928 r
.27462 .63901 .27569 .63991 .27734 .63938 .27627 .63844 Mtetra
.684 .766 .914 r
.27627 .63844 .27734 .63938 .27899 .63877 .27792 .63779 Mtetra
.687 .759 .907 r
.27792 .63779 .27899 .63877 .28065 .63813 .27958 .63713 Mtetra
.626 .737 .927 r
.27958 .63713 .28065 .63813 .28228 .63786 .28122 .63671 Mtetra
.631 .71 .904 r
.28122 .63671 .28228 .63786 .28391 .6375 .28286 .63629 Mtetra
.677 .713 .875 r
.28286 .63629 .28391 .6375 .28558 .63671 .28452 .63565 Mtetra
.802 .758 .813 r
.28452 .63565 .28558 .63671 .28739 .63397 .28625 .63407 Mtetra
.921 .923 .796 r
.28625 .63407 .28739 .63397 .28945 .62746 .28802 .63168 Mtetra
.008 0 .147 r
.28802 .63168 .28945 .62746 .30434 .43148 .28985 .62855 Mtetra
.539 .318 .527 r
.28985 .62855 .30434 .43148 .30608 .42826 .2916 .62663 Mtetra
.542 .32 .528 r
.2916 .62663 .30608 .42826 .30765 .42765 .29325 .62614 Mtetra
.543 .321 .528 r
.29325 .62614 .30765 .42765 .30916 .42785 .29486 .62621 Mtetra
.544 .321 .528 r
.29486 .62621 .30916 .42785 .31067 .42803 .29645 .62666 Mtetra
.543 .321 .528 r
.29645 .62666 .31067 .42803 .31221 .42788 .29808 .62664 Mtetra
.54 .319 .527 r
.29808 .62664 .31221 .42788 .31379 .42705 .29977 .62549 Mtetra
.519 .301 .523 r
.29977 .62549 .31379 .42705 .31549 .4244 .30218 .61341 Mtetra
0 0 .217 r
.30218 .61341 .31549 .4244 .31718 .42187 .31604 .42318 Mtetra
.962 .934 .617 r
.31604 .42318 .31718 .42187 .31883 .41997 .31782 .41923 Mtetra
.813 .808 .846 r
.31782 .41923 .31883 .41997 .32042 .41906 .31944 .41784 Mtetra
.639 .689 .88 r
.31944 .41784 .32042 .41906 .32198 .41864 .321 .41741 Mtetra
.554 .653 .901 r
.321 .41741 .32198 .41864 .32353 .41839 .32254 .41729 Mtetra
.61 .702 .909 r
.32254 .41729 .32353 .41839 .32509 .41798 .3241 .41697 Mtetra
.658 .733 .906 r
.3241 .41697 .32509 .41798 .32665 .41745 .32566 .41646 Mtetra
.67 .743 .905 r
.32566 .41646 .32665 .41745 .32823 .41686 .32723 .4159 Mtetra
.716 .759 .886 r
.32723 .4159 .32823 .41686 .32982 .41595 .32882 .41511 Mtetra
.724 .786 .902 r
.32882 .41511 .32982 .41595 .33141 .41507 .33041 .41432 Mtetra
.674 .796 .94 r
.33041 .41432 .33141 .41507 .33298 .41459 .33198 .41374 Mtetra
.466 .701 .97 r
.33198 .41374 .33298 .41459 .33446 .41555 .33352 .41372 Mtetra
.328 .439 .822 r
.33352 .41372 .33446 .41555 .33579 .41925 .33502 .41444 Mtetra
.337 .269 .631 r
.33502 .41444 .33579 .41925 .32603 .61468 .33646 .41635 Mtetra
.509 .297 .527 r
.33646 .41635 .32603 .61468 .32734 .6204 .3371 .43203 Mtetra
0 0 .253 r
.3371 .43203 .32734 .6204 .32889 .62204 .328 .61819 Mtetra
0 .056 .577 r
.328 .61819 .32889 .62204 .3305 .62267 .32947 .62124 Mtetra
.319 .516 .892 r
.32947 .62124 .3305 .62267 .33216 .62252 .33109 .62177 Mtetra
.663 .809 .953 r
.33109 .62177 .33216 .62252 .33384 .62189 .33278 .62118 Mtetra
.745 .828 .916 r
.33278 .62118 .33384 .62189 .33554 .6211 .33448 .62024 Mtetra
.653 .78 .941 r
.33448 .62024 .33554 .6211 .33721 .62077 .33616 .6197 Mtetra
.577 .709 .933 r
.33616 .6197 .33721 .62077 .33887 .62064 .33783 .61945 Mtetra
.637 .708 .898 r
.33783 .61945 .33887 .62064 .34055 .62011 .33951 .619 Mtetra
.745 .751 .857 r
.33951 .619 .34055 .62011 .34232 .61808 .34123 .61794 Mtetra
.882 .925 .847 r
.34123 .61794 .34232 .61808 .34423 .61316 .34298 .61608 Mtetra
0 0 0 r
.34298 .61608 .34423 .61316 .35613 .41666 .3448 .61295 Mtetra
.519 .301 .523 r
.3448 .61295 .35613 .41666 .35806 .40957 .34708 .601 Mtetra
0 0 .247 r
.34708 .601 .35806 .40957 .35975 .40703 .35863 .40884 Mtetra
.869 .909 .501 r
.35863 .40884 .35975 .40703 .36139 .40545 .36039 .40494 Mtetra
.848 .857 .849 r
.36039 .40494 .36139 .40545 .363 .40457 .36203 .40336 Mtetra
.646 .694 .881 r
.36203 .40336 .363 .40457 .36458 .40416 .36362 .40289 Mtetra
.553 .648 .898 r
.36362 .40289 .36458 .40416 .36616 .40393 .36519 .40278 Mtetra
.581 .683 .91 r
.36519 .40278 .36616 .40393 .36774 .4036 .36676 .40256 Mtetra
.648 .729 .908 r
.36676 .40256 .36774 .4036 .36933 .40308 .36835 .40208 Mtetra
.662 .742 .909 r
.36835 .40208 .36933 .40308 .37093 .4025 .36995 .40154 Mtetra
.705 .761 .896 r
.36995 .40154 .37093 .4025 .37253 .40165 .37155 .40081 Mtetra
.726 .79 .903 r
.37155 .40081 .37253 .40165 .37415 .40072 .37316 .39999 Mtetra
.68 .808 .944 r
.37316 .39999 .37415 .40072 .37575 .40017 .37476 .39938 Mtetra
.389 .684 .977 r
.37476 .39938 .37575 .40017 .37728 .40097 .37633 .39947 Mtetra
.068 .332 .81 r
.37633 .39947 .37728 .40097 .37868 .40486 .37786 .40054 Mtetra
.313 .267 .645 r
.37786 .40054 .37868 .40486 .37147 .6009 .37935 .40244 Mtetra
.539 .322 .533 r
.37935 .40244 .37147 .6009 .37292 .60593 .38084 .4045 Mtetra
.543 .325 .534 r
.38084 .4045 .37292 .60593 .37459 .60625 .3824 .40488 Mtetra
.547 .328 .534 r
.3824 .40488 .37459 .60625 .37633 .60495 .38405 .40342 Mtetra
.55 .331 .535 r
.38405 .40342 .37633 .60495 .37825 .59936 .38576 .40035 Mtetra
.38576 .40035 .37825 .59936 .3883 .40185 .38748 .39732 Mtetra
.695 .523 .65 r
.38748 .39732 .3883 .40185 .3901 .39665 .38916 .3951 Mtetra
.753 .684 .785 r
.38916 .3951 .3901 .39665 .39177 .39455 .3908 .39377 Mtetra
.684 .798 .936 r
.3908 .39377 .39177 .39455 .39338 .39383 .39241 .39314 Mtetra
.61 .8 .972 r
.39241 .39314 .39338 .39383 .39498 .39351 .39401 .39273 Mtetra
.597 .774 .964 r
.39401 .39273 .39498 .39351 .39658 .39326 .39561 .39238 Mtetra
.618 .756 .944 r
.39561 .39238 .39658 .39326 .39818 .3929 .39722 .39199 Mtetra
.618 .75 .94 r
.39722 .39199 .39818 .3929 .39979 .39255 .39882 .3916 Mtetra
.635 .748 .929 r
.39882 .3916 .39979 .39255 .40139 .39214 .40043 .39116 Mtetra
.658 .747 .916 r
.40043 .39116 .40139 .39214 .40301 .39165 .40204 .39064 Mtetra
.672 .745 .905 r
.40204 .39064 .40301 .39165 .40462 .39109 .40366 .39005 Mtetra
.689 .744 .893 r
.40366 .39005 .40462 .39109 .40624 .39046 .40528 .38938 Mtetra
.703 .74 .881 r
.40528 .38938 .40624 .39046 .40786 .38975 .4069 .38864 Mtetra
.701 .732 .875 r
.4069 .38864 .40786 .38975 .40948 .38904 .40853 .3879 Mtetra
.712 .73 .864 r
.40853 .3879 .40948 .38904 .41111 .3883 .41016 .38708 Mtetra
.712 .717 .853 r
.41016 .38708 .41111 .3883 .41273 .38757 .41179 .38624 Mtetra
.648 .679 .866 r
.41179 .38624 .41273 .38757 .41435 .38702 .4134 .38575 Mtetra
.34 .542 .904 r
.4134 .38575 .41435 .38702 .41596 .38687 .41499 .38619 Mtetra
.838 .371 .005 r
.41499 .38619 .41596 .38687 .41755 .38736 .4165 .38885 Mtetra
.953 .681 .483 r
.4165 .38885 .41755 .38736 .4191 .38878 .41185 .57723 Mtetra
.57 .343 .532 r
.41185 .57723 .4191 .38878 .42054 .39414 .41306 .59225 Mtetra
.547 .324 .528 r
.41306 .59225 .42054 .39414 .41585 .59126 .4147 .59448 Mtetra
.595 .256 .366 r
.4147 .59448 .41585 .59126 .41743 .59543 .41638 .59541 Mtetra
.129 0 0 r
.41638 .59541 .41743 .59543 .41911 .59671 .4181 .59559 Mtetra
.615 .718 .919 r
.4181 .59559 .41911 .59671 .42084 .59644 .41983 .5952 Mtetra
.668 .716 .884 r
.41983 .5952 .42084 .59644 .42258 .59573 .42156 .59458 Mtetra
.651 .725 .903 r
.42156 .59458 .42258 .59573 .42432 .59501 .4233 .59404 Mtetra
.56 .732 .956 r
.4233 .59404 .42432 .59501 .42605 .5946 .42503 .59381 Mtetra
.652 .802 .955 r
.42503 .59381 .42605 .5946 .42779 .59403 .42677 .59324 Mtetra
.822 .824 .85 r
.42677 .59324 .42779 .59403 .42955 .59296 .42854 .59169 Mtetra
.896 .742 .682 r
.42854 .59169 .42955 .59296 .43133 .59096 .43038 .5875 Mtetra
.918 .674 .553 r
.43038 .5875 .43133 .59096 .43313 .58834 .43262 .56865 Mtetra
.934 .664 .504 r
.43262 .56865 .43313 .58834 .43491 .58598 .4393 .38296 Mtetra
.545 .327 .534 r
.4393 .38296 .43491 .58598 .43664 .58586 .44095 .38208 Mtetra
.544 .326 .534 r
.44095 .38208 .43664 .58586 .43838 .58546 .44257 .38197 Mtetra
.546 .327 .534 r
.44257 .38197 .43838 .58546 .44019 .58243 .44423 .38084 Mtetra
.55 .33 .535 r
.44423 .38084 .44019 .58243 .44676 .38385 .44594 .37778 Mtetra
.668 .484 .627 r
.44594 .37778 .44676 .38385 .44854 .37745 .44762 .37549 Mtetra
.747 .646 .749 r
.44762 .37549 .44854 .37745 .45023 .37483 .44929 .37395 Mtetra
.695 .783 .919 r
.44929 .37395 .45023 .37483 .45188 .374 .45093 .37326 Mtetra
.624 .797 .965 r
.45093 .37326 .45188 .374 .45352 .3736 .45257 .37281 Mtetra
.593 .773 .966 r
.45257 .37281 .45352 .3736 .45516 .37337 .45421 .37246 Mtetra
.621 .754 .941 r
.45421 .37246 .45516 .37337 .4568 .37299 .45586 .37205 Mtetra
.62 .749 .938 r
.45586 .37205 .4568 .37299 .45844 .37262 .4575 .37165 Mtetra
.632 .746 .93 r
.4575 .37165 .45844 .37262 .46009 .37221 .45915 .37121 Mtetra
.656 .747 .917 r
.45915 .37121 .46009 .37221 .46173 .37171 .46079 .37068 Mtetra
.67 .746 .908 r
.46079 .37068 .46173 .37171 .46338 .37114 .46244 .37009 Mtetra
.684 .746 .898 r
.46244 .37009 .46338 .37114 .46504 .37051 .4641 .36944 Mtetra
.701 .745 .886 r
.4641 .36944 .46504 .37051 .46669 .3698 .46575 .3687 Mtetra
.701 .739 .881 r
.46575 .3687 .46669 .3698 .46835 .36908 .46741 .36795 Mtetra
.693 .731 .88 r
.46741 .36795 .46835 .36908 .47 .36839 .46907 .36723 Mtetra
.675 .721 .884 r
.46907 .36723 .47 .36839 .47166 .36779 .47072 .36661 Mtetra
.668 .714 .883 r
.47072 .36661 .47166 .36779 .47331 .36721 .47238 .36601 Mtetra
.675 .714 .878 r
.47238 .36601 .47331 .36721 .47497 .36662 .47404 .36539 Mtetra
.713 .721 .856 r
.47404 .36539 .47497 .36662 .47663 .36589 .4757 .36453 Mtetra
.661 .683 .86 r
.4757 .36453 .47663 .36589 .47829 .3653 .47736 .36396 Mtetra
.49 .609 .897 r
.47736 .36396 .47829 .3653 .47994 .36507 .47901 .36406 Mtetra
.734 .259 0 r
.47901 .36406 .47994 .36507 .48158 .36583 .48063 .36655 Mtetra
.928 .604 .407 r
.48063 .36655 .48158 .36583 .48322 .36721 .48213 .37814 Mtetra
.947 .667 .476 r
.48213 .37814 .48322 .36721 .48486 .36906 .48132 .57044 Mtetra
.543 .321 .528 r
.48132 .57044 .48486 .36906 .48651 .36904 .48308 .5709 Mtetra
.541 .319 .527 r
.48308 .5709 .48651 .36904 .48819 .36823 .48486 .57009 Mtetra
.54 .319 .527 r
.48486 .57009 .48819 .36823 .48986 .36716 .48665 .56872 Mtetra
.542 .32 .528 r
.48665 .56872 .48986 .36716 .49153 .36657 .48842 .56819 Mtetra
.48842 .56819 .49153 .36657 .4932 .366 .4902 .56765 Mtetra
.4902 .56765 .4932 .366 .49487 .36543 .49198 .56712 Mtetra
.49198 .56712 .49487 .36543 .49654 .36487 .49375 .56659 Mtetra
.49375 .56659 .49654 .36487 .49822 .36432 .49553 .56608 Mtetra
.49553 .56608 .49822 .36432 .49989 .36377 .49731 .56557 Mtetra
.49731 .56557 .49989 .36377 .50157 .36324 .4991 .56508 Mtetra
.4991 .56508 .50157 .36324 .50324 .36271 .50088 .56458 Mtetra
.50088 .56458 .50324 .36271 .50492 .36221 .50266 .56412 Mtetra
.543 .321 .528 r
.50266 .56412 .50492 .36221 .5066 .36219 .50445 .56442 Mtetra
.542 .32 .528 r
.50445 .56442 .5066 .36219 .50828 .36173 .50623 .56398 Mtetra
.539 .318 .527 r
.50623 .56398 .50828 .36173 .50996 .36034 .50803 .56195 Mtetra
0 0 .34 r
.50803 .56195 .50996 .36034 .51165 .3572 .5107 .3636 Mtetra
0 0 .076 r
.5107 .3636 .51165 .3572 .51334 .35477 .51242 .35509 Mtetra
.967 .93 .693 r
.51242 .35509 .51334 .35477 .51503 .35298 .51411 .35183 Mtetra
.736 .745 .859 r
.51411 .35183 .51503 .35298 .51671 .3522 .51579 .35085 Mtetra
.648 .682 .868 r
.51579 .35085 .51671 .3522 .51839 .35166 .51748 .35034 Mtetra
.594 .664 .887 r
.51748 .35034 .51839 .35166 .52008 .35125 .51916 .35006 Mtetra
.662 .715 .888 r
.51916 .35006 .52008 .35125 .52176 .35068 .52084 .34949 Mtetra
.657 .715 .891 r
.52084 .34949 .52176 .35068 .52345 .35011 .52253 .34894 Mtetra
.65 .715 .895 r
.52253 .34894 .52345 .35011 .52513 .34958 .52422 .34843 Mtetra
.624 .709 .907 r
.52422 .34843 .52513 .34958 .52682 .34914 .52591 .34802 Mtetra
.623 .714 .911 r
.52591 .34802 .52682 .34914 .52851 .34871 .5276 .34762 Mtetra
.635 .725 .913 r
.5276 .34762 .52851 .34871 .5302 .34822 .52929 .34716 Mtetra
.686 .75 .9 r
.52929 .34716 .5302 .34822 .53189 .3475 .53098 .34648 Mtetra
.698 .761 .9 r
.53098 .34648 .53189 .3475 .53358 .34674 .53267 .34575 Mtetra
.699 .767 .904 r
.53267 .34575 .53358 .34674 .53528 .34599 .53437 .34501 Mtetra
.711 .774 .902 r
.53437 .34501 .53528 .34599 .53697 .34506 .53606 .34422 Mtetra
.679 .796 .937 r
.53606 .34422 .53697 .34506 .53866 .34438 .53776 .34357 Mtetra
.599 .778 .966 r
.53776 .34357 .53866 .34438 .54036 .34418 .53945 .34319 Mtetra
.367 .626 .953 r
.53945 .34319 .54036 .34418 .54207 .34591 .54116 .34344 Mtetra
.358 .395 .763 r
.54116 .34344 .54207 .34591 .54381 .35157 .54286 .34443 Mtetra
.379 .269 .602 r
.54286 .34443 .54381 .35157 .54681 .55115 .54459 .34708 Mtetra
0 0 .368 r
.54459 .34708 .54681 .55115 .54865 .55456 .54763 .54543 Mtetra
.065 .033 .506 r
.54763 .54543 .54865 .55456 .55048 .55584 .5495 .55289 Mtetra
.085 .193 .681 r
.5495 .55289 .55048 .55584 .55231 .55629 .55135 .55523 Mtetra
.453 .67 .956 r
.55135 .55523 .55231 .55629 .55413 .55604 .55317 .5553 Mtetra
.641 .822 .97 r
.55317 .5553 .55413 .55604 .55596 .55548 .55499 .55472 Mtetra
.718 .839 .939 r
.55499 .55472 .55596 .55548 .55778 .55476 .55682 .55385 Mtetra
.61 .772 .958 r
.55682 .55385 .55778 .55476 .5596 .55453 .55864 .55342 Mtetra
.636 .739 .922 r
.55864 .55342 .5596 .55453 .56143 .55412 .56047 .55292 Mtetra
.691 .74 .889 r
.56047 .55292 .56143 .55412 .56325 .55321 .56229 .55215 Mtetra
.792 .789 .85 r
.56229 .55215 .56325 .55321 .56505 .5503 .56411 .55073 Mtetra
.847 .993 .743 r
.56411 .55073 .56505 .5503 .56681 .54373 .56592 .54853 Mtetra
.09 0 .248 r
.56592 .54853 .56681 .54373 .56602 .34255 .56771 .54475 Mtetra
0 0 .366 r
.56771 .54475 .56602 .34255 .56768 .33784 .56691 .34639 Mtetra
0 0 .211 r
.56691 .34639 .56768 .33784 .56938 .33554 .56851 .33644 Mtetra
.902 .942 .579 r
.56851 .33644 .56938 .33554 .57108 .33407 .57018 .33312 Mtetra
.766 .794 .876 r
.57018 .33312 .57108 .33407 .57279 .33332 .57189 .332 Mtetra
.623 .68 .883 r
.57189 .332 .57279 .33332 .57451 .33292 .57361 .3316 Mtetra
.549 .647 .898 r
.57361 .3316 .57451 .33292 .57624 .33266 .57534 .33149 Mtetra
.629 .709 .904 r
.57534 .33149 .57624 .33266 .57796 .33217 .57706 .33105 Mtetra
.66 .732 .903 r
.57706 .33105 .57796 .33217 .57968 .33157 .57879 .33048 Mtetra
.673 .743 .903 r
.57879 .33048 .57968 .33157 .5814 .33091 .58051 .32985 Mtetra
.723 .764 .885 r
.58051 .32985 .5814 .33091 .58311 .32988 .58223 .32896 Mtetra
.719 .793 .91 r
.58223 .32896 .58311 .32988 .58483 .32898 .58395 .32813 Mtetra
.662 .792 .944 r
.58395 .32813 .58483 .32898 .58656 .32853 .58567 .32754 Mtetra
.452 .671 .957 r
.58567 .32754 .58656 .32853 .58832 .32982 .58741 .3276 Mtetra
.379 .432 .79 r
.58741 .3276 .58832 .32982 .59016 .33435 .58917 .32841 Mtetra
.382 .288 .623 r
.58917 .32841 .59016 .33435 .59616 .5349 .59096 .33064 Mtetra
0 0 .39 r
.59096 .33064 .59616 .5349 .59811 .53929 .59691 .52644 Mtetra
.069 .018 .486 r
.59691 .52644 .59811 .53929 .6 .54073 .59901 .53724 Mtetra
.124 .19 .661 r
.59901 .53724 .6 .54073 .60188 .54123 .60093 .53992 Mtetra
.44 .611 .921 r
.60093 .53992 .60188 .54123 .60374 .54094 .6028 .54013 Mtetra
.673 .82 .954 r
.6028 .54013 .60374 .54094 .60559 .54024 .60465 .53944 Mtetra
.744 .838 .922 r
.60465 .53944 .60559 .54024 .60744 .5394 .6065 .53842 Mtetra
.534 .73 .965 r
.6065 .53842 .60744 .5394 .60931 .53929 .60837 .53823 Mtetra
.535 .712 .953 r
.60837 .53823 .60931 .53929 .61118 .53916 .61023 .53807 Mtetra
.705 .77 .903 r
.61023 .53807 .61118 .53916 .61303 .53835 .61209 .53723 Mtetra
.924 .777 .68 r
.61209 .53723 .61303 .53835 .61479 .53428 .61385 .53304 Mtetra
.973 .688 .426 r
.61385 .53304 .61479 .53428 .61109 .33021 .61019 .32837 Mtetra
.937 .713 .573 r
.61019 .32837 .61109 .33021 .61259 .32086 .61171 .31963 Mtetra
.832 .761 .784 r
.61171 .31963 .61259 .32086 .6143 .31887 .61342 .31768 Mtetra
.64 .714 .901 r
.61342 .31768 .6143 .31887 .61604 .31835 .61516 .31719 Mtetra
.501 .657 .93 r
.61516 .31719 .61604 .31835 .6178 .31833 .61692 .31719 Mtetra
.588 .703 .922 r
.61692 .31719 .6178 .31833 .61956 .31801 .61868 .3169 Mtetra
.651 .736 .911 r
.61868 .3169 .61956 .31801 .6213 .31743 .62043 .31636 Mtetra
.666 .748 .912 r
.62043 .31636 .6213 .31743 .62305 .3168 .62218 .31576 Mtetra
.717 .77 .894 r
.62218 .31576 .62305 .3168 .62479 .31582 .62392 .3149 Mtetra
.726 .799 .91 r
.62392 .3149 .62479 .31582 .62652 .31486 .62566 .31402 Mtetra
.676 .804 .943 r
.62566 .31402 .62652 .31486 .62828 .31432 .62741 .31337 Mtetra
.492 .702 .963 r
.62741 .31337 .62828 .31432 .63008 .31529 .62918 .31331 Mtetra
.387 .464 .817 r
.62918 .31331 .63008 .31529 .63199 .31914 .63098 .314 Mtetra
.389 .309 .644 r
.63098 .314 .63199 .31914 .64072 .5198 .63282 .3159 Mtetra
.521 .308 .532 r
.63282 .3159 .64072 .5198 .6428 .52524 .63502 .32781 Mtetra
0 0 .399 r
.63502 .32781 .6428 .52524 .64476 .52673 .64371 .52236 Mtetra
.16 .18 .633 r
.64371 .52236 .64476 .52673 .64668 .52728 .64573 .5256 Mtetra
.286 .459 .857 r
.64573 .5256 .64668 .52728 .64859 .52751 .64767 .52646 Mtetra
.546 .72 .954 r
.64767 .52646 .64859 .52751 .65049 .52736 .64957 .52625 Mtetra
.691 .766 .909 r
.64957 .52625 .65049 .52736 .65237 .52661 .65144 .52548 Mtetra
.772 .784 .863 r
.65144 .52548 .65237 .52661 .65419 .52437 .6533 .52419 Mtetra
.879 .969 .844 r
.6533 .52419 .65419 .52437 .6559 .51934 .65514 .52225 Mtetra
0 0 .091 r
.65514 .52225 .6559 .51934 .64981 .31807 .65693 .51911 Mtetra
.527 .308 .526 r
.65693 .51911 .64981 .31807 .6513 .31053 .65846 .50968 Mtetra
0 0 .392 r
.65846 .50968 .6513 .31053 .65298 .30796 .65226 .3102 Mtetra
0 0 0 r
.65226 .3102 .65298 .30796 .65471 .30634 .65388 .30587 Mtetra
.873 .911 .852 r
.65388 .30587 .65471 .30634 .65646 .30534 .6556 .3041 Mtetra
.677 .721 .882 r
.6556 .3041 .65646 .30534 .65823 .30471 .65736 .30342 Mtetra
.609 .684 .895 r
.65736 .30342 .65823 .30471 .66001 .30423 .65915 .30306 Mtetra
.674 .734 .895 r
.65915 .30306 .66001 .30423 .66177 .30338 .66092 .3024 Mtetra
.727 .79 .902 r
.66092 .3024 .66177 .30338 .66352 .30238 .66268 .3015 Mtetra
.683 .8 .937 r
.66268 .3015 .66352 .30238 .6653 .30177 .66445 .30081 Mtetra
.527 .719 .961 r
.66445 .30081 .6653 .30177 .66713 .30247 .66625 .30066 Mtetra
.395 .489 .838 r
.66625 .30066 .66713 .30247 .66909 .30588 .66808 .30126 Mtetra
.392 .323 .66 r
.66808 .30126 .66909 .30588 .68025 .50617 .66996 .30298 Mtetra
.528 .314 .533 r
.66996 .30298 .68025 .50617 .6825 .51301 .67215 .311 Mtetra
.003 0 .412 r
.67215 .311 .6825 .51301 .68451 .51464 .68342 .50977 Mtetra
.175 .178 .622 r
.68342 .50977 .68451 .51464 .68648 .51526 .68553 .51337 Mtetra
.212 .383 .817 r
.68553 .51337 .68648 .51526 .68843 .51559 .68753 .51461 Mtetra
.442 .69 .97 r
.68753 .51461 .68843 .51559 .69037 .51558 .68947 .51466 Mtetra
.713 .813 .928 r
.68947 .51466 .69037 .51558 .69227 .51482 .69137 .51377 Mtetra
.912 .806 .73 r
.69137 .51377 .69227 .51482 .69406 .51179 .69316 .5106 Mtetra
.977 .716 .467 r
.69316 .5106 .69406 .51179 .69514 .49495 .69406 .49017 Mtetra
.974 .68 .402 r
.69406 .49017 .69514 .49495 .68678 .29661 .68593 .29535 Mtetra
.887 .771 .728 r
.68593 .29535 .68678 .29661 .68845 .29366 .6876 .29246 Mtetra
.68 .733 .89 r
.6876 .29246 .68845 .29366 .69023 .29294 .68938 .29177 Mtetra
.551 .683 .926 r
.68938 .29177 .69023 .29294 .69205 .29274 .6912 .2916 Mtetra
.649 .733 .91 r
.6912 .2916 .69205 .29274 .69384 .29216 .693 .29106 Mtetra
.75 .774 .873 r
.693 .29106 .69384 .29216 .69561 .29106 .69476 .28998 Mtetra
.656 .748 .918 r
.69476 .28998 .69561 .29106 .6974 .29046 .69656 .2894 Mtetra
0 .29 .782 r
.69656 .2894 .6974 .29046 .6993 .2917 .69846 .29069 Mtetra
.948 .593 .224 r
.69846 .29069 .6993 .2917 .70173 .30222 .70097 .30257 Mtetra
.974 .673 .373 r
.70097 .30257 .70173 .30222 .71514 .50455 .71426 .50366 Mtetra
.553 .055 0 r
.71426 .50366 .71514 .50455 .71723 .50692 .71635 .50595 Mtetra
.605 .768 .958 r
.71635 .50595 .71723 .50692 .71917 .50652 .71829 .50551 Mtetra
.744 .808 .903 r
.71829 .50551 .71917 .50652 .72108 .50549 .72019 .50444 Mtetra
.676 .779 .928 r
.72019 .50444 .72108 .50549 .72301 .50481 .72212 .50373 Mtetra
.482 .686 .956 r
.72212 .50373 .72301 .50481 .72498 .50483 .72409 .50372 Mtetra
.637 .75 .93 r
.72409 .50372 .72498 .50483 .72692 .50432 .72603 .50318 Mtetra
.871 .804 .781 r
.72603 .50318 .72692 .50432 .72875 .50198 .72786 .5008 Mtetra
.974 .748 .535 r
.72786 .5008 .72875 .50198 .73014 .49257 .72923 .4911 Mtetra
.977 .681 .379 r
.72923 .4911 .73014 .49257 .71926 .287 .71842 .28578 Mtetra
.92 .777 .686 r
.71842 .28578 .71926 .287 .72087 .28327 .72004 .28209 Mtetra
.723 .756 .878 r
.72004 .28209 .72087 .28327 .72266 .28233 .72183 .28116 Mtetra
.6 .709 .921 r
.72183 .28116 .72266 .28233 .72449 .28198 .72366 .28082 Mtetra
.634 .725 .913 r
.72366 .28082 .72449 .28198 .72631 .28148 .72548 .28033 Mtetra
.741 .766 .873 r
.72548 .28033 .72631 .28148 .7281 .28044 .72727 .27929 Mtetra
.653 .735 .91 r
.72727 .27929 .7281 .28044 .72992 .27987 .72909 .27872 Mtetra
.116 .433 .874 r
.72909 .27872 .72992 .27987 .73184 .28081 .73101 .27966 Mtetra
.907 .523 .092 r
.73101 .27966 .73184 .28081 .73423 .28871 .7334 .28754 Mtetra
.975 .671 .352 r
.7334 .28754 .73423 .28871 .74995 .49286 .74908 .49176 Mtetra
.597 .136 0 r
.74908 .49176 .74995 .49286 .75214 .49579 .75127 .4947 Mtetra
.554 .722 .951 r
.75127 .4947 .75214 .49579 .75412 .49555 .75325 .49446 Mtetra
.713 .786 .909 r
.75325 .49446 .75412 .49555 .75606 .49464 .75518 .49355 Mtetra
.696 .78 .916 r
.75518 .49355 .75606 .49464 .758 .49382 .75712 .49273 Mtetra
.511 .701 .955 r
.75712 .49273 .758 .49382 .75999 .49372 .75912 .49263 Mtetra
.654 .764 .931 r
.75912 .49263 .75999 .49372 .76195 .4931 .76108 .49201 Mtetra
.868 .816 .796 r
.76108 .49201 .76195 .4931 .76379 .49086 .76292 .48976 Mtetra
.98 .749 .517 r
.76292 .48976 .76379 .49086 .76505 .48067 .76418 .47954 Mtetra
.977 .678 .362 r
.76418 .47954 .76505 .48067 .75204 .27586 .75122 .27471 Mtetra
.932 .788 .678 r
.75122 .27471 .75204 .27586 .75363 .27203 .75281 .27088 Mtetra
.726 .764 .883 r
.75281 .27088 .75363 .27203 .75544 .27108 .75462 .26993 Mtetra
.601 .714 .924 r
.75462 .26993 .75544 .27108 .75729 .27072 .75647 .26957 Mtetra
.6 .714 .924 r
.75647 .26957 .75729 .27072 .75914 .27037 .75833 .26922 Mtetra
.739 .769 .877 r
.75833 .26922 .75914 .27037 .76095 .26934 .76013 .26819 Mtetra
.656 .738 .91 r
.76013 .26819 .76095 .26934 .76279 .26875 .76197 .2676 Mtetra
.233 .509 .907 r
.76197 .2676 .76279 .26875 .76473 .26945 .76391 .26829 Mtetra
.883 .491 .036 r
.76391 .26829 .76473 .26945 .76718 .2767 .76637 .27556 Mtetra
.975 .667 .334 r
.76637 .27556 .76718 .2767 .78526 .48211 .7844 .48102 Mtetra
.656 .202 0 r
.7844 .48102 .78526 .48211 .78756 .48557 .7867 .48448 Mtetra
.381 .631 .952 r
.7867 .48448 .78756 .48557 .7896 .48584 .78875 .48475 Mtetra
.693 .781 .919 r
.78875 .48475 .7896 .48584 .79157 .48503 .79071 .48393 Mtetra
.874 .821 .793 r
.79071 .48393 .79157 .48503 .79341 .48272 .79256 .48163 Mtetra
.978 .767 .55 r
.79256 .48163 .79341 .48272 .79479 .47483 .79395 .47376 Mtetra
.977 .675 .347 r
.79395 .47376 .79479 .47483 .77972 .26742 .77891 .26628 Mtetra
.951 .786 .642 r
.77891 .26628 .77972 .26742 .78124 .26287 .78044 .26171 Mtetra
.745 .773 .876 r
.78044 .26171 .78124 .26287 .78305 .2618 .78225 .26064 Mtetra
.616 .722 .922 r
.78225 .26064 .78305 .2618 .78492 .26138 .78412 .26022 Mtetra
.583 .707 .928 r
.78412 .26022 .78492 .26138 .7868 .26108 .786 .25992 Mtetra
.746 .773 .874 r
.786 .25992 .7868 .26108 .78861 .26001 .78781 .25884 Mtetra
.67 .744 .906 r
.78781 .25884 .78861 .26001 .79047 .25935 .78967 .25818 Mtetra
.353 .581 .928 r
.78967 .25818 .79047 .25935 .79241 .25977 .79161 .2586 Mtetra
.834 .429 0 r
.79161 .2586 .79241 .25977 .79485 .26583 .79405 .26467 Mtetra
.973 .663 .318 r
.79405 .26467 .79485 .26583 .81496 .47246 .81412 .47136 Mtetra
.692 .246 0 r
.81412 .47136 .81496 .47246 .81736 .47638 .81652 .4753 Mtetra
.401 .646 .956 r
.81652 .4753 .81736 .47638 .81942 .47645 .81859 .47551 Mtetra
.682 .813 .946 r
.81859 .47551 .81942 .47645 .8214 .47567 .82058 .47473 Mtetra
.84 .853 .855 r
.82058 .47473 .8214 .47567 .82333 .4743 .82248 .47298 Mtetra
.922 .789 .696 r
.82248 .47298 .82333 .4743 .82525 .47278 .8242 .46928 Mtetra
.918 .672 .552 r
.8242 .46928 .82525 .47278 .8271 .47049 .82534 .45932 Mtetra
.972 .665 .36 r
.82534 .45932 .8271 .47049 .82877 .46627 .8088 .25759 Mtetra
.55 .33 .534 r
.8088 .25759 .82877 .46627 .81191 .26284 .8104 .25403 Mtetra
.624 .432 .601 r
.8104 .25403 .81191 .26284 .81309 .25485 .81214 .25196 Mtetra
.692 .575 .719 r
.81214 .25196 .81309 .25485 .81473 .25177 .81394 .25059 Mtetra
.695 .754 .897 r
.81394 .25059 .81473 .25177 .81657 .25077 .8158 .2498 Mtetra
.643 .778 .945 r
.8158 .2498 .81657 .25077 .81845 .25024 .81768 .24924 Mtetra
.63 .764 .943 r
.81768 .24924 .81845 .25024 .82035 .24989 .81957 .24873 Mtetra
.758 .78 .871 r
.81957 .24873 .82035 .24989 .82218 .24874 .82139 .24757 Mtetra
.688 .753 .901 r
.82139 .24757 .82218 .24874 .82404 .24799 .82326 .24681 Mtetra
.469 .645 .934 r
.82326 .24681 .82404 .24799 .82599 .2481 .8252 .24691 Mtetra
.767 .353 0 r
.8252 .24691 .82599 .2481 .82845 .25334 .82766 .25211 Mtetra
.971 .657 .298 r
.82766 .25211 .82845 .25334 .85101 .46091 .85018 .45975 Mtetra
.717 .286 0 r
.85018 .45975 .85101 .46091 .85355 .46549 .85272 .46435 Mtetra
.312 .581 .937 r
.85272 .46435 .85355 .46549 .85568 .46597 .85486 .46484 Mtetra
.651 .763 .931 r
.85486 .46484 .85568 .46597 .85771 .46534 .85688 .46421 Mtetra
.83 .82 .839 r
.85688 .46421 .85771 .46534 .85962 .46356 .85879 .46243 Mtetra
.976 .788 .588 r
.85879 .46243 .85962 .46356 .86108 .45746 .86026 .45635 Mtetra
.974 .667 .312 r
.86026 .45635 .86108 .45746 .84161 .24845 .84084 .24731 Mtetra
.976 .778 .572 r
.84084 .24731 .84161 .24845 .84293 .24227 .84216 .24111 Mtetra
.761 .762 .853 r
.23366 .4466 .23468 .44753 .23625 .44647 .23522 .44554 Mtetra
.609 .732 .933 r
.23522 .44554 .23625 .44647 .23775 .44613 .23672 .44522 Mtetra
.435 .67 .961 r
.23672 .44522 .23775 .44613 .23922 .44618 .23819 .44529 Mtetra
.636 .749 .93 r
.23819 .44529 .23922 .44618 .24073 .44575 .2397 .44488 Mtetra
.644 .753 .928 r
.2397 .44488 .24073 .44575 .24224 .44528 .24121 .44443 Mtetra
.652 .761 .929 r
.24121 .44443 .24224 .44528 .24376 .44475 .24273 .44395 Mtetra
.672 .778 .93 r
.24273 .44395 .24376 .44475 .2453 .44405 .24426 .4434 Mtetra
.678 .816 .949 r
.24426 .4434 .2453 .44405 .24684 .44331 .24578 .44281 Mtetra
.677 .853 .967 r
.24578 .44281 .24684 .44331 .24838 .44258 .24732 .44221 Mtetra
.673 .882 .976 r
.24732 .44221 .24838 .44258 .24993 .4418 .24885 .44158 Mtetra
.642 .913 .981 r
.24885 .44158 .24993 .4418 .25146 .44116 .25038 .44095 Mtetra
.627 .912 .982 r
.25038 .44095 .25146 .44116 .25298 .4408 .25192 .44036 Mtetra
.632 .86 .985 r
.25192 .44036 .25298 .4408 .25441 .44144 .25344 .43985 Mtetra
.644 .631 .823 r
.25344 .43985 .25441 .44144 .25578 .44276 .25497 .43937 Mtetra
.608 .492 .695 r
.25497 .43937 .25578 .44276 .2571 .44487 .25649 .43888 Mtetra
.588 .427 .63 r
.25649 .43888 .2571 .44487 .25855 .44525 .25803 .43832 Mtetra
.584 .414 .618 r
.25803 .43832 .25855 .44525 .2601 .44454 .25956 .43774 Mtetra
.585 .416 .619 r
.25956 .43774 .2601 .44454 .26169 .44338 .2611 .43715 Mtetra
.587 .423 .627 r
.2611 .43715 .26169 .44338 .26323 .44272 .26263 .4366 Mtetra
.587 .424 .628 r
.26263 .4366 .26323 .44272 .26477 .44213 .26417 .43605 Mtetra
.587 .425 .629 r
.26417 .43605 .26477 .44213 .26631 .44155 .2657 .43551 Mtetra
.587 .426 .629 r
.2657 .43551 .26631 .44155 .26785 .44098 .26724 .43496 Mtetra
.587 .426 .63 r
.26724 .43496 .26785 .44098 .2694 .44042 .26878 .43441 Mtetra
.587 .425 .63 r
.26878 .43441 .2694 .44042 .27093 .43989 .27032 .43388 Mtetra
.608 .441 .63 r
.27032 .43388 .27093 .43989 .27253 .43861 .27188 .43297 Mtetra
.597 .438 .636 r
.27188 .43297 .27253 .43861 .27409 .43781 .27343 .43231 Mtetra
.557 .41 .638 r
.27343 .43231 .27409 .43781 .27557 .43819 .27494 .43227 Mtetra
.174 .126 .559 r
.27494 .43227 .27557 .43819 .26272 .62699 .27618 .43566 Mtetra
0 0 .183 r
.27618 .43566 .26272 .62699 .26345 .63834 .2627 .63311 Mtetra
0 0 .228 r
.2627 .63311 .26345 .63834 .26484 .6412 .26382 .63942 Mtetra
.318 .455 .841 r
.26382 .63942 .26484 .6412 .26642 .64147 .26537 .6401 Mtetra
.643 .676 .866 r
.26537 .6401 .26642 .64147 .26805 .64098 .26701 .63962 Mtetra
.717 .701 .834 r
.26701 .63962 .26805 .64098 .26971 .64022 .26868 .6387 Mtetra
.665 .662 .837 r
.26868 .6387 .26971 .64022 .27135 .63978 .27033 .63807 Mtetra
.645 .632 .822 r
.27033 .63807 .27135 .63978 .27298 .63942 .27197 .63754 Mtetra
.64 .612 .805 r
.27197 .63754 .27298 .63942 .27462 .63901 .27362 .63702 Mtetra
.63 .595 .796 r
.27362 .63702 .27462 .63901 .27627 .63844 .27526 .63655 Mtetra
.628 .604 .807 r
.27526 .63655 .27627 .63844 .27792 .63779 .2769 .6361 Mtetra
.632 .629 .829 r
.2769 .6361 .27792 .63779 .27958 .63713 .27854 .63566 Mtetra
.639 .66 .855 r
.27854 .63566 .27958 .63713 .28122 .63671 .28019 .63519 Mtetra
.642 .654 .846 r
.28019 .63519 .28122 .63671 .28286 .63629 .28184 .6347 Mtetra
.644 .646 .837 r
.28184 .6347 .28286 .63629 .28452 .63565 .28348 .63419 Mtetra
.657 .669 .85 r
.28348 .63419 .28452 .63565 .28625 .63407 .28514 .63362 Mtetra
.64 .872 .985 r
.28514 .63362 .28625 .63407 .28802 .63168 .2868 .63304 Mtetra
.222 0 0 r
.2868 .63304 .28802 .63168 .28985 .62855 .28845 .63246 Mtetra
.456 .141 .342 r
.28845 .63246 .28985 .62855 .2916 .62663 .29011 .63197 Mtetra
.485 .194 .396 r
.29011 .63197 .2916 .62663 .29325 .62614 .29176 .63151 Mtetra
.486 .196 .397 r
.29176 .63151 .29325 .62614 .29486 .62621 .29341 .63106 Mtetra
.511 .211 .394 r
.29341 .63106 .29486 .62621 .29645 .62666 .29504 .63096 Mtetra
.491 .182 .371 r
.29504 .63096 .29645 .62666 .29808 .62664 .29668 .63071 Mtetra
.411 .102 .329 r
.29668 .63071 .29808 .62664 .29977 .62549 .29836 .62981 Mtetra
0 0 .07 r
.29836 .62981 .29977 .62549 .30218 .61341 .30025 .6259 Mtetra
.961 .707 .505 r
.30025 .6259 .30218 .61341 .31604 .42318 .31465 .42837 Mtetra
.848 .796 .301 r
.31465 .42837 .31604 .42318 .31782 .41923 .31677 .41922 Mtetra
.908 .921 .815 r
.31677 .41922 .31782 .41923 .31944 .41784 .31843 .41717 Mtetra
.694 .818 .941 r
.31843 .41717 .31944 .41784 .321 .41741 .32001 .41651 Mtetra
.565 .729 .952 r
.32001 .41651 .321 .41741 .32254 .41729 .32155 .41629 Mtetra
.621 .724 .92 r
.32155 .41629 .32254 .41729 .3241 .41697 .32311 .41592 Mtetra
.655 .725 .9 r
.32311 .41592 .3241 .41697 .32566 .41646 .32468 .41541 Mtetra
.655 .727 .902 r
.32468 .41541 .32566 .41646 .32723 .4159 .32624 .41491 Mtetra
.668 .743 .906 r
.32624 .41491 .32723 .4159 .32882 .41511 .32782 .41436 Mtetra
.675 .796 .939 r
.32782 .41436 .32882 .41511 .33041 .41432 .32939 .41377 Mtetra
.66 .847 .972 r
.32939 .41377 .33041 .41432 .33198 .41374 .33097 .4132 Mtetra
.73 .859 .942 r
.33097 .4132 .33198 .41374 .33352 .41372 .33256 .41239 Mtetra
.69 .687 .843 r
.33256 .41239 .33352 .41372 .33502 .41444 .33414 .41167 Mtetra
.579 .503 .733 r
.33414 .41167 .33502 .41444 .33646 .41635 .33569 .41149 Mtetra
.289 .234 .62 r
.33569 .41149 .33646 .41635 .3371 .43203 .33711 .41373 Mtetra
.971 .71 .479 r
.33711 .41373 .3371 .43203 .328 .61819 .32744 .60863 Mtetra
0 0 .29 r
.32744 .60863 .328 .61819 .32947 .62124 .3285 .61894 Mtetra
.127 .272 .744 r
.3285 .61894 .32947 .62124 .33109 .62177 .33006 .62041 Mtetra
.607 .668 .883 r
.33006 .62041 .33109 .62177 .33278 .62118 .33173 .62009 Mtetra
.714 .748 .879 r
.33173 .62009 .33278 .62118 .33448 .62024 .33343 .61926 Mtetra
.69 .763 .907 r
.33343 .61926 .33448 .62024 .33616 .6197 .33512 .61856 Mtetra
.645 .721 .903 r
.33512 .61856 .33616 .6197 .33783 .61945 .3368 .61807 Mtetra
.649 .68 .866 r
.3368 .61807 .33783 .61945 .33951 .619 .33849 .61755 Mtetra
.592 .647 .874 r
.33849 .61755 .33951 .619 .34123 .61794 .34016 .61729 Mtetra
.541 .797 .992 r
.34016 .61729 .34123 .61794 .34298 .61608 .34183 .61701 Mtetra
0 0 0 r
.34183 .61701 .34298 .61608 .3448 .61295 .34354 .61614 Mtetra
.34354 .61614 .3448 .61295 .34708 .601 .34537 .61282 Mtetra
.965 .707 .493 r
.34537 .61282 .34708 .601 .35863 .40884 .35711 .41811 Mtetra
0 0 0 r
.35711 .41811 .35863 .40884 .36039 .40494 .35934 .40523 Mtetra
.939 .945 .765 r
.35934 .40523 .36039 .40494 .36203 .40336 .36103 .40272 Mtetra
.707 .833 .942 r
.36103 .40272 .36203 .40336 .36362 .40289 .36263 .402 Mtetra
.568 .734 .953 r
.36263 .402 .36362 .40289 .36519 .40278 .36421 .40176 Mtetra
.591 .714 .929 r
.36421 .40176 .36519 .40278 .36676 .40256 .36579 .40148 Mtetra
.647 .721 .902 r
.36579 .40148 .36676 .40256 .36835 .40208 .36738 .40101 Mtetra
.646 .722 .903 r
.36738 .40101 .36835 .40208 .36995 .40154 .36897 .40054 Mtetra
.657 .739 .91 r
.36897 .40054 .36995 .40154 .37155 .40081 .37057 .40002 Mtetra
.666 .79 .94 r
.37057 .40002 .37155 .40081 .37316 .39999 .37217 .39946 Mtetra
.65 .85 .977 r
.37217 .39946 .37316 .39999 .37476 .39938 .37377 .3989 Mtetra
.622 .858 .987 r
.37377 .3989 .37476 .39938 .37633 .39947 .37536 .39839 Mtetra
.642 .719 .904 r
.37536 .39839 .37633 .39947 .37786 .40054 .37696 .39793 Mtetra
.616 .535 .74 r
.37696 .39793 .37786 .40054 .37935 .40244 .37856 .39748 Mtetra
.591 .444 .651 r
.37856 .39748 .37935 .40244 .38084 .4045 .38016 .39699 Mtetra
.579 .407 .613 r
.38016 .39699 .38084 .4045 .3824 .40488 .38176 .39645 Mtetra
.576 .399 .604 r
.38176 .39645 .3824 .40488 .38405 .40342 .38336 .39587 Mtetra
.582 .409 .612 r
.38336 .39587 .38405 .40342 .38576 .40035 .38497 .39526 Mtetra
.6 .449 .648 r
.38497 .39526 .38576 .40035 .38748 .39732 .38658 .39461 Mtetra
.635 .54 .73 r
.38658 .39461 .38748 .39732 .38916 .3951 .38819 .39397 Mtetra
.672 .719 .884 r
.38819 .39397 .38916 .3951 .3908 .39377 .3898 .39337 Mtetra
.614 .877 .99 r
.3898 .39337 .3908 .39377 .39241 .39314 .39141 .39284 Mtetra
.58 .89 .989 r
.39141 .39284 .39241 .39314 .39401 .39273 .39302 .39233 Mtetra
.611 .875 .991 r
.39302 .39233 .39401 .39273 .39561 .39238 .39463 .39181 Mtetra
.645 .842 .976 r
.39463 .39181 .39561 .39238 .39722 .39199 .39624 .39127 Mtetra
.659 .807 .954 r
.39624 .39127 .39722 .39199 .39882 .3916 .39785 .39072 Mtetra
.669 .77 .926 r
.39785 .39072 .39882 .3916 .40043 .39116 .39947 .39015 Mtetra
.673 .743 .904 r
.39947 .39015 .40043 .39116 .40204 .39064 .40108 .38956 Mtetra
.672 .73 .894 r
.40108 .38956 .40204 .39064 .40366 .39005 .4027 .38897 Mtetra
.668 .729 .895 r
.4027 .38897 .40366 .39005 .40528 .38938 .40432 .3884 Mtetra
.663 .747 .913 r
.40432 .3884 .40528 .38938 .4069 .38864 .40593 .38785 Mtetra
.659 .791 .945 r
.40593 .38785 .4069 .38864 .40853 .3879 .40755 .38731 Mtetra
.709 .851 .95 r
.40755 .38731 .40853 .3879 .41016 .38708 .40918 .38656 Mtetra
.75 .873 .936 r
.40918 .38656 .41016 .38708 .41179 .38624 .41081 .38563 Mtetra
.619 .827 .98 r
.41081 .38563 .41179 .38624 .4134 .38575 .41243 .38517 Mtetra
.455 0 0 r
.41243 .38517 .4134 .38575 .41499 .38619 .414 .38625 Mtetra
.929 .597 .389 r
.414 .38625 .41499 .38619 .4165 .38885 .41531 .39486 Mtetra
.947 .675 .488 r
.41531 .39486 .4165 .38885 .41185 .57723 .41027 .59283 Mtetra
.597 .341 .5 r
.41027 .59283 .41185 .57723 .41306 .59225 .41189 .5956 Mtetra
.497 .163 .332 r
.41189 .5956 .41306 .59225 .4147 .59448 .41361 .59553 Mtetra
.096 0 0 r
.41361 .59553 .4147 .59448 .41638 .59541 .41535 .59485 Mtetra
.703 .868 .96 r
.41535 .59485 .41638 .59541 .4181 .59559 .41709 .59406 Mtetra
.64 .66 .854 r
.41709 .59406 .4181 .59559 .41983 .5952 .41883 .59356 Mtetra
.644 .647 .838 r
.41883 .59356 .41983 .5952 .42156 .59458 .42056 .59303 Mtetra
.62 .649 .857 r
.42056 .59303 .42156 .59458 .4233 .59404 .42229 .59264 Mtetra
.571 .65 .889 r
.42229 .59264 .4233 .59404 .42503 .59381 .42402 .59245 Mtetra
.673 .698 .865 r
.42402 .59245 .42503 .59381 .42677 .59324 .42577 .59178 Mtetra
.819 .724 .76 r
.42577 .59178 .42677 .59324 .42854 .59169 .42755 .58961 Mtetra
.911 .696 .598 r
.42755 .58961 .42854 .59169 .43038 .5875 .42953 .58056 Mtetra
.951 .683 .491 r
.42953 .58056 .43038 .5875 .43262 .56865 .43676 .38045 Mtetra
.551 .332 .535 r
.43676 .38045 .43262 .56865 .4393 .38296 .43849 .37665 Mtetra
.603 .435 .627 r
.43849 .37665 .4393 .38296 .44095 .38208 .44014 .37575 Mtetra
.571 .412 .627 r
.44014 .37575 .44095 .38208 .44257 .38197 .44177 .37544 Mtetra
.564 .405 .624 r
.44177 .37544 .44257 .38197 .44423 .38084 .4434 .37525 Mtetra
.593 .437 .639 r
.4434 .37525 .44423 .38084 .44594 .37778 .44504 .37464 Mtetra
.622 .514 .71 r
.44504 .37464 .44594 .37778 .44762 .37549 .44668 .37404 Mtetra
.66 .667 .846 r
.44668 .37404 .44762 .37549 .44929 .37395 .44833 .37345 Mtetra
.624 .86 .987 r
.44833 .37345 .44929 .37395 .45093 .37326 .44997 .37293 Mtetra
.583 .886 .991 r
.44997 .37293 .45093 .37326 .45257 .37281 .45161 .37241 Mtetra
.603 .877 .992 r
.45161 .37241 .45257 .37281 .45421 .37246 .45326 .37188 Mtetra
.642 .844 .978 r
.45326 .37188 .45421 .37246 .45586 .37205 .45491 .37133 Mtetra
.658 .812 .957 r
.45491 .37133 .45586 .37205 .4575 .37165 .45655 .37077 Mtetra
.667 .776 .931 r
.45655 .37077 .4575 .37165 .45915 .37121 .4582 .37019 Mtetra
.673 .747 .906 r
.4582 .37019 .45915 .37121 .46079 .37068 .45985 .36959 Mtetra
.672 .732 .896 r
.45985 .36959 .46079 .37068 .46244 .37009 .46151 .36899 Mtetra
.668 .729 .895 r
.46151 .36899 .46244 .37009 .4641 .36944 .46316 .3684 Mtetra
.658 .74 .911 r
.46316 .3684 .4641 .36944 .46575 .3687 .46481 .36787 Mtetra
.655 .785 .944 r
.46481 .36787 .46575 .3687 .46741 .36795 .46646 .36733 Mtetra
.648 .837 .973 r
.46646 .36733 .46741 .36795 .46907 .36723 .46812 .36677 Mtetra
.65 .877 .982 r
.46812 .36677 .46907 .36723 .47072 .36661 .46978 .36615 Mtetra
.65 .879 .983 r
.46978 .36615 .47072 .36661 .47238 .36601 .47143 .36553 Mtetra
.678 .879 .973 r
.47143 .36553 .47238 .36601 .47404 .36539 .47309 .36484 Mtetra
.758 .875 .932 r
.47309 .36484 .47404 .36539 .4757 .36453 .47476 .36386 Mtetra
.655 .827 .966 r
.47476 .36386 .4757 .36453 .47736 .36396 .47642 .3633 Mtetra
.094 .547 .909 r
.47642 .3633 .47736 .36396 .47901 .36406 .47807 .36373 Mtetra
.922 .544 .276 r
.47807 .36373 .47901 .36406 .48063 .36655 .47964 .36933 Mtetra
.958 .68 .465 r
.47964 .36933 .48063 .36655 .48213 .37814 .47855 .57086 Mtetra
.55 .326 .528 r
.47855 .57086 .48213 .37814 .48132 .57044 .48026 .57489 Mtetra
.518 .209 .381 r
.48026 .57489 .48132 .57044 .48308 .5709 .48203 .57493 Mtetra
.443 .131 .341 r
.48203 .57493 .48308 .5709 .48486 .57009 .48381 .57425 Mtetra
.414 .109 .336 r
.48381 .57425 .48486 .57009 .48665 .56872 .48559 .57328 Mtetra
.47 .167 .369 r
.48559 .57328 .48665 .56872 .48842 .56819 .48737 .57275 Mtetra
.469 .166 .369 r
.48737 .57275 .48842 .56819 .4902 .56765 .48915 .57221 Mtetra
.48915 .57221 .4902 .56765 .49198 .56712 .49093 .57167 Mtetra
.47 .167 .369 r
.49093 .57167 .49198 .56712 .49375 .56659 .49271 .57115 Mtetra
.49271 .57115 .49375 .56659 .49553 .56608 .4945 .57062 Mtetra
.4945 .57062 .49553 .56608 .49731 .56557 .49628 .5701 Mtetra
.471 .167 .368 r
.49628 .5701 .49731 .56557 .4991 .56508 .49807 .56958 Mtetra
.47 .166 .367 r
.49807 .56958 .4991 .56508 .50088 .56458 .49985 .56905 Mtetra
.471 .166 .367 r
.49985 .56905 .50088 .56458 .50266 .56412 .50164 .56855 Mtetra
.508 .199 .377 r
.50164 .56855 .50266 .56412 .50445 .56442 .50343 .56847 Mtetra
.464 .151 .349 r
.50343 .56847 .50445 .56442 .50623 .56398 .50522 .56798 Mtetra
.36 .058 .31 r
.50522 .56798 .50623 .56398 .50803 .56195 .50702 .56662 Mtetra
0 0 .009 r
.50702 .56662 .50803 .56195 .5107 .3636 .50884 .56029 Mtetra
0 0 .319 r
.50884 .56029 .5107 .3636 .51242 .35509 .51148 .35686 Mtetra
.936 .879 .464 r
.51148 .35686 .51242 .35509 .51411 .35183 .51319 .35138 Mtetra
.795 .902 .917 r
.51319 .35138 .51411 .35183 .51579 .35085 .51487 .3502 Mtetra
.623 .824 .978 r
.51487 .3502 .51579 .35085 .51748 .35034 .51656 .34971 Mtetra
.461 .767 .996 r
.51656 .34971 .51748 .35034 .51916 .35006 .51824 .34957 Mtetra
.617 .865 .99 r
.51824 .34957 .51916 .35006 .52084 .34949 .51993 .34904 Mtetra
.607 .871 .992 r
.51993 .34904 .52084 .34949 .52253 .34894 .52161 .34851 Mtetra
.607 .875 .992 r
.52161 .34851 .52253 .34894 .52422 .34843 .5233 .34797 Mtetra
.638 .879 .986 r
.5233 .34797 .52422 .34843 .52591 .34802 .52499 .34736 Mtetra
.665 .836 .965 r
.52499 .34736 .52591 .34802 .5276 .34762 .52668 .34674 Mtetra
.673 .785 .934 r
.52668 .34674 .5276 .34762 .52929 .34716 .52837 .34612 Mtetra
.664 .746 .911 r
.52837 .34612 .52929 .34716 .53098 .34648 .53007 .34554 Mtetra
.662 .768 .928 r
.53007 .34554 .53098 .34648 .53267 .34575 .53176 .34497 Mtetra
.658 .805 .954 r
.53176 .34497 .53267 .34575 .53437 .34501 .53346 .3444 Mtetra
.661 .847 .971 r
.53346 .3444 .53437 .34501 .53606 .34422 .53515 .34378 Mtetra
.637 .884 .986 r
.53515 .34378 .53606 .34422 .53776 .34357 .53685 .34316 Mtetra
.62 .886 .989 r
.53685 .34316 .53776 .34357 .53945 .34319 .53855 .34257 Mtetra
.744 .863 .935 r
.53855 .34257 .53945 .34319 .54116 .34344 .54024 .34164 Mtetra
.653 .625 .809 r
.54024 .34164 .54116 .34344 .54286 .34443 .54194 .34103 Mtetra
.549 .461 .707 r
.54194 .34103 .54286 .34443 .54459 .34708 .54365 .34108 Mtetra
.171 .138 .576 r
.54365 .34108 .54459 .34708 .54763 .54543 .54538 .34517 Mtetra
0 0 .354 r
.54538 .34517 .54763 .54543 .5495 .55289 .54851 .54791 Mtetra
0 0 .483 r
.54851 .54791 .5495 .55289 .55135 .55523 .55037 .55339 Mtetra
.447 .529 .849 r
.55037 .55339 .55135 .55523 .55317 .5553 .5522 .55378 Mtetra
.654 .675 .857 r
.5522 .55378 .55317 .5553 .55499 .55472 .55403 .55318 Mtetra
.715 .696 .83 r
.55403 .55318 .55499 .55472 .55682 .55385 .55585 .55217 Mtetra
.64 .647 .841 r
.55585 .55217 .55682 .55385 .55864 .55342 .55767 .55163 Mtetra
.628 .629 .833 r
.55767 .55163 .55864 .55342 .56047 .55292 .5595 .55116 Mtetra
.634 .636 .835 r
.5595 .55116 .56047 .55292 .56229 .55215 .56133 .55066 Mtetra
.569 .642 .883 r
.56133 .55066 .56229 .55215 .56411 .55073 .56316 .55048 Mtetra
.487 .873 .971 r
.56316 .55048 .56411 .55073 .56592 .54853 .56499 .55 Mtetra
.057 0 0 r
.56499 .55 .56592 .54853 .56771 .54475 .56681 .54881 Mtetra
0 0 .071 r
.56681 .54881 .56771 .54475 .56691 .34639 .56859 .54379 Mtetra
0 0 .347 r
.56859 .54379 .56691 .34639 .56851 .33644 .56767 .33991 Mtetra
.717 .712 .182 r
.56767 .33991 .56851 .33644 .57018 .33312 .5693 .33288 Mtetra
.868 .948 .864 r
.5693 .33288 .57018 .33312 .57189 .332 .571 .3312 Mtetra
.67 .807 .948 r
.571 .3312 .57189 .332 .57361 .3316 .57272 .33058 Mtetra
.56 .715 .944 r
.57272 .33058 .57361 .3316 .57534 .33149 .57445 .33036 Mtetra
.639 .724 .909 r
.57445 .33036 .57534 .33149 .57706 .33105 .57617 .32988 Mtetra
.655 .721 .897 r
.57617 .32988 .57706 .33105 .57879 .33048 .57789 .32933 Mtetra
.656 .725 .9 r
.57789 .32933 .57879 .33048 .58051 .32985 .57962 .32877 Mtetra
.672 .746 .906 r
.57962 .32877 .58051 .32985 .58223 .32896 .58134 .32815 Mtetra
.674 .806 .945 r
.58134 .32815 .58223 .32896 .58395 .32813 .58306 .32751 Mtetra
.658 .851 .974 r
.58306 .32751 .58395 .32813 .58567 .32754 .58479 .32689 Mtetra
.739 .861 .938 r
.58479 .32689 .58567 .32754 .58741 .3276 .58651 .32597 Mtetra
.673 .656 .825 r
.58651 .32597 .58741 .3276 .58917 .32841 .58824 .32525 Mtetra
.568 .484 .72 r
.58824 .32525 .58917 .32841 .59096 .33064 .58998 .32514 Mtetra
.28 .225 .616 r
.58998 .32514 .59096 .33064 .59691 .52644 .59178 .32814 Mtetra
0 0 .372 r
.59178 .32814 .59691 .52644 .59901 .53724 .59794 .53041 Mtetra
0 0 .47 r
.59794 .53041 .59901 .53724 .60093 .53992 .59996 .53778 Mtetra
.331 .426 .809 r
.59996 .53778 .60093 .53992 .6028 .54013 .60185 .53873 Mtetra
.624 .684 .886 r
.60185 .53873 .6028 .54013 .60465 .53944 .60371 .53828 Mtetra
.718 .761 .886 r
.60371 .53828 .60465 .53944 .6065 .53842 .60556 .53736 Mtetra
.575 .728 .947 r
.60556 .53736 .6065 .53842 .60837 .53823 .60742 .53707 Mtetra
.592 .714 .929 r
.60742 .53707 .60837 .53823 .61023 .53807 .60929 .53674 Mtetra
.722 .733 .86 r
.60929 .53674 .61023 .53807 .61209 .53723 .61114 .53575 Mtetra
.902 .745 .678 r
.61114 .53575 .61209 .53723 .61385 .53304 .61291 .53159 Mtetra
.973 .687 .427 r
.61291 .53159 .61385 .53304 .61019 .32837 .60933 .32827 Mtetra
.988 .777 .533 r
.60933 .32827 .61019 .32837 .61171 .31963 .61085 .31913 Mtetra
.898 .889 .813 r
.61085 .31913 .61171 .31963 .61342 .31768 .61255 .31704 Mtetra
.672 .851 .968 r
.61255 .31704 .61342 .31768 .61516 .31719 .61429 .31636 Mtetra
.534 .752 .976 r
.61429 .31636 .61516 .31719 .61692 .31719 .61605 .31615 Mtetra
.612 .733 .932 r
.61605 .31615 .61692 .31719 .61868 .3169 .6178 .31576 Mtetra
.65 .727 .905 r
.6178 .31576 .61868 .3169 .62043 .31636 .61955 .31523 Mtetra
.651 .729 .906 r
.61955 .31523 .62043 .31636 .62218 .31576 .6213 .31468 Mtetra
.668 .748 .91 r
.6213 .31468 .62218 .31576 .62392 .3149 .62305 .31407 Mtetra
.677 .804 .943 r
.62305 .31407 .62392 .3149 .62566 .31402 .6248 .31341 Mtetra
.662 .856 .974 r
.6248 .31341 .62566 .31402 .62741 .31337 .62655 .31275 Mtetra
.735 .875 .945 r
.62655 .31275 .62741 .31337 .62918 .31331 .6283 .31183 Mtetra
.693 .688 .841 r
.6283 .31183 .62918 .31331 .63098 .314 .63004 .31102 Mtetra
.583 .503 .729 r
.63004 .31102 .63098 .314 .63282 .3159 .63181 .31078 Mtetra
.341 .276 .638 r
.63181 .31078 .63282 .3159 .63502 .32781 .63367 .31312 Mtetra
.982 .693 .362 r
.63367 .31312 .63502 .32781 .64371 .52236 .64254 .51433 Mtetra
0 0 .432 r
.64254 .51433 .64371 .52236 .64573 .5256 .64478 .52391 Mtetra
.089 .331 .806 r
.64478 .52391 .64573 .5256 .64767 .52646 .64674 .52531 Mtetra
.605 .725 .929 r
.64674 .52531 .64767 .52646 .64957 .52625 .64863 .52492 Mtetra
.71 .732 .868 r
.64863 .52492 .64957 .52625 .65144 .52548 .65051 .524 Mtetra
.632 .677 .875 r
.65051 .524 .65144 .52548 .6533 .52419 .6524 .52351 Mtetra
.538 .805 .995 r
.6524 .52351 .6533 .52419 .65514 .52225 .6543 .52317 Mtetra
0 0 0 r
.6543 .52317 .65514 .52225 .65693 .51911 .65617 .52223 Mtetra
0 0 .097 r
.65617 .52223 .65693 .51911 .65846 .50968 .65795 .51873 Mtetra
.982 .696 .385 r
.65795 .51873 .65846 .50968 .65226 .3102 .65181 .31934 Mtetra
0 0 .15 r
.65181 .31934 .65226 .3102 .65388 .30587 .65304 .30541 Mtetra
.93 .89 .77 r
.65304 .30541 .65388 .30587 .6556 .3041 .65473 .30286 Mtetra
.688 .726 .879 r
.65473 .30286 .6556 .3041 .65736 .30342 .6565 .30212 Mtetra
.581 .671 .901 r
.6565 .30212 .65736 .30342 .65915 .30306 .65828 .30188 Mtetra
.615 .708 .912 r
.65828 .30188 .65915 .30306 .66092 .3024 .66007 .30149 Mtetra
.675 .789 .935 r
.66007 .30149 .66092 .3024 .66268 .3015 .66184 .30083 Mtetra
.661 .845 .971 r
.66184 .30083 .66268 .3015 .66445 .30081 .66361 .30018 Mtetra
.722 .873 .952 r
.66361 .30018 .66445 .30081 .66625 .30066 .66538 .29931 Mtetra
.706 .714 .855 r
.66538 .29931 .66625 .30066 .66808 .30126 .66714 .29844 Mtetra
.595 .519 .739 r
.66714 .29844 .66808 .30126 .66996 .30298 .66894 .2981 Mtetra
.389 .315 .652 r
.66894 .2981 .66996 .30298 .67215 .311 .67083 .29994 Mtetra
.98 .686 .352 r
.67083 .29994 .67215 .311 .68342 .50977 .682 .49775 Mtetra
0 0 .434 r
.682 .49775 .68342 .50977 .68553 .51337 .68458 .51143 Mtetra
0 .193 .719 r
.68458 .51143 .68553 .51337 .68753 .51461 .68662 .51352 Mtetra
.496 .691 .955 r
.68662 .51352 .68753 .51461 .68947 .51466 .68856 .51348 Mtetra
.743 .771 .876 r
.68856 .51348 .68947 .51466 .69137 .51377 .69045 .51237 Mtetra
.89 .764 .717 r
.69045 .51237 .69137 .51377 .69316 .5106 .69223 .5091 Mtetra
.972 .717 .49 r
.69223 .5091 .69316 .5106 .69406 .49017 .69333 .4925 Mtetra
.979 .687 .385 r
.69333 .4925 .69406 .49017 .68593 .29535 .68511 .29487 Mtetra
.949 .876 .729 r
.68511 .29487 .68593 .29535 .6876 .29246 .68678 .29184 Mtetra
.722 .877 .954 r
.68678 .29184 .6876 .29246 .68938 .29177 .68856 .29096 Mtetra
.579 .782 .975 r
.68856 .29096 .68938 .29177 .6912 .2916 .69036 .2906 Mtetra
.658 .765 .929 r
.69036 .2906 .6912 .2916 .693 .29106 .69216 .29001 Mtetra
.728 .78 .894 r
.69216 .29001 .693 .29106 .69476 .28998 .69393 .28908 Mtetra
.613 .773 .957 r
.69393 .28908 .69476 .28998 .69656 .2894 .69574 .28864 Mtetra
0 .2 .673 r
.69574 .28864 .69656 .2894 .69846 .29069 .69764 .28998 Mtetra
.945 .583 .227 r
.69764 .28998 .69846 .29069 .70097 .30257 .70008 .30072 Mtetra
.976 .675 .366 r
.70008 .30072 .70097 .30257 .71426 .50366 .71332 .50187 Mtetra
0 .105 .66 r
.71332 .50187 .71426 .50366 .71635 .50595 .71542 .50429 Mtetra
.578 .63 .867 r
.71542 .50429 .71635 .50595 .71829 .50551 .71738 .50407 Mtetra
.691 .713 .865 r
.71738 .50407 .71829 .50551 .72019 .50444 .7193 .50323 Mtetra
.658 .739 .91 r
.7193 .50323 .72019 .50444 .72212 .50373 .72123 .5026 Mtetra
.534 .702 .947 r
.72123 .5026 .72212 .50373 .72409 .50372 .72319 .50244 Mtetra
.673 .734 .896 r
.72319 .50244 .72409 .50372 .72603 .50318 .72512 .50174 Mtetra
.859 .761 .754 r
.72512 .50174 .72603 .50318 .72786 .5008 .72694 .49916 Mtetra
.965 .726 .525 r
.72694 .49916 .72786 .5008 .72923 .4911 .72821 .48781 Mtetra
.976 .679 .384 r
.72821 .48781 .72923 .4911 .71842 .28578 .71757 .28441 Mtetra
.904 .762 .695 r
.71757 .28441 .71842 .28578 .72004 .28209 .7192 .28093 Mtetra
.72 .757 .882 r
.7192 .28093 .72004 .28209 .72183 .28116 .721 .28002 Mtetra
.599 .713 .924 r
.721 .28002 .72183 .28116 .72366 .28082 .72283 .27967 Mtetra
.635 .728 .915 r
.72283 .27967 .72366 .28082 .72548 .28033 .72465 .27918 Mtetra
.74 .766 .874 r
.72465 .27918 .72548 .28033 .72727 .27929 .72644 .27814 Mtetra
.653 .735 .91 r
.72644 .27814 .72727 .27929 .72909 .27872 .72826 .27758 Mtetra
.115 .433 .874 r
.72826 .27758 .72909 .27872 .73101 .27966 .73018 .27851 Mtetra
.906 .523 .091 r
.73018 .27851 .73101 .27966 .7334 .28754 .73257 .28638 Mtetra
.975 .671 .352 r
.73257 .28638 .7334 .28754 .74908 .49176 .7482 .49067 Mtetra
.598 .136 0 r
.7482 .49067 .74908 .49176 .75127 .4947 .7504 .49361 Mtetra
.554 .722 .952 r
.7504 .49361 .75127 .4947 .75325 .49446 .75238 .49337 Mtetra
.713 .786 .909 r
.75238 .49337 .75325 .49446 .75518 .49355 .75431 .49246 Mtetra
.696 .78 .916 r
.75431 .49246 .75518 .49355 .75712 .49273 .75625 .49164 Mtetra
.511 .701 .955 r
.75625 .49164 .75712 .49273 .75912 .49263 .75825 .49154 Mtetra
.654 .765 .931 r
.75825 .49154 .75912 .49263 .76108 .49201 .76021 .49091 Mtetra
.868 .816 .796 r
.76021 .49091 .76108 .49201 .76292 .48976 .76205 .48867 Mtetra
.98 .749 .517 r
.76205 .48867 .76292 .48976 .76418 .47954 .76332 .47843 Mtetra
.977 .678 .362 r
.76332 .47843 .76418 .47954 .75122 .27471 .7504 .27356 Mtetra
.932 .788 .679 r
.7504 .27356 .75122 .27471 .75281 .27088 .75199 .26973 Mtetra
.726 .764 .883 r
.75199 .26973 .75281 .27088 .75462 .26993 .7538 .26878 Mtetra
.601 .714 .924 r
.7538 .26878 .75462 .26993 .75647 .26957 .75566 .26842 Mtetra
.6 .714 .924 r
.75566 .26842 .75647 .26957 .75833 .26922 .75751 .26806 Mtetra
.739 .769 .877 r
.75751 .26806 .75833 .26922 .76013 .26819 .75932 .26703 Mtetra
.656 .738 .91 r
.75932 .26703 .76013 .26819 .76197 .2676 .76116 .26644 Mtetra
.232 .509 .907 r
.76116 .26644 .76197 .2676 .76391 .26829 .7631 .26714 Mtetra
.883 .491 .037 r
.7631 .26714 .76391 .26829 .76637 .27556 .76555 .27441 Mtetra
.975 .667 .334 r
.76555 .27441 .76637 .27556 .7844 .48102 .78355 .47992 Mtetra
.656 .202 0 r
.78355 .47992 .7844 .48102 .7867 .48448 .78584 .48338 Mtetra
.381 .631 .952 r
.78584 .48338 .7867 .48448 .78875 .48475 .78789 .48365 Mtetra
.693 .781 .919 r
.78789 .48365 .78875 .48475 .79071 .48393 .78986 .48284 Mtetra
.874 .82 .793 r
.78986 .48284 .79071 .48393 .79256 .48163 .7917 .48053 Mtetra
.978 .767 .551 r
.7917 .48053 .79256 .48163 .79395 .47376 .7931 .47267 Mtetra
.977 .675 .347 r
.7931 .47267 .79395 .47376 .77891 .26628 .7781 .26514 Mtetra
.951 .786 .642 r
.7781 .26514 .77891 .26628 .78044 .26171 .77963 .26056 Mtetra
.745 .773 .875 r
.77963 .26056 .78044 .26171 .78225 .26064 .78144 .25949 Mtetra
.617 .722 .921 r
.78144 .25949 .78225 .26064 .78412 .26022 .78331 .25906 Mtetra
.584 .707 .927 r
.78331 .25906 .78412 .26022 .786 .25992 .78519 .25876 Mtetra
.747 .773 .874 r
.78519 .25876 .786 .25992 .78781 .25884 .78701 .25768 Mtetra
.67 .744 .906 r
.78701 .25768 .78781 .25884 .78967 .25818 .78886 .25702 Mtetra
.353 .581 .928 r
.78886 .25702 .78967 .25818 .79161 .2586 .79081 .25743 Mtetra
.835 .429 0 r
.79081 .25743 .79161 .2586 .79405 .26467 .79325 .26351 Mtetra
.973 .663 .318 r
.79325 .26351 .79405 .26467 .81412 .47136 .81328 .47025 Mtetra
.693 .248 0 r
.81328 .47025 .81412 .47136 .81652 .4753 .81568 .47421 Mtetra
.355 .618 .95 r
.81568 .47421 .81652 .4753 .81859 .47551 .81776 .47455 Mtetra
.68 .808 .944 r
.81776 .47455 .81859 .47551 .82058 .47473 .81975 .47378 Mtetra
.871 .851 .821 r
.81975 .47378 .82058 .47473 .82248 .47298 .82162 .47168 Mtetra
.97 .766 .572 r
.82162 .47168 .82248 .47298 .8242 .46928 .82304 .4647 Mtetra
.975 .67 .342 r
.82304 .4647 .8242 .46928 .82534 .45932 .80609 .2565 Mtetra
.552 .332 .534 r
.80609 .2565 .82534 .45932 .8088 .25759 .80754 .25131 Mtetra
.614 .445 .63 r
.80754 .25131 .8088 .25759 .8104 .25403 .80936 .25012 Mtetra
.598 .479 .689 r
.80936 .25012 .8104 .25403 .81214 .25196 .81124 .24961 Mtetra
.579 .546 .781 r
.81124 .24961 .81214 .25196 .81394 .25059 .81315 .24942 Mtetra
.656 .738 .91 r
.81315 .24942 .81394 .25059 .8158 .2498 .81503 .24881 Mtetra
.652 .778 .941 r
.81503 .24881 .8158 .2498 .81768 .24924 .8169 .24821 Mtetra
.666 .776 .931 r
.8169 .24821 .81768 .24924 .81957 .24873 .81878 .24756 Mtetra
.758 .779 .871 r
.81878 .24756 .81957 .24873 .82139 .24757 .8206 .24641 Mtetra
.689 .754 .901 r
.8206 .24641 .82139 .24757 .82326 .24681 .82247 .24564 Mtetra
.47 .648 .936 r
.82247 .24564 .82326 .24681 .8252 .24691 .82442 .24573 Mtetra
.769 .353 0 r
.82442 .24573 .8252 .24691 .82766 .25211 .82687 .25092 Mtetra
.971 .657 .298 r
.82687 .25092 .82766 .25211 .85018 .45975 .84936 .4586 Mtetra
.721 .288 0 r
.84936 .4586 .85018 .45975 .85272 .46435 .8519 .46321 Mtetra
.311 .58 .937 r
.8519 .46321 .85272 .46435 .85486 .46484 .85403 .46371 Mtetra
.65 .762 .931 r
.85403 .46371 .85486 .46484 .85688 .46421 .85606 .46308 Mtetra
.829 .82 .84 r
.85606 .46308 .85688 .46421 .85879 .46243 .85797 .4613 Mtetra
.975 .789 .588 r
.85797 .4613 .85879 .46243 .86026 .45635 .85944 .45523 Mtetra
.974 .667 .312 r
.85944 .45523 .86026 .45635 .84084 .24731 .84006 .24616 Mtetra
.976 .777 .572 r
.84006 .24616 .84084 .24731 .84216 .24111 .84138 .23995 Mtetra
.76 .76 .853 r
.23263 .44566 .23366 .4466 .23522 .44554 .2342 .44461 Mtetra
.606 .73 .933 r
.2342 .44461 .23522 .44554 .23672 .44522 .2357 .4443 Mtetra
.429 .664 .96 r
.2357 .4443 .23672 .44522 .23819 .44529 .23716 .44438 Mtetra
.631 .743 .928 r
.23716 .44438 .23819 .44529 .2397 .44488 .23867 .44398 Mtetra
.639 .749 .928 r
.23867 .44398 .2397 .44488 .24121 .44443 .24018 .44356 Mtetra
.648 .756 .928 r
.24018 .44356 .24121 .44443 .24273 .44395 .2417 .44309 Mtetra
.669 .765 .922 r
.2417 .44309 .24273 .44395 .24426 .4434 .24323 .44255 Mtetra
.679 .769 .919 r
.24323 .44255 .24426 .4434 .24578 .44281 .24475 .44197 Mtetra
.686 .771 .916 r
.24475 .44197 .24578 .44281 .24732 .44221 .24629 .44136 Mtetra
.684 .771 .917 r
.24629 .44136 .24732 .44221 .24885 .44158 .24782 .44076 Mtetra
.689 .778 .919 r
.24782 .44076 .24885 .44158 .25038 .44095 .24935 .44014 Mtetra
.697 .78 .915 r
.24935 .44014 .25038 .44095 .25192 .44036 .25089 .43948 Mtetra
.714 .77 .897 r
.25089 .43948 .25192 .44036 .25344 .43985 .25244 .43874 Mtetra
.706 .723 .863 r
.25244 .43874 .25344 .43985 .25497 .43937 .25398 .43799 Mtetra
.69 .677 .833 r
.25398 .43799 .25497 .43937 .25649 .43888 .25553 .43727 Mtetra
.665 .638 .813 r
.25553 .43727 .25649 .43888 .25803 .43832 .25707 .43666 Mtetra
.656 .628 .81 r
.25707 .43666 .25803 .43832 .25956 .43774 .2586 .43609 Mtetra
.653 .628 .813 r
.2586 .43609 .25956 .43774 .2611 .43715 .26014 .43554 Mtetra
.654 .633 .817 r
.26014 .43554 .2611 .43715 .26263 .4366 .26167 .43499 Mtetra
.653 .634 .818 r
.26167 .43499 .26263 .4366 .26417 .43605 .26321 .43445 Mtetra
.653 .634 .819 r
.26321 .43445 .26417 .43605 .2657 .43551 .26474 .43391 Mtetra
.654 .635 .819 r
.26474 .43391 .2657 .43551 .26724 .43496 .26628 .43337 Mtetra
.653 .636 .82 r
.26628 .43337 .26724 .43496 .26878 .43441 .26782 .43283 Mtetra
.652 .636 .821 r
.26782 .43283 .26878 .43441 .27032 .43388 .26935 .4323 Mtetra
.69 .651 .806 r
.26935 .4323 .27032 .43388 .27188 .43297 .27091 .43151 Mtetra
.671 .659 .83 r
.27091 .43151 .27188 .43297 .27343 .43231 .27246 .43089 Mtetra
.584 .63 .863 r
.27246 .43089 .27343 .43231 .27494 .43227 .27397 .43069 Mtetra
0 0 .561 r
.27397 .43069 .27494 .43227 .27618 .43566 .27534 .43244 Mtetra
.875 .572 .055 r
.27534 .43244 .27618 .43566 .2627 .63311 .2764 .43829 Mtetra
0 0 .205 r
.2764 .43829 .2627 .63311 .26382 .63942 .26318 .63273 Mtetra
.426 .304 .611 r
.26318 .63273 .26382 .63942 .26537 .6401 .26465 .63442 Mtetra
.588 .435 .641 r
.26465 .63442 .26537 .6401 .26701 .63962 .26629 .63391 Mtetra
.632 .466 .64 r
.26629 .63391 .26701 .63962 .26868 .6387 .26798 .63259 Mtetra
.62 .453 .634 r
.26798 .63259 .26868 .6387 .27033 .63807 .26967 .63143 Mtetra
.596 .43 .627 r
.26967 .63143 .27033 .63807 .27197 .63754 .27133 .63065 Mtetra
.555 .397 .622 r
.27133 .63065 .27197 .63754 .27362 .63702 .27294 .6306 Mtetra
.409 .296 .613 r
.27294 .6306 .27362 .63702 .27526 .63655 .27442 .63241 Mtetra
.342 .297 .663 r
.27442 .63241 .27526 .63655 .2769 .6361 .27591 .63399 Mtetra
.276 .386 .795 r
.27591 .63399 .2769 .6361 .27854 .63566 .27745 .63494 Mtetra
.447 .74 .99 r
.27745 .63494 .27854 .63566 .28019 .63519 .27907 .63488 Mtetra
.566 .88 .992 r
.27907 .63488 .28019 .63519 .28184 .6347 .28072 .63439 Mtetra
.63 .899 .986 r
.28072 .63439 .28184 .6347 .28348 .63419 .28237 .63377 Mtetra
.552 .853 .998 r
.28237 .63377 .28348 .63419 .28514 .63362 .28402 .63337 Mtetra
.448 .844 .978 r
.28402 .63337 .28514 .63362 .2868 .63304 .28566 .63304 Mtetra
.331 .812 .88 r
.28566 .63304 .2868 .63304 .28845 .63246 .2873 .63268 Mtetra
.321 .807 .795 r
.2873 .63268 .28845 .63246 .29011 .63197 .28896 .63215 Mtetra
.407 .86 .84 r
.28896 .63215 .29011 .63197 .29176 .63151 .29062 .63154 Mtetra
.51 .907 .922 r
.29062 .63154 .29176 .63151 .29341 .63106 .29229 .63092 Mtetra
.353 .813 .931 r
.29229 .63092 .29341 .63106 .29504 .63096 .29393 .63063 Mtetra
.481 .845 .991 r
.29393 .63063 .29504 .63096 .29668 .63071 .29558 .6303 Mtetra
.694 .89 .969 r
.29558 .6303 .29668 .63071 .29836 .62981 .29725 .62954 Mtetra
.906 .867 .79 r
.29725 .62954 .29836 .62981 .30025 .6259 .29904 .62712 Mtetra
.99 .88 .617 r
.29904 .62712 .30025 .6259 .31465 .42837 .30103 .62158 Mtetra
0 0 .208 r
.30103 .62158 .31465 .42837 .31677 .41922 .31536 .42465 Mtetra
0 0 .052 r
.31536 .42465 .31677 .41922 .31843 .41717 .31725 .41907 Mtetra
0 0 0 r
.31725 .41907 .31843 .41717 .32001 .41651 .31894 .41671 Mtetra
.835 .989 .863 r
.31894 .41671 .32001 .41651 .32155 .41629 .32056 .41521 Mtetra
.73 .739 .859 r
.32056 .41521 .32155 .41629 .32311 .41592 .32216 .41431 Mtetra
.652 .637 .822 r
.32216 .41431 .32311 .41592 .32468 .41541 .32373 .41377 Mtetra
.62 .617 .827 r
.32373 .41377 .32468 .41541 .32624 .41491 .32529 .4134 Mtetra
.623 .636 .843 r
.32529 .4134 .32624 .41491 .32782 .41436 .32685 .41303 Mtetra
.632 .668 .866 r
.32685 .41303 .32782 .41436 .32939 .41377 .32841 .41262 Mtetra
.64 .702 .891 r
.32841 .41262 .32939 .41377 .33097 .4132 .32998 .41218 Mtetra
.721 .749 .874 r
.32998 .41218 .33097 .4132 .33256 .41239 .33157 .41135 Mtetra
.729 .748 .867 r
.33157 .41135 .33256 .41239 .33414 .41167 .33316 .41048 Mtetra
.652 .698 .88 r
.33316 .41048 .33414 .41167 .33569 .41149 .33474 .40998 Mtetra
.14 .377 .831 r
.33474 .40998 .33569 .41149 .33711 .41373 .33623 .4109 Mtetra
0 0 .337 r
.33623 .4109 .33711 .41373 .32744 .60863 .33757 .41453 Mtetra
0 0 .241 r
.33757 .41453 .32744 .60863 .3285 .61894 .32789 .61008 Mtetra
.104 .048 .503 r
.32789 .61008 .3285 .61894 .33006 .62041 .3292 .616 Mtetra
.355 .3 .657 r
.3292 .616 .33006 .62041 .33173 .62009 .33076 .61764 Mtetra
.426 .445 .777 r
.33076 .61764 .33173 .62009 .33343 .61926 .33238 .61826 Mtetra
.534 .71 .953 r
.33238 .61826 .33343 .61926 .33512 .61856 .33404 .61812 Mtetra
.642 .876 .984 r
.33404 .61812 .33512 .61856 .3368 .61807 .33573 .61751 Mtetra
.708 .86 .955 r
.33573 .61751 .3368 .61807 .33849 .61755 .33743 .61672 Mtetra
.583 .769 .968 r
.33743 .61672 .33849 .61755 .34016 .61729 .3391 .6164 Mtetra
.509 .725 .97 r
.3391 .6164 .34016 .61729 .34183 .61701 .34077 .61628 Mtetra
.643 .809 .963 r
.34077 .61628 .34183 .61701 .34354 .61614 .34246 .61575 Mtetra
.881 .872 .824 r
.34246 .61575 .34354 .61614 .34537 .61282 .34422 .61374 Mtetra
.986 .888 .634 r
.34422 .61374 .34537 .61282 .35711 .41811 .34614 .6088 Mtetra
0 0 .229 r
.34614 .6088 .35711 .41811 .35934 .40523 .35797 .41193 Mtetra
0 0 .1 r
.35797 .41193 .35934 .40523 .36103 .40272 .35989 .40491 Mtetra
0 0 0 r
.35989 .40491 .36103 .40272 .36263 .402 .36159 .4024 Mtetra
.794 .999 .815 r
.36159 .4024 .36263 .402 .36421 .40176 .36323 .40085 Mtetra
.734 .775 .886 r
.36323 .40085 .36421 .40176 .36579 .40148 .36484 .39997 Mtetra
.63 .641 .843 r
.36484 .39997 .36579 .40148 .36738 .40101 .36643 .39955 Mtetra
.589 .632 .862 r
.36643 .39955 .36738 .40101 .36897 .40054 .36801 .39933 Mtetra
.607 .682 .895 r
.36801 .39933 .36897 .40054 .37057 .40002 .36959 .39902 Mtetra
.651 .738 .913 r
.36959 .39902 .37057 .40002 .37217 .39946 .37119 .39852 Mtetra
.666 .757 .918 r
.37119 .39852 .37217 .39946 .37377 .3989 .37279 .39797 Mtetra
.686 .763 .91 r
.37279 .39797 .37377 .3989 .37536 .39839 .37439 .39733 Mtetra
.697 .739 .884 r
.37439 .39733 .37536 .39839 .37696 .39793 .376 .39662 Mtetra
.688 .693 .85 r
.376 .39662 .37696 .39793 .37856 .39748 .37761 .39591 Mtetra
.67 .652 .823 r
.37761 .39591 .37856 .39748 .38016 .39699 .37922 .39526 Mtetra
.653 .626 .81 r
.37922 .39526 .38016 .39699 .38176 .39645 .38082 .39468 Mtetra
.645 .618 .808 r
.38082 .39468 .38176 .39645 .38336 .39587 .38243 .39415 Mtetra
.634 .617 .816 r
.38243 .39415 .38336 .39587 .38497 .39526 .38403 .39368 Mtetra
.626 .632 .837 r
.38403 .39368 .38497 .39526 .38658 .39461 .38563 .39328 Mtetra
.627 .67 .871 r
.38563 .39328 .38658 .39461 .38819 .39397 .38723 .39289 Mtetra
.638 .719 .907 r
.38723 .39289 .38819 .39397 .3898 .39337 .38883 .39244 Mtetra
.656 .757 .924 r
.38883 .39244 .3898 .39337 .39141 .39284 .39044 .39193 Mtetra
.669 .763 .921 r
.39044 .39193 .39141 .39284 .39302 .39233 .39205 .39136 Mtetra
.685 .755 .905 r
.39205 .39136 .39302 .39233 .39463 .39181 .39367 .39071 Mtetra
.695 .734 .881 r
.39367 .39071 .39463 .39181 .39624 .39127 .39528 .39001 Mtetra
.69 .704 .858 r
.39528 .39001 .39624 .39127 .39785 .39072 .3969 .3893 Mtetra
.688 .679 .836 r
.3969 .3893 .39785 .39072 .39947 .39015 .39852 .38856 Mtetra
.678 .654 .819 r
.39852 .38856 .39947 .39015 .40108 .38956 .40015 .38785 Mtetra
.645 .624 .815 r
.40015 .38785 .40108 .38956 .4027 .38897 .40176 .38732 Mtetra
.537 .582 .847 r
.40176 .38732 .4027 .38897 .40432 .3884 .40336 .38732 Mtetra
.02 .393 .85 r
.40336 .38732 .40432 .3884 .40593 .38785 .40492 .38816 Mtetra
.715 .224 .075 r
.40492 .38816 .40593 .38785 .40755 .38731 .40647 .38958 Mtetra
.606 .241 .323 r
.40647 .38958 .40755 .38731 .40918 .38656 .40804 .39048 Mtetra
.397 .093 .328 r
.40804 .39048 .40918 .38656 .41081 .38563 .40968 .38947 Mtetra
.445 .134 .343 r
.40968 .38947 .41081 .38563 .41243 .38517 .4113 .38885 Mtetra
.7 .379 .429 r
.4113 .38885 .41243 .38517 .414 .38625 .41281 .39163 Mtetra
.948 .676 .488 r
.41281 .39163 .414 .38625 .41531 .39486 .40764 .58892 Mtetra
.551 .327 .529 r
.40764 .58892 .41531 .39486 .41027 .59283 .40918 .59384 Mtetra
.691 .254 .209 r
.40918 .59384 .41027 .59283 .41189 .5956 .41085 .5953 Mtetra
.418 .826 .976 r
.41085 .5953 .41189 .5956 .41361 .59553 .41257 .59501 Mtetra
.678 .873 .972 r
.41257 .59501 .41361 .59553 .41535 .59485 .41431 .5943 Mtetra
.679 .865 .97 r
.41431 .5943 .41535 .59485 .41709 .59406 .41605 .59359 Mtetra
.531 .841 .999 r
.41605 .59359 .41709 .59406 .41883 .59356 .41778 .59322 Mtetra
.584 .887 .991 r
.41778 .59322 .41883 .59356 .42056 .59303 .41952 .59266 Mtetra
.727 .916 .958 r
.41952 .59266 .42056 .59303 .42229 .59264 .42127 .59173 Mtetra
.818 .802 .836 r
.42127 .59173 .42229 .59264 .42402 .59245 .42304 .59013 Mtetra
.787 .649 .71 r
.42304 .59013 .42402 .59245 .42577 .59178 .42484 .58762 Mtetra
.81 .607 .627 r
.42484 .58762 .42577 .59178 .42755 .58961 .42673 .58193 Mtetra
.95 .681 .493 r
.42673 .58193 .42755 .58961 .42953 .58056 .43409 .38278 Mtetra
.554 .334 .535 r
.43409 .38278 .42953 .58056 .43676 .38045 .43587 .37735 Mtetra
.744 .587 .681 r
.43587 .37735 .43676 .38045 .43849 .37665 .43756 .375 Mtetra
.686 .651 .81 r
.43756 .375 .43849 .37665 .44014 .37575 .4392 .3742 Mtetra
.618 .635 .845 r
.4392 .3742 .44014 .37575 .44177 .37544 .44083 .37383 Mtetra
.587 .613 .845 r
.44083 .37383 .44177 .37544 .4434 .37525 .44247 .37362 Mtetra
.619 .625 .835 r
.44247 .37362 .4434 .37525 .44504 .37464 .4441 .37324 Mtetra
.618 .658 .867 r
.4441 .37324 .44504 .37464 .44668 .37404 .44574 .37288 Mtetra
.626 .704 .901 r
.44574 .37288 .44668 .37404 .44833 .37345 .44738 .37248 Mtetra
.649 .749 .923 r
.44738 .37248 .44833 .37345 .44997 .37293 .44902 .37198 Mtetra
.664 .76 .922 r
.44902 .37198 .44997 .37293 .45161 .37241 .45067 .37142 Mtetra
.68 .755 .908 r
.45067 .37142 .45161 .37241 .45326 .37188 .45232 .37079 Mtetra
.694 .739 .885 r
.45232 .37079 .45326 .37188 .45491 .37133 .45397 .37007 Mtetra
.691 .709 .862 r
.45397 .37007 .45491 .37133 .45655 .37077 .45562 .36935 Mtetra
.686 .682 .841 r
.45562 .36935 .45655 .37077 .4582 .37019 .45727 .36862 Mtetra
.684 .661 .821 r
.45727 .36862 .4582 .37019 .45985 .36959 .45893 .36786 Mtetra
.652 .629 .814 r
.45893 .36786 .45985 .36959 .46151 .36899 .46058 .36728 Mtetra
.581 .598 .834 r
.46058 .36728 .46151 .36899 .46316 .3684 .46222 .36709 Mtetra
.202 .455 .877 r
.46222 .36709 .46316 .3684 .46481 .36787 .46385 .36784 Mtetra
.677 .135 0 r
.46385 .36784 .46481 .36787 .46646 .36733 .46547 .36918 Mtetra
.684 .302 .318 r
.46547 .36918 .46646 .36733 .46812 .36677 .46709 .37082 Mtetra
.498 .187 .37 r
.46709 .37082 .46812 .36677 .46978 .36615 .46874 .37065 Mtetra
.436 .141 .364 r
.46874 .37065 .46978 .36615 .47143 .36553 .47041 .36977 Mtetra
.39 .095 .34 r
.47041 .36977 .47143 .36553 .47309 .36484 .47208 .36857 Mtetra
.345 .043 .302 r
.47208 .36857 .47309 .36484 .47476 .36386 .47375 .36723 Mtetra
.435 .112 .318 r
.47375 .36723 .47476 .36386 .47642 .3633 .47542 .36664 Mtetra
.628 .295 .387 r
.47542 .36664 .47642 .3633 .47807 .36373 .47705 .36801 Mtetra
.956 .677 .468 r
.47705 .36801 .47807 .36373 .47964 .36933 .47584 .56586 Mtetra
.554 .329 .529 r
.47584 .56586 .47964 .36933 .47855 .57086 .47751 .57249 Mtetra
.723 .329 .303 r
.47751 .57249 .47855 .57086 .48026 .57489 .47925 .57461 Mtetra
.305 .771 .942 r
.47925 .57461 .48026 .57489 .48203 .57493 .48102 .57445 Mtetra
.634 .879 .987 r
.48102 .57445 .48203 .57493 .48381 .57425 .4828 .57382 Mtetra
.683 .902 .974 r
.4828 .57382 .48381 .57425 .48559 .57328 .48459 .57303 Mtetra
.446 .852 .968 r
.48459 .57303 .48559 .57328 .48737 .57275 .48636 .57264 Mtetra
.371 .83 .916 r
.48636 .57264 .48737 .57275 .48915 .57221 .48814 .57225 Mtetra
.296 .793 .838 r
.48814 .57225 .48915 .57221 .49093 .57167 .48993 .57184 Mtetra
.275 .778 .776 r
.48993 .57184 .49093 .57167 .49271 .57115 .49171 .57133 Mtetra
.275 .777 .763 r
.49171 .57133 .49271 .57115 .4945 .57062 .49349 .57081 Mtetra
.285 .783 .768 r
.49349 .57081 .4945 .57062 .49628 .5701 .49528 .57027 Mtetra
.273 .776 .769 r
.49528 .57027 .49628 .5701 .49807 .56958 .49707 .56976 Mtetra
.283 .782 .771 r
.49707 .56976 .49807 .56958 .49985 .56905 .49886 .56923 Mtetra
.303 .796 .782 r
.49886 .56923 .49985 .56905 .50164 .56855 .50065 .56867 Mtetra
.196 .725 .757 r
.50065 .56867 .50164 .56855 .50343 .56847 .50244 .56831 Mtetra
.548 .911 .96 r
.50244 .56831 .50343 .56847 .50522 .56798 .50423 .56767 Mtetra
.781 .94 .931 r
.50423 .56767 .50522 .56798 .50702 .56662 .50603 .56645 Mtetra
.96 .868 .702 r
.50603 .56645 .50702 .56662 .50884 .56029 .50784 .56273 Mtetra
.986 .832 .447 r
.50784 .56273 .50884 .56029 .51148 .35686 .50967 .55296 Mtetra
0 0 .33 r
.50967 .55296 .51148 .35686 .51319 .35138 .51225 .35532 Mtetra
.31 .021 .301 r
.51225 .35532 .51319 .35138 .51487 .3502 .51394 .35361 Mtetra
.461 .138 .33 r
.51394 .35361 .51487 .3502 .51656 .34971 .51562 .35321 Mtetra
.537 .209 .36 r
.51562 .35321 .51656 .34971 .51824 .34957 .51731 .3535 Mtetra
.508 .193 .368 r
.51731 .3535 .51824 .34957 .51993 .34904 .519 .35345 Mtetra
.482 .18 .376 r
.519 .35345 .51993 .34904 .52161 .34851 .52069 .35305 Mtetra
.408 .118 .357 r
.52069 .35305 .52161 .34851 .5233 .34797 .52238 .35187 Mtetra
.083 0 .212 r
.52238 .35187 .5233 .34797 .52499 .34736 .52408 .34886 Mtetra
0 0 0 r
.52408 .34886 .52499 .34736 .52668 .34674 .52577 .34646 Mtetra
.883 .927 .846 r
.52577 .34646 .52668 .34674 .52837 .34612 .52746 .34466 Mtetra
.697 .684 .834 r
.52746 .34466 .52837 .34612 .53007 .34554 .52915 .34384 Mtetra
.646 .632 .822 r
.52915 .34384 .53007 .34554 .53176 .34497 .53085 .34328 Mtetra
.621 .623 .831 r
.53085 .34328 .53176 .34497 .53346 .3444 .53254 .34288 Mtetra
.631 .651 .852 r
.53254 .34288 .53346 .3444 .53515 .34378 .53424 .34244 Mtetra
.633 .679 .876 r
.53424 .34244 .53515 .34378 .53685 .34316 .53594 .34199 Mtetra
.642 .713 .899 r
.53594 .34199 .53685 .34316 .53855 .34257 .53764 .34151 Mtetra
.743 .765 .871 r
.53764 .34151 .53855 .34257 .54024 .34164 .53933 .34051 Mtetra
.709 .743 .878 r
.53933 .34051 .54024 .34164 .54194 .34103 .54103 .33969 Mtetra
.612 .671 .882 r
.54103 .33969 .54194 .34103 .54365 .34108 .54274 .33934 Mtetra
0 .128 .677 r
.54274 .33934 .54365 .34108 .54538 .34517 .54445 .34127 Mtetra
0 0 .226 r
.54445 .34127 .54538 .34517 .54851 .54791 .54621 .34806 Mtetra
0 0 .36 r
.54621 .34806 .54851 .54791 .55037 .55339 .54937 .54669 Mtetra
.505 .368 .628 r
.54937 .54669 .55037 .55339 .5522 .55378 .5512 .54748 Mtetra
.597 .436 .635 r
.5512 .54748 .5522 .55378 .55403 .55318 .55301 .54669 Mtetra
.602 .438 .632 r
.55301 .54669 .55403 .55318 .55585 .55217 .55483 .54576 Mtetra
.43 .319 .627 r
.55483 .54576 .55585 .55217 .55767 .55163 .55668 .54755 Mtetra
.383 .337 .683 r
.55668 .54755 .55767 .55163 .5595 .55116 .55852 .54904 Mtetra
.346 .437 .811 r
.55852 .54904 .5595 .55116 .56133 .55066 .56037 .54991 Mtetra
.338 .687 .98 r
.56037 .54991 .56133 .55066 .56316 .55048 .5622 .55004 Mtetra
.52 .853 .996 r
.5622 .55004 .56316 .55048 .56499 .55 .56404 .54963 Mtetra
.739 .931 .952 r
.56404 .54963 .56499 .55 .56681 .54881 .56586 .54858 Mtetra
.944 .903 .753 r
.56586 .54858 .56681 .54881 .56859 .54379 .56767 .54566 Mtetra
.947 .862 .442 r
.56767 .54566 .56859 .54379 .56767 .33991 .56942 .53907 Mtetra
0 0 .354 r
.56942 .53907 .56767 .33991 .5693 .33288 .56848 .3375 Mtetra
0 0 .184 r
.56848 .3375 .5693 .33288 .571 .3312 .57014 .33281 Mtetra
0 0 0 r
.57014 .33281 .571 .3312 .57272 .33058 .57184 .33052 Mtetra
.826 .984 .878 r
.57184 .33052 .57272 .33058 .57445 .33036 .57355 .32903 Mtetra
.71 .712 .849 r
.57355 .32903 .57445 .33036 .57617 .32988 .57526 .32815 Mtetra
.647 .631 .82 r
.57526 .32815 .57617 .32988 .57789 .32933 .57699 .32758 Mtetra
.619 .616 .826 r
.57699 .32758 .57789 .32933 .57962 .32877 .57871 .32718 Mtetra
.628 .64 .844 r
.57871 .32718 .57962 .32877 .58134 .32815 .58044 .32674 Mtetra
.634 .671 .867 r
.58044 .32674 .58134 .32815 .58306 .32751 .58217 .32628 Mtetra
.644 .705 .891 r
.58217 .32628 .58306 .32751 .58479 .32689 .5839 .32577 Mtetra
.733 .758 .872 r
.5839 .32577 .58479 .32689 .58651 .32597 .58562 .32481 Mtetra
.721 .747 .873 r
.58562 .32481 .58651 .32597 .58824 .32525 .58734 .32392 Mtetra
.635 .684 .879 r
.58734 .32392 .58824 .32525 .58998 .32514 .58907 .32345 Mtetra
.129 .341 .805 r
.58907 .32345 .58998 .32514 .59178 .32814 .59084 .32471 Mtetra
0 0 .476 r
.59084 .32471 .59178 .32814 .59794 .53041 .59269 .32917 Mtetra
0 0 .378 r
.59269 .32917 .59794 .53041 .59996 .53778 .59887 .53002 Mtetra
.258 .184 .58 r
.59887 .53002 .59996 .53778 .60185 .53873 .60083 .53451 Mtetra
.4 .346 .681 r
.60083 .53451 .60185 .53873 .60371 .53828 .60273 .53595 Mtetra
.457 .483 .798 r
.60273 .53595 .60371 .53828 .60556 .53736 .60462 .53645 Mtetra
.456 .709 .976 r
.60462 .53645 .60556 .53736 .60742 .53707 .60649 .53643 Mtetra
.603 .84 .989 r
.60649 .53643 .60742 .53707 .60929 .53674 .60835 .53592 Mtetra
.764 .838 .908 r
.60835 .53592 .60929 .53674 .61114 .53575 .6102 .53478 Mtetra
.895 .81 .757 r
.6102 .53478 .61114 .53575 .61291 .53159 .612 .53203 Mtetra
.997 .852 .566 r
.612 .53203 .61291 .53159 .60933 .32827 .61372 .52581 Mtetra
0 0 .369 r
.61372 .52581 .60933 .32827 .61085 .31913 .61013 .32419 Mtetra
0 0 .211 r
.61013 .32419 .61085 .31913 .61255 .31704 .61175 .31894 Mtetra
0 0 0 r
.61175 .31894 .61255 .31704 .61429 .31636 .61345 .31655 Mtetra
.771 .997 .819 r
.61345 .31655 .61429 .31636 .61605 .31615 .61517 .315 Mtetra
.711 .748 .881 r
.61517 .315 .61605 .31615 .6178 .31576 .61691 .31416 Mtetra
.627 .642 .846 r
.61691 .31416 .6178 .31576 .61955 .31523 .61866 .31372 Mtetra
.594 .641 .866 r
.61866 .31372 .61955 .31523 .6213 .31468 .62042 .31345 Mtetra
.631 .702 .897 r
.62042 .31345 .6213 .31468 .62305 .31407 .62218 .313 Mtetra
.666 .749 .912 r
.62218 .313 .62305 .31407 .6248 .31341 .62393 .31239 Mtetra
.68 .764 .915 r
.62393 .31239 .6248 .31341 .62655 .31275 .62568 .31172 Mtetra
.76 .784 .873 r
.62568 .31172 .62655 .31275 .6283 .31183 .62742 .31061 Mtetra
.741 .744 .854 r
.62742 .31061 .6283 .31183 .63004 .31102 .62916 .30955 Mtetra
.631 .663 .863 r
.62916 .30955 .63004 .31102 .63181 .31078 .63092 .3091 Mtetra
0 .091 .649 r
.63092 .3091 .63181 .31078 .63367 .31312 .63277 .31127 Mtetra
.974 .68 .398 r
.63277 .31127 .63367 .31312 .64254 .51433 .6416 .51267 Mtetra
.943 .589 .191 r
.6416 .51267 .64254 .51433 .64478 .52391 .64388 .52331 Mtetra
.416 0 0 r
.64388 .52331 .64478 .52391 .64674 .52531 .64583 .52466 Mtetra
.613 .844 .987 r
.64583 .52466 .64674 .52531 .64863 .52492 .64772 .52411 Mtetra
.755 .844 .918 r
.64772 .52411 .64863 .52492 .65051 .524 .64959 .52302 Mtetra
.599 .759 .955 r
.64959 .52302 .65051 .524 .6524 .52351 .65148 .52261 Mtetra
.481 .728 .979 r
.65148 .52261 .6524 .52351 .6543 .52317 .65339 .52252 Mtetra
.662 .86 .975 r
.65339 .52252 .6543 .52317 .65617 .52223 .65528 .52181 Mtetra
.954 .878 .722 r
.65528 .52181 .65617 .52223 .65795 .51873 .65706 .51846 Mtetra
.976 .687 .407 r
.65706 .51846 .65795 .51873 .65181 .31934 .65103 .32039 Mtetra
.995 .756 .436 r
.65103 .32039 .65181 .31934 .65304 .30541 .65216 .30387 Mtetra
.847 .731 .736 r
.65216 .30387 .65304 .30541 .65473 .30286 .65385 .30134 Mtetra
.657 .668 .849 r
.65385 .30134 .65473 .30286 .6565 .30212 .65562 .30073 Mtetra
.541 .634 .892 r
.65562 .30073 .6565 .30212 .65828 .30188 .65742 .30066 Mtetra
.579 .685 .913 r
.65742 .30066 .65828 .30188 .66007 .30149 .65921 .30041 Mtetra
.663 .748 .914 r
.65921 .30041 .66007 .30149 .66184 .30083 .66098 .2998 Mtetra
.676 .765 .918 r
.66098 .2998 .66184 .30083 .66361 .30018 .66276 .29914 Mtetra
.75 .785 .881 r
.66276 .29914 .66361 .30018 .66538 .29931 .66452 .29809 Mtetra
.75 .753 .854 r
.66452 .29809 .66538 .29931 .66714 .29844 .66627 .29698 Mtetra
.648 .674 .861 r
.66627 .29698 .66714 .29844 .66894 .2981 .66805 .29642 Mtetra
0 .254 .76 r
.66805 .29642 .66894 .2981 .67083 .29994 .66994 .29808 Mtetra
.975 .677 .38 r
.66994 .29808 .67083 .29994 .682 .49775 .68094 .49331 Mtetra
.907 .603 .111 r
.68094 .49331 .682 .49775 .68458 .51143 .6837 .51078 Mtetra
.59 .057 0 r
.6837 .51078 .68458 .51143 .68662 .51352 .68573 .5128 Mtetra
.517 .789 .995 r
.68573 .5128 .68662 .51352 .68856 .51348 .68766 .51253 Mtetra
.769 .823 .894 r
.68766 .51253 .68856 .51348 .69045 .51237 .68955 .51132 Mtetra
.88 .812 .777 r
.68955 .51132 .69045 .51237 .69223 .5091 .69137 .50885 Mtetra
.986 .849 .621 r
.69137 .50885 .69223 .5091 .69333 .4925 .69306 .50378 Mtetra
.982 .694 .362 r
.69306 .50378 .69333 .4925 .68511 .29487 .68469 .30204 Mtetra
0 0 .282 r
.68469 .30204 .68511 .29487 .68678 .29184 .68612 .2944 Mtetra
0 0 .106 r
.68612 .2944 .68678 .29184 .68856 .29096 .68781 .29179 Mtetra
0 0 0 r
.68781 .29179 .68856 .29096 .69036 .2906 .68955 .29013 Mtetra
.796 .925 .922 r
.68955 .29013 .69036 .2906 .69216 .29001 .69131 .28889 Mtetra
.723 .763 .884 r
.69131 .28889 .69216 .29001 .69393 .28908 .69309 .28797 Mtetra
.617 .726 .924 r
.69309 .28797 .69393 .28908 .69574 .28864 .6949 .28755 Mtetra
.207 .508 .91 r
.6949 .28755 .69574 .28864 .69764 .28998 .69676 .28823 Mtetra
0 0 .503 r
.69676 .28823 .69764 .28998 .70008 .30072 .69877 .29133 Mtetra
.979 .681 .342 r
.69877 .29133 .70008 .30072 .71332 .50187 .71183 .49024 Mtetra
.18 .11 .535 r
.71183 .49024 .71332 .50187 .71542 .50429 .71428 .49887 Mtetra
.413 .328 .651 r
.71428 .49887 .71542 .50429 .71738 .50407 .71635 .50068 Mtetra
.474 .428 .726 r
.71635 .50068 .71738 .50407 .7193 .50323 .71836 .50135 Mtetra
.485 .551 .848 r
.71836 .50135 .7193 .50323 .72123 .5026 .72034 .5016 Mtetra
.487 .709 .968 r
.72034 .5016 .72123 .5026 .72319 .50244 .72231 .50154 Mtetra
.691 .815 .942 r
.72231 .50154 .72319 .50244 .72512 .50174 .72424 .50074 Mtetra
.899 .825 .765 r
.72424 .50074 .72512 .50174 .72694 .49916 .72605 .49806 Mtetra
.978 .742 .511 r
.72605 .49806 .72694 .49916 .72821 .48781 .72732 .48661 Mtetra
.977 .681 .379 r
.72732 .48661 .72821 .48781 .71757 .28441 .71673 .28324 Mtetra
.918 .785 .698 r
.71673 .28324 .71757 .28441 .7192 .28093 .71837 .27977 Mtetra
.72 .758 .883 r
.71837 .27977 .7192 .28093 .721 .28002 .72016 .27886 Mtetra
.599 .711 .923 r
.72016 .27886 .721 .28002 .72283 .27967 .72199 .27852 Mtetra
.635 .727 .915 r
.72199 .27852 .72283 .27967 .72465 .27918 .72382 .27803 Mtetra
.74 .767 .874 r
.72382 .27803 .72465 .27918 .72644 .27814 .72561 .277 Mtetra
.652 .736 .911 r
.72561 .277 .72644 .27814 .72826 .27758 .72743 .27643 Mtetra
.115 .433 .873 r
.72743 .27643 .72826 .27758 .73018 .27851 .72935 .27737 Mtetra
.906 .523 .091 r
.72935 .27737 .73018 .27851 .73257 .28638 .73173 .28522 Mtetra
.975 .671 .352 r
.73173 .28522 .73257 .28638 .7482 .49067 .74733 .48958 Mtetra
.599 .137 0 r
.74733 .48958 .7482 .49067 .7504 .49361 .74952 .49252 Mtetra
.554 .722 .952 r
.74952 .49252 .7504 .49361 .75238 .49337 .7515 .49228 Mtetra
.713 .786 .909 r
.7515 .49228 .75238 .49337 .75431 .49246 .75344 .49137 Mtetra
.696 .78 .916 r
.75344 .49137 .75431 .49246 .75625 .49164 .75538 .49055 Mtetra
.511 .701 .956 r
.75538 .49055 .75625 .49164 .75825 .49154 .75737 .49045 Mtetra
.654 .765 .931 r
.75737 .49045 .75825 .49154 .76021 .49091 .75933 .48982 Mtetra
.868 .817 .796 r
.75933 .48982 .76021 .49091 .76205 .48867 .76118 .48757 Mtetra
.98 .749 .517 r
.76118 .48757 .76205 .48867 .76332 .47843 .76245 .47732 Mtetra
.977 .678 .362 r
.76245 .47732 .76332 .47843 .7504 .27356 .74958 .2724 Mtetra
.932 .789 .679 r
.74958 .2724 .7504 .27356 .75199 .26973 .75118 .26858 Mtetra
.726 .765 .883 r
.75118 .26858 .75199 .26973 .7538 .26878 .75298 .26763 Mtetra
.601 .715 .924 r
.75298 .26763 .7538 .26878 .75566 .26842 .75484 .26727 Mtetra
.6 .714 .924 r
.75484 .26727 .75566 .26842 .75751 .26806 .7567 .26691 Mtetra
.739 .769 .877 r
.7567 .26691 .75751 .26806 .75932 .26703 .7585 .26588 Mtetra
.656 .738 .911 r
.7585 .26588 .75932 .26703 .76116 .26644 .76034 .26529 Mtetra
.232 .509 .907 r
.76034 .26529 .76116 .26644 .7631 .26714 .76228 .26599 Mtetra
.884 .492 .037 r
.76228 .26599 .7631 .26714 .76555 .27441 .76474 .27327 Mtetra
.975 .667 .334 r
.76474 .27327 .76555 .27441 .78355 .47992 .78269 .47883 Mtetra
.655 .201 0 r
.78269 .47883 .78355 .47992 .78584 .48338 .78498 .48228 Mtetra
.381 .631 .952 r
.78498 .48228 .78584 .48338 .78789 .48365 .78703 .48255 Mtetra
.693 .781 .919 r
.78703 .48255 .78789 .48365 .78986 .48284 .789 .48174 Mtetra
.873 .82 .793 r
.789 .48174 .78986 .48284 .7917 .48053 .79085 .47943 Mtetra
.978 .767 .551 r
.79085 .47943 .7917 .48053 .7931 .47267 .79224 .47159 Mtetra
.977 .675 .347 r
.79224 .47159 .7931 .47267 .7781 .26514 .7773 .26399 Mtetra
.951 .786 .642 r
.7773 .26399 .7781 .26514 .77963 .26056 .77882 .2594 Mtetra
.745 .773 .875 r
.77882 .2594 .77963 .26056 .78144 .25949 .78064 .25833 Mtetra
.617 .722 .921 r
.78064 .25833 .78144 .25949 .78331 .25906 .78251 .2579 Mtetra
.584 .707 .927 r
.78251 .2579 .78331 .25906 .78519 .25876 .78439 .2576 Mtetra
.747 .773 .874 r
.78439 .2576 .78519 .25876 .78701 .25768 .78621 .25652 Mtetra
.67 .744 .906 r
.78621 .25652 .78701 .25768 .78886 .25702 .78806 .25585 Mtetra
.352 .581 .928 r
.78806 .25585 .78886 .25702 .79081 .25743 .79001 .25627 Mtetra
.836 .43 0 r
.79001 .25627 .79081 .25743 .79325 .26351 .79245 .26236 Mtetra
.973 .663 .318 r
.79245 .26236 .79325 .26351 .81328 .47025 .81243 .46915 Mtetra
.697 .25 0 r
.81243 .46915 .81328 .47025 .81568 .47421 .81483 .47311 Mtetra
.344 .61 .948 r
.81483 .47311 .81568 .47421 .81776 .47455 .81692 .47348 Mtetra
.679 .786 .93 r
.81692 .47348 .81776 .47455 .81975 .47378 .81891 .47273 Mtetra
.869 .832 .809 r
.81891 .47273 .81975 .47378 .82162 .47168 .82078 .47056 Mtetra
.981 .766 .541 r
.82078 .47056 .82162 .47168 .82304 .4647 .82211 .46249 Mtetra
.976 .671 .335 r
.82211 .46249 .82304 .4647 .80609 .2565 .80518 .25412 Mtetra
.883 .691 .638 r
.80518 .25412 .80609 .2565 .80754 .25131 .80668 .24945 Mtetra
.693 .652 .805 r
.80668 .24945 .80754 .25131 .80936 .25012 .80852 .2485 Mtetra
.589 .63 .86 r
.80852 .2485 .80936 .25012 .81124 .24961 .81043 .24823 Mtetra
.506 .625 .903 r
.81043 .24823 .81124 .24961 .81315 .24942 .81236 .24827 Mtetra
.645 .74 .919 r
.81236 .24827 .81315 .24942 .81503 .24881 .81424 .24772 Mtetra
.659 .758 .923 r
.81424 .24772 .81503 .24881 .8169 .24821 .81612 .2471 Mtetra
.684 .763 .911 r
.81612 .2471 .8169 .24821 .81878 .24756 .81799 .24636 Mtetra
.776 .778 .855 r
.81799 .24636 .81878 .24756 .8206 .24641 .8198 .24506 Mtetra
.707 .729 .868 r
.8198 .24506 .8206 .24641 .82247 .24564 .82165 .24417 Mtetra
.535 .626 .888 r
.82165 .24417 .82247 .24564 .82442 .24573 .82359 .24412 Mtetra
.631 .251 0 r
.82359 .24412 .82442 .24573 .82687 .25092 .82599 .2488 Mtetra
.971 .658 .295 r
.82599 .2488 .82687 .25092 .84936 .4586 .84849 .45702 Mtetra
.665 .271 0 r
.84849 .45702 .84936 .4586 .8519 .46321 .85107 .46206 Mtetra
.303 .572 .934 r
.85107 .46206 .8519 .46321 .85403 .46371 .85321 .46258 Mtetra
.649 .764 .933 r
.85321 .46258 .85403 .46371 .85606 .46308 .85524 .46196 Mtetra
.831 .822 .84 r
.85524 .46196 .85606 .46308 .85797 .4613 .85715 .46017 Mtetra
.975 .788 .589 r
.85715 .46017 .85797 .4613 .85944 .45523 .85862 .4541 Mtetra
.974 .667 .312 r
.85862 .4541 .85944 .45523 .84006 .24616 .83928 .245 Mtetra
.975 .776 .572 r
.83928 .245 .84006 .24616 .84138 .23995 .8406 .23877 Mtetra
.759 .759 .853 r
.23161 .44471 .23263 .44566 .2342 .44461 .23317 .44367 Mtetra
.604 .727 .932 r
.23317 .44367 .2342 .44461 .2357 .4443 .23467 .44336 Mtetra
.426 .66 .958 r
.23467 .44336 .2357 .4443 .23716 .44438 .23614 .44346 Mtetra
.628 .739 .927 r
.23614 .44346 .23716 .44438 .23867 .44398 .23764 .44307 Mtetra
.636 .743 .926 r
.23764 .44307 .23867 .44398 .24018 .44356 .23916 .44265 Mtetra
.645 .749 .924 r
.23916 .44265 .24018 .44356 .2417 .44309 .24067 .4422 Mtetra
.668 .757 .917 r
.24067 .4422 .2417 .44309 .24323 .44255 .2422 .44167 Mtetra
.678 .76 .913 r
.2422 .44167 .24323 .44255 .24475 .44197 .24373 .44109 Mtetra
.685 .763 .91 r
.24373 .44109 .24475 .44197 .24629 .44136 .24526 .44048 Mtetra
.684 .763 .911 r
.24526 .44048 .24629 .44136 .24782 .44076 .24679 .43988 Mtetra
.689 .763 .908 r
.24679 .43988 .24782 .44076 .24935 .44014 .24833 .43925 Mtetra
.696 .764 .904 r
.24833 .43925 .24935 .44014 .25089 .43948 .24987 .43859 Mtetra
.713 .767 .895 r
.24987 .43859 .25089 .43948 .25244 .43874 .25141 .43785 Mtetra
.714 .767 .894 r
.25141 .43785 .25244 .43874 .25398 .43799 .25296 .43711 Mtetra
.708 .767 .898 r
.25296 .43711 .25398 .43799 .25553 .43727 .25451 .43639 Mtetra
.685 .764 .911 r
.25451 .43639 .25553 .43727 .25707 .43666 .25604 .43578 Mtetra
.675 .763 .917 r
.25604 .43578 .25707 .43666 .2586 .43609 .25758 .43522 Mtetra
.669 .763 .921 r
.25758 .43522 .2586 .43609 .26014 .43554 .25911 .43468 Mtetra
.669 .764 .921 r
.25911 .43468 .26014 .43554 .26167 .43499 .26065 .43413 Mtetra
.668 .764 .922 r
.26065 .43413 .26167 .43499 .26321 .43445 .26218 .43359 Mtetra
.667 .765 .923 r
.26218 .43359 .26321 .43445 .26474 .43391 .26372 .43305 Mtetra
.667 .765 .924 r
.26372 .43305 .26474 .43391 .26628 .43337 .26526 .43252 Mtetra
.666 .767 .925 r
.26526 .43252 .26628 .43337 .26782 .43283 .26679 .43198 Mtetra
.665 .768 .926 r
.26679 .43198 .26782 .43283 .26935 .4323 .26833 .43145 Mtetra
.699 .775 .91 r
.26833 .43145 .26935 .4323 .27091 .43151 .26988 .43078 Mtetra
.678 .798 .939 r
.26988 .43078 .27091 .43151 .27246 .43089 .27143 .43019 Mtetra
.599 .789 .971 r
.27143 .43019 .27246 .43089 .27397 .43069 .27295 .42984 Mtetra
.055 .475 .887 r
.27295 .42984 .27397 .43069 .27534 .43244 .27441 .4304 Mtetra
.114 .276 .752 r
.27441 .4304 .27534 .43244 .2764 .43829 .27582 .43167 Mtetra
.391 .274 .599 r
.27582 .43167 .2764 .43829 .26318 .63273 .27717 .43371 Mtetra
.542 .324 .533 r
.27717 .43371 .26318 .63273 .26465 .63442 .27863 .43432 Mtetra
.544 .326 .534 r
.27863 .43432 .26465 .63442 .26629 .63391 .28018 .43369 Mtetra
.545 .327 .534 r
.28018 .43369 .26629 .63391 .26798 .63259 .28178 .43256 Mtetra
.546 .327 .534 r
.28178 .43256 .26798 .63259 .26967 .63143 .28339 .43114 Mtetra
.545 .326 .534 r
.28339 .43114 .26967 .63143 .27133 .63065 .28497 .43027 Mtetra
.542 .324 .533 r
.28497 .43027 .27133 .63065 .27294 .6306 .28646 .43054 Mtetra
0 0 .25 r
.28646 .43054 .27294 .6306 .27442 .63241 .27438 .6172 Mtetra
0 0 .331 r
.27438 .6172 .27442 .63241 .27591 .63399 .27499 .63087 Mtetra
0 0 .513 r
.27499 .63087 .27591 .63399 .27745 .63494 .27639 .63386 Mtetra
.298 .578 .938 r
.27639 .63386 .27745 .63494 .27907 .63488 .27797 .63424 Mtetra
.621 .82 .977 r
.27797 .63424 .27907 .63488 .28072 .63439 .27962 .63377 Mtetra
.707 .84 .946 r
.27962 .63377 .28072 .63439 .28237 .63377 .28129 .63301 Mtetra
.63 .793 .961 r
.28129 .63301 .28237 .63377 .28402 .63337 .28294 .63254 Mtetra
.598 .77 .962 r
.28294 .63254 .28402 .63337 .28566 .63304 .28458 .63219 Mtetra
.614 .768 .954 r
.28458 .63219 .28566 .63304 .2873 .63268 .28623 .63179 Mtetra
.662 .773 .932 r
.28623 .63179 .2873 .63268 .28896 .63215 .28789 .63122 Mtetra
.683 .769 .917 r
.28789 .63122 .28896 .63215 .29062 .63154 .28955 .63057 Mtetra
.686 .761 .909 r
.28955 .63057 .29062 .63154 .29229 .63092 .29122 .62991 Mtetra
.626 .738 .928 r
.29122 .62991 .29229 .63092 .29393 .63063 .29287 .62949 Mtetra
.625 .712 .909 r
.29287 .62949 .29393 .63063 .29558 .6303 .29452 .62909 Mtetra
.673 .714 .879 r
.29452 .62909 .29558 .6303 .29725 .62954 .29619 .62846 Mtetra
.77 .756 .841 r
.29619 .62846 .29725 .62954 .29904 .62712 .2979 .62722 Mtetra
.898 .949 .829 r
.2979 .62722 .29904 .62712 .30103 .62158 .29966 .62519 Mtetra
0 0 .005 r
.29966 .62519 .30103 .62158 .31536 .42465 .30152 .62174 Mtetra
0 0 .247 r
.30152 .62174 .31536 .42465 .31725 .41907 .31531 .43283 Mtetra
0 0 .116 r
.31531 .43283 .31725 .41907 .31894 .41671 .31779 .41802 Mtetra
.935 .948 .616 r
.31779 .41802 .31894 .41671 .32056 .41521 .31955 .4145 Mtetra
.819 .814 .845 r
.31955 .4145 .32056 .41521 .32216 .41431 .32118 .41306 Mtetra
.668 .694 .865 r
.32118 .41306 .32216 .41431 .32373 .41377 .32275 .41248 Mtetra
.595 .661 .884 r
.32275 .41248 .32373 .41377 .32529 .4134 .3243 .41223 Mtetra
.603 .684 .899 r
.3243 .41223 .32529 .4134 .32685 .41303 .32586 .41193 Mtetra
.62 .706 .907 r
.32586 .41193 .32685 .41303 .32841 .41262 .32742 .41157 Mtetra
.627 .718 .912 r
.32742 .41157 .32841 .41262 .32998 .41218 .32899 .41118 Mtetra
.697 .747 .89 r
.32899 .41118 .32998 .41218 .33157 .41135 .33057 .41049 Mtetra
.719 .78 .9 r
.33057 .41049 .33157 .41135 .33316 .41048 .33216 .4097 Mtetra
.675 .793 .937 r
.33216 .4097 .33316 .41048 .33474 .40998 .33374 .40912 Mtetra
.469 .701 .969 r
.33374 .40912 .33474 .40998 .33623 .4109 .33529 .4091 Mtetra
.319 .438 .825 r
.33529 .4091 .33623 .4109 .33757 .41453 .33679 .40982 Mtetra
.33 .266 .633 r
.33679 .40982 .33757 .41453 .32789 .61008 .33823 .41173 Mtetra
.513 .3 .528 r
.33823 .41173 .32789 .61008 .3292 .616 .33901 .42523 Mtetra
0 0 .253 r
.33901 .42523 .3292 .616 .33076 .61764 .32987 .61372 Mtetra
0 .054 .574 r
.32987 .61372 .33076 .61764 .33238 .61826 .33135 .61682 Mtetra
.302 .507 .889 r
.33135 .61682 .33238 .61826 .33404 .61812 .33297 .61739 Mtetra
.658 .813 .958 r
.33297 .61739 .33404 .61812 .33573 .61751 .33466 .61681 Mtetra
.743 .833 .92 r
.33466 .61681 .33573 .61751 .33743 .61672 .33637 .61588 Mtetra
.653 .784 .944 r
.33637 .61588 .33743 .61672 .3391 .6164 .33805 .61533 Mtetra
.572 .711 .936 r
.33805 .61533 .3391 .6164 .34077 .61628 .33973 .6151 Mtetra
.634 .709 .901 r
.33973 .6151 .34077 .61628 .34246 .61575 .34141 .61465 Mtetra
.745 .753 .858 r
.34141 .61465 .34246 .61575 .34422 .61374 .34313 .61359 Mtetra
.883 .922 .845 r
.34313 .61359 .34422 .61374 .34614 .6088 .34489 .6117 Mtetra
0 0 0 r
.34489 .6117 .34614 .6088 .35797 .41193 .34672 .60853 Mtetra
.518 .3 .522 r
.34672 .60853 .35797 .41193 .35989 .40491 .34901 .59635 Mtetra
0 0 .247 r
.34901 .59635 .35989 .40491 .36159 .4024 .36046 .40423 Mtetra
.863 .906 .495 r
.36046 .40423 .36159 .4024 .36323 .40085 .36223 .40034 Mtetra
.85 .859 .848 r
.36223 .40034 .36323 .40085 .36484 .39997 .36387 .39874 Mtetra
.646 .693 .879 r
.36387 .39874 .36484 .39997 .36643 .39955 .36546 .39827 Mtetra
.552 .645 .896 r
.36546 .39827 .36643 .39955 .36801 .39933 .36704 .39816 Mtetra
.575 .677 .909 r
.36704 .39816 .36801 .39933 .36959 .39902 .36862 .39796 Mtetra
.643 .724 .907 r
.36862 .39796 .36959 .39902 .37119 .39852 .37021 .3975 Mtetra
.657 .735 .907 r
.37021 .3975 .37119 .39852 .37279 .39797 .37181 .39698 Mtetra
.679 .748 .904 r
.37181 .39698 .37279 .39797 .37439 .39733 .37342 .39637 Mtetra
.695 .759 .901 r
.37342 .39637 .37439 .39733 .376 .39662 .37502 .39568 Mtetra
.697 .765 .904 r
.37502 .39568 .376 .39662 .37761 .39591 .37663 .39499 Mtetra
.686 .766 .912 r
.37663 .39499 .37761 .39591 .37922 .39526 .37824 .39435 Mtetra
.671 .764 .92 r
.37824 .39435 .37922 .39526 .38082 .39468 .37984 .39377 Mtetra
.661 .762 .925 r
.37984 .39377 .38082 .39468 .38243 .39415 .38145 .39324 Mtetra
.644 .757 .931 r
.38145 .39324 .38243 .39415 .38403 .39368 .38305 .39276 Mtetra
.628 .75 .935 r
.38305 .39276 .38403 .39368 .38563 .39328 .38465 .39234 Mtetra
.628 .746 .932 r
.38465 .39234 .38563 .39328 .38723 .39289 .38626 .39193 Mtetra
.643 .746 .924 r
.38626 .39193 .38723 .39289 .38883 .39244 .38786 .39146 Mtetra
.662 .746 .913 r
.38786 .39146 .38883 .39244 .39044 .39193 .38947 .39092 Mtetra
.675 .745 .903 r
.38947 .39092 .39044 .39193 .39205 .39136 .39108 .39032 Mtetra
.691 .744 .891 r
.39108 .39032 .39205 .39136 .39367 .39071 .3927 .38964 Mtetra
.704 .74 .88 r
.3927 .38964 .39367 .39071 .39528 .39001 .39432 .38889 Mtetra
.701 .731 .874 r
.39432 .38889 .39528 .39001 .3969 .3893 .39594 .38814 Mtetra
.712 .728 .863 r
.39594 .38814 .3969 .3893 .39852 .38856 .39757 .38732 Mtetra
.709 .713 .852 r
.39757 .38732 .39852 .38856 .40015 .38785 .39919 .3865 Mtetra
.643 .674 .865 r
.39919 .3865 .40015 .38785 .40176 .38732 .40081 .38603 Mtetra
.269 .5 .894 r
.40081 .38603 .40176 .38732 .40336 .38732 .40238 .38661 Mtetra
.872 .429 .081 r
.40238 .38661 .40336 .38732 .40492 .38816 .40386 .38971 Mtetra
.952 .681 .485 r
.40386 .38971 .40492 .38816 .40647 .38958 .39829 .58267 Mtetra
.557 .332 .529 r
.39829 .58267 .40647 .38958 .40804 .39048 .39968 .59112 Mtetra
.541 .319 .527 r
.39968 .59112 .40804 .39048 .40968 .38947 .40139 .59079 Mtetra
.54 .318 .527 r
.40139 .59079 .40968 .38947 .4113 .38885 .40314 .5898 Mtetra
.543 .32 .527 r
.40314 .5898 .4113 .38885 .41281 .39163 .40482 .5903 Mtetra
.546 .323 .528 r
.40482 .5903 .41281 .39163 .40764 .58892 .40646 .59242 Mtetra
.623 .291 .388 r
.40646 .59242 .40764 .58892 .40918 .59384 .40813 .59376 Mtetra
.303 0 0 r
.40813 .59376 .40918 .59384 .41085 .5953 .40982 .59423 Mtetra
.606 .726 .93 r
.40982 .59423 .41085 .5953 .41257 .59501 .41155 .59387 Mtetra
.663 .731 .9 r
.41155 .59387 .41257 .59501 .41431 .5943 .41329 .59328 Mtetra
.643 .749 .926 r
.41329 .59328 .41431 .5943 .41605 .59359 .41502 .59277 Mtetra
.544 .761 .977 r
.41502 .59277 .41605 .59359 .41778 .59322 .41675 .59253 Mtetra
.649 .827 .968 r
.41675 .59253 .41778 .59322 .41952 .59266 .41849 .59195 Mtetra
.822 .838 .861 r
.41849 .59195 .41952 .59266 .42127 .59173 .42026 .59043 Mtetra
.887 .741 .695 r
.42026 .59043 .42127 .59173 .42304 .59013 .4221 .58663 Mtetra
.896 .663 .579 r
.4221 .58663 .42304 .59013 .42484 .58762 .42419 .5741 Mtetra
.942 .673 .499 r
.42419 .5741 .42484 .58762 .42673 .58193 .43155 .38065 Mtetra
.55 .33 .534 r
.43155 .38065 .42673 .58193 .43409 .38278 .43327 .3773 Mtetra
.664 .488 .636 r
.43327 .3773 .43409 .38278 .43587 .37735 .43494 .37535 Mtetra
.719 .632 .759 r
.43494 .37535 .43587 .37735 .43756 .375 .4366 .37411 Mtetra
.69 .78 .919 r
.4366 .37411 .43756 .375 .4392 .3742 .43824 .37344 Mtetra
.617 .79 .964 r
.43824 .37344 .4392 .3742 .44083 .37383 .43988 .37302 Mtetra
.589 .766 .964 r
.43988 .37302 .44083 .37383 .44247 .37362 .44151 .37269 Mtetra
.618 .749 .94 r
.44151 .37269 .44247 .37362 .4441 .37324 .44315 .37229 Mtetra
.618 .745 .937 r
.44315 .37229 .4441 .37324 .44574 .37288 .44479 .3719 Mtetra
.63 .743 .929 r
.44479 .3719 .44574 .37288 .44738 .37248 .44643 .37147 Mtetra
.656 .744 .915 r
.44643 .37147 .44738 .37248 .44902 .37198 .44808 .37094 Mtetra
.67 .743 .905 r
.44808 .37094 .44902 .37198 .45067 .37142 .44972 .37035 Mtetra
.685 .742 .894 r
.44972 .37035 .45067 .37142 .45232 .37079 .45137 .36969 Mtetra
.702 .741 .881 r
.45137 .36969 .45232 .37079 .45397 .37007 .45303 .36893 Mtetra
.701 .733 .875 r
.45303 .36893 .45397 .37007 .45562 .36935 .45468 .36817 Mtetra
.705 .727 .868 r
.45468 .36817 .45562 .36935 .45727 .36862 .45633 .36739 Mtetra
.717 .722 .853 r
.45633 .36739 .45727 .36862 .45893 .36786 .45799 .3665 Mtetra
.66 .682 .86 r
.45799 .3665 .45893 .36786 .46058 .36728 .45964 .36593 Mtetra
.459 .594 .9 r
.45964 .36593 .46058 .36728 .46222 .36709 .46128 .36612 Mtetra
.767 .293 0 r
.46128 .36612 .46222 .36709 .46385 .36784 .46287 .36869 Mtetra
.929 .613 .422 r
.46287 .36869 .46385 .36784 .46547 .36918 .46427 .38186 Mtetra
.943 .664 .482 r
.46427 .38186 .46547 .36918 .46709 .37082 .46242 .57213 Mtetra
.543 .32 .527 r
.46242 .57213 .46709 .37082 .46874 .37065 .46417 .57249 Mtetra
.54 .318 .527 r
.46417 .57249 .46874 .37065 .47041 .36977 .46594 .57157 Mtetra
.539 .317 .527 r
.46594 .57157 .47041 .36977 .47208 .36857 .46773 .57004 Mtetra
.54 .318 .527 r
.46773 .57004 .47208 .36857 .47375 .36723 .46951 .56888 Mtetra
.541 .319 .527 r
.46951 .56888 .47375 .36723 .47542 .36664 .47127 .56827 Mtetra
.543 .321 .527 r
.47127 .56827 .47542 .36664 .47705 .36801 .47302 .56895 Mtetra
.546 .323 .528 r
.47302 .56895 .47705 .36801 .47584 .56586 .47475 .57127 Mtetra
.609 .306 .431 r
.47475 .57127 .47584 .56586 .47751 .57249 .4765 .57278 Mtetra
.522 0 0 r
.4765 .57278 .47751 .57249 .47925 .57461 .47826 .57352 Mtetra
.598 .723 .932 r
.47826 .57352 .47925 .57461 .48102 .57445 .48003 .57317 Mtetra
.658 .71 .886 r
.48003 .57317 .48102 .57445 .4828 .57382 .48181 .57259 Mtetra
.669 .722 .889 r
.48181 .57259 .4828 .57382 .48459 .57303 .48359 .57195 Mtetra
.603 .727 .932 r
.48359 .57195 .48459 .57303 .48636 .57264 .48537 .57158 Mtetra
.6 .732 .937 r
.48537 .57158 .48636 .57264 .48814 .57225 .48715 .57123 Mtetra
.607 .742 .941 r
.48715 .57123 .48814 .57225 .48993 .57184 .48893 .57084 Mtetra
.634 .758 .937 r
.48893 .57084 .48993 .57184 .49171 .57133 .49072 .57035 Mtetra
.642 .763 .936 r
.49072 .57035 .49171 .57133 .49349 .57081 .4925 .56983 Mtetra
.646 .765 .935 r
.4925 .56983 .49349 .57081 .49528 .57027 .49429 .56929 Mtetra
.639 .763 .938 r
.49429 .56929 .49528 .57027 .49707 .56976 .49608 .56877 Mtetra
.645 .764 .935 r
.49608 .56877 .49707 .56976 .49886 .56923 .49787 .56823 Mtetra
.654 .765 .931 r
.49787 .56823 .49886 .56923 .50065 .56867 .49966 .56766 Mtetra
.643 .758 .932 r
.49966 .56766 .50065 .56867 .50244 .56831 .50145 .56713 Mtetra
.678 .737 .895 r
.50145 .56713 .50244 .56831 .50423 .56767 .50324 .56645 Mtetra
.727 .744 .866 r
.50324 .56645 .50423 .56767 .50603 .56645 .50504 .56547 Mtetra
.848 .798 .802 r
.50504 .56547 .50603 .56645 .50784 .56273 .50684 .56345 Mtetra
.874 .976 .674 r
.50684 .56345 .50784 .56273 .50967 .55296 .50865 .56076 Mtetra
.322 .083 .387 r
.50865 .56076 .50967 .55296 .51225 .35532 .51046 .55741 Mtetra
.54 .318 .527 r
.51046 .55741 .51225 .35532 .51394 .35361 .51225 .55613 Mtetra
.541 .319 .527 r
.51225 .55613 .51394 .35361 .51562 .35321 .51405 .55576 Mtetra
.542 .32 .527 r
.51405 .55576 .51562 .35321 .51731 .3535 .51584 .55583 Mtetra
.543 .32 .527 r
.51584 .55583 .51731 .3535 .519 .35345 .51764 .55622 Mtetra
.541 .319 .527 r
.51764 .55622 .519 .35345 .52069 .35305 .51944 .55584 Mtetra
.539 .317 .527 r
.51944 .55584 .52069 .35305 .52238 .35187 .52124 .55404 Mtetra
0 0 .346 r
.52124 .55404 .52238 .35187 .52408 .34886 .52315 .3557 Mtetra
0 0 .108 r
.52315 .3557 .52408 .34886 .52577 .34646 .52485 .34687 Mtetra
.967 .935 .678 r
.52485 .34687 .52577 .34646 .52746 .34466 .52654 .34353 Mtetra
.746 .753 .858 r
.52654 .34353 .52746 .34466 .52915 .34384 .52824 .34248 Mtetra
.65 .683 .868 r
.52824 .34248 .52915 .34384 .53085 .34328 .52993 .34195 Mtetra
.588 .661 .888 r
.52993 .34195 .53085 .34328 .53254 .34288 .53163 .3417 Mtetra
.623 .703 .902 r
.53163 .3417 .53254 .34288 .53424 .34244 .53333 .34129 Mtetra
.622 .71 .909 r
.53333 .34129 .53424 .34244 .53594 .34199 .53502 .34089 Mtetra
.63 .723 .914 r
.53502 .34089 .53594 .34199 .53764 .34151 .53672 .34045 Mtetra
.715 .759 .887 r
.53672 .34045 .53764 .34151 .53933 .34051 .53842 .33962 Mtetra
.707 .793 .918 r
.53842 .33962 .53933 .34051 .54103 .33969 .54012 .33885 Mtetra
.646 .787 .949 r
.54012 .33885 .54103 .33969 .54274 .33934 .54183 .33832 Mtetra
.208 .527 .92 r
.54183 .33832 .54274 .33934 .54445 .34127 .54354 .33888 Mtetra
.27 .347 .759 r
.54354 .33888 .54445 .34127 .54621 .34806 .54525 .34016 Mtetra
.436 .303 .601 r
.54525 .34016 .54621 .34806 .54937 .54669 .54698 .34223 Mtetra
.544 .326 .534 r
.54698 .34223 .54937 .54669 .5512 .54748 .54869 .34168 Mtetra
.545 .326 .534 r
.54869 .34168 .5512 .54748 .55301 .54669 .5504 .34072 Mtetra
.543 .325 .533 r
.5504 .34072 .55301 .54669 .55483 .54576 .55211 .34071 Mtetra
0 0 .375 r
.55211 .34071 .55483 .54576 .55668 .54755 .55562 .53654 Mtetra
.029 0 .479 r
.55562 .53654 .55668 .54755 .55852 .54904 .55754 .54606 Mtetra
0 .126 .646 r
.55754 .54606 .55852 .54904 .56037 .54991 .5594 .54878 Mtetra
.363 .609 .944 r
.5594 .54878 .56037 .54991 .5622 .55004 .56124 .5491 Mtetra
.63 .773 .949 r
.56124 .5491 .5622 .55004 .56404 .54963 .56308 .5486 Mtetra
.744 .788 .888 r
.56308 .5486 .56404 .54963 .56586 .54858 .5649 .54755 Mtetra
.801 .797 .848 r
.5649 .54755 .56586 .54858 .56767 .54566 .56673 .54606 Mtetra
.861 .993 .748 r
.56673 .54606 .56767 .54566 .56942 .53907 .56854 .54381 Mtetra
.063 0 .234 r
.56854 .54381 .56942 .53907 .56848 .3375 .57033 .5399 Mtetra
0 0 .365 r
.57033 .5399 .56848 .3375 .57014 .33281 .56938 .34105 Mtetra
0 0 .204 r
.56938 .34105 .57014 .33281 .57184 .33052 .57097 .33139 Mtetra
.908 .943 .586 r
.57097 .33139 .57184 .33052 .57355 .32903 .57265 .32805 Mtetra
.785 .793 .859 r
.57265 .32805 .57355 .32903 .57526 .32815 .57436 .32678 Mtetra
.657 .687 .866 r
.57436 .32678 .57526 .32815 .57699 .32758 .57609 .3262 Mtetra
.593 .657 .882 r
.57609 .3262 .57699 .32758 .57871 .32718 .57782 .32592 Mtetra
.616 .69 .896 r
.57782 .32592 .57871 .32718 .58044 .32674 .57954 .32555 Mtetra
.624 .705 .904 r
.57954 .32555 .58044 .32674 .58217 .32628 .58127 .32513 Mtetra
.632 .717 .909 r
.58127 .32513 .58217 .32628 .5839 .32577 .583 .32467 Mtetra
.707 .753 .888 r
.583 .32467 .5839 .32577 .58562 .32481 .58473 .32387 Mtetra
.715 .787 .909 r
.58473 .32387 .58562 .32481 .58734 .32392 .58645 .32305 Mtetra
.663 .789 .941 r
.58645 .32305 .58734 .32392 .58907 .32345 .58819 .32245 Mtetra
.451 .669 .956 r
.58819 .32245 .58907 .32345 .59084 .32471 .58993 .32252 Mtetra
.37 .43 .793 r
.58993 .32252 .59084 .32471 .59269 .32917 .59169 .32335 Mtetra
.374 .285 .625 r
.59169 .32335 .59269 .32917 .59887 .53002 .59349 .3256 Mtetra
0 0 .39 r
.59349 .3256 .59887 .53002 .60083 .53451 .59962 .52151 Mtetra
.068 .017 .485 r
.59962 .52151 .60083 .53451 .60273 .53595 .60173 .53244 Mtetra
.126 .19 .66 r
.60173 .53244 .60273 .53595 .60462 .53645 .60367 .53513 Mtetra
.378 .577 .918 r
.60367 .53513 .60462 .53645 .60649 .53643 .60555 .53551 Mtetra
.649 .789 .949 r
.60555 .53551 .60649 .53643 .60835 .53592 .60741 .53493 Mtetra
.76 .804 .888 r
.60741 .53493 .60835 .53592 .6102 .53478 .60926 .53378 Mtetra
.8 .808 .858 r
.60926 .53378 .6102 .53478 .612 .53203 .6111 .53233 Mtetra
.832 .997 .771 r
.6111 .53233 .612 .53203 .61372 .52581 .61293 .5303 Mtetra
.128 0 .256 r
.61293 .5303 .61372 .52581 .61013 .32419 .61471 .52691 Mtetra
0 0 .392 r
.61471 .52691 .61013 .32419 .61175 .31894 .61133 .33462 Mtetra
0 0 .309 r
.61133 .33462 .61175 .31894 .61345 .31655 .61264 .3179 Mtetra
.795 .867 .428 r
.61264 .3179 .61345 .31655 .61517 .315 .6143 .31423 Mtetra
.814 .846 .873 r
.6143 .31423 .61517 .315 .61691 .31416 .61602 .31285 Mtetra
.635 .689 .883 r
.61602 .31285 .61691 .31416 .61866 .31372 .61778 .31238 Mtetra
.557 .649 .896 r
.61778 .31238 .61866 .31372 .62042 .31345 .61954 .31224 Mtetra
.61 .699 .907 r
.61954 .31224 .62042 .31345 .62218 .313 .6213 .31187 Mtetra
.659 .735 .906 r
.6213 .31187 .62218 .313 .62393 .31239 .62305 .31129 Mtetra
.672 .746 .906 r
.62305 .31129 .62393 .31239 .62568 .31172 .62481 .31066 Mtetra
.755 .778 .871 r
.62481 .31066 .62568 .31172 .62742 .31061 .62655 .30957 Mtetra
.749 .78 .879 r
.62655 .30957 .62742 .31061 .62916 .30955 .62829 .30853 Mtetra
.623 .742 .932 r
.62829 .30853 .62916 .30955 .63092 .3091 .63005 .30809 Mtetra
.569 .094 0 r
.63005 .30809 .63092 .3091 .63277 .31127 .63191 .31035 Mtetra
.974 .679 .4 r
.63191 .31035 .63277 .31127 .6416 .51267 .64072 .51274 Mtetra
.936 .573 .294 r
.64072 .51274 .6416 .51267 .64388 .52331 .64296 .52243 Mtetra
0 .248 .721 r
.64296 .52243 .64388 .52331 .64583 .52466 .64491 .52371 Mtetra
.649 .786 .947 r
.64491 .52371 .64583 .52466 .64772 .52411 .6468 .52312 Mtetra
.757 .808 .893 r
.6468 .52312 .64772 .52411 .64959 .52302 .64866 .52199 Mtetra
.614 .754 .945 r
.64866 .52199 .64959 .52302 .65148 .52261 .65056 .52154 Mtetra
.52 .704 .954 r
.65056 .52154 .65148 .52261 .65339 .52252 .65247 .52142 Mtetra
.683 .765 .913 r
.65247 .52142 .65339 .52252 .65528 .52181 .65435 .52068 Mtetra
.911 .789 .714 r
.65435 .52068 .65528 .52181 .65706 .51846 .65614 .51724 Mtetra
.975 .686 .409 r
.65614 .51724 .65706 .51846 .65103 .32039 .65004 .31624 Mtetra
.911 .658 .542 r
.65004 .31624 .65103 .32039 .65216 .30387 .65129 .30259 Mtetra
.863 .764 .751 r
.65129 .30259 .65216 .30387 .65385 .30134 .65298 .30012 Mtetra
.657 .718 .894 r
.65298 .30012 .65385 .30134 .65562 .30073 .65476 .29954 Mtetra
.516 .661 .926 r
.65476 .29954 .65562 .30073 .65742 .30066 .65656 .2995 Mtetra
.566 .692 .925 r
.65656 .2995 .65742 .30066 .65921 .30041 .65835 .29928 Mtetra
.656 .737 .909 r
.65835 .29928 .65921 .30041 .66098 .2998 .66012 .29871 Mtetra
.67 .748 .909 r
.66012 .29871 .66098 .2998 .66276 .29914 .6619 .29807 Mtetra
.746 .778 .879 r
.6619 .29807 .66276 .29914 .66452 .29809 .66366 .29704 Mtetra
.758 .784 .875 r
.66366 .29704 .66452 .29809 .66627 .29698 .66542 .29593 Mtetra
.647 .751 .925 r
.66542 .29593 .66627 .29698 .66805 .29642 .6672 .29539 Mtetra
0 .112 .635 r
.6672 .29539 .66805 .29642 .66994 .29808 .66909 .29711 Mtetra
.975 .676 .383 r
.66909 .29711 .66994 .29808 .68094 .49331 .68018 .49543 Mtetra
.922 .581 .376 r
.68018 .49543 .68094 .49331 .6837 .51078 .6828 .50988 Mtetra
0 .054 .553 r
.6828 .50988 .6837 .51078 .68573 .5128 .68483 .51175 Mtetra
.601 .747 .947 r
.68483 .51175 .68573 .5128 .68766 .51253 .68675 .51134 Mtetra
.753 .774 .87 r
.68675 .51134 .68766 .51253 .68955 .51132 .68864 .51017 Mtetra
.802 .791 .843 r
.68864 .51017 .68955 .51132 .69137 .50885 .69051 .50862 Mtetra
.872 .968 .853 r
.69051 .50862 .69137 .50885 .69306 .50378 .69236 .50673 Mtetra
0 0 .127 r
.69236 .50673 .69306 .50378 .68469 .30204 .69416 .50376 Mtetra
.528 .309 .526 r
.69416 .50376 .68469 .30204 .68612 .2944 .69568 .49546 Mtetra
0 0 .404 r
.69568 .49546 .68612 .2944 .68781 .29179 .68716 .29444 Mtetra
0 0 0 r
.68716 .29444 .68781 .29179 .68955 .29013 .68875 .28985 Mtetra
.909 .947 .815 r
.68875 .28985 .68955 .29013 .69131 .28889 .69046 .28775 Mtetra
.721 .761 .884 r
.69046 .28775 .69131 .28889 .69309 .28797 .69224 .28685 Mtetra
.611 .722 .924 r
.69224 .28685 .69309 .28797 .6949 .28755 .69405 .28646 Mtetra
.489 .67 .944 r
.69405 .28646 .6949 .28755 .69676 .28823 .69588 .28646 Mtetra
.432 .519 .847 r
.69588 .28646 .69676 .28823 .69877 .29133 .69774 .28691 Mtetra
.423 .35 .67 r
.69774 .28691 .69877 .29133 .71183 .49024 .69966 .28828 Mtetra
.533 .317 .533 r
.69966 .28828 .71183 .49024 .71428 .49887 .70181 .29372 Mtetra
.019 0 .421 r
.70181 .29372 .71428 .49887 .71635 .50068 .7152 .49499 Mtetra
.18 .165 .604 r
.7152 .49499 .71635 .50068 .71836 .50135 .71741 .49921 Mtetra
.224 .362 .793 r
.71741 .49921 .71836 .50135 .72034 .5016 .71946 .50061 Mtetra
.448 .692 .97 r
.71946 .50061 .72034 .5016 .72231 .50154 .72143 .50065 Mtetra
.71 .825 .937 r
.72143 .50065 .72231 .50154 .72424 .50074 .72335 .49977 Mtetra
.905 .826 .758 r
.72335 .49977 .72424 .50074 .72605 .49806 .72516 .49698 Mtetra
.978 .742 .511 r
.72516 .49698 .72605 .49806 .72732 .48661 .72644 .48547 Mtetra
.977 .681 .378 r
.72644 .48547 .72732 .48661 .71673 .28324 .7159 .28209 Mtetra
.919 .786 .698 r
.7159 .28209 .71673 .28324 .71837 .27977 .71753 .27862 Mtetra
.72 .76 .884 r
.71753 .27862 .71837 .27977 .72016 .27886 .71933 .27771 Mtetra
.599 .712 .924 r
.71933 .27771 .72016 .27886 .72199 .27852 .72116 .27737 Mtetra
.634 .728 .915 r
.72116 .27737 .72199 .27852 .72382 .27803 .72298 .27688 Mtetra
.74 .767 .875 r
.72298 .27688 .72382 .27803 .72561 .277 .72478 .27585 Mtetra
.652 .736 .911 r
.72478 .27585 .72561 .277 .72743 .27643 .7266 .27528 Mtetra
.114 .433 .873 r
.7266 .27528 .72743 .27643 .72935 .27737 .72852 .27622 Mtetra
.906 .522 .091 r
.72852 .27622 .72935 .27737 .73173 .28522 .7309 .28406 Mtetra
.975 .671 .352 r
.7309 .28406 .73173 .28522 .74733 .48958 .74645 .48849 Mtetra
.6 .138 0 r
.74645 .48849 .74733 .48958 .74952 .49252 .74864 .49143 Mtetra
.554 .722 .952 r
.74864 .49143 .74952 .49252 .7515 .49228 .75062 .49119 Mtetra
.713 .786 .909 r
.75062 .49119 .7515 .49228 .75344 .49137 .75256 .49028 Mtetra
.696 .781 .916 r
.75256 .49028 .75344 .49137 .75538 .49055 .75451 .48946 Mtetra
.511 .701 .956 r
.75451 .48946 .75538 .49055 .75737 .49045 .7565 .48935 Mtetra
.654 .765 .931 r
.7565 .48935 .75737 .49045 .75933 .48982 .75846 .48873 Mtetra
.869 .817 .796 r
.75846 .48873 .75933 .48982 .76118 .48757 .76031 .48648 Mtetra
.98 .75 .517 r
.76031 .48648 .76118 .48757 .76245 .47732 .76158 .47623 Mtetra
.977 .678 .362 r
.76158 .47623 .76245 .47732 .74958 .2724 .74875 .27125 Mtetra
.933 .789 .679 r
.74875 .27125 .74958 .2724 .75118 .26858 .75035 .26743 Mtetra
.726 .765 .883 r
.75035 .26743 .75118 .26858 .75298 .26763 .75217 .26647 Mtetra
.601 .715 .924 r
.75217 .26647 .75298 .26763 .75484 .26727 .75402 .26611 Mtetra
.6 .714 .925 r
.75402 .26611 .75484 .26727 .7567 .26691 .75588 .26575 Mtetra
.739 .769 .877 r
.75588 .26575 .7567 .26691 .7585 .26588 .75769 .26472 Mtetra
.656 .738 .911 r
.75769 .26472 .7585 .26588 .76034 .26529 .75953 .26413 Mtetra
.231 .508 .907 r
.75953 .26413 .76034 .26529 .76228 .26599 .76147 .26483 Mtetra
.884 .492 .037 r
.76147 .26483 .76228 .26599 .76474 .27327 .76392 .27212 Mtetra
.975 .667 .334 r
.76392 .27212 .76474 .27327 .78269 .47883 .78183 .47773 Mtetra
.655 .201 0 r
.78183 .47773 .78269 .47883 .78498 .48228 .78412 .48118 Mtetra
.381 .631 .952 r
.78412 .48118 .78498 .48228 .78703 .48255 .78617 .48145 Mtetra
.693 .781 .919 r
.78617 .48145 .78703 .48255 .789 .48174 .78814 .48064 Mtetra
.873 .82 .793 r
.78814 .48064 .789 .48174 .79085 .47943 .78999 .47833 Mtetra
.978 .767 .552 r
.78999 .47833 .79085 .47943 .79224 .47159 .79139 .47049 Mtetra
.977 .675 .347 r
.79139 .47049 .79224 .47159 .7773 .26399 .77649 .26283 Mtetra
.951 .785 .641 r
.77649 .26283 .7773 .26399 .77882 .2594 .77802 .25824 Mtetra
.745 .772 .875 r
.77802 .25824 .77882 .2594 .78064 .25833 .77983 .25717 Mtetra
.617 .722 .921 r
.77983 .25717 .78064 .25833 .78251 .2579 .7817 .25674 Mtetra
.584 .707 .927 r
.7817 .25674 .78251 .2579 .78439 .2576 .78358 .25644 Mtetra
.747 .773 .874 r
.78358 .25644 .78439 .2576 .78621 .25652 .7854 .25535 Mtetra
.67 .744 .906 r
.7854 .25535 .78621 .25652 .78806 .25585 .78726 .25469 Mtetra
.351 .581 .929 r
.78726 .25469 .78806 .25585 .79001 .25627 .78921 .2551 Mtetra
.836 .431 0 r
.78921 .2551 .79001 .25627 .79245 .26236 .79165 .26121 Mtetra
.973 .663 .318 r
.79165 .26121 .79245 .26236 .81243 .46915 .81159 .46805 Mtetra
.696 .25 0 r
.81159 .46805 .81243 .46915 .81483 .47311 .81399 .47201 Mtetra
.343 .608 .947 r
.81399 .47201 .81483 .47311 .81692 .47348 .81608 .47238 Mtetra
.678 .778 .926 r
.81608 .47238 .81692 .47348 .81891 .47273 .81807 .47163 Mtetra
.865 .826 .808 r
.81807 .47163 .81891 .47273 .82078 .47056 .81994 .46948 Mtetra
.982 .77 .543 r
.81994 .46948 .82078 .47056 .82211 .46249 .82129 .46158 Mtetra
.976 .672 .331 r
.82129 .46158 .82211 .46249 .80518 .25412 .8044 .25308 Mtetra
.963 .797 .63 r
.8044 .25308 .80518 .25412 .80668 .24945 .80589 .24834 Mtetra
.728 .779 .893 r
.80589 .24834 .80668 .24945 .80852 .2485 .80773 .24738 Mtetra
.574 .713 .937 r
.80773 .24738 .80852 .2485 .81043 .24823 .80964 .2471 Mtetra
.481 .664 .943 r
.80964 .2471 .81043 .24823 .81236 .24827 .81157 .24714 Mtetra
.648 .743 .919 r
.81157 .24714 .81236 .24827 .81424 .24772 .81345 .24657 Mtetra
.663 .747 .912 r
.81345 .24657 .81424 .24772 .81612 .2471 .81533 .24593 Mtetra
.687 .753 .902 r
.81533 .24593 .81612 .2471 .81799 .24636 .8172 .24518 Mtetra
.78 .782 .855 r
.8172 .24518 .81799 .24636 .8198 .24506 .81901 .24385 Mtetra
.715 .756 .885 r
.81901 .24385 .8198 .24506 .82165 .24417 .82086 .24294 Mtetra
.523 .665 .926 r
.82086 .24294 .82165 .24417 .82359 .24412 .8228 .24287 Mtetra
.711 .295 0 r
.8228 .24287 .82359 .24412 .82599 .2488 .82519 .24746 Mtetra
.971 .657 .298 r
.82519 .24746 .82599 .2488 .84849 .45702 .84765 .45578 Mtetra
.743 .322 0 r
.84765 .45578 .84849 .45702 .85107 .46206 .85024 .46091 Mtetra
.298 .57 .933 r
.85024 .46091 .85107 .46206 .85321 .46258 .85238 .46144 Mtetra
.649 .761 .931 r
.85238 .46144 .85321 .46258 .85524 .46196 .85441 .46082 Mtetra
.83 .819 .839 r
.85441 .46082 .85524 .46196 .85715 .46017 .85632 .45903 Mtetra
.975 .788 .589 r
.85632 .45903 .85715 .46017 .85862 .4541 .8578 .45296 Mtetra
.974 .667 .312 r
.8578 .45296 .85862 .4541 .83928 .245 .8385 .24382 Mtetra
.974 .775 .573 r
.8385 .24382 .83928 .245 .8406 .23877 .83982 .23759 Mtetra
.758 .758 .852 r
.23058 .44376 .23161 .44471 .23317 .44367 .23215 .44272 Mtetra
.603 .726 .931 r
.23215 .44272 .23317 .44367 .23467 .44336 .23365 .44241 Mtetra
.425 .657 .957 r
.23365 .44241 .23467 .44336 .23614 .44346 .23511 .44252 Mtetra
.627 .735 .925 r
.23511 .44252 .23614 .44346 .23764 .44307 .23662 .44213 Mtetra
.635 .738 .923 r
.23662 .44213 .23764 .44307 .23916 .44265 .23813 .44172 Mtetra
.645 .742 .92 r
.23813 .44172 .23916 .44265 .24067 .4422 .23965 .44127 Mtetra
.667 .748 .911 r
.23965 .44127 .24067 .4422 .2422 .44167 .24117 .44074 Mtetra
.677 .751 .907 r
.24117 .44074 .2422 .44167 .24373 .44109 .2427 .44016 Mtetra
.684 .753 .904 r
.2427 .44016 .24373 .44109 .24526 .44048 .24423 .43956 Mtetra
.686 .754 .903 r
.24423 .43956 .24526 .44048 .24679 .43988 .24577 .43894 Mtetra
.688 .752 .9 r
.24577 .43894 .24679 .43988 .24833 .43925 .2473 .43831 Mtetra
.2473 .43831 .24833 .43925 .24987 .43859 .24884 .43769 Mtetra
.686 .758 .906 r
.24884 .43769 .24987 .43859 .25141 .43785 .25038 .43707 Mtetra
.685 .786 .927 r
.25038 .43707 .25141 .43785 .25296 .43711 .25192 .43646 Mtetra
.68 .818 .949 r
.25192 .43646 .25296 .43711 .25451 .43639 .25345 .43587 Mtetra
.667 .846 .968 r
.25345 .43587 .25451 .43639 .25604 .43578 .25499 .43529 Mtetra
.66 .853 .974 r
.25499 .43529 .25604 .43578 .25758 .43522 .25652 .43473 Mtetra
.655 .853 .975 r
.25652 .43473 .25758 .43522 .25911 .43468 .25806 .43417 Mtetra
.653 .85 .975 r
.25806 .43417 .25911 .43468 .26065 .43413 .25959 .43363 Mtetra
.65 .849 .976 r
.25959 .43363 .26065 .43413 .26218 .43359 .26113 .43309 Mtetra
.648 .85 .977 r
.26113 .43309 .26218 .43359 .26372 .43305 .26267 .43256 Mtetra
.646 .85 .978 r
.26267 .43256 .26372 .43305 .26526 .43252 .2642 .43203 Mtetra
.645 .852 .979 r
.2642 .43203 .26526 .43252 .26679 .43198 .26574 .4315 Mtetra
.644 .854 .98 r
.26574 .4315 .26679 .43198 .26833 .43145 .26728 .43097 Mtetra
.651 .856 .978 r
.26728 .43097 .26833 .43145 .26988 .43078 .26882 .43042 Mtetra
.631 .882 .987 r
.26882 .43042 .26988 .43078 .27143 .43019 .27036 .42987 Mtetra
.614 .887 .99 r
.27036 .42987 .27143 .43019 .27295 .42984 .2719 .42935 Mtetra
.613 .845 .987 r
.2719 .42935 .27295 .42984 .27441 .4304 .27344 .42889 Mtetra
.636 .64 .838 r
.27344 .42889 .27441 .4304 .27582 .43167 .27498 .42846 Mtetra
.606 .498 .704 r
.27498 .42846 .27582 .43167 .27717 .43371 .27651 .42801 Mtetra
.589 .431 .635 r
.27651 .42801 .27717 .43371 .27863 .43432 .27806 .42747 Mtetra
.584 .415 .619 r
.27806 .42747 .27863 .43432 .28018 .43369 .27961 .42689 Mtetra
.584 .416 .619 r
.27961 .42689 .28018 .43369 .28178 .43256 .28116 .42631 Mtetra
.606 .437 .627 r
.28116 .42631 .28178 .43256 .28339 .43114 .28274 .42539 Mtetra
.598 .437 .634 r
.28274 .42539 .28339 .43114 .28497 .43027 .2843 .42468 Mtetra
.56 .411 .636 r
.2843 .42468 .28497 .43027 .28646 .43054 .28582 .42458 Mtetra
.228 .165 .575 r
.28582 .42458 .28646 .43054 .27438 .6172 .2871 .42766 Mtetra
0 0 .185 r
.2871 .42766 .27438 .6172 .27499 .63087 .27427 .62507 Mtetra
0 0 .229 r
.27427 .62507 .27499 .63087 .27639 .63386 .27537 .63201 Mtetra
.262 .412 .825 r
.27537 .63201 .27639 .63386 .27797 .63424 .27693 .63286 Mtetra
.636 .674 .869 r
.27693 .63286 .27797 .63424 .27962 .63377 .27857 .63241 Mtetra
.715 .702 .837 r
.27857 .63241 .27962 .63377 .28129 .63301 .28025 .6315 Mtetra
.669 .667 .839 r
.28025 .6315 .28129 .63301 .28294 .63254 .28191 .63085 Mtetra
.644 .634 .825 r
.28191 .63085 .28294 .63254 .28458 .63219 .28357 .63033 Mtetra
.64 .614 .808 r
.28357 .63033 .28458 .63219 .28623 .63179 .28522 .6298 Mtetra
.63 .597 .798 r
.28522 .6298 .28623 .63179 .28789 .63122 .28688 .62933 Mtetra
.629 .605 .807 r
.28688 .62933 .28789 .63122 .28955 .63057 .28853 .62887 Mtetra
.632 .628 .829 r
.28853 .62887 .28955 .63057 .29122 .62991 .29018 .62842 Mtetra
.636 .657 .854 r
.29018 .62842 .29122 .62991 .29287 .62949 .29184 .62796 Mtetra
.638 .653 .848 r
.29184 .62796 .29287 .62949 .29452 .62909 .2935 .62749 Mtetra
.643 .646 .837 r
.2935 .62749 .29452 .62909 .29619 .62846 .29516 .62698 Mtetra
.585 .638 .87 r
.29516 .62698 .29619 .62846 .2979 .62722 .2968 .62676 Mtetra
.548 .843 .998 r
.2968 .62676 .2979 .62722 .29966 .62519 .29845 .62638 Mtetra
0 0 0 r
.29845 .62638 .29966 .62519 .30152 .62174 .30015 .62537 Mtetra
.30015 .62537 .30152 .62174 .31531 .43283 .30205 .62128 Mtetra
0 0 .185 r
.30205 .62128 .31531 .43283 .31779 .41802 .31643 .42277 Mtetra
.837 .798 .304 r
.31643 .42277 .31779 .41802 .31955 .4145 .3185 .41449 Mtetra
.904 .927 .821 r
.3185 .41449 .31955 .4145 .32118 .41306 .32016 .4125 Mtetra
.671 .843 .966 r
.32016 .4125 .32118 .41306 .32275 .41248 .32173 .4119 Mtetra
.481 .779 .997 r
.32173 .4119 .32275 .41248 .3243 .41223 .32328 .41174 Mtetra
.568 .835 .996 r
.32328 .41174 .3243 .41223 .32586 .41193 .32484 .41137 Mtetra
.655 .839 .971 r
.32484 .41137 .32586 .41193 .32742 .41157 .32642 .41081 Mtetra
.666 .795 .943 r
.32642 .41081 .32742 .41157 .32899 .41118 .32799 .41026 Mtetra
.672 .759 .916 r
.32799 .41026 .32899 .41118 .33057 .41049 .32957 .40969 Mtetra
.671 .786 .935 r
.32957 .40969 .33057 .41049 .33216 .4097 .33115 .40911 Mtetra
.655 .835 .969 r
.33115 .40911 .33216 .4097 .33374 .40912 .33272 .40856 Mtetra
.722 .855 .945 r
.33272 .40856 .33374 .40912 .33529 .4091 .33432 .40778 Mtetra
.688 .69 .847 r
.33432 .40778 .33529 .4091 .33679 .40982 .33591 .40708 Mtetra
.578 .504 .736 r
.33591 .40708 .33679 .40982 .33823 .41173 .33746 .4069 Mtetra
.296 .24 .623 r
.33746 .4069 .33823 .41173 .33901 .42523 .33889 .40907 Mtetra
.969 .707 .481 r
.33889 .40907 .33901 .42523 .32987 .61372 .32933 .60368 Mtetra
0 0 .286 r
.32933 .60368 .32987 .61372 .33135 .61682 .33037 .61453 Mtetra
.102 .256 .737 r
.33037 .61453 .33135 .61682 .33297 .61739 .33194 .61606 Mtetra
.604 .672 .888 r
.33194 .61606 .33297 .61739 .33466 .61681 .33361 .61574 Mtetra
.714 .752 .882 r
.33361 .61574 .33466 .61681 .33637 .61588 .33531 .6149 Mtetra
.692 .767 .909 r
.33531 .6149 .33637 .61588 .33805 .61533 .33701 .6142 Mtetra
.643 .723 .906 r
.33701 .6142 .33805 .61533 .33973 .6151 .3387 .61371 Mtetra
.648 .681 .868 r
.3387 .61371 .33973 .6151 .34141 .61465 .34039 .6132 Mtetra
.595 .65 .874 r
.34039 .6132 .34141 .61465 .34313 .61359 .34206 .61292 Mtetra
.548 .796 .99 r
.34206 .61292 .34313 .61359 .34489 .6117 .34374 .61263 Mtetra
0 0 0 r
.34374 .61263 .34489 .6117 .34672 .60853 .34545 .61175 Mtetra
.34545 .61175 .34672 .60853 .34901 .59635 .34729 .60847 Mtetra
.966 .707 .492 r
.34729 .60847 .34901 .59635 .36046 .40423 .35894 .41376 Mtetra
0 0 0 r
.35894 .41376 .36046 .40423 .36223 .40034 .36118 .40064 Mtetra
.94 .944 .761 r
.36118 .40064 .36223 .40034 .36387 .39874 .36288 .39808 Mtetra
.708 .829 .94 r
.36288 .39808 .36387 .39874 .36546 .39827 .36448 .39735 Mtetra
.568 .731 .951 r
.36448 .39735 .36546 .39827 .36704 .39816 .36606 .39712 Mtetra
.587 .709 .927 r
.36606 .39712 .36704 .39816 .36862 .39796 .36765 .39686 Mtetra
.644 .716 .9 r
.36765 .39686 .36862 .39796 .37021 .3975 .36924 .39639 Mtetra
.643 .715 .9 r
.36924 .39639 .37021 .3975 .37181 .39698 .37084 .39593 Mtetra
.65 .729 .907 r
.37084 .39593 .37181 .39698 .37342 .39637 .37244 .39544 Mtetra
.658 .757 .923 r
.37244 .39544 .37342 .39637 .37502 .39568 .37404 .39491 Mtetra
.659 .794 .947 r
.37404 .39491 .37502 .39568 .37663 .39499 .37564 .39437 Mtetra
.653 .831 .968 r
.37564 .39437 .37663 .39499 .37824 .39435 .37724 .39382 Mtetra
.646 .853 .979 r
.37724 .39382 .37824 .39435 .37984 .39377 .37885 .39327 Mtetra
.645 .858 .981 r
.37885 .39327 .37984 .39377 .38145 .39324 .38045 .39271 Mtetra
.648 .853 .978 r
.38045 .39271 .38145 .39324 .38305 .39276 .38206 .39215 Mtetra
.657 .833 .968 r
.38206 .39215 .38305 .39276 .38465 .39234 .38367 .39158 Mtetra
.666 .799 .946 r
.38367 .39158 .38465 .39234 .38626 .39193 .38528 .39101 Mtetra
.672 .765 .92 r
.38528 .39101 .38626 .39193 .38786 .39146 .38689 .39043 Mtetra
.675 .741 .9 r
.38689 .39043 .38786 .39146 .38947 .39092 .3885 .38983 Mtetra
.673 .729 .892 r
.3885 .38983 .38947 .39092 .39108 .39032 .39012 .38923 Mtetra
.669 .729 .894 r
.39012 .38923 .39108 .39032 .3927 .38964 .39173 .38865 Mtetra
.665 .748 .912 r
.39173 .38865 .3927 .38964 .39432 .38889 .39334 .3881 Mtetra
.661 .791 .944 r
.39334 .3881 .39432 .38889 .39594 .38814 .39496 .38755 Mtetra
.714 .849 .947 r
.39496 .38755 .39594 .38814 .39757 .38732 .39658 .38678 Mtetra
.747 .866 .934 r
.39658 .38678 .39757 .38732 .39919 .3865 .39821 .38587 Mtetra
.613 .818 .979 r
.39821 .38587 .39919 .3865 .40081 .38603 .39982 .38543 Mtetra
.518 0 0 r
.39982 .38543 .40081 .38603 .40238 .38661 .40138 .38664 Mtetra
.933 .609 .401 r
.40138 .38664 .40238 .38661 .40386 .38971 .40261 .39632 Mtetra
.946 .674 .491 r
.40261 .39632 .40386 .38971 .39829 .58267 .39683 .59329 Mtetra
.611 .342 .485 r
.39683 .59329 .39829 .58267 .39968 .59112 .39844 .59582 Mtetra
.499 .196 .383 r
.39844 .59582 .39968 .59112 .40139 .59079 .40015 .59561 Mtetra
.446 .149 .367 r
.40015 .59561 .40139 .59079 .40314 .5898 .40189 .5948 Mtetra
.449 .155 .373 r
.40189 .5948 .40314 .5898 .40482 .5903 .40363 .59398 Mtetra
.463 .14 .333 r
.40363 .59398 .40482 .5903 .40646 .59242 .40536 .59358 Mtetra
.258 0 0 r
.40536 .59358 .40646 .59242 .40813 .59376 .40709 .59317 Mtetra
.599 .837 .989 r
.40709 .59317 .40813 .59376 .40982 .59423 .40882 .5927 Mtetra
.65 .665 .851 r
.40882 .5927 .40982 .59423 .41155 .59387 .41055 .59215 Mtetra
.649 .64 .827 r
.41055 .59215 .41155 .59387 .41329 .59328 .41229 .59157 Mtetra
.615 .627 .839 r
.41229 .59157 .41329 .59328 .41502 .59277 .41402 .59119 Mtetra
.559 .619 .868 r
.41402 .59119 .41502 .59277 .41675 .59253 .41574 .59107 Mtetra
.659 .679 .858 r
.41574 .59107 .41675 .59253 .41849 .59195 .41748 .59048 Mtetra
.816 .722 .761 r
.41748 .59048 .41849 .59195 .42026 .59043 .41927 .58835 Mtetra
.908 .695 .603 r
.41927 .58835 .42026 .59043 .4221 .58663 .42126 .57972 Mtetra
.951 .683 .493 r
.42126 .57972 .4221 .58663 .42419 .5741 .42898 .37923 Mtetra
.551 .331 .534 r
.42898 .37923 .42419 .5741 .43155 .38065 .43072 .37533 Mtetra
.619 .458 .643 r
.43072 .37533 .43155 .38065 .43327 .3773 .43237 .37431 Mtetra
.606 .51 .72 r
.43237 .37431 .43327 .3773 .43494 .37535 .434 .37388 Mtetra
.597 .638 .862 r
.434 .37388 .43494 .37535 .4366 .37411 .43564 .37361 Mtetra
.622 .858 .987 r
.43564 .37361 .4366 .37411 .43824 .37344 .43727 .37309 Mtetra
.577 .88 .993 r
.43727 .37309 .43824 .37344 .43988 .37302 .43891 .37259 Mtetra
.597 .87 .993 r
.43891 .37259 .43988 .37302 .44151 .37269 .44055 .3721 Mtetra
.64 .84 .977 r
.44055 .3721 .44151 .37269 .44315 .37229 .4422 .37156 Mtetra
.655 .808 .956 r
.4422 .37156 .44315 .37229 .44479 .3719 .44384 .37101 Mtetra
.666 .772 .929 r
.44384 .37101 .44479 .3719 .44643 .37147 .44548 .37044 Mtetra
.672 .744 .905 r
.44548 .37044 .44643 .37147 .44808 .37094 .44713 .36984 Mtetra
.672 .73 .894 r
.44713 .36984 .44808 .37094 .44972 .37035 .44878 .36924 Mtetra
.67 .727 .893 r
.44878 .36924 .44972 .37035 .45137 .36969 .45043 .36864 Mtetra
.665 .74 .906 r
.45043 .36864 .45137 .36969 .45303 .36893 .45208 .36808 Mtetra
.662 .781 .937 r
.45208 .36808 .45303 .36893 .45468 .36817 .45373 .36751 Mtetra
.687 .835 .955 r
.45373 .36751 .45468 .36817 .45633 .36739 .45538 .36684 Mtetra
.759 .874 .93 r
.45538 .36684 .45633 .36739 .45799 .3665 .45704 .36586 Mtetra
.654 .831 .968 r
.45704 .36586 .45799 .3665 .45964 .36593 .45869 .36529 Mtetra
0 .478 .859 r
.45869 .36529 .45964 .36593 .46128 .36612 .46032 .36584 Mtetra
.925 .556 .3 r
.46032 .36584 .46128 .36612 .46287 .36869 .46185 .37185 Mtetra
.956 .679 .47 r
.46185 .37185 .46287 .36869 .46427 .38186 .45963 .57298 Mtetra
.549 .325 .528 r
.45963 .57298 .46427 .38186 .46242 .57213 .46132 .5767 Mtetra
.514 .206 .383 r
.46132 .5767 .46242 .57213 .46417 .57249 .46307 .57668 Mtetra
.441 .133 .346 r
.46307 .57668 .46417 .57249 .46594 .57157 .46485 .57596 Mtetra
.418 .117 .345 r
.46485 .57596 .46594 .57157 .46773 .57004 .46662 .57498 Mtetra
.471 .174 .379 r
.46662 .57498 .46773 .57004 .46951 .56888 .4684 .5744 Mtetra
.48 .19 .396 r
.4684 .5744 .46951 .56888 .47127 .56827 .47017 .57383 Mtetra
.483 .194 .398 r
.47017 .57383 .47127 .56827 .47302 .56895 .47194 .5733 Mtetra
.474 .166 .363 r
.47194 .5733 .47302 .56895 .47475 .57127 .47371 .57287 Mtetra
.339 0 .077 r
.47371 .57287 .47475 .57127 .4765 .57278 .47549 .57245 Mtetra
.51 .865 .989 r
.47549 .57245 .4765 .57278 .47826 .57352 .47726 .57201 Mtetra
.64 .668 .861 r
.47726 .57201 .47826 .57352 .48003 .57317 .47904 .57151 Mtetra
.642 .646 .839 r
.47904 .57151 .48003 .57317 .48181 .57259 .48082 .57097 Mtetra
.646 .655 .844 r
.48082 .57097 .48181 .57259 .48359 .57195 .4826 .57042 Mtetra
.65 .669 .855 r
.4826 .57042 .48359 .57195 .48537 .57158 .48438 .56985 Mtetra
.646 .641 .831 r
.48438 .56985 .48537 .57158 .48715 .57123 .48617 .56929 Mtetra
.639 .615 .809 r
.48617 .56929 .48715 .57123 .48893 .57084 .48795 .56873 Mtetra
.63 .594 .795 r
.48795 .56873 .48893 .57084 .49072 .57035 .48973 .56821 Mtetra
.629 .591 .793 r
.48973 .56821 .49072 .57035 .4925 .56983 .49152 .5677 Mtetra
.629 .593 .794 r
.49152 .5677 .4925 .56983 .49429 .56929 .49331 .56719 Mtetra
.634 .598 .795 r
.49331 .56719 .49429 .56929 .49608 .56877 .4951 .56664 Mtetra
.633 .594 .792 r
.4951 .56664 .49608 .56877 .49787 .56823 .49688 .5661 Mtetra
.632 .593 .792 r
.49688 .5661 .49787 .56823 .49966 .56766 .49868 .56556 Mtetra
.624 .593 .797 r
.49868 .56556 .49966 .56766 .50145 .56713 .50047 .56508 Mtetra
.627 .598 .802 r
.50047 .56508 .50145 .56713 .50324 .56645 .50226 .56459 Mtetra
.635 .623 .82 r
.50226 .56459 .50324 .56645 .50504 .56547 .50405 .56407 Mtetra
.666 .696 .868 r
.50405 .56407 .50504 .56547 .50684 .56345 .50585 .56343 Mtetra
.495 .901 .914 r
.50585 .56343 .50684 .56345 .50865 .56076 .50765 .56276 Mtetra
.329 0 .137 r
.50765 .56276 .50865 .56076 .51046 .55741 .50945 .56211 Mtetra
.471 .17 .372 r
.50945 .56211 .51046 .55741 .51225 .55613 .51124 .56157 Mtetra
.484 .193 .395 r
.51124 .56157 .51225 .55613 .51405 .55576 .51304 .56105 Mtetra
.482 .189 .391 r
.51304 .56105 .51405 .55576 .51584 .55583 .51485 .56054 Mtetra
.511 .206 .385 r
.51485 .56054 .51584 .55583 .51764 .55622 .51665 .56048 Mtetra
.47 .161 .358 r
.51665 .56048 .51764 .55622 .51944 .55584 .51845 .56002 Mtetra
.383 .082 .325 r
.51845 .56002 .51944 .55584 .52124 .55404 .52026 .55878 Mtetra
0 0 .047 r
.52026 .55878 .52124 .55404 .52315 .3557 .52207 .55269 Mtetra
0 0 .324 r
.52207 .55269 .52315 .3557 .52485 .34687 .52393 .34883 Mtetra
.92 .865 .429 r
.52393 .34883 .52485 .34687 .52654 .34353 .52563 .34308 Mtetra
.806 .906 .911 r
.52563 .34308 .52654 .34353 .52824 .34248 .52732 .34183 Mtetra
.624 .828 .979 r
.52732 .34183 .52824 .34248 .52993 .34195 .52902 .34133 Mtetra
.458 .77 .997 r
.52902 .34133 .52993 .34195 .53163 .3417 .53072 .34119 Mtetra
.632 .867 .986 r
.53072 .34119 .53163 .3417 .53333 .34129 .53241 .34062 Mtetra
.659 .831 .966 r
.53241 .34062 .53333 .34129 .53502 .34089 .53411 .34002 Mtetra
.667 .785 .937 r
.53411 .34002 .53502 .34089 .53672 .34045 .53581 .33942 Mtetra
.669 .751 .912 r
.53581 .33942 .53672 .34045 .53842 .33962 .53751 .33882 Mtetra
.663 .802 .949 r
.53751 .33882 .53842 .33962 .54012 .33885 .53922 .33822 Mtetra
.645 .842 .976 r
.53922 .33822 .54012 .33885 .54183 .33832 .54092 .33765 Mtetra
.631 .826 .975 r
.54092 .33765 .54183 .33832 .54354 .33888 .54262 .33713 Mtetra
.637 .624 .821 r
.54262 .33713 .54354 .33888 .54525 .34016 .54433 .33663 Mtetra
.605 .491 .697 r
.54433 .33663 .54525 .34016 .54698 .34223 .54604 .33613 Mtetra
.609 .442 .631 r
.54604 .33613 .54698 .34223 .54869 .34168 .54774 .33512 Mtetra
.592 .426 .625 r
.54774 .33512 .54869 .34168 .5504 .34072 .54945 .33438 Mtetra
.558 .404 .629 r
.54945 .33438 .5504 .34072 .55211 .34071 .55116 .33429 Mtetra
.249 .187 .588 r
.55116 .33429 .55211 .34071 .55562 .53654 .55291 .33799 Mtetra
0 0 .353 r
.55291 .33799 .55562 .53654 .55754 .54606 .55654 .54087 Mtetra
0 0 .456 r
.55654 .54087 .55754 .54606 .5594 .54878 .55843 .54688 Mtetra
.392 .49 .84 r
.55843 .54688 .5594 .54878 .56124 .5491 .56027 .54749 Mtetra
.63 .654 .854 r
.56027 .54749 .56124 .5491 .56308 .5486 .56211 .54701 Mtetra
.703 .687 .832 r
.56211 .54701 .56308 .5486 .5649 .54755 .56394 .54607 Mtetra
.593 .657 .882 r
.56394 .54607 .5649 .54755 .56673 .54606 .56577 .54578 Mtetra
.517 .883 .978 r
.56577 .54578 .56673 .54606 .56854 .54381 .56761 .54526 Mtetra
.031 0 0 r
.56761 .54526 .56854 .54381 .57033 .5399 .56944 .54402 Mtetra
0 0 .072 r
.56944 .54402 .57033 .5399 .56938 .34105 .57121 .53892 Mtetra
0 0 .347 r
.57121 .53892 .56938 .34105 .57097 .33139 .57013 .3346 Mtetra
.748 .736 .214 r
.57013 .3346 .57097 .33139 .57265 .32805 .57176 .32777 Mtetra
.865 .942 .867 r
.57176 .32777 .57265 .32805 .57436 .32678 .57347 .32611 Mtetra
.647 .835 .973 r
.57347 .32611 .57436 .32678 .57609 .3262 .5752 .32553 Mtetra
.485 .773 .995 r
.5752 .32553 .57609 .3262 .57782 .32592 .57693 .32536 Mtetra
.607 .848 .99 r
.57693 .32536 .57782 .32592 .57954 .32555 .57866 .32486 Mtetra
.659 .833 .967 r
.57866 .32486 .57954 .32555 .58127 .32513 .58038 .32425 Mtetra
.668 .788 .938 r
.58038 .32425 .58127 .32513 .583 .32467 .58211 .32363 Mtetra
.673 .754 .912 r
.58211 .32363 .583 .32467 .58473 .32387 .58384 .323 Mtetra
.67 .792 .94 r
.58384 .323 .58473 .32387 .58645 .32305 .58557 .32238 Mtetra
.652 .836 .971 r
.58557 .32238 .58645 .32305 .58819 .32245 .5873 .32178 Mtetra
.729 .856 .941 r
.5873 .32178 .58819 .32245 .58993 .32252 .58903 .3209 Mtetra
.669 .657 .829 r
.58903 .3209 .58993 .32252 .59169 .32335 .59076 .32021 Mtetra
.565 .483 .721 r
.59076 .32021 .59169 .32335 .59349 .3256 .59251 .32011 Mtetra
.284 .228 .617 r
.59251 .32011 .59349 .3256 .59962 .52151 .59432 .32306 Mtetra
0 0 .372 r
.59432 .32306 .59962 .52151 .60173 .53244 .60066 .52555 Mtetra
0 0 .469 r
.60066 .52555 .60173 .53244 .60367 .53513 .6027 .533 Mtetra
.31 .415 .807 r
.6027 .533 .60367 .53513 .60555 .53551 .60459 .53401 Mtetra
.618 .666 .875 r
.60459 .53401 .60555 .53551 .60741 .53493 .60646 .5336 Mtetra
.71 .73 .866 r
.60646 .5336 .60741 .53493 .60926 .53378 .60831 .53269 Mtetra
.606 .735 .936 r
.60831 .53269 .60926 .53378 .6111 .53233 .61018 .53229 Mtetra
.33 .812 .87 r
.61018 .53229 .6111 .53233 .61293 .5303 .61205 .53185 Mtetra
.135 0 0 r
.61205 .53185 .61293 .5303 .61471 .52691 .61391 .53077 Mtetra
0 0 .137 r
.61391 .53077 .61471 .52691 .61133 .33462 .61568 .52661 Mtetra
0 0 .357 r
.61568 .52661 .61133 .33462 .61264 .3179 .61194 .32342 Mtetra
0 0 .022 r
.61194 .32342 .61264 .3179 .6143 .31423 .61345 .31423 Mtetra
.909 .972 .798 r
.61345 .31423 .6143 .31423 .61602 .31285 .61515 .31208 Mtetra
.686 .826 .95 r
.61515 .31208 .61602 .31285 .61778 .31238 .6169 .31138 Mtetra
.567 .726 .949 r
.6169 .31138 .61778 .31238 .61954 .31224 .61866 .31113 Mtetra
.621 .724 .92 r
.61866 .31113 .61954 .31224 .6213 .31187 .62042 .31071 Mtetra
.657 .727 .901 r
.62042 .31071 .6213 .31187 .62305 .31129 .62217 .31014 Mtetra
.656 .728 .902 r
.62217 .31014 .62305 .31129 .62481 .31066 .62393 .30957 Mtetra
.73 .766 .882 r
.62393 .30957 .62481 .31066 .62655 .30957 .62568 .30863 Mtetra
.726 .797 .908 r
.62568 .30863 .62655 .30957 .62829 .30853 .62742 .30774 Mtetra
.566 .779 .979 r
.62742 .30774 .62829 .30853 .63005 .30809 .62919 .30742 Mtetra
.687 .175 0 r
.62919 .30742 .63005 .30809 .63191 .31035 .63105 .3097 Mtetra
.973 .679 .401 r
.63105 .3097 .63191 .31035 .64072 .51274 .63976 .51085 Mtetra
.931 .577 .152 r
.63976 .51085 .64072 .51274 .64296 .52243 .64201 .52075 Mtetra
.077 .327 .805 r
.64201 .52075 .64296 .52243 .64491 .52371 .64396 .52216 Mtetra
.614 .66 .871 r
.64396 .52216 .64491 .52371 .6468 .52312 .64586 .52176 Mtetra
.71 .728 .864 r
.64586 .52176 .6468 .52312 .64866 .52199 .64774 .52083 Mtetra
.622 .732 .925 r
.64774 .52083 .64866 .52199 .65056 .52154 .64963 .52037 Mtetra
.577 .71 .933 r
.64963 .52037 .65056 .52154 .65247 .52142 .65153 .52008 Mtetra
.705 .731 .871 r
.65153 .52008 .65247 .52142 .65435 .52068 .65341 .51919 Mtetra
.887 .751 .706 r
.65341 .51919 .65435 .52068 .65614 .51724 .6552 .51575 Mtetra
.975 .686 .41 r
.6552 .51575 .65614 .51724 .65004 .31624 .64926 .3174 Mtetra
.996 .763 .435 r
.64926 .3174 .65004 .31624 .65129 .30259 .65045 .30207 Mtetra
.929 .879 .766 r
.65045 .30207 .65129 .30259 .65298 .30012 .65214 .29947 Mtetra
.692 .861 .962 r
.65214 .29947 .65298 .30012 .65476 .29954 .65391 .29871 Mtetra
.545 .761 .977 r
.65391 .29871 .65476 .29954 .65656 .2995 .6557 .29846 Mtetra
.596 .731 .939 r
.6557 .29846 .65656 .2995 .65835 .29928 .65748 .29812 Mtetra
.655 .729 .903 r
.65748 .29812 .65835 .29928 .66012 .29871 .65926 .29755 Mtetra
.656 .73 .904 r
.65926 .29755 .66012 .29871 .6619 .29807 .66104 .29698 Mtetra
.721 .765 .888 r
.66104 .29698 .6619 .29807 .66366 .29704 .66281 .29608 Mtetra
.737 .798 .901 r
.66281 .29608 .66366 .29704 .66542 .29593 .66457 .29513 Mtetra
.602 .79 .971 r
.66457 .29513 .66542 .29593 .6672 .29539 .66636 .2947 Mtetra
.515 0 0 r
.66636 .2947 .6672 .29539 .66909 .29711 .66825 .29644 Mtetra
.975 .676 .383 r
.66825 .29644 .66909 .29711 .68018 .49543 .67919 .49251 Mtetra
.939 .612 .173 r
.67919 .49251 .68018 .49543 .6828 .50988 .68186 .50815 Mtetra
0 .212 .736 r
.68186 .50815 .6828 .50988 .68483 .51175 .68389 .51006 Mtetra
.594 .632 .859 r
.68389 .51006 .68483 .51175 .68675 .51134 .68582 .50976 Mtetra
.694 .691 .843 r
.68582 .50976 .68675 .51134 .68864 .51017 .68772 .50887 Mtetra
.659 .722 .895 r
.68772 .50887 .68864 .51017 .69051 .50862 .68964 .50823 Mtetra
.44 .833 .983 r
.68964 .50823 .69051 .50862 .69236 .50673 .69157 .50789 Mtetra
.1 0 0 r
.69157 .50789 .69236 .50673 .69416 .50376 .69347 .50698 Mtetra
.025 0 .161 r
.69347 .50698 .69416 .50376 .69568 .49546 .69526 .5039 Mtetra
.73 .618 .051 r
.69526 .5039 .69568 .49546 .68716 .29444 .69618 .48382 Mtetra
0 0 .397 r
.69618 .48382 .68716 .29444 .68875 .28985 .68794 .28963 Mtetra
.96 .913 .723 r
.68794 .28963 .68875 .28985 .69046 .28775 .68961 .28661 Mtetra
.718 .759 .885 r
.68961 .28661 .69046 .28775 .69224 .28685 .6914 .28572 Mtetra
.604 .718 .925 r
.6914 .28572 .69224 .28685 .69405 .28646 .69321 .28535 Mtetra
.648 .742 .918 r
.69321 .28535 .69405 .28646 .69588 .28646 .69501 .28481 Mtetra
.694 .67 .822 r
.69501 .28481 .69588 .28646 .69774 .28691 .6968 .28393 Mtetra
.599 .514 .73 r
.6968 .28393 .69774 .28691 .69966 .28828 .69861 .28353 Mtetra
.435 .349 .661 r
.69861 .28353 .69966 .28828 .70181 .29372 .70053 .2849 Mtetra
0 0 .401 r
.70053 .2849 .70181 .29372 .7152 .49499 .70304 .29679 Mtetra
.001 0 .415 r
.70304 .29679 .7152 .49499 .71741 .49921 .71645 .49699 Mtetra
0 .125 .669 r
.71645 .49699 .71741 .49921 .71946 .50061 .71857 .49962 Mtetra
.416 .673 .968 r
.71857 .49962 .71946 .50061 .72143 .50065 .72055 .49974 Mtetra
.726 .825 .927 r
.72055 .49974 .72143 .50065 .72335 .49977 .72247 .49878 Mtetra
.908 .823 .751 r
.72247 .49878 .72335 .49977 .72516 .49698 .72427 .49589 Mtetra
.978 .742 .51 r
.72427 .49589 .72516 .49698 .72644 .48547 .72555 .48433 Mtetra
.977 .681 .378 r
.72555 .48433 .72644 .48547 .7159 .28209 .71506 .28094 Mtetra
.919 .787 .698 r
.71506 .28094 .7159 .28209 .71753 .27862 .7167 .27747 Mtetra
.72 .761 .885 r
.7167 .27747 .71753 .27862 .71933 .27771 .71849 .27657 Mtetra
.598 .713 .924 r
.71849 .27657 .71933 .27771 .72116 .27737 .72033 .27622 Mtetra
.634 .728 .916 r
.72033 .27622 .72116 .27737 .72298 .27688 .72215 .27573 Mtetra
.74 .767 .875 r
.72215 .27573 .72298 .27688 .72478 .27585 .72394 .2747 Mtetra
.652 .736 .911 r
.72394 .2747 .72478 .27585 .7266 .27528 .72576 .27413 Mtetra
.113 .433 .873 r
.72576 .27413 .7266 .27528 .72852 .27622 .72769 .27507 Mtetra
.906 .522 .09 r
.72769 .27507 .72852 .27622 .7309 .28406 .73007 .28291 Mtetra
.975 .671 .352 r
.73007 .28291 .7309 .28406 .74645 .48849 .74557 .48739 Mtetra
.601 .138 0 r
.74557 .48739 .74645 .48849 .74864 .49143 .74776 .49034 Mtetra
.553 .722 .952 r
.74776 .49034 .74864 .49143 .75062 .49119 .74975 .4901 Mtetra
.713 .786 .909 r
.74975 .4901 .75062 .49119 .75256 .49028 .75169 .48919 Mtetra
.696 .781 .917 r
.75169 .48919 .75256 .49028 .75451 .48946 .75363 .48836 Mtetra
.51 .701 .956 r
.75363 .48836 .75451 .48946 .7565 .48935 .75563 .48826 Mtetra
.654 .766 .931 r
.75563 .48826 .7565 .48935 .75846 .48873 .75759 .48764 Mtetra
.869 .817 .796 r
.75759 .48764 .75846 .48873 .76031 .48648 .75944 .48538 Mtetra
.98 .75 .517 r
.75944 .48538 .76031 .48648 .76158 .47623 .76071 .47514 Mtetra
.977 .678 .362 r
.76071 .47514 .76158 .47623 .74875 .27125 .74793 .2701 Mtetra
.933 .789 .679 r
.74793 .2701 .74875 .27125 .75035 .26743 .74953 .26627 Mtetra
.726 .765 .883 r
.74953 .26627 .75035 .26743 .75217 .26647 .75134 .26532 Mtetra
.601 .715 .925 r
.75134 .26532 .75217 .26647 .75402 .26611 .7532 .26496 Mtetra
.6 .714 .925 r
.7532 .26496 .75402 .26611 .75588 .26575 .75506 .2646 Mtetra
.739 .769 .877 r
.75506 .2646 .75588 .26575 .75769 .26472 .75687 .26357 Mtetra
.656 .739 .911 r
.75687 .26357 .75769 .26472 .75953 .26413 .75871 .26298 Mtetra
.231 .508 .907 r
.75871 .26298 .75953 .26413 .76147 .26483 .76065 .26368 Mtetra
.884 .492 .038 r
.76065 .26368 .76147 .26483 .76392 .27212 .76311 .27098 Mtetra
.975 .667 .334 r
.76311 .27098 .76392 .27212 .78183 .47773 .78097 .47663 Mtetra
.655 .201 0 r
.78097 .47663 .78183 .47773 .78412 .48118 .78326 .48008 Mtetra
.382 .631 .952 r
.78326 .48008 .78412 .48118 .78617 .48145 .78531 .48035 Mtetra
.693 .78 .919 r
.78531 .48035 .78617 .48145 .78814 .48064 .78728 .47953 Mtetra
.873 .82 .793 r
.78728 .47953 .78814 .48064 .78999 .47833 .78913 .47723 Mtetra
.978 .767 .552 r
.78913 .47723 .78999 .47833 .79139 .47049 .79054 .46939 Mtetra
.977 .675 .347 r
.79054 .46939 .79139 .47049 .77649 .26283 .77568 .26167 Mtetra
.951 .785 .641 r
.77568 .26167 .77649 .26283 .77802 .25824 .77721 .25708 Mtetra
.745 .772 .875 r
.77721 .25708 .77802 .25824 .77983 .25717 .77902 .256 Mtetra
.617 .722 .921 r
.77902 .256 .77983 .25717 .7817 .25674 .7809 .25557 Mtetra
.584 .707 .927 r
.7809 .25557 .7817 .25674 .78358 .25644 .78278 .25527 Mtetra
.747 .773 .874 r
.78278 .25527 .78358 .25644 .7854 .25535 .7846 .25418 Mtetra
.67 .744 .906 r
.7846 .25418 .7854 .25535 .78726 .25469 .78645 .25352 Mtetra
.351 .581 .929 r
.78645 .25352 .78726 .25469 .78921 .2551 .7884 .25394 Mtetra
.837 .432 0 r
.7884 .25394 .78921 .2551 .79165 .26121 .79085 .26006 Mtetra
.973 .663 .318 r
.79085 .26006 .79165 .26121 .81159 .46805 .81075 .46695 Mtetra
.696 .249 0 r
.81075 .46695 .81159 .46805 .81399 .47201 .81314 .47091 Mtetra
.348 .611 .948 r
.81314 .47091 .81399 .47201 .81608 .47238 .81523 .47127 Mtetra
.676 .774 .924 r
.81523 .47127 .81608 .47238 .81807 .47163 .81723 .47052 Mtetra
.858 .823 .812 r
.81723 .47052 .81807 .47163 .81994 .46948 .8191 .46843 Mtetra
.98 .778 .56 r
.8191 .46843 .81994 .46948 .82129 .46158 .82052 .46128 Mtetra
.976 .672 .329 r
.82052 .46128 .82129 .46158 .8044 .25308 .80367 .25269 Mtetra
.993 .844 .587 r
.80367 .25269 .8044 .25308 .80589 .24834 .80514 .2476 Mtetra
.762 .873 .928 r
.80514 .2476 .80589 .24834 .80773 .24738 .80697 .24651 Mtetra
.592 .78 .97 r
.80697 .24651 .80773 .24738 .80964 .2471 .80886 .2461 Mtetra
.509 .708 .961 r
.80886 .2461 .80964 .2471 .81157 .24714 .81078 .24599 Mtetra
.662 .748 .914 r
.81078 .24599 .81157 .24714 .81345 .24657 .81266 .24536 Mtetra
.665 .736 .903 r
.81266 .24536 .81345 .24657 .81533 .24593 .81453 .24471 Mtetra
.673 .738 .899 r
.81453 .24471 .81533 .24593 .8172 .24518 .81641 .24403 Mtetra
.751 .78 .877 r
.81641 .24403 .8172 .24518 .81901 .24385 .81824 .24291 Mtetra
.678 .801 .94 r
.81824 .24291 .81901 .24385 .82086 .24294 .82011 .2422 Mtetra
.344 .686 .98 r
.82011 .2422 .82086 .24294 .8228 .24287 .82207 .24234 Mtetra
.852 .415 0 r
.82207 .24234 .8228 .24287 .82519 .24746 .82454 .24767 Mtetra
.971 .657 .303 r
.82454 .24767 .82519 .24746 .84765 .45578 .84688 .45525 Mtetra
.81 .346 0 r
.84688 .45525 .84765 .45578 .85024 .46091 .84941 .45977 Mtetra
.307 .579 .937 r
.84941 .45977 .85024 .46091 .85238 .46144 .85155 .46027 Mtetra
.647 .754 .927 r
.85155 .46027 .85238 .46144 .85441 .46082 .85358 .45966 Mtetra
.825 .814 .839 r
.85358 .45966 .85441 .46082 .85632 .45903 .8555 .45789 Mtetra
.975 .788 .588 r
.8555 .45789 .85632 .45903 .8578 .45296 .85698 .45182 Mtetra
.974 .667 .312 r
.85698 .45182 .8578 .45296 .8385 .24382 .83772 .24263 Mtetra
.974 .774 .573 r
.83772 .24263 .8385 .24382 .83982 .23759 .83904 .23641 Mtetra
.758 .757 .852 r
.22955 .4428 .23058 .44376 .23215 .44272 .23112 .44176 Mtetra
.604 .724 .93 r
.23112 .44176 .23215 .44272 .23365 .44241 .23262 .44145 Mtetra
.429 .656 .955 r
.23262 .44145 .23365 .44241 .23511 .44252 .23408 .44155 Mtetra
.629 .731 .921 r
.23408 .44155 .23511 .44252 .23662 .44213 .23559 .44116 Mtetra
.638 .733 .917 r
.23559 .44116 .23662 .44213 .23813 .44172 .23711 .44074 Mtetra
.648 .734 .912 r
.23711 .44074 .23813 .44172 .23965 .44127 .23863 .44028 Mtetra
.666 .736 .902 r
.23863 .44028 .23965 .44127 .24117 .44074 .24015 .43975 Mtetra
.68 .74 .896 r
.24015 .43975 .24117 .44074 .2427 .44016 .24168 .43916 Mtetra
.691 .739 .888 r
.24168 .43916 .2427 .44016 .24423 .43956 .24322 .43851 Mtetra
.709 .735 .872 r
.24322 .43851 .24423 .43956 .24577 .43894 .24477 .43776 Mtetra
.706 .711 .853 r
.24477 .43776 .24577 .43894 .2473 .43831 .24631 .437 Mtetra
.696 .687 .837 r
.24631 .437 .2473 .43831 .24884 .43769 .24786 .43625 Mtetra
.675 .664 .831 r
.24786 .43625 .24884 .43769 .25038 .43707 .2494 .43561 Mtetra
.667 .657 .831 r
.2494 .43561 .25038 .43707 .25192 .43646 .25094 .43501 Mtetra
.663 .657 .834 r
.25094 .43501 .25192 .43646 .25345 .43587 .25247 .43443 Mtetra
.663 .66 .837 r
.25247 .43443 .25345 .43587 .25499 .43529 .25401 .43386 Mtetra
.661 .66 .839 r
.25401 .43386 .25499 .43529 .25652 .43473 .25554 .43331 Mtetra
.659 .661 .84 r
.25554 .43331 .25652 .43473 .25806 .43417 .25708 .43276 Mtetra
.658 .661 .842 r
.25708 .43276 .25806 .43417 .25959 .43363 .25861 .43222 Mtetra
.657 .661 .843 r
.25861 .43222 .25959 .43363 .26113 .43309 .26015 .43169 Mtetra
.656 .662 .844 r
.26015 .43169 .26113 .43309 .26267 .43256 .26169 .43116 Mtetra
.657 .663 .844 r
.26169 .43116 .26267 .43256 .2642 .43203 .26322 .43062 Mtetra
.655 .662 .845 r
.26322 .43062 .2642 .43203 .26574 .4315 .26476 .4301 Mtetra
.651 .661 .847 r
.26476 .4301 .26574 .4315 .26728 .43097 .2663 .4296 Mtetra
.631 .659 .858 r
.2663 .4296 .26728 .43097 .26882 .43042 .26783 .4292 Mtetra
.629 .683 .881 r
.26783 .4292 .26882 .43042 .27036 .42987 .26936 .42881 Mtetra
.639 .716 .903 r
.26936 .42881 .27036 .42987 .2719 .42935 .27089 .42838 Mtetra
.685 .748 .899 r
.27089 .42838 .2719 .42935 .27344 .42889 .27244 .42776 Mtetra
.695 .719 .868 r
.27244 .42776 .27344 .42889 .27498 .42846 .274 .42707 Mtetra
.685 .675 .834 r
.274 .42707 .27498 .42846 .27651 .42801 .27556 .42637 Mtetra
.662 .634 .811 r
.27556 .42637 .27651 .42801 .27806 .42747 .27711 .42576 Mtetra
.653 .623 .807 r
.27711 .42576 .27806 .42747 .27961 .42689 .27866 .42519 Mtetra
.65 .623 .809 r
.27866 .42519 .27961 .42689 .28116 .42631 .2802 .42465 Mtetra
.688 .643 .799 r
.2802 .42465 .28116 .42631 .28274 .42539 .28177 .42385 Mtetra
.673 .652 .821 r
.28177 .42385 .28274 .42539 .2843 .42468 .28333 .42319 Mtetra
.594 .626 .853 r
.28333 .42319 .2843 .42468 .28582 .42458 .28486 .42295 Mtetra
0 .085 .643 r
.28486 .42295 .28582 .42458 .2871 .42766 .28625 .42456 Mtetra
.84 .535 0 r
.28625 .42456 .2871 .42766 .27427 .62507 .28737 .42993 Mtetra
0 0 .21 r
.28737 .42993 .27427 .62507 .27537 .63201 .27473 .62513 Mtetra
.395 .279 .603 r
.27473 .62513 .27537 .63201 .27693 .63286 .27619 .6272 Mtetra
.583 .432 .642 r
.27619 .6272 .27693 .63286 .27857 .63241 .27783 .62675 Mtetra
.63 .466 .641 r
.27783 .62675 .27857 .63241 .28025 .6315 .27954 .62548 Mtetra
.621 .454 .636 r
.27954 .62548 .28025 .6315 .28191 .63085 .28123 .62431 Mtetra
.597 .431 .628 r
.28123 .62431 .28191 .63085 .28357 .63033 .28291 .62352 Mtetra
.558 .4 .623 r
.28291 .62352 .28357 .63033 .28522 .6298 .28453 .62341 Mtetra
.422 .306 .616 r
.28453 .62341 .28522 .6298 .28688 .62933 .28603 .62508 Mtetra
.35 .3 .661 r
.28603 .62508 .28688 .62933 .28853 .62887 .28754 .62665 Mtetra
.292 .385 .786 r
.28754 .62665 .28853 .62887 .29018 .62842 .2891 .62761 Mtetra
.434 .713 .983 r
.2891 .62761 .29018 .62842 .29184 .62796 .29073 .62761 Mtetra
.563 .872 .994 r
.29073 .62761 .29184 .62796 .2935 .62749 .29238 .62715 Mtetra
.639 .895 .985 r
.29238 .62715 .2935 .62749 .29516 .62698 .29405 .62652 Mtetra
.494 .822 1 r
.29405 .62652 .29516 .62698 .2968 .62676 .2957 .62624 Mtetra
.53 .822 .999 r
.2957 .62624 .2968 .62676 .29845 .62638 .29735 .62592 Mtetra
.699 .88 .965 r
.29735 .62592 .29845 .62638 .30015 .62537 .29903 .62516 Mtetra
.917 .868 .776 r
.29903 .62516 .30015 .62537 .30205 .62128 .30084 .62254 Mtetra
.992 .858 .603 r
.30084 .62254 .30205 .62128 .31643 .42277 .30288 .61615 Mtetra
0 0 .209 r
.30288 .61615 .31643 .42277 .3185 .41449 .31713 .41927 Mtetra
.069 0 .212 r
.31713 .41927 .3185 .41449 .32016 .4125 .31888 .416 Mtetra
.453 .132 .331 r
.31888 .416 .32016 .4125 .32173 .4119 .32044 .41555 Mtetra
.5 .181 .358 r
.32044 .41555 .32173 .4119 .32328 .41174 .32199 .41546 Mtetra
.198 0 .227 r
.32199 .41546 .32328 .41174 .32484 .41137 .32366 .41346 Mtetra
0 0 0 r
.32366 .41346 .32484 .41137 .32642 .41081 .32535 .41106 Mtetra
.885 .978 .828 r
.32535 .41106 .32642 .41081 .32799 .41026 .327 .40922 Mtetra
.74 .75 .86 r
.327 .40922 .32799 .41026 .32957 .40969 .3286 .40827 Mtetra
.639 .657 .852 r
.3286 .40827 .32957 .40969 .33115 .40911 .33017 .40782 Mtetra
.609 .665 .879 r
.33017 .40782 .33115 .40911 .33272 .40856 .33174 .4075 Mtetra
.706 .739 .877 r
.33174 .4075 .33272 .40856 .33432 .40778 .33333 .40675 Mtetra
.729 .75 .869 r
.33333 .40675 .33432 .40778 .33591 .40708 .33493 .40587 Mtetra
.653 .698 .879 r
.33493 .40587 .33591 .40708 .33746 .4069 .33651 .40537 Mtetra
.161 .387 .835 r
.33651 .40537 .33746 .4069 .33889 .40907 .338 .40627 Mtetra
0 0 .339 r
.338 .40627 .33889 .40907 .32933 .60368 .33935 .40987 Mtetra
0 0 .24 r
.33935 .40987 .32933 .60368 .33037 .61453 .32976 .60568 Mtetra
.094 .041 .5 r
.32976 .60568 .33037 .61453 .33194 .61606 .33107 .61167 Mtetra
.356 .301 .658 r
.33107 .61167 .33194 .61606 .33361 .61574 .33264 .61329 Mtetra
.428 .447 .777 r
.33264 .61329 .33361 .61574 .33531 .6149 .33426 .61389 Mtetra
.533 .708 .951 r
.33426 .61389 .33531 .6149 .33701 .6142 .33593 .61375 Mtetra
.64 .875 .985 r
.33593 .61375 .33701 .6142 .3387 .61371 .33762 .61315 Mtetra
.706 .859 .955 r
.33762 .61315 .3387 .61371 .34039 .6132 .33932 .61237 Mtetra
.587 .769 .966 r
.33932 .61237 .34039 .6132 .34206 .61292 .341 .61203 Mtetra
.506 .724 .971 r
.341 .61203 .34206 .61292 .34374 .61263 .34268 .61191 Mtetra
.64 .813 .966 r
.34268 .61191 .34374 .61263 .34545 .61175 .34437 .61139 Mtetra
.882 .88 .828 r
.34437 .61139 .34545 .61175 .34729 .60847 .34614 .60939 Mtetra
.987 .888 .632 r
.34614 .60939 .34729 .60847 .35894 .41376 .34806 .60442 Mtetra
0 0 .228 r
.34806 .60442 .35894 .41376 .36118 .40064 .35981 .40718 Mtetra
0 0 .088 r
.35981 .40718 .36118 .40064 .36288 .39808 .36174 .40022 Mtetra
0 0 0 r
.36174 .40022 .36288 .39808 .36448 .39735 .36343 .39774 Mtetra
.793 .999 .821 r
.36343 .39774 .36448 .39735 .36606 .39712 .36508 .3962 Mtetra
.733 .775 .887 r
.36508 .3962 .36606 .39712 .36765 .39686 .36669 .39532 Mtetra
.63 .639 .841 r
.36669 .39532 .36765 .39686 .36924 .39639 .36829 .3949 Mtetra
.589 .628 .858 r
.36829 .3949 .36924 .39639 .37084 .39593 .36987 .39467 Mtetra
.608 .675 .888 r
.36987 .39467 .37084 .39593 .37244 .39544 .37146 .39436 Mtetra
.652 .723 .901 r
.37146 .39436 .37244 .39544 .37404 .39491 .37306 .39386 Mtetra
.661 .732 .902 r
.37306 .39386 .37404 .39491 .37564 .39437 .37467 .39332 Mtetra
.662 .733 .902 r
.37467 .39332 .37564 .39437 .37724 .39382 .37627 .39278 Mtetra
.662 .735 .904 r
.37627 .39278 .37724 .39382 .37885 .39327 .37787 .39224 Mtetra
.67 .739 .902 r
.37787 .39224 .37885 .39327 .38045 .39271 .37948 .39166 Mtetra
.686 .741 .893 r
.37948 .39166 .38045 .39271 .38206 .39215 .38109 .39101 Mtetra
.696 .727 .874 r
.38109 .39101 .38206 .39215 .38367 .39158 .38271 .39029 Mtetra
.69 .699 .853 r
.38271 .39029 .38367 .39158 .38528 .39101 .38433 .38957 Mtetra
.688 .676 .833 r
.38433 .38957 .38528 .39101 .38689 .39043 .38594 .38883 Mtetra
.678 .652 .817 r
.38594 .38883 .38689 .39043 .3885 .38983 .38756 .38811 Mtetra
.644 .624 .815 r
.38756 .38811 .3885 .38983 .39012 .38923 .38917 .38759 Mtetra
.532 .58 .849 r
.38917 .38759 .39012 .38923 .39173 .38865 .39076 .38761 Mtetra
.006 .391 .848 r
.39076 .38761 .39173 .38865 .39334 .3881 .39232 .38843 Mtetra
.709 .219 .079 r
.39232 .38843 .39334 .3881 .39496 .38755 .39386 .38981 Mtetra
.588 .221 .313 r
.39386 .38981 .39496 .38755 .39658 .38678 .39542 .39055 Mtetra
.389 .081 .317 r
.39542 .39055 .39658 .38678 .39821 .38587 .39706 .38954 Mtetra
.444 .128 .335 r
.39706 .38954 .39821 .38587 .39982 .38543 .39868 .38897 Mtetra
.715 .391 .43 r
.39868 .38897 .39982 .38543 .40138 .38664 .40016 .39199 Mtetra
.947 .676 .49 r
.40016 .39199 .40138 .38664 .40261 .39632 .3942 .58935 Mtetra
.551 .326 .528 r
.3942 .58935 .40261 .39632 .39683 .59329 .39572 .59418 Mtetra
.686 .239 .183 r
.39572 .59418 .39683 .59329 .39844 .59582 .39738 .59557 Mtetra
.397 .824 .963 r
.39738 .59557 .39844 .59582 .40015 .59561 .3991 .59528 Mtetra
.654 .908 .98 r
.3991 .59528 .40015 .59561 .40189 .5948 .40083 .59456 Mtetra
.627 .919 .977 r
.40083 .59456 .40189 .5948 .40363 .59398 .40257 .59386 Mtetra
.415 .85 .937 r
.40257 .59386 .40363 .59398 .40536 .59358 .4043 .59345 Mtetra
.534 .904 .96 r
.4043 .59345 .40536 .59358 .40709 .59317 .40603 .59285 Mtetra
.768 .927 .939 r
.40603 .59285 .40709 .59317 .40882 .5927 .40779 .59174 Mtetra
.845 .79 .798 r
.40779 .59174 .40882 .5927 .41055 .59215 .40957 .58973 Mtetra
.785 .643 .704 r
.40957 .58973 .41055 .59215 .41229 .59157 .41138 .58713 Mtetra
.694 .529 .659 r
.41138 .58713 .41229 .59157 .41402 .59119 .41316 .58498 Mtetra
.557 .408 .634 r
.41316 .58498 .41402 .59119 .41574 .59107 .41488 .58491 Mtetra
.578 .424 .635 r
.41488 .58491 .41574 .59107 .41748 .59048 .41662 .58449 Mtetra
.708 .517 .628 r
.41662 .58449 .41748 .59048 .41927 .58835 .41844 .58111 Mtetra
.95 .682 .494 r
.41844 .58111 .41927 .58835 .42126 .57972 .42628 .38225 Mtetra
.555 .334 .535 r
.42628 .38225 .42126 .57972 .42898 .37923 .42809 .37614 Mtetra
.75 .591 .68 r
.42809 .37614 .42898 .37923 .43072 .37533 .42978 .3737 Mtetra
.668 .647 .82 r
.42978 .3737 .43072 .37533 .43237 .37431 .43142 .37304 Mtetra
.584 .666 .895 r
.43142 .37304 .43237 .37431 .434 .37388 .43305 .37281 Mtetra
.55 .692 .933 r
.43305 .37281 .434 .37388 .43564 .37361 .43468 .37265 Mtetra
.646 .751 .926 r
.43468 .37265 .43564 .37361 .43727 .37309 .43632 .37216 Mtetra
.658 .762 .926 r
.43632 .37216 .43727 .37309 .43891 .37259 .43796 .37162 Mtetra
.676 .757 .912 r
.43796 .37162 .43891 .37259 .44055 .3721 .4396 .37101 Mtetra
.692 .739 .887 r
.4396 .37101 .44055 .3721 .4422 .37156 .44125 .3703 Mtetra
.689 .709 .863 r
.44125 .3703 .4422 .37156 .44384 .37101 .4429 .36959 Mtetra
.685 .682 .841 r
.4429 .36959 .44384 .37101 .44548 .37044 .44455 .36886 Mtetra
.682 .66 .822 r
.44455 .36886 .44548 .37044 .44713 .36984 .4462 .36811 Mtetra
.651 .629 .814 r
.4462 .36811 .44713 .36984 .44878 .36924 .44785 .36754 Mtetra
.578 .597 .836 r
.44785 .36754 .44878 .36924 .45043 .36864 .44949 .36736 Mtetra
.208 .466 .883 r
.44949 .36736 .45043 .36864 .45208 .36808 .45111 .36807 Mtetra
.662 .116 0 r
.45111 .36807 .45208 .36808 .45373 .36751 .45272 .36933 Mtetra
.647 .258 .295 r
.45272 .36933 .45373 .36751 .45538 .36684 .45433 .37055 Mtetra
.392 .083 .317 r
.45433 .37055 .45538 .36684 .45704 .36586 .45599 .36956 Mtetra
.425 .112 .329 r
.45599 .36956 .45704 .36586 .45869 .36529 .45765 .36882 Mtetra
.621 .292 .392 r
.45765 .36882 .45869 .36529 .46032 .36584 .45927 .37013 Mtetra
.955 .677 .472 r
.45927 .37013 .46032 .36584 .46185 .37185 .45695 .56813 Mtetra
.553 .328 .528 r
.45695 .56813 .46185 .37185 .45963 .57298 .45858 .57447 Mtetra
.718 .318 .288 r
.45858 .57447 .45963 .57298 .46132 .5767 .4603 .57645 Mtetra
.313 .78 .938 r
.4603 .57645 .46132 .5767 .46307 .57668 .46206 .57626 Mtetra
.637 .891 .986 r
.46206 .57626 .46307 .57668 .46485 .57596 .46383 .5756 Mtetra
.674 .913 .976 r
.46383 .5756 .46485 .57596 .46662 .57498 .46561 .57482 Mtetra
.41 .845 .943 r
.46561 .57482 .46662 .57498 .4684 .5744 .46738 .57442 Mtetra
.313 .803 .855 r
.46738 .57442 .4684 .5744 .47017 .57383 .46915 .57401 Mtetra
.259 .767 .766 r
.46915 .57401 .47017 .57383 .47194 .5733 .47092 .57352 Mtetra
.353 .825 .782 r
.47092 .57352 .47194 .5733 .47371 .57287 .4727 .57286 Mtetra
.515 .911 .916 r
.4727 .57286 .47371 .57287 .47549 .57245 .47448 .57216 Mtetra
.604 .91 .982 r
.47448 .57216 .47549 .57245 .47726 .57201 .47626 .5715 Mtetra
.545 .842 .999 r
.47626 .5715 .47726 .57201 .47904 .57151 .47803 .5711 Mtetra
.572 .876 .994 r
.47803 .5711 .47904 .57151 .48082 .57097 .47981 .57058 Mtetra
.696 .913 .97 r
.47981 .57058 .48082 .57097 .4826 .57042 .4816 .56973 Mtetra
.86 .848 .83 r
.4816 .56973 .4826 .57042 .48438 .56985 .4834 .56784 Mtetra
.804 .677 .724 r
.4834 .56784 .48438 .56985 .48617 .56929 .4852 .56535 Mtetra
.74 .569 .662 r
.4852 .56535 .48617 .56929 .48795 .56873 .48701 .56248 Mtetra
.613 .447 .634 r
.48701 .56248 .48795 .56873 .48973 .56821 .4888 .56138 Mtetra
.572 .413 .627 r
.4888 .56138 .48973 .56821 .49152 .5677 .49058 .56102 Mtetra
.558 .405 .629 r
.49058 .56102 .49152 .5677 .49331 .56719 .49236 .5609 Mtetra
.606 .443 .634 r
.49236 .5609 .49331 .56719 .4951 .56664 .49415 .55993 Mtetra
.583 .422 .628 r
.49415 .55993 .4951 .56664 .49688 .5661 .49594 .55936 Mtetra
.537 .389 .627 r
.49594 .55936 .49688 .5661 .49868 .56556 .49772 .55962 Mtetra
.409 .31 .631 r
.49772 .55962 .49868 .56556 .50047 .56508 .4995 .56145 Mtetra
.378 .35 .701 r
.4995 .56145 .50047 .56508 .50226 .56459 .50128 .56277 Mtetra
.331 .464 .843 r
.50128 .56277 .50226 .56459 .50405 .56407 .50306 .56351 Mtetra
.444 .787 .998 r
.50306 .56351 .50405 .56407 .50585 .56343 .50486 .56333 Mtetra
.376 .835 .911 r
.50486 .56333 .50585 .56343 .50765 .56276 .50665 .56292 Mtetra
.312 .802 .792 r
.50665 .56292 .50765 .56276 .50945 .56211 .50845 .56236 Mtetra
.194 .716 .693 r
.50845 .56236 .50945 .56211 .51124 .56157 .51025 .56187 Mtetra
0 0 0 r
.51025 .56187 .51124 .56157 .51304 .56105 .51205 .56133 Mtetra
.251 .754 .707 r
.51205 .56133 .51304 .56105 .51485 .56054 .51386 .56074 Mtetra
0 0 0 r
.51386 .56074 .51485 .56054 .51665 .56048 .51566 .56039 Mtetra
.507 .901 .939 r
.51566 .56039 .51665 .56048 .51845 .56002 .51747 .55976 Mtetra
.758 .95 .94 r
.51747 .55976 .51845 .56002 .52026 .55878 .51927 .55861 Mtetra
.961 .873 .705 r
.51927 .55861 .52026 .55878 .52207 .55269 .52108 .55495 Mtetra
.987 .834 .451 r
.52108 .55495 .52207 .55269 .52393 .34883 .5229 .54548 Mtetra
0 0 .334 r
.5229 .54548 .52393 .34883 .52563 .34308 .52471 .34689 Mtetra
.336 .039 .304 r
.52471 .34689 .52563 .34308 .52732 .34183 .52641 .34542 Mtetra
.472 .152 .341 r
.52641 .34542 .52732 .34183 .52902 .34133 .52811 .34509 Mtetra
.487 .169 .353 r
.52811 .34509 .52902 .34133 .53072 .34119 .52981 .34486 Mtetra
.094 0 .204 r
.52981 .34486 .53072 .34119 .53241 .34062 .5315 .34208 Mtetra
0 0 0 r
.5315 .34208 .53241 .34062 .53411 .34002 .5332 .33976 Mtetra
.877 .936 .854 r
.5332 .33976 .53411 .34002 .53581 .33942 .5349 .33801 Mtetra
.68 .688 .851 r
.5349 .33801 .53581 .33942 .53751 .33882 .5366 .33731 Mtetra
.627 .651 .854 r
.5366 .33731 .53751 .33882 .53922 .33822 .5383 .33688 Mtetra
.607 .668 .883 r
.5383 .33688 .53922 .33822 .54092 .33765 .54001 .33655 Mtetra
.686 .743 .894 r
.54001 .33655 .54092 .33765 .54262 .33713 .54171 .33586 Mtetra
.693 .714 .865 r
.54171 .33586 .54262 .33713 .54433 .33663 .54342 .3351 Mtetra
.683 .672 .833 r
.54342 .3351 .54433 .33663 .54604 .33613 .54512 .33435 Mtetra
.696 .648 .798 r
.54512 .33435 .54604 .33613 .54774 .33512 .54683 .33342 Mtetra
.668 .644 .817 r
.54683 .33342 .54774 .33512 .54945 .33438 .54853 .33272 Mtetra
.587 .612 .845 r
.54853 .33272 .54945 .33438 .55116 .33429 .55025 .3325 Mtetra
0 .225 .74 r
.55025 .3325 .55116 .33429 .55291 .33799 .55198 .33415 Mtetra
0 0 .366 r
.55198 .33415 .55291 .33799 .55654 .54087 .55375 .3397 Mtetra
0 0 .362 r
.55375 .3397 .55654 .54087 .55843 .54688 .55741 .5401 Mtetra
.291 .217 .598 r
.55741 .5401 .55843 .54688 .56027 .54749 .55928 .54359 Mtetra
.407 .36 .693 r
.55928 .54359 .56027 .54749 .56211 .54701 .56113 .54484 Mtetra
.461 .5 .812 r
.56113 .54484 .56211 .54701 .56394 .54607 .56297 .54526 Mtetra
.394 .702 .983 r
.56297 .54526 .56394 .54607 .56577 .54578 .56482 .54532 Mtetra
.533 .854 .997 r
.56482 .54532 .56577 .54578 .56761 .54526 .56666 .54489 Mtetra
.743 .933 .95 r
.56666 .54489 .56761 .54526 .56944 .54402 .56849 .54382 Mtetra
.953 .897 .733 r
.56849 .54382 .56944 .54402 .57121 .53892 .57029 .54064 Mtetra
.98 .851 .464 r
.57029 .54064 .57121 .53892 .57013 .3346 .57203 .53298 Mtetra
0 0 .354 r
.57203 .53298 .57013 .3346 .57176 .32777 .57094 .33202 Mtetra
.245 0 .294 r
.57094 .33202 .57176 .32777 .57347 .32611 .57264 .32964 Mtetra
.462 .141 .335 r
.57264 .32964 .57347 .32611 .5752 .32553 .57437 .32923 Mtetra
.491 .171 .351 r
.57437 .32923 .5752 .32553 .57693 .32536 .57611 .32904 Mtetra
.176 0 .243 r
.57611 .32904 .57693 .32536 .57866 .32486 .57781 .3266 Mtetra
0 0 0 r
.57781 .3266 .57866 .32486 .58038 .32425 .57951 .32418 Mtetra
.881 .974 .837 r
.57951 .32418 .58038 .32425 .58211 .32363 .58121 .32234 Mtetra
.712 .721 .857 r
.58121 .32234 .58211 .32363 .58384 .323 .58294 .32146 Mtetra
.635 .653 .85 r
.58294 .32146 .58384 .323 .58557 .32238 .58467 .32099 Mtetra
.611 .665 .878 r
.58467 .32099 .58557 .32238 .5873 .32178 .58641 .32063 Mtetra
.721 .749 .874 r
.58641 .32063 .5873 .32178 .58903 .3209 .58814 .31973 Mtetra
.718 .745 .873 r
.58814 .31973 .58903 .3209 .59076 .32021 .58986 .31885 Mtetra
.633 .68 .877 r
.58986 .31885 .59076 .32021 .59251 .32011 .5916 .31839 Mtetra
.141 .344 .805 r
.5916 .31839 .59251 .32011 .59432 .32306 .59338 .31964 Mtetra
0 0 .469 r
.59338 .31964 .59432 .32306 .60066 .52555 .59523 .32416 Mtetra
0 0 .378 r
.59523 .32416 .60066 .52555 .6027 .533 .6016 .52541 Mtetra
.256 .185 .581 r
.6016 .52541 .6027 .533 .60459 .53401 .60357 .52982 Mtetra
.403 .348 .683 r
.60357 .52982 .60459 .53401 .60646 .5336 .60548 .53123 Mtetra
.457 .48 .794 r
.60548 .53123 .60646 .5336 .60831 .53269 .60737 .53173 Mtetra
.409 .676 .97 r
.60737 .53173 .60831 .53269 .61018 .53229 .60926 .53184 Mtetra
.48 .835 .995 r
.60926 .53184 .61018 .53229 .61205 .53185 .61113 .5315 Mtetra
.702 .933 .964 r
.61113 .5315 .61205 .53185 .61391 .53077 .61299 .53055 Mtetra
.931 .929 .782 r
.61299 .53055 .61391 .53077 .61568 .52661 .6148 .52797 Mtetra
.952 .881 .479 r
.6148 .52797 .61568 .52661 .61194 .32342 .61653 .52229 Mtetra
0 0 .37 r
.61653 .52229 .61194 .32342 .61345 .31423 .61276 .31987 Mtetra
0 0 .225 r
.61276 .31987 .61345 .31423 .61515 .31208 .61436 .31399 Mtetra
0 0 0 r
.61436 .31399 .61515 .31208 .6169 .31138 .61606 .31154 Mtetra
.781 .998 .827 r
.61606 .31154 .6169 .31138 .61866 .31113 .61778 .30998 Mtetra
.715 .751 .88 r
.61778 .30998 .61866 .31113 .62042 .31071 .61953 .30912 Mtetra
.632 .646 .846 r
.61953 .30912 .62042 .31071 .62217 .31014 .62129 .30865 Mtetra
.598 .645 .868 r
.62129 .30865 .62217 .31014 .62393 .30957 .62305 .30835 Mtetra
.684 .727 .883 r
.62305 .30835 .62393 .30957 .62568 .30863 .6248 .30764 Mtetra
.708 .781 .909 r
.6248 .30764 .62568 .30863 .62742 .30774 .62655 .30684 Mtetra
.609 .767 .955 r
.62655 .30684 .62742 .30774 .62919 .30742 .62832 .30643 Mtetra
0 .33 .805 r
.62832 .30643 .62919 .30742 .63105 .3097 .63014 .30753 Mtetra
0 0 .302 r
.63014 .30753 .63105 .3097 .63976 .51085 .63207 .31197 Mtetra
0 0 .389 r
.63207 .31197 .63976 .51085 .64201 .52075 .64085 .51304 Mtetra
.246 .179 .58 r
.64085 .51304 .64201 .52075 .64396 .52216 .64292 .51774 Mtetra
.41 .347 .676 r
.64292 .51774 .64396 .52216 .64586 .52176 .64488 .51919 Mtetra
.466 .47 .779 r
.64488 .51919 .64586 .52176 .64774 .52083 .64681 .51971 Mtetra
.483 .677 .95 r
.64681 .51971 .64774 .52083 .64963 .52037 .64872 .51971 Mtetra
.583 .831 .992 r
.64872 .51971 .64963 .52037 .65153 .52008 .65062 .51924 Mtetra
.748 .838 .919 r
.65062 .51924 .65153 .52008 .65341 .51919 .65249 .51818 Mtetra
.882 .814 .777 r
.65249 .51818 .65341 .51919 .6552 .51575 .65432 .51571 Mtetra
.991 .848 .602 r
.65432 .51571 .6552 .51575 .64926 .3174 .65602 .5102 Mtetra
0 0 .376 r
.65602 .5102 .64926 .3174 .65045 .30207 .64987 .30814 Mtetra
0 0 .252 r
.64987 .30814 .65045 .30207 .65214 .29947 .65142 .30183 Mtetra
0 0 .064 r
.65142 .30183 .65214 .29947 .65391 .29871 .65312 .2994 Mtetra
.481 .823 .538 r
.65312 .2994 .65391 .29871 .6557 .29846 .65485 .29785 Mtetra
.746 .883 .942 r
.65485 .29785 .6557 .29846 .65748 .29812 .65661 .29687 Mtetra
.665 .718 .889 r
.65661 .29687 .65748 .29812 .65926 .29755 .65839 .29626 Mtetra
.63 .695 .892 r
.65839 .29626 .65926 .29755 .66104 .29698 .66018 .2958 Mtetra
.688 .739 .89 r
.66018 .2958 .66104 .29698 .66281 .29608 .66195 .29507 Mtetra
.719 .782 .902 r
.66195 .29507 .66281 .29608 .66457 .29513 .66372 .2942 Mtetra
.631 .772 .948 r
.66372 .2942 .66457 .29513 .66636 .2947 .66551 .29371 Mtetra
.086 .451 .883 r
.66551 .29371 .66636 .2947 .66825 .29644 .66736 .29452 Mtetra
0 0 .386 r
.66736 .29452 .66825 .29644 .67919 .49251 .66935 .29832 Mtetra
0 0 .397 r
.66935 .29832 .67919 .49251 .68186 .50815 .68059 .49937 Mtetra
.228 .159 .566 r
.68059 .49937 .68186 .50815 .68389 .51006 .6828 .50508 Mtetra
.428 .347 .662 r
.6828 .50508 .68389 .51006 .68582 .50976 .68481 .50655 Mtetra
.485 .443 .736 r
.68481 .50655 .68582 .50976 .68772 .50887 .68678 .5071 Mtetra
.466 .554 .862 r
.68678 .5071 .68772 .50887 .68964 .50823 .68874 .50739 Mtetra
.425 .715 .985 r
.68874 .50739 .68964 .50823 .69157 .50789 .69069 .5074 Mtetra
.64 .894 .985 r
.69069 .5074 .69157 .50789 .69347 .50698 .6926 .50668 Mtetra
.943 .92 .759 r
.6926 .50668 .69347 .50698 .69526 .5039 .69441 .50385 Mtetra
.993 .765 .484 r
.69441 .50385 .69526 .5039 .69618 .48382 .69575 .4918 Mtetra
.981 .691 .368 r
.69575 .4918 .69618 .48382 .68794 .28963 .6871 .2887 Mtetra
.926 .811 .714 r
.6871 .2887 .68794 .28963 .68961 .28661 .68876 .28545 Mtetra
.714 .754 .883 r
.68876 .28545 .68961 .28661 .6914 .28572 .69055 .28458 Mtetra
.599 .712 .924 r
.69055 .28458 .6914 .28572 .69321 .28535 .69236 .28423 Mtetra
.674 .747 .906 r
.69236 .28423 .69321 .28535 .69501 .28481 .69416 .28357 Mtetra
.75 .752 .854 r
.69416 .28357 .69501 .28481 .6968 .28393 .69593 .28244 Mtetra
.66 .678 .856 r
.69593 .28244 .6968 .28393 .69861 .28353 .69773 .28181 Mtetra
.229 .403 .828 r
.69773 .28181 .69861 .28353 .70053 .2849 .69963 .2829 Mtetra
.873 .514 .02 r
.69963 .2829 .70053 .2849 .70304 .29679 .70194 .29113 Mtetra
.978 .678 .352 r
.70194 .29113 .70304 .29679 .71645 .49699 .71554 .49564 Mtetra
0 0 .451 r
.71554 .49564 .71645 .49699 .71857 .49962 .71768 .49858 Mtetra
.421 .666 .963 r
.71768 .49858 .71857 .49962 .72055 .49974 .71966 .49871 Mtetra
.728 .801 .91 r
.71966 .49871 .72055 .49974 .72247 .49878 .72158 .49773 Mtetra
.905 .815 .747 r
.72158 .49773 .72247 .49878 .72427 .49589 .72338 .49481 Mtetra
.979 .742 .51 r
.72338 .49481 .72427 .49589 .72555 .48433 .72466 .48324 Mtetra
.977 .681 .378 r
.72466 .48324 .72555 .48433 .71506 .28094 .71422 .27979 Mtetra
.92 .788 .699 r
.71422 .27979 .71506 .28094 .7167 .27747 .71586 .27633 Mtetra
.72 .761 .885 r
.71586 .27633 .7167 .27747 .71849 .27657 .71766 .27542 Mtetra
.598 .713 .924 r
.71766 .27542 .71849 .27657 .72033 .27622 .71949 .27507 Mtetra
.634 .728 .916 r
.71949 .27507 .72033 .27622 .72215 .27573 .72132 .27458 Mtetra
.739 .768 .876 r
.72132 .27458 .72215 .27573 .72394 .2747 .72311 .27355 Mtetra
.651 .736 .911 r
.72311 .27355 .72394 .2747 .72576 .27413 .72493 .27299 Mtetra
.113 .433 .873 r
.72493 .27299 .72576 .27413 .72769 .27507 .72685 .27392 Mtetra
.906 .522 .091 r
.72685 .27392 .72769 .27507 .73007 .28291 .72923 .28176 Mtetra
.975 .671 .352 r
.72923 .28176 .73007 .28291 .74557 .48739 .74469 .4863 Mtetra
.601 .139 0 r
.74469 .4863 .74557 .48739 .74776 .49034 .74689 .48925 Mtetra
.553 .722 .952 r
.74689 .48925 .74776 .49034 .74975 .4901 .74887 .48901 Mtetra
.713 .787 .91 r
.74887 .48901 .74975 .4901 .75169 .48919 .75081 .4881 Mtetra
.696 .781 .917 r
.75081 .4881 .75169 .48919 .75363 .48836 .75275 .48727 Mtetra
.51 .702 .956 r
.75275 .48727 .75363 .48836 .75563 .48826 .75475 .48717 Mtetra
.654 .766 .932 r
.75475 .48717 .75563 .48826 .75759 .48764 .75672 .48654 Mtetra
.869 .817 .796 r
.75672 .48654 .75759 .48764 .75944 .48538 .75856 .48429 Mtetra
.98 .75 .517 r
.75856 .48429 .75944 .48538 .76071 .47514 .75984 .47406 Mtetra
.977 .678 .362 r
.75984 .47406 .76071 .47514 .74793 .2701 .74711 .26895 Mtetra
.933 .789 .678 r
.74711 .26895 .74793 .2701 .74953 .26627 .74871 .26512 Mtetra
.727 .765 .884 r
.74871 .26512 .74953 .26627 .75134 .26532 .75052 .26416 Mtetra
.601 .715 .925 r
.75052 .26416 .75134 .26532 .7532 .26496 .75238 .2638 Mtetra
.6 .715 .925 r
.75238 .2638 .7532 .26496 .75506 .2646 .75424 .26344 Mtetra
.739 .769 .877 r
.75424 .26344 .75506 .2646 .75687 .26357 .75605 .26241 Mtetra
.656 .739 .911 r
.75605 .26241 .75687 .26357 .75871 .26298 .75789 .26182 Mtetra
.23 .508 .907 r
.75789 .26182 .75871 .26298 .76065 .26368 .75983 .26252 Mtetra
.884 .493 .038 r
.75983 .26252 .76065 .26368 .76311 .27098 .76229 .26983 Mtetra
.975 .667 .334 r
.76229 .26983 .76311 .27098 .78097 .47663 .7801 .47552 Mtetra
.654 .2 0 r
.7801 .47552 .78097 .47663 .78326 .48008 .7824 .47898 Mtetra
.382 .631 .952 r
.7824 .47898 .78326 .48008 .78531 .48035 .78445 .47925 Mtetra
.692 .78 .919 r
.78445 .47925 .78531 .48035 .78728 .47953 .78642 .47843 Mtetra
.873 .82 .793 r
.78642 .47843 .78728 .47953 .78913 .47723 .78827 .47612 Mtetra
.978 .767 .552 r
.78827 .47612 .78913 .47723 .79054 .46939 .78968 .46829 Mtetra
.977 .675 .347 r
.78968 .46829 .79054 .46939 .77568 .26167 .77487 .26051 Mtetra
.951 .785 .641 r
.77487 .26051 .77568 .26167 .77721 .25708 .7764 .25591 Mtetra
.745 .772 .875 r
.7764 .25591 .77721 .25708 .77902 .256 .77822 .25484 Mtetra
.617 .722 .921 r
.77822 .25484 .77902 .256 .7809 .25557 .78009 .25441 Mtetra
.584 .707 .927 r
.78009 .25441 .7809 .25557 .78278 .25527 .78197 .2541 Mtetra
.747 .773 .874 r
.78197 .2541 .78278 .25527 .7846 .25418 .78379 .25302 Mtetra
.67 .744 .906 r
.78379 .25302 .7846 .25418 .78645 .25352 .78565 .25235 Mtetra
.35 .58 .928 r
.78565 .25235 .78645 .25352 .7884 .25394 .7876 .25277 Mtetra
.837 .432 0 r
.7876 .25277 .7884 .25394 .79085 .26006 .79004 .25891 Mtetra
.973 .663 .318 r
.79004 .25891 .79085 .26006 .81075 .46695 .8099 .46585 Mtetra
.694 .248 0 r
.8099 .46585 .81075 .46695 .81314 .47091 .8123 .4698 Mtetra
.348 .61 .948 r
.8123 .4698 .81314 .47091 .81523 .47127 .81439 .47016 Mtetra
.675 .776 .926 r
.81439 .47016 .81523 .47127 .81723 .47052 .81638 .46942 Mtetra
.858 .824 .814 r
.81638 .46942 .81723 .47052 .8191 .46843 .81826 .46734 Mtetra
.979 .777 .563 r
.81826 .46734 .8191 .46843 .82052 .46128 .81969 .46026 Mtetra
.976 .672 .332 r
.81969 .46026 .82052 .46128 .80367 .25269 .80288 .2516 Mtetra
.965 .789 .615 r
.80288 .2516 .80367 .25269 .80514 .2476 .80434 .24646 Mtetra
.751 .781 .878 r
.80434 .24646 .80514 .2476 .80697 .24651 .80617 .24535 Mtetra
.611 .724 .926 r
.80617 .24535 .80697 .24651 .80886 .2461 .80807 .24494 Mtetra
.531 .684 .936 r
.80807 .24494 .80886 .2461 .81078 .24599 .80999 .24482 Mtetra
.692 .754 .899 r
.80999 .24482 .81078 .24599 .81266 .24536 .81185 .24404 Mtetra
.663 .715 .887 r
.81185 .24404 .81266 .24536 .81453 .24471 .81373 .24339 Mtetra
.602 .687 .902 r
.81373 .24339 .81453 .24471 .81641 .24403 .81563 .24303 Mtetra
.337 .615 .952 r
.81563 .24303 .81641 .24403 .81824 .24291 .81761 .24337 Mtetra
.6 .052 0 r
.81761 .24337 .81824 .24291 .82011 .2422 .81967 .24457 Mtetra
.767 .375 .312 r
.81967 .24457 .82011 .2422 .82207 .24234 .82196 .24819 Mtetra
.971 .654 .325 r
.82196 .24819 .82207 .24234 .82454 .24767 .8437 .45142 Mtetra
.55 .325 .527 r
.8437 .45142 .82454 .24767 .84688 .45525 .84631 .45677 Mtetra
.686 .24 .187 r
.84631 .45677 .84688 .45525 .84941 .45977 .84859 .45868 Mtetra
.374 .632 .954 r
.84859 .45868 .84941 .45977 .85155 .46027 .8507 .45897 Mtetra
.644 .727 .909 r
.8507 .45897 .85155 .46027 .85358 .45966 .85274 .45837 Mtetra
.803 .789 .84 r
.85274 .45837 .85358 .45966 .8555 .45789 .85467 .45675 Mtetra
.975 .788 .588 r
.85467 .45675 .8555 .45789 .85698 .45182 .85615 .45065 Mtetra
.974 .667 .312 r
.85615 .45065 .85698 .45182 .83772 .24263 .83693 .24141 Mtetra
.973 .773 .575 r
.83693 .24141 .83772 .24263 .83904 .23641 .83826 .23521 Mtetra
.758 .756 .851 r
.22853 .44184 .22955 .4428 .23112 .44176 .23009 .44079 Mtetra
.605 .723 .928 r
.23009 .44079 .23112 .44176 .23262 .44145 .23159 .44048 Mtetra
.435 .657 .954 r
.23159 .44048 .23262 .44145 .23408 .44155 .23306 .44058 Mtetra
.633 .729 .917 r
.23306 .44058 .23408 .44155 .23559 .44116 .23457 .44017 Mtetra
.642 .729 .912 r
.23457 .44017 .23559 .44116 .23711 .44074 .23609 .43974 Mtetra
.653 .729 .905 r
.23609 .43974 .23711 .44074 .23863 .44028 .23761 .43926 Mtetra
.67 .73 .895 r
.23761 .43926 .23863 .44028 .24015 .43975 .23913 .43871 Mtetra
.682 .73 .886 r
.23913 .43871 .24015 .43975 .24168 .43916 .24067 .4381 Mtetra
.693 .729 .878 r
.24067 .4381 .24168 .43916 .24322 .43851 .24221 .43743 Mtetra
.711 .73 .866 r
.24221 .43743 .24322 .43851 .24477 .43776 .24375 .43666 Mtetra
.712 .727 .862 r
.24375 .43666 .24477 .43776 .24631 .437 .2453 .43588 Mtetra
.707 .723 .862 r
.2453 .43588 .24631 .437 .24786 .43625 .24685 .43512 Mtetra
.687 .715 .871 r
.24685 .43512 .24786 .43625 .2494 .43561 .24839 .43448 Mtetra
.678 .712 .874 r
.24839 .43448 .2494 .43561 .25094 .43501 .24993 .43388 Mtetra
.672 .711 .877 r
.24993 .43388 .25094 .43501 .25247 .43443 .25147 .4333 Mtetra
.671 .711 .878 r
.25147 .4333 .25247 .43443 .25401 .43386 .253 .43273 Mtetra
.668 .711 .88 r
.253 .43273 .25401 .43386 .25554 .43331 .25454 .43218 Mtetra
.666 .711 .881 r
.25454 .43218 .25554 .43331 .25708 .43276 .25607 .43164 Mtetra
.664 .711 .883 r
.25607 .43164 .25708 .43276 .25861 .43222 .25761 .4311 Mtetra
.663 .711 .884 r
.25761 .4311 .25861 .43222 .26015 .43169 .25914 .43057 Mtetra
.661 .712 .885 r
.25914 .43057 .26015 .43169 .26169 .43116 .26068 .43005 Mtetra
.663 .713 .886 r
.26068 .43005 .26169 .43116 .26322 .43062 .26222 .42952 Mtetra
.659 .714 .888 r
.26222 .42952 .26322 .43062 .26476 .4301 .26376 .42901 Mtetra
.653 .713 .892 r
.26376 .42901 .26476 .4301 .2663 .4296 .26529 .42852 Mtetra
.625 .708 .905 r
.26529 .42852 .2663 .4296 .26783 .4292 .26682 .42815 Mtetra
.619 .711 .912 r
.26682 .42815 .26783 .4292 .26936 .42881 .26835 .42779 Mtetra
.629 .722 .914 r
.26835 .42779 .26936 .42881 .27089 .42838 .26988 .4274 Mtetra
.679 .744 .9 r
.26988 .4274 .27089 .42838 .27244 .42776 .27143 .42681 Mtetra
.697 .753 .895 r
.27143 .42681 .27244 .42776 .274 .42707 .27298 .42614 Mtetra
.699 .758 .897 r
.27298 .42614 .274 .42707 .27556 .42637 .27454 .42545 Mtetra
.68 .757 .909 r
.27454 .42545 .27556 .42637 .27711 .42576 .27609 .42486 Mtetra
.67 .758 .916 r
.27609 .42486 .27711 .42576 .27866 .42519 .27764 .4243 Mtetra
.666 .76 .92 r
.27764 .4243 .27866 .42519 .2802 .42465 .27919 .42376 Mtetra
.7 .769 .905 r
.27919 .42376 .2802 .42465 .28177 .42385 .28075 .42308 Mtetra
.684 .791 .931 r
.28075 .42308 .28177 .42385 .28333 .42319 .2823 .42247 Mtetra
.611 .785 .965 r
.2823 .42247 .28333 .42319 .28486 .42295 .28384 .42208 Mtetra
.118 .511 .91 r
.28384 .42208 .28486 .42295 .28625 .42456 .28532 .42259 Mtetra
.104 .281 .759 r
.28532 .42259 .28625 .42456 .28737 .42993 .28674 .42384 Mtetra
.373 .269 .606 r
.28674 .42384 .28737 .42993 .27473 .62513 .2881 .42587 Mtetra
.541 .322 .532 r
.2881 .42587 .27473 .62513 .27619 .6272 .28957 .42666 Mtetra
.543 .325 .533 r
.28957 .42666 .27619 .6272 .27783 .62675 .29113 .42609 Mtetra
.545 .326 .533 r
.29113 .42609 .27783 .62675 .27954 .62548 .29273 .42498 Mtetra
.29273 .42498 .27954 .62548 .28123 .62431 .29435 .42356 Mtetra
.544 .325 .533 r
.29435 .42356 .28123 .62431 .28291 .62352 .29594 .42264 Mtetra
.542 .323 .533 r
.29594 .42264 .28291 .62352 .28453 .62341 .29745 .42283 Mtetra
0 0 .271 r
.29745 .42283 .28453 .62341 .28603 .62508 .2863 .6048 Mtetra
0 0 .312 r
.2863 .6048 .28603 .62508 .28754 .62665 .28663 .62333 Mtetra
0 0 .516 r
.28663 .62333 .28754 .62665 .2891 .62761 .28804 .62645 Mtetra
.254 .536 .921 r
.28804 .62645 .2891 .62761 .29073 .62761 .28963 .62695 Mtetra
.613 .813 .977 r
.28963 .62695 .29073 .62761 .29238 .62715 .29129 .6265 Mtetra
.71 .837 .943 r
.29129 .6265 .29238 .62715 .29405 .62652 .29297 .62573 Mtetra
.635 .79 .957 r
.29297 .62573 .29405 .62652 .2957 .62624 .29463 .62525 Mtetra
.628 .743 .93 r
.29463 .62525 .2957 .62624 .29735 .62592 .29629 .62481 Mtetra
.684 .736 .89 r
.29629 .62481 .29735 .62592 .29903 .62516 .29797 .62414 Mtetra
.804 .769 .821 r
.29797 .62414 .29903 .62516 .30084 .62254 .2997 .62258 Mtetra
.922 .915 .793 r
.2997 .62258 .30084 .62254 .30288 .61615 .30149 .62014 Mtetra
0 0 .098 r
.30149 .62014 .30288 .61615 .31713 .41927 .30334 .61686 Mtetra
.539 .316 .526 r
.30334 .61686 .31713 .41927 .31888 .416 .30506 .61542 Mtetra
.541 .319 .526 r
.30506 .61542 .31888 .416 .32044 .41555 .3067 .61542 Mtetra
.54 .318 .526 r
.3067 .61542 .32044 .41555 .32199 .41546 .30838 .61469 Mtetra
.516 .298 .521 r
.30838 .61469 .32199 .41546 .32366 .41346 .31082 .6019 Mtetra
0 0 .221 r
.31082 .6019 .32366 .41346 .32535 .41106 .3242 .41248 Mtetra
.95 .936 .599 r
.3242 .41248 .32535 .41106 .327 .40922 .32599 .40854 Mtetra
.824 .821 .846 r
.32599 .40854 .327 .40922 .3286 .40827 .32762 .40707 Mtetra
.644 .696 .884 r
.32762 .40707 .3286 .40827 .33017 .40782 .32919 .40661 Mtetra
.565 .665 .905 r
.32919 .40661 .33017 .40782 .33174 .4075 .33075 .40645 Mtetra
.668 .73 .897 r
.33075 .40645 .33174 .4075 .33333 .40675 .33233 .40589 Mtetra
.72 .782 .901 r
.33233 .40589 .33333 .40675 .33493 .40587 .33392 .4051 Mtetra
.675 .794 .938 r
.33392 .4051 .33493 .40587 .33651 .40537 .33551 .40451 Mtetra
.467 .702 .97 r
.33551 .40451 .33651 .40537 .338 .40627 .33706 .40449 Mtetra
.306 .435 .828 r
.33706 .40449 .338 .40627 .33935 .40987 .33857 .40523 Mtetra
.32 .261 .634 r
.33857 .40523 .33935 .40987 .32976 .60568 .34001 .40717 Mtetra
.512 .299 .527 r
.34001 .40717 .32976 .60568 .33107 .61167 .3408 .42072 Mtetra
0 0 .253 r
.3408 .42072 .33107 .61167 .33264 .61329 .33175 .60934 Mtetra
0 .057 .575 r
.33175 .60934 .33264 .61329 .33426 .61389 .33323 .61244 Mtetra
.293 .5 .887 r
.33323 .61244 .33426 .61389 .33593 .61375 .33486 .61303 Mtetra
.656 .816 .96 r
.33486 .61303 .33593 .61375 .33762 .61315 .33655 .61246 Mtetra
.743 .836 .922 r
.33655 .61246 .33762 .61315 .33932 .61237 .33826 .61152 Mtetra
.656 .787 .944 r
.33826 .61152 .33932 .61237 .341 .61203 .33995 .61096 Mtetra
.57 .711 .938 r
.33995 .61096 .341 .61203 .34268 .61191 .34163 .61073 Mtetra
.633 .71 .902 r
.34163 .61073 .34268 .61191 .34437 .61139 .34332 .61028 Mtetra
.746 .754 .859 r
.34332 .61028 .34437 .61139 .34614 .60939 .34505 .60922 Mtetra
.885 .917 .841 r
.34505 .60922 .34614 .60939 .34806 .60442 .34681 .6073 Mtetra
0 0 0 r
.34681 .6073 .34806 .60442 .35981 .40718 .34865 .60406 Mtetra
.516 .298 .522 r
.34865 .60406 .35981 .40718 .36174 .40022 .35097 .5913 Mtetra
0 0 .247 r
.35097 .5913 .36174 .40022 .36343 .39774 .36231 .39955 Mtetra
.861 .906 .496 r
.36231 .39955 .36343 .39774 .36508 .3962 .36407 .39569 Mtetra
.851 .857 .846 r
.36407 .39569 .36508 .3962 .36669 .39532 .36573 .39407 Mtetra
.647 .689 .875 r
.36573 .39407 .36669 .39532 .36829 .3949 .36732 .39358 Mtetra
.558 .642 .89 r
.36732 .39358 .36829 .3949 .36987 .39467 .3689 .39346 Mtetra
.581 .671 .901 r
.3689 .39346 .36987 .39467 .37146 .39436 .37049 .39324 Mtetra
.649 .714 .896 r
.37049 .39324 .37146 .39436 .37306 .39386 .37209 .39275 Mtetra
.658 .719 .894 r
.37209 .39275 .37306 .39386 .37467 .39332 .37369 .39222 Mtetra
.66 .722 .895 r
.37369 .39222 .37467 .39332 .37627 .39278 .3753 .39169 Mtetra
.661 .724 .896 r
.3753 .39169 .37627 .39278 .37787 .39224 .3769 .39114 Mtetra
.67 .727 .892 r
.3769 .39114 .37787 .39224 .37948 .39166 .37851 .39056 Mtetra
.689 .731 .883 r
.37851 .39056 .37948 .39166 .38109 .39101 .38012 .38989 Mtetra
.702 .731 .873 r
.38012 .38989 .38109 .39101 .38271 .39029 .38174 .38914 Mtetra
.7 .725 .869 r
.38174 .38914 .38271 .39029 .38433 .38957 .38336 .38839 Mtetra
.712 .723 .859 r
.38336 .38839 .38433 .38957 .38594 .38883 .38498 .38756 Mtetra
.706 .708 .849 r
.38498 .38756 .38594 .38883 .38756 .38811 .38661 .38675 Mtetra
.64 .67 .863 r
.38661 .38675 .38756 .38811 .38917 .38759 .38821 .38629 Mtetra
.237 .48 .887 r
.38821 .38629 .38917 .38759 .39076 .38761 .38978 .38693 Mtetra
.877 .438 .102 r
.38978 .38693 .39076 .38761 .39232 .38843 .39124 .39007 Mtetra
.951 .681 .488 r
.39124 .39007 .39232 .38843 .39386 .38981 .38489 .5832 Mtetra
.556 .331 .529 r
.38489 .5832 .39386 .38981 .39542 .39055 .38626 .59117 Mtetra
.541 .318 .526 r
.38626 .59117 .39542 .39055 .39706 .38954 .38798 .59079 Mtetra
.54 .317 .526 r
.38798 .59079 .39706 .38954 .39868 .38897 .38972 .58977 Mtetra
.543 .32 .527 r
.38972 .58977 .39868 .38897 .40016 .39199 .39139 .59046 Mtetra
.545 .322 .527 r
.39139 .59046 .40016 .39199 .3942 .58935 .39301 .59265 Mtetra
.627 .29 .381 r
.39301 .59265 .3942 .58935 .39572 .59418 .39466 .59401 Mtetra
.237 0 0 r
.39466 .59401 .39572 .59418 .39738 .59557 .39635 .59444 Mtetra
.615 .719 .919 r
.39635 .59444 .39738 .59557 .3991 .59528 .39807 .59406 Mtetra
.668 .718 .886 r
.39807 .59406 .3991 .59528 .40083 .59456 .39981 .59343 Mtetra
.644 .728 .91 r
.39981 .59343 .40083 .59456 .40257 .59386 .40154 .59293 Mtetra
.56 .741 .961 r
.40154 .59293 .40257 .59386 .4043 .59345 .40326 .59268 Mtetra
.658 .81 .956 r
.40326 .59268 .4043 .59345 .40603 .59285 .405 .59209 Mtetra
.833 .825 .841 r
.405 .59209 .40603 .59285 .40779 .59174 .40677 .59042 Mtetra
.895 .737 .678 r
.40677 .59042 .40779 .59174 .40957 .58973 .40863 .5861 Mtetra
.953 .687 .493 r
.40863 .5861 .40957 .58973 .41138 .58713 .41665 .39847 Mtetra
.576 .352 .538 r
.41665 .39847 .41138 .58713 .41316 .58498 .41883 .38187 Mtetra
.544 .325 .533 r
.41883 .38187 .41316 .58498 .41488 .58491 .42047 .38109 Mtetra
.542 .324 .533 r
.42047 .38109 .41488 .58491 .41662 .58449 .42209 .38102 Mtetra
.545 .326 .533 r
.42209 .38102 .41662 .58449 .41844 .58111 .42375 .37965 Mtetra
.549 .329 .534 r
.42375 .37965 .41844 .58111 .42628 .38225 .42547 .37652 Mtetra
.673 .491 .631 r
.42547 .37652 .42628 .38225 .42809 .37614 .42716 .37423 Mtetra
.742 .648 .756 r
.42716 .37423 .42809 .37614 .42978 .3737 .42882 .37278 Mtetra
.659 .765 .928 r
.42882 .37278 .42978 .3737 .43142 .37304 .43046 .37224 Mtetra
.577 .768 .969 r
.43046 .37224 .43142 .37304 .43305 .37281 .43209 .37194 Mtetra
.579 .75 .959 r
.43209 .37194 .43305 .37281 .43468 .37265 .43372 .37165 Mtetra
.652 .745 .918 r
.43372 .37165 .43468 .37265 .43632 .37216 .43536 .37113 Mtetra
.666 .745 .909 r
.43536 .37113 .43632 .37216 .43796 .37162 .43701 .37056 Mtetra
.683 .743 .897 r
.43701 .37056 .43796 .37162 .4396 .37101 .43865 .36991 Mtetra
.701 .741 .882 r
.43865 .36991 .4396 .37101 .44125 .3703 .4403 .36916 Mtetra
.7 .732 .875 r
.4403 .36916 .44125 .3703 .4429 .36959 .44195 .36841 Mtetra
.705 .726 .866 r
.44195 .36841 .4429 .36959 .44455 .36886 .4436 .36761 Mtetra
.715 .718 .852 r
.4436 .36761 .44455 .36886 .4462 .36811 .44526 .36674 Mtetra
.657 .679 .859 r
.44526 .36674 .4462 .36811 .44785 .36754 .44691 .36618 Mtetra
.441 .584 .899 r
.44691 .36618 .44785 .36754 .44949 .36736 .44853 .36642 Mtetra
.778 .303 0 r
.44853 .36642 .44949 .36736 .45111 .36807 .45011 .36898 Mtetra
.925 .609 .424 r
.45011 .36898 .45111 .36807 .45272 .36933 .45146 .38154 Mtetra
.942 .665 .484 r
.45146 .38154 .45272 .36933 .45433 .37055 .44885 .57194 Mtetra
.541 .319 .526 r
.44885 .57194 .45433 .37055 .45599 .36956 .4506 .57183 Mtetra
.54 .317 .526 r
.4506 .57183 .45599 .36956 .45765 .36882 .45237 .57083 Mtetra
.541 .319 .526 r
.45237 .57083 .45765 .36882 .45927 .37013 .45412 .57076 Mtetra
.546 .322 .527 r
.45412 .57076 .45927 .37013 .45695 .56813 .45582 .57314 Mtetra
.613 .305 .424 r
.45582 .57314 .45695 .56813 .45858 .57447 .45755 .57466 Mtetra
.489 0 0 r
.45755 .57466 .45858 .57447 .4603 .57645 .45929 .57534 Mtetra
.603 .722 .928 r
.45929 .57534 .4603 .57645 .46206 .57626 .46106 .57498 Mtetra
.661 .711 .885 r
.46106 .57498 .46206 .57626 .46383 .5756 .46283 .57438 Mtetra
.669 .724 .891 r
.46283 .57438 .46383 .5756 .46561 .57482 .4646 .57375 Mtetra
.601 .73 .935 r
.4646 .57375 .46561 .57482 .46738 .57442 .46637 .57339 Mtetra
.602 .739 .941 r
.46637 .57339 .46738 .57442 .46915 .57401 .46814 .57302 Mtetra
.621 .755 .942 r
.46814 .57302 .46915 .57401 .47092 .57352 .46992 .57258 Mtetra
.667 .779 .933 r
.46992 .57258 .47092 .57352 .4727 .57286 .47169 .57195 Mtetra
.678 .789 .933 r
.47169 .57195 .4727 .57286 .47448 .57216 .47347 .57128 Mtetra
.664 .791 .942 r
.47347 .57128 .47448 .57216 .47626 .5715 .47525 .57066 Mtetra
.545 .76 .977 r
.47525 .57066 .47626 .5715 .47803 .5711 .47703 .57041 Mtetra
.621 .824 .978 r
.47703 .57041 .47803 .5711 .47981 .57058 .47881 .5699 Mtetra
.78 .855 .907 r
.47881 .5699 .47981 .57058 .4816 .56973 .4806 .56871 Mtetra
.908 .775 .703 r
.4806 .56871 .4816 .56973 .4834 .56784 .48242 .56501 Mtetra
.901 .677 .589 r
.48242 .56501 .4834 .56784 .4852 .56535 .48431 .55534 Mtetra
.953 .679 .479 r
.48431 .55534 .4852 .56535 .48701 .56248 .48835 .35846 Mtetra
.546 .326 .533 r
.48835 .35846 .48701 .56248 .4888 .56138 .49004 .35678 Mtetra
.543 .324 .533 r
.49004 .35678 .4888 .56138 .49058 .56102 .49171 .35643 Mtetra
.542 .323 .533 r
.49171 .35643 .49058 .56102 .49236 .5609 .49338 .35664 Mtetra
.545 .326 .533 r
.49338 .35664 .49236 .5609 .49415 .55993 .49507 .35524 Mtetra
.543 .325 .533 r
.49507 .35524 .49415 .55993 .49594 .55936 .49675 .35463 Mtetra
.54 .322 .532 r
.49675 .35463 .49594 .55936 .49772 .55962 .49842 .35581 Mtetra
0 0 .345 r
.49842 .35581 .49772 .55962 .4995 .56145 .49856 .55393 Mtetra
.008 .004 .501 r
.49856 .55393 .4995 .56145 .50128 .56277 .5003 .56034 Mtetra
0 .138 .67 r
.5003 .56034 .50128 .56277 .50306 .56351 .50207 .5626 Mtetra
.445 .701 .975 r
.50207 .5626 .50306 .56351 .50486 .56333 .50386 .56261 Mtetra
.606 .814 .98 r
.50386 .56261 .50486 .56333 .50665 .56292 .50566 .56215 Mtetra
.682 .825 .952 r
.50566 .56215 .50665 .56292 .50845 .56236 .50746 .56143 Mtetra
.633 .774 .949 r
.50746 .56143 .50845 .56236 .51025 .56187 .50926 .56093 Mtetra
.648 .776 .942 r
.50926 .56093 .51025 .56187 .51205 .56133 .51107 .56037 Mtetra
.662 .776 .934 r
.51107 .56037 .51205 .56133 .51386 .56074 .51287 .55976 Mtetra
.643 .766 .938 r
.51287 .55976 .51386 .56074 .51566 .56039 .51468 .55923 Mtetra
.678 .742 .899 r
.51468 .55923 .51566 .56039 .51747 .55976 .51648 .55854 Mtetra
.723 .745 .869 r
.51648 .55854 .51747 .55976 .51927 .55861 .51829 .55758 Mtetra
.846 .793 .8 r
.51829 .55758 .51927 .55861 .52108 .55495 .5201 .55555 Mtetra
.9 .979 .695 r
.5201 .55555 .52108 .55495 .5229 .54548 .52191 .55281 Mtetra
.288 .05 .369 r
.52191 .55281 .5229 .54548 .52471 .34689 .52372 .54924 Mtetra
.541 .318 .526 r
.52372 .54924 .52471 .34689 .52641 .34542 .52553 .54885 Mtetra
.52553 .54885 .52641 .34542 .52811 .34509 .52734 .54865 Mtetra
.539 .317 .526 r
.52734 .54865 .52811 .34509 .52981 .34486 .52915 .54737 Mtetra
0 0 .348 r
.52915 .54737 .52981 .34486 .5315 .34208 .5306 .34889 Mtetra
0 0 .12 r
.5306 .34889 .5315 .34208 .5332 .33976 .53229 .34024 Mtetra
.962 .943 .669 r
.53229 .34024 .5332 .33976 .5349 .33801 .53398 .33693 Mtetra
.733 .759 .874 r
.53398 .33693 .5349 .33801 .5366 .33731 .53568 .33598 Mtetra
.62 .677 .883 r
.53568 .33598 .5366 .33731 .5383 .33688 .53739 .33559 Mtetra
.56 .658 .902 r
.53739 .33559 .5383 .33688 .54001 .33655 .53909 .33544 Mtetra
.676 .739 .898 r
.53909 .33544 .54001 .33655 .54171 .33586 .5408 .3348 Mtetra
.695 .754 .897 r
.5408 .3348 .54171 .33586 .54342 .3351 .5425 .33407 Mtetra
.696 .76 .901 r
.5425 .33407 .54342 .3351 .54512 .33435 .54421 .33334 Mtetra
.709 .768 .899 r
.54421 .33334 .54512 .33435 .54683 .33342 .54592 .33254 Mtetra
.681 .79 .932 r
.54592 .33254 .54683 .33342 .54853 .33272 .54763 .33188 Mtetra
.604 .774 .962 r
.54763 .33188 .54853 .33272 .55025 .3325 .54934 .33149 Mtetra
.369 .625 .951 r
.54934 .33149 .55025 .3325 .55198 .33415 .55106 .33174 Mtetra
.344 .392 .768 r
.55106 .33174 .55198 .33415 .55375 .3397 .55279 .33275 Mtetra
.368 .264 .603 r
.55279 .33275 .55375 .3397 .55741 .5401 .55453 .33544 Mtetra
0 0 .37 r
.55453 .33544 .55741 .5401 .55928 .54359 .55823 .53407 Mtetra
.077 .039 .507 r
.55823 .53407 .55928 .54359 .56113 .54484 .56014 .54172 Mtetra
.113 .202 .679 r
.56014 .54172 .56113 .54484 .56297 .54526 .56201 .54409 Mtetra
.387 .612 .94 r
.56201 .54409 .56297 .54526 .56482 .54532 .56385 .54437 Mtetra
.634 .773 .947 r
.56385 .54437 .56482 .54532 .56666 .54489 .56569 .54385 Mtetra
.746 .787 .886 r
.56569 .54385 .56666 .54489 .56849 .54382 .56753 .54278 Mtetra
.836 .799 .815 r
.56753 .54278 .56849 .54382 .57029 .54064 .56935 .5409 Mtetra
.924 .975 .744 r
.56935 .5409 .57029 .54064 .57203 .53298 .57116 .53826 Mtetra
.174 0 .293 r
.57116 .53826 .57203 .53298 .57094 .33202 .57296 .53472 Mtetra
.54 .317 .526 r
.57296 .53472 .57094 .33202 .57264 .32964 .57479 .53372 Mtetra
.541 .319 .526 r
.57479 .53372 .57264 .32964 .57437 .32923 .57664 .5336 Mtetra
.54 .317 .526 r
.57664 .5336 .57437 .32923 .57611 .32904 .57848 .53256 Mtetra
0 0 .375 r
.57848 .53256 .57611 .32904 .57781 .3266 .57711 .33751 Mtetra
0 0 .242 r
.57711 .33751 .57781 .3266 .57951 .32418 .57864 .32505 Mtetra
.932 .935 .578 r
.57864 .32505 .57951 .32418 .58121 .32234 .58032 .32138 Mtetra
.784 .8 .866 r
.58032 .32138 .58121 .32234 .58294 .32146 .58204 .32014 Mtetra
.634 .686 .881 r
.58204 .32014 .58294 .32146 .58467 .32099 .58377 .31968 Mtetra
.569 .66 .899 r
.58377 .31968 .58467 .32099 .58641 .32063 .58551 .31949 Mtetra
.688 .739 .89 r
.58551 .31949 .58641 .32063 .58814 .31973 .58725 .31877 Mtetra
.712 .785 .909 r
.58725 .31877 .58814 .31973 .58986 .31885 .58898 .31796 Mtetra
.659 .786 .942 r
.58898 .31796 .58986 .31885 .5916 .31839 .59071 .31738 Mtetra
.443 .665 .956 r
.59071 .31738 .5916 .31839 .59338 .31964 .59247 .31747 Mtetra
.356 .424 .794 r
.59247 .31747 .59338 .31964 .59523 .32416 .59424 .31834 Mtetra
.364 .278 .623 r
.59424 .31834 .59523 .32416 .6016 .52541 .59604 .32069 Mtetra
0 0 .389 r
.59604 .32069 .6016 .52541 .60357 .52982 .60236 .51728 Mtetra
.075 .024 .49 r
.60236 .51728 .60357 .52982 .60548 .53123 .60448 .5277 Mtetra
.128 .191 .661 r
.60448 .5277 .60548 .53123 .60737 .53173 .60642 .53038 Mtetra
.33 .546 .91 r
.60642 .53038 .60737 .53173 .60926 .53184 .60831 .5309 Mtetra
.604 .769 .959 r
.60831 .5309 .60926 .53184 .61113 .5315 .61019 .53048 Mtetra
.732 .793 .901 r
.61019 .53048 .61113 .5315 .61299 .53055 .61204 .5295 Mtetra
.795 .8 .856 r
.61204 .5295 .61299 .53055 .6148 .52797 .61389 .52806 Mtetra
.884 .988 .805 r
.61389 .52806 .6148 .52797 .61653 .52229 .61572 .52593 Mtetra
0 0 .155 r
.61572 .52593 .61653 .52229 .61276 .31987 .61751 .52239 Mtetra
.038 0 .407 r
.61751 .52239 .61276 .31987 .61436 .31399 .61428 .34121 Mtetra
0 0 .339 r
.61428 .34121 .61436 .31399 .61606 .31154 .61525 .31294 Mtetra
.783 .857 .411 r
.61525 .31294 .61606 .31154 .61778 .30998 .61691 .30923 Mtetra
.82 .85 .871 r
.61691 .30923 .61778 .30998 .61953 .30912 .61864 .3078 Mtetra
.638 .691 .883 r
.61864 .3078 .61953 .30912 .62129 .30865 .6204 .30731 Mtetra
.56 .653 .898 r
.6204 .30731 .62129 .30865 .62305 .30835 .62217 .30715 Mtetra
.644 .716 .901 r
.62217 .30715 .62305 .30835 .6248 .30764 .62393 .30664 Mtetra
.687 .772 .916 r
.62393 .30664 .6248 .30764 .62655 .30684 .62568 .30594 Mtetra
.64 .778 .947 r
.62568 .30594 .62655 .30684 .62832 .30643 .62745 .30542 Mtetra
.483 .685 .956 r
.62745 .30542 .62832 .30643 .63014 .30753 .62923 .3054 Mtetra
.399 .456 .803 r
.62923 .3054 .63014 .30753 .63207 .31197 .63103 .3061 Mtetra
.403 .305 .629 r
.63103 .3061 .63207 .31197 .64085 .51304 .63289 .30809 Mtetra
.008 0 .408 r
.63289 .30809 .64085 .51304 .64292 .51774 .64143 .50071 Mtetra
.075 .014 .476 r
.64143 .50071 .64292 .51774 .64488 .51919 .64385 .51525 Mtetra
.157 .194 .65 r
.64385 .51525 .64488 .51919 .64681 .51971 .64586 .51817 Mtetra
.344 .519 .886 r
.64586 .51817 .64681 .51971 .64872 .51971 .6478 .51877 Mtetra
.631 .782 .954 r
.6478 .51877 .64872 .51971 .65062 .51924 .64969 .51824 Mtetra
.75 .805 .896 r
.64969 .51824 .65062 .51924 .65249 .51818 .65157 .51714 Mtetra
.797 .806 .859 r
.65157 .51714 .65249 .51818 .65432 .51571 .65343 .51568 Mtetra
.867 .989 .831 r
.65343 .51568 .65432 .51571 .65602 .5102 .65528 .51373 Mtetra
.058 0 .187 r
.65528 .51373 .65602 .5102 .64987 .30814 .65707 .51063 Mtetra
.525 .306 .525 r
.65707 .51063 .64987 .30814 .65142 .30183 .6586 .50075 Mtetra
0 0 .39 r
.6586 .50075 .65142 .30183 .65312 .2994 .65239 .30167 Mtetra
0 0 0 r
.65239 .30167 .65312 .2994 .65485 .29785 .65402 .2974 Mtetra
.875 .918 .852 r
.65402 .2974 .65485 .29785 .65661 .29687 .65575 .29562 Mtetra
.677 .721 .882 r
.65575 .29562 .65661 .29687 .65839 .29626 .65752 .29494 Mtetra
.604 .679 .894 r
.65752 .29494 .65839 .29626 .66018 .2958 .65931 .2946 Mtetra
.65 .72 .9 r
.65931 .2946 .66018 .2958 .66195 .29507 .66109 .29405 Mtetra
.698 .775 .911 r
.66109 .29405 .66195 .29507 .66372 .2942 .66287 .29328 Mtetra
.653 .783 .943 r
.66287 .29328 .66372 .2942 .66551 .29371 .66465 .2927 Mtetra
.517 .706 .956 r
.66465 .2927 .66551 .29371 .66736 .29452 .66646 .29259 Mtetra
.414 .487 .826 r
.66646 .29259 .66736 .29452 .66935 .29832 .6683 .29316 Mtetra
.415 .327 .648 r
.6683 .29316 .66935 .29832 .68059 .49937 .67019 .29482 Mtetra
.527 .312 .532 r
.67019 .29482 .68059 .49937 .6828 .50508 .67241 .30318 Mtetra
.001 0 .41 r
.67241 .30318 .6828 .50508 .68481 .50655 .68371 .50159 Mtetra
.186 .183 .622 r
.68371 .50159 .68481 .50655 .68678 .5071 .68583 .50515 Mtetra
.219 .381 .813 r
.68583 .50515 .68678 .5071 .68874 .50739 .68784 .50641 Mtetra
.433 .684 .969 r
.68784 .50641 .68874 .50739 .69069 .5074 .68979 .50648 Mtetra
.701 .812 .934 r
.68979 .50648 .69069 .5074 .6926 .50668 .6917 .50565 Mtetra
.905 .813 .746 r
.6917 .50565 .6926 .50668 .69441 .50385 .69351 .5027 Mtetra
.975 .735 .51 r
.69351 .5027 .69441 .50385 .69575 .4918 .69482 .49022 Mtetra
.976 .683 .392 r
.69482 .49022 .69575 .4918 .6871 .2887 .68625 .2875 Mtetra
.905 .779 .712 r
.68625 .2875 .6871 .2887 .68876 .28545 .68791 .28429 Mtetra
.712 .753 .884 r
.68791 .28429 .68876 .28545 .69055 .28458 .6897 .28343 Mtetra
.595 .71 .924 r
.6897 .28343 .69055 .28458 .69236 .28423 .69151 .28309 Mtetra
.67 .744 .905 r
.69151 .28309 .69236 .28423 .69416 .28357 .69331 .28245 Mtetra
.755 .775 .869 r
.69331 .28245 .69416 .28357 .69593 .28244 .69509 .28133 Mtetra
.664 .747 .912 r
.69509 .28133 .69593 .28244 .69773 .28181 .69689 .28071 Mtetra
0 .365 .834 r
.69689 .28071 .69773 .28181 .69963 .2829 .69879 .28182 Mtetra
.924 .548 .143 r
.69879 .28182 .69963 .2829 .70194 .29113 .70111 .29029 Mtetra
.975 .673 .367 r
.70111 .29029 .70194 .29113 .71554 .49564 .71465 .49462 Mtetra
.638 .164 0 r
.71465 .49462 .71554 .49564 .71768 .49858 .71679 .49752 Mtetra
.428 .666 .961 r
.71679 .49752 .71768 .49858 .71966 .49871 .71877 .49764 Mtetra
.728 .793 .904 r
.71877 .49764 .71966 .49871 .72158 .49773 .72069 .49665 Mtetra
.904 .812 .747 r
.72069 .49665 .72158 .49773 .72338 .49481 .72249 .49373 Mtetra
.979 .742 .51 r
.72249 .49373 .72338 .49481 .72466 .48324 .72377 .48215 Mtetra
.977 .681 .378 r
.72377 .48215 .72466 .48324 .71422 .27979 .71338 .27865 Mtetra
.92 .788 .699 r
.71338 .27865 .71422 .27979 .71586 .27633 .71502 .27518 Mtetra
.72 .761 .885 r
.71502 .27518 .71586 .27633 .71766 .27542 .71682 .27427 Mtetra
.598 .713 .925 r
.71682 .27427 .71766 .27542 .71949 .27507 .71865 .27392 Mtetra
.634 .729 .917 r
.71865 .27392 .71949 .27507 .72132 .27458 .72048 .27343 Mtetra
.739 .768 .876 r
.72048 .27343 .72132 .27458 .72311 .27355 .72227 .2724 Mtetra
.651 .736 .912 r
.72227 .2724 .72311 .27355 .72493 .27299 .7241 .27184 Mtetra
.112 .432 .873 r
.7241 .27184 .72493 .27299 .72685 .27392 .72602 .27278 Mtetra
.906 .522 .091 r
.72602 .27278 .72685 .27392 .72923 .28176 .7284 .28062 Mtetra
.975 .671 .352 r
.7284 .28062 .72923 .28176 .74469 .4863 .74381 .48521 Mtetra
.602 .139 0 r
.74381 .48521 .74469 .4863 .74689 .48925 .74601 .48816 Mtetra
.553 .722 .953 r
.74601 .48816 .74689 .48925 .74887 .48901 .74799 .48792 Mtetra
.713 .787 .91 r
.74799 .48792 .74887 .48901 .75081 .4881 .74993 .48701 Mtetra
.696 .781 .917 r
.74993 .48701 .75081 .4881 .75275 .48727 .75188 .48618 Mtetra
.51 .702 .957 r
.75188 .48618 .75275 .48727 .75475 .48717 .75388 .48608 Mtetra
.654 .766 .932 r
.75388 .48608 .75475 .48717 .75672 .48654 .75584 .48545 Mtetra
.869 .818 .796 r
.75584 .48545 .75672 .48654 .75856 .48429 .75769 .4832 Mtetra
.98 .75 .517 r
.75769 .4832 .75856 .48429 .75984 .47406 .75898 .473 Mtetra
.977 .678 .362 r
.75898 .473 .75984 .47406 .74711 .26895 .74628 .26781 Mtetra
.933 .79 .678 r
.74628 .26781 .74711 .26895 .74871 .26512 .74789 .26397 Mtetra
.727 .766 .884 r
.74789 .26397 .74871 .26512 .75052 .26416 .7497 .26301 Mtetra
.601 .715 .925 r
.7497 .26301 .75052 .26416 .75238 .2638 .75156 .26265 Mtetra
.6 .715 .925 r
.75156 .26265 .75238 .2638 .75424 .26344 .75342 .26229 Mtetra
.739 .77 .878 r
.75342 .26229 .75424 .26344 .75605 .26241 .75523 .26126 Mtetra
.656 .739 .911 r
.75523 .26126 .75605 .26241 .75789 .26182 .75707 .26066 Mtetra
.23 .508 .907 r
.75707 .26066 .75789 .26182 .75983 .26252 .75902 .26136 Mtetra
.884 .493 .039 r
.75902 .26136 .75983 .26252 .76229 .26983 .76147 .26868 Mtetra
.975 .667 .334 r
.76147 .26868 .76229 .26983 .7801 .47552 .77924 .47442 Mtetra
.654 .2 0 r
.77924 .47442 .7801 .47552 .7824 .47898 .78154 .47787 Mtetra
.382 .631 .952 r
.78154 .47787 .7824 .47898 .78445 .47925 .78359 .47814 Mtetra
.692 .78 .918 r
.78359 .47814 .78445 .47925 .78642 .47843 .78556 .47732 Mtetra
.873 .82 .793 r
.78556 .47732 .78642 .47843 .78827 .47612 .78741 .47501 Mtetra
.978 .767 .552 r
.78741 .47501 .78827 .47612 .78968 .46829 .78882 .46719 Mtetra
.977 .675 .347 r
.78882 .46719 .78968 .46829 .77487 .26051 .77405 .25935 Mtetra
.951 .785 .641 r
.77405 .25935 .77487 .26051 .7764 .25591 .77559 .25475 Mtetra
.745 .772 .875 r
.77559 .25475 .7764 .25591 .77822 .25484 .77741 .25367 Mtetra
.617 .722 .921 r
.77741 .25367 .77822 .25484 .78009 .25441 .77928 .25324 Mtetra
.584 .707 .927 r
.77928 .25324 .78009 .25441 .78197 .2541 .78116 .25294 Mtetra
.747 .773 .874 r
.78116 .25294 .78197 .2541 .78379 .25302 .78298 .25185 Mtetra
.67 .744 .906 r
.78298 .25185 .78379 .25302 .78565 .25235 .78484 .25118 Mtetra
.35 .58 .928 r
.78484 .25118 .78565 .25235 .7876 .25277 .78679 .2516 Mtetra
.838 .433 0 r
.78679 .2516 .7876 .25277 .79004 .25891 .78924 .25775 Mtetra
.973 .663 .318 r
.78924 .25775 .79004 .25891 .8099 .46585 .80905 .46474 Mtetra
.693 .247 0 r
.80905 .46474 .8099 .46585 .8123 .4698 .81145 .46869 Mtetra
.348 .61 .947 r
.81145 .46869 .8123 .4698 .81439 .47016 .81354 .46905 Mtetra
.675 .775 .926 r
.81354 .46905 .81439 .47016 .81638 .46942 .81554 .46831 Mtetra
.857 .823 .814 r
.81554 .46831 .81638 .46942 .81826 .46734 .81742 .46624 Mtetra
.978 .777 .565 r
.81742 .46624 .81826 .46734 .81969 .46026 .81885 .4592 Mtetra
.976 .672 .332 r
.81885 .4592 .81969 .46026 .80288 .2516 .80208 .25048 Mtetra
.964 .786 .614 r
.80208 .25048 .80288 .2516 .80434 .24646 .80355 .24531 Mtetra
.752 .779 .876 r
.80355 .24531 .80434 .24646 .80617 .24535 .80538 .24419 Mtetra
.612 .722 .924 r
.80538 .24419 .80617 .24535 .80807 .24494 .80727 .24377 Mtetra
.536 .684 .934 r
.80727 .24377 .80807 .24494 .80999 .24482 .80919 .24364 Mtetra
.719 .763 .888 r
.80919 .24364 .80999 .24482 .81185 .24404 .81104 .24271 Mtetra
.662 .714 .886 r
.81104 .24271 .81185 .24404 .81373 .24339 .81292 .24207 Mtetra
.515 .642 .912 r
.81292 .24207 .81373 .24339 .81563 .24303 .81486 .24205 Mtetra
0 0 .471 r
.81486 .24205 .81563 .24303 .81761 .24337 .81705 .24469 Mtetra
.972 .657 .311 r
.81705 .24469 .81761 .24337 .81967 .24457 .83781 .44084 Mtetra
.564 .335 .527 r
.83781 .44084 .81967 .24457 .82196 .24819 .84125 .45504 Mtetra
.544 .321 .526 r
.84125 .45504 .82196 .24819 .8437 .45142 .84351 .45688 Mtetra
.555 .248 .402 r
.84351 .45688 .8437 .45142 .84631 .45677 .84566 .45754 Mtetra
.345 0 0 r
.84566 .45754 .84631 .45677 .84859 .45868 .84776 .4576 Mtetra
.455 .679 .961 r
.84776 .4576 .84859 .45868 .8507 .45897 .84986 .45765 Mtetra
.639 .724 .91 r
.84986 .45765 .8507 .45897 .85274 .45837 .85189 .45709 Mtetra
.786 .784 .851 r
.85189 .45709 .85274 .45837 .85467 .45675 .85384 .45561 Mtetra
.975 .788 .587 r
.85384 .45561 .85467 .45675 .85615 .45065 .85532 .44948 Mtetra
.974 .667 .312 r
.85532 .44948 .85615 .45065 .83693 .24141 .83615 .24019 Mtetra
.973 .773 .576 r
.83615 .24019 .83693 .24141 .83826 .23521 .83748 .23401 Mtetra
.758 .756 .851 r
.2275 .44087 .22853 .44184 .23009 .44079 .22906 .43982 Mtetra
.607 .723 .927 r
.22906 .43982 .23009 .44079 .23159 .44048 .23057 .43951 Mtetra
.443 .659 .952 r
.23057 .43951 .23159 .44048 .23306 .44058 .23203 .43959 Mtetra
.639 .728 .913 r
.23203 .43959 .23306 .44058 .23457 .44017 .23355 .43916 Mtetra
.648 .727 .906 r
.23355 .43916 .23457 .44017 .23609 .43974 .23507 .4387 Mtetra
.657 .725 .899 r
.23507 .4387 .23609 .43974 .23761 .43926 .23659 .43821 Mtetra
.679 .727 .886 r
.23659 .43821 .23761 .43926 .23913 .43871 .23812 .43761 Mtetra
.683 .72 .877 r
.23812 .43761 .23913 .43871 .24067 .4381 .23965 .43699 Mtetra
.684 .718 .875 r
.23965 .43699 .24067 .4381 .24221 .43743 .24119 .43636 Mtetra
.673 .722 .886 r
.24119 .43636 .24221 .43743 .24375 .43666 .24272 .43579 Mtetra
.674 .763 .918 r
.24272 .43579 .24375 .43666 .2453 .43588 .24425 .43523 Mtetra
.671 .814 .952 r
.24425 .43523 .2453 .43588 .24685 .43512 .24579 .43466 Mtetra
.671 .862 .972 r
.24579 .43466 .24685 .43512 .24839 .43448 .24732 .43405 Mtetra
.669 .872 .976 r
.24732 .43405 .24839 .43448 .24993 .43388 .24886 .43344 Mtetra
.667 .87 .976 r
.24886 .43344 .24993 .43388 .25147 .4333 .2504 .43284 Mtetra
.659 .862 .977 r
.2504 .43284 .25147 .4333 .253 .43273 .25194 .43227 Mtetra
.653 .859 .978 r
.25194 .43227 .253 .43273 .25454 .43218 .25347 .43171 Mtetra
.648 .858 .979 r
.25347 .43171 .25454 .43218 .25607 .43164 .25501 .43117 Mtetra
.644 .857 .981 r
.25501 .43117 .25607 .43164 .25761 .4311 .25655 .43063 Mtetra
.64 .857 .982 r
.25655 .43063 .25761 .4311 .25914 .43057 .25808 .43011 Mtetra
.635 .857 .984 r
.25808 .43011 .25914 .43057 .26068 .43005 .25962 .42959 Mtetra
.627 .857 .986 r
.25962 .42959 .26068 .43005 .26222 .42952 .26116 .4291 Mtetra
.62 .864 .989 r
.26116 .4291 .26222 .42952 .26376 .42901 .26269 .4286 Mtetra
.62 .868 .989 r
.26269 .4286 .26376 .42901 .26529 .42852 .26423 .4281 Mtetra
.639 .868 .984 r
.26423 .4281 .26529 .42852 .26682 .42815 .26577 .42756 Mtetra
.661 .831 .965 r
.26577 .42756 .26682 .42815 .26835 .42779 .26732 .42701 Mtetra
.67 .784 .935 r
.26732 .42701 .26835 .42779 .26988 .4274 .26886 .42645 Mtetra
.665 .747 .911 r
.26886 .42645 .26988 .4274 .27143 .42681 .27041 .42592 Mtetra
.663 .76 .922 r
.27041 .42592 .27143 .42681 .27298 .42614 .27195 .42539 Mtetra
.66 .793 .946 r
.27195 .42539 .27298 .42614 .27454 .42545 .27349 .42487 Mtetra
.654 .832 .968 r
.27349 .42487 .27454 .42545 .27609 .42486 .27504 .42433 Mtetra
.651 .846 .975 r
.27504 .42433 .27609 .42486 .27764 .4243 .27659 .42379 Mtetra
.65 .85 .977 r
.27659 .42379 .27764 .4243 .27919 .42376 .27814 .42325 Mtetra
.658 .85 .973 r
.27814 .42325 .27919 .42376 .28075 .42308 .27969 .42268 Mtetra
.641 .877 .985 r
.27969 .42268 .28075 .42308 .2823 .42247 .28124 .42212 Mtetra
.621 .884 .989 r
.28124 .42212 .2823 .42247 .28384 .42208 .28279 .42158 Mtetra
.611 .844 .988 r
.28279 .42158 .28384 .42208 .28532 .42259 .28434 .42113 Mtetra
.633 .648 .847 r
.28434 .42113 .28532 .42259 .28674 .42384 .28588 .42072 Mtetra
.605 .501 .71 r
.28588 .42072 .28674 .42384 .2881 .42587 .28743 .42029 Mtetra
.588 .432 .637 r
.28743 .42029 .2881 .42587 .28957 .42666 .28899 .41977 Mtetra
.583 .414 .618 r
.28899 .41977 .28957 .42666 .29113 .42609 .29054 .41919 Mtetra
.29054 .41919 .29113 .42609 .29273 .42498 .2921 .41861 Mtetra
.603 .434 .625 r
.2921 .41861 .29273 .42498 .29435 .42356 .29369 .41771 Mtetra
.598 .436 .633 r
.29369 .41771 .29435 .42356 .29594 .42264 .29526 .41698 Mtetra
.562 .412 .635 r
.29526 .41698 .29594 .42264 .29745 .42283 .29679 .41684 Mtetra
.274 .198 .586 r
.29679 .41684 .29745 .42283 .2863 .6048 .29812 .41963 Mtetra
0 0 .178 r
.29812 .41963 .2863 .6048 .28663 .62333 .28595 .61679 Mtetra
0 0 .233 r
.28595 .61679 .28663 .62333 .28804 .62645 .28703 .62451 Mtetra
.213 .371 .806 r
.28703 .62451 .28804 .62645 .28963 .62695 .28859 .62552 Mtetra
.631 .667 .866 r
.28859 .62552 .28963 .62695 .29129 .6265 .29025 .62509 Mtetra
.71 .695 .834 r
.29025 .62509 .29129 .6265 .29297 .62573 .29194 .62419 Mtetra
.661 .661 .839 r
.29194 .62419 .29297 .62573 .29463 .62525 .29361 .62358 Mtetra
.63 .632 .834 r
.29361 .62358 .29463 .62525 .29629 .62481 .29526 .62314 Mtetra
.635 .633 .832 r
.29526 .62314 .29629 .62481 .29797 .62414 .29693 .62267 Mtetra
.657 .669 .85 r
.29693 .62267 .29797 .62414 .2997 .62258 .2986 .62209 Mtetra
.66 .867 .978 r
.2986 .62209 .2997 .62258 .30149 .62014 .30027 .62146 Mtetra
.18 0 0 r
.30027 .62146 .30149 .62014 .30334 .61686 .30195 .62082 Mtetra
.492 .175 .356 r
.30195 .62082 .30334 .61686 .30506 .61542 .3036 .62064 Mtetra
.502 .207 .397 r
.3036 .62064 .30506 .61542 .3067 .61542 .30525 .62041 Mtetra
.443 .149 .369 r
.30525 .62041 .3067 .61542 .30838 .61469 .30694 .61958 Mtetra
0 0 .168 r
.30694 .61958 .30838 .61469 .31082 .6019 .30882 .61584 Mtetra
.964 .709 .5 r
.30882 .61584 .31082 .6019 .3242 .41248 .32278 .41825 Mtetra
.808 .766 .254 r
.32278 .41825 .3242 .41248 .32599 .40854 .32493 .40859 Mtetra
.917 .927 .802 r
.32493 .40859 .32599 .40854 .32762 .40707 .32661 .4064 Mtetra
.698 .823 .942 r
.32661 .4064 .32762 .40707 .32919 .40661 .32819 .40572 Mtetra
.569 .735 .954 r
.32819 .40572 .32919 .40661 .33075 .40645 .32975 .40548 Mtetra
.627 .737 .927 r
.32975 .40548 .33075 .40645 .33233 .40589 .33132 .40508 Mtetra
.671 .785 .935 r
.33132 .40508 .33233 .40589 .33392 .4051 .33291 .40451 Mtetra
.651 .835 .971 r
.33291 .40451 .33392 .4051 .33551 .40451 .33449 .40397 Mtetra
.716 .858 .949 r
.33449 .40397 .33551 .40451 .33706 .40449 .33608 .4032 Mtetra
.688 .695 .852 r
.33608 .4032 .33706 .40449 .33857 .40523 .33768 .4025 Mtetra
.578 .505 .737 r
.33768 .4025 .33857 .40523 .34001 .40717 .33924 .40233 Mtetra
.303 .244 .624 r
.33924 .40233 .34001 .40717 .3408 .42072 .34067 .40446 Mtetra
.97 .707 .479 r
.34067 .40446 .3408 .42072 .33175 .60934 .33121 .59909 Mtetra
0 0 .286 r
.33121 .59909 .33175 .60934 .33323 .61244 .33225 .61013 Mtetra
.086 .245 .731 r
.33225 .61013 .33323 .61244 .33486 .61303 .33382 .61171 Mtetra
.603 .674 .89 r
.33382 .61171 .33486 .61303 .33655 .61246 .3355 .61139 Mtetra
.714 .754 .883 r
.3355 .61139 .33655 .61246 .33826 .61152 .3372 .61055 Mtetra
.694 .768 .909 r
.3372 .61055 .33826 .61152 .33995 .61096 .33891 .60983 Mtetra
.642 .724 .907 r
.33891 .60983 .33995 .61096 .34163 .61073 .3406 .60935 Mtetra
.648 .682 .868 r
.3406 .60935 .34163 .61073 .34332 .61028 .34229 .60883 Mtetra
.6 .652 .873 r
.34229 .60883 .34332 .61028 .34505 .60922 .34398 .60853 Mtetra
.559 .795 .987 r
.34398 .60853 .34505 .60922 .34681 .6073 .34566 .60821 Mtetra
0 0 0 r
.34566 .60821 .34681 .6073 .34865 .60406 .34738 .60732 Mtetra
.34738 .60732 .34865 .60406 .35097 .5913 .34922 .60404 Mtetra
.967 .708 .49 r
.34922 .60404 .35097 .5913 .36231 .39955 .3608 .4088 Mtetra
0 0 0 r
.3608 .4088 .36231 .39955 .36407 .39569 .36303 .39596 Mtetra
.942 .94 .76 r
.36303 .39596 .36407 .39569 .36573 .39407 .36473 .39337 Mtetra
.711 .822 .934 r
.36473 .39337 .36573 .39407 .36732 .39358 .36634 .39263 Mtetra
.578 .726 .944 r
.36634 .39263 .36732 .39358 .3689 .39346 .36793 .39237 Mtetra
.594 .703 .919 r
.36793 .39237 .3689 .39346 .37049 .39324 .36952 .39209 Mtetra
.651 .71 .891 r
.36952 .39209 .37049 .39324 .37209 .39275 .37112 .39159 Mtetra
.651 .708 .889 r
.37112 .39159 .37209 .39275 .37369 .39222 .37272 .39109 Mtetra
.658 .716 .891 r
.37272 .39109 .37369 .39222 .3753 .39169 .37433 .39056 Mtetra
.665 .72 .89 r
.37433 .39056 .3753 .39169 .3769 .39114 .37593 .39 Mtetra
.667 .717 .886 r
.37593 .39 .3769 .39114 .37851 .39056 .37754 .38943 Mtetra
.665 .719 .889 r
.37754 .38943 .37851 .39056 .38012 .38989 .37915 .38887 Mtetra
.664 .74 .907 r
.37915 .38887 .38012 .38989 .38174 .38914 .38076 .38832 Mtetra
.662 .784 .939 r
.38076 .38832 .38174 .38914 .38336 .38839 .38237 .38777 Mtetra
.719 .843 .941 r
.38237 .38777 .38336 .38839 .38498 .38756 .38399 .38698 Mtetra
.744 .857 .932 r
.38399 .38698 .38498 .38756 .38661 .38675 .38562 .38609 Mtetra
.608 .81 .978 r
.38562 .38609 .38661 .38675 .38821 .38629 .38722 .38567 Mtetra
.564 .009 0 r
.38722 .38567 .38821 .38629 .38978 .38693 .38876 .38698 Mtetra
.933 .614 .412 r
.38876 .38698 .38978 .38693 .39124 .39007 .38992 .39739 Mtetra
.944 .673 .495 r
.38992 .39739 .39124 .39007 .38489 .5832 .38339 .59362 Mtetra
.608 .339 .483 r
.38339 .59362 .38489 .5832 .38626 .59117 .38499 .59601 Mtetra
.497 .196 .385 r
.38499 .59601 .38626 .59117 .38798 .59079 .3867 .59577 Mtetra
.445 .151 .37 r
.3867 .59577 .38798 .59079 .38972 .58977 .38844 .59494 Mtetra
.452 .16 .377 r
.38844 .59494 .38972 .58977 .39139 .59046 .39017 .59413 Mtetra
.462 .138 .331 r
.39017 .59413 .39139 .59046 .39301 .59265 .39189 .59373 Mtetra
.24 0 0 r
.39189 .59373 .39301 .59265 .39466 .59401 .39361 .59333 Mtetra
.598 .815 .983 r
.39361 .59333 .39466 .59401 .39635 .59444 .39534 .5929 Mtetra
.637 .657 .853 r
.39534 .5929 .39635 .59444 .39807 .59406 .39707 .59241 Mtetra
.641 .646 .839 r
.39707 .59241 .39807 .59406 .39981 .59343 .3988 .59189 Mtetra
.612 .647 .861 r
.3988 .59189 .39981 .59343 .40154 .59293 .40052 .59154 Mtetra
.573 .654 .891 r
.40052 .59154 .40154 .59293 .40326 .59268 .40224 .59134 Mtetra
.679 .703 .866 r
.40224 .59134 .40326 .59268 .405 .59209 .40398 .59064 Mtetra
.829 .727 .751 r
.40398 .59064 .405 .59209 .40677 .59042 .40578 .58829 Mtetra
.913 .694 .592 r
.40578 .58829 .40677 .59042 .40863 .5861 .40784 .5783 Mtetra
.949 .681 .496 r
.40784 .5783 .40863 .5861 .41665 .39847 .41631 .37903 Mtetra
.609 .396 .567 r
.41631 .37903 .41665 .39847 .41883 .38187 .41804 .37549 Mtetra
.6 .432 .626 r
.41804 .37549 .41883 .38187 .42047 .38109 .41969 .37463 Mtetra
.569 .409 .625 r
.41969 .37463 .42047 .38109 .42209 .38102 .42131 .37434 Mtetra
.565 .404 .622 r
.42131 .37434 .42209 .38102 .42375 .37965 .42294 .37411 Mtetra
.595 .438 .64 r
.42294 .37411 .42375 .37965 .42547 .37652 .42457 .37346 Mtetra
.627 .52 .713 r
.42457 .37346 .42547 .37652 .42716 .37423 .42621 .37281 Mtetra
.665 .675 .85 r
.42621 .37281 .42716 .37423 .42882 .37278 .42785 .37221 Mtetra
.636 .843 .979 r
.42785 .37221 .42882 .37278 .43046 .37224 .42949 .37168 Mtetra
.63 .844 .982 r
.42949 .37168 .43046 .37224 .43209 .37194 .43113 .37116 Mtetra
.653 .796 .951 r
.43113 .37116 .43209 .37194 .43372 .37165 .43277 .37063 Mtetra
.668 .745 .908 r
.43277 .37063 .43372 .37165 .43536 .37113 .43441 .37004 Mtetra
.669 .732 .897 r
.43441 .37004 .43536 .37113 .43701 .37056 .43606 .36946 Mtetra
.668 .729 .895 r
.43606 .36946 .43701 .37056 .43865 .36991 .4377 .36887 Mtetra
.665 .742 .907 r
.4377 .36887 .43865 .36991 .4403 .36916 .43934 .3683 Mtetra
.663 .781 .937 r
.43934 .3683 .4403 .36916 .44195 .36841 .44099 .36774 Mtetra
.693 .835 .951 r
.44099 .36774 .44195 .36841 .4436 .36761 .44264 .36705 Mtetra
.757 .868 .929 r
.44264 .36705 .4436 .36761 .44526 .36674 .4443 .36608 Mtetra
.65 .825 .967 r
.4443 .36608 .44526 .36674 .44691 .36618 .44595 .36552 Mtetra
0 .43 .827 r
.44595 .36552 .44691 .36618 .44853 .36642 .44757 .36616 Mtetra
.925 .561 .311 r
.44757 .36616 .44853 .36642 .45011 .36898 .44906 .37232 Mtetra
.955 .679 .473 r
.44906 .37232 .45011 .36898 .45146 .38154 .44603 .57328 Mtetra
.548 .324 .527 r
.44603 .57328 .45146 .38154 .44885 .57194 .4477 .57685 Mtetra
.511 .209 .391 r
.4477 .57685 .44885 .57194 .4506 .57183 .44945 .57677 Mtetra
.453 .158 .373 r
.44945 .57677 .4506 .57183 .45237 .57083 .45122 .57602 Mtetra
.442 .151 .375 r
.45122 .57602 .45237 .57083 .45412 .57076 .453 .57507 Mtetra
.475 .165 .361 r
.453 .57507 .45412 .57076 .45582 .57314 .45476 .57466 Mtetra
.328 0 .054 r
.45476 .57466 .45582 .57314 .45755 .57466 .45652 .57425 Mtetra
.537 .86 .996 r
.45652 .57425 .45755 .57466 .45929 .57534 .45829 .57381 Mtetra
.64 .664 .857 r
.45829 .57381 .45929 .57534 .46106 .57498 .46006 .5733 Mtetra
.642 .645 .837 r
.46006 .5733 .46106 .57498 .46283 .57438 .46183 .57277 Mtetra
.646 .655 .844 r
.46183 .57277 .46283 .57438 .4646 .57375 .4636 .57221 Mtetra
.649 .667 .854 r
.4636 .57221 .4646 .57375 .46637 .57339 .46538 .57165 Mtetra
.645 .638 .829 r
.46538 .57165 .46637 .57339 .46814 .57302 .46715 .57108 Mtetra
.638 .614 .809 r
.46715 .57108 .46814 .57302 .46992 .57258 .46893 .57053 Mtetra
.63 .599 .8 r
.46893 .57053 .46992 .57258 .47169 .57195 .4707 .57002 Mtetra
.632 .612 .812 r
.4707 .57002 .47169 .57195 .47347 .57128 .47248 .56951 Mtetra
.624 .627 .833 r
.47248 .56951 .47347 .57128 .47525 .57066 .47426 .56907 Mtetra
.548 .615 .871 r
.47426 .56907 .47525 .57066 .47703 .57041 .47603 .56899 Mtetra
.641 .682 .873 r
.47603 .56899 .47703 .57041 .47881 .5699 .47781 .56848 Mtetra
.779 .727 .805 r
.47781 .56848 .47881 .5699 .4806 .56871 .47961 .56695 Mtetra
.911 .713 .623 r
.47961 .56695 .4806 .56871 .48242 .56501 .48147 .5603 Mtetra
.959 .686 .473 r
.48147 .5603 .48242 .56501 .48431 .55534 .48575 .35709 Mtetra
.552 .332 .534 r
.48575 .35709 .48431 .55534 .48835 .35846 .48748 .35198 Mtetra
.612 .44 .625 r
.48748 .35198 .48835 .35846 .49004 .35678 .48916 .35084 Mtetra
.581 .424 .634 r
.48916 .35084 .49004 .35678 .49171 .35643 .49083 .35037 Mtetra
.564 .411 .632 r
.49083 .35037 .49171 .35643 .49338 .35664 .49251 .35018 Mtetra
.605 .435 .625 r
.49251 .35018 .49338 .35664 .49507 .35524 .49419 .3492 Mtetra
.587 .427 .632 r
.49419 .3492 .49507 .35524 .49675 .35463 .49587 .34861 Mtetra
.535 .391 .632 r
.49587 .34861 .49675 .35463 .49842 .35581 .49754 .34887 Mtetra
.076 .054 .526 r
.49754 .34887 .49842 .35581 .49856 .55393 .49917 .35423 Mtetra
0 0 .33 r
.49917 .35423 .49856 .55393 .5003 .56034 .49932 .5566 Mtetra
0 0 .48 r
.49932 .5566 .5003 .56034 .50207 .5626 .50108 .56095 Mtetra
.506 .586 .869 r
.50108 .56095 .50207 .5626 .50386 .56261 .50288 .56105 Mtetra
.66 .669 .848 r
.50288 .56105 .50386 .56261 .50566 .56215 .50468 .56041 Mtetra
.705 .667 .81 r
.50468 .56041 .50566 .56215 .50746 .56143 .50648 .55941 Mtetra
.639 .608 .802 r
.50648 .55941 .50746 .56143 .50926 .56093 .50828 .55884 Mtetra
.639 .601 .795 r
.50828 .55884 .50926 .56093 .51107 .56037 .51008 .55825 Mtetra
.638 .598 .793 r
.51008 .55825 .51107 .56037 .51287 .55976 .51189 .55767 Mtetra
.628 .597 .799 r
.51189 .55767 .51287 .55976 .51468 .55923 .51369 .55716 Mtetra
.629 .6 .801 r
.51369 .55716 .51468 .55923 .51648 .55854 .5155 .55665 Mtetra
.637 .622 .818 r
.5155 .55665 .51648 .55854 .51829 .55758 .51731 .55611 Mtetra
.667 .687 .859 r
.51731 .55611 .51829 .55758 .5201 .55555 .51911 .55544 Mtetra
.547 .918 .945 r
.51911 .55544 .5201 .55555 .52191 .55281 .52092 .55474 Mtetra
.311 0 .119 r
.52092 .55474 .52191 .55281 .52372 .54924 .52274 .55405 Mtetra
.51 .206 .386 r
.52274 .55405 .52372 .54924 .52553 .54885 .52455 .55398 Mtetra
.486 .19 .387 r
.52455 .55398 .52553 .54885 .52734 .54865 .52636 .55356 Mtetra
.416 .125 .36 r
.52636 .55356 .52734 .54865 .52915 .54737 .52817 .55238 Mtetra
0 0 .106 r
.52817 .55238 .52915 .54737 .5306 .34889 .52998 .54653 Mtetra
0 0 .328 r
.52998 .54653 .5306 .34889 .53229 .34024 .53138 .34246 Mtetra
.889 .844 .385 r
.53138 .34246 .53229 .34024 .53398 .33693 .53307 .33651 Mtetra
.826 .914 .897 r
.53307 .33651 .53398 .33693 .53568 .33598 .53477 .33513 Mtetra
.658 .789 .944 r
.53477 .33513 .53568 .33598 .53739 .33559 .53647 .33456 Mtetra
.556 .709 .943 r
.53647 .33456 .53739 .33559 .53909 .33544 .53818 .33436 Mtetra
.654 .738 .911 r
.53818 .33436 .53909 .33544 .5408 .3348 .53989 .33382 Mtetra
.659 .761 .925 r
.53989 .33382 .5408 .3348 .5425 .33407 .54159 .33325 Mtetra
.655 .797 .951 r
.54159 .33325 .5425 .33407 .54421 .33334 .5433 .33269 Mtetra
.662 .841 .969 r
.5433 .33269 .54421 .33334 .54592 .33254 .54501 .33207 Mtetra
.64 .879 .985 r
.54501 .33207 .54592 .33254 .54763 .33188 .54672 .33145 Mtetra
.62 .883 .989 r
.54672 .33145 .54763 .33188 .54934 .33149 .54843 .33086 Mtetra
.733 .862 .942 r
.54843 .33086 .54934 .33149 .55106 .33174 .55014 .32997 Mtetra
.653 .63 .815 r
.55014 .32997 .55106 .33174 .55279 .33275 .55186 .32936 Mtetra
.55 .462 .709 r
.55186 .32936 .55279 .33275 .55453 .33544 .55358 .3294 Mtetra
.215 .168 .587 r
.55358 .3294 .55453 .33544 .55823 .53407 .55534 .33316 Mtetra
0 0 .357 r
.55534 .33316 .55823 .53407 .56014 .54172 .55913 .53626 Mtetra
0 0 .482 r
.55913 .53626 .56014 .54172 .56201 .54409 .56103 .54214 Mtetra
.395 .487 .836 r
.56103 .54214 .56201 .54409 .56385 .54437 .56288 .54274 Mtetra
.634 .655 .853 r
.56288 .54274 .56385 .54437 .56569 .54385 .56472 .54225 Mtetra
.705 .687 .83 r
.56472 .54225 .56569 .54385 .56753 .54278 .56656 .54129 Mtetra
.678 .691 .855 r
.56656 .54129 .56753 .54278 .56935 .5409 .5684 .54054 Mtetra
.628 .91 .983 r
.5684 .54054 .56935 .5409 .57116 .53826 .57024 .53983 Mtetra
.248 0 .026 r
.57024 .53983 .57116 .53826 .57296 .53472 .57208 .5391 Mtetra
.499 .187 .369 r
.57208 .5391 .57296 .53472 .57479 .53372 .57393 .53894 Mtetra
.493 .196 .391 r
.57393 .53894 .57479 .53372 .57664 .5336 .57578 .53859 Mtetra
.433 .141 .368 r
.57578 .53859 .57664 .5336 .57848 .53256 .57762 .53755 Mtetra
0 0 .203 r
.57762 .53755 .57848 .53256 .57711 .33751 .5794 .53276 Mtetra
0 0 .344 r
.5794 .53276 .57711 .33751 .57864 .32505 .57782 .32844 Mtetra
.752 .73 .204 r
.57782 .32844 .57864 .32505 .58032 .32138 .57944 .32112 Mtetra
.882 .942 .849 r
.57944 .32112 .58032 .32138 .58204 .32014 .58115 .31932 Mtetra
.677 .807 .944 r
.58115 .31932 .58204 .32014 .58377 .31968 .58288 .31866 Mtetra
.568 .721 .945 r
.58288 .31866 .58377 .31968 .58551 .31949 .58462 .31841 Mtetra
.646 .739 .917 r
.58462 .31841 .58551 .31949 .58725 .31877 .58636 .3179 Mtetra
.666 .79 .941 r
.58636 .3179 .58725 .31877 .58898 .31796 .58809 .31729 Mtetra
.644 .833 .973 r
.58809 .31729 .58898 .31796 .59071 .31738 .58983 .31671 Mtetra
.721 .856 .946 r
.58983 .31671 .59071 .31738 .59247 .31747 .59156 .31587 Mtetra
.667 .659 .833 r
.59156 .31587 .59247 .31747 .59424 .31834 .5933 .31519 Mtetra
.563 .482 .722 r
.5933 .31519 .59424 .31834 .59604 .32069 .59505 .31511 Mtetra
.287 .229 .616 r
.59505 .31511 .59604 .32069 .60236 .51728 .59688 .31807 Mtetra
0 0 .373 r
.59688 .31807 .60236 .51728 .60448 .5277 .6034 .52091 Mtetra
0 0 .471 r
.6034 .52091 .60448 .5277 .60642 .53038 .60545 .52824 Mtetra
.301 .409 .805 r
.60545 .52824 .60642 .53038 .60831 .5309 .60735 .52929 Mtetra
.614 .649 .861 r
.60735 .52929 .60831 .5309 .61019 .53048 .60923 .52889 Mtetra
.697 .688 .837 r
.60923 .52889 .61019 .53048 .61204 .5295 .61109 .52798 Mtetra
.621 .667 .873 r
.61109 .52798 .61204 .5295 .61389 .52806 .61296 .52755 Mtetra
.552 .854 .998 r
.61296 .52755 .61389 .52806 .61572 .52593 .61484 .52708 Mtetra
0 0 0 r
.61484 .52708 .61572 .52593 .61751 .52239 .6167 .52598 Mtetra
0 0 .106 r
.6167 .52598 .61751 .52239 .61428 .34121 .61847 .52193 Mtetra
0 0 .334 r
.61847 .52193 .61428 .34121 .61525 .31294 .61457 .31903 Mtetra
0 0 .053 r
.61457 .31903 .61525 .31294 .61691 .30923 .61606 .30925 Mtetra
.913 .973 .787 r
.61606 .30925 .61691 .30923 .61864 .3078 .61777 .30704 Mtetra
.69 .828 .95 r
.61777 .30704 .61864 .3078 .6204 .30731 .61952 .30631 Mtetra
.57 .729 .949 r
.61952 .30631 .6204 .30731 .62217 .30715 .62129 .30605 Mtetra
.628 .729 .919 r
.62129 .30605 .62217 .30715 .62393 .30664 .62305 .3056 Mtetra
.667 .756 .917 r
.62305 .3056 .62393 .30664 .62568 .30594 .62481 .30498 Mtetra
.66 .773 .933 r
.62481 .30498 .62568 .30594 .62745 .30542 .62657 .30439 Mtetra
.716 .776 .899 r
.62657 .30439 .62745 .30542 .62923 .3054 .62833 .30354 Mtetra
.671 .632 .802 r
.62833 .30354 .62923 .3054 .63103 .3061 .63008 .30277 Mtetra
.577 .483 .712 r
.63008 .30277 .63103 .3061 .63289 .30809 .63186 .30256 Mtetra
.356 .279 .63 r
.63186 .30256 .63289 .30809 .64143 .50071 .63373 .30491 Mtetra
0 0 .384 r
.63373 .30491 .64143 .50071 .64385 .51525 .64265 .5065 Mtetra
0 0 .466 r
.64265 .5065 .64385 .51525 .64586 .51817 .64489 .51578 Mtetra
.242 .347 .771 r
.64489 .51578 .64586 .51817 .6478 .51877 .64685 .51722 Mtetra
.604 .656 .874 r
.64685 .51722 .6478 .51877 .64969 .51824 .64876 .51687 Mtetra
.703 .725 .867 r
.64876 .51687 .64969 .51824 .65157 .51714 .65064 .51598 Mtetra
.635 .737 .922 r
.65064 .51598 .65157 .51714 .65343 .51568 .65254 .51546 Mtetra
.389 .831 .944 r
.65254 .51546 .65343 .51568 .65528 .51373 .65445 .51508 Mtetra
.125 0 0 r
.65445 .51508 .65528 .51373 .65707 .51063 .65633 .51411 Mtetra
0 0 .151 r
.65633 .51411 .65707 .51063 .6586 .50075 .65812 .51062 Mtetra
.982 .696 .38 r
.65812 .51062 .6586 .50075 .65239 .30167 .65195 .31123 Mtetra
0 0 .162 r
.65195 .31123 .65239 .30167 .65402 .2974 .65318 .29698 Mtetra
.934 .895 .766 r
.65318 .29698 .65402 .2974 .65575 .29562 .65488 .29438 Mtetra
.688 .728 .88 r
.65488 .29438 .65575 .29562 .65752 .29494 .65665 .29364 Mtetra
.58 .671 .902 r
.65665 .29364 .65752 .29494 .65931 .2946 .65844 .29339 Mtetra
.611 .704 .91 r
.65844 .29339 .65931 .2946 .66109 .29405 .66024 .29301 Mtetra
.675 .763 .917 r
.66024 .29301 .66109 .29405 .66287 .29328 .66202 .29235 Mtetra
.672 .786 .934 r
.66202 .29235 .66287 .29328 .66465 .2927 .6638 .2917 Mtetra
.719 .784 .904 r
.6638 .2917 .66465 .2927 .66646 .29259 .66557 .29083 Mtetra
.688 .653 .81 r
.66557 .29083 .66646 .29259 .6683 .29316 .66735 .28996 Mtetra
.591 .498 .718 r
.66735 .28996 .6683 .29316 .67019 .29482 .66915 .28962 Mtetra
.405 .319 .646 r
.66915 .28962 .67019 .29482 .67241 .30318 .67105 .2914 Mtetra
.98 .686 .347 r
.67105 .2914 .67241 .30318 .68371 .50159 .68225 .48878 Mtetra
0 0 .433 r
.68225 .48878 .68371 .50159 .68583 .50515 .68488 .50317 Mtetra
0 .181 .711 r
.68488 .50317 .68583 .50515 .68784 .50641 .68693 .50534 Mtetra
.476 .687 .959 r
.68693 .50534 .68784 .50641 .68979 .50648 .68888 .50533 Mtetra
.738 .779 .886 r
.68888 .50533 .68979 .50648 .6917 .50565 .69078 .50427 Mtetra
.891 .769 .72 r
.69078 .50427 .6917 .50565 .69351 .5027 .69257 .50104 Mtetra
.97 .715 .492 r
.69257 .50104 .69351 .5027 .69482 .49022 .69369 .48461 Mtetra
.973 .679 .401 r
.69369 .48461 .69482 .49022 .68625 .2875 .68539 .28619 Mtetra
.891 .766 .718 r
.68539 .28619 .68625 .2875 .68791 .28429 .68706 .28313 Mtetra
.71 .753 .886 r
.68706 .28313 .68791 .28429 .6897 .28343 .68885 .28227 Mtetra
.594 .709 .924 r
.68885 .28227 .6897 .28343 .69151 .28309 .69066 .28195 Mtetra
.653 .735 .91 r
.69066 .28195 .69151 .28309 .69331 .28245 .69247 .28138 Mtetra
.735 .779 .888 r
.69247 .28138 .69331 .28245 .69509 .28133 .69425 .2804 Mtetra
.628 .773 .95 r
.69425 .2804 .69509 .28133 .69689 .28071 .69606 .27991 Mtetra
0 .244 .718 r
.69606 .27991 .69689 .28071 .69879 .28182 .69797 .28117 Mtetra
.943 .578 .224 r
.69797 .28117 .69879 .28182 .70111 .29029 .7004 .29161 Mtetra
.974 .671 .373 r
.7004 .29161 .70111 .29029 .71465 .49462 .71376 .49375 Mtetra
.646 .153 0 r
.71376 .49375 .71465 .49462 .71679 .49752 .71589 .49645 Mtetra
.438 .668 .959 r
.71589 .49645 .71679 .49752 .71877 .49764 .71787 .49655 Mtetra
.727 .789 .901 r
.71787 .49655 .71877 .49764 .72069 .49665 .71979 .49556 Mtetra
.902 .81 .747 r
.71979 .49556 .72069 .49665 .72249 .49373 .7216 .49265 Mtetra
.979 .742 .51 r
.7216 .49265 .72249 .49373 .72377 .48215 .72289 .48106 Mtetra
.977 .681 .378 r
.72289 .48106 .72377 .48215 .71338 .27865 .71254 .2775 Mtetra
.92 .788 .699 r
.71254 .2775 .71338 .27865 .71502 .27518 .71418 .27403 Mtetra
.72 .762 .885 r
.71418 .27403 .71502 .27518 .71682 .27427 .71598 .27312 Mtetra
.598 .714 .925 r
.71598 .27312 .71682 .27427 .71865 .27392 .71782 .27277 Mtetra
.633 .729 .917 r
.71782 .27277 .71865 .27392 .72048 .27343 .71964 .27228 Mtetra
.739 .768 .876 r
.71964 .27228 .72048 .27343 .72227 .2724 .72144 .27126 Mtetra
.651 .736 .912 r
.72144 .27126 .72227 .2724 .7241 .27184 .72326 .27069 Mtetra
.111 .432 .873 r
.72326 .27069 .7241 .27184 .72602 .27278 .72519 .27163 Mtetra
.906 .523 .092 r
.72519 .27163 .72602 .27278 .7284 .28062 .72756 .27948 Mtetra
.975 .671 .352 r
.72756 .27948 .7284 .28062 .74381 .48521 .74293 .48412 Mtetra
.603 .14 0 r
.74293 .48412 .74381 .48521 .74601 .48816 .74512 .48707 Mtetra
.552 .723 .953 r
.74512 .48707 .74601 .48816 .74799 .48792 .74711 .48683 Mtetra
.713 .787 .91 r
.74711 .48683 .74799 .48792 .74993 .48701 .74905 .48592 Mtetra
.696 .782 .918 r
.74905 .48592 .74993 .48701 .75188 .48618 .751 .48509 Mtetra
.51 .702 .957 r
.751 .48509 .75188 .48618 .75388 .48608 .753 .48499 Mtetra
.653 .767 .932 r
.753 .48499 .75388 .48608 .75584 .48545 .75496 .48436 Mtetra
.869 .818 .797 r
.75496 .48436 .75584 .48545 .75769 .4832 .75682 .48211 Mtetra
.98 .75 .518 r
.75682 .48211 .75769 .4832 .75898 .473 .75811 .47195 Mtetra
.977 .678 .362 r
.75811 .47195 .75898 .473 .74628 .26781 .74546 .26666 Mtetra
.934 .79 .678 r
.74546 .26666 .74628 .26781 .74789 .26397 .74706 .26281 Mtetra
.727 .766 .884 r
.74706 .26281 .74789 .26397 .7497 .26301 .74888 .26186 Mtetra
.601 .716 .925 r
.74888 .26186 .7497 .26301 .75156 .26265 .75074 .26149 Mtetra
.6 .715 .925 r
.75074 .26149 .75156 .26265 .75342 .26229 .7526 .26113 Mtetra
.739 .77 .878 r
.7526 .26113 .75342 .26229 .75523 .26126 .75441 .2601 Mtetra
.656 .739 .911 r
.75441 .2601 .75523 .26126 .75707 .26066 .75625 .2595 Mtetra
.23 .508 .907 r
.75625 .2595 .75707 .26066 .75902 .26136 .7582 .2602 Mtetra
.885 .493 .039 r
.7582 .2602 .75902 .26136 .76147 .26868 .76065 .26753 Mtetra
.975 .667 .334 r
.76065 .26753 .76147 .26868 .77924 .47442 .77838 .47332 Mtetra
.654 .2 0 r
.77838 .47332 .77924 .47442 .78154 .47787 .78067 .47677 Mtetra
.382 .631 .952 r
.78067 .47677 .78154 .47787 .78359 .47814 .78273 .47703 Mtetra
.693 .78 .918 r
.78273 .47703 .78359 .47814 .78556 .47732 .7847 .47621 Mtetra
.873 .82 .793 r
.7847 .47621 .78556 .47732 .78741 .47501 .78655 .4739 Mtetra
.978 .767 .552 r
.78655 .4739 .78741 .47501 .78882 .46719 .78796 .46608 Mtetra
.977 .675 .347 r
.78796 .46608 .78882 .46719 .77405 .25935 .77324 .25818 Mtetra
.951 .785 .641 r
.77324 .25818 .77405 .25935 .77559 .25475 .77478 .25358 Mtetra
.746 .772 .874 r
.77478 .25358 .77559 .25475 .77741 .25367 .77659 .2525 Mtetra
.617 .722 .921 r
.77659 .2525 .77741 .25367 .77928 .25324 .77847 .25207 Mtetra
.584 .706 .927 r
.77847 .25207 .77928 .25324 .78116 .25294 .78035 .25176 Mtetra
.747 .772 .874 r
.78035 .25176 .78116 .25294 .78298 .25185 .78217 .25068 Mtetra
.67 .744 .906 r
.78217 .25068 .78298 .25185 .78484 .25118 .78403 .25001 Mtetra
.35 .58 .928 r
.78403 .25001 .78484 .25118 .78679 .2516 .78598 .25043 Mtetra
.838 .433 0 r
.78598 .25043 .78679 .2516 .78924 .25775 .78843 .25659 Mtetra
.973 .663 .318 r
.78843 .25659 .78924 .25775 .80905 .46474 .8082 .46362 Mtetra
.692 .246 0 r
.8082 .46362 .80905 .46474 .81145 .46869 .8106 .46757 Mtetra
.348 .609 .947 r
.8106 .46757 .81145 .46869 .81354 .46905 .81269 .46793 Mtetra
.674 .775 .926 r
.81269 .46793 .81354 .46905 .81554 .46831 .81469 .4672 Mtetra
.857 .822 .814 r
.81469 .4672 .81554 .46831 .81742 .46624 .81657 .46512 Mtetra
.978 .777 .566 r
.81657 .46512 .81742 .46624 .81885 .4592 .81801 .45813 Mtetra
.976 .672 .332 r
.81801 .45813 .81885 .4592 .80208 .25048 .80129 .24935 Mtetra
.964 .786 .613 r
.80129 .24935 .80208 .25048 .80355 .24531 .80275 .24415 Mtetra
.753 .78 .875 r
.80275 .24415 .80355 .24531 .80538 .24419 .80458 .24303 Mtetra
.614 .723 .924 r
.80458 .24303 .80538 .24419 .80727 .24377 .80647 .2426 Mtetra
.539 .686 .934 r
.80647 .2426 .80727 .24377 .80919 .24364 .8084 .24245 Mtetra
.736 .769 .88 r
.8084 .24245 .80919 .24364 .81104 .24271 .81024 .24143 Mtetra
.662 .722 .893 r
.81024 .24143 .81104 .24271 .81292 .24207 .81212 .24079 Mtetra
.435 .606 .919 r
.81212 .24079 .81292 .24207 .81486 .24205 .81408 .24102 Mtetra
.814 .395 0 r
.81408 .24102 .81486 .24205 .81705 .24469 .81655 .24658 Mtetra
.972 .657 .313 r
.81655 .24658 .81705 .24469 .83781 .44084 .83831 .45367 Mtetra
.63 .351 .477 r
.83831 .45367 .83781 .44084 .84125 .45504 .84081 .458 Mtetra
.503 .145 .292 r
.84081 .458 .84125 .45504 .84351 .45688 .84291 .45811 Mtetra
.238 0 0 r
.84291 .45811 .84351 .45688 .84566 .45754 .84494 .45748 Mtetra
.552 .932 .881 r
.84494 .45748 .84566 .45754 .84776 .4576 .84693 .45651 Mtetra
.512 .707 .959 r
.84693 .45651 .84776 .4576 .84986 .45765 .84901 .45639 Mtetra
.634 .731 .918 r
.84901 .45639 .84986 .45765 .85189 .45709 .85105 .45584 Mtetra
.775 .788 .863 r
.85105 .45584 .85189 .45709 .85384 .45561 .85301 .45446 Mtetra
.976 .788 .586 r
.85301 .45446 .85384 .45561 .85532 .44948 .85449 .44832 Mtetra
.974 .667 .312 r
.85449 .44832 .85532 .44948 .83615 .24019 .83536 .23897 Mtetra
.972 .773 .576 r
.83536 .23897 .83615 .24019 .83748 .23401 .83669 .2328 Mtetra
.758 .756 .85 r
.22647 .4399 .2275 .44087 .22906 .43982 .22804 .43885 Mtetra
.61 .723 .926 r
.22804 .43885 .22906 .43982 .23057 .43951 .22954 .43852 Mtetra
.454 .662 .951 r
.22954 .43852 .23057 .43951 .23203 .43959 .23101 .43858 Mtetra
.641 .727 .91 r
.23101 .43858 .23203 .43959 .23355 .43916 .23252 .43815 Mtetra
.654 .728 .904 r
.23252 .43815 .23355 .43916 .23507 .4387 .23404 .43767 Mtetra
.668 .727 .893 r
.23404 .43767 .23507 .4387 .23659 .43821 .23557 .43712 Mtetra
.729 .732 .853 r
.23557 .43712 .23659 .43821 .23812 .43761 .23713 .43624 Mtetra
.7 .68 .827 r
.23713 .43624 .23812 .43761 .23965 .43699 .23868 .43545 Mtetra
.653 .642 .826 r
.23868 .43545 .23965 .43699 .24119 .43636 .24021 .43491 Mtetra
.316 .493 .875 r
.24021 .43491 .24119 .43636 .24272 .43579 .24164 .43544 Mtetra
.643 .082 0 r
.24164 .43544 .24272 .43579 .24425 .43523 .24303 .43657 Mtetra
.719 .337 .325 r
.24303 .43657 .24425 .43523 .24579 .43466 .24437 .43828 Mtetra
.517 .198 .365 r
.24437 .43828 .24579 .43466 .24732 .43405 .24585 .43835 Mtetra
.431 .13 .351 r
.24585 .43835 .24732 .43405 .24886 .43344 .2474 .43758 Mtetra
.381 .079 .323 r
.2474 .43758 .24886 .43344 .2504 .43284 .24899 .43648 Mtetra
.423 .107 .323 r
.24899 .43648 .2504 .43284 .25194 .43227 .25054 .43582 Mtetra
.43 .111 .321 r
.25054 .43582 .25194 .43227 .25347 .43171 .25208 .43521 Mtetra
.432 .112 .32 r
.25208 .43521 .25347 .43171 .25501 .43117 .25362 .43464 Mtetra
.438 .116 .322 r
.25362 .43464 .25501 .43117 .25655 .43063 .25516 .43411 Mtetra
.441 .12 .323 r
.25516 .43411 .25655 .43063 .25808 .43011 .2567 .4336 Mtetra
.443 .122 .325 r
.2567 .4336 .25808 .43011 .25962 .42959 .25823 .4331 Mtetra
.495 .173 .35 r
.25823 .4331 .25962 .42959 .26116 .4291 .25974 .43299 Mtetra
.476 .164 .357 r
.25974 .43299 .26116 .4291 .26269 .4286 .26127 .43267 Mtetra
.4 .096 .33 r
.26127 .43267 .26269 .4286 .26423 .4281 .26284 .43172 Mtetra
.026 0 .128 r
.26284 .43172 .26423 .4281 .26577 .42756 .26455 .42919 Mtetra
.578 .816 .433 r
.26455 .42919 .26577 .42756 .26732 .42701 .26623 .42693 Mtetra
.881 .921 .847 r
.26623 .42693 .26732 .42701 .26886 .42645 .26787 .42519 Mtetra
.715 .703 .838 r
.26787 .42519 .26886 .42645 .27041 .42592 .26944 .42434 Mtetra
.65 .637 .824 r
.26944 .42434 .27041 .42592 .27195 .42539 .27098 .42382 Mtetra
.626 .628 .832 r
.27098 .42382 .27195 .42539 .27349 .42487 .27252 .42342 Mtetra
.649 .655 .842 r
.27252 .42342 .27349 .42487 .27504 .42433 .27406 .42292 Mtetra
.655 .662 .845 r
.27406 .42292 .27504 .42433 .27659 .42379 .27561 .42239 Mtetra
.656 .664 .846 r
.27561 .42239 .27659 .42379 .27814 .42325 .27716 .42186 Mtetra
.657 .667 .848 r
.27716 .42186 .27814 .42325 .27969 .42268 .27871 .42133 Mtetra
.659 .672 .852 r
.27871 .42133 .27969 .42268 .28124 .42212 .28026 .42079 Mtetra
.66 .676 .854 r
.28026 .42079 .28124 .42212 .28279 .42158 .28181 .42024 Mtetra
.662 .676 .853 r
.28181 .42024 .28279 .42158 .28434 .42113 .28336 .41969 Mtetra
.66 .66 .839 r
.28336 .41969 .28434 .42113 .28588 .42072 .28492 .41913 Mtetra
.656 .639 .822 r
.28492 .41913 .28588 .42072 .28743 .42029 .28648 .41857 Mtetra
.652 .622 .807 r
.28648 .41857 .28743 .42029 .28899 .41977 .28803 .41801 Mtetra
.65 .617 .803 r
.28803 .41801 .28899 .41977 .29054 .41919 .28959 .41745 Mtetra
.649 .618 .805 r
.28959 .41745 .29054 .41919 .2921 .41861 .29115 .4169 Mtetra
.684 .636 .796 r
.29115 .4169 .2921 .41861 .29369 .41771 .29272 .41611 Mtetra
.673 .645 .814 r
.29272 .41611 .29369 .41771 .29526 .41698 .29429 .41544 Mtetra
.601 .622 .845 r
.29429 .41544 .29526 .41698 .29679 .41684 .29583 .41517 Mtetra
0 .165 .704 r
.29583 .41517 .29679 .41684 .29812 .41963 .29725 .41663 Mtetra
.799 .494 0 r
.29725 .41663 .29812 .41963 .28595 .61679 .29843 .42157 Mtetra
0 0 .215 r
.29843 .42157 .28595 .61679 .28703 .62451 .28639 .61736 Mtetra
.39 .273 .598 r
.28639 .61736 .28703 .62451 .28859 .62552 .28786 .61956 Mtetra
.589 .433 .637 r
.28786 .61956 .28859 .62552 .29025 .62509 .28952 .61897 Mtetra
.607 .444 .634 r
.28952 .61897 .29025 .62509 .29194 .62419 .29121 .61804 Mtetra
.456 .334 .625 r
.29121 .61804 .29194 .62419 .29361 .62358 .29276 .61928 Mtetra
.359 .305 .661 r
.29276 .61928 .29361 .62358 .29526 .62314 .29428 .62082 Mtetra
.311 .387 .78 r
.29428 .62082 .29526 .62314 .29693 .62267 .29585 .62177 Mtetra
.434 .692 .973 r
.29585 .62177 .29693 .62267 .2986 .62209 .29748 .62181 Mtetra
.524 .872 .989 r
.29748 .62181 .2986 .62209 .30027 .62146 .29915 .62137 Mtetra
.548 .912 .958 r
.29915 .62137 .30027 .62146 .30195 .62082 .30082 .62076 Mtetra
.298 .789 .885 r
.30082 .62076 .30195 .62082 .3036 .62064 .30248 .62047 Mtetra
.38 .825 .943 r
.30248 .62047 .3036 .62064 .30525 .62041 .30414 .62016 Mtetra
.665 .92 .975 r
.30414 .62016 .30525 .62041 .30694 .61958 .30582 .61942 Mtetra
.91 .889 .798 r
.30582 .61942 .30694 .61958 .30882 .61584 .30762 .61705 Mtetra
.99 .882 .615 r
.30762 .61705 .30882 .61584 .32278 .41825 .3096 .61153 Mtetra
0 0 .21 r
.3096 .61153 .32278 .41825 .32493 .40859 .32353 .41408 Mtetra
0 0 .063 r
.32353 .41408 .32493 .40859 .32661 .4064 .32542 .4085 Mtetra
0 0 0 r
.32542 .4085 .32661 .4064 .32819 .40572 .3271 .40629 Mtetra
.69 .971 .763 r
.3271 .40629 .32819 .40572 .32975 .40548 .32873 .40488 Mtetra
.743 .845 .927 r
.32873 .40488 .32975 .40548 .33132 .40508 .33033 .40401 Mtetra
.669 .728 .894 r
.33033 .40401 .33132 .40508 .33291 .40451 .33192 .40344 Mtetra
.64 .72 .906 r
.33192 .40344 .33291 .40451 .33449 .40397 .33349 .403 Mtetra
.721 .76 .884 r
.33349 .403 .33449 .40397 .33608 .4032 .33509 .40218 Mtetra
.733 .753 .869 r
.33509 .40218 .33608 .4032 .33768 .4025 .3367 .40128 Mtetra
.653 .695 .876 r
.3367 .40128 .33768 .4025 .33924 .40233 .33828 .40077 Mtetra
.18 .394 .836 r
.33828 .40077 .33924 .40233 .34067 .40446 .33978 .40165 Mtetra
0 0 .338 r
.33978 .40165 .34067 .40446 .33121 .59909 .34113 .40527 Mtetra
0 0 .239 r
.34113 .40527 .33121 .59909 .33225 .61013 .33162 .60142 Mtetra
.089 .038 .499 r
.33162 .60142 .33225 .61013 .33382 .61171 .33295 .60735 Mtetra
.359 .305 .66 r
.33295 .60735 .33382 .61171 .3355 .61139 .33452 .60894 Mtetra
.433 .451 .778 r
.33452 .60894 .3355 .61139 .3372 .61055 .33615 .60951 Mtetra
.536 .705 .948 r
.33615 .60951 .3372 .61055 .33891 .60983 .33782 .60937 Mtetra
.641 .873 .984 r
.33782 .60937 .33891 .60983 .3406 .60935 .33952 .60876 Mtetra
.706 .857 .954 r
.33952 .60876 .3406 .60935 .34229 .60883 .34123 .60798 Mtetra
.593 .769 .964 r
.34123 .60798 .34229 .60883 .34398 .60853 .34292 .60763 Mtetra
.507 .724 .97 r
.34292 .60763 .34398 .60853 .34566 .60821 .34459 .60751 Mtetra
.639 .816 .968 r
.34459 .60751 .34566 .60821 .34738 .60732 .34629 .60698 Mtetra
.883 .885 .829 r
.34629 .60698 .34738 .60732 .34922 .60404 .34807 .60498 Mtetra
.988 .886 .629 r
.34807 .60498 .34922 .60404 .3608 .4088 .35 .5999 Mtetra
0 0 .228 r
.35 .5999 .3608 .4088 .36303 .39596 .36169 .40207 Mtetra
0 0 .063 r
.36169 .40207 .36303 .39596 .36473 .39337 .3636 .39539 Mtetra
0 0 0 r
.3636 .39539 .36473 .39337 .36634 .39263 .36529 .39297 Mtetra
.804 1 .831 r
.36529 .39297 .36634 .39263 .36793 .39237 .36694 .39143 Mtetra
.747 .774 .875 r
.36694 .39143 .36793 .39237 .36952 .39209 .36857 .39045 Mtetra
.657 .639 .82 r
.36857 .39045 .36952 .39209 .37112 .39159 .37017 .38986 Mtetra
.626 .614 .819 r
.37017 .38986 .37112 .39159 .37272 .39109 .37177 .38944 Mtetra
.646 .633 .822 r
.37177 .38944 .37272 .39109 .37433 .39056 .37338 .38892 Mtetra
.666 .642 .816 r
.37338 .38892 .37433 .39056 .37593 .39 .37499 .38827 Mtetra
.638 .619 .814 r
.37499 .38827 .37593 .39 .37754 .38943 .37659 .38778 Mtetra
.523 .574 .848 r
.37659 .38778 .37754 .38943 .37915 .38887 .37817 .38783 Mtetra
.001 .391 .847 r
.37817 .38783 .37915 .38887 .38076 .38832 .37972 .38864 Mtetra
.703 .21 .071 r
.37972 .38864 .38076 .38832 .38237 .38777 .38125 .38998 Mtetra
.571 .2 .3 r
.38125 .38998 .38237 .38777 .38399 .38698 .38281 .39057 Mtetra
.381 .068 .304 r
.38281 .39057 .38399 .38698 .38562 .38609 .38445 .38959 Mtetra
.442 .121 .325 r
.38445 .38959 .38562 .38609 .38722 .38567 .38606 .38906 Mtetra
.727 .402 .43 r
.38606 .38906 .38722 .38567 .38876 .38698 .38752 .39229 Mtetra
.946 .676 .493 r
.38752 .39229 .38876 .38698 .38992 .39739 .38077 .58972 Mtetra
.55 .325 .527 r
.38077 .58972 .38992 .39739 .38339 .59362 .38227 .59448 Mtetra
.678 .226 .171 r
.38227 .59448 .38339 .59362 .38499 .59601 .38392 .5958 Mtetra
.395 .829 .955 r
.38392 .5958 .38499 .59601 .3867 .59577 .38563 .59548 Mtetra
.654 .917 .978 r
.38563 .59548 .3867 .59577 .38844 .59494 .38736 .59474 Mtetra
.643 .932 .97 r
.38736 .59474 .38844 .59494 .39017 .59413 .3891 .59398 Mtetra
.517 .895 .963 r
.3891 .59398 .39017 .59413 .39189 .59373 .39083 .59343 Mtetra
.572 .891 .988 r
.39083 .59343 .39189 .59373 .39361 .59333 .39256 .59288 Mtetra
.57 .859 .996 r
.39256 .59288 .39361 .59333 .39534 .5929 .39428 .59242 Mtetra
.535 .84 .999 r
.39428 .59242 .39534 .5929 .39707 .59241 .39601 .59204 Mtetra
.59 .884 .992 r
.39601 .59204 .39707 .59241 .3988 .59189 .39774 .5915 Mtetra
.731 .908 .956 r
.39774 .5915 .3988 .59189 .40052 .59154 .39949 .59056 Mtetra
.811 .788 .831 r
.39949 .59056 .40052 .59154 .40224 .59134 .40126 .58898 Mtetra
.784 .645 .708 r
.40126 .58898 .40224 .59134 .40398 .59064 .40306 .58647 Mtetra
.814 .609 .625 r
.40306 .58647 .40398 .59064 .40578 .58829 .40499 .5805 Mtetra
.948 .681 .497 r
.40499 .5805 .40578 .58829 .40784 .5783 .41362 .38127 Mtetra
.553 .332 .534 r
.41362 .38127 .40784 .5783 .41631 .37903 .41542 .37602 Mtetra
.743 .59 .685 r
.41542 .37602 .41631 .37903 .41804 .37549 .41711 .37377 Mtetra
.68 .641 .804 r
.41711 .37377 .41804 .37549 .41969 .37463 .41875 .37299 Mtetra
.615 .622 .835 r
.41875 .37299 .41969 .37463 .42131 .37434 .42037 .37263 Mtetra
.589 .602 .833 r
.42037 .37263 .42131 .37434 .42294 .37411 .422 .3724 Mtetra
.618 .616 .826 r
.422 .3724 .42294 .37411 .42457 .37346 .42363 .37203 Mtetra
.622 .655 .861 r
.42363 .37203 .42457 .37346 .42621 .37281 .42526 .37164 Mtetra
.645 .709 .893 r
.42526 .37164 .42621 .37281 .42785 .37221 .4269 .37116 Mtetra
.686 .745 .896 r
.4269 .37116 .42785 .37221 .42949 .37168 .42854 .3705 Mtetra
.69 .721 .874 r
.42854 .3705 .42949 .37168 .43113 .37116 .43018 .3698 Mtetra
.687 .691 .848 r
.43018 .3698 .43113 .37116 .43277 .37063 .43183 .36907 Mtetra
.68 .662 .825 r
.43183 .36907 .43277 .37063 .43441 .37004 .43348 .36834 Mtetra
.649 .631 .818 r
.43348 .36834 .43441 .37004 .43606 .36946 .43512 .36778 Mtetra
.571 .597 .84 r
.43512 .36778 .43606 .36946 .4377 .36887 .43675 .36763 Mtetra
.193 .467 .886 r
.43675 .36763 .4377 .36887 .43934 .3683 .43836 .36833 Mtetra
.657 .113 0 r
.43836 .36833 .43934 .3683 .44099 .36774 .43996 .36955 Mtetra
.629 .238 .285 r
.43996 .36955 .44099 .36774 .44264 .36705 .44157 .37061 Mtetra
.382 .068 .304 r
.44157 .37061 .44264 .36705 .4443 .36608 .44323 .36961 Mtetra
.421 .103 .319 r
.44323 .36961 .4443 .36608 .44595 .36552 .44488 .3689 Mtetra
.634 .302 .39 r
.44488 .3689 .44595 .36552 .44757 .36616 .44649 .37037 Mtetra
.954 .678 .475 r
.44649 .37037 .44757 .36616 .44906 .37232 .44336 .56848 Mtetra
.552 .327 .527 r
.44336 .56848 .44906 .37232 .44603 .57328 .44496 .57475 Mtetra
.714 .311 .284 r
.44496 .57475 .44603 .57328 .4477 .57685 .44667 .57667 Mtetra
.287 .773 .913 r
.44667 .57667 .4477 .57685 .44945 .57677 .44842 .57646 Mtetra
.628 .91 .982 r
.44842 .57646 .44945 .57677 .45122 .57602 .45019 .57577 Mtetra
.674 .935 .968 r
.45019 .57577 .45122 .57602 .453 .57507 .45196 .57492 Mtetra
.507 .894 .956 r
.45196 .57492 .453 .57507 .45476 .57466 .45373 .57436 Mtetra
.566 .894 .985 r
.45373 .57436 .45476 .57466 .45652 .57425 .4555 .5738 Mtetra
.59 .869 .994 r
.4555 .5738 .45652 .57425 .45829 .57381 .45727 .57327 Mtetra
.545 .833 .998 r
.45727 .57327 .45829 .57381 .46006 .5733 .45904 .57289 Mtetra
.58 .876 .994 r
.45904 .57289 .46006 .5733 .46183 .57277 .46081 .57236 Mtetra
.716 .912 .962 r
.46081 .57236 .46183 .57277 .4636 .57221 .46259 .57145 Mtetra
.856 .833 .823 r
.46259 .57145 .4636 .57221 .46538 .57165 .46439 .56954 Mtetra
.799 .668 .72 r
.46439 .56954 .46538 .57165 .46715 .57108 .4662 .56704 Mtetra
.732 .562 .661 r
.4662 .56704 .46715 .57108 .46893 .57053 .46801 .56427 Mtetra
.607 .443 .634 r
.46801 .56427 .46893 .57053 .4707 .57002 .46979 .56329 Mtetra
.568 .41 .628 r
.46979 .56329 .4707 .57002 .47248 .56951 .47156 .563 Mtetra
.548 .399 .63 r
.47156 .563 .47248 .56951 .47426 .56907 .47333 .56306 Mtetra
.532 .394 .638 r
.47333 .56306 .47426 .56907 .47603 .56899 .4751 .56336 Mtetra
.582 .434 .646 r
.4751 .56336 .47603 .56899 .47781 .56848 .47688 .56291 Mtetra
.675 .499 .639 r
.47688 .56291 .47781 .56848 .47961 .56695 .47868 .56065 Mtetra
.957 .684 .476 r
.47868 .56065 .47961 .56695 .48147 .5603 .48307 .36177 Mtetra
.559 .337 .535 r
.48307 .36177 .48147 .5603 .48575 .35709 .48484 .35334 Mtetra
.756 .577 .654 r
.48484 .35334 .48575 .35709 .48748 .35198 .48655 .35019 Mtetra
.7 .646 .793 r
.48655 .35019 .48748 .35198 .48916 .35084 .48823 .34924 Mtetra
.639 .642 .837 r
.48823 .34924 .48916 .35084 .49083 .35037 .48991 .34875 Mtetra
.603 .622 .843 r
.48991 .34875 .49083 .35037 .49251 .35018 .49158 .34844 Mtetra
.69 .647 .802 r
.49158 .34844 .49251 .35018 .49419 .3492 .49326 .34758 Mtetra
.655 .647 .83 r
.49326 .34758 .49419 .3492 .49587 .34861 .49494 .34699 Mtetra
.538 .592 .856 r
.49494 .34699 .49587 .34861 .49754 .34887 .49662 .34697 Mtetra
0 0 .537 r
.49662 .34697 .49754 .34887 .49917 .35423 .49827 .34947 Mtetra
.901 .618 .116 r
.49827 .34947 .49917 .35423 .49932 .5566 .49985 .36206 Mtetra
0 0 .338 r
.49985 .36206 .49932 .5566 .50108 .56095 .50013 .55507 Mtetra
.519 .387 .641 r
.50013 .55507 .50108 .56095 .50288 .56105 .50192 .55557 Mtetra
.601 .45 .648 r
.50192 .55557 .50288 .56105 .50468 .56041 .50371 .55482 Mtetra
.635 .471 .644 r
.50371 .55482 .50468 .56041 .50648 .55941 .50552 .55342 Mtetra
.612 .45 .638 r
.50552 .55342 .50648 .55941 .50828 .55884 .50732 .55239 Mtetra
.591 .43 .632 r
.50732 .55239 .50828 .55884 .51008 .55825 .50912 .55167 Mtetra
.552 .401 .63 r
.50912 .55167 .51008 .55825 .51189 .55767 .51092 .55167 Mtetra
.417 .315 .631 r
.51092 .55167 .51189 .55767 .51369 .55716 .51272 .55343 Mtetra
.389 .353 .698 r
.51272 .55343 .51369 .55716 .5155 .55665 .51451 .55472 Mtetra
.351 .462 .834 r
.51451 .55472 .5155 .55665 .51731 .55611 .51632 .55545 Mtetra
.524 .801 .996 r
.51632 .55545 .51731 .55611 .51911 .55544 .51813 .55516 Mtetra
.541 .891 .98 r
.51813 .55516 .51911 .55544 .52092 .55474 .51994 .55461 Mtetra
.556 .918 .952 r
.51994 .55461 .52092 .55474 .52274 .55405 .52175 .55392 Mtetra
.242 .75 .878 r
.52175 .55392 .52274 .55405 .52455 .55398 .52356 .55371 Mtetra
.486 .87 .974 r
.52356 .55371 .52455 .55398 .52636 .55356 .52538 .55325 Mtetra
.721 .938 .957 r
.52538 .55325 .52636 .55356 .52817 .55238 .52719 .55225 Mtetra
.956 .894 .727 r
.52719 .55225 .52817 .55238 .52998 .54653 .52901 .54896 Mtetra
.955 .843 .417 r
.52901 .54896 .52998 .54653 .53138 .34246 .53081 .54088 Mtetra
0 0 .336 r
.53081 .54088 .53138 .34246 .53307 .33651 .53216 .34023 Mtetra
0 0 .118 r
.53216 .34023 .53307 .33651 .53477 .33513 .53386 .33641 Mtetra
0 0 0 r
.53386 .33641 .53477 .33513 .53647 .33456 .53556 .33433 Mtetra
.823 .954 .902 r
.53556 .33433 .53647 .33456 .53818 .33436 .53726 .33295 Mtetra
.698 .695 .843 r
.53726 .33295 .53818 .33436 .53989 .33382 .53897 .33213 Mtetra
.645 .636 .826 r
.53897 .33213 .53989 .33382 .54159 .33325 .54068 .33158 Mtetra
.619 .626 .835 r
.54068 .33158 .54159 .33325 .5433 .33269 .54239 .33118 Mtetra
.63 .654 .855 r
.54239 .33118 .5433 .33269 .54501 .33207 .5441 .33074 Mtetra
.633 .683 .88 r
.5441 .33074 .54501 .33207 .54672 .33145 .54581 .33028 Mtetra
.642 .717 .903 r
.54581 .33028 .54672 .33145 .54843 .33086 .54752 .32979 Mtetra
.741 .767 .874 r
.54752 .32979 .54843 .33086 .55014 .32997 .54923 .3288 Mtetra
.712 .74 .874 r
.54923 .3288 .55014 .32997 .55186 .32936 .55095 .32796 Mtetra
.618 .665 .873 r
.55095 .32796 .55186 .32936 .55358 .3294 .55266 .32757 Mtetra
.017 .247 .751 r
.55266 .32757 .55358 .3294 .55534 .33316 .5544 .32916 Mtetra
0 0 .386 r
.5544 .32916 .55534 .33316 .55913 .53626 .55618 .33472 Mtetra
0 0 .362 r
.55618 .33472 .55913 .53626 .56103 .54214 .56001 .53539 Mtetra
.293 .219 .6 r
.56001 .53539 .56103 .54214 .56288 .54274 .56188 .53883 Mtetra
.413 .364 .694 r
.56188 .53883 .56288 .54274 .56472 .54225 .56374 .54004 Mtetra
.468 .501 .809 r
.56374 .54004 .56472 .54225 .56656 .54129 .56559 .54043 Mtetra
.53 .758 .98 r
.56559 .54043 .56656 .54129 .5684 .54054 .56744 .54021 Mtetra
.546 .885 .986 r
.56744 .54021 .5684 .54054 .57024 .53983 .56928 .53966 Mtetra
.561 .919 .955 r
.56928 .53966 .57024 .53983 .57208 .5391 .57113 .53896 Mtetra
.302 .787 .901 r
.57113 .53896 .57208 .5391 .57393 .53894 .57298 .53867 Mtetra
.454 .856 .969 r
.57298 .53867 .57393 .53894 .57578 .53859 .57483 .53825 Mtetra
.692 .931 .967 r
.57483 .53825 .57578 .53859 .57762 .53755 .57667 .53733 Mtetra
.943 .91 .757 r
.57667 .53733 .57762 .53755 .5794 .53276 .57848 .53446 Mtetra
.963 .863 .458 r
.57848 .53446 .5794 .53276 .57782 .32844 .58023 .52771 Mtetra
0 0 .356 r
.58023 .52771 .57782 .32844 .57944 .32112 .57863 .32548 Mtetra
0 0 .159 r
.57863 .32548 .57944 .32112 .58115 .31932 .5803 .32085 Mtetra
0 0 0 r
.5803 .32085 .58115 .31932 .58288 .31866 .582 .31862 Mtetra
.809 .989 .881 r
.582 .31862 .58288 .31866 .58462 .31841 .58372 .31718 Mtetra
.699 .727 .872 r
.58372 .31718 .58462 .31841 .58636 .3179 .58545 .31638 Mtetra
.632 .656 .856 r
.58545 .31638 .58636 .3179 .58809 .31729 .58719 .31592 Mtetra
.605 .668 .884 r
.58719 .31592 .58809 .31729 .58983 .31671 .58894 .31559 Mtetra
.719 .754 .88 r
.58894 .31559 .58983 .31671 .59156 .31587 .59067 .31471 Mtetra
.719 .748 .875 r
.59067 .31471 .59156 .31587 .5933 .31519 .5924 .31382 Mtetra
.634 .679 .875 r
.5924 .31382 .5933 .31519 .59505 .31511 .59415 .31335 Mtetra
.152 .346 .803 r
.59415 .31335 .59505 .31511 .59688 .31807 .59593 .3146 Mtetra
0 0 .459 r
.59593 .3146 .59688 .31807 .6034 .52091 .5978 .31926 Mtetra
0 0 .378 r
.5978 .31926 .6034 .52091 .60545 .52824 .60435 .52086 Mtetra
.255 .187 .584 r
.60435 .52086 .60545 .52824 .60735 .52929 .60633 .52514 Mtetra
.407 .353 .685 r
.60633 .52514 .60735 .52929 .60923 .52889 .60825 .52649 Mtetra
.464 .483 .793 r
.60825 .52649 .60923 .52889 .61109 .52798 .61014 .52696 Mtetra
.43 .673 .964 r
.61014 .52696 .61109 .52798 .61296 .52755 .61203 .52706 Mtetra
.495 .833 .998 r
.61203 .52706 .61296 .52755 .61484 .52708 .61391 .52671 Mtetra
.703 .93 .965 r
.61391 .52671 .61484 .52708 .6167 .52598 .61578 .52576 Mtetra
.93 .93 .784 r
.61578 .52576 .6167 .52598 .61847 .52193 .6176 .52321 Mtetra
.958 .884 .49 r
.6176 .52321 .61847 .52193 .61457 .31903 .61933 .51757 Mtetra
0 0 .369 r
.61933 .51757 .61457 .31903 .61606 .30925 .61538 .31505 Mtetra
0 0 .236 r
.61538 .31505 .61606 .30925 .61777 .30704 .61698 .30915 Mtetra
0 0 0 r
.61698 .30915 .61777 .30704 .61952 .30631 .61869 .30681 Mtetra
.6 .918 .675 r
.61869 .30681 .61952 .30631 .62129 .30605 .62042 .30532 Mtetra
.738 .848 .931 r
.62042 .30532 .62129 .30605 .62305 .3056 .62217 .30438 Mtetra
.666 .723 .891 r
.62217 .30438 .62305 .3056 .62481 .30498 .62393 .30377 Mtetra
.639 .712 .9 r
.62393 .30377 .62481 .30498 .62657 .30439 .62569 .30327 Mtetra
.724 .76 .882 r
.62569 .30327 .62657 .30439 .62833 .30354 .62745 .30236 Mtetra
.733 .752 .868 r
.62745 .30236 .62833 .30354 .63008 .30277 .6292 .30138 Mtetra
.652 .686 .869 r
.6292 .30138 .63008 .30277 .63186 .30256 .63096 .30081 Mtetra
.268 .423 .832 r
.63096 .30081 .63186 .30256 .63373 .30491 .63278 .30176 Mtetra
0 0 .526 r
.63278 .30176 .63373 .30491 .64265 .5065 .63471 .30575 Mtetra
0 0 .391 r
.63471 .30575 .64265 .5065 .64489 .51578 .6437 .50741 Mtetra
.24 .168 .571 r
.6437 .50741 .64489 .51578 .64685 .51722 .64579 .51257 Mtetra
.427 .353 .671 r
.64579 .51257 .64685 .51722 .64876 .51687 .64776 .51393 Mtetra
.486 .459 .752 r
.64776 .51393 .64876 .51687 .65064 .51598 .64969 .5144 Mtetra
.443 .57 .887 r
.64969 .5144 .65064 .51598 .65254 .51546 .65163 .51471 Mtetra
.424 .736 .991 r
.65163 .51471 .65254 .51546 .65445 .51508 .65355 .51466 Mtetra
.66 .914 .978 r
.65355 .51466 .65445 .51508 .65633 .51411 .65544 .51385 Mtetra
.96 .9 .719 r
.65544 .51385 .65633 .51411 .65812 .51062 .65723 .51051 Mtetra
.976 .687 .404 r
.65723 .51051 .65812 .51062 .65195 .31123 .65139 .31767 Mtetra
.915 .725 .229 r
.65139 .31767 .65195 .31123 .65318 .29698 .6523 .29547 Mtetra
.854 .737 .733 r
.6523 .29547 .65318 .29698 .65488 .29438 .65399 .29285 Mtetra
.659 .669 .849 r
.65399 .29285 .65488 .29438 .65665 .29364 .65577 .29222 Mtetra
.543 .633 .891 r
.65577 .29222 .65665 .29364 .65844 .29339 .65757 .29214 Mtetra
.576 .68 .911 r
.65757 .29214 .65844 .29339 .66024 .29301 .65937 .2919 Mtetra
.662 .744 .911 r
.65937 .2919 .66024 .29301 .66202 .29235 .66116 .29129 Mtetra
.676 .761 .915 r
.66116 .29129 .66202 .29235 .6638 .2917 .66294 .29063 Mtetra
.748 .78 .879 r
.66294 .29063 .6638 .2917 .66557 .29083 .6647 .28957 Mtetra
.751 .748 .849 r
.6647 .28957 .66557 .29083 .66735 .28996 .66647 .28843 Mtetra
.654 .669 .852 r
.66647 .28843 .66735 .28996 .66915 .28962 .66826 .28783 Mtetra
.114 .318 .79 r
.66826 .28783 .66915 .28962 .67105 .2914 .67014 .28927 Mtetra
.941 .601 .177 r
.67014 .28927 .67105 .2914 .68225 .48878 .67256 .30204 Mtetra
0 0 .389 r
.67256 .30204 .68225 .48878 .68488 .50317 .68395 .50189 Mtetra
0 0 .534 r
.68395 .50189 .68488 .50317 .68693 .50534 .68602 .50431 Mtetra
.468 .693 .965 r
.68602 .50431 .68693 .50534 .68888 .50533 .68797 .50431 Mtetra
.752 .806 .895 r
.68797 .50431 .68888 .50533 .69078 .50427 .68987 .50319 Mtetra
.918 .802 .716 r
.68987 .50319 .69078 .50427 .69257 .50104 .69165 .49976 Mtetra
.977 .684 .393 r
.69165 .49976 .69257 .50104 .69369 .48461 .68357 .30203 Mtetra
.576 .35 .535 r
.68357 .30203 .69369 .48461 .68539 .28619 .68451 .28448 Mtetra
.854 .721 .716 r
.68451 .28448 .68539 .28619 .68706 .28313 .68619 .28162 Mtetra
.676 .682 .848 r
.68619 .28162 .68706 .28313 .68885 .28227 .68798 .28089 Mtetra
.568 .654 .894 r
.68798 .28089 .68885 .28227 .69066 .28195 .68981 .2807 Mtetra
.631 .707 .901 r
.68981 .2807 .69066 .28195 .69247 .28138 .69162 .28023 Mtetra
.728 .763 .88 r
.69162 .28023 .69247 .28138 .69425 .2804 .6934 .27928 Mtetra
.633 .733 .92 r
.6934 .27928 .69425 .2804 .69606 .27991 .69521 .27879 Mtetra
0 .309 .798 r
.69521 .27879 .69606 .27991 .69797 .28117 .69712 .28006 Mtetra
.94 .579 .192 r
.69712 .28006 .69797 .28117 .7004 .29161 .69956 .29069 Mtetra
.975 .673 .367 r
.69956 .29069 .7004 .29161 .71376 .49375 .71287 .49268 Mtetra
.582 .111 0 r
.71287 .49268 .71376 .49375 .71589 .49645 .715 .49538 Mtetra
.44 .668 .959 r
.715 .49538 .71589 .49645 .71787 .49655 .71698 .49547 Mtetra
.728 .791 .903 r
.71698 .49547 .71787 .49655 .71979 .49556 .7189 .49448 Mtetra
.903 .811 .747 r
.7189 .49448 .71979 .49556 .7216 .49265 .72071 .49156 Mtetra
.978 .742 .51 r
.72071 .49156 .7216 .49265 .72289 .48106 .72199 .47995 Mtetra
.977 .681 .378 r
.72199 .47995 .72289 .48106 .71254 .2775 .7117 .27635 Mtetra
.92 .788 .699 r
.7117 .27635 .71254 .2775 .71418 .27403 .71334 .27289 Mtetra
.72 .762 .885 r
.71334 .27289 .71418 .27403 .71598 .27312 .71514 .27197 Mtetra
.598 .714 .925 r
.71514 .27197 .71598 .27312 .71782 .27277 .71698 .27163 Mtetra
.633 .729 .917 r
.71698 .27163 .71782 .27277 .71964 .27228 .71881 .27114 Mtetra
.739 .768 .876 r
.71881 .27114 .71964 .27228 .72144 .27126 .7206 .27011 Mtetra
.651 .736 .912 r
.7206 .27011 .72144 .27126 .72326 .27069 .72243 .26954 Mtetra
.11 .431 .873 r
.72243 .26954 .72326 .27069 .72519 .27163 .72435 .27048 Mtetra
.907 .523 .092 r
.72435 .27048 .72519 .27163 .72756 .27948 .72673 .27835 Mtetra
.975 .671 .352 r
.72673 .27835 .72756 .27948 .74293 .48412 .74205 .48303 Mtetra
.603 .14 0 r
.74205 .48303 .74293 .48412 .74512 .48707 .74424 .48598 Mtetra
.552 .723 .953 r
.74424 .48598 .74512 .48707 .74711 .48683 .74623 .48574 Mtetra
.712 .788 .911 r
.74623 .48574 .74711 .48683 .74905 .48592 .74817 .48483 Mtetra
.695 .782 .918 r
.74817 .48483 .74905 .48592 .751 .48509 .75012 .48401 Mtetra
.509 .703 .957 r
.75012 .48401 .751 .48509 .753 .48499 .75212 .4839 Mtetra
.653 .767 .933 r
.75212 .4839 .753 .48499 .75496 .48436 .75409 .48327 Mtetra
.869 .819 .797 r
.75409 .48327 .75496 .48436 .75682 .48211 .75594 .48103 Mtetra
.98 .751 .519 r
.75594 .48103 .75682 .48211 .75811 .47195 .75724 .47091 Mtetra
.977 .678 .362 r
.75724 .47091 .75811 .47195 .74546 .26666 .74463 .26552 Mtetra
.934 .79 .678 r
.74463 .26552 .74546 .26666 .74706 .26281 .74624 .26166 Mtetra
.727 .766 .884 r
.74624 .26166 .74706 .26281 .74888 .26186 .74805 .2607 Mtetra
.601 .716 .925 r
.74805 .2607 .74888 .26186 .75074 .26149 .74991 .26034 Mtetra
.6 .715 .925 r
.74991 .26034 .75074 .26149 .7526 .26113 .75177 .25998 Mtetra
.74 .77 .878 r
.75177 .25998 .7526 .26113 .75441 .2601 .75359 .25894 Mtetra
.656 .739 .911 r
.75359 .25894 .75441 .2601 .75625 .2595 .75543 .25834 Mtetra
.229 .508 .907 r
.75543 .25834 .75625 .2595 .7582 .2602 .75738 .25904 Mtetra
.885 .494 .04 r
.75738 .25904 .7582 .2602 .76065 .26753 .75983 .26639 Mtetra
.975 .667 .334 r
.75983 .26639 .76065 .26753 .77838 .47332 .77751 .47221 Mtetra
.654 .199 0 r
.77751 .47221 .77838 .47332 .78067 .47677 .77981 .47566 Mtetra
.382 .631 .952 r
.77981 .47566 .78067 .47677 .78273 .47703 .78186 .47592 Mtetra
.693 .78 .918 r
.78186 .47592 .78273 .47703 .7847 .47621 .78384 .47511 Mtetra
.873 .82 .793 r
.78384 .47511 .7847 .47621 .78655 .4739 .78569 .47279 Mtetra
.978 .767 .552 r
.78569 .47279 .78655 .4739 .78796 .46608 .78711 .46497 Mtetra
.977 .675 .347 r
.78711 .46497 .78796 .46608 .77324 .25818 .77243 .25702 Mtetra
.951 .785 .641 r
.77243 .25702 .77324 .25818 .77478 .25358 .77396 .25241 Mtetra
.746 .772 .874 r
.77396 .25241 .77478 .25358 .77659 .2525 .77578 .25133 Mtetra
.617 .722 .921 r
.77578 .25133 .77659 .2525 .77847 .25207 .77766 .2509 Mtetra
.584 .706 .927 r
.77766 .2509 .77847 .25207 .78035 .25176 .77954 .25059 Mtetra
.747 .772 .874 r
.77954 .25059 .78035 .25176 .78217 .25068 .78137 .2495 Mtetra
.67 .744 .906 r
.78137 .2495 .78217 .25068 .78403 .25001 .78322 .24884 Mtetra
.35 .58 .928 r
.78322 .24884 .78403 .25001 .78598 .25043 .78518 .24925 Mtetra
.838 .433 0 r
.78518 .24925 .78598 .25043 .78843 .25659 .78762 .25541 Mtetra
.973 .663 .318 r
.78762 .25541 .78843 .25659 .8082 .46362 .80735 .4625 Mtetra
.691 .246 0 r
.80735 .4625 .8082 .46362 .8106 .46757 .80975 .46645 Mtetra
.349 .609 .947 r
.80975 .46645 .8106 .46757 .81269 .46793 .81184 .46681 Mtetra
.674 .774 .925 r
.81184 .46681 .81269 .46793 .81469 .4672 .81384 .46608 Mtetra
.856 .822 .814 r
.81384 .46608 .81469 .4672 .81657 .46512 .81572 .46401 Mtetra
.977 .777 .567 r
.81572 .46401 .81657 .46512 .81801 .45813 .81717 .45703 Mtetra
.976 .672 .332 r
.81717 .45703 .81801 .45813 .80129 .24935 .80049 .2482 Mtetra
.963 .783 .613 r
.80049 .2482 .80129 .24935 .80275 .24415 .80195 .24298 Mtetra
.752 .777 .873 r
.80195 .24298 .80275 .24415 .80458 .24303 .80378 .24186 Mtetra
.614 .722 .923 r
.80378 .24186 .80458 .24303 .80647 .2426 .80568 .24143 Mtetra
.537 .686 .935 r
.80568 .24143 .80647 .2426 .8084 .24245 .8076 .24129 Mtetra
.723 .769 .889 r
.8076 .24129 .8084 .24245 .81024 .24143 .80945 .24034 Mtetra
.665 .763 .924 r
.80945 .24034 .81024 .24143 .81212 .24079 .81133 .23969 Mtetra
.477 .672 .95 r
.81133 .23969 .81212 .24079 .81408 .24102 .81327 .23972 Mtetra
0 0 .504 r
.81327 .23972 .81408 .24102 .81655 .24658 .8155 .24268 Mtetra
.971 .659 .291 r
.8155 .24268 .81655 .24658 .83831 .45367 .83667 .44405 Mtetra
.07 .053 .529 r
.83667 .44405 .83831 .45367 .84081 .458 .83966 .45358 Mtetra
.422 .362 .685 r
.83966 .45358 .84081 .458 .84291 .45811 .84188 .45502 Mtetra
.501 .465 .748 r
.84188 .45502 .84291 .45811 .84494 .45748 .84401 .45544 Mtetra
.558 .579 .831 r
.84401 .45544 .84494 .45748 .84693 .45651 .8461 .45534 Mtetra
.477 .672 .95 r
.8461 .45534 .84693 .45651 .84901 .45639 .84819 .45536 Mtetra
.631 .78 .953 r
.84819 .45536 .84901 .45639 .85105 .45584 .85023 .45479 Mtetra
.799 .832 .877 r
.85023 .45479 .85105 .45584 .85301 .45446 .85218 .45333 Mtetra
.976 .788 .586 r
.85218 .45333 .85301 .45446 .85449 .44832 .85367 .44718 Mtetra
.974 .667 .312 r
.85367 .44718 .85449 .44832 .83536 .23897 .83457 .23776 Mtetra
.973 .775 .576 r
.83457 .23776 .83536 .23897 .83669 .2328 .83591 .2316 Mtetra
.759 .756 .85 r
.22544 .43893 .22647 .4399 .22804 .43885 .22701 .43787 Mtetra
.614 .724 .924 r
.22701 .43787 .22804 .43885 .22954 .43852 .22851 .43753 Mtetra
.464 .665 .95 r
.22851 .43753 .22954 .43852 .23101 .43858 .22998 .43758 Mtetra
.648 .727 .907 r
.22998 .43758 .23101 .43858 .23252 .43815 .2315 .43711 Mtetra
.661 .725 .897 r
.2315 .43711 .23252 .43815 .23404 .43767 .23302 .4366 Mtetra
.673 .723 .887 r
.23302 .4366 .23404 .43767 .23557 .43712 .23455 .43603 Mtetra
.752 .736 .838 r
.23455 .43603 .23557 .43712 .23713 .43624 .23613 .43497 Mtetra
.711 .7 .838 r
.23613 .43497 .23713 .43624 .23868 .43545 .23768 .43415 Mtetra
.619 .664 .872 r
.23768 .43415 .23868 .43545 .24021 .43491 .23919 .4338 Mtetra
.726 .245 0 r
.23919 .4338 .24021 .43491 .24164 .43544 .2405 .43576 Mtetra
.901 .58 .428 r
.2405 .43576 .24164 .43544 .24303 .43657 .24141 .44242 Mtetra
.93 .673 .527 r
.24141 .44242 .24303 .43657 .24437 .43828 .22623 .63538 Mtetra
.543 .32 .526 r
.22623 .63538 .24437 .43828 .24585 .43835 .22773 .63638 Mtetra
.539 .317 .525 r
.22773 .63638 .24585 .43835 .2474 .43758 .22937 .63566 Mtetra
.538 .315 .525 r
.22937 .63566 .2474 .43758 .24899 .43648 .23108 .63412 Mtetra
.539 .317 .525 r
.23108 .63412 .24899 .43648 .25054 .43582 .23272 .63341 Mtetra
.54 .317 .525 r
.23272 .63341 .25054 .43582 .25208 .43521 .23436 .63281 Mtetra
.23436 .63281 .25208 .43521 .25362 .43464 .23599 .63224 Mtetra
.23599 .63224 .25362 .43464 .25516 .43411 .23762 .63176 Mtetra
.23762 .63176 .25516 .43411 .2567 .4336 .23924 .63131 Mtetra
.23924 .63131 .2567 .4336 .25823 .4331 .24087 .63086 Mtetra
.542 .319 .526 r
.24087 .63086 .25823 .4331 .25974 .43299 .24242 .63132 Mtetra
.54 .318 .526 r
.24242 .63132 .25974 .43299 .26127 .43267 .24402 .63116 Mtetra
.538 .315 .525 r
.24402 .63116 .26127 .43267 .26284 .43172 .24574 .6296 Mtetra
0 0 .2 r
.24574 .6296 .26284 .43172 .26455 .42919 .2628 .43725 Mtetra
0 0 0 r
.2628 .43725 .26455 .42919 .26623 .42693 .26508 .42763 Mtetra
.967 .921 .702 r
.26508 .42763 .26623 .42693 .26787 .42519 .26685 .42424 Mtetra
.775 .764 .843 r
.26685 .42424 .26787 .42519 .26944 .42434 .26844 .42306 Mtetra
.659 .684 .862 r
.26844 .42306 .26944 .42434 .27098 .42382 .26999 .42253 Mtetra
.6 .661 .881 r
.26999 .42253 .27098 .42382 .27252 .42342 .27152 .42225 Mtetra
.648 .7 .884 r
.27152 .42225 .27252 .42342 .27406 .42292 .27306 .42178 Mtetra
.659 .709 .884 r
.27306 .42178 .27406 .42292 .27561 .42239 .27461 .42126 Mtetra
.659 .71 .886 r
.27461 .42126 .27561 .42239 .27716 .42186 .27615 .42075 Mtetra
.661 .713 .887 r
.27615 .42075 .27716 .42186 .27871 .42133 .2777 .42022 Mtetra
.661 .715 .888 r
.2777 .42022 .27871 .42133 .28026 .42079 .27925 .41969 Mtetra
.661 .718 .89 r
.27925 .41969 .28026 .42079 .28181 .42024 .28081 .41917 Mtetra
.66 .721 .894 r
.28081 .41917 .28181 .42024 .28336 .41969 .28236 .41865 Mtetra
.66 .728 .9 r
.28236 .41865 .28336 .41969 .28492 .41913 .28391 .41813 Mtetra
.661 .737 .906 r
.28391 .41813 .28492 .41913 .28648 .41857 .28546 .41761 Mtetra
.664 .746 .911 r
.28546 .41761 .28648 .41857 .28803 .41801 .28702 .41707 Mtetra
.666 .752 .915 r
.28702 .41707 .28803 .41801 .28959 .41745 .28858 .41653 Mtetra
.666 .756 .917 r
.28858 .41653 .28959 .41745 .29115 .4169 .29013 .41598 Mtetra
.697 .764 .904 r
.29013 .41598 .29115 .4169 .29272 .41611 .2917 .41531 Mtetra
.685 .786 .927 r
.2917 .41531 .29272 .41611 .29429 .41544 .29327 .41469 Mtetra
.617 .783 .961 r
.29327 .41469 .29429 .41544 .29583 .41517 .29482 .41429 Mtetra
.174 .544 .928 r
.29482 .41429 .29583 .41517 .29725 .41663 .29631 .41473 Mtetra
.104 .292 .769 r
.29631 .41473 .29725 .41663 .29843 .42157 .29775 .41594 Mtetra
.36 .267 .613 r
.29775 .41594 .29843 .42157 .28639 .61736 .29914 .41792 Mtetra
.541 .323 .532 r
.29914 .41792 .28639 .61736 .28786 .61956 .30066 .41809 Mtetra
.544 .325 .532 r
.30066 .41809 .28786 .61956 .28952 .61897 .30225 .41716 Mtetra
.542 .323 .532 r
.30225 .41716 .28952 .61897 .29121 .61804 .3038 .41692 Mtetra
.476 .269 .518 r
.3038 .41692 .29121 .61804 .29276 .61928 .30345 .44464 Mtetra
0 0 .228 r
.30345 .44464 .29276 .61928 .29428 .62082 .29338 .61733 Mtetra
0 0 .522 r
.29338 .61733 .29428 .62082 .29585 .62177 .2948 .62052 Mtetra
.248 .516 .909 r
.2948 .62052 .29585 .62177 .29748 .62181 .29639 .62107 Mtetra
.617 .8 .969 r
.29639 .62107 .29748 .62181 .29915 .62137 .29806 .62063 Mtetra
.71 .818 .932 r
.29806 .62063 .29915 .62137 .30082 .62076 .29975 .61985 Mtetra
.638 .766 .94 r
.29975 .61985 .30082 .62076 .30248 .62047 .30141 .61937 Mtetra
.62 .72 .918 r
.30141 .61937 .30248 .62047 .30414 .62016 .30308 .61898 Mtetra
.675 .721 .884 r
.30308 .61898 .30414 .62016 .30582 .61942 .30476 .61834 Mtetra
.771 .76 .843 r
.30476 .61834 .30582 .61942 .30762 .61705 .30648 .61709 Mtetra
.898 .941 .83 r
.30648 .61709 .30762 .61705 .3096 .61153 .30825 .61505 Mtetra
0 0 0 r
.30825 .61505 .3096 .61153 .32353 .41408 .31011 .61167 Mtetra
.51 .292 .519 r
.31011 .61167 .32353 .41408 .32542 .4085 .31269 .59649 Mtetra
0 0 .223 r
.31269 .59649 .32542 .4085 .3271 .40629 .32593 .40814 Mtetra
.854 .91 .503 r
.32593 .40814 .3271 .40629 .32873 .40488 .32771 .40441 Mtetra
.843 .863 .857 r
.32771 .40441 .32873 .40488 .33033 .40401 .32935 .40289 Mtetra
.675 .72 .883 r
.32935 .40289 .33033 .40401 .33192 .40344 .33093 .40229 Mtetra
.606 .692 .903 r
.33093 .40229 .33192 .40344 .33349 .403 .3325 .40197 Mtetra
.685 .743 .895 r
.3325 .40197 .33349 .403 .33509 .40218 .33409 .40133 Mtetra
.726 .787 .901 r
.33409 .40133 .33509 .40218 .3367 .40128 .33569 .40051 Mtetra
.676 .797 .939 r
.33569 .40051 .3367 .40128 .33828 .40077 .33728 .39991 Mtetra
.466 .704 .972 r
.33728 .39991 .33828 .40077 .33978 .40165 .33884 .39989 Mtetra
.295 .432 .83 r
.33884 .39989 .33978 .40165 .34113 .40527 .34035 .40064 Mtetra
.312 .256 .633 r
.34035 .40064 .34113 .40527 .33162 .60142 .3418 .40262 Mtetra
.51 .297 .526 r
.3418 .40262 .33162 .60142 .33295 .60735 .34255 .41689 Mtetra
0 0 .253 r
.34255 .41689 .33295 .60735 .33452 .60894 .33363 .60496 Mtetra
0 .062 .578 r
.33363 .60496 .33452 .60894 .33615 .60951 .33512 .60805 Mtetra
.289 .494 .884 r
.33512 .60805 .33615 .60951 .33782 .60937 .33675 .60865 Mtetra
.656 .817 .961 r
.33675 .60865 .33782 .60937 .33952 .60876 .33845 .60808 Mtetra
.743 .837 .922 r
.33845 .60808 .33952 .60876 .34123 .60798 .34017 .60713 Mtetra
.661 .788 .942 r
.34017 .60713 .34123 .60798 .34292 .60763 .34187 .60656 Mtetra
.57 .711 .938 r
.34187 .60656 .34292 .60763 .34459 .60751 .34355 .60632 Mtetra
.634 .71 .902 r
.34355 .60632 .34459 .60751 .34629 .60698 .34524 .60587 Mtetra
.748 .754 .857 r
.34524 .60587 .34629 .60698 .34807 .60498 .34697 .60478 Mtetra
.889 .911 .835 r
.34697 .60478 .34807 .60498 .35 .5999 .34875 .60279 Mtetra
0 0 0 r
.34875 .60279 .35 .5999 .36169 .40207 .3506 .5994 Mtetra
.509 .292 .52 r
.3506 .5994 .36169 .40207 .3636 .39539 .35307 .58354 Mtetra
0 0 .247 r
.35307 .58354 .3636 .39539 .36529 .39297 .36417 .39468 Mtetra
.875 .916 .517 r
.36417 .39468 .36529 .39297 .36694 .39143 .36594 .39087 Mtetra
.857 .847 .833 r
.36594 .39087 .36694 .39143 .36857 .39045 .3676 .38914 Mtetra
.682 .693 .854 r
.3676 .38914 .36857 .39045 .37017 .38986 .36921 .38847 Mtetra
.615 .655 .866 r
.36921 .38847 .37017 .38986 .37177 .38944 .37081 .38812 Mtetra
.653 .681 .864 r
.37081 .38812 .37177 .38944 .37338 .38892 .37241 .3876 Mtetra
.692 .695 .848 r
.37241 .3876 .37338 .38892 .37499 .38827 .37403 .38686 Mtetra
.63 .66 .86 r
.37403 .38686 .37499 .38827 .37659 .38778 .37563 .38645 Mtetra
.208 .457 .877 r
.37563 .38645 .37659 .38778 .37817 .38783 .37718 .38715 Mtetra
.879 .442 .11 r
.37718 .38715 .37817 .38783 .37972 .38864 .37862 .39029 Mtetra
.95 .681 .491 r
.37862 .39029 .37972 .38864 .38125 .38998 .37153 .58311 Mtetra
.556 .33 .528 r
.37153 .58311 .38125 .38998 .38281 .39057 .37286 .59113 Mtetra
.54 .317 .526 r
.37286 .59113 .38281 .39057 .38445 .38959 .37457 .59073 Mtetra
.539 .316 .525 r
.37457 .59073 .38445 .38959 .38606 .38906 .3763 .58971 Mtetra
.542 .319 .526 r
.3763 .58971 .38606 .38906 .38752 .39229 .37796 .59062 Mtetra
.545 .321 .526 r
.37796 .59062 .38752 .39229 .38077 .58972 .37956 .59288 Mtetra
.631 .291 .376 r
.37956 .59288 .38077 .58972 .38227 .59448 .3812 .59426 Mtetra
.188 0 0 r
.3812 .59426 .38227 .59448 .38392 .5958 .38288 .59467 Mtetra
.621 .72 .917 r
.38288 .59467 .38392 .5958 .38563 .59548 .3846 .59426 Mtetra
.672 .719 .885 r
.3846 .59426 .38563 .59548 .38736 .59474 .38633 .59362 Mtetra
.672 .737 .899 r
.38633 .59362 .38736 .59474 .3891 .59398 .38806 .59298 Mtetra
.639 .754 .932 r
.38806 .59298 .3891 .59398 .39083 .59343 .38979 .59249 Mtetra
.637 .766 .941 r
.38979 .59249 .39083 .59343 .39256 .59288 .39151 .592 Mtetra
.593 .764 .961 r
.39151 .592 .39256 .59288 .39428 .59242 .39324 .59164 Mtetra
.539 .769 .983 r
.39324 .59164 .39428 .59242 .39601 .59204 .39496 .59139 Mtetra
.65 .836 .972 r
.39496 .59139 .39601 .59204 .39774 .5915 .39669 .5908 Mtetra
.831 .84 .854 r
.39669 .5908 .39774 .5915 .39949 .59056 .39846 .58921 Mtetra
.884 .736 .692 r
.39846 .58921 .39949 .59056 .40126 .58898 .40032 .58533 Mtetra
.898 .663 .575 r
.40032 .58533 .40126 .58898 .40306 .58647 .40253 .5715 Mtetra
.939 .671 .504 r
.40253 .5715 .40306 .58647 .40499 .5805 .41107 .37942 Mtetra
.548 .328 .533 r
.41107 .37942 .40499 .5805 .41362 .38127 .4128 .37608 Mtetra
.669 .495 .641 r
.4128 .37608 .41362 .38127 .41542 .37602 .41448 .3741 Mtetra
.723 .64 .766 r
.41448 .3741 .41542 .37602 .41711 .37377 .41614 .37287 Mtetra
.689 .778 .919 r
.41614 .37287 .41711 .37377 .41875 .37299 .41778 .37221 Mtetra
.619 .785 .961 r
.41778 .37221 .41875 .37299 .42037 .37263 .41941 .37178 Mtetra
.595 .76 .958 r
.41941 .37178 .42037 .37263 .422 .3724 .42103 .37144 Mtetra
.619 .743 .935 r
.42103 .37144 .422 .3724 .42363 .37203 .42267 .37105 Mtetra
.626 .741 .93 r
.42267 .37105 .42363 .37203 .42526 .37164 .4243 .37063 Mtetra
.656 .744 .914 r
.4243 .37063 .42526 .37164 .4269 .37116 .42594 .3701 Mtetra
.697 .746 .889 r
.42594 .3701 .4269 .37116 .42854 .3705 .42758 .36938 Mtetra
.701 .736 .878 r
.42758 .36938 .42854 .3705 .43018 .3698 .42923 .36863 Mtetra
.708 .729 .867 r
.42923 .36863 .43018 .3698 .43183 .36907 .43088 .36782 Mtetra
.713 .718 .853 r
.43088 .36782 .43183 .36907 .43348 .36834 .43253 .36697 Mtetra
.654 .678 .86 r
.43253 .36697 .43348 .36834 .43512 .36778 .43417 .36643 Mtetra
.418 .573 .9 r
.43417 .36643 .43512 .36778 .43675 .36763 .43579 .36672 Mtetra
.793 .32 0 r
.43579 .36672 .43675 .36763 .43836 .36833 .43735 .36931 Mtetra
.924 .611 .43 r
.43735 .36931 .43836 .36833 .43996 .36955 .43863 .38234 Mtetra
.94 .664 .487 r
.43863 .38234 .43996 .36955 .44157 .37061 .43527 .57198 Mtetra
.54 .318 .526 r
.43527 .57198 .44157 .37061 .44323 .36961 .43701 .57181 Mtetra
.539 .316 .525 r
.43701 .57181 .44323 .36961 .44488 .3689 .43878 .57078 Mtetra
.541 .318 .526 r
.43878 .57078 .44488 .3689 .44649 .37037 .44052 .57088 Mtetra
.545 .321 .526 r
.44052 .57088 .44649 .37037 .44336 .56848 .44221 .57336 Mtetra
.616 .306 .421 r
.44221 .57336 .44336 .56848 .44496 .57475 .44392 .5749 Mtetra
.473 0 0 r
.44392 .5749 .44496 .57475 .44667 .57667 .44565 .57557 Mtetra
.604 .723 .929 r
.44565 .57557 .44667 .57667 .44842 .57646 .44741 .5752 Mtetra
.665 .716 .886 r
.44741 .5752 .44842 .57646 .45019 .57577 .44918 .57458 Mtetra
.68 .733 .89 r
.44918 .57458 .45019 .57577 .45196 .57492 .45095 .57389 Mtetra
.64 .751 .929 r
.45095 .57389 .45196 .57492 .45373 .57436 .45272 .57338 Mtetra
.639 .762 .937 r
.45272 .57338 .45373 .57436 .4555 .5738 .45449 .57287 Mtetra
.62 .768 .951 r
.45449 .57287 .4555 .5738 .45727 .57327 .45626 .57242 Mtetra
.536 .755 .977 r
.45626 .57242 .45727 .57327 .45904 .57289 .45802 .5722 Mtetra
.627 .825 .976 r
.45802 .5722 .45904 .57289 .46081 .57236 .45979 .57167 Mtetra
.796 .852 .892 r
.45979 .57167 .46081 .57236 .46259 .57145 .46158 .57038 Mtetra
.906 .767 .697 r
.46158 .57038 .46259 .57145 .46439 .56954 .46342 .56653 Mtetra
.903 .674 .582 r
.46342 .56653 .46439 .56954 .4662 .56704 .46537 .55556 Mtetra
.95 .677 .485 r
.46537 .55556 .4662 .56704 .46801 .56427 .47047 .36032 Mtetra
.545 .325 .532 r
.47047 .36032 .46801 .56427 .46979 .56329 .47216 .3588 Mtetra
.542 .323 .532 r
.47216 .3588 .46979 .56329 .47156 .563 .47382 .35857 Mtetra
.541 .322 .532 r
.47382 .35857 .47156 .563 .47333 .56306 .47548 .359 Mtetra
.541 .323 .532 r
.47548 .359 .47333 .56306 .4751 .56336 .47714 .35917 Mtetra
.542 .323 .532 r
.47714 .35917 .4751 .56336 .47688 .56291 .47881 .3588 Mtetra
.545 .326 .533 r
.47881 .3588 .47688 .56291 .47868 .56065 .48051 .3571 Mtetra
.549 .328 .533 r
.48051 .3571 .47868 .56065 .48307 .36177 .48222 .3536 Mtetra
.649 .454 .606 r
.48222 .3536 .48307 .36177 .48484 .35334 .48392 .35104 Mtetra
.749 .627 .725 r
.48392 .35104 .48484 .35334 .48655 .35019 .48561 .34924 Mtetra
.707 .776 .906 r
.48561 .34924 .48655 .35019 .48823 .34924 .48729 .34847 Mtetra
.641 .801 .959 r
.48729 .34847 .48823 .34924 .48991 .34875 .48897 .34796 Mtetra
.612 .786 .965 r
.48897 .34796 .48991 .34875 .49158 .34844 .49064 .34754 Mtetra
.702 .786 .917 r
.49064 .34754 .49158 .34844 .49326 .34758 .49233 .3468 Mtetra
.665 .805 .95 r
.49233 .3468 .49326 .34758 .49494 .34699 .49401 .34621 Mtetra
.56 .769 .976 r
.49401 .34621 .49494 .34699 .49662 .34697 .49568 .34593 Mtetra
.041 .413 .862 r
.49568 .34593 .49662 .34697 .49827 .34947 .49735 .34676 Mtetra
.22 .287 .72 r
.49735 .34676 .49827 .34947 .49985 .36206 .49902 .34836 Mtetra
.467 .297 .566 r
.49902 .34836 .49985 .36206 .50013 .55507 .50068 .35092 Mtetra
.541 .323 .532 r
.50068 .35092 .50013 .55507 .50192 .55557 .50237 .35116 Mtetra
.543 .324 .532 r
.50237 .35116 .50192 .55557 .50371 .55482 .50406 .35026 Mtetra
.544 .325 .532 r
.50406 .35026 .50371 .55482 .50552 .55342 .50576 .34888 Mtetra
.545 .325 .532 r
.50576 .34888 .50552 .55342 .50732 .55239 .50745 .34725 Mtetra
.543 .324 .532 r
.50745 .34725 .50732 .55239 .50912 .55167 .50915 .34645 Mtetra
.54 .322 .532 r
.50915 .34645 .50912 .55167 .51092 .55167 .51083 .3472 Mtetra
0 0 .351 r
.51083 .3472 .51092 .55167 .51272 .55343 .51176 .54522 Mtetra
.025 .009 .499 r
.51176 .54522 .51272 .55343 .51451 .55472 .51353 .55211 Mtetra
0 .139 .666 r
.51353 .55211 .51451 .55472 .51632 .55545 .51533 .55448 Mtetra
.501 .714 .967 r
.51533 .55448 .51632 .55545 .51813 .55516 .51714 .55438 Mtetra
.657 .817 .961 r
.51714 .55438 .51813 .55516 .51994 .55461 .51895 .55376 Mtetra
.721 .818 .925 r
.51895 .55376 .51994 .55461 .52175 .55392 .52077 .55287 Mtetra
.599 .739 .942 r
.52077 .55287 .52175 .55392 .52356 .55371 .52258 .5525 Mtetra
.638 .72 .907 r
.52258 .5525 .52356 .55371 .52538 .55325 .5244 .552 Mtetra
.695 .733 .88 r
.5244 .552 .52538 .55325 .52719 .55225 .52621 .5512 Mtetra
.809 .792 .836 r
.52621 .5512 .52719 .55225 .52901 .54896 .52803 .54962 Mtetra
.846 .98 .686 r
.52803 .54962 .52901 .54896 .53081 .54088 .52984 .54715 Mtetra
.125 0 .294 r
.52984 .54715 .53081 .54088 .53216 .34023 .53165 .54263 Mtetra
0 0 .344 r
.53165 .54263 .53216 .34023 .53386 .33641 .53296 .34202 Mtetra
0 0 .095 r
.53296 .34202 .53386 .33641 .53556 .33433 .53465 .33488 Mtetra
.94 .961 .672 r
.53465 .33488 .53556 .33433 .53726 .33295 .53635 .33185 Mtetra
.754 .764 .86 r
.53635 .33185 .53726 .33295 .53897 .33213 .53805 .33076 Mtetra
.651 .683 .868 r
.53805 .33076 .53897 .33213 .54068 .33158 .53976 .33022 Mtetra
.589 .659 .886 r
.53976 .33022 .54068 .33158 .54239 .33118 .54147 .32996 Mtetra
.619 .696 .9 r
.54147 .32996 .54239 .33118 .5441 .33074 .54319 .32956 Mtetra
.621 .707 .907 r
.54319 .32956 .5441 .33074 .54581 .33028 .5449 .32916 Mtetra
.63 .721 .912 r
.5449 .32916 .54581 .33028 .54752 .32979 .54661 .32872 Mtetra
.714 .758 .887 r
.54661 .32872 .54752 .32979 .54923 .3288 .54832 .32788 Mtetra
.711 .789 .913 r
.54832 .32788 .54923 .3288 .55095 .32796 .55004 .32708 Mtetra
.652 .783 .943 r
.55004 .32708 .55095 .32796 .55266 .32757 .55175 .32653 Mtetra
.398 .632 .949 r
.55175 .32653 .55266 .32757 .5544 .32916 .55348 .32673 Mtetra
.344 .392 .767 r
.55348 .32673 .5544 .32916 .55618 .33472 .55521 .32774 Mtetra
.365 .262 .602 r
.55521 .32774 .55618 .33472 .56001 .53539 .55697 .33047 Mtetra
0 0 .37 r
.55697 .33047 .56001 .53539 .56188 .53883 .56082 .52911 Mtetra
.082 .041 .507 r
.56082 .52911 .56188 .53883 .56374 .54004 .56275 .53686 Mtetra
.12 .204 .678 r
.56275 .53686 .56374 .54004 .56559 .54043 .56463 .53924 Mtetra
.441 .638 .939 r
.56463 .53924 .56559 .54043 .56744 .54021 .56648 .53939 Mtetra
.644 .809 .962 r
.56648 .53939 .56744 .54021 .56928 .53966 .56832 .5388 Mtetra
.719 .82 .928 r
.56832 .5388 .56928 .53966 .57113 .53896 .57016 .53792 Mtetra
.625 .753 .939 r
.57016 .53792 .57113 .53896 .57298 .53867 .57201 .53744 Mtetra
.633 .719 .909 r
.57201 .53744 .57298 .53867 .57483 .53825 .57386 .53695 Mtetra
.686 .726 .881 r
.57386 .53695 .57483 .53825 .57667 .53733 .57571 .53619 Mtetra
.791 .78 .843 r
.57571 .53619 .57667 .53733 .57848 .53446 .57754 .53473 Mtetra
.888 .99 .766 r
.57754 .53473 .57848 .53446 .58023 .52771 .57937 .53242 Mtetra
.039 0 .223 r
.57937 .53242 .58023 .52771 .57863 .32548 .58116 .52837 Mtetra
0 0 .367 r
.58116 .52837 .57863 .32548 .5803 .32085 .57956 .32884 Mtetra
0 0 .21 r
.57956 .32884 .5803 .32085 .582 .31862 .58114 .31958 Mtetra
.877 .934 .556 r
.58114 .31958 .582 .31862 .58372 .31718 .58283 .31628 Mtetra
.781 .812 .878 r
.58283 .31628 .58372 .31718 .58545 .31638 .58455 .31507 Mtetra
.63 .687 .885 r
.58455 .31507 .58545 .31638 .58719 .31592 .58629 .31463 Mtetra
.562 .661 .903 r
.58629 .31463 .58719 .31592 .58894 .31559 .58804 .31446 Mtetra
.685 .742 .895 r
.58804 .31446 .58894 .31559 .59067 .31471 .58978 .31376 Mtetra
.713 .788 .91 r
.58978 .31376 .59067 .31471 .5924 .31382 .59151 .31294 Mtetra
.66 .788 .943 r
.59151 .31294 .5924 .31382 .59415 .31335 .59326 .31234 Mtetra
.44 .664 .956 r
.59326 .31234 .59415 .31335 .59593 .3146 .59501 .31244 Mtetra
.345 .418 .794 r
.59501 .31244 .59593 .3146 .5978 .31926 .59679 .31334 Mtetra
.357 .272 .621 r
.59679 .31334 .5978 .31926 .60435 .52086 .59861 .3158 Mtetra
0 0 .389 r
.59861 .3158 .60435 .52086 .60633 .52514 .60512 .51314 Mtetra
.086 .034 .496 r
.60512 .51314 .60633 .52514 .60825 .52649 .60724 .52294 Mtetra
.141 .199 .663 r
.60724 .52294 .60825 .52649 .61014 .52696 .60919 .52558 Mtetra
.337 .543 .906 r
.60919 .52558 .61014 .52696 .61203 .52706 .61109 .5261 Mtetra
.605 .766 .957 r
.61109 .5261 .61203 .52706 .61391 .52671 .61297 .52567 Mtetra
.731 .791 .9 r
.61297 .52567 .61391 .52671 .61578 .52576 .61483 .52469 Mtetra
.796 .798 .854 r
.61483 .52469 .61578 .52576 .6176 .52321 .61668 .52323 Mtetra
.889 .984 .811 r
.61668 .52323 .6176 .52321 .61933 .51757 .61852 .5211 Mtetra
0 0 .143 r
.61852 .5211 .61933 .51757 .61538 .31505 .62031 .51763 Mtetra
.517 .3 .523 r
.62031 .51763 .61538 .31505 .61698 .30915 .62181 .50408 Mtetra
0 0 .376 r
.62181 .50408 .61698 .30915 .61869 .30681 .61789 .30864 Mtetra
.668 .768 .289 r
.61789 .30864 .61869 .30681 .62042 .30532 .61956 .30471 Mtetra
.846 .884 .867 r
.61956 .30471 .62042 .30532 .62217 .30438 .62128 .30313 Mtetra
.671 .717 .883 r
.62128 .30313 .62217 .30438 .62393 .30377 .62304 .30248 Mtetra
.608 .686 .897 r
.62304 .30248 .62393 .30377 .62569 .30327 .62481 .30212 Mtetra
.69 .744 .892 r
.62481 .30212 .62569 .30327 .62745 .30236 .62657 .30139 Mtetra
.728 .792 .903 r
.62657 .30139 .62745 .30236 .6292 .30138 .62833 .30049 Mtetra
.678 .795 .937 r
.62833 .30049 .6292 .30138 .63096 .30081 .63009 .29982 Mtetra
.49 .693 .958 r
.63009 .29982 .63096 .30081 .63278 .30176 .63187 .29977 Mtetra
.365 .451 .817 r
.63187 .29977 .63278 .30176 .63471 .30575 .63369 .30054 Mtetra
.372 .296 .64 r
.63369 .30054 .63471 .30575 .6437 .50741 .63555 .3026 Mtetra
.51 .299 .529 r
.63555 .3026 .6437 .50741 .64579 .51257 .63792 .3186 Mtetra
0 0 .397 r
.63792 .3186 .64579 .51257 .64776 .51393 .64671 .50954 Mtetra
.175 .191 .637 r
.64671 .50954 .64776 .51393 .64969 .5144 .64874 .51267 Mtetra
.213 .409 .839 r
.64874 .51267 .64969 .5144 .65163 .51471 .6507 .51376 Mtetra
.456 .705 .975 r
.6507 .51376 .65163 .51471 .65355 .51466 .65262 .51375 Mtetra
.724 .819 .924 r
.65262 .51375 .65355 .51466 .65544 .51385 .65451 .51281 Mtetra
.919 .801 .713 r
.65451 .51281 .65544 .51385 .65723 .51051 .6563 .50933 Mtetra
.975 .686 .407 r
.6563 .50933 .65723 .51051 .65139 .31767 .65026 .31011 Mtetra
.866 .608 .545 r
.65026 .31011 .65139 .31767 .6523 .29547 .65142 .29416 Mtetra
.867 .762 .745 r
.65142 .29416 .6523 .29547 .65399 .29285 .65312 .2916 Mtetra
.659 .716 .89 r
.65312 .2916 .65399 .29285 .65577 .29222 .6549 .291 Mtetra
.519 .659 .923 r
.6549 .291 .65577 .29222 .65757 .29214 .65671 .29095 Mtetra
.564 .687 .923 r
.65671 .29095 .65757 .29214 .65937 .2919 .65851 .29074 Mtetra
.656 .733 .906 r
.65851 .29074 .65937 .2919 .66116 .29129 .66029 .29016 Mtetra
.671 .744 .905 r
.66029 .29016 .66116 .29129 .66294 .29063 .66208 .28952 Mtetra
.744 .772 .876 r
.66208 .28952 .66294 .29063 .6647 .28957 .66384 .28848 Mtetra
.759 .778 .869 r
.66384 .28848 .6647 .28957 .66647 .28843 .66561 .28734 Mtetra
.66 .748 .915 r
.66561 .28734 .66647 .28843 .66826 .28783 .6674 .28675 Mtetra
0 .222 .732 r
.6674 .28675 .66826 .28783 .67014 .28927 .66928 .2882 Mtetra
.956 .611 .257 r
.66928 .2882 .67014 .28927 .67256 .30204 .67174 .30186 Mtetra
.974 .675 .382 r
.67174 .30186 .67256 .30204 .68395 .50189 .68305 .50087 Mtetra
.547 .066 0 r
.68305 .50087 .68395 .50189 .68602 .50431 .68511 .50326 Mtetra
.479 .692 .961 r
.68511 .50326 .68602 .50431 .68797 .50431 .68706 .50323 Mtetra
.753 .797 .888 r
.68706 .50323 .68797 .50431 .68987 .50319 .68896 .50209 Mtetra
.919 .799 .712 r
.68896 .50209 .68987 .50319 .69165 .49976 .69074 .49859 Mtetra
.977 .684 .392 r
.69074 .49859 .69165 .49976 .68357 .30203 .68256 .29793 Mtetra
.922 .663 .529 r
.68256 .29793 .68357 .30203 .68451 .28448 .68364 .28318 Mtetra
.881 .768 .732 r
.68364 .28318 .68451 .28448 .68619 .28162 .68533 .28037 Mtetra
.679 .726 .885 r
.68533 .28037 .68619 .28162 .68798 .28089 .68713 .27967 Mtetra
.553 .676 .92 r
.68713 .27967 .68798 .28089 .68981 .2807 .68895 .27951 Mtetra
.624 .714 .911 r
.68895 .27951 .68981 .2807 .69162 .28023 .69076 .27906 Mtetra
.725 .757 .879 r
.69076 .27906 .69162 .28023 .6934 .27928 .69255 .27812 Mtetra
.632 .726 .915 r
.69255 .27812 .6934 .27928 .69521 .27879 .69436 .27764 Mtetra
0 .313 .802 r
.69436 .27764 .69521 .27879 .69712 .28006 .69628 .27891 Mtetra
.94 .579 .189 r
.69628 .27891 .69712 .28006 .69956 .29069 .69871 .28952 Mtetra
.975 .674 .366 r
.69871 .28952 .69956 .29069 .71287 .49268 .71197 .49159 Mtetra
.574 .106 0 r
.71197 .49159 .71287 .49268 .715 .49538 .7141 .49429 Mtetra
.442 .667 .958 r
.7141 .49429 .715 .49538 .71698 .49547 .71608 .49438 Mtetra
.728 .79 .902 r
.71608 .49438 .71698 .49547 .7189 .49448 .718 .49339 Mtetra
.903 .81 .747 r
.718 .49339 .7189 .49448 .72071 .49156 .71981 .49047 Mtetra
.978 .742 .51 r
.71981 .49047 .72071 .49156 .72199 .47995 .7211 .47883 Mtetra
.977 .681 .378 r
.7211 .47883 .72199 .47995 .7117 .27635 .71085 .2752 Mtetra
.92 .788 .699 r
.71085 .2752 .7117 .27635 .71334 .27289 .7125 .27174 Mtetra
.72 .761 .885 r
.7125 .27174 .71334 .27289 .71514 .27197 .7143 .27082 Mtetra
.598 .714 .925 r
.7143 .27082 .71514 .27197 .71698 .27163 .71614 .27047 Mtetra
.633 .729 .917 r
.71614 .27047 .71698 .27163 .71881 .27114 .71797 .26999 Mtetra
.739 .768 .876 r
.71797 .26999 .71881 .27114 .7206 .27011 .71976 .26896 Mtetra
.651 .736 .912 r
.71976 .26896 .7206 .27011 .72243 .26954 .72159 .26839 Mtetra
.109 .431 .872 r
.72159 .26839 .72243 .26954 .72435 .27048 .72351 .26933 Mtetra
.907 .524 .093 r
.72351 .26933 .72435 .27048 .72673 .27835 .72589 .27723 Mtetra
.975 .671 .352 r
.72589 .27723 .72673 .27835 .74205 .48303 .74117 .48195 Mtetra
.603 .14 0 r
.74117 .48195 .74205 .48303 .74424 .48598 .74336 .48489 Mtetra
.551 .723 .954 r
.74336 .48489 .74424 .48598 .74623 .48574 .74535 .48465 Mtetra
.712 .788 .911 r
.74535 .48465 .74623 .48574 .74817 .48483 .74729 .48374 Mtetra
.695 .783 .919 r
.74729 .48374 .74817 .48483 .75012 .48401 .74924 .48292 Mtetra
.509 .703 .958 r
.74924 .48292 .75012 .48401 .75212 .4839 .75124 .48282 Mtetra
.653 .768 .933 r
.75124 .48282 .75212 .4839 .75409 .48327 .75321 .48219 Mtetra
.869 .819 .798 r
.75321 .48219 .75409 .48327 .75594 .48103 .75506 .47994 Mtetra
.98 .751 .519 r
.75506 .47994 .75594 .48103 .75724 .47091 .75637 .4699 Mtetra
.977 .678 .362 r
.75637 .4699 .75724 .47091 .74463 .26552 .74381 .26438 Mtetra
.935 .791 .677 r
.74381 .26438 .74463 .26552 .74624 .26166 .74541 .26051 Mtetra
.728 .767 .884 r
.74541 .26051 .74624 .26166 .74805 .2607 .74723 .25955 Mtetra
.601 .716 .926 r
.74723 .25955 .74805 .2607 .74991 .26034 .74909 .25918 Mtetra
.6 .716 .926 r
.74909 .25918 .74991 .26034 .75177 .25998 .75095 .25882 Mtetra
.74 .771 .878 r
.75095 .25882 .75177 .25998 .75359 .25894 .75276 .25778 Mtetra
.656 .74 .911 r
.75276 .25778 .75359 .25894 .75543 .25834 .75461 .25719 Mtetra
.229 .508 .907 r
.75461 .25719 .75543 .25834 .75738 .25904 .75656 .25788 Mtetra
.885 .494 .041 r
.75656 .25788 .75738 .25904 .75983 .26639 .75901 .26524 Mtetra
.975 .667 .334 r
.75901 .26524 .75983 .26639 .77751 .47221 .77665 .47111 Mtetra
.653 .199 0 r
.77665 .47111 .77751 .47221 .77981 .47566 .77894 .47455 Mtetra
.382 .631 .952 r
.77894 .47455 .77981 .47566 .78186 .47592 .781 .47481 Mtetra
.693 .78 .918 r
.781 .47481 .78186 .47592 .78384 .47511 .78297 .47399 Mtetra
.873 .82 .793 r
.78297 .47399 .78384 .47511 .78569 .47279 .78483 .47168 Mtetra
.978 .767 .552 r
.78483 .47168 .78569 .47279 .78711 .46497 .78624 .46385 Mtetra
.977 .675 .347 r
.78624 .46385 .78711 .46497 .77243 .25702 .77161 .25585 Mtetra
.95 .785 .641 r
.77161 .25585 .77243 .25702 .77396 .25241 .77315 .25124 Mtetra
.746 .772 .874 r
.77315 .25124 .77396 .25241 .77578 .25133 .77497 .25016 Mtetra
.617 .722 .92 r
.77497 .25016 .77578 .25133 .77766 .2509 .77684 .24972 Mtetra
.584 .706 .927 r
.77684 .24972 .77766 .2509 .77954 .25059 .77873 .24942 Mtetra
.747 .772 .874 r
.77873 .24942 .77954 .25059 .78137 .2495 .78056 .24833 Mtetra
.67 .744 .906 r
.78056 .24833 .78137 .2495 .78322 .24884 .78241 .24766 Mtetra
.351 .58 .928 r
.78241 .24766 .78322 .24884 .78518 .24925 .78437 .24808 Mtetra
.837 .432 0 r
.78437 .24808 .78518 .24925 .78762 .25541 .78681 .25423 Mtetra
.973 .663 .318 r
.78681 .25423 .78762 .25541 .80735 .4625 .8065 .46138 Mtetra
.69 .245 0 r
.8065 .46138 .80735 .4625 .80975 .46645 .8089 .46533 Mtetra
.349 .609 .946 r
.8089 .46533 .80975 .46645 .81184 .46681 .81099 .46569 Mtetra
.674 .773 .925 r
.81099 .46569 .81184 .46681 .81384 .46608 .81299 .46495 Mtetra
.856 .821 .814 r
.81299 .46495 .81384 .46608 .81572 .46401 .81487 .46288 Mtetra
.977 .777 .567 r
.81487 .46288 .81572 .46401 .81717 .45703 .81632 .4559 Mtetra
.976 .672 .332 r
.81632 .4559 .81717 .45703 .80049 .2482 .79969 .24702 Mtetra
.962 .782 .614 r
.79969 .24702 .80049 .2482 .80195 .24298 .80115 .2418 Mtetra
.751 .775 .873 r
.80115 .2418 .80195 .24298 .80378 .24186 .80298 .24068 Mtetra
.613 .721 .922 r
.80298 .24068 .80378 .24186 .80568 .24143 .80488 .24026 Mtetra
.534 .683 .934 r
.80488 .24026 .80568 .24143 .8076 .24129 .8068 .24013 Mtetra
.698 .76 .9 r
.8068 .24013 .8076 .24129 .80945 .24034 .80867 .23932 Mtetra
.666 .777 .932 r
.80867 .23932 .80945 .24034 .81133 .23969 .81055 .23866 Mtetra
.579 .737 .951 r
.81055 .23866 .81133 .23969 .81327 .23972 .81246 .23833 Mtetra
.346 .536 .898 r
.81246 .23833 .81327 .23972 .8155 .24268 .81446 .2389 Mtetra
.373 .341 .694 r
.81446 .2389 .8155 .24268 .83667 .44405 .81656 .24053 Mtetra
.532 .316 .532 r
.81656 .24053 .83667 .44405 .83966 .45358 .81903 .24591 Mtetra
.078 0 .454 r
.81903 .24591 .83966 .45358 .84188 .45502 .8405 .44822 Mtetra
.274 .217 .61 r
.8405 .44822 .84188 .45502 .84401 .45544 .843 .4525 Mtetra
.305 .35 .744 r
.843 .4525 .84401 .45544 .8461 .45534 .84526 .45415 Mtetra
.405 .628 .944 r
.84526 .45415 .8461 .45534 .84819 .45536 .84738 .4544 Mtetra
.634 .796 .96 r
.84738 .4544 .84819 .45536 .85023 .45479 .84942 .45381 Mtetra
.821 .848 .869 r
.84942 .45381 .85023 .45479 .85218 .45333 .85135 .45219 Mtetra
.976 .788 .586 r
.85135 .45219 .85218 .45333 .85367 .44718 .85284 .44605 Mtetra
.974 .667 .312 r
.85284 .44605 .85367 .44718 .83457 .23776 .83378 .23656 Mtetra
.974 .775 .575 r
.83378 .23656 .83457 .23776 .83591 .2316 .83512 .23039 Mtetra
.76 .756 .849 r
.2244 .43796 .22544 .43893 .22701 .43787 .22598 .43689 Mtetra
.618 .725 .922 r
.22598 .43689 .22701 .43787 .22851 .43753 .22748 .43654 Mtetra
.474 .669 .949 r
.22748 .43654 .22851 .43753 .22998 .43758 .22896 .43656 Mtetra
.662 .731 .901 r
.22896 .43656 .22998 .43758 .2315 .43711 .23048 .43604 Mtetra
.667 .721 .89 r
.23048 .43604 .2315 .43711 .23302 .4366 .23201 .4355 Mtetra
.667 .716 .885 r
.23201 .4355 .23302 .4366 .23455 .43603 .23353 .43496 Mtetra
.742 .737 .847 r
.23353 .43496 .23455 .43603 .23613 .43497 .2351 .43399 Mtetra
.69 .743 .891 r
.2351 .43399 .23613 .43497 .23768 .43415 .23664 .43334 Mtetra
.431 .698 .977 r
.23664 .43334 .23768 .43415 .23919 .4338 .23812 .43337 Mtetra
.91 .542 .32 r
.23812 .43337 .23919 .4338 .2405 .43576 .23923 .43755 Mtetra
.935 .679 .525 r
.23923 .43755 .2405 .43576 .24141 .44242 .2235 .6351 Mtetra
.551 .326 .528 r
.2235 .6351 .24141 .44242 .22623 .63538 .22463 .6403 Mtetra
.543 .242 .407 r
.22463 .6403 .22623 .63538 .22773 .63638 .22618 .64062 Mtetra
.45 .14 .348 r
.22618 .64062 .22773 .63638 .22937 .63566 .22782 .64004 Mtetra
.401 .098 .331 r
.22782 .64004 .22937 .63566 .23108 .63412 .22949 .63904 Mtetra
.464 .167 .375 r
.22949 .63904 .23108 .63412 .23272 .63341 .23112 .63846 Mtetra
.471 .175 .381 r
.23112 .63846 .23272 .63341 .23436 .63281 .23275 .63793 Mtetra
.473 .178 .384 r
.23275 .63793 .23436 .63281 .23599 .63224 .23438 .63741 Mtetra
.478 .183 .386 r
.23438 .63741 .23599 .63224 .23762 .63176 .23601 .63693 Mtetra
.478 .184 .387 r
.23601 .63693 .23762 .63176 .23924 .63131 .23764 .63646 Mtetra
.478 .183 .386 r
.23764 .63646 .23924 .63131 .24087 .63086 .23927 .63598 Mtetra
.516 .219 .401 r
.23927 .63598 .24087 .63086 .24242 .63132 .24087 .63595 Mtetra
.485 .181 .375 r
.24087 .63595 .24242 .63132 .24402 .63116 .24249 .63562 Mtetra
.398 .097 .333 r
.24249 .63562 .24402 .63116 .24574 .6296 .24417 .63457 Mtetra
0 0 0 r
.24417 .63457 .24574 .6296 .2628 .43725 .24618 .62941 Mtetra
0 0 .153 r
.24618 .62941 .2628 .43725 .26508 .42763 .26377 .43016 Mtetra
.972 .891 .525 r
.26377 .43016 .26508 .42763 .26685 .42424 .26578 .42394 Mtetra
.851 .889 .866 r
.26578 .42394 .26685 .42424 .26844 .42306 .2674 .42243 Mtetra
.658 .82 .962 r
.2674 .42243 .26844 .42306 .26999 .42253 .26895 .42189 Mtetra
.49 .769 .993 r
.26895 .42189 .26999 .42253 .27152 .42225 .27046 .42174 Mtetra
.609 .839 .987 r
.27046 .42174 .27152 .42225 .27306 .42178 .272 .4213 Mtetra
.634 .853 .983 r
.272 .4213 .27306 .42178 .27461 .42126 .27355 .42079 Mtetra
.631 .854 .984 r
.27355 .42079 .27461 .42126 .27615 .42075 .2751 .42028 Mtetra
.629 .857 .985 r
.2751 .42028 .27615 .42075 .2777 .42022 .27665 .41978 Mtetra
.628 .862 .987 r
.27665 .41978 .2777 .42022 .27925 .41969 .2782 .41926 Mtetra
.63 .866 .987 r
.2782 .41926 .27925 .41969 .28081 .41917 .27975 .41874 Mtetra
.645 .871 .983 r
.27975 .41874 .28081 .41917 .28236 .41865 .28131 .41818 Mtetra
.656 .863 .978 r
.28131 .41818 .28236 .41865 .28391 .41813 .28286 .41761 Mtetra
.661 .85 .972 r
.28286 .41761 .28391 .41813 .28546 .41761 .28442 .41703 Mtetra
.654 .836 .97 r
.28442 .41703 .28546 .41761 .28702 .41707 .28598 .41649 Mtetra
.649 .833 .971 r
.28598 .41649 .28702 .41707 .28858 .41653 .28753 .41596 Mtetra
.647 .837 .973 r
.28753 .41596 .28858 .41653 .29013 .41598 .28909 .41544 Mtetra
.656 .844 .972 r
.28909 .41544 .29013 .41598 .2917 .41531 .29065 .41488 Mtetra
.643 .871 .984 r
.29065 .41488 .2917 .41531 .29327 .41469 .29221 .41432 Mtetra
.623 .881 .989 r
.29221 .41432 .29327 .41469 .29482 .41429 .29378 .41379 Mtetra
.612 .845 .988 r
.29378 .41379 .29482 .41429 .29631 .41473 .29533 .41333 Mtetra
.633 .657 .856 r
.29533 .41333 .29631 .41473 .29775 .41594 .29689 .41291 Mtetra
.604 .505 .715 r
.29689 .41291 .29775 .41594 .29914 .41792 .29844 .41249 Mtetra
.608 .449 .64 r
.29844 .41249 .29914 .41792 .30066 .41809 .30003 .41165 Mtetra
.595 .427 .624 r
.30003 .41165 .30066 .41809 .30225 .41716 .30161 .41089 Mtetra
.564 .406 .626 r
.30161 .41089 .30225 .41716 .3038 .41692 .30315 .41068 Mtetra
.315 .225 .592 r
.30315 .41068 .3038 .41692 .30345 .44464 .30451 .41326 Mtetra
.983 .729 .467 r
.30451 .41326 .30345 .44464 .29338 .61733 .29274 .60999 Mtetra
0 0 .24 r
.29274 .60999 .29338 .61733 .2948 .62052 .29379 .61848 Mtetra
.163 .327 .782 r
.29379 .61848 .2948 .62052 .29639 .62107 .29535 .61966 Mtetra
.613 .663 .874 r
.29535 .61966 .29639 .62107 .29806 .62063 .29701 .61931 Mtetra
.704 .708 .851 r
.29701 .61931 .29806 .62063 .29975 .61985 .2987 .61848 Mtetra
.668 .688 .859 r
.2987 .61848 .29975 .61985 .30141 .61937 .30038 .61785 Mtetra
.638 .656 .851 r
.30038 .61785 .30141 .61937 .30308 .61898 .30205 .61737 Mtetra
.644 .647 .838 r
.30205 .61737 .30308 .61898 .30476 .61834 .30372 .61685 Mtetra
.589 .641 .87 r
.30372 .61685 .30476 .61834 .30648 .61709 .30538 .61661 Mtetra
.541 .836 .999 r
.30538 .61661 .30648 .61709 .30825 .61505 .30705 .61625 Mtetra
0 0 0 r
.30705 .61625 .30825 .61505 .31011 .61167 .30875 .61527 Mtetra
.30875 .61527 .31011 .61167 .31269 .59649 .31064 .61148 Mtetra
.966 .71 .497 r
.31064 .61148 .31269 .59649 .32593 .40814 .32454 .41339 Mtetra
.853 .795 .301 r
.32454 .41339 .32593 .40814 .32771 .40441 .32668 .40394 Mtetra
.889 .842 .793 r
.32668 .40394 .32771 .40441 .32935 .40289 .32836 .40176 Mtetra
.682 .722 .88 r
.32836 .40176 .32935 .40289 .33093 .40229 .32995 .40113 Mtetra
.569 .677 .912 r
.32995 .40113 .33093 .40229 .3325 .40197 .33151 .40094 Mtetra
.621 .722 .918 r
.33151 .40094 .3325 .40197 .33409 .40133 .33308 .40056 Mtetra
.675 .796 .939 r
.33308 .40056 .33409 .40133 .33569 .40051 .33467 .39997 Mtetra
.657 .848 .973 r
.33467 .39997 .33569 .40051 .33728 .39991 .33626 .39939 Mtetra
.716 .864 .952 r
.33626 .39939 .33728 .39991 .33884 .39989 .33786 .39862 Mtetra
.689 .7 .855 r
.33786 .39862 .33884 .39989 .34035 .40064 .33946 .39792 Mtetra
.578 .506 .738 r
.33946 .39792 .34035 .40064 .3418 .40262 .34102 .39774 Mtetra
.311 .249 .625 r
.34102 .39774 .3418 .40262 .34255 .41689 .34246 .39983 Mtetra
.971 .709 .477 r
.34246 .39983 .34255 .41689 .33363 .60496 .3331 .5945 Mtetra
0 0 .288 r
.3331 .5945 .33363 .60496 .33512 .60805 .33413 .60571 Mtetra
.075 .236 .726 r
.33413 .60571 .33512 .60805 .33675 .60865 .33571 .60733 Mtetra
.604 .675 .891 r
.33571 .60733 .33675 .60865 .33845 .60808 .33739 .60701 Mtetra
.716 .755 .883 r
.33739 .60701 .33845 .60808 .34017 .60713 .33911 .60615 Mtetra
.697 .769 .907 r
.33911 .60615 .34017 .60713 .34187 .60656 .34082 .60542 Mtetra
.643 .724 .907 r
.34082 .60542 .34187 .60656 .34355 .60632 .34251 .60493 Mtetra
.649 .682 .867 r
.34251 .60493 .34355 .60632 .34524 .60587 .34421 .60439 Mtetra
.607 .653 .87 r
.34421 .60439 .34524 .60587 .34697 .60478 .3459 .60406 Mtetra
.577 .794 .982 r
.3459 .60406 .34697 .60478 .34875 .60279 .3476 .60371 Mtetra
0 0 0 r
.3476 .60371 .34875 .60279 .3506 .5994 .34932 .60277 Mtetra
.34932 .60277 .3506 .5994 .35307 .58354 .35117 .59941 Mtetra
.971 .712 .484 r
.35117 .59941 .35307 .58354 .36417 .39468 .36277 .40206 Mtetra
0 0 0 r
.36277 .40206 .36417 .39468 .36594 .39087 .3649 .39105 Mtetra
.94 .93 .766 r
.3649 .39105 .36594 .39087 .3676 .38914 .3666 .38848 Mtetra
.713 .832 .938 r
.3666 .38848 .3676 .38914 .36921 .38847 .36822 .38773 Mtetra
.562 .774 .978 r
.36822 .38773 .36921 .38847 .37081 .38812 .36981 .38745 Mtetra
.646 .817 .966 r
.36981 .38745 .37081 .38812 .37241 .3876 .37142 .38693 Mtetra
.727 .833 .931 r
.37142 .38693 .37241 .3876 .37403 .38686 .37304 .38612 Mtetra
.59 .782 .972 r
.37304 .38612 .37403 .38686 .37563 .38645 .37463 .38577 Mtetra
.594 .049 0 r
.37463 .38577 .37563 .38645 .37718 .38715 .37615 .38719 Mtetra
.933 .615 .415 r
.37615 .38719 .37718 .38715 .37862 .39029 .37726 .39764 Mtetra
.943 .673 .497 r
.37726 .39764 .37862 .39029 .37153 .58311 .36996 .59386 Mtetra
.604 .336 .484 r
.36996 .59386 .37153 .58311 .37286 .59113 .37154 .59617 Mtetra
.497 .198 .389 r
.37154 .59617 .37286 .59113 .37457 .59073 .37325 .59592 Mtetra
.447 .155 .375 r
.37325 .59592 .37457 .59073 .3763 .58971 .37498 .59507 Mtetra
.457 .167 .383 r
.37498 .59507 .3763 .58971 .37796 .59062 .37671 .5943 Mtetra
.464 .14 .331 r
.37671 .5943 .37796 .59062 .37956 .59288 .37843 .59392 Mtetra
.236 0 0 r
.37843 .59392 .37956 .59288 .3812 .59426 .38014 .59355 Mtetra
.603 .807 .978 r
.38014 .59355 .3812 .59426 .38288 .59467 .38186 .59311 Mtetra
.641 .657 .851 r
.38186 .59311 .38288 .59467 .3846 .59426 .38359 .59261 Mtetra
.643 .646 .838 r
.38359 .59261 .3846 .59426 .38633 .59362 .38531 .59207 Mtetra
.648 .662 .85 r
.38531 .59207 .38633 .59362 .38806 .59298 .38704 .59153 Mtetra
.649 .675 .861 r
.38704 .59153 .38806 .59298 .38979 .59249 .38877 .59098 Mtetra
.648 .667 .854 r
.38877 .59098 .38979 .59249 .39151 .592 .3905 .59044 Mtetra
.604 .642 .861 r
.3905 .59044 .39151 .592 .39324 .59164 .39222 .59012 Mtetra
.559 .627 .876 r
.39222 .59012 .39324 .59164 .39496 .59139 .39394 .58999 Mtetra
.665 .689 .863 r
.39394 .58999 .39496 .59139 .39669 .5908 .39567 .58936 Mtetra
.827 .727 .754 r
.39567 .58936 .39669 .5908 .39846 .58921 .39747 .58707 Mtetra
.909 .693 .599 r
.39747 .58707 .39846 .58921 .40032 .58533 .39953 .57777 Mtetra
.948 .682 .497 r
.39953 .57777 .40032 .58533 .40253 .5715 .40851 .37785 Mtetra
.549 .329 .533 r
.40851 .37785 .40253 .5715 .41107 .37942 .41025 .37416 Mtetra
.619 .459 .644 r
.41025 .37416 .41107 .37942 .4128 .37608 .4119 .37315 Mtetra
.609 .515 .723 r
.4119 .37315 .4128 .37608 .41448 .3741 .41353 .37269 Mtetra
.608 .652 .868 r
.41353 .37269 .41448 .3741 .41614 .37287 .41516 .37237 Mtetra
.629 .859 .986 r
.41516 .37237 .41614 .37287 .41778 .37221 .41679 .37184 Mtetra
.59 .879 .993 r
.41679 .37184 .41778 .37221 .41941 .37178 .41842 .37133 Mtetra
.613 .867 .991 r
.41842 .37133 .41941 .37178 .42103 .37144 .42006 .37081 Mtetra
.653 .832 .969 r
.42006 .37081 .42103 .37144 .42267 .37105 .4217 .37025 Mtetra
.664 .794 .944 r
.4217 .37025 .42267 .37105 .4243 .37063 .42334 .36967 Mtetra
.666 .759 .92 r
.42334 .36967 .4243 .37063 .42594 .3701 .42498 .3691 Mtetra
.665 .75 .913 r
.42498 .3691 .42594 .3701 .42758 .36938 .42662 .36853 Mtetra
.664 .784 .938 r
.42662 .36853 .42758 .36938 .42923 .36863 .42826 .36796 Mtetra
.698 .836 .949 r
.42826 .36796 .42923 .36863 .43088 .36782 .42991 .36725 Mtetra
.754 .865 .93 r
.42991 .36725 .43088 .36782 .43253 .36697 .43156 .36629 Mtetra
.645 .82 .967 r
.43156 .36629 .43253 .36697 .43417 .36643 .4332 .36576 Mtetra
0 .373 .783 r
.4332 .36576 .43417 .36643 .43579 .36672 .43481 .36649 Mtetra
.926 .567 .324 r
.43481 .36649 .43579 .36672 .43735 .36931 .43627 .37289 Mtetra
.954 .679 .477 r
.43627 .37289 .43735 .36931 .43863 .38234 .43244 .57365 Mtetra
.547 .323 .526 r
.43244 .57365 .43863 .38234 .43527 .57198 .43409 .57706 Mtetra
.509 .209 .393 r
.43409 .57706 .43527 .57198 .43701 .57181 .43583 .57695 Mtetra
.454 .16 .376 r
.43583 .57695 .43701 .57181 .43878 .57078 .4376 .57617 Mtetra
.446 .158 .38 r
.4376 .57617 .43878 .57078 .44052 .57088 .43937 .57524 Mtetra
.476 .167 .361 r
.43937 .57524 .44052 .57088 .44221 .57336 .44113 .57485 Mtetra
.327 0 .047 r
.44113 .57485 .44221 .57336 .44392 .5749 .44289 .57446 Mtetra
.544 .855 .998 r
.44289 .57446 .44392 .5749 .44565 .57557 .44465 .57403 Mtetra
.641 .664 .856 r
.44465 .57403 .44565 .57557 .44741 .5752 .44641 .57351 Mtetra
.643 .644 .836 r
.44641 .57351 .44741 .5752 .44918 .57458 .44818 .57297 Mtetra
.647 .656 .844 r
.44818 .57297 .44918 .57458 .45095 .57389 .44995 .57241 Mtetra
.65 .675 .86 r
.44995 .57241 .45095 .57389 .45272 .57338 .45172 .57184 Mtetra
.65 .667 .853 r
.45172 .57184 .45272 .57338 .45449 .57287 .45349 .57128 Mtetra
.629 .651 .853 r
.45349 .57128 .45449 .57287 .45626 .57242 .45526 .57082 Mtetra
.548 .613 .87 r
.45526 .57082 .45626 .57242 .45802 .5722 .45702 .57074 Mtetra
.643 .676 .867 r
.45702 .57074 .45802 .5722 .45979 .57167 .45879 .57022 Mtetra
.789 .724 .792 r
.45879 .57022 .45979 .57167 .46158 .57038 .46059 .56854 Mtetra
.912 .709 .615 r
.46059 .56854 .46158 .57038 .46342 .56653 .46249 .56129 Mtetra
.957 .685 .478 r
.46249 .56129 .46342 .56653 .46537 .55556 .46788 .35856 Mtetra
.551 .33 .533 r
.46788 .35856 .46537 .55556 .47047 .36032 .46962 .35388 Mtetra
.608 .438 .625 r
.46962 .35388 .47047 .36032 .47216 .3588 .4713 .35283 Mtetra
.577 .421 .633 r
.4713 .35283 .47216 .3588 .47382 .35857 .47296 .35242 Mtetra
.56 .406 .63 r
.47296 .35242 .47382 .35857 .47548 .359 .47463 .35228 Mtetra
.578 .413 .622 r
.47463 .35228 .47548 .359 .47714 .35917 .4763 .35178 Mtetra
.575 .406 .614 r
.4763 .35178 .47714 .35917 .47881 .3588 .47797 .35128 Mtetra
.577 .406 .613 r
.47797 .35128 .47881 .3588 .48051 .3571 .47964 .35073 Mtetra
.59 .425 .627 r
.47964 .35073 .48051 .3571 .48222 .3536 .48132 .35005 Mtetra
.621 .5 .693 r
.48132 .35005 .48222 .3536 .48392 .35104 .48299 .34935 Mtetra
.666 .642 .817 r
.48299 .34935 .48392 .35104 .48561 .34924 .48467 .34868 Mtetra
.639 .852 .981 r
.48467 .34868 .48561 .34924 .48729 .34847 .48635 .34811 Mtetra
.589 .887 .991 r
.48635 .34811 .48729 .34847 .48897 .34796 .48803 .34757 Mtetra
.596 .883 .992 r
.48803 .34757 .48897 .34796 .49064 .34754 .4897 .34703 Mtetra
.645 .869 .983 r
.4897 .34703 .49064 .34754 .49233 .3468 .49138 .34643 Mtetra
.617 .893 .988 r
.49138 .34643 .49233 .3468 .49401 .34621 .49307 .34583 Mtetra
.603 .889 .99 r
.49307 .34583 .49401 .34621 .49568 .34593 .49475 .34527 Mtetra
.607 .82 .982 r
.49475 .34527 .49568 .34593 .49735 .34676 .49643 .34482 Mtetra
.622 .595 .802 r
.49643 .34482 .49735 .34676 .49902 .34836 .49811 .34438 Mtetra
.595 .471 .68 r
.49811 .34438 .49902 .34836 .50068 .35092 .4998 .34392 Mtetra
.582 .414 .619 r
.4998 .34392 .50068 .35092 .50237 .35116 .50148 .34331 Mtetra
.58 .405 .61 r
.50148 .34331 .50237 .35116 .50406 .35026 .50317 .34266 Mtetra
.582 .409 .612 r
.50317 .34266 .50406 .35026 .50576 .34888 .50486 .342 Mtetra
.604 .431 .62 r
.50486 .342 .50576 .34888 .50745 .34725 .50655 .34094 Mtetra
.589 .426 .628 r
.50655 .34094 .50745 .34725 .50915 .34645 .50824 .34027 Mtetra
.547 .398 .63 r
.50824 .34027 .50915 .34645 .51083 .3472 .50993 .34033 Mtetra
.145 .105 .55 r
.50993 .34033 .51083 .3472 .51176 .54522 .5116 .34509 Mtetra
0 0 .335 r
.5116 .34509 .51176 .54522 .51353 .55211 .51256 .5479 Mtetra
0 0 .468 r
.51256 .5479 .51353 .55211 .51533 .55448 .51435 .55277 Mtetra
.484 .568 .865 r
.51435 .55277 .51533 .55448 .51714 .55438 .51615 .55296 Mtetra
.653 .69 .872 r
.51615 .55296 .51714 .55438 .51895 .55376 .51797 .55238 Mtetra
.718 .718 .85 r
.51797 .55238 .51895 .55376 .52077 .55287 .51978 .5514 Mtetra
.641 .677 .868 r
.51978 .5514 .52077 .55287 .52258 .5525 .5216 .55087 Mtetra
.643 .656 .847 r
.5216 .55087 .52258 .5525 .5244 .552 .52341 .55032 Mtetra
.651 .653 .839 r
.52341 .55032 .5244 .552 .52621 .5512 .52523 .54972 Mtetra
.58 .65 .884 r
.52523 .54972 .52621 .5512 .52803 .54962 .52705 .54948 Mtetra
.501 .895 .946 r
.52705 .54948 .52803 .54962 .52984 .54715 .52887 .54889 Mtetra
.061 0 0 r
.52887 .54889 .52984 .54715 .53165 .54263 .53068 .54753 Mtetra
0 0 .071 r
.53068 .54753 .53165 .54263 .53296 .34202 .53249 .54142 Mtetra
0 0 .331 r
.53249 .54142 .53296 .34202 .53465 .33488 .53374 .33712 Mtetra
.863 .837 .368 r
.53374 .33712 .53465 .33488 .53635 .33185 .53543 .33142 Mtetra
.821 .913 .9 r
.53543 .33142 .53635 .33185 .53805 .33076 .53714 .33007 Mtetra
.632 .823 .974 r
.53714 .33007 .53805 .33076 .53976 .33022 .53885 .32955 Mtetra
.474 .767 .995 r
.53885 .32955 .53976 .33022 .54147 .32996 .54056 .3294 Mtetra
.622 .854 .987 r
.54056 .3294 .54147 .32996 .54319 .32956 .54227 .32886 Mtetra
.655 .827 .966 r
.54227 .32886 .54319 .32956 .5449 .32916 .54399 .32827 Mtetra
.664 .784 .938 r
.54399 .32827 .5449 .32916 .54661 .32872 .5457 .32768 Mtetra
.673 .754 .911 r
.5457 .32768 .54661 .32872 .54832 .32788 .54741 .32705 Mtetra
.67 .799 .944 r
.54741 .32705 .54832 .32788 .55004 .32708 .54913 .32642 Mtetra
.65 .838 .973 r
.54913 .32642 .55004 .32708 .55175 .32653 .55085 .32584 Mtetra
.729 .848 .937 r
.55085 .32584 .55175 .32653 .55348 .32673 .55256 .32496 Mtetra
.652 .631 .816 r
.55256 .32496 .55348 .32673 .55521 .32774 .55428 .32436 Mtetra
.55 .463 .709 r
.55428 .32436 .55521 .32774 .55697 .33047 .55601 .32439 Mtetra
.23 .178 .59 r
.55601 .32439 .55697 .33047 .56082 .52911 .55777 .32804 Mtetra
0 0 .357 r
.55777 .32804 .56082 .52911 .56275 .53686 .56174 .53122 Mtetra
0 0 .48 r
.56174 .53122 .56275 .53686 .56463 .53924 .56365 .53727 Mtetra
.391 .483 .834 r
.56365 .53727 .56463 .53924 .56648 .53939 .56551 .53789 Mtetra
.638 .676 .87 r
.56551 .53789 .56648 .53939 .56832 .5388 .56735 .53738 Mtetra
.713 .714 .85 r
.56735 .53738 .56832 .5388 .57016 .53792 .56919 .53641 Mtetra
.658 .682 .862 r
.56919 .53641 .57016 .53792 .57201 .53744 .57104 .53578 Mtetra
.643 .655 .847 r
.57104 .53578 .57201 .53744 .57386 .53695 .57289 .53522 Mtetra
.649 .649 .836 r
.57289 .53522 .57386 .53695 .57571 .53619 .57474 .53462 Mtetra
.589 .643 .872 r
.57474 .53462 .57571 .53619 .57754 .53473 .57659 .53435 Mtetra
.543 .875 .991 r
.57659 .53435 .57754 .53473 .57937 .53242 .57844 .53384 Mtetra
.038 0 0 r
.57844 .53384 .57937 .53242 .58116 .52837 .58029 .53264 Mtetra
0 0 .115 r
.58029 .53264 .58116 .52837 .57956 .32884 .58207 .52776 Mtetra
0 0 .351 r
.58207 .52776 .57956 .32884 .58114 .31958 .58033 .32322 Mtetra
0 0 0 r
.58033 .32322 .58114 .31958 .58283 .31628 .58195 .31608 Mtetra
.882 .954 .848 r
.58195 .31608 .58283 .31628 .58455 .31507 .58366 .31426 Mtetra
.672 .809 .949 r
.58366 .31426 .58455 .31507 .58629 .31463 .5854 .31362 Mtetra
.561 .721 .948 r
.5854 .31362 .58629 .31463 .58804 .31446 .58715 .31339 Mtetra
.642 .74 .92 r
.58715 .31339 .58804 .31446 .58978 .31376 .58889 .31288 Mtetra
.667 .792 .941 r
.58889 .31288 .58978 .31376 .59151 .31294 .59063 .31227 Mtetra
.645 .836 .974 r
.59063 .31227 .59151 .31294 .59326 .31234 .59237 .31168 Mtetra
.717 .858 .949 r
.59237 .31168 .59326 .31234 .59501 .31244 .59411 .31084 Mtetra
.666 .661 .836 r
.59411 .31084 .59501 .31244 .59679 .31334 .59585 .31017 Mtetra
.562 .481 .721 r
.59585 .31017 .59679 .31334 .59861 .3158 .59761 .3101 Mtetra
.296 .233 .615 r
.59761 .3101 .59861 .3158 .60512 .51314 .59944 .31304 Mtetra
0 0 .374 r
.59944 .31304 .60512 .51314 .60724 .52294 .60615 .51608 Mtetra
0 0 .475 r
.60615 .51608 .60724 .52294 .60919 .52558 .60821 .52339 Mtetra
.299 .403 .801 r
.60821 .52339 .60919 .52558 .61109 .5261 .61013 .52447 Mtetra
.614 .648 .86 r
.61013 .52447 .61109 .5261 .61297 .52567 .61201 .52407 Mtetra
.696 .687 .837 r
.61201 .52407 .61297 .52567 .61483 .52469 .61387 .52317 Mtetra
.623 .667 .872 r
.61387 .52317 .61483 .52469 .61668 .52323 .61576 .52272 Mtetra
.548 .851 .998 r
.61576 .52272 .61668 .52323 .61852 .5211 .61764 .52226 Mtetra
.001 0 0 r
.61764 .52226 .61852 .5211 .62031 .51763 .6195 .52118 Mtetra
0 0 .103 r
.6195 .52118 .62031 .51763 .62181 .50408 .62128 .51719 Mtetra
.983 .701 .389 r
.62128 .51719 .62181 .50408 .61789 .30864 .61721 .31416 Mtetra
0 0 0 r
.61721 .31416 .61789 .30864 .61956 .30471 .61869 .30412 Mtetra
.903 .872 .797 r
.61869 .30412 .61956 .30471 .62128 .30313 .6204 .30188 Mtetra
.679 .721 .881 r
.6204 .30188 .62128 .30313 .62304 .30248 .62216 .30119 Mtetra
.576 .671 .904 r
.62216 .30119 .62304 .30248 .62481 .30212 .62393 .30096 Mtetra
.63 .719 .911 r
.62393 .30096 .62481 .30212 .62657 .30139 .6257 .3005 Mtetra
.679 .796 .937 r
.6257 .3005 .62657 .30139 .62833 .30049 .62746 .29983 Mtetra
.663 .848 .971 r
.62746 .29983 .62833 .30049 .63009 .29982 .62923 .29917 Mtetra
.723 .868 .95 r
.62923 .29917 .63009 .29982 .63187 .29977 .63099 .2983 Mtetra
.687 .688 .846 r
.63099 .2983 .63187 .29977 .63369 .30054 .63275 .29752 Mtetra
.579 .499 .729 r
.63275 .29752 .63369 .30054 .63555 .3026 .63453 .2973 Mtetra
.351 .28 .635 r
.63453 .2973 .63555 .3026 .63792 .3186 .6364 .2996 Mtetra
.982 .694 .342 r
.6364 .2996 .63792 .3186 .64671 .50954 .64552 .50138 Mtetra
0 0 .438 r
.64552 .50138 .64671 .50954 .64874 .51267 .64779 .51093 Mtetra
0 .239 .753 r
.64779 .51093 .64874 .51267 .6507 .51376 .64977 .51269 Mtetra
.517 .706 .957 r
.64977 .51269 .6507 .51376 .65262 .51375 .65169 .51257 Mtetra
.752 .773 .87 r
.65169 .51257 .65262 .51375 .65451 .51281 .65357 .5114 Mtetra
.897 .761 .703 r
.65357 .5114 .65451 .51281 .6563 .50933 .65536 .50784 Mtetra
.975 .685 .407 r
.65536 .50784 .6563 .50933 .65026 .31011 .64953 .3128 Mtetra
.99 .758 .376 r
.64953 .3128 .65026 .31011 .65142 .29416 .65057 .29361 Mtetra
.93 .872 .759 r
.65057 .29361 .65142 .29416 .65312 .2916 .65227 .29092 Mtetra
.695 .855 .959 r
.65227 .29092 .65312 .2916 .6549 .291 .65405 .29015 Mtetra
.548 .757 .974 r
.65405 .29015 .6549 .291 .65671 .29095 .65584 .28989 Mtetra
.594 .728 .937 r
.65584 .28989 .65671 .29095 .65851 .29074 .65764 .28955 Mtetra
.657 .726 .9 r
.65764 .28955 .65851 .29074 .66029 .29016 .65942 .28896 Mtetra
.659 .726 .898 r
.65942 .28896 .66029 .29016 .66208 .28952 .66121 .28837 Mtetra
.723 .758 .881 r
.66121 .28837 .66208 .28952 .66384 .28848 .66299 .28745 Mtetra
.741 .788 .89 r
.66299 .28745 .66384 .28848 .66561 .28734 .66476 .28645 Mtetra
.62 .779 .957 r
.66476 .28645 .66561 .28734 .6674 .28675 .66655 .28599 Mtetra
0 .066 .548 r
.66655 .28599 .6674 .28675 .66928 .2882 .66845 .28763 Mtetra
.975 .675 .381 r
.66845 .28763 .66928 .2882 .67174 .30186 .67931 .48111 Mtetra
.574 .343 .527 r
.67931 .48111 .67174 .30186 .68305 .50087 .68214 .49995 Mtetra
.541 .043 0 r
.68214 .49995 .68305 .50087 .68511 .50326 .6842 .50216 Mtetra
.499 .694 .955 r
.6842 .50216 .68511 .50326 .68706 .50323 .68615 .50209 Mtetra
.75 .784 .88 r
.68615 .50209 .68706 .50323 .68896 .50209 .68805 .50095 Mtetra
.911 .797 .721 r
.68805 .50095 .68896 .50209 .69074 .49859 .68984 .49762 Mtetra
.98 .721 .466 r
.68984 .49762 .69074 .49859 .68256 .29793 .69083 .47838 Mtetra
0 0 .376 r
.69083 .47838 .68256 .29793 .68364 .28318 .68282 .28271 Mtetra
.95 .88 .73 r
.68282 .28271 .68364 .28318 .68533 .28037 .6845 .27968 Mtetra
.721 .861 .948 r
.6845 .27968 .68533 .28037 .68713 .27967 .68629 .2788 Mtetra
.582 .769 .968 r
.68629 .2788 .68713 .27967 .68895 .27951 .6881 .27844 Mtetra
.653 .753 .923 r
.6881 .27844 .68895 .27951 .69076 .27906 .68991 .27787 Mtetra
.724 .753 .875 r
.68991 .27787 .69076 .27906 .69255 .27812 .6917 .27693 Mtetra
.627 .715 .91 r
.6917 .27693 .69255 .27812 .69436 .27764 .69351 .27647 Mtetra
0 .31 .801 r
.69351 .27647 .69436 .27764 .69628 .27891 .69543 .27776 Mtetra
.939 .577 .186 r
.69543 .27776 .69628 .27891 .69871 .28952 .69785 .28826 Mtetra
.976 .674 .366 r
.69785 .28826 .69871 .28952 .71197 .49159 .71107 .49049 Mtetra
.57 .105 0 r
.71107 .49049 .71197 .49159 .7141 .49429 .7132 .49319 Mtetra
.442 .665 .957 r
.7132 .49319 .7141 .49429 .71608 .49438 .71518 .49329 Mtetra
.727 .789 .901 r
.71518 .49329 .71608 .49438 .718 .49339 .71711 .49229 Mtetra
.902 .81 .746 r
.71711 .49229 .718 .49339 .71981 .49047 .71892 .48937 Mtetra
.978 .741 .509 r
.71892 .48937 .71981 .49047 .7211 .47883 .72021 .47769 Mtetra
.977 .681 .378 r
.72021 .47769 .7211 .47883 .71085 .2752 .71001 .27405 Mtetra
.919 .788 .699 r
.71001 .27405 .71085 .2752 .7125 .27174 .71166 .27058 Mtetra
.72 .761 .885 r
.71166 .27058 .7125 .27174 .7143 .27082 .71346 .26967 Mtetra
.598 .713 .925 r
.71346 .26967 .7143 .27082 .71614 .27047 .7153 .26932 Mtetra
.633 .729 .917 r
.7153 .26932 .71614 .27047 .71797 .26999 .71713 .26883 Mtetra
.739 .768 .876 r
.71713 .26883 .71797 .26999 .71976 .26896 .71892 .26781 Mtetra
.65 .736 .912 r
.71892 .26781 .71976 .26896 .72159 .26839 .72075 .26724 Mtetra
.107 .43 .872 r
.72075 .26724 .72159 .26839 .72351 .26933 .72268 .26818 Mtetra
.908 .524 .095 r
.72268 .26818 .72351 .26933 .72589 .27723 .72506 .27611 Mtetra
.975 .671 .352 r
.72506 .27611 .72589 .27723 .74117 .48195 .74028 .48086 Mtetra
.604 .14 0 r
.74028 .48086 .74117 .48195 .74336 .48489 .74248 .4838 Mtetra
.55 .723 .954 r
.74248 .4838 .74336 .48489 .74535 .48465 .74446 .48357 Mtetra
.711 .788 .912 r
.74446 .48357 .74535 .48465 .74729 .48374 .74641 .48266 Mtetra
.694 .783 .919 r
.74641 .48266 .74729 .48374 .74924 .48292 .74836 .48184 Mtetra
.508 .704 .959 r
.74836 .48184 .74924 .48292 .75124 .48282 .75036 .48173 Mtetra
.653 .769 .934 r
.75036 .48173 .75124 .48282 .75321 .48219 .75233 .48111 Mtetra
.869 .82 .799 r
.75233 .48111 .75321 .48219 .75506 .47994 .75419 .47887 Mtetra
.98 .752 .521 r
.75419 .47887 .75506 .47994 .75637 .4699 .7555 .46892 Mtetra
.977 .678 .362 r
.7555 .46892 .75637 .4699 .74381 .26438 .74298 .26325 Mtetra
.936 .791 .676 r
.74298 .26325 .74381 .26438 .74541 .26051 .74459 .25936 Mtetra
.728 .768 .885 r
.74459 .25936 .74541 .26051 .74723 .25955 .7464 .2584 Mtetra
.601 .717 .926 r
.7464 .2584 .74723 .25955 .74909 .25918 .74826 .25803 Mtetra
.6 .716 .926 r
.74826 .25803 .74909 .25918 .75095 .25882 .75013 .25767 Mtetra
.74 .771 .878 r
.75013 .25767 .75095 .25882 .75276 .25778 .75194 .25662 Mtetra
.656 .74 .911 r
.75194 .25662 .75276 .25778 .75461 .25719 .75379 .25603 Mtetra
.228 .508 .907 r
.75379 .25603 .75461 .25719 .75656 .25788 .75573 .25672 Mtetra
.886 .495 .042 r
.75573 .25672 .75656 .25788 .75901 .26524 .75819 .2641 Mtetra
.975 .667 .334 r
.75819 .2641 .75901 .26524 .77665 .47111 .77578 .47 Mtetra
.653 .199 0 r
.77578 .47 .77665 .47111 .77894 .47455 .77807 .47344 Mtetra
.383 .631 .952 r
.77807 .47344 .77894 .47455 .781 .47481 .78013 .4737 Mtetra
.693 .78 .918 r
.78013 .4737 .781 .47481 .78297 .47399 .78211 .47288 Mtetra
.873 .82 .793 r
.78211 .47288 .78297 .47399 .78483 .47168 .78396 .47057 Mtetra
.978 .767 .552 r
.78396 .47057 .78483 .47168 .78624 .46385 .78538 .46274 Mtetra
.977 .675 .347 r
.78538 .46274 .78624 .46385 .77161 .25585 .77079 .25468 Mtetra
.95 .785 .641 r
.77079 .25468 .77161 .25585 .77315 .25124 .77233 .25006 Mtetra
.746 .772 .874 r
.77233 .25006 .77315 .25124 .77497 .25016 .77416 .24898 Mtetra
.617 .722 .92 r
.77416 .24898 .77497 .25016 .77684 .24972 .77603 .24855 Mtetra
.584 .706 .927 r
.77603 .24855 .77684 .24972 .77873 .24942 .77792 .24824 Mtetra
.747 .772 .874 r
.77792 .24824 .77873 .24942 .78056 .24833 .77974 .24715 Mtetra
.67 .744 .906 r
.77974 .24715 .78056 .24833 .78241 .24766 .7816 .24648 Mtetra
.351 .58 .928 r
.7816 .24648 .78241 .24766 .78437 .24808 .78356 .2469 Mtetra
.837 .432 0 r
.78356 .2469 .78437 .24808 .78681 .25423 .786 .25304 Mtetra
.973 .663 .318 r
.786 .25304 .78681 .25423 .8065 .46138 .80565 .46024 Mtetra
.689 .245 0 r
.80565 .46024 .8065 .46138 .8089 .46533 .80804 .4642 Mtetra
.35 .609 .946 r
.80804 .4642 .8089 .46533 .81099 .46569 .81014 .46456 Mtetra
.674 .773 .924 r
.81014 .46456 .81099 .46569 .81299 .46495 .81214 .46382 Mtetra
.856 .821 .813 r
.81214 .46382 .81299 .46495 .81487 .46288 .81402 .46175 Mtetra
.977 .776 .567 r
.81402 .46175 .81487 .46288 .81632 .4559 .81547 .45475 Mtetra
.976 .672 .332 r
.81547 .45475 .81632 .4559 .79969 .24702 .79888 .24582 Mtetra
.961 .78 .615 r
.79888 .24582 .79969 .24702 .80115 .2418 .80035 .24061 Mtetra
.749 .773 .872 r
.80035 .24061 .80115 .2418 .80298 .24068 .80218 .2395 Mtetra
.612 .719 .922 r
.80218 .2395 .80298 .24068 .80488 .24026 .80408 .23908 Mtetra
.531 .68 .934 r
.80408 .23908 .80488 .24026 .8068 .24013 .80601 .23896 Mtetra
.668 .747 .91 r
.80601 .23896 .8068 .24013 .80867 .23932 .80789 .2383 Mtetra
.667 .779 .933 r
.80789 .2383 .80867 .23932 .81055 .23866 .80977 .23763 Mtetra
.67 .779 .931 r
.80977 .23763 .81055 .23866 .81246 .23833 .81165 .23696 Mtetra
.725 .732 .857 r
.81165 .23696 .81246 .23833 .81446 .2389 .81349 .23594 Mtetra
.621 .532 .732 r
.81349 .23594 .81446 .2389 .81656 .24053 .81538 .23531 Mtetra
.536 .409 .655 r
.81538 .23531 .81656 .24053 .81903 .24591 .81735 .23556 Mtetra
.307 .206 .573 r
.81735 .23556 .81903 .24591 .8405 .44822 .81986 .24139 Mtetra
.063 0 .449 r
.81986 .24139 .8405 .44822 .843 .4525 .84191 .44871 Mtetra
0 .098 .615 r
.84191 .44871 .843 .4525 .84526 .45415 .84442 .45296 Mtetra
.325 .581 .935 r
.84442 .45296 .84526 .45415 .84738 .4544 .84656 .45344 Mtetra
.64 .799 .959 r
.84656 .45344 .84738 .4544 .84942 .45381 .8486 .45282 Mtetra
.838 .85 .855 r
.8486 .45282 .84942 .45381 .85135 .45219 .85052 .45105 Mtetra
.976 .788 .587 r
.85052 .45105 .85135 .45219 .85284 .44605 .85201 .44492 Mtetra
.974 .667 .312 r
.85201 .44492 .85284 .44605 .83378 .23656 .83299 .23536 Mtetra
.974 .775 .575 r
.83299 .23536 .83378 .23656 .83512 .23039 .83433 .22918 Mtetra
.761 .756 .847 r
.22337 .43698 .2244 .43796 .22598 .43689 .22495 .4359 Mtetra
.622 .725 .92 r
.22495 .4359 .22598 .43689 .22748 .43654 .22645 .43554 Mtetra
.481 .671 .947 r
.22645 .43554 .22748 .43654 .22896 .43656 .22793 .43555 Mtetra
.693 .738 .886 r
.22793 .43555 .22896 .43656 .23048 .43604 .22946 .43489 Mtetra
.671 .706 .874 r
.22946 .43489 .23048 .43604 .23201 .4355 .23099 .43431 Mtetra
.622 .685 .888 r
.23099 .43431 .23201 .4355 .23353 .43496 .23251 .43396 Mtetra
.434 .65 .95 r
.23251 .43396 .23353 .43496 .2351 .43399 .23398 .43406 Mtetra
.567 .008 0 r
.23398 .43406 .2351 .43399 .23664 .43334 .23539 .43481 Mtetra
.747 .381 .36 r
.23539 .43481 .23664 .43334 .23812 .43337 .23668 .43699 Mtetra
.932 .676 .527 r
.23668 .43699 .23812 .43337 .23923 .43755 .22116 .63035 Mtetra
.555 .33 .528 r
.22116 .63035 .23923 .43755 .2235 .6351 .22207 .63794 Mtetra
.704 .372 .412 r
.22207 .63794 .2235 .6351 .22463 .6403 .22344 .64031 Mtetra
.038 0 0 r
.22344 .64031 .22463 .6403 .22618 .64062 .22502 .64034 Mtetra
.61 .897 .987 r
.22502 .64034 .22618 .64062 .22782 .64004 .22666 .63977 Mtetra
.72 .917 .961 r
.22666 .63977 .22782 .64004 .22949 .63904 .22832 .6389 Mtetra
.553 .904 .972 r
.22832 .6389 .22949 .63904 .23112 .63846 .22995 .63834 Mtetra
.518 .894 .964 r
.22995 .63834 .23112 .63846 .23275 .63793 .23158 .63783 Mtetra
.505 .891 .959 r
.23158 .63783 .23275 .63793 .23438 .63741 .23321 .63732 Mtetra
.48 .882 .951 r
.23321 .63732 .23438 .63741 .23601 .63693 .23484 .63684 Mtetra
.473 .879 .949 r
.23484 .63684 .23601 .63693 .23764 .63646 .23647 .63637 Mtetra
.23647 .63637 .23764 .63646 .23927 .63598 .23811 .6359 Mtetra
.212 .732 .857 r
.23811 .6359 .23927 .63598 .24087 .63595 .23971 .63574 Mtetra
.46 .856 .973 r
.23971 .63574 .24087 .63595 .24249 .63562 .24134 .63537 Mtetra
.716 .923 .962 r
.24134 .63537 .24249 .63562 .24417 .63457 .243 .6345 Mtetra
.933 .855 .741 r
.243 .6345 .24417 .63457 .24618 .62941 .24486 .63131 Mtetra
.995 .839 .577 r
.24486 .63131 .24618 .62941 .26377 .43016 .24713 .62296 Mtetra
0 0 .171 r
.24713 .62296 .26377 .43016 .26578 .42394 .26438 .42769 Mtetra
.11 0 .177 r
.26438 .42769 .26578 .42394 .2674 .42243 .26607 .42539 Mtetra
.418 .08 .282 r
.26607 .42539 .2674 .42243 .26895 .42189 .26761 .42487 Mtetra
.52 .181 .334 r
.26761 .42487 .26895 .42189 .27046 .42174 .26911 .42502 Mtetra
.457 .128 .32 r
.26911 .42502 .27046 .42174 .272 .4213 .27065 .42466 Mtetra
.44 .114 .316 r
.27065 .42466 .272 .4213 .27355 .42079 .27219 .42418 Mtetra
.441 .116 .318 r
.27219 .42418 .27355 .42079 .2751 .42028 .27374 .42369 Mtetra
.485 .16 .339 r
.27374 .42369 .2751 .42028 .27665 .41978 .27527 .42352 Mtetra
.471 .155 .348 r
.27527 .42352 .27665 .41978 .2782 .41926 .27681 .42319 Mtetra
.398 .09 .322 r
.27681 .42319 .2782 .41926 .27975 .41874 .27839 .42227 Mtetra
.054 0 .138 r
.27839 .42227 .27975 .41874 .28131 .41818 .28009 .41988 Mtetra
0 0 0 r
.28009 .41988 .28131 .41818 .28286 .41761 .28177 .41763 Mtetra
.883 .943 .848 r
.28177 .41763 .28286 .41761 .28442 .41703 .28342 .41588 Mtetra
.728 .726 .848 r
.28342 .41588 .28442 .41703 .28598 .41649 .28501 .41497 Mtetra
.654 .648 .832 r
.28501 .41497 .28598 .41649 .28753 .41596 .28656 .41443 Mtetra
.628 .636 .839 r
.28656 .41443 .28753 .41596 .28909 .41544 .28811 .41402 Mtetra
.648 .661 .849 r
.28811 .41402 .28909 .41544 .29065 .41488 .28967 .41353 Mtetra
.657 .673 .854 r
.28967 .41353 .29065 .41488 .29221 .41432 .29123 .413 Mtetra
.659 .678 .857 r
.29123 .413 .29221 .41432 .29378 .41379 .29279 .41245 Mtetra
.663 .679 .855 r
.29279 .41245 .29378 .41379 .29533 .41333 .29435 .41189 Mtetra
.662 .663 .84 r
.29435 .41189 .29533 .41333 .29689 .41291 .29592 .41132 Mtetra
.657 .64 .822 r
.29592 .41132 .29689 .41291 .29844 .41249 .29749 .41075 Mtetra
.683 .634 .794 r
.29749 .41075 .29844 .41249 .30003 .41165 .29907 .40995 Mtetra
.672 .635 .804 r
.29907 .40995 .30003 .41165 .30161 .41089 .30065 .40926 Mtetra
.605 .614 .833 r
.30065 .40926 .30161 .41089 .30315 .41068 .3022 .40896 Mtetra
.039 .275 .771 r
.3022 .40896 .30315 .41068 .30451 .41326 .30364 .41017 Mtetra
0 0 .237 r
.30364 .41017 .30451 .41326 .29274 .60999 .30489 .41436 Mtetra
0 0 .217 r
.30489 .41436 .29274 .60999 .29379 .61848 .29317 .61086 Mtetra
.13 .077 .524 r
.29317 .61086 .29379 .61848 .29535 .61966 .29448 .6156 Mtetra
.361 .314 .671 r
.29448 .6156 .29535 .61966 .29701 .61931 .29602 .61704 Mtetra
.437 .468 .794 r
.29602 .61704 .29701 .61931 .2987 .61848 .29762 .61754 Mtetra
.55 .731 .959 r
.29762 .61754 .2987 .61848 .30038 .61785 .29927 .61733 Mtetra
.652 .86 .979 r
.29927 .61733 .30038 .61785 .30205 .61737 .30095 .61672 Mtetra
.705 .839 .947 r
.30095 .61672 .30205 .61737 .30372 .61685 .30264 .61596 Mtetra
.51 .727 .971 r
.30264 .61596 .30372 .61685 .30538 .61661 .30429 .61584 Mtetra
.452 .733 .987 r
.30429 .61584 .30538 .61661 .30705 .61625 .30594 .61578 Mtetra
.672 .877 .975 r
.30594 .61578 .30705 .61625 .30875 .61527 .30763 .61509 Mtetra
.938 .84 .72 r
.30763 .61509 .30875 .61527 .31064 .61148 .3095 .61154 Mtetra
.948 .69 .512 r
.3095 .61154 .31064 .61148 .32454 .41339 .32347 .41357 Mtetra
.961 .752 .575 r
.32347 .41357 .32454 .41339 .32668 .40394 .3257 .40256 Mtetra
.822 .716 .748 r
.3257 .40256 .32668 .40394 .32836 .40176 .32738 .40038 Mtetra
.652 .67 .854 r
.32738 .40038 .32836 .40176 .32995 .40113 .32897 .39986 Mtetra
.521 .636 .904 r
.32897 .39986 .32995 .40113 .33151 .40094 .33052 .39984 Mtetra
.581 .694 .92 r
.33052 .39984 .33151 .40094 .33308 .40056 .33208 .39961 Mtetra
.659 .751 .918 r
.33208 .39961 .33308 .40056 .33467 .39997 .33367 .39908 Mtetra
.672 .77 .924 r
.33367 .39908 .33467 .39997 .33626 .39939 .33526 .3985 Mtetra
.738 .781 .888 r
.33526 .3985 .33626 .39939 .33786 .39862 .33687 .39761 Mtetra
.737 .757 .869 r
.33687 .39761 .33786 .39862 .33946 .39792 .33848 .39668 Mtetra
.657 .696 .874 r
.33848 .39668 .33946 .39792 .34102 .39774 .34006 .39615 Mtetra
.204 .405 .838 r
.34006 .39615 .34102 .39774 .34246 .39983 .34158 .397 Mtetra
0 0 .342 r
.34158 .397 .34246 .39983 .3331 .5945 .34293 .40063 Mtetra
0 0 .238 r
.34293 .40063 .3331 .5945 .33413 .60571 .3335 .59707 Mtetra
.084 .035 .499 r
.3335 .59707 .33413 .60571 .33571 .60733 .33483 .60299 Mtetra
.362 .308 .662 r
.33483 .60299 .33571 .60733 .33739 .60701 .33642 .60454 Mtetra
.44 .454 .777 r
.33642 .60454 .33739 .60701 .33911 .60615 .33805 .60509 Mtetra
.542 .702 .944 r
.33805 .60509 .33911 .60615 .34082 .60542 .33973 .60493 Mtetra
.648 .87 .982 r
.33973 .60493 .34082 .60542 .34251 .60493 .34144 .60431 Mtetra
.711 .852 .95 r
.34144 .60431 .34251 .60493 .34421 .60439 .34315 .60351 Mtetra
.604 .766 .957 r
.34315 .60351 .34421 .60439 .3459 .60406 .34484 .60313 Mtetra
.514 .721 .966 r
.34484 .60313 .3459 .60406 .3476 .60371 .34653 .603 Mtetra
.643 .817 .967 r
.34653 .603 .3476 .60371 .34932 .60277 .34823 .60246 Mtetra
.894 .884 .816 r
.34823 .60246 .34932 .60277 .35117 .59941 .35002 .60031 Mtetra
.99 .859 .614 r
.35002 .60031 .35117 .59941 .36277 .40206 .352 .59439 Mtetra
0 0 .23 r
.352 .59439 .36277 .40206 .3649 .39105 .36362 .39588 Mtetra
0 0 .102 r
.36362 .39588 .3649 .39105 .3666 .38848 .36543 .39128 Mtetra
.348 .008 .239 r
.36543 .39128 .3666 .38848 .36822 .38773 .36705 .39042 Mtetra
.481 .129 .293 r
.36705 .39042 .36822 .38773 .36981 .38745 .36864 .39033 Mtetra
.423 .081 .279 r
.36864 .39033 .36981 .38745 .37142 .38693 .37024 .38984 Mtetra
.333 0 .24 r
.37024 .38984 .37142 .38693 .37304 .38612 .37188 .38885 Mtetra
.463 .114 .288 r
.37188 .38885 .37304 .38612 .37463 .38577 .37347 .38864 Mtetra
.75 .418 .422 r
.37347 .38864 .37463 .38577 .37615 .38719 .3749 .39207 Mtetra
.946 .676 .495 r
.3749 .39207 .37615 .38719 .37726 .39764 .36736 .58982 Mtetra
.55 .325 .527 r
.36736 .58982 .37726 .39764 .36996 .59386 .36882 .59472 Mtetra
.674 .221 .168 r
.36882 .59472 .36996 .59386 .37154 .59617 .37046 .596 Mtetra
.372 .823 .938 r
.37046 .596 .37154 .59617 .37325 .59592 .37217 .59569 Mtetra
.644 .925 .975 r
.37217 .59569 .37325 .59592 .37498 .59507 .3739 .59494 Mtetra
.622 .935 .963 r
.3739 .59494 .37498 .59507 .37671 .5943 .37563 .59419 Mtetra
.5 .892 .952 r
.37563 .59419 .37671 .5943 .37843 .59392 .37735 .59364 Mtetra
.569 .893 .987 r
.37735 .59364 .37843 .59392 .38014 .59355 .37908 .59309 Mtetra
.574 .858 .996 r
.37908 .59309 .38014 .59355 .38186 .59311 .3808 .59262 Mtetra
.548 .842 .998 r
.3808 .59262 .38186 .59311 .38359 .59261 .38252 .59223 Mtetra
.601 .885 .991 r
.38252 .59223 .38359 .59261 .38531 .59207 .38425 .59166 Mtetra
.774 .906 .932 r
.38425 .59166 .38531 .59207 .38704 .59153 .386 .59055 Mtetra
.841 .785 .798 r
.386 .59055 .38704 .59153 .38877 .59098 .38779 .58856 Mtetra
.782 .641 .706 r
.38779 .58856 .38877 .59098 .3905 .59044 .38959 .58604 Mtetra
.683 .522 .662 r
.38959 .58604 .3905 .59044 .39222 .59012 .39138 .58414 Mtetra
.555 .409 .638 r
.39138 .58414 .39222 .59012 .39394 .58999 .39309 .58409 Mtetra
.582 .429 .639 r
.39309 .58409 .39394 .58999 .39567 .58936 .39482 .58361 Mtetra
.724 .53 .628 r
.39482 .58361 .39567 .58936 .39747 .58707 .39667 .57986 Mtetra
.949 .682 .497 r
.39667 .57986 .39747 .58707 .39953 .57777 .40578 .38074 Mtetra
.553 .332 .534 r
.40578 .38074 .39953 .57777 .40851 .37785 .40761 .37483 Mtetra
.747 .591 .683 r
.40761 .37483 .40851 .37785 .41025 .37416 .40931 .37249 Mtetra
.663 .64 .816 r
.40931 .37249 .41025 .37416 .4119 .37315 .41095 .37185 Mtetra
.583 .66 .891 r
.41095 .37185 .4119 .37315 .41353 .37269 .41257 .37162 Mtetra
.561 .697 .931 r
.41257 .37162 .41353 .37269 .41516 .37237 .41419 .37143 Mtetra
.651 .758 .927 r
.41419 .37143 .41516 .37237 .41679 .37184 .41582 .37092 Mtetra
.663 .767 .927 r
.41582 .37092 .41679 .37184 .41842 .37133 .41746 .37036 Mtetra
.692 .763 .906 r
.41746 .37036 .41842 .37133 .42006 .37081 .4191 .36967 Mtetra
.715 .737 .869 r
.4191 .36967 .42006 .37081 .4217 .37025 .42075 .36884 Mtetra
.679 .681 .846 r
.42075 .36884 .4217 .37025 .42334 .36967 .42239 .36816 Mtetra
.586 .627 .859 r
.42239 .36816 .42334 .36967 .42498 .3691 .42402 .36793 Mtetra
.181 .477 .894 r
.42402 .36793 .42498 .3691 .42662 .36853 .42562 .36859 Mtetra
.653 .11 0 r
.42562 .36859 .42662 .36853 .42826 .36796 .42721 .36977 Mtetra
.612 .22 .276 r
.42721 .36977 .42826 .36796 .42991 .36725 .42881 .37069 Mtetra
.372 .055 .293 r
.42881 .37069 .42991 .36725 .43156 .36629 .43047 .36969 Mtetra
.418 .095 .309 r
.43047 .36969 .43156 .36629 .4332 .36576 .43212 .369 Mtetra
.649 .313 .39 r
.43212 .369 .4332 .36576 .43481 .36649 .43371 .37065 Mtetra
.953 .678 .478 r
.43371 .37065 .43481 .36649 .43627 .37289 .42978 .56891 Mtetra
.552 .326 .527 r
.42978 .56891 .43627 .37289 .43244 .57365 .43135 .57508 Mtetra
.71 .304 .277 r
.43135 .57508 .43244 .57365 .43409 .57706 .43304 .57692 Mtetra
.274 .769 .895 r
.43304 .57692 .43409 .57706 .43583 .57695 .43479 .57669 Mtetra
.621 .918 .978 r
.43479 .57669 .43583 .57695 .4376 .57617 .43656 .57599 Mtetra
.659 .941 .963 r
.43656 .57599 .4376 .57617 .43937 .57524 .43833 .57514 Mtetra
.49 .891 .943 r
.43833 .57514 .43937 .57524 .44113 .57485 .44009 .57458 Mtetra
.562 .896 .983 r
.44009 .57458 .44113 .57485 .44289 .57446 .44185 .57401 Mtetra
.589 .869 .994 r
.44185 .57401 .44289 .57446 .44465 .57403 .44362 .57348 Mtetra
.551 .834 .998 r
.44362 .57348 .44465 .57403 .44641 .57351 .44538 .57309 Mtetra
.589 .876 .993 r
.44538 .57309 .44641 .57351 .44818 .57297 .44715 .57255 Mtetra
.727 .909 .958 r
.44715 .57255 .44818 .57297 .44995 .57241 .44893 .57161 Mtetra
.853 .825 .821 r
.44893 .57161 .44995 .57241 .45172 .57184 .45073 .5697 Mtetra
.796 .665 .719 r
.45073 .5697 .45172 .57184 .45349 .57128 .45254 .56721 Mtetra
.72 .553 .664 r
.45254 .56721 .45349 .57128 .45526 .57082 .45435 .56472 Mtetra
.557 .41 .637 r
.45435 .56472 .45526 .57082 .45702 .57074 .45611 .56463 Mtetra
.573 .421 .637 r
.45611 .56463 .45702 .57074 .45879 .57022 .45788 .56428 Mtetra
.671 .491 .634 r
.45788 .56428 .45879 .57022 .46059 .56854 .45968 .56197 Mtetra
.956 .683 .48 r
.45968 .56197 .46059 .56854 .46249 .56129 .46519 .36242 Mtetra
.556 .334 .534 r
.46519 .36242 .46249 .56129 .46788 .35856 .46698 .35501 Mtetra
.755 .582 .661 r
.46698 .35501 .46788 .35856 .46962 .35388 .46869 .35207 Mtetra
.692 .64 .792 r
.46869 .35207 .46962 .35388 .4713 .35283 .47037 .35117 Mtetra
.631 .63 .831 r
.47037 .35117 .4713 .35283 .47296 .35242 .47203 .35071 Mtetra
.596 .609 .834 r
.47203 .35071 .47296 .35242 .47463 .35228 .4737 .35044 Mtetra
.642 .614 .807 r
.4737 .35044 .47463 .35228 .4763 .35178 .47537 .34989 Mtetra
.637 .607 .803 r
.47537 .34989 .4763 .35178 .47797 .35128 .47704 .34937 Mtetra
.63 .602 .803 r
.47704 .34937 .47797 .35128 .47964 .35073 .47871 .34889 Mtetra
.617 .603 .814 r
.47871 .34889 .47964 .35073 .48132 .35005 .48038 .34849 Mtetra
.618 .639 .849 r
.48038 .34849 .48132 .35005 .48299 .34935 .48206 .34811 Mtetra
.624 .693 .893 r
.48206 .34811 .48299 .34935 .48467 .34868 .48373 .34771 Mtetra
.647 .756 .928 r
.48373 .34771 .48467 .34868 .48635 .34811 .48541 .3472 Mtetra
.657 .771 .933 r
.48541 .3472 .48635 .34811 .48803 .34757 .48709 .34664 Mtetra
.663 .77 .929 r
.48709 .34664 .48803 .34757 .4897 .34703 .48877 .34607 Mtetra
.66 .761 .925 r
.48877 .34607 .4897 .34703 .49138 .34643 .49045 .34551 Mtetra
.667 .772 .929 r
.49045 .34551 .49138 .34643 .49307 .34583 .49213 .34491 Mtetra
.678 .777 .925 r
.49213 .34491 .49307 .34583 .49475 .34527 .49381 .34427 Mtetra
.701 .767 .903 r
.49381 .34427 .49475 .34527 .49643 .34482 .4955 .34353 Mtetra
.694 .71 .861 r
.4955 .34353 .49643 .34482 .49811 .34438 .49718 .34277 Mtetra
.678 .658 .823 r
.49718 .34277 .49811 .34438 .4998 .34392 .49887 .34203 Mtetra
.655 .617 .799 r
.49887 .34203 .4998 .34392 .50148 .34331 .50056 .34138 Mtetra
.65 .611 .797 r
.50056 .34138 .50148 .34331 .50317 .34266 .50225 .34076 Mtetra
.649 .613 .8 r
.50225 .34076 .50317 .34266 .50486 .342 .50394 .34016 Mtetra
.693 .639 .791 r
.50394 .34016 .50486 .342 .50655 .34094 .50563 .33924 Mtetra
.662 .64 .817 r
.50563 .33924 .50655 .34094 .50824 .34027 .50732 .33858 Mtetra
.571 .599 .842 r
.50732 .33858 .50824 .34027 .50993 .34033 .50901 .33842 Mtetra
0 .101 .656 r
.50901 .33842 .50993 .34033 .5116 .34509 .51069 .34048 Mtetra
0 0 .208 r
.51069 .34048 .5116 .34509 .51256 .5479 .51235 .34809 Mtetra
0 0 .342 r
.51235 .34809 .51256 .5479 .51435 .55277 .51337 .54683 Mtetra
.329 .254 .619 r
.51337 .54683 .51435 .55277 .51615 .55296 .51517 .54945 Mtetra
.418 .382 .712 r
.51517 .54945 .51615 .55296 .51797 .55238 .51698 .55047 Mtetra
.473 .536 .841 r
.51698 .55047 .51797 .55238 .51978 .5514 .51879 .55075 Mtetra
.531 .807 .997 r
.51879 .55075 .51978 .5514 .5216 .55087 .52061 .55043 Mtetra
.6 .882 .992 r
.52061 .55043 .5216 .55087 .52341 .55032 .52242 .54985 Mtetra
.659 .891 .981 r
.52242 .54985 .52341 .55032 .52523 .54972 .52424 .54912 Mtetra
.468 .792 .999 r
.52424 .54912 .52523 .54972 .52705 .54948 .52606 .54891 Mtetra
.574 .842 .995 r
.52606 .54891 .52705 .54948 .52887 .54889 .52788 .54845 Mtetra
.731 .915 .956 r
.52788 .54845 .52887 .54889 .53068 .54753 .5297 .54747 Mtetra
.964 .891 .706 r
.5297 .54747 .53068 .54753 .53249 .54142 .53152 .54389 Mtetra
.979 .83 .429 r
.53152 .54389 .53249 .54142 .53374 .33712 .53332 .53419 Mtetra
0 0 .336 r
.53332 .53419 .53374 .33712 .53543 .33142 .53453 .33501 Mtetra
.288 0 .273 r
.53453 .33501 .53543 .33142 .53714 .33007 .53624 .33335 Mtetra
.46 .129 .318 r
.53624 .33335 .53714 .33007 .53885 .32955 .53795 .33299 Mtetra
.483 .155 .334 r
.53795 .33299 .53885 .32955 .54056 .3294 .53967 .33279 Mtetra
.111 0 .193 r
.53967 .33279 .54056 .3294 .54227 .32886 .54137 .3303 Mtetra
0 0 0 r
.54137 .3303 .54227 .32886 .54399 .32827 .54308 .32805 Mtetra
.874 .947 .857 r
.54308 .32805 .54399 .32827 .5457 .32768 .54478 .32632 Mtetra
.691 .702 .855 r
.54478 .32632 .5457 .32768 .54741 .32705 .5465 .32555 Mtetra
.632 .657 .856 r
.5465 .32555 .54741 .32705 .54913 .32642 .54822 .32509 Mtetra
.611 .674 .886 r
.54822 .32509 .54913 .32642 .55085 .32584 .54993 .32473 Mtetra
.735 .759 .873 r
.54993 .32473 .55085 .32584 .55256 .32496 .55165 .32377 Mtetra
.711 .736 .87 r
.55165 .32377 .55256 .32496 .55428 .32436 .55337 .32292 Mtetra
.619 .66 .868 r
.55337 .32292 .55428 .32436 .55601 .32439 .55509 .32252 Mtetra
.049 .263 .758 r
.55509 .32252 .55601 .32439 .55777 .32804 .55683 .32407 Mtetra
0 0 .4 r
.55683 .32407 .55777 .32804 .56174 .53122 .55862 .32949 Mtetra
0 0 .362 r
.55862 .32949 .56174 .53122 .56365 .53727 .56262 .53048 Mtetra
.286 .214 .598 r
.56262 .53048 .56365 .53727 .56551 .53789 .56451 .534 Mtetra
.413 .365 .695 r
.56451 .534 .56551 .53789 .56735 .53738 .56637 .53519 Mtetra
.476 .509 .812 r
.56637 .53519 .56735 .53738 .56919 .53641 .56823 .53554 Mtetra
.583 .776 .971 r
.56823 .53554 .56919 .53641 .57104 .53578 .57008 .53517 Mtetra
.668 .865 .974 r
.57008 .53517 .57104 .53578 .57289 .53522 .57193 .53444 Mtetra
.71 .837 .943 r
.57193 .53444 .57289 .53522 .57474 .53462 .57377 .53359 Mtetra
.539 .722 .958 r
.57377 .53359 .57474 .53462 .57659 .53435 .57563 .5334 Mtetra
.545 .743 .968 r
.57563 .5334 .57659 .53435 .57844 .53384 .57749 .53316 Mtetra
.676 .853 .967 r
.57749 .53316 .57844 .53384 .58029 .53264 .57934 .53243 Mtetra
.941 .915 .763 r
.57934 .53243 .58029 .53264 .58207 .52776 .58116 .52963 Mtetra
.947 .858 .435 r
.58116 .52963 .58207 .52776 .58033 .32322 .58291 .52288 Mtetra
0 0 .356 r
.58291 .52288 .58033 .32322 .58195 .31608 .58115 .32048 Mtetra
0 0 .176 r
.58115 .32048 .58195 .31608 .58366 .31426 .58282 .31601 Mtetra
0 0 0 r
.58282 .31601 .58366 .31426 .5854 .31362 .58453 .31392 Mtetra
.668 .968 .785 r
.58453 .31392 .5854 .31362 .58715 .31339 .58626 .31256 Mtetra
.724 .819 .924 r
.58626 .31256 .58715 .31339 .58889 .31288 .58799 .3117 Mtetra
.662 .725 .896 r
.58799 .3117 .58889 .31288 .59063 .31227 .58973 .31111 Mtetra
.637 .72 .908 r
.58973 .31111 .59063 .31227 .59237 .31168 .59148 .31062 Mtetra
.732 .771 .884 r
.59148 .31062 .59237 .31168 .59411 .31084 .59322 .30968 Mtetra
.723 .749 .873 r
.59322 .30968 .59411 .31084 .59585 .31017 .59495 .30876 Mtetra
.635 .674 .87 r
.59495 .30876 .59585 .31017 .59761 .3101 .5967 .30829 Mtetra
.169 .351 .802 r
.5967 .30829 .59761 .3101 .59944 .31304 .59849 .30953 Mtetra
0 0 .458 r
.59849 .30953 .59944 .31304 .60615 .51608 .60037 .31424 Mtetra
0 0 .378 r
.60037 .31424 .60615 .51608 .60821 .52339 .60711 .51603 Mtetra
.271 .198 .588 r
.60711 .51603 .60821 .52339 .61013 .52447 .6091 .52011 Mtetra
.433 .364 .68 r
.6091 .52011 .61013 .52447 .61201 .52407 .61102 .52131 Mtetra
.494 .473 .763 r
.61102 .52131 .61201 .52407 .61387 .52317 .61292 .52169 Mtetra
.431 .58 .9 r
.61292 .52169 .61387 .52317 .61576 .52272 .61482 .52198 Mtetra
.455 .756 .994 r
.61482 .52198 .61576 .52272 .61764 .52226 .61671 .52186 Mtetra
.692 .923 .969 r
.61671 .52186 .61764 .52226 .6195 .52118 .61858 .52096 Mtetra
.969 .881 .691 r
.61858 .52096 .6195 .52118 .62128 .51719 .62037 .51716 Mtetra
.975 .688 .418 r
.62037 .51716 .62128 .51719 .61721 .31416 .61636 .31437 Mtetra
.992 .767 .494 r
.61636 .31437 .61721 .31416 .61869 .30412 .61779 .30261 Mtetra
.832 .731 .753 r
.61779 .30261 .61869 .30412 .6204 .30188 .6195 .30038 Mtetra
.649 .668 .854 r
.6195 .30038 .6204 .30188 .62216 .30119 .62127 .29981 Mtetra
.533 .634 .897 r
.62127 .29981 .62216 .30119 .62393 .30096 .62305 .29976 Mtetra
.595 .697 .913 r
.62305 .29976 .62393 .30096 .6257 .3005 .62482 .29944 Mtetra
.666 .754 .916 r
.62482 .29944 .6257 .3005 .62746 .29983 .62659 .29883 Mtetra
.678 .771 .921 r
.62659 .29883 .62746 .29983 .62923 .29917 .62835 .29816 Mtetra
.759 .791 .879 r
.62835 .29816 .62923 .29917 .63099 .2983 .6301 .29706 Mtetra
.743 .745 .854 r
.6301 .29706 .63099 .2983 .63275 .29752 .63186 .29598 Mtetra
.634 .657 .855 r
.63186 .29598 .63275 .29752 .63453 .2973 .63363 .29549 Mtetra
0 .153 .693 r
.63363 .29549 .63453 .2973 .6364 .2996 .63549 .29753 Mtetra
.975 .68 .392 r
.63549 .29753 .6364 .2996 .64552 .50138 .64454 .49872 Mtetra
.92 .583 .123 r
.64454 .49872 .64552 .50138 .64779 .51093 .64687 .51025 Mtetra
.501 0 0 r
.64687 .51025 .64779 .51093 .64977 .51269 .64886 .51193 Mtetra
.55 .795 .99 r
.64886 .51193 .64977 .51269 .65169 .51257 .65077 .51159 Mtetra
.777 .817 .884 r
.65077 .51159 .65169 .51257 .65357 .5114 .65264 .51032 Mtetra
.885 .804 .764 r
.65264 .51032 .65357 .5114 .65536 .50784 .65447 .50768 Mtetra
.989 .84 .605 r
.65447 .50768 .65536 .50784 .64953 .3128 .65618 .5021 Mtetra
0 0 .366 r
.65618 .5021 .64953 .3128 .65057 .29361 .64998 .29935 Mtetra
0 0 .231 r
.64998 .29935 .65057 .29361 .65227 .29092 .65154 .29315 Mtetra
0 0 .036 r
.65154 .29315 .65227 .29092 .65405 .29015 .65325 .29078 Mtetra
.499 .843 .571 r
.65325 .29078 .65405 .29015 .65584 .28989 .655 .28927 Mtetra
.745 .88 .942 r
.655 .28927 .65584 .28989 .65764 .28955 .65677 .28829 Mtetra
.668 .717 .886 r
.65677 .28829 .65764 .28955 .65942 .28896 .65855 .28764 Mtetra
.635 .694 .887 r
.65855 .28764 .65942 .28896 .66121 .28837 .66034 .28716 Mtetra
.705 .741 .879 r
.66034 .28716 .66121 .28837 .66299 .28745 .66212 .28632 Mtetra
.734 .766 .878 r
.66212 .28632 .66299 .28745 .66476 .28645 .66389 .28534 Mtetra
.621 .728 .923 r
.66389 .28534 .66476 .28645 .66655 .28599 .66569 .2849 Mtetra
0 .097 .626 r
.66569 .2849 .66655 .28599 .66845 .28763 .66759 .28671 Mtetra
.975 .676 .38 r
.66759 .28671 .66845 .28763 .67931 .48111 .67873 .48711 Mtetra
.839 .515 .44 r
.67873 .48711 .67931 .48111 .68214 .49995 .68125 .49947 Mtetra
.612 .064 0 r
.68125 .49947 .68214 .49995 .6842 .50216 .6833 .50139 Mtetra
.532 .786 .991 r
.6833 .50139 .6842 .50216 .68615 .50209 .68524 .50109 Mtetra
.769 .814 .888 r
.68524 .50109 .68615 .50209 .68805 .50095 .68713 .49986 Mtetra
.883 .808 .771 r
.68713 .49986 .68805 .50095 .68984 .49762 .68896 .49731 Mtetra
.987 .836 .608 r
.68896 .49731 .68984 .49762 .69083 .47838 .69065 .49182 Mtetra
.983 .695 .353 r
.69065 .49182 .69083 .47838 .68282 .28271 .68231 .28842 Mtetra
0 0 .228 r
.68231 .28842 .68282 .28271 .6845 .27968 .68381 .28186 Mtetra
0 0 .033 r
.68381 .28186 .6845 .27968 .68629 .2788 .68553 .27944 Mtetra
.497 .836 .554 r
.68553 .27944 .68629 .2788 .6881 .27844 .68728 .27787 Mtetra
.799 .904 .915 r
.68728 .27787 .6881 .27844 .68991 .27787 .68905 .27661 Mtetra
.731 .744 .862 r
.68905 .27661 .68991 .27787 .6917 .27693 .69084 .2756 Mtetra
.612 .685 .894 r
.69084 .2756 .6917 .27693 .69351 .27647 .69266 .27522 Mtetra
0 .299 .795 r
.69266 .27522 .69351 .27647 .69543 .27776 .69457 .27657 Mtetra
.937 .574 .178 r
.69457 .27657 .69543 .27776 .69785 .28826 .69698 .28678 Mtetra
.976 .674 .365 r
.69698 .28678 .69785 .28826 .71107 .49049 .71017 .48936 Mtetra
.567 .105 0 r
.71017 .48936 .71107 .49049 .7132 .49319 .7123 .49208 Mtetra
.442 .663 .956 r
.7123 .49208 .7132 .49319 .71518 .49329 .71428 .49218 Mtetra
.727 .788 .901 r
.71428 .49218 .71518 .49329 .71711 .49229 .71621 .49119 Mtetra
.902 .809 .746 r
.71621 .49119 .71711 .49229 .71892 .48937 .71802 .48826 Mtetra
.978 .741 .509 r
.71802 .48826 .71892 .48937 .72021 .47769 .71931 .47653 Mtetra
.977 .681 .378 r
.71931 .47653 .72021 .47769 .71001 .27405 .70917 .27289 Mtetra
.919 .787 .699 r
.70917 .27289 .71001 .27405 .71166 .27058 .71082 .26943 Mtetra
.719 .761 .885 r
.71082 .26943 .71166 .27058 .71346 .26967 .71262 .26852 Mtetra
.597 .713 .925 r
.71262 .26852 .71346 .26967 .7153 .26932 .71446 .26817 Mtetra
.633 .729 .917 r
.71446 .26817 .7153 .26932 .71713 .26883 .71629 .26768 Mtetra
.739 .768 .877 r
.71629 .26768 .71713 .26883 .71892 .26781 .71809 .26665 Mtetra
.65 .736 .912 r
.71809 .26665 .71892 .26781 .72075 .26724 .71991 .26609 Mtetra
.106 .429 .871 r
.71991 .26609 .72075 .26724 .72268 .26818 .72184 .26703 Mtetra
.908 .525 .096 r
.72184 .26703 .72268 .26818 .72506 .27611 .72422 .275 Mtetra
.975 .671 .352 r
.72422 .275 .72506 .27611 .74028 .48086 .7394 .47978 Mtetra
.604 .139 0 r
.7394 .47978 .74028 .48086 .74248 .4838 .74159 .48272 Mtetra
.55 .723 .954 r
.74159 .48272 .74248 .4838 .74446 .48357 .74358 .48248 Mtetra
.711 .789 .913 r
.74358 .48248 .74446 .48357 .74641 .48266 .74553 .48158 Mtetra
.693 .784 .92 r
.74553 .48158 .74641 .48266 .74836 .48184 .74748 .48076 Mtetra
.506 .704 .96 r
.74748 .48076 .74836 .48184 .75036 .48173 .74948 .48066 Mtetra
.651 .771 .936 r
.74948 .48066 .75036 .48173 .75233 .48111 .75145 .48004 Mtetra
.869 .823 .8 r
.75145 .48004 .75233 .48111 .75419 .47887 .75331 .47781 Mtetra
.981 .754 .522 r
.75331 .47781 .75419 .47887 .7555 .46892 .75464 .46801 Mtetra
.978 .678 .361 r
.75464 .46801 .7555 .46892 .74298 .26325 .74215 .26213 Mtetra
.937 .793 .675 r
.74215 .26213 .74298 .26325 .74459 .25936 .74376 .25822 Mtetra
.729 .769 .885 r
.74376 .25822 .74459 .25936 .7464 .2584 .74558 .25725 Mtetra
.601 .718 .926 r
.74558 .25725 .7464 .2584 .74826 .25803 .74744 .25688 Mtetra
.6 .717 .926 r
.74744 .25688 .74826 .25803 .75013 .25767 .7493 .25651 Mtetra
.741 .772 .878 r
.7493 .25651 .75013 .25767 .75194 .25662 .75112 .25547 Mtetra
.657 .741 .912 r
.75112 .25547 .75194 .25662 .75379 .25603 .75296 .25487 Mtetra
.228 .508 .907 r
.75296 .25487 .75379 .25603 .75573 .25672 .75491 .25556 Mtetra
.886 .495 .043 r
.75491 .25556 .75573 .25672 .75819 .2641 .75736 .26296 Mtetra
.975 .667 .334 r
.75736 .26296 .75819 .2641 .77578 .47 .77491 .46889 Mtetra
.653 .198 0 r
.77491 .46889 .77578 .47 .77807 .47344 .77721 .47233 Mtetra
.383 .632 .952 r
.77721 .47233 .77807 .47344 .78013 .4737 .77926 .47259 Mtetra
.693 .781 .918 r
.77926 .47259 .78013 .4737 .78211 .47288 .78124 .47177 Mtetra
.873 .82 .793 r
.78124 .47177 .78211 .47288 .78396 .47057 .7831 .46945 Mtetra
.978 .767 .552 r
.7831 .46945 .78396 .47057 .78538 .46274 .78452 .46162 Mtetra
.977 .675 .347 r
.78452 .46162 .78538 .46274 .77079 .25468 .76998 .25351 Mtetra
.95 .785 .641 r
.76998 .25351 .77079 .25468 .77233 .25006 .77152 .24889 Mtetra
.746 .772 .874 r
.77152 .24889 .77233 .25006 .77416 .24898 .77334 .2478 Mtetra
.617 .722 .92 r
.77334 .2478 .77416 .24898 .77603 .24855 .77522 .24737 Mtetra
.585 .706 .927 r
.77522 .24737 .77603 .24855 .77792 .24824 .77711 .24706 Mtetra
.747 .772 .873 r
.77711 .24706 .77792 .24824 .77974 .24715 .77893 .24597 Mtetra
.67 .744 .906 r
.77893 .24597 .77974 .24715 .7816 .24648 .78079 .2453 Mtetra
.352 .58 .928 r
.78079 .2453 .7816 .24648 .78356 .2469 .78275 .24571 Mtetra
.836 .431 0 r
.78275 .24571 .78356 .2469 .786 .25304 .78519 .25184 Mtetra
.973 .663 .318 r
.78519 .25184 .786 .25304 .80565 .46024 .80479 .4591 Mtetra
.689 .245 0 r
.80479 .4591 .80565 .46024 .80804 .4642 .80719 .46306 Mtetra
.35 .608 .946 r
.80719 .46306 .80804 .4642 .81014 .46456 .80929 .46343 Mtetra
.675 .772 .924 r
.80929 .46343 .81014 .46456 .81214 .46382 .81129 .46269 Mtetra
.856 .82 .813 r
.81129 .46269 .81214 .46382 .81402 .46175 .81317 .4606 Mtetra
.977 .775 .566 r
.81317 .4606 .81402 .46175 .81547 .45475 .81462 .45355 Mtetra
.976 .672 .332 r
.81462 .45355 .81547 .45475 .79888 .24582 .79807 .24457 Mtetra
.958 .777 .616 r
.79807 .24457 .79888 .24582 .80035 .24061 .79954 .2394 Mtetra
.747 .768 .87 r
.79954 .2394 .80035 .24061 .80218 .2395 .80138 .23829 Mtetra
.611 .715 .919 r
.80138 .23829 .80218 .2395 .80408 .23908 .80328 .23788 Mtetra
.529 .676 .931 r
.80328 .23788 .80408 .23908 .80601 .23896 .80521 .23777 Mtetra
.658 .739 .91 r
.80521 .23777 .80601 .23896 .80789 .2383 .80709 .23715 Mtetra
.667 .752 .914 r
.80709 .23715 .80789 .2383 .80977 .23763 .80897 .23649 Mtetra
.688 .762 .908 r
.80897 .23649 .80977 .23763 .81165 .23696 .81084 .23573 Mtetra
.779 .778 .852 r
.81084 .23573 .81165 .23696 .81349 .23594 .81266 .2344 Mtetra
.702 .698 .844 r
.81266 .2344 .81349 .23594 .81538 .23531 .81452 .23348 Mtetra
.551 .583 .84 r
.81452 .23348 .81538 .23531 .81735 .23556 .81647 .23341 Mtetra
0 0 .434 r
.81647 .23341 .81735 .23556 .81986 .24139 .81886 .23803 Mtetra
.971 .658 .29 r
.81886 .23803 .81986 .24139 .84191 .44871 .841 .44672 Mtetra
0 0 .364 r
.841 .44672 .84191 .44871 .84442 .45296 .84358 .45182 Mtetra
.292 .572 .935 r
.84358 .45182 .84442 .45296 .84656 .45344 .84573 .45235 Mtetra
.648 .774 .941 r
.84573 .45235 .84656 .45344 .8486 .45282 .84777 .45172 Mtetra
.835 .829 .842 r
.84777 .45172 .8486 .45282 .85052 .45105 .84969 .44992 Mtetra
.976 .788 .587 r
.84969 .44992 .85052 .45105 .85201 .44492 .85118 .44378 Mtetra
.974 .667 .312 r
.85118 .44378 .85201 .44492 .83299 .23536 .8322 .23415 Mtetra
.973 .774 .575 r
.8322 .23415 .83299 .23536 .83433 .22918 .83355 .22796 Mtetra
.763 .756 .846 r
.22234 .43601 .22337 .43698 .22495 .4359 .22391 .43492 Mtetra
.625 .726 .919 r
.22391 .43492 .22495 .4359 .22645 .43554 .22542 .43454 Mtetra
.486 .673 .947 r
.22542 .43454 .22645 .43554 .22793 .43555 .2269 .43454 Mtetra
.721 .744 .87 r
.2269 .43454 .22793 .43555 .22946 .43489 .22845 .43372 Mtetra
.677 .706 .87 r
.22845 .43372 .22946 .43489 .23099 .43431 .22998 .43312 Mtetra
.561 .662 .904 r
.22998 .43312 .23099 .43431 .23251 .43396 .23147 .43298 Mtetra
.728 .232 0 r
.23147 .43298 .23251 .43396 .23398 .43406 .23279 .4348 Mtetra
.883 .562 .436 r
.23279 .4348 .23398 .43406 .23539 .43481 .23372 .44105 Mtetra
.929 .672 .529 r
.23372 .44105 .23539 .43481 .23668 .43699 .21806 .63419 Mtetra
.547 .322 .526 r
.21806 .63419 .23668 .43699 .22116 .63035 .21934 .6375 Mtetra
.594 .313 .46 r
.21934 .6375 .22116 .63035 .22207 .63794 .2208 .63886 Mtetra
.551 .081 .093 r
.2208 .63886 .22207 .63794 .22344 .64031 .22234 .6394 Mtetra
.574 .741 .956 r
.22234 .6394 .22344 .64031 .22502 .64034 .22394 .63913 Mtetra
.667 .71 .88 r
.22394 .63913 .22502 .64034 .22666 .63977 .22558 .63855 Mtetra
.694 .716 .866 r
.22558 .63855 .22666 .63977 .22832 .6389 .22723 .63781 Mtetra
.659 .729 .901 r
.22723 .63781 .22832 .6389 .22995 .63834 .22886 .63727 Mtetra
.651 .73 .907 r
.22886 .63727 .22995 .63834 .23158 .63783 .23049 .63676 Mtetra
.647 .731 .91 r
.23049 .63676 .23158 .63783 .23321 .63732 .23212 .63627 Mtetra
.643 .732 .914 r
.23212 .63627 .23321 .63732 .23484 .63684 .23375 .63579 Mtetra
.641 .732 .915 r
.23375 .63579 .23484 .63684 .23647 .63637 .23538 .63533 Mtetra
.64 .733 .916 r
.23538 .63533 .23647 .63637 .23811 .6359 .23702 .63486 Mtetra
.589 .72 .934 r
.23702 .63486 .23811 .6359 .23971 .63574 .23863 .63457 Mtetra
.625 .706 .904 r
.23863 .63457 .23971 .63574 .24134 .63537 .24026 .63417 Mtetra
.684 .718 .875 r
.24026 .63417 .24134 .63537 .243 .6345 .24191 .63349 Mtetra
.821 .766 .801 r
.24191 .63349 .243 .6345 .24486 .63131 .24366 .6317 Mtetra
.937 .94 .77 r
.24366 .6317 .24486 .63131 .24713 .62296 .24547 .62905 Mtetra
.125 0 .256 r
.24547 .62905 .24713 .62296 .26438 .42769 .24736 .62539 Mtetra
.536 .314 .524 r
.24736 .62539 .26438 .42769 .26607 .42539 .24912 .62342 Mtetra
.539 .316 .525 r
.24912 .62342 .26607 .42539 .26761 .42487 .25075 .623 Mtetra
.541 .317 .525 r
.25075 .623 .26761 .42487 .26911 .42502 .25233 .62324 Mtetra
.54 .316 .525 r
.25233 .62324 .26911 .42502 .27065 .42466 .25396 .62294 Mtetra
.539 .316 .525 r
.25396 .62294 .27065 .42466 .27219 .42418 .2556 .62249 Mtetra
.2556 .62249 .27219 .42418 .27374 .42369 .25724 .62202 Mtetra
.541 .318 .525 r
.25724 .62202 .27374 .42369 .27527 .42352 .25881 .62241 Mtetra
.54 .317 .525 r
.25881 .62241 .27527 .42352 .27681 .42319 .26043 .62228 Mtetra
.537 .314 .524 r
.26043 .62228 .27681 .42319 .27839 .42227 .26215 .62077 Mtetra
0 0 .214 r
.26215 .62077 .27839 .42227 .28009 .41988 .27829 .42915 Mtetra
0 0 .006 r
.27829 .42915 .28009 .41988 .28177 .41763 .28062 .4185 Mtetra
.968 .932 .683 r
.28062 .4185 .28177 .41763 .28342 .41588 .2824 .415 Mtetra
.793 .781 .842 r
.2824 .415 .28342 .41588 .28501 .41497 .28401 .4137 Mtetra
.664 .689 .863 r
.28401 .4137 .28501 .41497 .28656 .41443 .28557 .41314 Mtetra
.603 .664 .882 r
.28557 .41314 .28656 .41443 .28811 .41402 .28711 .41285 Mtetra
.643 .699 .887 r
.28711 .41285 .28811 .41402 .28967 .41353 .28867 .4124 Mtetra
.659 .712 .887 r
.28867 .4124 .28967 .41353 .29123 .413 .29023 .41188 Mtetra
.658 .715 .89 r
.29023 .41188 .29123 .413 .29279 .41245 .29179 .41136 Mtetra
.66 .72 .893 r
.29179 .41136 .29279 .41245 .29435 .41189 .29335 .41084 Mtetra
.661 .728 .899 r
.29335 .41084 .29435 .41189 .29592 .41132 .29491 .41031 Mtetra
.662 .738 .906 r
.29491 .41031 .29592 .41132 .29749 .41075 .29648 .40978 Mtetra
.694 .754 .898 r
.29648 .40978 .29749 .41075 .29907 .40995 .29805 .40911 Mtetra
.687 .779 .921 r
.29805 .40911 .29907 .40995 .30065 .40926 .29962 .40848 Mtetra
.622 .778 .956 r
.29962 .40848 .30065 .40926 .3022 .40896 .30118 .40806 Mtetra
.376 .652 .965 r
.30118 .40806 .3022 .40896 .30364 .41017 .3027 .40822 Mtetra
.27 .389 .801 r
.3027 .40822 .30364 .41017 .30489 .41436 .30417 .40911 Mtetra
.305 .235 .611 r
.30417 .40911 .30489 .41436 .29317 .61086 .30556 .41135 Mtetra
0 0 .249 r
.30556 .41135 .29317 .61086 .29448 .6156 .29433 .60092 Mtetra
0 0 .365 r
.29433 .60092 .29448 .6156 .29602 .61704 .29512 .61348 Mtetra
0 .065 .589 r
.29512 .61348 .29602 .61704 .29762 .61754 .29657 .61624 Mtetra
.352 .562 .915 r
.29657 .61624 .29762 .61754 .29927 .61733 .29818 .61662 Mtetra
.664 .818 .957 r
.29818 .61662 .29927 .61733 .30095 .61672 .29986 .61602 Mtetra
.742 .831 .92 r
.29986 .61602 .30095 .61672 .30264 .61596 .30156 .6151 Mtetra
.544 .746 .97 r
.30156 .6151 .30264 .61596 .30429 .61584 .30322 .61488 Mtetra
.498 .707 .964 r
.30322 .61488 .30429 .61584 .30594 .61578 .30487 .61481 Mtetra
.693 .766 .908 r
.30487 .61481 .30594 .61578 .30763 .61509 .30656 .6141 Mtetra
.892 .758 .706 r
.30656 .6141 .30763 .61509 .3095 .61154 .30844 .61045 Mtetra
.947 .689 .513 r
.30844 .61045 .3095 .61154 .32347 .41357 .32254 .4114 Mtetra
.903 .685 .597 r
.32254 .4114 .32347 .41357 .3257 .40256 .32471 .40138 Mtetra
.833 .739 .761 r
.32471 .40138 .3257 .40256 .32738 .40038 .32639 .39925 Mtetra
.649 .712 .894 r
.32639 .39925 .32738 .40038 .32897 .39986 .32797 .39877 Mtetra
.488 .658 .936 r
.32797 .39877 .32897 .39986 .33052 .39984 .32952 .39879 Mtetra
.564 .698 .931 r
.32952 .39879 .33052 .39984 .33208 .39961 .33109 .3986 Mtetra
.65 .736 .912 r
.33109 .3986 .33208 .39961 .33367 .39908 .33267 .39811 Mtetra
.665 .748 .912 r
.33267 .39811 .33367 .39908 .33526 .3985 .33426 .39756 Mtetra
.716 .765 .891 r
.33426 .39756 .33526 .3985 .33687 .39761 .33586 .39677 Mtetra
.731 .791 .9 r
.33586 .39677 .33687 .39761 .33848 .39668 .33747 .39592 Mtetra
.683 .801 .937 r
.33747 .39592 .33848 .39668 .34006 .39615 .33906 .39529 Mtetra
.473 .708 .972 r
.33906 .39529 .34006 .39615 .34158 .397 .34062 .39526 Mtetra
.287 .43 .831 r
.34062 .39526 .34158 .397 .34293 .40063 .34214 .39602 Mtetra
.306 .253 .632 r
.34214 .39602 .34293 .40063 .3335 .59707 .34359 .39802 Mtetra
.509 .296 .526 r
.34359 .39802 .3335 .59707 .33483 .60299 .34437 .41213 Mtetra
0 0 .254 r
.34437 .41213 .33483 .60299 .33642 .60454 .33552 .6005 Mtetra
.002 .068 .579 r
.33552 .6005 .33642 .60454 .33805 .60509 .33702 .60359 Mtetra
.29 .489 .88 r
.33702 .60359 .33805 .60509 .33973 .60493 .33866 .60421 Mtetra
.659 .816 .959 r
.33866 .60421 .33973 .60493 .34144 .60431 .34036 .60362 Mtetra
.746 .837 .92 r
.34036 .60362 .34144 .60431 .34315 .60351 .34209 .60266 Mtetra
.669 .788 .938 r
.34209 .60266 .34315 .60351 .34484 .60313 .34379 .60204 Mtetra
.573 .71 .935 r
.34379 .60204 .34484 .60313 .34653 .603 .34548 .6018 Mtetra
.635 .709 .9 r
.34548 .6018 .34653 .603 .34823 .60246 .34718 .60134 Mtetra
.775 .757 .837 r
.34718 .60134 .34823 .60246 .35002 .60031 .34893 .60001 Mtetra
.911 .873 .786 r
.34893 .60001 .35002 .60031 .352 .59439 .35073 .59751 Mtetra
0 0 0 r
.35073 .59751 .352 .59439 .36362 .39588 .35259 .59392 Mtetra
.534 .311 .524 r
.35259 .59392 .36362 .39588 .36543 .39128 .35445 .59048 Mtetra
.538 .316 .525 r
.35445 .59048 .36543 .39128 .36705 .39042 .35617 .58957 Mtetra
.541 .317 .525 r
.35617 .58957 .36705 .39042 .36864 .39033 .35784 .5898 Mtetra
.539 .316 .525 r
.35784 .5898 .36864 .39033 .37024 .38984 .35954 .58939 Mtetra
.538 .315 .525 r
.35954 .58939 .37024 .38984 .37188 .38885 .36128 .58829 Mtetra
.54 .317 .525 r
.36128 .58829 .37188 .38885 .37347 .38864 .36296 .58824 Mtetra
.544 .32 .526 r
.36296 .58824 .37347 .38864 .3749 .39207 .36455 .59045 Mtetra
.545 .321 .526 r
.36455 .59045 .3749 .39207 .36736 .58982 .36612 .59298 Mtetra
.638 .298 .379 r
.36612 .59298 .36736 .58982 .36882 .59472 .36774 .59446 Mtetra
.175 0 0 r
.36774 .59446 .36882 .59472 .37046 .596 .36942 .59488 Mtetra
.62 .72 .918 r
.36942 .59488 .37046 .596 .37217 .59569 .37113 .59447 Mtetra
.672 .721 .886 r
.37113 .59447 .37217 .59569 .3739 .59494 .37286 .59383 Mtetra
.67 .74 .902 r
.37286 .59383 .3739 .59494 .37563 .59419 .37458 .59321 Mtetra
.638 .757 .934 r
.37458 .59321 .37563 .59419 .37735 .59364 .3763 .59271 Mtetra
.637 .769 .943 r
.3763 .59271 .37735 .59364 .37908 .59309 .37803 .59222 Mtetra
.59 .767 .963 r
.37803 .59222 .37908 .59309 .3808 .59262 .37974 .59187 Mtetra
.543 .777 .985 r
.37974 .59187 .3808 .59262 .38252 .59223 .38146 .5916 Mtetra
.657 .842 .971 r
.38146 .5916 .38252 .59223 .38425 .59166 .38319 .59098 Mtetra
.846 .839 .838 r
.38319 .59098 .38425 .59166 .386 .59055 .38497 .58922 Mtetra
.894 .735 .677 r
.38497 .58922 .386 .59055 .38779 .58856 .38685 .58484 Mtetra
.952 .686 .497 r
.38685 .58484 .38779 .58856 .38959 .58604 .39615 .39525 Mtetra
.57 .346 .536 r
.39615 .39525 .38959 .58604 .39138 .58414 .39832 .381 Mtetra
.542 .323 .532 r
.39832 .381 .39138 .58414 .39309 .58409 .39996 .38029 Mtetra
.541 .322 .531 r
.39996 .38029 .39309 .58409 .39482 .58361 .40157 .38025 Mtetra
.544 .325 .532 r
.40157 .38025 .39482 .58361 .39667 .57986 .40325 .37856 Mtetra
.548 .327 .532 r
.40325 .37856 .39667 .57986 .40578 .38074 .40498 .37532 Mtetra
.68 .5 .635 r
.40498 .37532 .40578 .38074 .40761 .37483 .40668 .37299 Mtetra
.743 .655 .763 r
.40668 .37299 .40761 .37483 .40931 .37249 .40834 .37158 Mtetra
.657 .765 .929 r
.40834 .37158 .40931 .37249 .41095 .37185 .40997 .37104 Mtetra
.577 .766 .968 r
.40997 .37104 .41095 .37185 .41257 .37162 .41159 .37074 Mtetra
.588 .751 .955 r
.41159 .37074 .41257 .37162 .41419 .37143 .41322 .37043 Mtetra
.658 .746 .915 r
.41322 .37043 .41419 .37143 .41582 .37092 .41486 .36989 Mtetra
.671 .745 .906 r
.41486 .36989 .41582 .37092 .41746 .37036 .41649 .3693 Mtetra
.707 .748 .884 r
.41649 .3693 .41746 .37036 .4191 .36967 .41814 .36852 Mtetra
.738 .74 .853 r
.41814 .36852 .4191 .36967 .42075 .36884 .41979 .36753 Mtetra
.681 .697 .859 r
.41979 .36753 .42075 .36884 .42239 .36816 .42143 .36685 Mtetra
.431 .589 .908 r
.42143 .36685 .42239 .36816 .42402 .36793 .42305 .36708 Mtetra
.809 .336 0 r
.42305 .36708 .42402 .36793 .42562 .36859 .42459 .36969 Mtetra
.925 .615 .438 r
.42459 .36969 .42562 .36859 .42721 .36977 .42578 .38382 Mtetra
.937 .662 .491 r
.42578 .38382 .42721 .36977 .42881 .37069 .4217 .57206 Mtetra
.54 .317 .525 r
.4217 .57206 .42881 .37069 .43047 .36969 .42344 .57182 Mtetra
.538 .315 .525 r
.42344 .57182 .43047 .36969 .43212 .369 .4252 .57075 Mtetra
.541 .317 .525 r
.4252 .57075 .43212 .369 .43371 .37065 .42693 .57105 Mtetra
.545 .321 .526 r
.42693 .57105 .43371 .37065 .42978 .56891 .4286 .57361 Mtetra
.619 .306 .418 r
.4286 .57361 .42978 .56891 .43135 .57508 .43029 .57518 Mtetra
.452 0 0 r
.43029 .57518 .43135 .57508 .43304 .57692 .43202 .57581 Mtetra
.606 .724 .928 r
.43202 .57581 .43304 .57692 .43479 .57669 .43378 .57544 Mtetra
.667 .718 .887 r
.43378 .57544 .43479 .57669 .43656 .57599 .43554 .57481 Mtetra
.68 .736 .893 r
.43554 .57481 .43656 .57599 .43833 .57514 .43731 .57412 Mtetra
.641 .754 .93 r
.43731 .57412 .43833 .57514 .44009 .57458 .43907 .57361 Mtetra
.64 .765 .938 r
.43907 .57361 .44009 .57458 .44185 .57401 .44083 .57309 Mtetra
.617 .77 .953 r
.44083 .57309 .44185 .57401 .44362 .57348 .44259 .57265 Mtetra
.537 .76 .979 r
.44259 .57265 .44362 .57348 .44538 .57309 .44435 .57241 Mtetra
.632 .83 .977 r
.44435 .57241 .44538 .57309 .44715 .57255 .44612 .57187 Mtetra
.806 .853 .885 r
.44612 .57187 .44715 .57255 .44893 .57161 .44791 .5705 Mtetra
.905 .763 .694 r
.44791 .5705 .44893 .57161 .45073 .5697 .44976 .56658 Mtetra
.904 .673 .577 r
.44976 .56658 .45073 .5697 .45254 .56721 .45177 .55471 Mtetra
.947 .675 .489 r
.45177 .55471 .45254 .56721 .45435 .56472 .45762 .36068 Mtetra
.543 .324 .532 r
.45762 .36068 .45435 .56472 .45611 .56463 .4593 .35969 Mtetra
.541 .322 .531 r
.4593 .35969 .45611 .56463 .45788 .56428 .46096 .35955 Mtetra
.543 .323 .532 r
.46096 .35955 .45788 .56428 .45968 .56197 .46263 .35864 Mtetra
.548 .327 .532 r
.46263 .35864 .45968 .56197 .46519 .36242 .46435 .35529 Mtetra
.659 .467 .615 r
.46435 .35529 .46519 .36242 .46698 .35501 .46606 .35281 Mtetra
.748 .633 .733 r
.46606 .35281 .46698 .35501 .46869 .35207 .46775 .3511 Mtetra
.702 .771 .906 r
.46775 .3511 .46869 .35207 .47037 .35117 .46942 .35036 Mtetra
.638 .79 .955 r
.46942 .35036 .47037 .35117 .47203 .35071 .47109 .34986 Mtetra
.609 .771 .957 r
.47109 .34986 .47203 .35071 .4737 .35044 .47275 .34947 Mtetra
.659 .758 .923 r
.47275 .34947 .4737 .35044 .47537 .34989 .47442 .34891 Mtetra
.654 .755 .924 r
.47442 .34891 .47537 .34989 .47704 .34937 .4761 .34838 Mtetra
.644 .749 .926 r
.4761 .34838 .47704 .34937 .47871 .34889 .47777 .34788 Mtetra
.618 .738 .932 r
.47777 .34788 .47871 .34889 .48038 .34849 .47944 .34748 Mtetra
.614 .735 .932 r
.47944 .34748 .48038 .34849 .48206 .34811 .48112 .3471 Mtetra
.621 .737 .93 r
.48112 .3471 .48206 .34811 .48373 .34771 .48279 .34669 Mtetra
.649 .746 .92 r
.48279 .34669 .48373 .34771 .48541 .3472 .48447 .34617 Mtetra
.659 .748 .916 r
.48447 .34617 .48541 .3472 .48709 .34664 .48615 .34561 Mtetra
.664 .748 .913 r
.48615 .34561 .48709 .34664 .48877 .34607 .48783 .34503 Mtetra
.659 .746 .914 r
.48783 .34503 .48877 .34607 .49045 .34551 .48951 .34448 Mtetra
.666 .749 .913 r
.48951 .34448 .49045 .34551 .49213 .34491 .49119 .34389 Mtetra
.676 .754 .91 r
.49119 .34389 .49213 .34491 .49381 .34427 .49288 .34326 Mtetra
.699 .762 .9 r
.49288 .34326 .49381 .34427 .4955 .34353 .49456 .34251 Mtetra
.702 .764 .9 r
.49456 .34251 .4955 .34353 .49718 .34277 .49625 .34176 Mtetra
.698 .763 .903 r
.49625 .34176 .49718 .34277 .49887 .34203 .49794 .34103 Mtetra
.676 .759 .913 r
.49794 .34103 .49887 .34203 .50056 .34138 .49963 .34039 Mtetra
.669 .76 .918 r
.49963 .34039 .50056 .34138 .50225 .34076 .50132 .33979 Mtetra
.668 .763 .921 r
.50132 .33979 .50225 .34076 .50394 .34016 .503 .33919 Mtetra
.711 .777 .904 r
.503 .33919 .50394 .34016 .50563 .33924 .5047 .3384 Mtetra
.679 .798 .938 r
.5047 .3384 .50563 .33924 .50732 .33858 .50639 .33775 Mtetra
.595 .773 .965 r
.50639 .33775 .50732 .33858 .50901 .33842 .50808 .33738 Mtetra
.299 .578 .938 r
.50808 .33738 .50901 .33842 .51069 .34048 .50977 .33778 Mtetra
.313 .349 .739 r
.50977 .33778 .51069 .34048 .51235 .34809 .51146 .33902 Mtetra
.368 .244 .577 r
.51146 .33902 .51235 .34809 .51337 .54683 .51314 .34241 Mtetra
0 0 .348 r
.51314 .34241 .51337 .54683 .51517 .54945 .5142 .54203 Mtetra
.079 .057 .528 r
.5142 .54203 .51517 .54945 .51698 .55047 .516 .54778 Mtetra
.093 .219 .704 r
.516 .54778 .51698 .55047 .51879 .55075 .5178 .54981 Mtetra
.486 .716 .972 r
.5178 .54981 .51879 .55075 .52061 .55043 .51962 .54973 Mtetra
.649 .835 .972 r
.51962 .54973 .52061 .55043 .52242 .54985 .52144 .54912 Mtetra
.721 .846 .941 r
.52144 .54912 .52242 .54985 .52424 .54912 .52326 .54823 Mtetra
.6 .774 .963 r
.52326 .54823 .52424 .54912 .52606 .54891 .52508 .54782 Mtetra
.643 .746 .924 r
.52508 .54782 .52606 .54891 .52788 .54845 .5269 .54728 Mtetra
.702 .75 .889 r
.5269 .54728 .52788 .54845 .5297 .54747 .52872 .54646 Mtetra
.846 .801 .806 r
.52872 .54646 .5297 .54747 .53152 .54389 .53054 .54446 Mtetra
.909 .976 .693 r
.53054 .54446 .53152 .54389 .53332 .53419 .53236 .54163 Mtetra
.267 .034 .363 r
.53236 .54163 .53332 .53419 .53453 .33501 .53417 .53778 Mtetra
.539 .316 .525 r
.53417 .53778 .53453 .33501 .53624 .33335 .536 .53716 Mtetra
.54 .317 .525 r
.536 .53716 .53624 .33335 .53795 .33299 .53782 .53705 Mtetra
.538 .315 .525 r
.53782 .53705 .53795 .33299 .53967 .33279 .53965 .53586 Mtetra
0 0 .352 r
.53965 .53586 .53967 .33279 .54137 .3303 .54049 .33735 Mtetra
0 0 .141 r
.54049 .33735 .54137 .3303 .54308 .32805 .54217 .32862 Mtetra
.956 .946 .652 r
.54217 .32862 .54308 .32805 .54478 .32632 .54387 .32526 Mtetra
.748 .771 .871 r
.54387 .32526 .54478 .32632 .5465 .32555 .54558 .32422 Mtetra
.626 .681 .882 r
.54558 .32422 .5465 .32555 .54822 .32509 .5473 .32379 Mtetra
.565 .661 .902 r
.5473 .32379 .54822 .32509 .54993 .32473 .54902 .32361 Mtetra
.705 .748 .886 r
.54902 .32361 .54993 .32473 .55165 .32377 .55074 .32282 Mtetra
.711 .785 .91 r
.55074 .32282 .55165 .32377 .55337 .32292 .55246 .32202 Mtetra
.652 .779 .941 r
.55246 .32202 .55337 .32292 .55509 .32252 .55418 .32146 Mtetra
.401 .632 .948 r
.55418 .32146 .55509 .32252 .55683 .32407 .55591 .32166 Mtetra
.341 .392 .77 r
.55591 .32166 .55683 .32407 .55862 .32949 .55765 .32268 Mtetra
.362 .261 .604 r
.55765 .32268 .55862 .32949 .56262 .53048 .55941 .32538 Mtetra
0 0 .371 r
.55941 .32538 .56262 .53048 .56451 .534 .56343 .52402 Mtetra
.082 .04 .505 r
.56343 .52402 .56451 .534 .56637 .53519 .56538 .53197 Mtetra
.128 .207 .678 r
.56538 .53197 .56637 .53519 .56823 .53554 .56726 .53434 Mtetra
.481 .658 .939 r
.56726 .53434 .56823 .53554 .57008 .53517 .56912 .53438 Mtetra
.685 .829 .952 r
.56912 .53438 .57008 .53517 .57193 .53444 .57097 .53363 Mtetra
.749 .837 .919 r
.57097 .53363 .57193 .53444 .57377 .53359 .57281 .53259 Mtetra
.599 .752 .951 r
.57281 .53259 .57377 .53359 .57563 .5334 .57466 .5322 Mtetra
.586 .706 .926 r
.57466 .5322 .57563 .5334 .57749 .53316 .57652 .53189 Mtetra
.65 .719 .899 r
.57652 .53189 .57749 .53316 .57934 .53243 .57838 .53132 Mtetra
.786 .786 .853 r
.57838 .53132 .57934 .53243 .58116 .52963 .58022 .52992 Mtetra
.88 .992 .762 r
.58022 .52992 .58116 .52963 .58291 .52288 .58205 .52763 Mtetra
.059 0 .232 r
.58205 .52763 .58291 .52288 .58115 .32048 .58385 .52368 Mtetra
0 0 .371 r
.58385 .52368 .58115 .32048 .58282 .31601 .58213 .32664 Mtetra
0 0 .266 r
.58213 .32664 .58282 .31601 .58453 .31392 .58368 .31527 Mtetra
.782 .873 .442 r
.58368 .31527 .58453 .31392 .58626 .31256 .58536 .31181 Mtetra
.81 .848 .878 r
.58536 .31181 .58626 .31256 .58799 .3117 .58709 .31045 Mtetra
.662 .714 .886 r
.58709 .31045 .58799 .3117 .58973 .31111 .58883 .30985 Mtetra
.604 .688 .902 r
.58883 .30985 .58973 .31111 .59148 .31062 .59058 .30951 Mtetra
.701 .753 .892 r
.59058 .30951 .59148 .31062 .59322 .30968 .59233 .30873 Mtetra
.72 .793 .909 r
.59233 .30873 .59322 .30968 .59495 .30876 .59407 .30787 Mtetra
.664 .789 .941 r
.59407 .30787 .59495 .30876 .5967 .30829 .59581 .30727 Mtetra
.442 .663 .955 r
.59581 .30727 .5967 .30829 .59849 .30953 .59758 .30735 Mtetra
.343 .417 .794 r
.59758 .30735 .59849 .30953 .60037 .31424 .59936 .30826 Mtetra
.363 .275 .621 r
.59936 .30826 .60037 .31424 .60711 .51603 .60119 .31067 Mtetra
0 0 .392 r
.60119 .31067 .60711 .51603 .6091 .52011 .60782 .50581 Mtetra
.092 .03 .487 r
.60782 .50581 .6091 .52011 .61102 .52131 .61 .51736 Mtetra
.171 .203 .653 r
.61 .51736 .61102 .52131 .61292 .52169 .61196 .52012 Mtetra
.222 .442 .863 r
.61196 .52012 .61292 .52169 .61482 .52198 .61388 .52105 Mtetra
.491 .724 .975 r
.61388 .52105 .61482 .52198 .61671 .52186 .61577 .52094 Mtetra
.743 .819 .911 r
.61577 .52094 .61671 .52186 .61858 .52096 .61764 .51991 Mtetra
.926 .791 .691 r
.61764 .51991 .61858 .52096 .62037 .51716 .61943 .51596 Mtetra
.974 .687 .42 r
.61943 .51596 .62037 .51716 .61636 .31437 .61543 .31205 Mtetra
.936 .698 .553 r
.61543 .31205 .61636 .31437 .61779 .30261 .6169 .30132 Mtetra
.844 .759 .768 r
.6169 .30132 .61779 .30261 .6195 .30038 .61862 .29914 Mtetra
.646 .711 .895 r
.61862 .29914 .6195 .30038 .62127 .29981 .62038 .29862 Mtetra
.505 .656 .927 r
.62038 .29862 .62127 .29981 .62305 .29976 .62216 .2986 Mtetra
.583 .7 .923 r
.62216 .2986 .62305 .29976 .62482 .29944 .62394 .29832 Mtetra
.659 .74 .91 r
.62394 .29832 .62482 .29944 .62659 .29883 .62571 .29774 Mtetra
.672 .751 .91 r
.62571 .29774 .62659 .29883 .62835 .29816 .62747 .2971 Mtetra
.755 .781 .874 r
.62747 .2971 .62835 .29816 .6301 .29706 .62923 .296 Mtetra
.753 .782 .876 r
.62923 .296 .6301 .29706 .63186 .29598 .63098 .29492 Mtetra
.633 .743 .928 r
.63098 .29492 .63186 .29598 .63363 .29549 .63275 .29444 Mtetra
0 0 .495 r
.63275 .29444 .63363 .29549 .63549 .29753 .63462 .29655 Mtetra
.974 .679 .395 r
.63462 .29655 .63549 .29753 .64454 .49872 .64365 .49886 Mtetra
.938 .579 .3 r
.64365 .49886 .64454 .49872 .64687 .51025 .64595 .50936 Mtetra
0 .156 .641 r
.64595 .50936 .64687 .51025 .64886 .51193 .64793 .51088 Mtetra
.619 .756 .944 r
.64793 .51088 .64886 .51193 .65077 .51159 .64983 .51041 Mtetra
.761 .777 .866 r
.64983 .51041 .65077 .51159 .65264 .51032 .65171 .50918 Mtetra
.806 .793 .84 r
.65171 .50918 .65264 .51032 .65447 .50768 .65358 .50759 Mtetra
.882 .98 .83 r
.65358 .50759 .65447 .50768 .65618 .5021 .65543 .50556 Mtetra
.017 0 .164 r
.65543 .50556 .65618 .5021 .64998 .29935 .65723 .50232 Mtetra
.522 .303 .523 r
.65723 .50232 .64998 .29935 .65154 .29315 .65873 .4917 Mtetra
0 0 .388 r
.65873 .4917 .65154 .29315 .65325 .29078 .65252 .29302 Mtetra
0 0 0 r
.65252 .29302 .65325 .29078 .655 .28927 .65416 .28882 Mtetra
.878 .92 .851 r
.65416 .28882 .655 .28927 .65677 .28829 .65589 .28701 Mtetra
.681 .721 .879 r
.65589 .28701 .65677 .28829 .65855 .28764 .65767 .2863 Mtetra
.61 .679 .89 r
.65767 .2863 .65855 .28764 .66034 .28716 .65947 .28592 Mtetra
.687 .731 .883 r
.65947 .28592 .66034 .28716 .66212 .28632 .66126 .28518 Mtetra
.731 .763 .878 r
.66126 .28518 .66212 .28632 .66389 .28534 .66303 .28421 Mtetra
.616 .724 .923 r
.66303 .28421 .66389 .28534 .66569 .2849 .66483 .2838 Mtetra
0 .081 .613 r
.66483 .2838 .66569 .2849 .66759 .28671 .66673 .28566 Mtetra
.975 .676 .38 r
.66673 .28566 .66759 .28671 .67873 .48711 .67787 .48713 Mtetra
.942 .583 .285 r
.67787 .48713 .67873 .48711 .68125 .49947 .68035 .49854 Mtetra
0 .089 .589 r
.68035 .49854 .68125 .49947 .6833 .50139 .68238 .50033 Mtetra
.606 .751 .947 r
.68238 .50033 .6833 .50139 .68524 .50109 .68432 .4999 Mtetra
.756 .776 .87 r
.68432 .4999 .68524 .50109 .68713 .49986 .68622 .49869 Mtetra
.81 .793 .836 r
.68622 .49869 .68713 .49986 .68896 .49731 .68809 .49705 Mtetra
.892 .958 .834 r
.68809 .49705 .68896 .49731 .69065 .49182 .68995 .49497 Mtetra
0 0 .125 r
.68995 .49497 .69065 .49182 .68231 .28842 .69174 .49163 Mtetra
.521 .302 .523 r
.69174 .49163 .68231 .28842 .68381 .28186 .69313 .48039 Mtetra
0 0 .4 r
.69313 .48039 .68381 .28186 .68553 .27944 .68485 .28169 Mtetra
0 0 0 r
.68485 .28169 .68553 .27944 .68728 .27787 .68647 .2775 Mtetra
.912 .929 .811 r
.68647 .2775 .68728 .27787 .68905 .27661 .68819 .27534 Mtetra
.742 .745 .855 r
.68819 .27534 .68905 .27661 .69084 .2756 .68997 .27425 Mtetra
.595 .673 .895 r
.68997 .27425 .69084 .2756 .69266 .27522 .6918 .27394 Mtetra
0 .278 .781 r
.6918 .27394 .69266 .27522 .69457 .27657 .69372 .27537 Mtetra
.934 .569 .168 r
.69372 .27537 .69457 .27657 .69698 .28678 .69611 .28521 Mtetra
.976 .674 .365 r
.69611 .28521 .69698 .28678 .71017 .48936 .70926 .48821 Mtetra
.568 .109 0 r
.70926 .48821 .71017 .48936 .7123 .49208 .7114 .49097 Mtetra
.441 .661 .954 r
.7114 .49097 .7123 .49208 .71428 .49218 .71338 .49108 Mtetra
.726 .786 .9 r
.71338 .49108 .71428 .49218 .71621 .49119 .71531 .49009 Mtetra
.902 .808 .746 r
.71531 .49009 .71621 .49119 .71802 .48826 .71712 .48715 Mtetra
.978 .74 .508 r
.71712 .48715 .71802 .48826 .71931 .47653 .71841 .47534 Mtetra
.977 .681 .379 r
.71841 .47534 .71931 .47653 .70917 .27289 .70832 .27173 Mtetra
.919 .787 .7 r
.70832 .27173 .70917 .27289 .71082 .26943 .70997 .26827 Mtetra
.719 .761 .885 r
.70997 .26827 .71082 .26943 .71262 .26852 .71178 .26736 Mtetra
.597 .713 .925 r
.71178 .26736 .71262 .26852 .71446 .26817 .71361 .26702 Mtetra
.632 .728 .917 r
.71361 .26702 .71446 .26817 .71629 .26768 .71545 .26653 Mtetra
.739 .768 .877 r
.71545 .26653 .71629 .26768 .71809 .26665 .71724 .2655 Mtetra
.65 .736 .913 r
.71724 .2655 .71809 .26665 .71991 .26609 .71907 .26494 Mtetra
.103 .427 .871 r
.71907 .26494 .71991 .26609 .72184 .26703 .721 .26589 Mtetra
.909 .527 .098 r
.721 .26589 .72184 .26703 .72422 .275 .72338 .27391 Mtetra
.975 .671 .352 r
.72338 .27391 .72422 .275 .7394 .47978 .73851 .47871 Mtetra
.604 .139 0 r
.73851 .47871 .7394 .47978 .74159 .48272 .7407 .48163 Mtetra
.548 .723 .955 r
.7407 .48163 .74159 .48272 .74358 .48248 .7427 .4814 Mtetra
.71 .789 .914 r
.7427 .4814 .74358 .48248 .74553 .48158 .74464 .4805 Mtetra
.692 .785 .922 r
.74464 .4805 .74553 .48158 .74748 .48076 .7466 .47969 Mtetra
.504 .705 .961 r
.7466 .47969 .74748 .48076 .74948 .48066 .7486 .47959 Mtetra
.65 .771 .937 r
.7486 .47959 .74948 .48066 .75145 .48004 .75057 .47897 Mtetra
.868 .823 .801 r
.75057 .47897 .75145 .48004 .75331 .47781 .75243 .47675 Mtetra
.98 .755 .525 r
.75243 .47675 .75331 .47781 .75464 .46801 .75378 .46712 Mtetra
.978 .678 .361 r
.75378 .46712 .75464 .46801 .74215 .26213 .74132 .26102 Mtetra
.938 .793 .674 r
.74132 .26102 .74215 .26213 .74376 .25822 .74293 .25708 Mtetra
.73 .77 .885 r
.74293 .25708 .74376 .25822 .74558 .25725 .74475 .2561 Mtetra
.601 .719 .927 r
.74475 .2561 .74558 .25725 .74744 .25688 .74661 .25573 Mtetra
.6 .718 .927 r
.74661 .25573 .74744 .25688 .7493 .25651 .74848 .25536 Mtetra
.742 .773 .878 r
.74848 .25536 .7493 .25651 .75112 .25547 .75029 .25431 Mtetra
.657 .741 .912 r
.75029 .25431 .75112 .25547 .75296 .25487 .75214 .25371 Mtetra
.227 .508 .907 r
.75214 .25371 .75296 .25487 .75491 .25556 .75409 .2544 Mtetra
.887 .496 .044 r
.75409 .2544 .75491 .25556 .75736 .26296 .75654 .26183 Mtetra
.975 .667 .334 r
.75654 .26183 .75736 .26296 .77491 .46889 .77404 .46779 Mtetra
.652 .197 0 r
.77404 .46779 .77491 .46889 .77721 .47233 .77634 .47122 Mtetra
.383 .632 .952 r
.77634 .47122 .77721 .47233 .77926 .47259 .77839 .47148 Mtetra
.693 .781 .918 r
.77839 .47148 .77926 .47259 .78124 .47177 .78037 .47065 Mtetra
.873 .82 .793 r
.78037 .47065 .78124 .47177 .7831 .46945 .78223 .46834 Mtetra
.978 .767 .552 r
.78223 .46834 .7831 .46945 .78452 .46162 .78366 .4605 Mtetra
.977 .675 .347 r
.78366 .4605 .78452 .46162 .76998 .25351 .76916 .25233 Mtetra
.95 .785 .641 r
.76916 .25233 .76998 .25351 .77152 .24889 .7707 .24771 Mtetra
.746 .772 .874 r
.7707 .24771 .77152 .24889 .77334 .2478 .77252 .24663 Mtetra
.618 .722 .92 r
.77252 .24663 .77334 .2478 .77522 .24737 .7744 .24619 Mtetra
.585 .706 .927 r
.7744 .24619 .77522 .24737 .77711 .24706 .77629 .24588 Mtetra
.747 .772 .873 r
.77629 .24588 .77711 .24706 .77893 .24597 .77812 .24478 Mtetra
.67 .743 .905 r
.77812 .24478 .77893 .24597 .78079 .2453 .77998 .24411 Mtetra
.353 .581 .928 r
.77998 .24411 .78079 .2453 .78275 .24571 .78193 .24452 Mtetra
.835 .43 0 r
.78193 .24452 .78275 .24571 .78519 .25184 .78437 .25063 Mtetra
.973 .663 .318 r
.78437 .25063 .78519 .25184 .80479 .4591 .80393 .45796 Mtetra
.688 .245 0 r
.80393 .45796 .80479 .4591 .80719 .46306 .80633 .46193 Mtetra
.351 .608 .946 r
.80633 .46193 .80719 .46306 .80929 .46343 .80843 .46229 Mtetra
.675 .772 .923 r
.80843 .46229 .80929 .46343 .81129 .46269 .81043 .46154 Mtetra
.856 .819 .812 r
.81043 .46154 .81129 .46269 .81317 .4606 .81232 .45945 Mtetra
.977 .774 .565 r
.81232 .45945 .81317 .4606 .81462 .45355 .81376 .45234 Mtetra
.976 .672 .332 r
.81376 .45234 .81462 .45355 .79807 .24457 .79726 .24332 Mtetra
.957 .777 .618 r
.79726 .24332 .79807 .24457 .79954 .2394 .79874 .23818 Mtetra
.746 .767 .87 r
.79874 .23818 .79954 .2394 .80138 .23829 .80057 .23708 Mtetra
.61 .713 .918 r
.80057 .23708 .80138 .23829 .80328 .23788 .80247 .23667 Mtetra
.528 .674 .93 r
.80247 .23667 .80328 .23788 .80521 .23777 .8044 .23657 Mtetra
.655 .736 .909 r
.8044 .23657 .80521 .23777 .80709 .23715 .80629 .23596 Mtetra
.664 .742 .908 r
.80629 .23596 .80709 .23715 .80897 .23649 .80817 .23531 Mtetra
.685 .752 .902 r
.80817 .23531 .80897 .23649 .81084 .23573 .81005 .23456 Mtetra
.782 .787 .857 r
.81005 .23456 .81084 .23573 .81266 .2344 .81187 .23321 Mtetra
.718 .765 .89 r
.81187 .23321 .81266 .2344 .81452 .23348 .81373 .23229 Mtetra
.517 .674 .935 r
.81373 .23229 .81452 .23348 .81647 .23341 .81567 .23222 Mtetra
.731 .31 0 r
.81567 .23222 .81647 .23341 .81886 .23803 .81807 .23687 Mtetra
.971 .657 .298 r
.81807 .23687 .81886 .23803 .841 .44672 .84016 .44562 Mtetra
.766 .335 0 r
.84016 .44562 .841 .44672 .84358 .45182 .84275 .4507 Mtetra
.289 .574 .937 r
.84275 .4507 .84358 .45182 .84573 .45235 .8449 .45123 Mtetra
.65 .767 .935 r
.8449 .45123 .84573 .45235 .84777 .45172 .84693 .45059 Mtetra
.833 .823 .839 r
.84693 .45059 .84777 .45172 .84969 .44992 .84886 .44878 Mtetra
.976 .788 .586 r
.84886 .44878 .84969 .44992 .85118 .44378 .85035 .44263 Mtetra
.974 .667 .312 r
.85035 .44263 .85118 .44378 .8322 .23415 .83141 .23293 Mtetra
.973 .774 .576 r
.83141 .23293 .8322 .23415 .83355 .22796 .83276 .22675 Mtetra
.764 .756 .846 r
.2213 .43503 .22234 .43601 .22391 .43492 .22288 .43393 Mtetra
.628 .727 .919 r
.22288 .43393 .22391 .43492 .22542 .43454 .22439 .43354 Mtetra
.49 .676 .947 r
.22439 .43354 .22542 .43454 .2269 .43454 .22587 .43353 Mtetra
.742 .749 .858 r
.22587 .43353 .2269 .43454 .22845 .43372 .22743 .43258 Mtetra
.682 .712 .872 r
.22743 .43258 .22845 .43372 .22998 .43312 .22897 .43196 Mtetra
.488 .638 .921 r
.22897 .43196 .22998 .43312 .23147 .43298 .23044 .432 Mtetra
.93 .556 .268 r
.23044 .432 .23147 .43298 .23279 .4348 .23154 .43622 Mtetra
.935 .679 .526 r
.23154 .43622 .23279 .4348 .23372 .44105 .21533 .63386 Mtetra
.55 .325 .527 r
.21533 .63386 .23372 .44105 .21806 .63419 .21644 .63908 Mtetra
.547 .245 .407 r
.21644 .63908 .21806 .63419 .21934 .6375 .21798 .63946 Mtetra
.346 0 .133 r
.21798 .63946 .21934 .6375 .2208 .63886 .21961 .63897 Mtetra
.65 .961 .925 r
.21961 .63897 .2208 .63886 .22234 .6394 .22127 .63807 Mtetra
.666 .69 .864 r
.22127 .63807 .22234 .6394 .22394 .63913 .2229 .63748 Mtetra
.657 .643 .824 r
.2229 .63748 .22394 .63913 .22558 .63855 .22454 .63688 Mtetra
.658 .642 .823 r
.22454 .63688 .22558 .63855 .22723 .63781 .22618 .63628 Mtetra
.649 .656 .843 r
.22618 .63628 .22723 .63781 .22886 .63727 .22781 .63575 Mtetra
.644 .655 .846 r
.22781 .63575 .22886 .63727 .23049 .63676 .22944 .63524 Mtetra
.64 .654 .848 r
.22944 .63524 .23049 .63676 .23212 .63627 .23107 .63476 Mtetra
.638 .655 .85 r
.23107 .63476 .23212 .63627 .23375 .63579 .2327 .63429 Mtetra
.636 .655 .852 r
.2327 .63429 .23375 .63579 .23538 .63533 .23433 .63384 Mtetra
.634 .656 .854 r
.23433 .63384 .23538 .63533 .23702 .63486 .23596 .63339 Mtetra
.629 .656 .858 r
.23596 .63339 .23702 .63486 .23863 .63457 .23759 .63297 Mtetra
.63 .639 .841 r
.23759 .63297 .23863 .63457 .24026 .63417 .23922 .63253 Mtetra
.636 .637 .834 r
.23922 .63253 .24026 .63417 .24191 .63349 .24086 .63206 Mtetra
.665 .676 .851 r
.24086 .63206 .24191 .63349 .24366 .6317 .2425 .63146 Mtetra
.633 .91 .982 r
.2425 .63146 .24366 .6317 .24547 .62905 .24416 .6308 Mtetra
.266 0 .053 r
.24416 .6308 .24547 .62905 .24736 .62539 .24581 .63016 Mtetra
.467 .166 .371 r
.24581 .63016 .24736 .62539 .24912 .62342 .24745 .62964 Mtetra
.49 .206 .41 r
.24745 .62964 .24912 .62342 .25075 .623 .24909 .62917 Mtetra
.491 .207 .41 r
.24909 .62917 .25075 .623 .25233 .62324 .25073 .62873 Mtetra
.482 .191 .394 r
.25073 .62873 .25233 .62324 .25396 .62294 .25237 .62826 Mtetra
.479 .186 .389 r
.25237 .62826 .25396 .62294 .2556 .62249 .25402 .62778 Mtetra
.477 .183 .388 r
.25402 .62778 .2556 .62249 .25724 .62202 .25566 .62728 Mtetra
.512 .216 .4 r
.25566 .62728 .25724 .62202 .25881 .62241 .25728 .6272 Mtetra
.487 .185 .379 r
.25728 .6272 .25881 .62241 .26043 .62228 .25891 .62688 Mtetra
.407 .107 .34 r
.25891 .62688 .26043 .62228 .26215 .62077 .2606 .62586 Mtetra
0 0 .053 r
.2606 .62586 .26215 .62077 .27829 .42915 .26258 .6211 Mtetra
0 0 .163 r
.26258 .6211 .27829 .42915 .28062 .4185 .2793 .42153 Mtetra
.952 .879 .475 r
.2793 .42153 .28062 .4185 .2824 .415 .28133 .41477 Mtetra
.872 .899 .849 r
.28133 .41477 .2824 .415 .28401 .4137 .28297 .41308 Mtetra
.669 .826 .959 r
.28297 .41308 .28401 .4137 .28557 .41314 .28453 .4125 Mtetra
.502 .772 .992 r
.28453 .4125 .28557 .41314 .28711 .41285 .28607 .41232 Mtetra
.591 .832 .99 r
.28607 .41232 .28711 .41285 .28867 .4124 .28762 .41192 Mtetra
.627 .855 .986 r
.28762 .41192 .28867 .4124 .29023 .41188 .28918 .41142 Mtetra
.625 .859 .987 r
.28918 .41142 .29023 .41188 .29179 .41136 .29074 .41091 Mtetra
.641 .866 .983 r
.29074 .41091 .29179 .41136 .29335 .41084 .2923 .41036 Mtetra
.653 .862 .979 r
.2923 .41036 .29335 .41084 .29491 .41031 .29387 .40979 Mtetra
.66 .852 .974 r
.29387 .40979 .29491 .41031 .29648 .40978 .29544 .40921 Mtetra
.665 .842 .968 r
.29544 .40921 .29648 .40978 .29805 .40911 .297 .40863 Mtetra
.65 .862 .98 r
.297 .40863 .29805 .40911 .29962 .40848 .29857 .40807 Mtetra
.625 .872 .988 r
.29857 .40807 .29962 .40848 .30118 .40806 .30014 .40754 Mtetra
.714 .859 .951 r
.30014 .40754 .30118 .40806 .3027 .40822 .30172 .40678 Mtetra
.667 .665 .839 r
.30172 .40678 .3027 .40822 .30417 .40911 .3033 .40618 Mtetra
.56 .483 .725 r
.3033 .40618 .30417 .40911 .30556 .41135 .30484 .40612 Mtetra
.24 .189 .597 r
.30484 .40612 .30556 .41135 .29433 .60092 .30619 .40876 Mtetra
0 0 .205 r
.30619 .40876 .29433 .60092 .29512 .61348 .29449 .60581 Mtetra
0 0 .284 r
.29449 .60581 .29512 .61348 .29657 .61624 .29557 .61412 Mtetra
.172 .324 .777 r
.29557 .61412 .29657 .61624 .29818 .61662 .29713 .61533 Mtetra
.613 .683 .892 r
.29713 .61533 .29818 .61662 .29986 .61602 .29879 .61497 Mtetra
.717 .756 .883 r
.29879 .61497 .29986 .61602 .30156 .6151 .30049 .61412 Mtetra
.587 .737 .947 r
.30049 .61412 .30156 .6151 .30322 .61488 .30215 .61382 Mtetra
.568 .711 .938 r
.30215 .61382 .30322 .61488 .30487 .61481 .30381 .61359 Mtetra
.711 .727 .862 r
.30381 .61359 .30487 .61481 .30656 .6141 .30551 .61273 Mtetra
.871 .726 .699 r
.30551 .61273 .30656 .6141 .30844 .61045 .30739 .60906 Mtetra
.947 .688 .513 r
.30739 .60906 .30844 .61045 .32254 .4114 .32148 .41122 Mtetra
.953 .744 .584 r
.32148 .41122 .32254 .4114 .32471 .40138 .32368 .40088 Mtetra
.889 .835 .787 r
.32368 .40088 .32471 .40138 .32639 .39925 .32537 .39865 Mtetra
.684 .839 .958 r
.32537 .39865 .32639 .39925 .32797 .39877 .32696 .39801 Mtetra
.52 .751 .98 r
.32696 .39801 .32797 .39877 .32952 .39879 .32852 .39784 Mtetra
.591 .731 .941 r
.32852 .39784 .32952 .39879 .33109 .3986 .33009 .39755 Mtetra
.648 .728 .907 r
.33009 .39755 .33109 .3986 .33267 .39811 .33168 .39707 Mtetra
.651 .73 .907 r
.33168 .39707 .33267 .39811 .33426 .39756 .33326 .39657 Mtetra
.669 .748 .909 r
.33326 .39657 .33426 .39756 .33586 .39677 .33485 .396 Mtetra
.681 .799 .938 r
.33485 .396 .33586 .39677 .33747 .39592 .33645 .39538 Mtetra
.666 .852 .971 r
.33645 .39538 .33747 .39592 .33906 .39529 .33804 .39478 Mtetra
.717 .866 .952 r
.33804 .39478 .33906 .39529 .34062 .39526 .33964 .394 Mtetra
.689 .703 .857 r
.33964 .394 .34062 .39526 .34214 .39602 .34125 .39329 Mtetra
.578 .506 .738 r
.34125 .39329 .34214 .39602 .34359 .39802 .34282 .39311 Mtetra
.321 .256 .626 r
.34282 .39311 .34359 .39802 .34437 .41213 .34427 .39514 Mtetra
.971 .709 .475 r
.34427 .39514 .34437 .41213 .33552 .6005 .33502 .58942 Mtetra
0 0 .288 r
.33502 .58942 .33552 .6005 .33702 .60359 .33604 .60121 Mtetra
.066 .226 .719 r
.33604 .60121 .33702 .60359 .33866 .60421 .33761 .60287 Mtetra
.605 .675 .89 r
.33761 .60287 .33866 .60421 .34036 .60362 .3393 .60255 Mtetra
.718 .756 .883 r
.3393 .60255 .34036 .60362 .34209 .60266 .34102 .60168 Mtetra
.703 .771 .905 r
.34102 .60168 .34209 .60266 .34379 .60204 .34274 .60091 Mtetra
.646 .726 .907 r
.34274 .60091 .34379 .60204 .34548 .6018 .34444 .6004 Mtetra
.651 .682 .867 r
.34444 .6004 .34548 .6018 .34718 .60134 .34615 .59986 Mtetra
.665 .676 .85 r
.34615 .59986 .34718 .60134 .34893 .60001 .34786 .59922 Mtetra
.691 .809 .938 r
.34786 .59922 .34893 .60001 .35073 .59751 .34958 .59851 Mtetra
.039 0 0 r
.34958 .59851 .35073 .59751 .35259 .59392 .35129 .59781 Mtetra
.44 .122 .329 r
.35129 .59781 .35259 .59392 .35445 .59048 .35301 .5972 Mtetra
.493 .214 .419 r
.35301 .5972 .35445 .59048 .35617 .58957 .35471 .59671 Mtetra
.498 .222 .426 r
.35471 .59671 .35617 .58957 .35784 .5898 .35642 .59625 Mtetra
.491 .21 .414 r
.35642 .59625 .35784 .5898 .35954 .58939 .35813 .59576 Mtetra
.487 .205 .411 r
.35813 .59576 .35954 .58939 .36128 .58829 .35984 .59523 Mtetra
.494 .217 .422 r
.35984 .59523 .36128 .58829 .36296 .58824 .36156 .59472 Mtetra
.497 .215 .416 r
.36156 .59472 .36296 .58824 .36455 .59045 .36327 .59432 Mtetra
.475 .154 .343 r
.36327 .59432 .36455 .59045 .36612 .59298 .36497 .59402 Mtetra
.264 0 0 r
.36497 .59402 .36612 .59298 .36774 .59446 .36668 .59371 Mtetra
.592 .795 .977 r
.36668 .59371 .36774 .59446 .36942 .59488 .36839 .59332 Mtetra
.638 .655 .851 r
.36839 .59332 .36942 .59488 .37113 .59447 .37011 .59283 Mtetra
.642 .646 .839 r
.37011 .59283 .37113 .59447 .37286 .59383 .37183 .5923 Mtetra
.647 .663 .852 r
.37183 .5923 .37286 .59383 .37458 .59321 .37356 .59176 Mtetra
.648 .676 .862 r
.37356 .59176 .37458 .59321 .3763 .59271 .37528 .59122 Mtetra
.648 .669 .856 r
.37528 .59122 .3763 .59271 .37803 .59222 .377 .59068 Mtetra
.6 .642 .864 r
.377 .59068 .37803 .59222 .37974 .59187 .37872 .59037 Mtetra
.562 .633 .879 r
.37872 .59037 .37974 .59187 .38146 .5916 .38043 .59022 Mtetra
.671 .695 .864 r
.38043 .59022 .38146 .5916 .38319 .59098 .38216 .58957 Mtetra
.835 .729 .747 r
.38216 .58957 .38319 .59098 .38497 .58922 .38397 .58711 Mtetra
.914 .694 .59 r
.38397 .58711 .38497 .58922 .38685 .58484 .38611 .57669 Mtetra
.947 .681 .5 r
.38611 .57669 .38685 .58484 .39615 .39525 .39583 .37779 Mtetra
.612 .4 .57 r
.39583 .37779 .39615 .39525 .39832 .381 .39757 .37441 Mtetra
.596 .427 .623 r
.39757 .37441 .39832 .381 .39996 .38029 .39921 .37358 Mtetra
.566 .404 .621 r
.39921 .37358 .39996 .38029 .40157 .38025 .40083 .3733 Mtetra
.566 .401 .618 r
.40083 .3733 .40157 .38025 .40325 .37856 .40245 .37302 Mtetra
.597 .44 .639 r
.40245 .37302 .40325 .37856 .40498 .37532 .40408 .37233 Mtetra
.632 .527 .716 r
.40408 .37233 .40498 .37532 .40668 .37299 .40572 .37164 Mtetra
.671 .687 .856 r
.40572 .37164 .40668 .37299 .40834 .37158 .40735 .371 Mtetra
.638 .844 .979 r
.40735 .371 .40834 .37158 .40997 .37104 .40899 .37047 Mtetra
.632 .842 .98 r
.40899 .37047 .40997 .37104 .41159 .37074 .41062 .36995 Mtetra
.657 .794 .948 r
.41062 .36995 .41159 .37074 .41322 .37043 .41225 .3694 Mtetra
.673 .746 .905 r
.41225 .3694 .41322 .37043 .41486 .36989 .41389 .3688 Mtetra
.673 .733 .895 r
.41389 .3688 .41486 .36989 .41649 .3693 .41553 .36819 Mtetra
.699 .738 .881 r
.41553 .36819 .41649 .3693 .41814 .36852 .41717 .36745 Mtetra
.73 .753 .871 r
.41717 .36745 .41814 .36852 .41979 .36753 .41883 .36654 Mtetra
.642 .745 .924 r
.41883 .36654 .41979 .36753 .42143 .36685 .42046 .36606 Mtetra
0 .323 .766 r
.42046 .36606 .42143 .36685 .42305 .36708 .42206 .36693 Mtetra
.927 .576 .344 r
.42206 .36693 .42305 .36708 .42459 .36969 .42346 .37386 Mtetra
.952 .678 .48 r
.42346 .37386 .42459 .36969 .42578 .38382 .41884 .57411 Mtetra
.546 .321 .525 r
.41884 .57411 .42578 .38382 .4217 .57206 .42048 .57728 Mtetra
.506 .208 .395 r
.42048 .57728 .4217 .57206 .42344 .57182 .42222 .57713 Mtetra
.454 .162 .379 r
.42222 .57713 .42344 .57182 .4252 .57075 .42398 .57633 Mtetra
.45 .163 .384 r
.42398 .57633 .4252 .57075 .42693 .57105 .42575 .57543 Mtetra
.477 .167 .361 r
.42575 .57543 .42693 .57105 .4286 .57361 .4275 .57506 Mtetra
.326 0 .036 r
.4275 .57506 .4286 .57361 .43029 .57518 .42925 .57469 Mtetra
.549 .847 .998 r
.42925 .57469 .43029 .57518 .43202 .57581 .43101 .57427 Mtetra
.641 .663 .856 r
.43101 .57427 .43202 .57581 .43378 .57544 .43277 .57376 Mtetra
.644 .645 .836 r
.43277 .57376 .43378 .57544 .43554 .57481 .43453 .57321 Mtetra
.648 .657 .845 r
.43453 .57321 .43554 .57481 .43731 .57412 .43629 .57264 Mtetra
.65 .675 .861 r
.43629 .57264 .43731 .57412 .43907 .57361 .43806 .57208 Mtetra
.65 .668 .854 r
.43806 .57208 .43907 .57361 .44083 .57309 .43982 .57151 Mtetra
.626 .651 .855 r
.43982 .57151 .44083 .57309 .44259 .57265 .44159 .57107 Mtetra
.551 .617 .872 r
.44159 .57107 .44259 .57265 .44435 .57241 .44334 .57097 Mtetra
.648 .681 .867 r
.44334 .57097 .44435 .57241 .44612 .57187 .44511 .57042 Mtetra
.798 .727 .785 r
.44511 .57042 .44612 .57187 .44791 .5705 .44691 .56863 Mtetra
.912 .706 .611 r
.44691 .56863 .44791 .5705 .44976 .56658 .44884 .56098 Mtetra
.956 .685 .481 r
.44884 .56098 .44976 .56658 .45177 .55471 .45504 .35856 Mtetra
.55 .329 .533 r
.45504 .35856 .45177 .55471 .45762 .36068 .45679 .35413 Mtetra
.604 .433 .624 r
.45679 .35413 .45762 .36068 .4593 .35969 .45846 .35314 Mtetra
.572 .41 .624 r
.45846 .35314 .4593 .35969 .46096 .35955 .46012 .35277 Mtetra
.561 .4 .621 r
.46012 .35277 .46096 .35955 .46263 .35864 .46178 .35258 Mtetra
.592 .43 .631 r
.46178 .35258 .46263 .35864 .46435 .35529 .46345 .35188 Mtetra
.624 .506 .699 r
.46345 .35188 .46435 .35529 .46606 .35281 .46512 .35118 Mtetra
.666 .649 .823 r
.46512 .35118 .46606 .35281 .46775 .3511 .46679 .35051 Mtetra
.643 .846 .978 r
.46679 .35051 .46775 .3511 .46942 .35036 .46846 .34995 Mtetra
.601 .878 .992 r
.46846 .34995 .46942 .35036 .47109 .34986 .47013 .34942 Mtetra
.606 .87 .992 r
.47013 .34942 .47109 .34986 .47275 .34947 .4718 .34889 Mtetra
.636 .847 .981 r
.4718 .34889 .47275 .34947 .47442 .34891 .47347 .34834 Mtetra
.635 .849 .982 r
.47347 .34834 .47442 .34891 .4761 .34838 .47515 .34779 Mtetra
.635 .845 .981 r
.47515 .34779 .4761 .34838 .47777 .34788 .47682 .34725 Mtetra
.635 .833 .976 r
.47682 .34725 .47777 .34788 .47944 .34748 .4785 .34671 Mtetra
.645 .803 .959 r
.4785 .34671 .47944 .34748 .48112 .3471 .48017 .34618 Mtetra
.652 .771 .936 r
.48017 .34618 .48112 .3471 .48279 .34669 .48185 .34565 Mtetra
.658 .745 .914 r
.48185 .34565 .48279 .34669 .48447 .34617 .48353 .3451 Mtetra
.659 .738 .908 r
.48353 .3451 .48447 .34617 .48615 .34561 .48521 .34454 Mtetra
.661 .739 .907 r
.48521 .34454 .48615 .34561 .48783 .34503 .48689 .34397 Mtetra
.662 .742 .909 r
.48689 .34397 .48783 .34503 .48951 .34448 .48857 .3434 Mtetra
.664 .74 .906 r
.48857 .3434 .48951 .34448 .49119 .34389 .49026 .34282 Mtetra
.666 .742 .907 r
.49026 .34282 .49119 .34389 .49288 .34326 .49194 .34223 Mtetra
.669 .752 .913 r
.49194 .34223 .49288 .34326 .49456 .34251 .49363 .34163 Mtetra
.67 .783 .934 r
.49363 .34163 .49456 .34251 .49625 .34176 .49531 .34102 Mtetra
.665 .818 .957 r
.49531 .34102 .49625 .34176 .49794 .34103 .497 .34042 Mtetra
.652 .846 .975 r
.497 .34042 .49794 .34103 .49963 .34039 .49869 .33982 Mtetra
.649 .855 .979 r
.49869 .33982 .49963 .34039 .50132 .33979 .50038 .33923 Mtetra
.65 .857 .979 r
.50038 .33923 .50132 .33979 .503 .33919 .50207 .33862 Mtetra
.668 .86 .973 r
.50207 .33862 .503 .33919 .5047 .3384 .50376 .33797 Mtetra
.643 .888 .985 r
.50376 .33797 .5047 .3384 .50639 .33775 .50545 .33733 Mtetra
.623 .886 .989 r
.50545 .33733 .50639 .33775 .50808 .33738 .50715 .33674 Mtetra
.734 .855 .938 r
.50715 .33674 .50808 .33738 .50977 .33778 .50884 .33585 Mtetra
.635 .604 .801 r
.50884 .33585 .50977 .33778 .51146 .33902 .51054 .33533 Mtetra
.531 .439 .695 r
.51054 .33533 .51146 .33902 .51314 .34241 .51223 .33553 Mtetra
.114 .083 .541 r
.51223 .33553 .51314 .34241 .5142 .54203 .51391 .34056 Mtetra
0 0 .337 r
.51391 .34056 .5142 .54203 .516 .54778 .51502 .54348 Mtetra
0 0 .498 r
.51502 .54348 .516 .54778 .5178 .54981 .51682 .54813 Mtetra
.492 .577 .869 r
.51682 .54813 .5178 .54981 .51962 .54973 .51863 .54828 Mtetra
.664 .691 .865 r
.51863 .54828 .51962 .54973 .52144 .54912 .52045 .54763 Mtetra
.721 .707 .836 r
.52045 .54763 .52144 .54912 .52326 .54823 .52227 .54659 Mtetra
.638 .654 .85 r
.52227 .54659 .52326 .54823 .52508 .54782 .52409 .54607 Mtetra
.634 .638 .837 r
.52409 .54607 .52508 .54782 .5269 .54728 .52591 .54556 Mtetra
.641 .644 .837 r
.52591 .54556 .5269 .54728 .52872 .54646 .52773 .545 Mtetra
.672 .694 .862 r
.52773 .545 .52872 .54646 .53054 .54446 .52956 .5443 Mtetra
.584 .927 .957 r
.52956 .5443 .53054 .54446 .53236 .54163 .53138 .54356 Mtetra
.296 0 .107 r
.53138 .54356 .53236 .54163 .53417 .53778 .53321 .54282 Mtetra
.508 .206 .389 r
.53321 .54282 .53417 .53778 .536 .53716 .53504 .54272 Mtetra
.491 .199 .396 r
.53504 .54272 .536 .53716 .53782 .53705 .53687 .54234 Mtetra
.428 .14 .372 r
.53687 .54234 .53782 .53705 .53965 .53586 .53869 .54121 Mtetra
0 0 .166 r
.53869 .54121 .53965 .53586 .54049 .33735 .5405 .53563 Mtetra
0 0 .331 r
.5405 .53563 .54049 .33735 .54217 .32862 .54127 .33107 Mtetra
.861 .823 .346 r
.54127 .33107 .54217 .32862 .54387 .32526 .54296 .32486 Mtetra
.844 .92 .884 r
.54296 .32486 .54387 .32526 .54558 .32422 .54467 .32336 Mtetra
.663 .792 .944 r
.54467 .32336 .54558 .32422 .5473 .32379 .54639 .32276 Mtetra
.561 .714 .944 r
.54639 .32276 .5473 .32379 .54902 .32361 .54811 .32254 Mtetra
.661 .745 .912 r
.54811 .32254 .54902 .32361 .55074 .32282 .54983 .32196 Mtetra
.669 .795 .942 r
.54983 .32196 .55074 .32282 .55246 .32202 .55155 .32134 Mtetra
.647 .834 .972 r
.55155 .32134 .55246 .32202 .55418 .32146 .55327 .32077 Mtetra
.724 .847 .939 r
.55327 .32077 .55418 .32146 .55591 .32166 .55499 .31991 Mtetra
.651 .633 .819 r
.55499 .31991 .55591 .32166 .55765 .32268 .55672 .31931 Mtetra
.55 .464 .711 r
.55672 .31931 .55765 .32268 .55941 .32538 .55845 .31933 Mtetra
.24 .187 .594 r
.55845 .31933 .55941 .32538 .56343 .52402 .56022 .32286 Mtetra
0 0 .357 r
.56022 .32286 .56343 .52402 .56538 .53197 .56435 .52612 Mtetra
0 0 .477 r
.56435 .52612 .56538 .53197 .56726 .53434 .56628 .53237 Mtetra
.38 .477 .833 r
.56628 .53237 .56726 .53434 .56912 .53438 .56815 .53303 Mtetra
.641 .701 .89 r
.56815 .53303 .56912 .53438 .57097 .53363 .57 .5325 Mtetra
.728 .768 .885 r
.57 .5325 .57097 .53363 .57281 .53259 .57184 .53152 Mtetra
.66 .76 .924 r
.57184 .53152 .57281 .53259 .57466 .5322 .5737 .5309 Mtetra
.639 .71 .898 r
.5737 .5309 .57466 .5322 .57652 .53189 .57555 .53038 Mtetra
.645 .677 .866 r
.57555 .53038 .57652 .53189 .57838 .53132 .57741 .52981 Mtetra
.582 .651 .883 r
.57741 .52981 .57838 .53132 .58022 .52992 .57927 .52956 Mtetra
.52 .871 .988 r
.57927 .52956 .58022 .52992 .58205 .52763 .58113 .52908 Mtetra
.058 0 0 r
.58113 .52908 .58205 .52763 .58385 .52368 .58298 .5279 Mtetra
0 0 .12 r
.58298 .5279 .58385 .52368 .58213 .32664 .58476 .52317 Mtetra
0 0 .346 r
.58476 .52317 .58213 .32664 .58368 .31527 .58286 .31848 Mtetra
.791 .753 .235 r
.58286 .31848 .58368 .31527 .58536 .31181 .58447 .31105 Mtetra
.862 .845 .826 r
.58447 .31105 .58536 .31181 .58709 .31045 .58619 .30921 Mtetra
.665 .715 .885 r
.58619 .30921 .58709 .31045 .58883 .30985 .58793 .30859 Mtetra
.566 .671 .909 r
.58793 .30859 .58883 .30985 .59058 .30951 .58969 .30839 Mtetra
.642 .731 .913 r
.58969 .30839 .59058 .30951 .59233 .30873 .59144 .30789 Mtetra
.675 .803 .944 r
.59144 .30789 .59233 .30873 .59407 .30787 .59318 .30723 Mtetra
.655 .848 .974 r
.59318 .30723 .59407 .30787 .59581 .30727 .59493 .30661 Mtetra
.723 .861 .947 r
.59493 .30661 .59581 .30727 .59758 .30735 .59667 .30574 Mtetra
.669 .661 .833 r
.59667 .30574 .59758 .30735 .59936 .30826 .59842 .30505 Mtetra
.564 .48 .718 r
.59842 .30505 .59936 .30826 .60119 .31067 .60018 .30495 Mtetra
.303 .237 .616 r
.60018 .30495 .60119 .31067 .60782 .50581 .60202 .30783 Mtetra
0 0 .37 r
.60202 .30783 .60782 .50581 .61 .51736 .60892 .51115 Mtetra
0 0 .443 r
.60892 .51115 .61 .51736 .61196 .52012 .611 .51855 Mtetra
.018 .306 .797 r
.611 .51855 .61196 .52012 .61388 .52105 .61293 .51997 Mtetra
.551 .719 .951 r
.61293 .51997 .61388 .52105 .61577 .52094 .61482 .51975 Mtetra
.765 .771 .858 r
.61482 .51975 .61577 .52094 .61764 .51991 .61668 .51848 Mtetra
.903 .754 .686 r
.61668 .51848 .61764 .51991 .61943 .51596 .61847 .51449 Mtetra
.973 .687 .42 r
.61847 .51449 .61943 .51596 .61543 .31205 .61458 .3121 Mtetra
.99 .766 .502 r
.61458 .3121 .61543 .31205 .6169 .30132 .61603 .30075 Mtetra
.908 .876 .792 r
.61603 .30075 .6169 .30132 .61862 .29914 .61775 .29845 Mtetra
.678 .844 .963 r
.61775 .29845 .61862 .29914 .62038 .29862 .61951 .29775 Mtetra
.533 .748 .974 r
.61951 .29775 .62038 .29862 .62216 .2986 .62128 .29754 Mtetra
.606 .731 .933 r
.62128 .29754 .62216 .2986 .62394 .29832 .62306 .29716 Mtetra
.656 .73 .904 r
.62306 .29716 .62394 .29832 .62571 .29774 .62482 .29659 Mtetra
.657 .732 .905 r
.62482 .29659 .62571 .29774 .62747 .2971 .62659 .29601 Mtetra
.731 .77 .884 r
.62659 .29601 .62747 .2971 .62923 .296 .62835 .29506 Mtetra
.733 .8 .905 r
.62835 .29506 .62923 .296 .63098 .29492 .63011 .29412 Mtetra
.583 .784 .975 r
.63011 .29412 .63098 .29492 .63275 .29444 .63189 .29375 Mtetra
.642 .124 0 r
.63189 .29375 .63275 .29444 .63462 .29655 .63376 .29587 Mtetra
.974 .678 .396 r
.63376 .29587 .63462 .29655 .64365 .49886 .64269 .49695 Mtetra
.936 .585 .167 r
.64269 .49695 .64365 .49886 .64595 .50936 .64499 .5077 Mtetra
.018 .29 .785 r
.64499 .5077 .64595 .50936 .64793 .51088 .64697 .50924 Mtetra
.608 .646 .862 r
.64697 .50924 .64793 .51088 .64983 .51041 .64888 .50886 Mtetra
.703 .7 .844 r
.64888 .50886 .64983 .51041 .65171 .50918 .65078 .50792 Mtetra
.652 .726 .903 r
.65078 .50792 .65171 .50918 .65358 .50759 .65268 .50732 Mtetra
.436 .85 .963 r
.65268 .50732 .65358 .50759 .65543 .50556 .6546 .5069 Mtetra
.104 0 0 r
.6546 .5069 .65543 .50556 .65723 .50232 .65649 .50589 Mtetra
0 0 .16 r
.65649 .50589 .65723 .50232 .65873 .4917 .65828 .5024 Mtetra
.983 .697 .376 r
.65828 .5024 .65873 .4917 .65252 .29302 .65207 .30237 Mtetra
0 0 .158 r
.65207 .30237 .65252 .29302 .65416 .28882 .65332 .28841 Mtetra
.937 .897 .762 r
.65332 .28841 .65416 .28882 .65589 .28701 .65502 .28575 Mtetra
.694 .729 .877 r
.65502 .28575 .65589 .28701 .65767 .2863 .6568 .28497 Mtetra
.588 .673 .898 r
.6568 .28497 .65767 .2863 .65947 .28592 .6586 .28469 Mtetra
.668 .724 .891 r
.6586 .28469 .65947 .28592 .66126 .28518 .66039 .28405 Mtetra
.726 .764 .883 r
.66039 .28405 .66126 .28518 .66303 .28421 .66217 .28312 Mtetra
.613 .73 .929 r
.66217 .28312 .66303 .28421 .66483 .2838 .66397 .28271 Mtetra
0 .132 .658 r
.66397 .28271 .66483 .2838 .66673 .28566 .66586 .28441 Mtetra
.975 .676 .379 r
.66586 .28441 .66673 .28566 .67787 .48713 .67669 .48031 Mtetra
.737 .499 0 r
.67669 .48031 .67787 .48713 .68035 .49854 .6794 .4967 Mtetra
0 .215 .736 r
.6794 .4967 .68035 .49854 .68238 .50033 .68144 .49865 Mtetra
.597 .638 .862 r
.68144 .49865 .68238 .50033 .68432 .4999 .68338 .49832 Mtetra
.701 .698 .844 r
.68338 .49832 .68432 .4999 .68622 .49869 .68529 .49738 Mtetra
.677 .73 .89 r
.68529 .49738 .68622 .49869 .68809 .49705 .68721 .49664 Mtetra
.49 .855 .989 r
.68721 .49664 .68809 .49705 .68995 .49497 .68915 .49621 Mtetra
.08 0 0 r
.68915 .49621 .68995 .49497 .69174 .49163 .69106 .4952 Mtetra
.042 0 .186 r
.69106 .4952 .69174 .49163 .69313 .48039 .69286 .49192 Mtetra
.982 .694 .357 r
.69286 .49192 .69313 .48039 .68485 .28169 .68453 .29119 Mtetra
0 0 .188 r
.68453 .29119 .68485 .28169 .68647 .2775 .68565 .27718 Mtetra
.959 .898 .72 r
.68565 .27718 .68647 .2775 .68819 .27534 .68733 .27408 Mtetra
.752 .75 .851 r
.68733 .27408 .68819 .27534 .68997 .27425 .68911 .27292 Mtetra
.579 .669 .9 r
.68911 .27292 .68997 .27425 .6918 .27394 .69094 .27267 Mtetra
0 .26 .768 r
.69094 .27267 .6918 .27394 .69372 .27537 .69286 .27415 Mtetra
.93 .562 .156 r
.69286 .27415 .69372 .27537 .69611 .28521 .69522 .28357 Mtetra
.976 .674 .365 r
.69522 .28357 .69611 .28521 .70926 .48821 .70836 .48704 Mtetra
.571 .114 0 r
.70836 .48704 .70926 .48821 .7114 .49097 .71049 .48984 Mtetra
.439 .658 .953 r
.71049 .48984 .7114 .49097 .71338 .49108 .71248 .48996 Mtetra
.725 .785 .9 r
.71248 .48996 .71338 .49108 .71531 .49009 .71441 .48897 Mtetra
.902 .808 .746 r
.71441 .48897 .71531 .49009 .71712 .48715 .71622 .48604 Mtetra
.978 .74 .507 r
.71622 .48604 .71712 .48715 .71841 .47534 .71751 .47412 Mtetra
.977 .681 .379 r
.71751 .47412 .71841 .47534 .70832 .27173 .70747 .27056 Mtetra
.918 .787 .7 r
.70747 .27056 .70832 .27173 .70997 .26827 .70913 .26711 Mtetra
.718 .76 .886 r
.70913 .26711 .70997 .26827 .71178 .26736 .71093 .26621 Mtetra
.597 .713 .925 r
.71093 .26621 .71178 .26736 .71361 .26702 .71277 .26586 Mtetra
.632 .728 .917 r
.71277 .26586 .71361 .26702 .71545 .26653 .7146 .26537 Mtetra
.738 .768 .877 r
.7146 .26537 .71545 .26653 .71724 .2655 .7164 .26435 Mtetra
.649 .736 .913 r
.7164 .26435 .71724 .2655 .71907 .26494 .71823 .26378 Mtetra
.101 .426 .87 r
.71823 .26378 .71907 .26494 .721 .26589 .72016 .26474 Mtetra
.91 .528 .101 r
.72016 .26474 .721 .26589 .72338 .27391 .72255 .27283 Mtetra
.975 .671 .352 r
.72255 .27283 .72338 .27391 .73851 .47871 .73763 .47763 Mtetra
.605 .138 0 r
.73763 .47763 .73851 .47871 .7407 .48163 .73982 .48055 Mtetra
.546 .723 .956 r
.73982 .48055 .7407 .48163 .7427 .4814 .74181 .48032 Mtetra
.708 .79 .915 r
.74181 .48032 .7427 .4814 .74464 .4805 .74376 .47943 Mtetra
.691 .786 .923 r
.74376 .47943 .74464 .4805 .7466 .47969 .74571 .47862 Mtetra
.505 .707 .961 r
.74571 .47862 .7466 .47969 .7486 .47959 .74772 .47852 Mtetra
.651 .771 .937 r
.74772 .47852 .7486 .47959 .75057 .47897 .74969 .47789 Mtetra
.867 .822 .802 r
.74969 .47789 .75057 .47897 .75243 .47675 .75155 .47568 Mtetra
.98 .756 .527 r
.75155 .47568 .75243 .47675 .75378 .46712 .75291 .4662 Mtetra
.978 .678 .361 r
.75291 .4662 .75378 .46712 .74132 .26102 .7405 .25991 Mtetra
.939 .794 .672 r
.7405 .25991 .74132 .26102 .74293 .25708 .7421 .25594 Mtetra
.731 .772 .886 r
.7421 .25594 .74293 .25708 .74475 .2561 .74392 .25496 Mtetra
.602 .721 .928 r
.74392 .25496 .74475 .2561 .74661 .25573 .74578 .25458 Mtetra
.601 .719 .928 r
.74578 .25458 .74661 .25573 .74848 .25536 .74765 .25421 Mtetra
.742 .774 .878 r
.74765 .25421 .74848 .25536 .75029 .25431 .74946 .25315 Mtetra
.658 .742 .912 r
.74946 .25315 .75029 .25431 .75214 .25371 .75131 .25255 Mtetra
.227 .508 .907 r
.75131 .25255 .75214 .25371 .75409 .2544 .75326 .25324 Mtetra
.887 .497 .046 r
.75326 .25324 .75409 .2544 .75654 .26183 .75572 .2607 Mtetra
.975 .667 .334 r
.75572 .2607 .75654 .26183 .77404 .46779 .77317 .46668 Mtetra
.652 .197 0 r
.77317 .46668 .77404 .46779 .77634 .47122 .77547 .4701 Mtetra
.384 .632 .952 r
.77547 .4701 .77634 .47122 .77839 .47148 .77752 .47036 Mtetra
.693 .781 .918 r
.77752 .47036 .77839 .47148 .78037 .47065 .7795 .46954 Mtetra
.873 .82 .793 r
.7795 .46954 .78037 .47065 .78223 .46834 .78136 .46722 Mtetra
.978 .767 .552 r
.78136 .46722 .78223 .46834 .78366 .4605 .78279 .45938 Mtetra
.977 .675 .347 r
.78279 .45938 .78366 .4605 .76916 .25233 .76834 .25115 Mtetra
.95 .785 .641 r
.76834 .25115 .76916 .25233 .7707 .24771 .76988 .24653 Mtetra
.746 .772 .874 r
.76988 .24653 .7707 .24771 .77252 .24663 .77171 .24545 Mtetra
.618 .722 .92 r
.77171 .24545 .77252 .24663 .7744 .24619 .77359 .24501 Mtetra
.585 .706 .926 r
.77359 .24501 .7744 .24619 .77629 .24588 .77548 .2447 Mtetra
.747 .772 .873 r
.77548 .2447 .77629 .24588 .77812 .24478 .7773 .2436 Mtetra
.67 .743 .905 r
.7773 .2436 .77812 .24478 .77998 .24411 .77917 .24292 Mtetra
.355 .581 .928 r
.77917 .24292 .77998 .24411 .78193 .24452 .78112 .24333 Mtetra
.833 .428 0 r
.78112 .24333 .78193 .24452 .78437 .25063 .78355 .24941 Mtetra
.973 .663 .318 r
.78355 .24941 .78437 .25063 .80393 .45796 .80308 .4568 Mtetra
.688 .246 0 r
.80308 .4568 .80393 .45796 .80633 .46193 .80548 .46078 Mtetra
.353 .608 .945 r
.80548 .46078 .80633 .46193 .80843 .46229 .80757 .46114 Mtetra
.676 .771 .922 r
.80757 .46114 .80843 .46229 .81043 .46154 .80958 .46039 Mtetra
.856 .818 .811 r
.80958 .46039 .81043 .46154 .81232 .45945 .81146 .45829 Mtetra
.977 .773 .563 r
.81146 .45829 .81232 .45945 .81376 .45234 .8129 .45112 Mtetra
.976 .672 .332 r
.8129 .45112 .81376 .45234 .79726 .24332 .79645 .24208 Mtetra
.957 .778 .619 r
.79645 .24208 .79726 .24332 .79874 .23818 .79793 .23697 Mtetra
.746 .768 .871 r
.79793 .23697 .79874 .23818 .80057 .23708 .79977 .23587 Mtetra
.61 .714 .918 r
.79977 .23587 .80057 .23708 .80247 .23667 .80167 .23546 Mtetra
.528 .673 .93 r
.80167 .23546 .80247 .23667 .8044 .23657 .8036 .23536 Mtetra
.656 .734 .907 r
.8036 .23536 .8044 .23657 .80629 .23596 .80549 .23474 Mtetra
.661 .735 .904 r
.80549 .23474 .80629 .23596 .80817 .23531 .80737 .2341 Mtetra
.675 .744 .902 r
.80737 .2341 .80817 .23531 .81005 .23456 .80925 .2334 Mtetra
.765 .785 .87 r
.80925 .2334 .81005 .23456 .81187 .23321 .81108 .23219 Mtetra
.698 .79 .922 r
.81108 .23219 .81187 .23321 .81373 .23229 .81296 .23138 Mtetra
.428 .692 .974 r
.81296 .23138 .81373 .23229 .81567 .23222 .81491 .23143 Mtetra
.823 .387 0 r
.81491 .23143 .81567 .23222 .81807 .23687 .81736 .23656 Mtetra
.971 .657 .302 r
.81736 .23656 .81807 .23687 .84016 .44562 .83937 .44492 Mtetra
.798 .342 0 r
.83937 .44492 .84016 .44562 .84275 .4507 .84191 .44959 Mtetra
.299 .581 .94 r
.84191 .44959 .84275 .4507 .8449 .45123 .84406 .45008 Mtetra
.65 .763 .932 r
.84406 .45008 .8449 .45123 .84693 .45059 .8461 .44944 Mtetra
.83 .82 .839 r
.8461 .44944 .84693 .45059 .84886 .44878 .84802 .44764 Mtetra
.976 .788 .586 r
.84802 .44764 .84886 .44878 .85035 .44263 .84951 .44148 Mtetra
.974 .667 .312 r
.84951 .44148 .85035 .44263 .83141 .23293 .83062 .23171 Mtetra
.973 .774 .576 r
.83062 .23171 .83141 .23293 .83276 .22675 .83197 .22553 Mtetra
.765 .757 .845 r
.22027 .43406 .2213 .43503 .22288 .43393 .22184 .43295 Mtetra
.63 .73 .919 r
.22184 .43295 .22288 .43393 .22439 .43354 .22336 .43255 Mtetra
.493 .679 .949 r
.22336 .43255 .22439 .43354 .22587 .43353 .22483 .43253 Mtetra
.748 .751 .855 r
.22483 .43253 .22587 .43353 .22743 .43258 .2264 .43154 Mtetra
.688 .732 .885 r
.2264 .43154 .22743 .43258 .22897 .43196 .22794 .4309 Mtetra
.454 .647 .941 r
.22794 .4309 .22897 .43196 .23044 .432 .22941 .43098 Mtetra
.939 .586 .317 r
.22941 .43098 .23044 .432 .23154 .43622 .23044 .43606 Mtetra
.937 .682 .525 r
.23044 .43606 .23154 .43622 .21533 .63386 .21407 .63462 Mtetra
.857 .51 .394 r
.21407 .63462 .21533 .63386 .21644 .63908 .21525 .63908 Mtetra
.055 0 0 r
.21525 .63908 .21644 .63908 .21798 .63946 .21682 .63913 Mtetra
.709 .906 .965 r
.21682 .63913 .21798 .63946 .21961 .63897 .21847 .63832 Mtetra
.796 .831 .879 r
.21847 .63832 .21961 .63897 .22127 .63807 .22017 .63707 Mtetra
.694 .754 .897 r
.22017 .63707 .22127 .63807 .2229 .63748 .22181 .63636 Mtetra
.67 .728 .893 r
.22181 .63636 .2229 .63748 .22454 .63688 .22345 .63577 Mtetra
.654 .724 .9 r
.22345 .63577 .22454 .63688 .22618 .63628 .22508 .63524 Mtetra
.618 .729 .926 r
.22508 .63524 .22618 .63628 .22781 .63575 .2267 .63486 Mtetra
.595 .755 .954 r
.2267 .63486 .22781 .63575 .22944 .63524 .22832 .63453 Mtetra
.576 .789 .98 r
.22832 .63453 .22944 .63524 .23107 .63476 .22994 .6342 Mtetra
.591 .83 .99 r
.22994 .6342 .23107 .63476 .2327 .63429 .23156 .63378 Mtetra
.594 .844 .992 r
.23156 .63378 .2327 .63429 .23433 .63384 .23319 .63334 Mtetra
.597 .847 .992 r
.23319 .63334 .23433 .63384 .23596 .63339 .23482 .63288 Mtetra
.6 .846 .991 r
.23482 .63288 .23596 .63339 .23759 .63297 .23646 .63242 Mtetra
.601 .837 .989 r
.23646 .63242 .23759 .63297 .23922 .63253 .23809 .63197 Mtetra
.592 .831 .99 r
.23809 .63197 .23922 .63253 .24086 .63206 .23972 .63155 Mtetra
.536 .825 .999 r
.23972 .63155 .24086 .63206 .2425 .63146 .24135 .63122 Mtetra
.422 .836 .97 r
.24135 .63122 .2425 .63146 .24416 .6308 .24297 .63092 Mtetra
.229 .749 .795 r
.24297 .63092 .24416 .6308 .24581 .63016 .2446 .63059 Mtetra
0 0 0 r
.2446 .63059 .24581 .63016 .24745 .62964 .24624 .63017 Mtetra
.24624 .63017 .24745 .62964 .24909 .62917 .24788 .62969 Mtetra
.24788 .62969 .24909 .62917 .25073 .62873 .24952 .62917 Mtetra
.24952 .62917 .25073 .62873 .25237 .62826 .25118 .62858 Mtetra
.345 .818 .766 r
.25118 .62858 .25237 .62826 .25402 .62778 .25283 .62795 Mtetra
.441 .878 .861 r
.25283 .62795 .25402 .62778 .25566 .62728 .25449 .62732 Mtetra
.218 .741 .817 r
.25449 .62732 .25566 .62728 .25728 .6272 .25612 .62706 Mtetra
.428 .852 .951 r
.25612 .62706 .25728 .6272 .25891 .62688 .25776 .62668 Mtetra
.698 .932 .965 r
.25776 .62668 .25891 .62688 .2606 .62586 .25944 .62583 Mtetra
.934 .871 .752 r
.25944 .62583 .2606 .62586 .26258 .6211 .26128 .62282 Mtetra
.994 .844 .582 r
.26128 .62282 .26258 .6211 .2793 .42153 .26349 .61505 Mtetra
0 0 .18 r
.26349 .61505 .2793 .42153 .28133 .41477 .27995 .4186 Mtetra
.035 0 .145 r
.27995 .4186 .28133 .41477 .28297 .41308 .28167 .41594 Mtetra
.399 .057 .265 r
.28167 .41594 .28297 .41308 .28453 .4125 .28323 .41535 Mtetra
.51 .166 .319 r
.28323 .41535 .28453 .4125 .28607 .41232 .28475 .41544 Mtetra
.5 .165 .33 r
.28475 .41544 .28607 .41232 .28762 .41192 .28627 .41543 Mtetra
.47 .146 .335 r
.28627 .41543 .28762 .41192 .28918 .41142 .28782 .41513 Mtetra
.404 .09 .315 r
.28782 .41513 .28918 .41142 .29074 .41091 .2894 .41432 Mtetra
.076 0 .142 r
.2894 .41432 .29074 .41091 .2923 .41036 .29109 .41208 Mtetra
0 0 0 r
.29109 .41208 .2923 .41036 .29387 .40979 .29278 .40987 Mtetra
.88 .957 .85 r
.29278 .40987 .29387 .40979 .29544 .40921 .29443 .40814 Mtetra
.724 .74 .864 r
.29443 .40814 .29544 .40921 .297 .40863 .29602 .40728 Mtetra
.638 .668 .862 r
.29602 .40728 .297 .40863 .29857 .40807 .29758 .40684 Mtetra
.61 .679 .89 r
.29758 .40684 .29857 .40807 .30014 .40754 .29913 .40652 Mtetra
.717 .749 .877 r
.29913 .40652 .30014 .40754 .30172 .40678 .30072 .40571 Mtetra
.721 .74 .866 r
.30072 .40571 .30172 .40678 .3033 .40618 .30231 .40486 Mtetra
.638 .675 .868 r
.30231 .40486 .3033 .40618 .30484 .40612 .30388 .40442 Mtetra
.077 .305 .788 r
.30388 .40442 .30484 .40612 .30619 .40876 .30534 .40555 Mtetra
0 0 .272 r
.30534 .40555 .30619 .40876 .29449 .60581 .30659 .40971 Mtetra
0 0 .218 r
.30659 .40971 .29449 .60581 .29557 .61412 .29493 .60653 Mtetra
.124 .073 .523 r
.29493 .60653 .29557 .61412 .29713 .61533 .29625 .6113 Mtetra
.362 .317 .673 r
.29625 .6113 .29713 .61533 .29879 .61497 .2978 .61271 Mtetra
.44 .471 .796 r
.2978 .61271 .29879 .61497 .30049 .61412 .29941 .6132 Mtetra
.438 .688 .97 r
.29941 .6132 .30049 .61412 .30215 .61382 .30105 .61324 Mtetra
.583 .828 .991 r
.30105 .61324 .30215 .61382 .30381 .61359 .30272 .61282 Mtetra
.754 .819 .903 r
.30272 .61282 .30381 .61359 .30551 .61273 .30443 .61181 Mtetra
.869 .778 .758 r
.30443 .61181 .30551 .61273 .30739 .60906 .30625 .60924 Mtetra
.965 .806 .635 r
.30625 .60924 .30739 .60906 .32148 .41122 .30828 .60308 Mtetra
0 0 .201 r
.30828 .60308 .32148 .41122 .32368 .40088 .32233 .40543 Mtetra
0 0 0 r
.32233 .40543 .32368 .40088 .32537 .39865 .32419 .40045 Mtetra
.32419 .40045 .32537 .39865 .32696 .39801 .32588 .39827 Mtetra
.794 .996 .863 r
.32588 .39827 .32696 .39801 .32852 .39784 .32752 .39687 Mtetra
.716 .76 .888 r
.32752 .39687 .32852 .39784 .33009 .39755 .32912 .39608 Mtetra
.628 .648 .851 r
.32912 .39608 .33009 .39755 .33168 .39707 .3307 .39567 Mtetra
.592 .644 .871 r
.3307 .39567 .33168 .39707 .33326 .39657 .33227 .39542 Mtetra
.622 .7 .9 r
.33227 .39542 .33326 .39657 .33485 .396 .33385 .39504 Mtetra
.663 .752 .916 r
.33385 .39504 .33485 .396 .33645 .39538 .33544 .3945 Mtetra
.678 .772 .922 r
.33544 .3945 .33645 .39538 .33804 .39478 .33704 .3939 Mtetra
.741 .784 .888 r
.33704 .3939 .33804 .39478 .33964 .394 .33865 .39299 Mtetra
.74 .758 .867 r
.33865 .39299 .33964 .394 .34125 .39329 .34027 .39204 Mtetra
.661 .694 .871 r
.34027 .39204 .34125 .39329 .34282 .39311 .34186 .39149 Mtetra
.229 .415 .838 r
.34186 .39149 .34282 .39311 .34427 .39514 .34338 .3923 Mtetra
0 0 .352 r
.34338 .3923 .34427 .39514 .33502 .58942 .34474 .39591 Mtetra
0 0 .237 r
.34474 .39591 .33502 .58942 .33604 .60121 .33541 .59243 Mtetra
.094 .041 .501 r
.33541 .59243 .33604 .60121 .33761 .60287 .33675 .59834 Mtetra
.394 .324 .66 r
.33675 .59834 .33761 .60287 .3393 .60255 .33834 .59974 Mtetra
.476 .451 .751 r
.33834 .59974 .3393 .60255 .34102 .60168 .33999 .60019 Mtetra
.559 .631 .879 r
.33999 .60019 .34102 .60168 .34274 .60091 .34167 .60006 Mtetra
.636 .782 .951 r
.34167 .60006 .34274 .60091 .34444 .6004 .34338 .59956 Mtetra
.677 .796 .938 r
.34338 .59956 .34444 .6004 .34615 .59986 .34509 .59891 Mtetra
.646 .766 .936 r
.34509 .59891 .34615 .59986 .34786 .59922 .34679 .59839 Mtetra
.586 .773 .969 r
.34679 .59839 .34786 .59922 .34958 .59851 .34849 .59805 Mtetra
.518 .836 .999 r
.34849 .59805 .34958 .59851 .35129 .59781 .35019 .5977 Mtetra
.404 .846 .93 r
.35019 .5977 .35129 .59781 .35301 .5972 .35189 .5973 Mtetra
.335 .817 .84 r
.35189 .5973 .35301 .5972 .35471 .59671 .3536 .59682 Mtetra
.344 .823 .838 r
.3536 .59682 .35471 .59671 .35642 .59625 .35531 .59632 Mtetra
.374 .84 .865 r
.35531 .59632 .35642 .59625 .35813 .59576 .35703 .59582 Mtetra
.381 .844 .872 r
.35703 .59582 .35813 .59576 .35984 .59523 .35874 .59532 Mtetra
.366 .836 .856 r
.35874 .59532 .35984 .59523 .36156 .59472 .36045 .59481 Mtetra
.372 .839 .859 r
.36045 .59481 .36156 .59472 .36327 .59432 .36217 .59429 Mtetra
.441 .872 .918 r
.36217 .59429 .36327 .59432 .36497 .59402 .36389 .59378 Mtetra
.539 .889 .981 r
.36389 .59378 .36497 .59402 .36668 .59371 .3656 .59326 Mtetra
.558 .854 .997 r
.3656 .59326 .36668 .59371 .36839 .59332 .36732 .59282 Mtetra
.546 .84 .999 r
.36732 .59282 .36839 .59332 .37011 .59283 .36903 .59243 Mtetra
.604 .883 .991 r
.36903 .59243 .37011 .59283 .37183 .5923 .37076 .59187 Mtetra
.778 .901 .928 r
.37076 .59187 .37183 .5923 .37356 .59176 .37251 .59073 Mtetra
.836 .778 .796 r
.37251 .59073 .37356 .59176 .37528 .59122 .3743 .58876 Mtetra
.778 .638 .706 r
.3743 .58876 .37528 .59122 .377 .59068 .37611 .58627 Mtetra
.675 .517 .664 r
.37611 .58627 .377 .59068 .37872 .59037 .37788 .58452 Mtetra
.555 .411 .64 r
.37788 .58452 .37872 .59037 .38043 .59022 .37959 .58446 Mtetra
.585 .433 .641 r
.37959 .58446 .38043 .59022 .38216 .58957 .38131 .58393 Mtetra
.735 .539 .628 r
.38131 .58393 .38216 .58957 .38397 .58711 .38319 .57988 Mtetra
.948 .682 .5 r
.38319 .57988 .38397 .58711 .38611 .57669 .39309 .38069 Mtetra
.553 .331 .533 r
.39309 .38069 .38611 .57669 .39583 .37779 .39493 .37494 Mtetra
.752 .601 .689 r
.39493 .37494 .39583 .37779 .39757 .37441 .39663 .37262 Mtetra
.676 .632 .798 r
.39663 .37262 .39757 .37441 .39921 .37358 .39826 .37186 Mtetra
.612 .611 .826 r
.39826 .37186 .39921 .37358 .40083 .3733 .39988 .37151 Mtetra
.592 .593 .821 r
.39988 .37151 .40083 .3733 .40245 .37302 .4015 .37126 Mtetra
.618 .609 .82 r
.4015 .37126 .40245 .37302 .40408 .37233 .40313 .37088 Mtetra
.624 .653 .858 r
.40313 .37088 .40408 .37233 .40572 .37164 .40475 .37048 Mtetra
.65 .713 .894 r
.40475 .37048 .40572 .37164 .40735 .371 .40638 .36998 Mtetra
.688 .75 .899 r
.40638 .36998 .40735 .371 .40899 .37047 .40802 .3693 Mtetra
.691 .725 .876 r
.40802 .3693 .40899 .37047 .41062 .36995 .40966 .3686 Mtetra
.69 .694 .849 r
.40966 .3686 .41062 .36995 .41225 .3694 .4113 .36786 Mtetra
.682 .664 .826 r
.4113 .36786 .41225 .3694 .41389 .3688 .41295 .36712 Mtetra
.651 .635 .821 r
.41295 .36712 .41389 .3688 .41553 .36819 .41458 .36655 Mtetra
.592 .613 .842 r
.41458 .36655 .41553 .36819 .41717 .36745 .41621 .3663 Mtetra
.377 .595 .931 r
.41621 .3663 .41717 .36745 .41883 .36654 .41782 .36659 Mtetra
.618 .063 0 r
.41782 .36659 .41883 .36654 .42046 .36606 .41941 .36764 Mtetra
.807 .445 .37 r
.41941 .36764 .42046 .36606 .42206 .36693 .42092 .37134 Mtetra
.952 .677 .481 r
.42092 .37134 .42206 .36693 .42346 .37386 .41617 .57035 Mtetra
.549 .324 .526 r
.41617 .57035 .42346 .37386 .41884 .57411 .41773 .57562 Mtetra
.683 .277 .269 r
.41773 .57562 .41884 .57411 .42048 .57728 .41942 .57718 Mtetra
.271 .77 .883 r
.41942 .57718 .42048 .57728 .42222 .57713 .42117 .57693 Mtetra
.615 .925 .971 r
.42117 .57693 .42222 .57713 .42398 .57633 .42293 .57621 Mtetra
.643 .945 .955 r
.42293 .57621 .42398 .57633 .42575 .57543 .42469 .57537 Mtetra
.473 .886 .929 r
.42469 .57537 .42575 .57543 .4275 .57506 .42645 .5748 Mtetra
.558 .897 .981 r
.42645 .5748 .4275 .57506 .42925 .57469 .42821 .57423 Mtetra
.589 .867 .994 r
.42821 .57423 .42925 .57469 .43101 .57427 .42997 .57371 Mtetra
.557 .832 .997 r
.42997 .57371 .43101 .57427 .43277 .57376 .43173 .57331 Mtetra
.598 .874 .993 r
.43173 .57331 .43277 .57376 .43453 .57321 .43349 .57276 Mtetra
.737 .904 .953 r
.43349 .57276 .43453 .57321 .43629 .57264 .43527 .57179 Mtetra
.849 .816 .817 r
.43527 .57179 .43629 .57264 .43806 .57208 .43707 .56988 Mtetra
.792 .66 .717 r
.43707 .56988 .43806 .57208 .43982 .57151 .43888 .5674 Mtetra
.713 .548 .664 r
.43888 .5674 .43982 .57151 .44159 .57107 .44069 .56503 Mtetra
.557 .41 .638 r
.44069 .56503 .44159 .57107 .44334 .57097 .44245 .56494 Mtetra
.575 .423 .638 r
.44245 .56494 .44334 .57097 .44511 .57042 .44421 .56456 Mtetra
.682 .5 .633 r
.44421 .56456 .44511 .57042 .44691 .56863 .44602 .56197 Mtetra
.954 .683 .483 r
.44602 .56197 .44691 .56863 .44884 .56098 .45233 .36209 Mtetra
.555 .333 .533 r
.45233 .36209 .44884 .56098 .45504 .35856 .45414 .35509 Mtetra
.753 .583 .664 r
.45414 .35509 .45504 .35856 .45679 .35413 .45586 .35226 Mtetra
.687 .631 .788 r
.45586 .35226 .45679 .35413 .45846 .35314 .45753 .35138 Mtetra
.624 .615 .82 r
.45753 .35138 .45846 .35314 .46012 .35277 .45919 .35095 Mtetra
.587 .59 .823 r
.45919 .35095 .46012 .35277 .46178 .35258 .46085 .35072 Mtetra
.617 .601 .812 r
.46085 .35072 .46178 .35258 .46345 .35188 .46251 .35033 Mtetra
.619 .641 .85 r
.46251 .35033 .46345 .35188 .46512 .35118 .46418 .34995 Mtetra
.635 .698 .891 r
.46418 .34995 .46512 .35118 .46679 .35051 .46584 .34949 Mtetra
.681 .754 .907 r
.46584 .34949 .46679 .35051 .46846 .34995 .46751 .34884 Mtetra
.688 .739 .89 r
.46751 .34884 .46846 .34995 .47013 .34942 .46919 .34815 Mtetra
.681 .708 .868 r
.46919 .34815 .47013 .34942 .4718 .34889 .47086 .34746 Mtetra
.659 .675 .854 r
.47086 .34746 .4718 .34889 .47347 .34834 .47254 .34688 Mtetra
.654 .668 .851 r
.47254 .34688 .47347 .34834 .47515 .34779 .47421 .34631 Mtetra
.652 .665 .85 r
.47421 .34631 .47515 .34779 .47682 .34725 .47588 .34576 Mtetra
.652 .664 .849 r
.47588 .34576 .47682 .34725 .4785 .34671 .47756 .34521 Mtetra
.651 .66 .846 r
.47756 .34521 .4785 .34671 .48017 .34618 .47924 .34465 Mtetra
.651 .657 .843 r
.47924 .34465 .48017 .34618 .48185 .34565 .48092 .3441 Mtetra
.651 .654 .84 r
.48092 .3441 .48185 .34565 .48353 .3451 .4826 .34353 Mtetra
.652 .653 .839 r
.4826 .34353 .48353 .3451 .48521 .34454 .48428 .34297 Mtetra
.652 .653 .838 r
.48428 .34297 .48521 .34454 .48689 .34397 .48596 .3424 Mtetra
.653 .653 .838 r
.48596 .3424 .48689 .34397 .48857 .3434 .48764 .34183 Mtetra
.48764 .34183 .48857 .3434 .49026 .34282 .48932 .34126 Mtetra
.653 .654 .838 r
.48932 .34126 .49026 .34282 .49194 .34223 .49101 .34068 Mtetra
.657 .657 .839 r
.49101 .34068 .49194 .34223 .49363 .34163 .49269 .34008 Mtetra
.655 .657 .841 r
.49269 .34008 .49363 .34163 .49531 .34102 .49438 .3395 Mtetra
.65 .659 .846 r
.49438 .3395 .49531 .34102 .497 .34042 .49607 .33895 Mtetra
.633 .66 .859 r
.49607 .33895 .497 .34042 .49869 .33982 .49776 .3385 Mtetra
.632 .682 .88 r
.49776 .3385 .49869 .33982 .50038 .33923 .49945 .33805 Mtetra
.636 .712 .902 r
.49945 .33805 .50038 .33923 .50207 .33862 .50114 .33759 Mtetra
.66 .749 .916 r
.50114 .33759 .50207 .33862 .50376 .33797 .50283 .33702 Mtetra
.672 .771 .925 r
.50283 .33702 .50376 .33797 .50545 .33733 .50452 .33641 Mtetra
.683 .779 .924 r
.50452 .33641 .50545 .33733 .50715 .33674 .50622 .33574 Mtetra
.759 .783 .873 r
.50622 .33574 .50715 .33674 .50884 .33585 .50791 .33466 Mtetra
.705 .733 .872 r
.50791 .33466 .50884 .33585 .51054 .33533 .50961 .33385 Mtetra
.597 .643 .867 r
.50961 .33385 .51054 .33533 .51223 .33553 .51131 .33356 Mtetra
0 .039 .609 r
.51131 .33356 .51223 .33553 .51391 .34056 .51299 .33586 Mtetra
.789 .527 0 r
.51299 .33586 .51391 .34056 .51502 .54348 .51466 .3457 Mtetra
0 0 .342 r
.51466 .3457 .51502 .54348 .51682 .54813 .51584 .54224 Mtetra
.531 .396 .641 r
.51584 .54224 .51682 .54813 .51863 .54828 .51765 .54254 Mtetra
.602 .447 .643 r
.51765 .54254 .51863 .54828 .52045 .54763 .51947 .54171 Mtetra
.607 .448 .64 r
.51947 .54171 .52045 .54763 .52227 .54659 .52129 .54075 Mtetra
.43 .326 .636 r
.52129 .54075 .52227 .54659 .52409 .54607 .5231 .54232 Mtetra
.395 .357 .698 r
.5231 .54232 .52409 .54607 .52591 .54556 .52492 .54356 Mtetra
.363 .463 .829 r
.52492 .54356 .52591 .54556 .52773 .545 .52675 .54428 Mtetra
.518 .784 .993 r
.52675 .54428 .52773 .545 .52956 .5443 .52857 .54403 Mtetra
.529 .888 .978 r
.52857 .54403 .52956 .5443 .53138 .54356 .5304 .54348 Mtetra
.52 .909 .932 r
.5304 .54348 .53138 .54356 .53321 .54282 .53223 .5428 Mtetra
.177 .712 .809 r
.53223 .5428 .53321 .54282 .53504 .54272 .53406 .54258 Mtetra
.41 .849 .932 r
.53406 .54258 .53504 .54272 .53687 .54234 .53589 .54214 Mtetra
.688 .953 .954 r
.53589 .54214 .53687 .54234 .53869 .54121 .53772 .54116 Mtetra
.957 .912 .729 r
.53772 .54116 .53869 .54121 .5405 .53563 .53954 .53796 Mtetra
.953 .844 .418 r
.53954 .53796 .5405 .53563 .54127 .33107 .54133 .53005 Mtetra
0 0 .338 r
.54133 .53005 .54127 .33107 .54296 .32486 .54207 .32855 Mtetra
0 0 .105 r
.54207 .32855 .54296 .32486 .54467 .32336 .54377 .32463 Mtetra
0 0 0 r
.54377 .32463 .54467 .32336 .54639 .32276 .54548 .32257 Mtetra
.812 .964 .906 r
.54548 .32257 .54639 .32276 .54811 .32254 .54719 .32121 Mtetra
.687 .706 .863 r
.54719 .32121 .54811 .32254 .54983 .32196 .54891 .32048 Mtetra
.632 .66 .859 r
.54891 .32048 .54983 .32196 .55155 .32134 .55063 .32002 Mtetra
.609 .676 .889 r
.55063 .32002 .55155 .32134 .55327 .32077 .55236 .31966 Mtetra
.733 .761 .875 r
.55236 .31966 .55327 .32077 .55499 .31991 .55408 .31871 Mtetra
.712 .737 .87 r
.55408 .31871 .55499 .31991 .55672 .31931 .5558 .31785 Mtetra
.622 .659 .866 r
.5558 .31785 .55672 .31931 .55845 .31933 .55753 .31744 Mtetra
.074 .277 .765 r
.55753 .31744 .55845 .31933 .56022 .32286 .55928 .31895 Mtetra
0 0 .409 r
.55928 .31895 .56022 .32286 .56435 .52612 .56108 .32425 Mtetra
0 0 .362 r
.56108 .32425 .56435 .52612 .56628 .53237 .56524 .52556 Mtetra
.279 .209 .596 r
.56524 .52556 .56628 .53237 .56815 .53303 .56714 .52915 Mtetra
.413 .366 .696 r
.56714 .52915 .56815 .53303 .57 .5325 .56901 .53033 Mtetra
.475 .511 .815 r
.56901 .53033 .57 .5325 .57184 .53152 .57088 .53067 Mtetra
.571 .779 .977 r
.57088 .53067 .57184 .53152 .5737 .5309 .57274 .53032 Mtetra
.654 .871 .98 r
.57274 .53032 .5737 .5309 .57555 .53038 .57459 .52963 Mtetra
.702 .844 .951 r
.57459 .52963 .57555 .53038 .57741 .52981 .57644 .52881 Mtetra
.482 .702 .966 r
.57644 .52881 .57741 .52981 .57927 .52956 .57831 .52876 Mtetra
.489 .755 .989 r
.57831 .52876 .57927 .52956 .58113 .52908 .58018 .5286 Mtetra
.692 .905 .971 r
.58018 .5286 .58113 .52908 .58298 .5279 .58203 .52774 Mtetra
.976 .861 .661 r
.58203 .52774 .58298 .5279 .58476 .52317 .58383 .52332 Mtetra
.973 .69 .43 r
.58383 .52332 .58476 .52317 .58286 .31848 .58196 .31789 Mtetra
.973 .765 .561 r
.58196 .31789 .58286 .31848 .58447 .31105 .58357 .30956 Mtetra
.803 .723 .776 r
.58357 .30956 .58447 .31105 .58619 .30921 .58529 .30773 Mtetra
.637 .666 .861 r
.58529 .30773 .58619 .30921 .58793 .30859 .58703 .30724 Mtetra
.523 .633 .901 r
.58703 .30724 .58793 .30859 .58969 .30839 .58879 .30721 Mtetra
.611 .706 .912 r
.58879 .30721 .58969 .30839 .59144 .30789 .59054 .30684 Mtetra
.662 .752 .917 r
.59054 .30684 .59144 .30789 .59318 .30723 .59229 .30624 Mtetra
.674 .769 .922 r
.59229 .30624 .59318 .30723 .59493 .30661 .59404 .30559 Mtetra
.763 .789 .874 r
.59404 .30559 .59493 .30661 .59667 .30574 .59577 .30447 Mtetra
.731 .734 .853 r
.59577 .30447 .59667 .30574 .59842 .30505 .59752 .30346 Mtetra
.615 .64 .852 r
.59752 .30346 .59842 .30505 .60018 .30495 .59927 .30307 Mtetra
0 .006 .581 r
.59927 .30307 .60018 .30495 .60202 .30783 .6011 .30563 Mtetra
.974 .682 .406 r
.6011 .30563 .60202 .30783 .60892 .51115 .60795 .50921 Mtetra
.92 .561 .122 r
.60795 .50921 .60892 .51115 .611 .51855 .61006 .51787 Mtetra
0 .167 .607 r
.61006 .51787 .611 .51855 .61293 .51997 .61199 .51918 Mtetra
.588 .802 .981 r
.61199 .51918 .61293 .51997 .61482 .51975 .61387 .51875 Mtetra
.788 .812 .872 r
.61387 .51875 .61482 .51975 .61668 .51848 .61573 .5174 Mtetra
.892 .798 .75 r
.61573 .5174 .61668 .51848 .61847 .51449 .61756 .51456 Mtetra
.993 .837 .584 r
.61756 .51456 .61847 .51449 .61458 .3121 .61928 .50837 Mtetra
0 0 .363 r
.61928 .50837 .61458 .3121 .61603 .30075 .61532 .30563 Mtetra
0 0 .194 r
.61532 .30563 .61603 .30075 .61775 .29845 .61695 .30045 Mtetra
0 0 0 r
.61695 .30045 .61775 .29845 .61951 .29775 .61867 .29825 Mtetra
.568 .904 .669 r
.61867 .29825 .61951 .29775 .62128 .29754 .62041 .29682 Mtetra
.732 .851 .937 r
.62041 .29682 .62128 .29754 .62306 .29716 .62217 .29591 Mtetra
.661 .716 .889 r
.62217 .29591 .62306 .29716 .62482 .29659 .62394 .29531 Mtetra
.63 .698 .894 r
.62394 .29531 .62482 .29659 .62659 .29601 .62571 .29485 Mtetra
.7 .747 .888 r
.62571 .29485 .62659 .29601 .62835 .29506 .62747 .29406 Mtetra
.717 .785 .906 r
.62747 .29406 .62835 .29506 .63011 .29412 .62924 .29321 Mtetra
.617 .77 .954 r
.62924 .29321 .63011 .29412 .63189 .29375 .63102 .29276 Mtetra
0 .341 .812 r
.63102 .29276 .63189 .29375 .63376 .29587 .63285 .29383 Mtetra
.676 .318 0 r
.63285 .29383 .63376 .29587 .64269 .49695 .63481 .29841 Mtetra
0 0 .386 r
.63481 .29841 .64269 .49695 .64499 .5077 .64383 .50027 Mtetra
.253 .187 .585 r
.64383 .50027 .64499 .5077 .64697 .50924 .64591 .50467 Mtetra
.439 .363 .675 r
.64591 .50467 .64697 .50924 .64888 .50886 .64788 .50588 Mtetra
.497 .463 .75 r
.64788 .50588 .64888 .50886 .65078 .50792 .64982 .50627 Mtetra
.458 .569 .879 r
.64982 .50627 .65078 .50792 .65268 .50732 .65176 .50654 Mtetra
.429 .734 .99 r
.65176 .50654 .65268 .50732 .6546 .5069 .65369 .50649 Mtetra
.651 .916 .979 r
.65369 .50649 .6546 .5069 .65649 .50589 .65559 .50569 Mtetra
.961 .911 .721 r
.65559 .50569 .65649 .50589 .65828 .5024 .6574 .50241 Mtetra
.984 .717 .435 r
.6574 .50241 .65828 .5024 .65207 .30237 .65813 .47269 Mtetra
0 0 .36 r
.65813 .47269 .65207 .30237 .65332 .28841 .65243 .28692 Mtetra
.861 .742 .731 r
.65243 .28692 .65332 .28841 .65502 .28575 .65413 .28422 Mtetra
.665 .673 .848 r
.65413 .28422 .65502 .28575 .6568 .28497 .65592 .28355 Mtetra
.55 .638 .89 r
.65592 .28355 .6568 .28497 .6586 .28469 .65773 .28343 Mtetra
.627 .702 .9 r
.65773 .28343 .6586 .28469 .66039 .28405 .65952 .28298 Mtetra
.71 .771 .899 r
.65952 .28298 .66039 .28405 .66217 .28312 .66131 .28214 Mtetra
.627 .763 .944 r
.66131 .28214 .66217 .28312 .66397 .28271 .6631 .28166 Mtetra
.098 .451 .884 r
.6631 .28166 .66397 .28271 .66586 .28441 .66496 .28249 Mtetra
0 0 .363 r
.66496 .28249 .66586 .28441 .67669 .48031 .66697 .28641 Mtetra
0 0 .392 r
.66697 .28641 .67669 .48031 .6794 .4967 .67814 .48833 Mtetra
.223 .158 .569 r
.67814 .48833 .6794 .4967 .68144 .49865 .68035 .49378 Mtetra
.436 .354 .666 r
.68035 .49378 .68144 .49865 .68338 .49832 .68236 .49512 Mtetra
.496 .452 .738 r
.68236 .49512 .68338 .49832 .68529 .49738 .68434 .49556 Mtetra
.482 .56 .858 r
.68434 .49556 .68529 .49738 .68721 .49664 .68631 .49579 Mtetra
.433 .719 .985 r
.68631 .49579 .68721 .49664 .68915 .49621 .68827 .49577 Mtetra
.643 .91 .982 r
.68827 .49577 .68915 .49621 .69106 .4952 .6902 .495 Mtetra
.954 .926 .736 r
.6902 .495 .69106 .4952 .69286 .49192 .69201 .49195 Mtetra
.987 .725 .431 r
.69201 .49195 .69286 .49192 .68453 .29119 .69276 .46813 Mtetra
0 0 .375 r
.69276 .46813 .68453 .29119 .68565 .27718 .68478 .27573 Mtetra
.887 .753 .708 r
.68478 .27573 .68565 .27718 .68733 .27408 .68646 .27255 Mtetra
.722 .7 .828 r
.68646 .27255 .68733 .27408 .68911 .27292 .68824 .2715 Mtetra
.552 .64 .891 r
.68824 .2715 .68911 .27292 .69094 .27267 .69008 .27137 Mtetra
0 .238 .754 r
.69008 .27137 .69094 .27267 .69286 .27415 .692 .27293 Mtetra
.928 .558 .149 r
.692 .27293 .69286 .27415 .69522 .28357 .69435 .28207 Mtetra
.976 .674 .365 r
.69435 .28207 .69522 .28357 .70836 .48704 .70745 .48588 Mtetra
.578 .121 0 r
.70745 .48588 .70836 .48704 .71049 .48984 .70959 .48871 Mtetra
.435 .654 .952 r
.70959 .48871 .71049 .48984 .71248 .48996 .71157 .48884 Mtetra
.724 .783 .9 r
.71157 .48884 .71248 .48996 .71441 .48897 .7135 .48786 Mtetra
.901 .807 .745 r
.7135 .48786 .71441 .48897 .71622 .48604 .71532 .48492 Mtetra
.978 .739 .506 r
.71532 .48492 .71622 .48604 .71751 .47412 .7166 .47288 Mtetra
.977 .681 .379 r
.7166 .47288 .71751 .47412 .70747 .27056 .70662 .26939 Mtetra
.918 .787 .7 r
.70662 .26939 .70747 .27056 .70913 .26711 .70828 .26595 Mtetra
.718 .76 .886 r
.70828 .26595 .70913 .26711 .71093 .26621 .71009 .26505 Mtetra
.596 .712 .925 r
.71009 .26505 .71093 .26621 .71277 .26586 .71193 .2647 Mtetra
.631 .728 .917 r
.71193 .2647 .71277 .26586 .7146 .26537 .71376 .26422 Mtetra
.738 .768 .877 r
.71376 .26422 .7146 .26537 .7164 .26435 .71556 .26319 Mtetra
.649 .736 .913 r
.71556 .26319 .7164 .26435 .71823 .26378 .71739 .26263 Mtetra
.098 .424 .869 r
.71739 .26263 .71823 .26378 .72016 .26474 .71932 .26359 Mtetra
.911 .53 .104 r
.71932 .26359 .72016 .26474 .72255 .27283 .72171 .27176 Mtetra
.975 .671 .352 r
.72171 .27176 .72255 .27283 .73763 .47763 .73674 .47656 Mtetra
.604 .137 0 r
.73674 .47656 .73763 .47763 .73982 .48055 .73893 .47947 Mtetra
.549 .724 .955 r
.73893 .47947 .73982 .48055 .74181 .48032 .74092 .47923 Mtetra
.706 .786 .914 r
.74092 .47923 .74181 .48032 .74376 .47943 .74287 .47835 Mtetra
.675 .779 .928 r
.74287 .47835 .74376 .47943 .74571 .47862 .74484 .47762 Mtetra
.441 .69 .97 r
.74484 .47762 .74571 .47862 .74772 .47852 .74685 .47766 Mtetra
.601 .801 .976 r
.74685 .47766 .74772 .47852 .74969 .47789 .74883 .47717 Mtetra
.879 .888 .836 r
.74883 .47717 .74969 .47789 .75155 .47568 .75071 .47513 Mtetra
.991 .785 .529 r
.75071 .47513 .75155 .47568 .75291 .4662 .75215 .46674 Mtetra
.978 .68 .357 r
.75215 .46674 .75291 .4662 .7405 .25991 .73969 .25905 Mtetra
.96 .815 .657 r
.73969 .25905 .7405 .25991 .7421 .25594 .74128 .25482 Mtetra
.736 .776 .885 r
.74128 .25482 .7421 .25594 .74392 .25496 .74309 .25381 Mtetra
.603 .719 .927 r
.74309 .25381 .74392 .25496 .74578 .25458 .74496 .25343 Mtetra
.6 .718 .927 r
.74496 .25343 .74578 .25458 .74765 .25421 .74682 .25306 Mtetra
.744 .775 .878 r
.74682 .25306 .74765 .25421 .74946 .25315 .74864 .252 Mtetra
.659 .743 .912 r
.74864 .252 .74946 .25315 .75131 .25255 .75049 .25139 Mtetra
.226 .508 .907 r
.75049 .25139 .75131 .25255 .75326 .25324 .75244 .25208 Mtetra
.888 .498 .047 r
.75244 .25208 .75326 .25324 .75572 .2607 .75489 .25957 Mtetra
.975 .667 .334 r
.75489 .25957 .75572 .2607 .77317 .46668 .7723 .46557 Mtetra
.651 .196 0 r
.7723 .46557 .77317 .46668 .77547 .4701 .77459 .46899 Mtetra
.384 .633 .953 r
.77459 .46899 .77547 .4701 .77752 .47036 .77665 .46925 Mtetra
.693 .781 .918 r
.77665 .46925 .77752 .47036 .7795 .46954 .77863 .46842 Mtetra
.873 .82 .793 r
.77863 .46842 .7795 .46954 .78136 .46722 .78049 .4661 Mtetra
.978 .767 .552 r
.78049 .4661 .78136 .46722 .78279 .45938 .78192 .45826 Mtetra
.977 .675 .347 r
.78192 .45826 .78279 .45938 .76834 .25115 .76752 .24998 Mtetra
.95 .784 .641 r
.76752 .24998 .76834 .25115 .76988 .24653 .76906 .24535 Mtetra
.746 .772 .874 r
.76906 .24535 .76988 .24653 .77171 .24545 .77089 .24426 Mtetra
.618 .722 .92 r
.77089 .24426 .77171 .24545 .77359 .24501 .77277 .24382 Mtetra
.586 .706 .926 r
.77277 .24382 .77359 .24501 .77548 .2447 .77466 .24351 Mtetra
.747 .772 .873 r
.77466 .24351 .77548 .2447 .7773 .2436 .77649 .24241 Mtetra
.671 .743 .905 r
.77649 .24241 .7773 .2436 .77917 .24292 .77835 .24173 Mtetra
.357 .582 .928 r
.77835 .24173 .77917 .24292 .78112 .24333 .78031 .24214 Mtetra
.832 .426 0 r
.78031 .24214 .78112 .24333 .78355 .24941 .78274 .24818 Mtetra
.973 .663 .318 r
.78274 .24818 .78355 .24941 .80308 .4568 .80222 .45564 Mtetra
.688 .246 0 r
.80222 .45564 .80308 .4568 .80548 .46078 .80462 .45964 Mtetra
.349 .605 .944 r
.80462 .45964 .80548 .46078 .80757 .46114 .80672 .46001 Mtetra
.677 .774 .923 r
.80672 .46001 .80757 .46114 .80958 .46039 .80872 .45925 Mtetra
.861 .82 .806 r
.80872 .45925 .80958 .46039 .81146 .45829 .8106 .45709 Mtetra
.978 .765 .547 r
.8106 .45709 .81146 .45829 .8129 .45112 .81198 .44919 Mtetra
.976 .671 .334 r
.81198 .44919 .8129 .45112 .79645 .24208 .79557 .24012 Mtetra
.91 .723 .637 r
.79557 .24012 .79645 .24208 .79793 .23697 .79709 .23536 Mtetra
.707 .69 .832 r
.79709 .23536 .79793 .23697 .79977 .23587 .79894 .23438 Mtetra
.588 .653 .881 r
.79894 .23438 .79977 .23587 .80167 .23546 .80085 .23409 Mtetra
.505 .631 .908 r
.80085 .23409 .80167 .23546 .8036 .23536 .80279 .23412 Mtetra
.649 .726 .905 r
.80279 .23412 .8036 .23536 .80549 .23474 .80468 .23354 Mtetra
.659 .738 .908 r
.80468 .23354 .80549 .23474 .80737 .2341 .80657 .23291 Mtetra
.676 .747 .904 r
.80657 .23291 .80737 .2341 .80925 .2334 .80845 .2322 Mtetra
.76 .777 .867 r
.80845 .2322 .80925 .2334 .81108 .23219 .81029 .23101 Mtetra
.693 .757 .901 r
.81029 .23101 .81108 .23219 .81296 .23138 .81216 .23022 Mtetra
.471 .653 .94 r
.81216 .23022 .81296 .23138 .81491 .23143 .81412 .23028 Mtetra
.776 .358 0 r
.81412 .23028 .81491 .23143 .81736 .23656 .81657 .23548 Mtetra
.971 .657 .299 r
.81657 .23548 .81736 .23656 .83937 .44492 .83853 .44384 Mtetra
.737 .298 0 r
.83853 .44384 .83937 .44492 .84191 .44959 .84107 .44845 Mtetra
.305 .582 .939 r
.84107 .44845 .84191 .44959 .84406 .45008 .84322 .44894 Mtetra
.651 .766 .933 r
.84322 .44894 .84406 .45008 .8461 .44944 .84526 .4483 Mtetra
.831 .822 .84 r
.84526 .4483 .8461 .44944 .84802 .44764 .84719 .44649 Mtetra
.976 .788 .586 r
.84719 .44649 .84802 .44764 .84951 .44148 .84868 .44033 Mtetra
.974 .667 .312 r
.84868 .44033 .84951 .44148 .83062 .23171 .82983 .2305 Mtetra
.973 .774 .576 r
.82983 .2305 .83062 .23171 .83197 .22553 .83117 .22432 Mtetra
.766 .757 .845 r
.21923 .43309 .22027 .43406 .22184 .43295 .22081 .43198 Mtetra
.631 .731 .92 r
.22081 .43198 .22184 .43295 .22336 .43255 .22232 .43157 Mtetra
.495 .682 .95 r
.22232 .43157 .22336 .43255 .22483 .43253 .2238 .43154 Mtetra
.75 .753 .855 r
.2238 .43154 .22483 .43253 .2264 .43154 .22537 .43054 Mtetra
.691 .742 .89 r
.22537 .43054 .2264 .43154 .22794 .4309 .22691 .4299 Mtetra
.451 .657 .949 r
.22691 .4299 .22794 .4309 .22941 .43098 .22838 .42997 Mtetra
.939 .583 .312 r
.22838 .42997 .22941 .43098 .23044 .43606 .22941 .43494 Mtetra
.939 .683 .524 r
.22941 .43494 .23044 .43606 .21407 .63462 .21297 .6336 Mtetra
.93 .556 .271 r
.21297 .6336 .21407 .63462 .21525 .63908 .21414 .63812 Mtetra
.438 .679 .966 r
.21414 .63812 .21525 .63908 .21682 .63913 .21571 .63818 Mtetra
.718 .767 .891 r
.21571 .63818 .21682 .63913 .21847 .63832 .21737 .63735 Mtetra
.779 .771 .846 r
.21737 .63735 .21847 .63832 .22017 .63707 .21906 .63608 Mtetra
.695 .759 .901 r
.21906 .63608 .22017 .63707 .22181 .63636 .22071 .63538 Mtetra
.669 .753 .913 r
.22071 .63538 .22181 .63636 .22345 .63577 .22235 .63479 Mtetra
.648 .75 .924 r
.22235 .63479 .22345 .63577 .22508 .63524 .22398 .63429 Mtetra
.599 .741 .944 r
.22398 .63429 .22508 .63524 .2267 .63486 .22559 .63396 Mtetra
.577 .746 .957 r
.22559 .63396 .2267 .63486 .22832 .63453 .22721 .63368 Mtetra
.573 .756 .965 r
.22721 .63368 .22832 .63453 .22994 .6342 .22882 .6334 Mtetra
.609 .778 .962 r
.22882 .6334 .22994 .6342 .23156 .63378 .23044 .633 Mtetra
.62 .787 .962 r
.23044 .633 .23156 .63378 .23319 .63334 .23207 .63257 Mtetra
.625 .792 .962 r
.23207 .63257 .23319 .63334 .23482 .63288 .23371 .63212 Mtetra
.628 .794 .962 r
.23371 .63212 .23482 .63288 .23646 .63242 .23534 .63166 Mtetra
.625 .794 .963 r
.23534 .63166 .23646 .63242 .23809 .63197 .23697 .63121 Mtetra
.616 .791 .965 r
.23697 .63121 .23809 .63197 .23972 .63155 .23861 .63078 Mtetra
.582 .78 .974 r
.23861 .63078 .23972 .63155 .24135 .63122 .24023 .63045 Mtetra
.576 .776 .974 r
.24023 .63045 .24135 .63122 .24297 .63092 .24186 .63014 Mtetra
.586 .778 .971 r
.24186 .63014 .24297 .63092 .2446 .63059 .24349 .6298 Mtetra
.618 .784 .961 r
.24349 .6298 .2446 .63059 .24624 .63017 .24513 .62937 Mtetra
.638 .787 .953 r
.24513 .62937 .24624 .63017 .24788 .62969 .24677 .62888 Mtetra
.654 .788 .946 r
.24677 .62888 .24788 .62969 .24952 .62917 .24842 .62834 Mtetra
.679 .789 .933 r
.24842 .62834 .24952 .62917 .25118 .62858 .25007 .6277 Mtetra
.688 .782 .923 r
.25007 .6277 .25118 .62858 .25283 .62795 .25174 .62703 Mtetra
.688 .773 .916 r
.25174 .62703 .25283 .62795 .25449 .62732 .2534 .62636 Mtetra
.621 .747 .937 r
.2534 .62636 .25449 .62732 .25612 .62706 .25504 .62595 Mtetra
.632 .722 .912 r
.25504 .62595 .25612 .62706 .25776 .62668 .25669 .62551 Mtetra
.685 .726 .881 r
.25669 .62551 .25776 .62668 .25944 .62583 .25835 .62483 Mtetra
.819 .769 .806 r
.25835 .62483 .25944 .62583 .26128 .62282 .2601 .62308 Mtetra
.936 .926 .772 r
.2601 .62308 .26128 .62282 .26349 .61505 .26192 .6204 Mtetra
.031 0 .193 r
.26192 .6204 .26349 .61505 .27995 .4186 .26382 .61666 Mtetra
.535 .312 .523 r
.26382 .61666 .27995 .4186 .28167 .41594 .26561 .61433 Mtetra
.538 .315 .524 r
.26561 .61433 .28167 .41594 .28323 .41535 .26726 .61382 Mtetra
.54 .316 .524 r
.26726 .61382 .28323 .41535 .28475 .41544 .26886 .61406 Mtetra
.541 .317 .524 r
.26886 .61406 .28475 .41544 .28627 .41543 .27043 .61469 Mtetra
.539 .316 .524 r
.27043 .61469 .28627 .41543 .28782 .41513 .27205 .61467 Mtetra
.537 .314 .524 r
.27205 .61467 .28782 .41513 .2894 .41432 .27377 .61328 Mtetra
0 0 .224 r
.27377 .61328 .2894 .41432 .29109 .41208 .28926 .42236 Mtetra
0 0 .043 r
.28926 .42236 .29109 .41208 .29278 .40987 .29162 .41088 Mtetra
.964 .94 .665 r
.29162 .41088 .29278 .40987 .29443 .40814 .2934 .40733 Mtetra
.795 .797 .854 r
.2934 .40733 .29443 .40814 .29602 .40728 .29502 .40606 Mtetra
.638 .69 .882 r
.29502 .40606 .29602 .40728 .29758 .40684 .29658 .40563 Mtetra
.566 .664 .904 r
.29658 .40563 .29758 .40684 .29913 .40652 .29813 .40546 Mtetra
.683 .734 .889 r
.29813 .40546 .29913 .40652 .30072 .40571 .2997 .40482 Mtetra
.717 .777 .899 r
.2997 .40482 .30072 .40571 .30231 .40486 .30129 .40405 Mtetra
.667 .782 .935 r
.30129 .40405 .30231 .40486 .30388 .40442 .30286 .40349 Mtetra
.42 .664 .962 r
.30286 .40349 .30388 .40442 .30534 .40555 .30439 .40359 Mtetra
.27 .389 .8 r
.30439 .40359 .30534 .40555 .30659 .40971 .30587 .40448 Mtetra
.296 .229 .61 r
.30587 .40448 .30659 .40971 .29493 .60653 .30725 .40676 Mtetra
0 0 .248 r
.30725 .40676 .29493 .60653 .29625 .6113 .29609 .59664 Mtetra
0 0 .367 r
.29609 .59664 .29625 .6113 .2978 .61271 .29689 .60912 Mtetra
0 .069 .591 r
.29689 .60912 .2978 .61271 .29941 .6132 .29835 .61188 Mtetra
.272 .516 .904 r
.29835 .61188 .29941 .6132 .30105 .61324 .29996 .61242 Mtetra
.633 .787 .956 r
.29996 .61242 .30105 .61324 .30272 .61282 .30164 .61194 Mtetra
.755 .795 .885 r
.30164 .61194 .30272 .61282 .30443 .61181 .30335 .61089 Mtetra
.801 .789 .842 r
.30335 .61089 .30443 .61181 .30625 .60924 .30509 .60945 Mtetra
.897 .967 .823 r
.30509 .60945 .30625 .60924 .30828 .60308 .30687 .60739 Mtetra
0 0 .114 r
.30687 .60739 .30828 .60308 .32233 .40543 .30875 .60389 Mtetra
0 0 .245 r
.30875 .60389 .32233 .40543 .32419 .40045 .32233 .41327 Mtetra
0 0 .124 r
.32233 .41327 .32419 .40045 .32588 .39827 .32473 .39975 Mtetra
.902 .941 .579 r
.32473 .39975 .32588 .39827 .32752 .39687 .3265 .39624 Mtetra
.822 .837 .859 r
.3265 .39624 .32752 .39687 .32912 .39608 .32814 .39483 Mtetra
.637 .688 .881 r
.32814 .39483 .32912 .39608 .3307 .39567 .32972 .3944 Mtetra
.549 .648 .899 r
.32972 .3944 .3307 .39567 .33227 .39542 .33128 .39429 Mtetra
.591 .692 .912 r
.33128 .39429 .33227 .39542 .33385 .39504 .33285 .39402 Mtetra
.653 .735 .91 r
.33285 .39402 .33385 .39504 .33544 .3945 .33444 .39352 Mtetra
.669 .748 .91 r
.33444 .39352 .33544 .3945 .33704 .3939 .33604 .39295 Mtetra
.719 .767 .89 r
.33604 .39295 .33704 .3939 .33865 .39299 .33764 .39214 Mtetra
.735 .791 .898 r
.33764 .39214 .33865 .39299 .34027 .39204 .33926 .39127 Mtetra
.688 .801 .935 r
.33926 .39127 .34027 .39204 .34186 .39149 .34086 .39062 Mtetra
.479 .709 .971 r
.34086 .39062 .34186 .39149 .34338 .3923 .34242 .39057 Mtetra
.282 .43 .833 r
.34242 .39057 .34338 .3923 .34474 .39591 .34395 .39133 Mtetra
.31 .257 .635 r
.34395 .39133 .34474 .39591 .33541 .59243 .3454 .39328 Mtetra
.519 .304 .527 r
.3454 .39328 .33541 .59243 .33675 .59834 .34644 .40289 Mtetra
0 0 .255 r
.34644 .40289 .33675 .59834 .33834 .59974 .33747 .59521 Mtetra
.04 .077 .572 r
.33747 .59521 .33834 .59974 .33999 .60019 .33897 .5985 Mtetra
.264 .444 .852 r
.33897 .5985 .33999 .60019 .34167 .60006 .3406 .59928 Mtetra
.608 .791 .969 r
.3406 .59928 .34167 .60006 .34338 .59956 .3423 .59885 Mtetra
.706 .831 .942 r
.3423 .59885 .34338 .59956 .34509 .59891 .34402 .59808 Mtetra
.671 .795 .941 r
.34402 .59808 .34509 .59891 .34679 .59839 .34573 .59745 Mtetra
.599 .751 .95 r
.34573 .59745 .34679 .59839 .34849 .59805 .34743 .59709 Mtetra
.599 .749 .949 r
.34743 .59709 .34849 .59805 .35019 .5977 .34913 .59674 Mtetra
.618 .752 .942 r
.34913 .59674 .35019 .5977 .35189 .5973 .35084 .59632 Mtetra
.637 .756 .934 r
.35084 .59632 .35189 .5973 .3536 .59682 .35255 .59584 Mtetra
.642 .756 .931 r
.35255 .59584 .3536 .59682 .35531 .59632 .35426 .59533 Mtetra
.642 .755 .93 r
.35426 .59533 .35531 .59632 .35703 .59582 .35597 .59483 Mtetra
.64 .754 .931 r
.35597 .59483 .35703 .59582 .35874 .59532 .35768 .59433 Mtetra
.639 .755 .933 r
.35768 .59433 .35874 .59532 .36045 .59481 .3594 .59384 Mtetra
.635 .758 .937 r
.3594 .59384 .36045 .59481 .36217 .59429 .36111 .59336 Mtetra
.63 .764 .943 r
.36111 .59336 .36217 .59429 .36389 .59378 .36283 .59289 Mtetra
.629 .775 .95 r
.36283 .59289 .36389 .59378 .3656 .59326 .36454 .59242 Mtetra
.577 .769 .97 r
.36454 .59242 .3656 .59326 .36732 .59282 .36625 .59209 Mtetra
.538 .781 .988 r
.36625 .59209 .36732 .59282 .36903 .59243 .36796 .59183 Mtetra
.658 .847 .973 r
.36796 .59183 .36903 .59243 .37076 .59187 .36969 .5912 Mtetra
.851 .838 .832 r
.36969 .5912 .37076 .59187 .37251 .59073 .37147 .58938 Mtetra
.893 .732 .676 r
.37147 .58938 .37251 .59073 .3743 .58876 .37337 .58494 Mtetra
.951 .686 .499 r
.37337 .58494 .3743 .58876 .37611 .58627 .38347 .39393 Mtetra
.566 .342 .535 r
.38347 .39393 .37611 .58627 .37788 .58452 .38562 .38141 Mtetra
.542 .322 .531 r
.38562 .38141 .37788 .58452 .37959 .58446 .38725 .38075 Mtetra
.54 .321 .531 r
.38725 .38075 .37959 .58446 .38131 .58393 .38886 .38071 Mtetra
.544 .324 .531 r
.38886 .38071 .38131 .58393 .38319 .57988 .39054 .37882 Mtetra
.547 .327 .532 r
.39054 .37882 .38319 .57988 .39309 .38069 .39228 .37555 Mtetra
.687 .508 .639 r
.39228 .37555 .39309 .38069 .39493 .37494 .39398 .37319 Mtetra
.752 .667 .767 r
.39398 .37319 .39493 .37494 .39663 .37262 .39565 .37174 Mtetra
.689 .781 .921 r
.39565 .37174 .39663 .37262 .39826 .37186 .39728 .37107 Mtetra
.621 .785 .96 r
.39728 .37107 .39826 .37186 .39988 .37151 .3989 .37064 Mtetra
.6 .759 .955 r
.3989 .37064 .39988 .37151 .4015 .37126 .40053 .37029 Mtetra
.621 .742 .933 r
.40053 .37029 .4015 .37126 .40313 .37088 .40215 .36989 Mtetra
.628 .74 .928 r
.40215 .36989 .40313 .37088 .40475 .37048 .40378 .36946 Mtetra
.661 .745 .912 r
.40378 .36946 .40475 .37048 .40638 .36998 .40541 .36891 Mtetra
.699 .746 .888 r
.40541 .36891 .40638 .36998 .40802 .3693 .40705 .36818 Mtetra
.703 .736 .877 r
.40705 .36818 .40802 .3693 .40966 .3686 .4087 .36742 Mtetra
.711 .728 .864 r
.4087 .36742 .40966 .3686 .4113 .36786 .41034 .36659 Mtetra
.711 .715 .851 r
.41034 .36659 .4113 .36786 .41295 .36712 .41199 .36574 Mtetra
.652 .676 .86 r
.41199 .36574 .41295 .36712 .41458 .36655 .41363 .36521 Mtetra
.418 .575 .902 r
.41363 .36521 .41458 .36655 .41621 .3663 .41524 .36548 Mtetra
.755 .26 0 r
.41524 .36548 .41621 .3663 .41782 .36659 .41678 .3677 Mtetra
.902 .573 .415 r
.41678 .3677 .41782 .36659 .41941 .36764 .41812 .37636 Mtetra
.945 .671 .486 r
.41812 .37636 .41941 .36764 .42092 .37134 .41333 .57163 Mtetra
.545 .32 .525 r
.41333 .57163 .42092 .37134 .41617 .57035 .41497 .57455 Mtetra
.603 .282 .399 r
.41497 .57455 .41617 .57035 .41773 .57562 .41666 .57575 Mtetra
.301 0 0 r
.41666 .57575 .41773 .57562 .41942 .57718 .41839 .57607 Mtetra
.609 .724 .927 r
.41839 .57607 .41942 .57718 .42117 .57693 .42014 .57569 Mtetra
.67 .72 .887 r
.42014 .57569 .42117 .57693 .42293 .57621 .4219 .57505 Mtetra
.681 .738 .894 r
.4219 .57505 .42293 .57621 .42469 .57537 .42366 .57435 Mtetra
.642 .755 .931 r
.42366 .57435 .42469 .57537 .42645 .5748 .42542 .57384 Mtetra
.64 .766 .939 r
.42542 .57384 .42645 .5748 .42821 .57423 .42718 .57332 Mtetra
.613 .77 .955 r
.42718 .57332 .42821 .57423 .42997 .57371 .42894 .57289 Mtetra
.539 .764 .98 r
.42894 .57289 .42997 .57371 .43173 .57331 .43069 .57265 Mtetra
.636 .833 .976 r
.43069 .57265 .43173 .57331 .43349 .57276 .43246 .57208 Mtetra
.815 .852 .877 r
.43246 .57208 .43349 .57276 .43527 .57179 .43424 .57065 Mtetra
.903 .758 .691 r
.43424 .57065 .43527 .57179 .43707 .56988 .4361 .56665 Mtetra
.906 .672 .573 r
.4361 .56665 .43707 .56988 .43888 .5674 .43818 .55375 Mtetra
.945 .673 .493 r
.43818 .55375 .43888 .5674 .44069 .56503 .44478 .36096 Mtetra
.542 .323 .531 r
.44478 .36096 .44069 .56503 .44245 .56494 .44645 .36 Mtetra
.541 .321 .531 r
.44645 .36 .44245 .56494 .44421 .56456 .4481 .35986 Mtetra
.543 .323 .531 r
.4481 .35986 .44421 .56456 .44602 .56197 .44978 .35877 Mtetra
.547 .326 .532 r
.44978 .35877 .44602 .56197 .45233 .36209 .45151 .35541 Mtetra
.664 .475 .619 r
.45151 .35541 .45233 .36209 .45414 .35509 .45321 .35295 Mtetra
.748 .637 .737 r
.45321 .35295 .45414 .35509 .45586 .35226 .4549 .35127 Mtetra
.7 .766 .903 r
.4549 .35127 .45586 .35226 .45753 .35138 .45657 .35053 Mtetra
.635 .78 .951 r
.45657 .35053 .45753 .35138 .45919 .35095 .45823 .35006 Mtetra
.597 .755 .954 r
.45823 .35006 .45919 .35095 .46085 .35072 .4599 .34971 Mtetra
.618 .735 .93 r
.4599 .34971 .46085 .35072 .46251 .35033 .46156 .34931 Mtetra
.619 .734 .928 r
.46156 .34931 .46251 .35033 .46418 .34995 .46323 .34891 Mtetra
.641 .738 .919 r
.46323 .34891 .46418 .34995 .46584 .34949 .46489 .34843 Mtetra
.69 .748 .896 r
.46489 .34843 .46584 .34949 .46751 .34884 .46657 .34773 Mtetra
.697 .741 .885 r
.46657 .34773 .46751 .34884 .46919 .34815 .46824 .34698 Mtetra
.692 .731 .88 r
.46824 .34698 .46919 .34815 .47086 .34746 .46992 .34626 Mtetra
.668 .716 .884 r
.46992 .34626 .47086 .34746 .47254 .34688 .47159 .34565 Mtetra
.662 .71 .883 r
.47159 .34565 .47254 .34688 .47421 .34631 .47327 .34507 Mtetra
.658 .706 .883 r
.47327 .34507 .47421 .34631 .47588 .34576 .47494 .34451 Mtetra
.66 .705 .88 r
.47494 .34451 .47588 .34576 .47756 .34521 .47662 .34394 Mtetra
.659 .702 .879 r
.47662 .34394 .47756 .34521 .47924 .34465 .4783 .34338 Mtetra
.658 .7 .878 r
.4783 .34338 .47924 .34465 .48092 .3441 .47998 .34281 Mtetra
.659 .699 .876 r
.47998 .34281 .48092 .3441 .4826 .34353 .48166 .34224 Mtetra
.659 .698 .875 r
.48166 .34224 .4826 .34353 .48428 .34297 .48334 .34168 Mtetra
.659 .697 .875 r
.48334 .34168 .48428 .34297 .48596 .3424 .48502 .34111 Mtetra
.48502 .34111 .48596 .3424 .48764 .34183 .4867 .34054 Mtetra
.658 .698 .875 r
.4867 .34054 .48764 .34183 .48932 .34126 .48839 .33997 Mtetra
.658 .699 .876 r
.48839 .33997 .48932 .34126 .49101 .34068 .49007 .3394 Mtetra
.662 .701 .876 r
.49007 .3394 .49101 .34068 .49269 .34008 .49176 .33881 Mtetra
.658 .702 .879 r
.49176 .33881 .49269 .34008 .49438 .3395 .49345 .33825 Mtetra
.651 .701 .884 r
.49345 .33825 .49438 .3395 .49607 .33895 .49513 .33772 Mtetra
.625 .696 .895 r
.49513 .33772 .49607 .33895 .49776 .3385 .49682 .3373 Mtetra
.62 .701 .903 r
.49682 .3373 .49776 .3385 .49945 .33805 .49851 .33691 Mtetra
.624 .712 .909 r
.49851 .33691 .49945 .33805 .50114 .33759 .5002 .33649 Mtetra
.652 .732 .908 r
.5002 .33649 .50114 .33759 .50283 .33702 .50189 .33596 Mtetra
.666 .744 .908 r
.50189 .33596 .50283 .33702 .50452 .33641 .50359 .33536 Mtetra
.679 .753 .907 r
.50359 .33536 .50452 .33641 .50622 .33574 .50528 .33472 Mtetra
.733 .771 .883 r
.50528 .33472 .50622 .33574 .50791 .33466 .50698 .33378 Mtetra
.711 .798 .918 r
.50698 .33378 .50791 .33466 .50961 .33385 .50868 .33299 Mtetra
.638 .781 .95 r
.50868 .33299 .50961 .33385 .51131 .33356 .51038 .33249 Mtetra
.112 .457 .887 r
.51038 .33249 .51131 .33356 .51299 .33586 .51207 .33323 Mtetra
.224 .298 .73 r
.51207 .33323 .51299 .33586 .51466 .3457 .51376 .33476 Mtetra
.439 .286 .575 r
.51376 .33476 .51466 .3457 .51584 .54224 .51546 .33741 Mtetra
.542 .322 .531 r
.51546 .33741 .51584 .54224 .51765 .54254 .51716 .33662 Mtetra
.542 .323 .531 r
.51716 .33662 .51765 .54254 .51947 .54171 .51887 .33559 Mtetra
.54 .321 .531 r
.51887 .33559 .51947 .54171 .52129 .54075 .52058 .33568 Mtetra
0 0 .354 r
.52058 .33568 .52129 .54075 .5231 .54232 .52212 .53364 Mtetra
.035 .013 .498 r
.52212 .53364 .5231 .54232 .52492 .54356 .52394 .54083 Mtetra
0 .14 .663 r
.52394 .54083 .52492 .54356 .52675 .54428 .52576 .54327 Mtetra
.469 .693 .965 r
.52576 .54327 .52675 .54428 .52857 .54403 .52759 .54326 Mtetra
.648 .822 .967 r
.52759 .54326 .52857 .54403 .5304 .54348 .52941 .54266 Mtetra
.718 .826 .932 r
.52941 .54266 .5304 .54348 .53223 .5428 .53124 .54178 Mtetra
.601 .749 .948 r
.53124 .54178 .53223 .5428 .53406 .54258 .53307 .54139 Mtetra
.633 .725 .914 r
.53307 .54139 .53406 .54258 .53589 .54214 .5349 .5409 Mtetra
.693 .737 .885 r
.5349 .5409 .53589 .54214 .53772 .54116 .53673 .54011 Mtetra
.809 .795 .838 r
.53673 .54011 .53772 .54116 .53954 .53796 .53856 .53852 Mtetra
.866 .985 .705 r
.53856 .53852 .53954 .53796 .54133 .53005 .54039 .53603 Mtetra
.097 0 .276 r
.54039 .53603 .54133 .53005 .54207 .32855 .5422 .5315 Mtetra
0 0 .347 r
.5422 .5315 .54207 .32855 .54377 .32463 .54289 .33061 Mtetra
0 0 .123 r
.54289 .33061 .54377 .32463 .54548 .32257 .54457 .32324 Mtetra
.922 .961 .645 r
.54457 .32324 .54548 .32257 .54719 .32121 .54628 .32018 Mtetra
.749 .778 .876 r
.54628 .32018 .54719 .32121 .54891 .32048 .54799 .31915 Mtetra
.625 .682 .883 r
.54799 .31915 .54891 .32048 .55063 .32002 .54972 .31872 Mtetra
.564 .662 .903 r
.54972 .31872 .55063 .32002 .55236 .31966 .55144 .31854 Mtetra
.703 .748 .887 r
.55144 .31854 .55236 .31966 .55408 .31871 .55317 .31775 Mtetra
.712 .785 .909 r
.55317 .31775 .55408 .31871 .5558 .31785 .55489 .31694 Mtetra
.654 .779 .941 r
.55489 .31694 .5558 .31785 .55753 .31744 .55662 .31638 Mtetra
.402 .633 .948 r
.55662 .31638 .55753 .31744 .55928 .31895 .55835 .31658 Mtetra
.334 .392 .773 r
.55835 .31658 .55928 .31895 .56108 .32425 .5601 .3176 Mtetra
.354 .258 .605 r
.5601 .3176 .56108 .32425 .56524 .52556 .56187 .3203 Mtetra
0 0 .371 r
.56187 .3203 .56524 .52556 .56714 .52915 .56606 .51897 Mtetra
.081 .038 .503 r
.56606 .51897 .56714 .52915 .56901 .53033 .56802 .52708 Mtetra
.127 .205 .676 r
.56802 .52708 .56901 .53033 .57088 .53067 .56991 .52948 Mtetra
.463 .651 .941 r
.56991 .52948 .57088 .53067 .57274 .53032 .57177 .52956 Mtetra
.675 .834 .96 r
.57177 .52956 .57274 .53032 .57459 .52963 .57363 .52884 Mtetra
.744 .844 .926 r
.57363 .52884 .57459 .52963 .57644 .52881 .57548 .52783 Mtetra
.503 .718 .969 r
.57548 .52783 .57644 .52881 .57831 .52876 .57734 .52771 Mtetra
.534 .717 .957 r
.57734 .52771 .57831 .52876 .58018 .5286 .57921 .52753 Mtetra
.713 .779 .904 r
.57921 .52753 .58018 .5286 .58203 .52774 .58107 .52665 Mtetra
.931 .777 .668 r
.58107 .52665 .58203 .52774 .58383 .52332 .58286 .52211 Mtetra
.972 .688 .432 r
.58286 .52211 .58383 .52332 .58196 .31789 .58105 .31617 Mtetra
.935 .718 .586 r
.58105 .31617 .58196 .31789 .58357 .30956 .58266 .30828 Mtetra
.815 .753 .794 r
.58266 .30828 .58357 .30956 .58529 .30773 .58438 .3065 Mtetra
.631 .705 .899 r
.58438 .3065 .58529 .30773 .58703 .30724 .58613 .30604 Mtetra
.495 .651 .928 r
.58613 .30604 .58703 .30724 .58879 .30721 .58789 .30606 Mtetra
.6 .707 .919 r
.58789 .30606 .58879 .30721 .59054 .30684 .58964 .30572 Mtetra
.656 .737 .909 r
.58964 .30572 .59054 .30684 .59229 .30624 .59139 .30515 Mtetra
.669 .747 .909 r
.59139 .30515 .59229 .30624 .59404 .30559 .59314 .30453 Mtetra
.759 .778 .868 r
.59314 .30453 .59404 .30559 .59577 .30447 .59488 .3034 Mtetra
.742 .775 .88 r
.59488 .3034 .59577 .30447 .59752 .30346 .59662 .3024 Mtetra
.608 .73 .932 r
.59662 .3024 .59752 .30346 .59927 .30307 .59838 .30201 Mtetra
.664 .196 0 r
.59838 .30201 .59927 .30307 .6011 .30563 .60021 .30466 Mtetra
.973 .68 .409 r
.60021 .30466 .6011 .30563 .60795 .50921 .60702 .50882 Mtetra
.934 .56 .251 r
.60702 .50882 .60795 .50921 .61006 .51787 .60911 .51699 Mtetra
0 .299 .761 r
.60911 .51699 .61006 .51787 .61199 .51918 .61104 .51813 Mtetra
.64 .761 .936 r
.61104 .51813 .61199 .51918 .61387 .51875 .61292 .51758 Mtetra
.769 .777 .859 r
.61292 .51758 .61387 .51875 .61573 .5174 .61479 .51629 Mtetra
.809 .796 .839 r
.61479 .51629 .61573 .5174 .61756 .51456 .61664 .51469 Mtetra
.876 .993 .797 r
.61664 .51469 .61756 .51456 .61928 .50837 .61848 .51255 Mtetra
.073 0 .218 r
.61848 .51255 .61928 .50837 .61532 .30563 .62029 .50909 Mtetra
.511 .294 .521 r
.62029 .50909 .61532 .30563 .61695 .30045 .62172 .49307 Mtetra
0 0 .374 r
.62172 .49307 .61695 .30045 .61867 .29825 .61787 .3001 Mtetra
0 0 0 r
.61787 .3001 .61867 .29825 .62041 .29682 .61954 .29623 Mtetra
.848 .89 .868 r
.61954 .29623 .62041 .29682 .62217 .29591 .62128 .29464 Mtetra
.669 .716 .883 r
.62128 .29464 .62217 .29591 .62394 .29531 .62305 .294 Mtetra
.6 .679 .897 r
.62305 .294 .62394 .29531 .62571 .29485 .62483 .29367 Mtetra
.663 .729 .899 r
.62483 .29367 .62571 .29485 .62747 .29406 .6266 .29306 Mtetra
.698 .778 .913 r
.6266 .29306 .62747 .29406 .62924 .29321 .62836 .29229 Mtetra
.647 .782 .946 r
.62836 .29229 .62924 .29321 .63102 .29276 .63014 .29174 Mtetra
.479 .684 .957 r
.63014 .29174 .63102 .29276 .63285 .29383 .63193 .29173 Mtetra
.382 .45 .807 r
.63193 .29173 .63285 .29383 .63481 .29841 .63376 .29247 Mtetra
.398 .301 .628 r
.63376 .29247 .63481 .29841 .64383 .50027 .63563 .29451 Mtetra
.037 0 .417 r
.63563 .29451 .64383 .50027 .64591 .50467 .64407 .47844 Mtetra
.056 0 .452 r
.64407 .47844 .64591 .50467 .64788 .50588 .64682 .50139 Mtetra
.191 .199 .638 r
.64682 .50139 .64788 .50588 .64982 .50627 .64886 .50447 Mtetra
.226 .408 .834 r
.64886 .50447 .64982 .50627 .65176 .50654 .65083 .50556 Mtetra
.453 .698 .972 r
.65083 .50556 .65176 .50654 .65369 .50649 .65277 .50557 Mtetra
.719 .816 .926 r
.65277 .50557 .65369 .50649 .65559 .50569 .65467 .50465 Mtetra
.919 .803 .717 r
.65467 .50465 .65559 .50569 .6574 .50241 .65647 .50122 Mtetra
.976 .685 .404 r
.65647 .50122 .6574 .50241 .65813 .47269 .65043 .30269 Mtetra
.577 .349 .534 r
.65043 .30269 .65813 .47269 .65243 .28692 .65155 .28558 Mtetra
.869 .76 .74 r
.65155 .28558 .65243 .28692 .65413 .28422 .65326 .28295 Mtetra
.664 .716 .887 r
.65326 .28295 .65413 .28422 .65592 .28355 .65504 .28232 Mtetra
.527 .663 .922 r
.65504 .28232 .65592 .28355 .65773 .28343 .65686 .28224 Mtetra
.596 .703 .918 r
.65686 .28224 .65773 .28343 .65952 .28298 .65866 .28191 Mtetra
.688 .764 .909 r
.65866 .28191 .65952 .28298 .66131 .28214 .66045 .28118 Mtetra
.648 .774 .94 r
.66045 .28118 .66131 .28214 .6631 .28166 .66224 .28062 Mtetra
.51 .696 .953 r
.66224 .28062 .6631 .28166 .66496 .28249 .66406 .28054 Mtetra
.395 .476 .825 r
.66406 .28054 .66496 .28249 .66697 .28641 .66591 .28117 Mtetra
.405 .318 .645 r
.66591 .28117 .66697 .28641 .67814 .48833 .66782 .28293 Mtetra
.524 .309 .529 r
.66782 .28293 .67814 .48833 .68035 .49378 .67006 .29166 Mtetra
0 0 .407 r
.67006 .29166 .68035 .49378 .68236 .49512 .68126 .49001 Mtetra
.201 .191 .622 r
.68126 .49001 .68236 .49512 .68434 .49556 .68338 .49352 Mtetra
.236 .383 .808 r
.68338 .49352 .68434 .49556 .68631 .49579 .6854 .49476 Mtetra
.439 .681 .966 r
.6854 .49476 .68631 .49579 .68827 .49577 .68736 .49483 Mtetra
.71 .813 .929 r
.68736 .49483 .68827 .49577 .6902 .495 .68928 .49394 Mtetra
.915 .81 .729 r
.68928 .49394 .6902 .495 .69201 .49195 .69109 .49073 Mtetra
.977 .683 .39 r
.69109 .49073 .69201 .49195 .69276 .46813 .68298 .29225 Mtetra
.577 .349 .534 r
.68298 .29225 .69276 .46813 .68478 .27573 .68391 .27435 Mtetra
.889 .761 .714 r
.68391 .27435 .68478 .27573 .68646 .27255 .68559 .27125 Mtetra
.729 .738 .858 r
.68559 .27125 .68646 .27255 .68824 .2715 .68738 .27024 Mtetra
.535 .662 .918 r
.68738 .27024 .68824 .2715 .69008 .27137 .68922 .27014 Mtetra
0 .226 .743 r
.68922 .27014 .69008 .27137 .692 .27293 .69114 .27169 Mtetra
.923 .551 .136 r
.69114 .27169 .692 .27293 .69435 .28207 .69347 .28043 Mtetra
.976 .674 .365 r
.69347 .28043 .69435 .28207 .70745 .48588 .70654 .48468 Mtetra
.578 .126 0 r
.70654 .48468 .70745 .48588 .70959 .48871 .70868 .48756 Mtetra
.432 .65 .95 r
.70868 .48756 .70959 .48871 .71157 .48884 .71067 .4877 Mtetra
.722 .781 .899 r
.71067 .4877 .71157 .48884 .7135 .48786 .7126 .48673 Mtetra
.901 .806 .745 r
.7126 .48673 .7135 .48786 .71532 .48492 .71442 .48379 Mtetra
.978 .739 .505 r
.71442 .48379 .71532 .48492 .7166 .47288 .7157 .4716 Mtetra
.977 .681 .379 r
.7157 .4716 .7166 .47288 .70662 .26939 .70577 .26822 Mtetra
.917 .786 .701 r
.70577 .26822 .70662 .26939 .70828 .26595 .70743 .26479 Mtetra
.717 .759 .886 r
.70743 .26479 .70828 .26595 .71009 .26505 .70924 .26388 Mtetra
.595 .712 .925 r
.70924 .26388 .71009 .26505 .71193 .2647 .71108 .26354 Mtetra
.63 .728 .917 r
.71108 .26354 .71193 .2647 .71376 .26422 .71291 .26306 Mtetra
.737 .768 .877 r
.71291 .26306 .71376 .26422 .71556 .26319 .71472 .26204 Mtetra
.648 .736 .913 r
.71472 .26204 .71556 .26319 .71739 .26263 .71655 .26148 Mtetra
.094 .422 .868 r
.71655 .26148 .71739 .26263 .71932 .26359 .71848 .26244 Mtetra
.913 .532 .107 r
.71848 .26244 .71932 .26359 .72171 .27176 .72087 .27071 Mtetra
.975 .671 .352 r
.72087 .27071 .72171 .27176 .73674 .47656 .73585 .4755 Mtetra
.603 .135 0 r
.73585 .4755 .73674 .47656 .73893 .47947 .73804 .47839 Mtetra
.547 .725 .957 r
.73804 .47839 .73893 .47947 .74092 .47923 .74003 .47816 Mtetra
.704 .79 .918 r
.74003 .47816 .74092 .47923 .74287 .47835 .74199 .47729 Mtetra
.669 .78 .932 r
.74199 .47729 .74287 .47835 .74484 .47762 .74395 .47658 Mtetra
.435 .678 .966 r
.74395 .47658 .74484 .47762 .74685 .47766 .74597 .47666 Mtetra
.604 .768 .958 r
.74597 .47666 .74685 .47766 .74883 .47717 .74796 .4762 Mtetra
.858 .841 .827 r
.74796 .4762 .74883 .47717 .75071 .47513 .74984 .47421 Mtetra
.981 .773 .549 r
.74984 .47421 .75071 .47513 .75215 .46674 .7513 .46618 Mtetra
.978 .679 .36 r
.7513 .46618 .75215 .46674 .73969 .25905 .73886 .25805 Mtetra
.953 .8 .653 r
.73886 .25805 .73969 .25905 .74128 .25482 .74045 .2537 Mtetra
.739 .779 .885 r
.74045 .2537 .74128 .25482 .74309 .25381 .74226 .25267 Mtetra
.603 .723 .929 r
.74226 .25267 .74309 .25381 .74496 .25343 .74413 .25229 Mtetra
.6 .721 .929 r
.74413 .25229 .74496 .25343 .74682 .25306 .74599 .25192 Mtetra
.745 .776 .878 r
.74599 .25192 .74682 .25306 .74864 .252 .74781 .25085 Mtetra
.66 .744 .912 r
.74781 .25085 .74864 .252 .75049 .25139 .74966 .25023 Mtetra
.226 .508 .908 r
.74966 .25023 .75049 .25139 .75244 .25208 .75161 .25093 Mtetra
.889 .499 .049 r
.75161 .25093 .75244 .25208 .75489 .25957 .75407 .25845 Mtetra
.975 .667 .334 r
.75407 .25845 .75489 .25957 .7723 .46557 .77143 .46446 Mtetra
.65 .195 0 r
.77143 .46446 .7723 .46557 .77459 .46899 .77372 .46787 Mtetra
.385 .633 .953 r
.77372 .46787 .77459 .46899 .77665 .46925 .77578 .46813 Mtetra
.693 .781 .918 r
.77578 .46813 .77665 .46925 .77863 .46842 .77776 .4673 Mtetra
.873 .82 .793 r
.77776 .4673 .77863 .46842 .78049 .4661 .77962 .46498 Mtetra
.978 .767 .552 r
.77962 .46498 .78049 .4661 .78192 .45826 .78106 .45714 Mtetra
.977 .675 .347 r
.78106 .45714 .78192 .45826 .76752 .24998 .7667 .2488 Mtetra
.95 .784 .641 r
.7667 .2488 .76752 .24998 .76906 .24535 .76824 .24417 Mtetra
.746 .772 .874 r
.76824 .24417 .76906 .24535 .77089 .24426 .77007 .24308 Mtetra
.618 .722 .92 r
.77007 .24308 .77089 .24426 .77277 .24382 .77195 .24264 Mtetra
.586 .707 .926 r
.77195 .24264 .77277 .24382 .77466 .24351 .77384 .24232 Mtetra
.747 .772 .873 r
.77384 .24232 .77466 .24351 .77649 .24241 .77567 .24122 Mtetra
.671 .743 .905 r
.77567 .24122 .77649 .24241 .77835 .24173 .77753 .24054 Mtetra
.359 .583 .928 r
.77753 .24054 .77835 .24173 .78031 .24214 .77949 .24094 Mtetra
.83 .423 0 r
.77949 .24094 .78031 .24214 .78274 .24818 .78192 .24693 Mtetra
.973 .663 .318 r
.78192 .24693 .78274 .24818 .80222 .45564 .80135 .45446 Mtetra
.688 .247 0 r
.80135 .45446 .80222 .45564 .80462 .45964 .80376 .45848 Mtetra
.351 .605 .944 r
.80376 .45848 .80462 .45964 .80672 .46001 .80586 .45885 Mtetra
.679 .771 .92 r
.80586 .45885 .80672 .46001 .80872 .45925 .80786 .45809 Mtetra
.862 .817 .803 r
.80786 .45809 .80872 .45925 .8106 .45709 .80974 .45589 Mtetra
.98 .763 .54 r
.80974 .45589 .8106 .45709 .81198 .44919 .81109 .44766 Mtetra
.976 .671 .333 r
.81109 .44766 .81198 .44919 .79557 .24012 .79474 .23867 Mtetra
.938 .765 .64 r
.79474 .23867 .79557 .24012 .79709 .23536 .79627 .23402 Mtetra
.715 .737 .868 r
.79627 .23402 .79709 .23536 .79894 .23438 .79812 .23308 Mtetra
.576 .68 .911 r
.79812 .23308 .79894 .23438 .80085 .23409 .80004 .23282 Mtetra
.487 .64 .923 r
.80004 .23282 .80085 .23409 .80279 .23412 .80198 .23287 Mtetra
.645 .724 .906 r
.80198 .23287 .80279 .23412 .80468 .23354 .80388 .23231 Mtetra
.657 .732 .905 r
.80388 .23231 .80468 .23354 .80657 .23291 .80576 .23169 Mtetra
.674 .742 .902 r
.80576 .23169 .80657 .23291 .80845 .2322 .80765 .23099 Mtetra
.758 .775 .867 r
.80765 .23099 .80845 .2322 .81029 .23101 .80949 .22981 Mtetra
.691 .752 .899 r
.80949 .22981 .81029 .23101 .81216 .23022 .81136 .22902 Mtetra
.472 .649 .936 r
.81136 .22902 .81216 .23022 .81412 .23028 .81332 .22909 Mtetra
.772 .357 0 r
.81332 .22909 .81412 .23028 .81657 .23548 .81577 .23432 Mtetra
.971 .657 .298 r
.81577 .23432 .81657 .23548 .83853 .44384 .8377 .44272 Mtetra
.729 .292 0 r
.8377 .44272 .83853 .44384 .84107 .44845 .84023 .44732 Mtetra
.307 .582 .939 r
.84023 .44732 .84107 .44845 .84322 .44894 .84238 .4478 Mtetra
.651 .766 .933 r
.84238 .4478 .84322 .44894 .84526 .4483 .84442 .44715 Mtetra
.831 .822 .839 r
.84442 .44715 .84526 .4483 .84719 .44649 .84635 .44535 Mtetra
.976 .788 .586 r
.84635 .44535 .84719 .44649 .84868 .44033 .84785 .43918 Mtetra
.974 .667 .312 r
.84785 .43918 .84868 .44033 .82983 .2305 .82903 .22928 Mtetra
.973 .775 .576 r
.82903 .22928 .82983 .2305 .83117 .22432 .83038 .22311 Mtetra
.766 .758 .846 r
.21819 .43212 .21923 .43309 .22081 .43198 .21977 .431 Mtetra
.632 .732 .92 r
.21977 .431 .22081 .43198 .22232 .43157 .22128 .4306 Mtetra
.497 .684 .95 r
.22128 .4306 .22232 .43157 .2238 .43154 .22276 .43056 Mtetra
.749 .755 .857 r
.22276 .43056 .2238 .43154 .22537 .43054 .22433 .42957 Mtetra
.692 .748 .894 r
.22433 .42957 .22537 .43054 .22691 .4299 .22587 .42892 Mtetra
.461 .67 .953 r
.22587 .42892 .22691 .4299 .22838 .42997 .22735 .42896 Mtetra
.934 .567 .283 r
.22735 .42896 .22838 .42997 .22941 .43494 .22842 .43344 Mtetra
.939 .684 .524 r
.22842 .43344 .22941 .43494 .21297 .6336 .21193 .63181 Mtetra
.942 .579 .208 r
.21193 .63181 .21297 .6336 .21414 .63812 .21307 .63675 Mtetra
.449 .595 .904 r
.21307 .63675 .21414 .63812 .21571 .63818 .21463 .63693 Mtetra
.686 .71 .866 r
.21463 .63693 .21571 .63818 .21737 .63735 .21628 .63623 Mtetra
.754 .744 .843 r
.21628 .63623 .21737 .63735 .21906 .63608 .21796 .6351 Mtetra
.679 .756 .91 r
.21796 .6351 .21906 .63608 .22071 .63538 .2196 .63447 Mtetra
.664 .769 .928 r
.2196 .63447 .22071 .63538 .22235 .63479 .22123 .63391 Mtetra
.658 .772 .933 r
.22123 .63391 .22235 .63479 .22398 .63429 .22287 .63337 Mtetra
.653 .762 .929 r
.22287 .63337 .22398 .63429 .22559 .63396 .2245 .63284 Mtetra
.648 .722 .902 r
.2245 .63284 .22559 .63396 .22721 .63368 .22613 .63234 Mtetra
.641 .682 .873 r
.22613 .63234 .22721 .63368 .22882 .6334 .22776 .63187 Mtetra
.629 .649 .851 r
.22776 .63187 .22882 .6334 .23044 .633 .22939 .63144 Mtetra
.625 .643 .848 r
.22939 .63144 .23044 .633 .23207 .63257 .23102 .63103 Mtetra
.625 .646 .851 r
.23102 .63103 .23207 .63257 .23371 .63212 .23265 .63063 Mtetra
.631 .655 .855 r
.23265 .63063 .23371 .63212 .23534 .63166 .23428 .63019 Mtetra
.633 .66 .858 r
.23428 .63019 .23534 .63166 .23697 .63121 .23591 .62975 Mtetra
.634 .661 .859 r
.23591 .62975 .23697 .63121 .23861 .63078 .23755 .6293 Mtetra
.633 .658 .856 r
.23755 .6293 .23861 .63078 .24023 .63045 .23918 .62886 Mtetra
.633 .642 .842 r
.23918 .62886 .24023 .63045 .24186 .63014 .24082 .6284 Mtetra
.633 .626 .825 r
.24082 .6284 .24186 .63014 .24349 .6298 .24246 .62794 Mtetra
.636 .613 .81 r
.24246 .62794 .24349 .6298 .24513 .62937 .24411 .62744 Mtetra
.636 .606 .803 r
.24411 .62744 .24513 .62937 .24677 .62888 .24575 .62693 Mtetra
.636 .604 .8 r
.24575 .62693 .24677 .62888 .24842 .62834 .2474 .62641 Mtetra
.634 .606 .804 r
.2474 .62641 .24842 .62834 .25007 .6277 .24904 .62591 Mtetra
.636 .621 .818 r
.24904 .62591 .25007 .6277 .25174 .62703 .25069 .62542 Mtetra
.64 .644 .838 r
.25069 .62542 .25174 .62703 .2534 .62636 .25234 .62492 Mtetra
.641 .669 .861 r
.25234 .62492 .2534 .62636 .25504 .62595 .25399 .62444 Mtetra
.643 .659 .85 r
.25399 .62444 .25504 .62595 .25669 .62551 .25564 .62394 Mtetra
.648 .652 .84 r
.25564 .62394 .25669 .62551 .25835 .62483 .25729 .6234 Mtetra
.674 .682 .849 r
.25729 .6234 .25835 .62483 .2601 .62308 .25896 .62273 Mtetra
.673 .901 .977 r
.25896 .62273 .2601 .62308 .26192 .6204 .26063 .62202 Mtetra
.217 0 0 r
.26063 .62202 .26192 .6204 .26382 .61666 .2623 .62131 Mtetra
.461 .158 .364 r
.2623 .62131 .26382 .61666 .26561 .61433 .26396 .62076 Mtetra
.49 .208 .413 r
.26396 .62076 .26561 .61433 .26726 .61382 .26561 .62029 Mtetra
.492 .21 .414 r
.26561 .62029 .26726 .61382 .26886 .61406 .26727 .61984 Mtetra
.514 .224 .411 r
.26727 .61984 .26886 .61406 .27043 .61469 .26889 .61976 Mtetra
.493 .194 .388 r
.26889 .61976 .27043 .61469 .27205 .61467 .27054 .61948 Mtetra
.42 .122 .351 r
.27054 .61948 .27205 .61467 .27377 .61328 .27223 .61852 Mtetra
0 0 .116 r
.27223 .61852 .27377 .61328 .28926 .42236 .27418 .6141 Mtetra
0 0 .169 r
.27418 .6141 .28926 .42236 .29162 .41088 .29027 .41455 Mtetra
.918 .857 .415 r
.29027 .41455 .29162 .41088 .2934 .40733 .29233 .40719 Mtetra
.889 .909 .834 r
.29233 .40719 .2934 .40733 .29502 .40606 .29399 .40533 Mtetra
.685 .805 .939 r
.29399 .40533 .29502 .40606 .29658 .40563 .29557 .4047 Mtetra
.566 .726 .949 r
.29557 .4047 .29658 .40563 .29813 .40546 .29711 .40447 Mtetra
.643 .738 .918 r
.29711 .40447 .29813 .40546 .2997 .40482 .29868 .40401 Mtetra
.674 .785 .933 r
.29868 .40401 .2997 .40482 .30129 .40405 .30025 .40343 Mtetra
.653 .828 .967 r
.30025 .40343 .30129 .40405 .30286 .40349 .30183 .40289 Mtetra
.711 .842 .945 r
.30183 .40289 .30286 .40349 .30439 .40359 .30341 .40215 Mtetra
.665 .666 .842 r
.30341 .40215 .30439 .40359 .30587 .40448 .30499 .40156 Mtetra
.558 .483 .727 r
.30499 .40156 .30587 .40448 .30725 .40676 .30653 .40152 Mtetra
.247 .194 .598 r
.30653 .40152 .30725 .40676 .29609 .59664 .3079 .40411 Mtetra
0 0 .206 r
.3079 .40411 .29609 .59664 .29689 .60912 .29627 .60131 Mtetra
0 0 .284 r
.29627 .60131 .29689 .60912 .29835 .61188 .29735 .60975 Mtetra
.141 .304 .769 r
.29735 .60975 .29835 .61188 .29996 .61242 .29891 .61103 Mtetra
.605 .665 .881 r
.29891 .61103 .29996 .61242 .30164 .61194 .30058 .61071 Mtetra
.709 .725 .862 r
.30058 .61071 .30164 .61194 .30335 .61089 .30228 .60986 Mtetra
.636 .741 .924 r
.30228 .60986 .30335 .61089 .30509 .60945 .30396 .60939 Mtetra
.403 .849 .92 r
.30396 .60939 .30509 .60945 .30687 .60739 .30564 .60897 Mtetra
.068 0 0 r
.30564 .60897 .30687 .60739 .30875 .60389 .30735 .60793 Mtetra
0 0 .028 r
.30735 .60793 .30875 .60389 .32233 .41327 .30925 .6041 Mtetra
0 0 .194 r
.30925 .6041 .32233 .41327 .32473 .39975 .3233 .40558 Mtetra
.763 .742 .22 r
.3233 .40558 .32473 .39975 .3265 .39624 .32543 .39634 Mtetra
.92 .934 .8 r
.32543 .39634 .3265 .39624 .32814 .39483 .32712 .39412 Mtetra
.691 .815 .941 r
.32712 .39412 .32814 .39483 .32972 .3944 .32871 .39346 Mtetra
.555 .723 .952 r
.32871 .39346 .32972 .3944 .33128 .39429 .33028 .39326 Mtetra
.598 .717 .928 r
.33028 .39326 .33128 .39429 .33285 .39402 .33186 .39296 Mtetra
.65 .727 .905 r
.33186 .39296 .33285 .39402 .33444 .39352 .33345 .39247 Mtetra
.653 .73 .906 r
.33345 .39247 .33444 .39352 .33604 .39295 .33504 .39196 Mtetra
.673 .749 .908 r
.33504 .39196 .33604 .39295 .33764 .39214 .33663 .39137 Mtetra
.687 .801 .935 r
.33663 .39137 .33764 .39214 .33926 .39127 .33823 .39073 Mtetra
.672 .854 .969 r
.33823 .39073 .33926 .39127 .34086 .39062 .33983 .3901 Mtetra
.719 .867 .951 r
.33983 .3901 .34086 .39062 .34242 .39057 .34144 .38931 Mtetra
.691 .704 .857 r
.34144 .38931 .34242 .39057 .34395 .39133 .34305 .38859 Mtetra
.579 .506 .737 r
.34305 .38859 .34395 .39133 .3454 .39328 .34463 .3884 Mtetra
.327 .26 .628 r
.34463 .3884 .3454 .39328 .34644 .40289 .34608 .39037 Mtetra
.966 .702 .481 r
.34608 .39037 .34644 .40289 .33747 .59521 .33694 .58461 Mtetra
0 0 .24 r
.33694 .58461 .33747 .59521 .33897 .5985 .33794 .5968 Mtetra
0 .116 .667 r
.33794 .5968 .33897 .5985 .3406 .59928 .33952 .5985 Mtetra
.58 .785 .976 r
.33952 .5985 .3406 .59928 .3423 .59885 .34122 .59815 Mtetra
.733 .836 .929 r
.34122 .59815 .3423 .59885 .34402 .59808 .34295 .59726 Mtetra
.714 .807 .923 r
.34295 .59726 .34402 .59808 .34573 .59745 .34467 .59645 Mtetra
.648 .753 .926 r
.34467 .59645 .34573 .59745 .34743 .59709 .34638 .59592 Mtetra
.647 .721 .902 r
.34638 .59592 .34743 .59709 .34913 .59674 .34809 .5954 Mtetra
.645 .692 .879 r
.34809 .5954 .34913 .59674 .35084 .59632 .3498 .59489 Mtetra
.642 .676 .867 r
.3498 .59489 .35084 .59632 .35255 .59584 .35151 .59439 Mtetra
.64 .672 .865 r
.35151 .59439 .35255 .59584 .35426 .59533 .35322 .59389 Mtetra
.638 .673 .867 r
.35322 .59389 .35426 .59533 .35597 .59483 .35493 .59341 Mtetra
.637 .675 .87 r
.35493 .59341 .35597 .59483 .35768 .59433 .35665 .59293 Mtetra
.638 .679 .872 r
.35665 .59293 .35768 .59433 .3594 .59384 .35836 .59245 Mtetra
.641 .682 .873 r
.35836 .59245 .3594 .59384 .36111 .59336 .36008 .59195 Mtetra
.645 .68 .869 r
.36008 .59195 .36111 .59336 .36283 .59289 .36179 .59143 Mtetra
.646 .673 .862 r
.36179 .59143 .36283 .59289 .36454 .59242 .36351 .5909 Mtetra
.593 .644 .87 r
.36351 .5909 .36454 .59242 .36625 .59209 .36522 .59063 Mtetra
.562 .638 .884 r
.36522 .59063 .36625 .59209 .36796 .59183 .36693 .59048 Mtetra
.675 .701 .866 r
.36693 .59048 .36796 .59183 .36969 .5912 .36866 .5898 Mtetra
.841 .731 .743 r
.36866 .5898 .36969 .5912 .37147 .58938 .37047 .58724 Mtetra
.915 .693 .587 r
.37047 .58724 .37147 .58938 .37337 .58494 .37267 .57622 Mtetra
.945 .68 .503 r
.37267 .57622 .37337 .58494 .38347 .39393 .38315 .37795 Mtetra
.615 .405 .573 r
.38315 .37795 .38347 .39393 .38562 .38141 .38489 .3747 Mtetra
.593 .424 .621 r
.38489 .3747 .38562 .38141 .38725 .38075 .38652 .3739 Mtetra
.564 .401 .619 r
.38652 .3739 .38725 .38075 .38886 .38071 .38813 .37364 Mtetra
.566 .4 .616 r
.38813 .37364 .38886 .38071 .39054 .37882 .38975 .37333 Mtetra
.598 .441 .64 r
.38975 .37333 .39054 .37882 .39228 .37555 .39138 .37262 Mtetra
.635 .532 .719 r
.39138 .37262 .39228 .37555 .39398 .37319 .39302 .37191 Mtetra
.676 .699 .864 r
.39302 .37191 .39398 .37319 .39565 .37174 .39465 .37126 Mtetra
.631 .866 .986 r
.39465 .37126 .39565 .37174 .39728 .37107 .39628 .37071 Mtetra
.597 .883 .992 r
.39628 .37071 .39728 .37107 .3989 .37064 .39791 .37018 Mtetra
.621 .868 .989 r
.39791 .37018 .3989 .37064 .40053 .37029 .39954 .36965 Mtetra
.655 .83 .968 r
.39954 .36965 .40053 .37029 .40215 .36989 .40117 .36908 Mtetra
.665 .793 .943 r
.40117 .36908 .40215 .36989 .40378 .36946 .4028 .3685 Mtetra
.669 .759 .918 r
.4028 .3685 .40378 .36946 .40541 .36891 .40444 .36792 Mtetra
.67 .753 .913 r
.40444 .36792 .40541 .36891 .40705 .36818 .40607 .36733 Mtetra
.67 .785 .935 r
.40607 .36733 .40705 .36818 .4087 .36742 .40771 .36674 Mtetra
.709 .835 .942 r
.40771 .36674 .4087 .36742 .41034 .36659 .40936 .36599 Mtetra
.752 .856 .926 r
.40936 .36599 .41034 .36659 .41199 .36574 .41101 .36504 Mtetra
.642 .813 .965 r
.41101 .36504 .41199 .36574 .41363 .36521 .41264 .36452 Mtetra
0 .316 .738 r
.41264 .36452 .41363 .36521 .41524 .36548 .41424 .36534 Mtetra
.923 .565 .333 r
.41424 .36534 .41524 .36548 .41678 .3677 .41564 .37162 Mtetra
.952 .678 .481 r
.41564 .37162 .41678 .3677 .41812 .37636 .41051 .57238 Mtetra
.546 .321 .525 r
.41051 .57238 .41812 .37636 .41333 .57163 .41213 .57579 Mtetra
.517 .199 .367 r
.41213 .57579 .41333 .57163 .41497 .57455 .41386 .57587 Mtetra
.222 0 0 r
.41386 .57587 .41497 .57455 .41666 .57575 .41561 .57529 Mtetra
.683 .891 .973 r
.41561 .57529 .41666 .57575 .41839 .57607 .41737 .57452 Mtetra
.641 .662 .855 r
.41737 .57452 .41839 .57607 .42014 .57569 .41913 .57401 Mtetra
.646 .646 .836 r
.41913 .57401 .42014 .57569 .4219 .57505 .42089 .57344 Mtetra
.65 .658 .844 r
.42089 .57344 .4219 .57505 .42366 .57435 .42265 .57286 Mtetra
.649 .674 .86 r
.42265 .57286 .42366 .57435 .42542 .57384 .42441 .5723 Mtetra
.649 .667 .854 r
.42441 .5723 .42542 .57384 .42718 .57332 .42617 .57174 Mtetra
.621 .649 .857 r
.42617 .57174 .42718 .57332 .42894 .57289 .42792 .57132 Mtetra
.552 .621 .874 r
.42792 .57132 .42894 .57289 .43069 .57265 .42968 .57122 Mtetra
.652 .685 .868 r
.42968 .57122 .43069 .57265 .43246 .57208 .43144 .57065 Mtetra
.806 .729 .779 r
.43144 .57065 .43246 .57208 .43424 .57065 .43324 .56874 Mtetra
.913 .704 .607 r
.43324 .56874 .43424 .57065 .4361 .56665 .43521 .56068 Mtetra
.955 .684 .485 r
.43521 .56068 .4361 .56665 .43818 .55375 .44221 .3586 Mtetra
.549 .328 .532 r
.44221 .3586 .43818 .55375 .44478 .36096 .44396 .35437 Mtetra
.602 .431 .623 r
.44396 .35437 .44478 .36096 .44645 .36 .44563 .3534 Mtetra
.571 .409 .623 r
.44563 .3534 .44645 .36 .4481 .35986 .44729 .35303 Mtetra
.562 .401 .62 r
.44729 .35303 .4481 .35986 .44978 .35877 .44894 .3528 Mtetra
.594 .433 .632 r
.44894 .3528 .44978 .35877 .45151 .35541 .45061 .35208 Mtetra
.627 .511 .702 r
.45061 .35208 .45151 .35541 .45321 .35295 .45227 .35135 Mtetra
.67 .656 .827 r
.45227 .35135 .45321 .35295 .4549 .35127 .45394 .35067 Mtetra
.645 .844 .977 r
.45394 .35067 .4549 .35127 .45657 .35053 .4556 .35011 Mtetra
.606 .875 .992 r
.4556 .35011 .45657 .35053 .45823 .35006 .45727 .34957 Mtetra
.613 .864 .99 r
.45727 .34957 .45823 .35006 .4599 .34971 .45894 .34905 Mtetra
.645 .829 .971 r
.45894 .34905 .4599 .34971 .46156 .34931 .46061 .34849 Mtetra
.655 .793 .948 r
.46061 .34849 .46156 .34931 .46323 .34891 .46227 .34794 Mtetra
.658 .76 .925 r
.46227 .34794 .46323 .34891 .46489 .34843 .46394 .34739 Mtetra
.658 .744 .914 r
.46394 .34739 .46489 .34843 .46657 .34773 .46562 .34683 Mtetra
.658 .777 .937 r
.46562 .34683 .46657 .34773 .46824 .34698 .46729 .34628 Mtetra
.654 .82 .963 r
.46729 .34628 .46824 .34698 .46992 .34626 .46896 .34571 Mtetra
.648 .858 .98 r
.46896 .34571 .46992 .34626 .47159 .34565 .47064 .34511 Mtetra
.648 .861 .981 r
.47064 .34511 .47159 .34565 .47327 .34507 .47231 .34452 Mtetra
.649 .857 .979 r
.47231 .34452 .47327 .34507 .47494 .34451 .47399 .34392 Mtetra
.648 .848 .977 r
.47399 .34392 .47494 .34451 .47662 .34394 .47567 .34334 Mtetra
.648 .844 .976 r
.47567 .34334 .47662 .34394 .4783 .34338 .47735 .34276 Mtetra
.648 .841 .975 r
.47735 .34276 .4783 .34338 .47998 .34281 .47903 .34218 Mtetra
.648 .839 .974 r
.47903 .34218 .47998 .34281 .48166 .34224 .48071 .34161 Mtetra
.648 .838 .973 r
.48071 .34161 .48166 .34224 .48334 .34168 .48239 .34104 Mtetra
.647 .837 .973 r
.48239 .34104 .48334 .34168 .48502 .34111 .48407 .34047 Mtetra
.646 .837 .974 r
.48407 .34047 .48502 .34111 .4867 .34054 .48576 .3399 Mtetra
.645 .837 .975 r
.48576 .3399 .4867 .34054 .48839 .33997 .48744 .33934 Mtetra
.642 .838 .976 r
.48744 .33934 .48839 .33997 .49007 .3394 .48913 .33878 Mtetra
.636 .839 .978 r
.48913 .33878 .49007 .3394 .49176 .33881 .49081 .33823 Mtetra
.631 .848 .983 r
.49081 .33823 .49176 .33881 .49345 .33825 .4925 .33769 Mtetra
.631 .853 .984 r
.4925 .33769 .49345 .33825 .49513 .33772 .49419 .33713 Mtetra
.644 .851 .979 r
.49419 .33713 .49513 .33772 .49682 .3373 .49588 .33655 Mtetra
.659 .814 .958 r
.49588 .33655 .49682 .3373 .49851 .33691 .49757 .33597 Mtetra
.664 .771 .929 r
.49757 .33597 .49851 .33691 .5002 .33649 .49927 .33538 Mtetra
.658 .734 .905 r
.49927 .33538 .5002 .33649 .50189 .33596 .50096 .33482 Mtetra
.658 .728 .901 r
.50096 .33482 .50189 .33596 .50359 .33536 .50265 .33426 Mtetra
.661 .735 .904 r
.50265 .33426 .50359 .33536 .50528 .33472 .50435 .33369 Mtetra
.677 .755 .91 r
.50435 .33369 .50528 .33472 .50698 .33378 .50605 .33304 Mtetra
.672 .821 .955 r
.50605 .33304 .50698 .33378 .50868 .33299 .50774 .33241 Mtetra
.65 .854 .978 r
.50774 .33241 .50868 .33299 .51038 .33249 .50944 .33181 Mtetra
.611 .816 .979 r
.50944 .33181 .51038 .33249 .51207 .33323 .51114 .33135 Mtetra
.621 .602 .81 r
.51114 .33135 .51207 .33323 .51376 .33476 .51284 .33091 Mtetra
.594 .474 .686 r
.51284 .33091 .51376 .33476 .51546 .33741 .51454 .33047 Mtetra
.602 .429 .619 r
.51454 .33047 .51546 .33741 .51716 .33662 .51625 .32942 Mtetra
.586 .415 .616 r
.51625 .32942 .51716 .33662 .51887 .33559 .51795 .32869 Mtetra
.552 .393 .62 r
.51795 .32869 .51887 .33559 .52058 .33568 .51966 .32865 Mtetra
.197 .14 .563 r
.51966 .32865 .52058 .33568 .52212 .53364 .52136 .33306 Mtetra
0 0 .337 r
.52136 .33306 .52212 .53364 .52394 .54083 .52295 .53637 Mtetra
0 0 .463 r
.52295 .53637 .52394 .54083 .52576 .54327 .52477 .54153 Mtetra
.449 .546 .863 r
.52477 .54153 .52576 .54327 .52759 .54326 .5266 .54185 Mtetra
.648 .692 .877 r
.5266 .54185 .52759 .54326 .52941 .54266 .52843 .54129 Mtetra
.717 .723 .854 r
.52843 .54129 .52941 .54266 .53124 .54178 .53026 .54032 Mtetra
.645 .682 .871 r
.53026 .54032 .53124 .54178 .53307 .54139 .53209 .53976 Mtetra
.641 .658 .851 r
.53209 .53976 .53307 .54139 .5349 .5409 .53392 .53922 Mtetra
.65 .655 .842 r
.53392 .53922 .5349 .5409 .53673 .54011 .53575 .53861 Mtetra
.589 .654 .882 r
.53575 .53861 .53673 .54011 .53856 .53852 .53758 .53833 Mtetra
.527 .9 .961 r
.53758 .53833 .53856 .53852 .54039 .53603 .53942 .53772 Mtetra
.054 0 0 r
.53942 .53772 .54039 .53603 .5422 .5315 .54125 .53638 Mtetra
0 0 .106 r
.54125 .53638 .5422 .5315 .54289 .33061 .54306 .53069 Mtetra
0 0 .334 r
.54306 .53069 .54289 .33061 .54457 .32324 .54368 .32593 Mtetra
.804 .791 .294 r
.54368 .32593 .54457 .32324 .54628 .32018 .54536 .31982 Mtetra
.847 .927 .882 r
.54536 .31982 .54628 .32018 .54799 .31915 .54708 .31829 Mtetra
.662 .794 .945 r
.54708 .31829 .54799 .31915 .54972 .31872 .5488 .31769 Mtetra
.56 .715 .945 r
.5488 .31769 .54972 .31872 .55144 .31854 .55053 .31747 Mtetra
.659 .745 .913 r
.55053 .31747 .55144 .31854 .55317 .31775 .55226 .3169 Mtetra
.67 .796 .942 r
.55226 .3169 .55317 .31775 .55489 .31694 .55398 .31627 Mtetra
.648 .834 .972 r
.55398 .31627 .55489 .31694 .55662 .31638 .55571 .31569 Mtetra
.72 .847 .942 r
.55571 .31569 .55662 .31638 .55835 .31658 .55744 .31485 Mtetra
.65 .636 .822 r
.55744 .31485 .55835 .31658 .5601 .3176 .55917 .31425 Mtetra
.549 .464 .712 r
.55917 .31425 .5601 .3176 .56187 .3203 .5609 .31428 Mtetra
.247 .191 .596 r
.5609 .31428 .56187 .3203 .56606 .51897 .56268 .31774 Mtetra
0 0 .357 r
.56268 .31774 .56606 .51897 .56802 .52708 .56699 .52116 Mtetra
0 0 .474 r
.56699 .52116 .56802 .52708 .56991 .52948 .56893 .52751 Mtetra
.359 .467 .834 r
.56893 .52751 .56991 .52948 .57177 .52956 .5708 .52824 Mtetra
.635 .705 .897 r
.5708 .52824 .57177 .52956 .57363 .52884 .57266 .52774 Mtetra
.726 .774 .891 r
.57266 .52774 .57363 .52884 .57548 .52783 .57451 .52677 Mtetra
.553 .724 .953 r
.57451 .52677 .57548 .52783 .57734 .52771 .57638 .52654 Mtetra
.592 .715 .929 r
.57638 .52654 .57734 .52771 .57921 .52753 .57824 .5262 Mtetra
.726 .736 .858 r
.57824 .5262 .57921 .52753 .58107 .52665 .5801 .52517 Mtetra
.908 .745 .667 r
.5801 .52517 .58107 .52665 .58286 .52211 .58189 .52065 Mtetra
.971 .688 .433 r
.58189 .52065 .58286 .52211 .58105 .31617 .58016 .31574 Mtetra
.978 .774 .562 r
.58016 .31574 .58105 .31617 .58266 .30828 .58177 .30768 Mtetra
.877 .874 .83 r
.58177 .30768 .58266 .30828 .58438 .3065 .58349 .30578 Mtetra
.66 .829 .965 r
.58349 .30578 .58438 .3065 .58613 .30604 .58523 .30516 Mtetra
.524 .736 .972 r
.58523 .30516 .58613 .30604 .58789 .30606 .58699 .30498 Mtetra
.619 .732 .927 r
.58699 .30498 .58789 .30606 .58964 .30572 .58874 .30456 Mtetra
.653 .728 .904 r
.58874 .30456 .58964 .30572 .59139 .30515 .59049 .304 Mtetra
.655 .73 .905 r
.59049 .304 .59139 .30515 .59314 .30453 .59224 .30344 Mtetra
.736 .769 .879 r
.59224 .30344 .59314 .30453 .59488 .3034 .59399 .30246 Mtetra
.721 .795 .91 r
.59399 .30246 .59488 .3034 .59662 .3024 .59573 .30159 Mtetra
.548 .769 .98 r
.59573 .30159 .59662 .3024 .59838 .30201 .59749 .30132 Mtetra
.753 .259 0 r
.59749 .30132 .59838 .30201 .60021 .30466 .59933 .30396 Mtetra
.972 .68 .41 r
.59933 .30396 .60021 .30466 .60702 .50882 .60605 .50706 Mtetra
.921 .556 .126 r
.60605 .50706 .60702 .50882 .60911 .51699 .60815 .51535 Mtetra
.146 .382 .834 r
.60815 .51535 .60911 .51699 .61104 .51813 .61007 .51651 Mtetra
.621 .655 .862 r
.61007 .51651 .61104 .51813 .61292 .51758 .61196 .51607 Mtetra
.71 .706 .845 r
.61196 .51607 .61292 .51758 .61479 .51629 .61383 .51509 Mtetra
.635 .73 .916 r
.61383 .51509 .61479 .51629 .61664 .51469 .61572 .51457 Mtetra
.394 .845 .913 r
.61572 .51457 .61664 .51469 .61848 .51255 .61761 .51409 Mtetra
.121 0 0 r
.61761 .51409 .61848 .51255 .62029 .50909 .61948 .51299 Mtetra
0 0 .152 r
.61948 .51299 .62029 .50909 .62172 .49307 .62128 .50902 Mtetra
.985 .703 .379 r
.62128 .50902 .62172 .49307 .61787 .3001 .61718 .30568 Mtetra
0 0 0 r
.61718 .30568 .61787 .3001 .61954 .29623 .61867 .29566 Mtetra
.906 .877 .796 r
.61867 .29566 .61954 .29623 .62128 .29464 .62039 .29339 Mtetra
.678 .722 .882 r
.62039 .29339 .62128 .29464 .62305 .294 .62216 .2927 Mtetra
.573 .67 .904 r
.62216 .2927 .62305 .294 .62483 .29367 .62394 .29248 Mtetra
.625 .713 .909 r
.62394 .29248 .62483 .29367 .6266 .29306 .62572 .29204 Mtetra
.677 .768 .919 r
.62572 .29204 .6266 .29306 .62836 .29229 .62749 .29137 Mtetra
.672 .787 .936 r
.62749 .29137 .62836 .29229 .63014 .29174 .62926 .29072 Mtetra
.718 .781 .901 r
.62926 .29072 .63014 .29174 .63193 .29173 .63103 .28985 Mtetra
.672 .633 .802 r
.63103 .28985 .63193 .29173 .63376 .29247 .6328 .28906 Mtetra
.577 .481 .709 r
.6328 .28906 .63376 .29247 .63563 .29451 .63459 .28883 Mtetra
.371 .286 .629 r
.63459 .28883 .63563 .29451 .64407 .47844 .63647 .29106 Mtetra
0 0 .37 r
.63647 .29106 .64407 .47844 .64682 .50139 .64562 .49287 Mtetra
0 0 .44 r
.64562 .49287 .64682 .50139 .64886 .50447 .6479 .50266 Mtetra
0 .233 .748 r
.6479 .50266 .64886 .50447 .65083 .50556 .6499 .50447 Mtetra
.509 .7 .956 r
.6499 .50447 .65083 .50556 .65277 .50557 .65183 .50437 Mtetra
.749 .772 .872 r
.65183 .50437 .65277 .50557 .65467 .50465 .65372 .50322 Mtetra
.896 .761 .705 r
.65372 .50322 .65467 .50465 .65647 .50122 .65552 .49969 Mtetra
.975 .685 .405 r
.65552 .49969 .65647 .50122 .65043 .30269 .64968 .30484 Mtetra
.993 .753 .394 r
.64968 .30484 .65043 .30269 .65155 .28558 .6507 .28497 Mtetra
.929 .864 .755 r
.6507 .28497 .65155 .28558 .65326 .28295 .6524 .28224 Mtetra
.698 .85 .956 r
.6524 .28224 .65326 .28295 .65504 .28232 .65418 .28146 Mtetra
.552 .758 .973 r
.65418 .28146 .65504 .28232 .65686 .28224 .65599 .28119 Mtetra
.601 .733 .938 r
.65599 .28119 .65686 .28224 .65866 .28191 .65779 .28082 Mtetra
.669 .752 .913 r
.65779 .28082 .65866 .28191 .66045 .28118 .65958 .28018 Mtetra
.664 .769 .928 r
.65958 .28018 .66045 .28118 .66224 .28062 .66138 .27956 Mtetra
.706 .771 .903 r
.66138 .27956 .66224 .28062 .66406 .28054 .66316 .27874 Mtetra
.68 .648 .811 r
.66316 .27874 .66406 .28054 .66591 .28117 .66495 .27791 Mtetra
.587 .494 .716 r
.66495 .27791 .66591 .28117 .66782 .28293 .66676 .27759 Mtetra
.413 .322 .643 r
.66676 .27759 .66782 .28293 .67006 .29166 .66867 .27929 Mtetra
.98 .685 .342 r
.66867 .27929 .67006 .29166 .68126 .49001 .67964 .47412 Mtetra
0 0 .428 r
.67964 .47412 .68126 .49001 .68338 .49352 .68241 .49141 Mtetra
0 .179 .707 r
.68241 .49141 .68338 .49352 .6854 .49476 .68448 .49364 Mtetra
.486 .683 .953 r
.68448 .49364 .6854 .49476 .68736 .49483 .68644 .49362 Mtetra
.743 .771 .876 r
.68644 .49362 .68736 .49483 .68928 .49394 .68835 .4925 Mtetra
.893 .763 .711 r
.68835 .4925 .68928 .49394 .69109 .49073 .69015 .4891 Mtetra
.976 .683 .391 r
.69015 .4891 .69109 .49073 .68298 .29225 .68209 .29064 Mtetra
.971 .712 .482 r
.68209 .29064 .68298 .29225 .68391 .27435 .68307 .27362 Mtetra
.938 .841 .721 r
.68307 .27362 .68391 .27435 .68559 .27125 .68475 .27045 Mtetra
.776 .849 .906 r
.68475 .27045 .68559 .27125 .68738 .27024 .68653 .26929 Mtetra
.554 .741 .963 r
.68653 .26929 .68738 .27024 .68922 .27014 .68836 .26904 Mtetra
0 .252 .756 r
.68836 .26904 .68922 .27014 .69114 .27169 .69028 .27045 Mtetra
.915 .538 .114 r
.69028 .27045 .69114 .27169 .69347 .28043 .69257 .27858 Mtetra
.976 .674 .364 r
.69257 .27858 .69347 .28043 .70654 .48468 .70563 .48342 Mtetra
.579 .134 0 r
.70563 .48342 .70654 .48468 .70868 .48756 .70777 .4864 Mtetra
.427 .644 .948 r
.70777 .4864 .70868 .48756 .71067 .4877 .70976 .48656 Mtetra
.72 .779 .899 r
.70976 .48656 .71067 .4877 .7126 .48673 .71169 .4856 Mtetra
.901 .805 .745 r
.71169 .4856 .7126 .48673 .71442 .48379 .71351 .48265 Mtetra
.978 .738 .503 r
.71351 .48265 .71442 .48379 .7157 .4716 .71478 .47028 Mtetra
.977 .681 .379 r
.71478 .47028 .7157 .4716 .70577 .26822 .70492 .26704 Mtetra
.917 .786 .702 r
.70492 .26704 .70577 .26822 .70743 .26479 .70658 .26362 Mtetra
.717 .759 .886 r
.70658 .26362 .70743 .26479 .70924 .26388 .70839 .26272 Mtetra
.595 .711 .925 r
.70839 .26272 .70924 .26388 .71108 .26354 .71023 .26238 Mtetra
.63 .727 .918 r
.71023 .26238 .71108 .26354 .71291 .26306 .71207 .2619 Mtetra
.737 .768 .878 r
.71207 .2619 .71291 .26306 .71472 .26204 .71387 .26088 Mtetra
.647 .736 .914 r
.71387 .26088 .71472 .26204 .71655 .26148 .71571 .26032 Mtetra
.09 .419 .866 r
.71571 .26032 .71655 .26148 .71848 .26244 .71764 .2613 Mtetra
.914 .535 .111 r
.71764 .2613 .71848 .26244 .72087 .27071 .72004 .26967 Mtetra
.975 .671 .352 r
.72004 .26967 .72087 .27071 .73585 .4755 .73496 .47443 Mtetra
.604 .136 0 r
.73496 .47443 .73585 .4755 .73804 .47839 .73715 .47733 Mtetra
.537 .724 .96 r
.73715 .47733 .73804 .47839 .74003 .47816 .73915 .47712 Mtetra
.703 .798 .923 r
.73915 .47712 .74003 .47816 .74199 .47729 .7411 .47625 Mtetra
.689 .794 .929 r
.7411 .47625 .74199 .47729 .74395 .47658 .74306 .47545 Mtetra
.524 .703 .952 r
.74306 .47545 .74395 .47658 .74597 .47666 .74507 .47531 Mtetra
.657 .721 .896 r
.74507 .47531 .74597 .47666 .74796 .4762 .74704 .47466 Mtetra
.83 .75 .775 r
.74704 .47466 .74796 .4762 .74984 .47421 .74891 .47246 Mtetra
.959 .732 .552 r
.74891 .47246 .74984 .47421 .7513 .46618 .75031 .4635 Mtetra
.977 .677 .366 r
.75031 .4635 .7513 .46618 .73886 .25805 .73801 .25667 Mtetra
.924 .766 .667 r
.73801 .25667 .73886 .25805 .74045 .2537 .73962 .25259 Mtetra
.737 .78 .887 r
.73962 .25259 .74045 .2537 .74226 .25267 .74144 .25158 Mtetra
.606 .732 .934 r
.74144 .25158 .74226 .25267 .74413 .25229 .7433 .25117 Mtetra
.606 .729 .932 r
.7433 .25117 .74413 .25229 .74599 .25192 .74517 .25078 Mtetra
.747 .777 .878 r
.74517 .25078 .74599 .25192 .74781 .25085 .74698 .2497 Mtetra
.661 .745 .912 r
.74698 .2497 .74781 .25085 .74966 .25023 .74883 .24907 Mtetra
.225 .508 .908 r
.74883 .24907 .74966 .25023 .75161 .25093 .75078 .24977 Mtetra
.89 .5 .051 r
.75078 .24977 .75161 .25093 .75407 .25845 .75324 .25733 Mtetra
.975 .667 .334 r
.75324 .25733 .75407 .25845 .77143 .46446 .77055 .46335 Mtetra
.649 .194 0 r
.77055 .46335 .77143 .46446 .77372 .46787 .77285 .46676 Mtetra
.385 .633 .953 r
.77285 .46676 .77372 .46787 .77578 .46813 .77491 .46701 Mtetra
.693 .781 .918 r
.77491 .46701 .77578 .46813 .77776 .4673 .77689 .46618 Mtetra
.873 .82 .793 r
.77689 .46618 .77776 .4673 .77962 .46498 .77875 .46386 Mtetra
.978 .767 .552 r
.77875 .46386 .77962 .46498 .78106 .45714 .78019 .45601 Mtetra
.977 .675 .347 r
.78019 .45601 .78106 .45714 .7667 .2488 .76587 .24762 Mtetra
.95 .784 .641 r
.76587 .24762 .7667 .2488 .76824 .24417 .76742 .24299 Mtetra
.746 .772 .874 r
.76742 .24299 .76824 .24417 .77007 .24308 .76925 .2419 Mtetra
.619 .722 .92 r
.76925 .2419 .77007 .24308 .77195 .24264 .77113 .24145 Mtetra
.587 .707 .926 r
.77113 .24145 .77195 .24264 .77384 .24232 .77302 .24113 Mtetra
.747 .771 .873 r
.77302 .24113 .77384 .24232 .77567 .24122 .77485 .24003 Mtetra
.672 .743 .904 r
.77485 .24003 .77567 .24122 .77753 .24054 .77672 .23935 Mtetra
.361 .584 .928 r
.77672 .23935 .77753 .24054 .77949 .24094 .77867 .23974 Mtetra
.827 .421 0 r
.77867 .23974 .77949 .24094 .78192 .24693 .78109 .24568 Mtetra
.973 .663 .318 r
.78109 .24568 .78192 .24693 .80135 .45446 .80049 .45328 Mtetra
.688 .248 0 r
.80049 .45328 .80135 .45446 .80376 .45848 .8029 .45732 Mtetra
.362 .609 .944 r
.8029 .45732 .80376 .45848 .80586 .45885 .80499 .45766 Mtetra
.68 .765 .915 r
.80499 .45766 .80586 .45885 .80786 .45809 .807 .45689 Mtetra
.856 .811 .805 r
.807 .45689 .80786 .45809 .80974 .45589 .80888 .45474 Mtetra
.978 .772 .557 r
.80888 .45474 .80974 .45589 .81109 .44766 .81031 .44735 Mtetra
.976 .672 .33 r
.81031 .44735 .81109 .44766 .79474 .23867 .79401 .23834 Mtetra
.994 .852 .589 r
.79401 .23834 .79474 .23867 .79627 .23402 .7955 .23334 Mtetra
.766 .889 .932 r
.7955 .23334 .79627 .23402 .79812 .23308 .79734 .23221 Mtetra
.599 .789 .972 r
.79734 .23221 .79812 .23308 .80004 .23282 .79924 .23177 Mtetra
.521 .707 .955 r
.79924 .23177 .80004 .23282 .80198 .23287 .80117 .23163 Mtetra
.651 .727 .905 r
.80117 .23163 .80198 .23287 .80388 .23231 .80306 .23104 Mtetra
.653 .723 .9 r
.80306 .23104 .80388 .23231 .80576 .23169 .80496 .23044 Mtetra
.666 .731 .899 r
.80496 .23044 .80576 .23169 .80765 .23099 .80684 .22977 Mtetra
.755 .773 .867 r
.80684 .22977 .80765 .23099 .80949 .22981 .80868 .2286 Mtetra
.689 .751 .899 r
.80868 .2286 .80949 .22981 .81136 .22902 .81056 .22783 Mtetra
.469 .647 .936 r
.81056 .22783 .81136 .22902 .81332 .22909 .81252 .22791 Mtetra
.775 .359 0 r
.81252 .22791 .81332 .22909 .81577 .23432 .81498 .23317 Mtetra
.971 .657 .298 r
.81498 .23317 .81577 .23432 .8377 .44272 .83686 .44159 Mtetra
.727 .291 0 r
.83686 .44159 .8377 .44272 .84023 .44732 .83939 .44617 Mtetra
.309 .583 .939 r
.83939 .44617 .84023 .44732 .84238 .4478 .84154 .44665 Mtetra
.651 .765 .933 r
.84154 .44665 .84238 .4478 .84442 .44715 .84358 .44601 Mtetra
.831 .821 .839 r
.84358 .44601 .84442 .44715 .84635 .44535 .84551 .4442 Mtetra
.976 .788 .586 r
.84551 .4442 .84635 .44535 .84785 .43918 .84701 .43803 Mtetra
.974 .667 .312 r
.84701 .43803 .84785 .43918 .82903 .22928 .82824 .22807 Mtetra
.974 .775 .575 r
.82824 .22807 .82903 .22928 .83038 .22311 .82959 .22189 Mtetra
.766 .759 .846 r
.21715 .43115 .21819 .43212 .21977 .431 .21873 .43004 Mtetra
.632 .733 .921 r
.21873 .43004 .21977 .431 .22128 .4306 .22024 .42963 Mtetra
.495 .686 .952 r
.22024 .42963 .22128 .4306 .22276 .43056 .22172 .42959 Mtetra
.751 .757 .857 r
.22172 .42959 .22276 .43056 .22433 .42957 .22329 .42859 Mtetra
.692 .746 .892 r
.22329 .42859 .22433 .42957 .22587 .42892 .22483 .42794 Mtetra
.451 .664 .953 r
.22483 .42794 .22587 .42892 .22735 .42896 .22631 .428 Mtetra
.936 .578 .31 r
.22631 .428 .22735 .42896 .22842 .43344 .22735 .43285 Mtetra
.938 .682 .524 r
.22735 .43285 .22842 .43344 .21193 .63181 .21076 .63158 Mtetra
.902 .541 .345 r
.21076 .63158 .21193 .63181 .21307 .63675 .21192 .6362 Mtetra
.279 .701 .969 r
.21192 .6362 .21307 .63675 .21463 .63693 .21349 .63628 Mtetra
.72 .832 .934 r
.21349 .63628 .21463 .63693 .21628 .63623 .21515 .63547 Mtetra
.789 .809 .868 r
.21515 .63547 .21628 .63623 .21796 .6351 .21684 .63422 Mtetra
.651 .77 .936 r
.21684 .63422 .21796 .6351 .2196 .63447 .21848 .6337 Mtetra
.649 .794 .952 r
.21848 .6337 .2196 .63447 .22123 .63391 .22011 .63318 Mtetra
.7 .813 .935 r
.22011 .63318 .22123 .63391 .22287 .63337 .22176 .63246 Mtetra
.816 .78 .819 r
.22176 .63246 .22287 .63337 .2245 .63284 .22349 .63081 Mtetra
.781 .657 .726 r
.22349 .63081 .2245 .63284 .22613 .63234 .22527 .62862 Mtetra
.733 .568 .668 r
.22527 .62862 .22613 .63234 .22776 .63187 .22708 .62601 Mtetra
.618 .454 .637 r
.22708 .62601 .22776 .63187 .22939 .63144 .22877 .62491 Mtetra
.565 .408 .626 r
.22877 .62491 .22939 .63144 .23102 .63103 .23038 .62466 Mtetra
.545 .394 .628 r
.23038 .62466 .23102 .63103 .23265 .63063 .23196 .62474 Mtetra
.571 .419 .637 r
.23196 .62474 .23265 .63063 .23428 .63019 .23358 .62444 Mtetra
.576 .425 .639 r
.23358 .62444 .23428 .63019 .23591 .62975 .23521 .62407 Mtetra
.578 .427 .641 r
.23521 .62407 .23591 .62975 .23755 .6293 .23684 .62368 Mtetra
.58 .43 .642 r
.23684 .62368 .23755 .6293 .23918 .62886 .23847 .62325 Mtetra
.582 .431 .642 r
.23847 .62325 .23918 .62886 .24082 .6284 .2401 .62281 Mtetra
.583 .432 .642 r
.2401 .62281 .24082 .6284 .24246 .62794 .24174 .62234 Mtetra
.606 .449 .642 r
.24174 .62234 .24246 .62794 .24411 .62744 .24341 .62151 Mtetra
.593 .435 .637 r
.24341 .62151 .24411 .62744 .24575 .62693 .24507 .62084 Mtetra
.557 .407 .633 r
.24507 .62084 .24575 .62693 .2474 .62641 .24668 .62074 Mtetra
.424 .317 .629 r
.24668 .62074 .2474 .62641 .24904 .62591 .24817 .62214 Mtetra
.365 .327 .683 r
.24817 .62214 .24904 .62591 .25069 .62542 .24968 .62341 Mtetra
.315 .425 .815 r
.24968 .62341 .25069 .62542 .25234 .62492 .25123 .62418 Mtetra
.493 .755 .988 r
.25123 .62418 .25234 .62492 .25399 .62444 .25285 .62403 Mtetra
.598 .87 .993 r
.25285 .62403 .25399 .62444 .25564 .62394 .2545 .62353 Mtetra
.649 .881 .983 r
.2545 .62353 .25564 .62394 .25729 .6234 .25616 .6229 Mtetra
.572 .842 .996 r
.25616 .6229 .25729 .6234 .25896 .62273 .25781 .62249 Mtetra
.456 .85 .977 r
.25781 .62249 .25896 .62273 .26063 .62202 .25945 .62214 Mtetra
.271 .777 .812 r
.25945 .62214 .26063 .62202 .2623 .62131 .2611 .62175 Mtetra
0 0 0 r
.2611 .62175 .2623 .62131 .26396 .62076 .26276 .62121 Mtetra
.26276 .62121 .26396 .62076 .26561 .62029 .26442 .6206 Mtetra
.352 .823 .772 r
.26442 .6206 .26561 .62029 .26727 .61984 .26609 .61996 Mtetra
.161 .701 .753 r
.26609 .61996 .26727 .61984 .26889 .61976 .26774 .61969 Mtetra
.36 .824 .912 r
.26774 .61969 .26889 .61976 .27054 .61948 .26939 .61934 Mtetra
.668 .939 .965 r
.26939 .61934 .27054 .61948 .27223 .61852 .27107 .61853 Mtetra
.929 .895 .775 r
.27107 .61853 .27223 .61852 .27418 .6141 .27289 .61585 Mtetra
.994 .873 .584 r
.27289 .61585 .27418 .6141 .29027 .41455 .275 .60924 Mtetra
0 0 .186 r
.275 .60924 .29027 .41455 .29233 .40719 .29095 .41128 Mtetra
0 0 0 r
.29095 .41128 .29233 .40719 .29399 .40533 .2928 .40682 Mtetra
.2928 .40682 .29399 .40533 .29557 .4047 .29448 .40474 Mtetra
.823 .972 .894 r
.29448 .40474 .29557 .4047 .29711 .40447 .29611 .40339 Mtetra
.723 .739 .864 r
.29611 .40339 .29711 .40447 .29868 .40401 .2977 .40253 Mtetra
.66 .657 .836 r
.2977 .40253 .29868 .40401 .30025 .40343 .29928 .40195 Mtetra
.634 .648 .847 r
.29928 .40195 .30025 .40343 .30183 .40289 .30084 .40152 Mtetra
.691 .685 .839 r
.30084 .40152 .30183 .40289 .30341 .40215 .30243 .40078 Mtetra
.688 .683 .84 r
.30243 .40078 .30341 .40215 .30499 .40156 .30401 .40006 Mtetra
.61 .635 .851 r
.30401 .40006 .30499 .40156 .30653 .40152 .30558 .39974 Mtetra
.082 .297 .779 r
.30558 .39974 .30653 .40152 .3079 .40411 .30704 .40091 Mtetra
0 0 .26 r
.30704 .40091 .3079 .40411 .29627 .60131 .3083 .40512 Mtetra
0 0 .217 r
.3083 .40512 .29627 .60131 .29735 .60975 .2967 .60228 Mtetra
.119 .071 .523 r
.2967 .60228 .29735 .60975 .29891 .61103 .29803 .60699 Mtetra
.365 .319 .673 r
.29803 .60699 .29891 .61103 .30058 .61071 .29959 .60838 Mtetra
.441 .466 .79 r
.29959 .60838 .30058 .61071 .30228 .60986 .3012 .60888 Mtetra
.394 .655 .963 r
.3012 .60888 .30228 .60986 .30396 .60939 .30284 .60902 Mtetra
.436 .82 .989 r
.30284 .60902 .30396 .60939 .30564 .60897 .30451 .60877 Mtetra
.687 .935 .966 r
.30451 .60877 .30564 .60897 .30735 .60793 .30621 .60792 Mtetra
.919 .915 .797 r
.30621 .60792 .30735 .60793 .30925 .6041 .30802 .60552 Mtetra
.99 .889 .6 r
.30802 .60552 .30925 .6041 .3233 .40558 .31003 .59987 Mtetra
0 0 .207 r
.31003 .59987 .3233 .40558 .32543 .39634 .32404 .40143 Mtetra
0 0 .007 r
.32404 .40143 .32543 .39634 .32712 .39412 .32594 .3959 Mtetra
0 0 0 r
.32594 .3959 .32712 .39412 .32871 .39346 .32764 .39368 Mtetra
.801 .994 .87 r
.32764 .39368 .32871 .39346 .33028 .39326 .32928 .39228 Mtetra
.716 .759 .887 r
.32928 .39228 .33028 .39326 .33186 .39296 .33088 .39149 Mtetra
.629 .649 .851 r
.33088 .39149 .33186 .39296 .33345 .39247 .33247 .39107 Mtetra
.593 .646 .872 r
.33247 .39107 .33345 .39247 .33504 .39196 .33404 .39082 Mtetra
.625 .703 .902 r
.33404 .39082 .33504 .39196 .33663 .39137 .33563 .39043 Mtetra
.668 .757 .917 r
.33563 .39043 .33663 .39137 .33823 .39073 .33722 .38986 Mtetra
.683 .777 .923 r
.33722 .38986 .33823 .39073 .33983 .3901 .33883 .38923 Mtetra
.757 .789 .88 r
.33883 .38923 .33983 .3901 .34144 .38931 .34045 .38822 Mtetra
.749 .747 .85 r
.34045 .38822 .34144 .38931 .34305 .38859 .34207 .38718 Mtetra
.643 .664 .855 r
.34207 .38718 .34305 .38859 .34463 .3884 .34367 .3867 Mtetra
0 .083 .643 r
.34367 .3867 .34463 .3884 .34608 .39037 .34514 .38842 Mtetra
.953 .686 .494 r
.34514 .38842 .34608 .39037 .33694 .58461 .33614 .57891 Mtetra
.977 .7 .304 r
.33614 .57891 .33694 .58461 .33794 .5968 .33685 .59628 Mtetra
.74 .217 0 r
.33685 .59628 .33794 .5968 .33952 .5985 .33843 .59812 Mtetra
.489 .842 .995 r
.33843 .59812 .33952 .5985 .34122 .59815 .34012 .59778 Mtetra
.725 .909 .959 r
.34012 .59778 .34122 .59815 .34295 .59726 .34185 .59687 Mtetra
.704 .904 .967 r
.34185 .59687 .34295 .59726 .34467 .59645 .34358 .59604 Mtetra
.601 .877 .992 r
.34358 .59604 .34467 .59645 .34638 .59592 .34529 .5955 Mtetra
.603 .874 .992 r
.34529 .5955 .34638 .59592 .34809 .5954 .347 .59495 Mtetra
.601 .868 .993 r
.347 .59495 .34809 .5954 .3498 .59489 .34871 .59443 Mtetra
.596 .863 .993 r
.34871 .59443 .3498 .59489 .35151 .59439 .35042 .59392 Mtetra
.594 .862 .994 r
.35042 .59392 .35151 .59439 .35322 .59389 .35214 .59342 Mtetra
.553 .847 .998 r
.35214 .59342 .35322 .59389 .35493 .59341 .35385 .59301 Mtetra
.516 .85 .997 r
.35385 .59301 .35493 .59341 .35665 .59293 .35555 .59263 Mtetra
.581 .893 .988 r
.35555 .59263 .35665 .59293 .35836 .59245 .35727 .59206 Mtetra
.781 .909 .929 r
.35727 .59206 .35836 .59245 .36008 .59195 .35902 .59091 Mtetra
.834 .776 .797 r
.35902 .59091 .36008 .59195 .36179 .59143 .36081 .58896 Mtetra
.775 .636 .707 r
.36081 .58896 .36179 .59143 .36351 .5909 .36262 .58651 Mtetra
.667 .513 .665 r
.36262 .58651 .36351 .5909 .36522 .59063 .36439 .58491 Mtetra
.554 .412 .642 r
.36439 .58491 .36522 .59063 .36693 .59048 .36609 .58486 Mtetra
.588 .437 .644 r
.36609 .58486 .36693 .59048 .36866 .5898 .36781 .58431 Mtetra
.743 .547 .628 r
.36781 .58431 .36866 .5898 .37047 .58724 .36971 .58003 Mtetra
.947 .682 .502 r
.36971 .58003 .37047 .58724 .37267 .57622 .38039 .3808 Mtetra
.552 .33 .532 r
.38039 .3808 .37267 .57622 .38315 .37795 .38224 .37513 Mtetra
.75 .601 .691 r
.38224 .37513 .38315 .37795 .38489 .3747 .38394 .37288 Mtetra
.672 .627 .796 r
.38394 .37288 .38489 .3747 .38652 .3739 .38557 .37214 Mtetra
.608 .605 .822 r
.38557 .37214 .38652 .3739 .38813 .37364 .38719 .37181 Mtetra
.592 .589 .817 r
.38719 .37181 .38813 .37364 .38975 .37333 .3888 .37156 Mtetra
.619 .608 .818 r
.3888 .37156 .38975 .37333 .39138 .37262 .39042 .37117 Mtetra
.621 .652 .859 r
.39042 .37117 .39138 .37262 .39302 .37191 .39204 .37078 Mtetra
.633 .714 .905 r
.39204 .37078 .39302 .37191 .39465 .37126 .39367 .37035 Mtetra
.655 .765 .931 r
.39367 .37035 .39465 .37126 .39628 .37071 .39529 .36982 Mtetra
.669 .774 .928 r
.39529 .36982 .39628 .37071 .39791 .37018 .39693 .36923 Mtetra
.699 .769 .906 r
.39693 .36923 .39791 .37018 .39954 .36965 .39856 .36852 Mtetra
.715 .738 .87 r
.39856 .36852 .39954 .36965 .40117 .36908 .40021 .36768 Mtetra
.678 .683 .848 r
.40021 .36768 .40117 .36908 .4028 .3685 .40185 .367 Mtetra
.579 .627 .863 r
.40185 .367 .4028 .3685 .40444 .36792 .40347 .36681 Mtetra
.175 .487 .901 r
.40347 .36681 .40444 .36792 .40607 .36733 .40506 .36743 Mtetra
.635 .089 0 r
.40506 .36743 .40607 .36733 .40771 .36674 .40663 .36851 Mtetra
.577 .178 .25 r
.40663 .36851 .40771 .36674 .40936 .36599 .40823 .36917 Mtetra
.348 .023 .264 r
.40823 .36917 .40936 .36599 .41101 .36504 .40989 .36815 Mtetra
.406 .073 .284 r
.40989 .36815 .41101 .36504 .41264 .36452 .41153 .36749 Mtetra
.666 .324 .384 r
.41153 .36749 .41264 .36452 .41424 .36534 .41309 .36932 Mtetra
.952 .678 .482 r
.41309 .36932 .41424 .36534 .41564 .37162 .40787 .56779 Mtetra
.55 .325 .525 r
.40787 .56779 .41564 .37162 .41051 .57238 .40938 .57398 Mtetra
.691 .292 .285 r
.40938 .57398 .41051 .57238 .41213 .57579 .41106 .57567 Mtetra
.396 .841 .93 r
.41106 .57567 .41213 .57579 .41386 .57587 .41281 .57527 Mtetra
.723 .864 .948 r
.41281 .57527 .41386 .57587 .41561 .57529 .41457 .57439 Mtetra
.717 .797 .914 r
.41457 .57439 .41561 .57529 .41737 .57452 .41634 .57354 Mtetra
.571 .737 .954 r
.41634 .57354 .41737 .57452 .41913 .57401 .41809 .57326 Mtetra
.596 .801 .978 r
.41809 .57326 .41913 .57401 .42089 .57344 .41984 .57284 Mtetra
.725 .866 .948 r
.41984 .57284 .42089 .57344 .42265 .57286 .42161 .57195 Mtetra
.841 .804 .814 r
.42161 .57195 .42265 .57286 .42441 .5723 .42341 .57006 Mtetra
.788 .656 .716 r
.42341 .57006 .42441 .5723 .42617 .57174 .42523 .56761 Mtetra
.706 .544 .665 r
.42523 .56761 .42617 .57174 .42792 .57132 .42704 .56537 Mtetra
.555 .41 .639 r
.42704 .56537 .42792 .57132 .42968 .57122 .42879 .5653 Mtetra
.577 .426 .64 r
.42879 .5653 .42968 .57122 .43144 .57065 .43054 .56488 Mtetra
.694 .509 .633 r
.43054 .56488 .43144 .57065 .43324 .56874 .43237 .56204 Mtetra
.953 .683 .486 r
.43237 .56204 .43324 .56874 .43521 .56068 .43948 .36194 Mtetra
.554 .332 .532 r
.43948 .36194 .43521 .56068 .44221 .3586 .44131 .35521 Mtetra
.753 .584 .668 r
.44131 .35521 .44221 .3586 .44396 .35437 .44302 .35247 Mtetra
.683 .627 .786 r
.44302 .35247 .44396 .35437 .44563 .3534 .44469 .35161 Mtetra
.624 .611 .817 r
.44469 .35161 .44563 .3534 .44729 .35303 .44635 .35117 Mtetra
.598 .591 .816 r
.44635 .35117 .44729 .35303 .44894 .3528 .448 .35089 Mtetra
.638 .605 .799 r
.448 .35089 .44894 .3528 .45061 .35208 .44967 .35035 Mtetra
.642 .627 .82 r
.44967 .35035 .45061 .35208 .45227 .35135 .45133 .34982 Mtetra
.648 .655 .843 r
.45133 .34982 .45227 .35135 .45394 .35067 .45299 .34929 Mtetra
.655 .68 .861 r
.45299 .34929 .45394 .35067 .4556 .35011 .45466 .34873 Mtetra
.656 .682 .862 r
.45466 .34873 .4556 .35011 .45727 .34957 .45632 .34816 Mtetra
.661 .679 .856 r
.45632 .34816 .45727 .34957 .45894 .34905 .45799 .34757 Mtetra
.677 .675 .841 r
.45799 .34757 .45894 .34905 .46061 .34849 .45966 .34688 Mtetra
.651 .645 .831 r
.45966 .34688 .46061 .34849 .46227 .34794 .46133 .3463 Mtetra
.593 .617 .845 r
.46133 .3463 .46227 .34794 .46394 .34739 .463 .34604 Mtetra
.285 .503 .892 r
.463 .34604 .46394 .34739 .46562 .34683 .46465 .34663 Mtetra
.553 0 0 r
.46465 .34663 .46562 .34683 .46729 .34628 .46629 .34768 Mtetra
.659 .242 .243 r
.46629 .34768 .46729 .34628 .46896 .34571 .46794 .34896 Mtetra
.479 .145 .322 r
.46794 .34896 .46896 .34571 .47064 .34511 .46961 .34878 Mtetra
.419 .103 .32 r
.46961 .34878 .47064 .34511 .47231 .34452 .47129 .34803 Mtetra
.385 .068 .3 r
.47129 .34803 .47231 .34452 .47399 .34392 .47297 .34709 Mtetra
.42 .088 .294 r
.47297 .34709 .47399 .34392 .47567 .34334 .47466 .34649 Mtetra
.419 .087 .293 r
.47466 .34649 .47567 .34334 .47735 .34276 .47634 .34589 Mtetra
.42 .086 .292 r
.47634 .34589 .47735 .34276 .47903 .34218 .47802 .3453 Mtetra
.421 .087 .292 r
.47802 .3453 .47903 .34218 .48071 .34161 .4797 .34472 Mtetra
.423 .088 .292 r
.4797 .34472 .48071 .34161 .48239 .34104 .48139 .34416 Mtetra
.424 .09 .293 r
.48139 .34416 .48239 .34104 .48407 .34047 .48307 .3436 Mtetra
.427 .093 .295 r
.48307 .3436 .48407 .34047 .48576 .3399 .48476 .34306 Mtetra
.429 .096 .297 r
.48476 .34306 .48576 .3399 .48744 .33934 .48645 .34252 Mtetra
.434 .102 .301 r
.48645 .34252 .48744 .33934 .48913 .33878 .48814 .34202 Mtetra
.483 .148 .322 r
.48814 .34202 .48913 .33878 .49081 .33823 .48982 .34187 Mtetra
.455 .134 .332 r
.48982 .34187 .49081 .33823 .4925 .33769 .49151 .34141 Mtetra
.37 .062 .306 r
.49151 .34141 .4925 .33769 .49419 .33713 .49321 .34028 Mtetra
.019 0 .127 r
.49321 .34028 .49419 .33713 .49588 .33655 .49492 .33768 Mtetra
.6 .846 .481 r
.49492 .33768 .49588 .33655 .49757 .33597 .49663 .33552 Mtetra
.861 .898 .859 r
.49663 .33552 .49757 .33597 .49927 .33538 .49833 .33386 Mtetra
.685 .675 .834 r
.49833 .33386 .49927 .33538 .50096 .33482 .50003 .3331 Mtetra
.641 .63 .823 r
.50003 .3331 .50096 .33482 .50265 .33426 .50172 .33257 Mtetra
.618 .623 .834 r
.50172 .33257 .50265 .33426 .50435 .33369 .50342 .33217 Mtetra
.63 .653 .854 r
.50342 .33217 .50435 .33369 .50605 .33304 .50511 .33172 Mtetra
.634 .685 .881 r
.50511 .33172 .50605 .33304 .50774 .33241 .50681 .33127 Mtetra
.645 .723 .905 r
.50681 .33127 .50774 .33241 .50944 .33181 .50851 .33076 Mtetra
.694 .758 .901 r
.50851 .33076 .50944 .33181 .51114 .33135 .51021 .33004 Mtetra
.693 .71 .861 r
.51021 .33004 .51114 .33135 .51284 .33091 .51191 .32927 Mtetra
.679 .657 .821 r
.51191 .32927 .51284 .33091 .51454 .33047 .51362 .32851 Mtetra
.693 .629 .78 r
.51362 .32851 .51454 .33047 .51625 .32942 .51532 .32754 Mtetra
.661 .622 .8 r
.51532 .32754 .51625 .32942 .51795 .32869 .51703 .32685 Mtetra
.579 .586 .824 r
.51703 .32685 .51795 .32869 .51966 .32865 .51873 .32665 Mtetra
0 .148 .687 r
.51873 .32665 .51966 .32865 .52136 .33306 .52043 .32861 Mtetra
0 0 .233 r
.52043 .32861 .52136 .33306 .52295 .53637 .52214 .33585 Mtetra
0 0 .344 r
.52214 .33585 .52295 .53637 .52477 .54153 .52378 .53561 Mtetra
.317 .247 .618 r
.52378 .53561 .52477 .54153 .5266 .54185 .52561 .53832 Mtetra
.421 .385 .712 r
.52561 .53832 .5266 .54185 .52843 .54129 .52744 .53932 Mtetra
.48 .534 .835 r
.52744 .53932 .52843 .54129 .53026 .54032 .52927 .53958 Mtetra
.539 .791 .991 r
.52927 .53958 .53026 .54032 .53209 .53976 .5311 .53928 Mtetra
.602 .873 .992 r
.5311 .53928 .53209 .53976 .53392 .53922 .53293 .5387 Mtetra
.657 .883 .981 r
.53293 .5387 .53392 .53922 .53575 .53861 .53477 .53799 Mtetra
.478 .791 .999 r
.53477 .53799 .53575 .53861 .53758 .53833 .5366 .53776 Mtetra
.557 .839 .998 r
.5366 .53776 .53758 .53833 .53942 .53772 .53844 .53734 Mtetra
.713 .924 .963 r
.53844 .53734 .53942 .53772 .54125 .53638 .54027 .53638 Mtetra
.958 .919 .728 r
.54027 .53638 .54125 .53638 .54306 .53069 .5421 .53319 Mtetra
.939 .839 .398 r
.5421 .53319 .54306 .53069 .54368 .32593 .54389 .52524 Mtetra
0 0 .338 r
.54389 .52524 .54368 .32593 .54536 .31982 .54448 .32346 Mtetra
0 0 .098 r
.54448 .32346 .54536 .31982 .54708 .31829 .54618 .31955 Mtetra
0 0 0 r
.54618 .31955 .54708 .31829 .5488 .31769 .54789 .31751 Mtetra
.808 .966 .907 r
.54789 .31751 .5488 .31769 .55053 .31747 .54961 .31617 Mtetra
.689 .712 .866 r
.54961 .31617 .55053 .31747 .55226 .3169 .55134 .31542 Mtetra
.633 .663 .861 r
.55134 .31542 .55226 .3169 .55398 .31627 .55307 .31495 Mtetra
.61 .679 .891 r
.55307 .31495 .55398 .31627 .55571 .31569 .5548 .31459 Mtetra
.732 .763 .878 r
.5548 .31459 .55571 .31569 .55744 .31485 .55652 .31364 Mtetra
.713 .737 .87 r
.55652 .31364 .55744 .31485 .55917 .31425 .55825 .31277 Mtetra
.623 .658 .864 r
.55825 .31277 .55917 .31425 .5609 .31428 .55998 .31235 Mtetra
.091 .285 .767 r
.55998 .31235 .5609 .31428 .56268 .31774 .56174 .31384 Mtetra
0 0 .405 r
.56174 .31384 .56268 .31774 .56699 .52116 .56355 .31917 Mtetra
0 0 .361 r
.56355 .31917 .56699 .52116 .56893 .52751 .56789 .52081 Mtetra
.272 .206 .596 r
.56789 .52081 .56893 .52751 .5708 .52824 .56979 .52441 Mtetra
.412 .367 .698 r
.56979 .52441 .5708 .52824 .57266 .52774 .57168 .52558 Mtetra
.477 .514 .817 r
.57168 .52558 .57266 .52774 .57451 .52677 .57355 .52591 Mtetra
.457 .724 .983 r
.57355 .52591 .57451 .52677 .57638 .52654 .57542 .52585 Mtetra
.614 .833 .984 r
.57542 .52585 .57638 .52654 .57824 .5262 .57728 .52531 Mtetra
.767 .827 .899 r
.57728 .52531 .57824 .5262 .5801 .52517 .57913 .52414 Mtetra
.9 .799 .739 r
.57913 .52414 .5801 .52517 .58189 .52065 .58095 .52111 Mtetra
.997 .827 .548 r
.58095 .52111 .58189 .52065 .58016 .31574 .5827 .51363 Mtetra
0 0 .351 r
.5827 .51363 .58016 .31574 .58177 .30768 .58095 .31156 Mtetra
0 0 .121 r
.58095 .31156 .58177 .30768 .58349 .30578 .58264 .30727 Mtetra
0 0 0 r
.58264 .30727 .58349 .30578 .58523 .30516 .58435 .30516 Mtetra
.781 .993 .88 r
.58435 .30516 .58523 .30516 .58699 .30498 .58609 .30377 Mtetra
.698 .735 .88 r
.58609 .30377 .58699 .30498 .58874 .30456 .58783 .30299 Mtetra
.628 .649 .852 r
.58783 .30299 .58874 .30456 .59049 .304 .58959 .30254 Mtetra
.597 .651 .874 r
.58959 .30254 .59049 .304 .59224 .30344 .59134 .30224 Mtetra
.694 .735 .883 r
.59134 .30224 .59224 .30344 .59399 .30246 .59309 .30148 Mtetra
.704 .781 .912 r
.59309 .30148 .59399 .30246 .59573 .30159 .59484 .30069 Mtetra
.594 .762 .959 r
.59484 .30069 .59573 .30159 .59749 .30132 .5966 .30032 Mtetra
0 .205 .707 r
.5966 .30032 .59749 .30132 .59933 .30396 .5984 .30169 Mtetra
.758 .409 0 r
.5984 .30169 .59933 .30396 .60605 .50706 .60031 .30717 Mtetra
0 0 .374 r
.60031 .30717 .60605 .50706 .60815 .51535 .60705 .50866 Mtetra
.282 .214 .601 r
.60705 .50866 .60815 .51535 .61007 .51651 .60904 .51223 Mtetra
.444 .374 .684 r
.60904 .51223 .61007 .51651 .61196 .51607 .61096 .51329 Mtetra
.503 .479 .763 r
.61096 .51329 .61196 .51607 .61383 .51509 .61287 .51361 Mtetra
.439 .585 .901 r
.61287 .51361 .61383 .51509 .61572 .51457 .61478 .51387 Mtetra
.439 .759 .996 r
.61478 .51387 .61572 .51457 .61761 .51409 .61668 .51376 Mtetra
.672 .932 .969 r
.61668 .51376 .61761 .51409 .61948 .51299 .61856 .51287 Mtetra
.971 .895 .692 r
.61856 .51287 .61948 .51299 .62128 .50902 .62036 .50914 Mtetra
.975 .688 .415 r
.62036 .50914 .62128 .50902 .61718 .30568 .61635 .30669 Mtetra
.998 .779 .46 r
.61635 .30669 .61718 .30568 .61867 .29566 .61777 .29418 Mtetra
.838 .736 .752 r
.61777 .29418 .61867 .29566 .62039 .29339 .61949 .29187 Mtetra
.65 .669 .854 r
.61949 .29187 .62039 .29339 .62216 .2927 .62126 .2913 Mtetra
.533 .633 .895 r
.62126 .2913 .62216 .2927 .62394 .29248 .62305 .29125 Mtetra
.591 .691 .912 r
.62305 .29125 .62394 .29248 .62572 .29204 .62483 .29094 Mtetra
.665 .748 .913 r
.62483 .29094 .62572 .29204 .62749 .29137 .62661 .29033 Mtetra
.678 .764 .916 r
.62661 .29033 .62749 .29137 .62926 .29072 .62838 .28965 Mtetra
.756 .782 .874 r
.62838 .28965 .62926 .29072 .63103 .28985 .63014 .28854 Mtetra
.743 .737 .846 r
.63014 .28854 .63103 .28985 .6328 .28906 .6319 .28744 Mtetra
.642 .65 .843 r
.6319 .28744 .6328 .28906 .63459 .28883 .63368 .2869 Mtetra
.017 .234 .741 r
.63368 .2869 .63459 .28883 .63647 .29106 .63554 .28868 Mtetra
.975 .68 .389 r
.63554 .28868 .63647 .29106 .64562 .49287 .64435 .48256 Mtetra
0 0 .187 r
.64435 .48256 .64562 .49287 .6479 .50266 .64696 .50138 Mtetra
0 .096 .634 r
.64696 .50138 .6479 .50266 .6499 .50447 .64897 .50335 Mtetra
.54 .707 .948 r
.64897 .50335 .6499 .50447 .65183 .50437 .65089 .50316 Mtetra
.746 .769 .872 r
.65089 .50316 .65183 .50437 .65372 .50322 .65278 .50203 Mtetra
.875 .791 .764 r
.65278 .50203 .65372 .50322 .65552 .49969 .65462 .49945 Mtetra
.987 .832 .603 r
.65462 .49945 .65552 .49969 .64968 .30484 .65633 .49372 Mtetra
0 0 .362 r
.65633 .49372 .64968 .30484 .6507 .28497 .65008 .29023 Mtetra
0 0 .204 r
.65008 .29023 .6507 .28497 .6524 .28224 .65166 .28432 Mtetra
0 0 .005 r
.65166 .28432 .6524 .28224 .65418 .28146 .65338 .28205 Mtetra
.502 .852 .591 r
.65338 .28205 .65418 .28146 .65599 .28119 .65514 .28058 Mtetra
.742 .886 .945 r
.65514 .28058 .65599 .28119 .65779 .28082 .65692 .2796 Mtetra
.674 .731 .893 r
.65692 .2796 .65779 .28082 .65958 .28018 .65871 .27893 Mtetra
.648 .715 .896 r
.65871 .27893 .65958 .28018 .66138 .27956 .66051 .27838 Mtetra
.725 .756 .877 r
.66051 .27838 .66138 .27956 .66316 .27874 .66229 .27743 Mtetra
.747 .74 .846 r
.66229 .27743 .66316 .27874 .66495 .27791 .66406 .27629 Mtetra
.654 .658 .842 r
.66406 .27629 .66495 .27791 .66676 .27759 .66586 .27567 Mtetra
.186 .35 .796 r
.66586 .27567 .66676 .27759 .66867 .27929 .66775 .27699 Mtetra
.906 .562 .09 r
.66775 .27699 .66867 .27929 .67964 .47412 .67005 .28715 Mtetra
0 0 .381 r
.67005 .28715 .67964 .47412 .68241 .49141 .68148 .49001 Mtetra
0 0 .549 r
.68148 .49001 .68241 .49141 .68448 .49364 .68356 .4925 Mtetra
.517 .695 .949 r
.68356 .4925 .68448 .49364 .68644 .49362 .68552 .49239 Mtetra
.744 .768 .873 r
.68552 .49239 .68644 .49362 .68835 .4925 .68743 .49126 Mtetra
.876 .789 .761 r
.68743 .49126 .68835 .4925 .69015 .4891 .68927 .48864 Mtetra
.986 .812 .586 r
.68927 .48864 .69015 .4891 .68209 .29064 .69091 .48229 Mtetra
0 0 .379 r
.69091 .48229 .68209 .29064 .68307 .27362 .68248 .27762 Mtetra
0 0 .092 r
.68248 .27762 .68307 .27362 .68475 .27045 .68403 .27188 Mtetra
0 0 0 r
.68403 .27188 .68475 .27045 .68653 .26929 .68574 .26933 Mtetra
.704 .985 .864 r
.68574 .26933 .68653 .26929 .68836 .26904 .68752 .26806 Mtetra
.153 .505 .91 r
.68752 .26806 .68836 .26904 .69028 .27045 .6894 .26873 Mtetra
.832 .452 0 r
.6894 .26873 .69028 .27045 .69257 .27858 .69158 .27499 Mtetra
.977 .676 .359 r
.69158 .27499 .69257 .27858 .70563 .48342 .70469 .48179 Mtetra
0 0 .423 r
.70469 .48179 .70563 .48342 .70777 .4864 .70686 .48521 Mtetra
.416 .634 .945 r
.70686 .48521 .70777 .4864 .70976 .48656 .70885 .48541 Mtetra
.718 .778 .9 r
.70885 .48541 .70976 .48656 .71169 .4856 .71079 .48446 Mtetra
.901 .805 .744 r
.71079 .48446 .71169 .4856 .71351 .48265 .71261 .4815 Mtetra
.978 .737 .502 r
.71261 .4815 .71351 .48265 .71478 .47028 .71387 .46892 Mtetra
.977 .681 .379 r
.71387 .46892 .71478 .47028 .70492 .26704 .70407 .26586 Mtetra
.916 .786 .702 r
.70407 .26586 .70492 .26704 .70658 .26362 .70573 .26245 Mtetra
.716 .759 .886 r
.70573 .26245 .70658 .26362 .70839 .26272 .70754 .26156 Mtetra
.594 .711 .925 r
.70754 .26156 .70839 .26272 .71023 .26238 .70939 .26122 Mtetra
.629 .727 .918 r
.70939 .26122 .71023 .26238 .71207 .2619 .71122 .26074 Mtetra
.736 .767 .878 r
.71122 .26074 .71207 .2619 .71387 .26088 .71303 .25972 Mtetra
.646 .735 .914 r
.71303 .25972 .71387 .26088 .71571 .26032 .71486 .25917 Mtetra
.085 .416 .865 r
.71486 .25917 .71571 .26032 .71764 .2613 .71679 .26015 Mtetra
.916 .538 .117 r
.71679 .26015 .71764 .2613 .72004 .26967 .7192 .26868 Mtetra
.975 .671 .353 r
.7192 .26868 .72004 .26967 .73496 .47443 .73407 .47338 Mtetra
.613 .144 0 r
.73407 .47338 .73496 .47443 .73715 .47733 .73627 .4763 Mtetra
.497 .714 .968 r
.73627 .4763 .73715 .47733 .73915 .47712 .73827 .4762 Mtetra
.709 .825 .937 r
.73827 .4762 .73915 .47712 .7411 .47625 .74022 .4753 Mtetra
.783 .838 .893 r
.74022 .4753 .7411 .47625 .74306 .47545 .74215 .47398 Mtetra
.77 .744 .83 r
.74215 .47398 .74306 .47545 .74507 .47531 .74407 .47254 Mtetra
.757 .624 .713 r
.74407 .47254 .74507 .47531 .74704 .47466 .74594 .47032 Mtetra
.795 .594 .63 r
.74594 .47032 .74704 .47466 .74891 .47246 .74764 .46567 Mtetra
.974 .674 .377 r
.74764 .46567 .74891 .47246 .75031 .4635 .73567 .26115 Mtetra
.553 .33 .531 r
.73567 .26115 .75031 .4635 .73801 .25667 .73709 .25418 Mtetra
.799 .65 .697 r
.73709 .25418 .73801 .25667 .73962 .25259 .73879 .25149 Mtetra
.717 .776 .899 r
.73879 .25149 .73962 .25259 .74144 .25158 .74062 .25059 Mtetra
.614 .762 .95 r
.74062 .25059 .74144 .25158 .7433 .25117 .74248 .25014 Mtetra
.629 .757 .939 r
.74248 .25014 .7433 .25117 .74517 .25078 .74434 .24964 Mtetra
.748 .779 .878 r
.74434 .24964 .74517 .25078 .74698 .2497 .74615 .24855 Mtetra
.663 .747 .913 r
.74615 .24855 .74698 .2497 .74883 .24907 .74801 .24792 Mtetra
.226 .51 .909 r
.74801 .24792 .74883 .24907 .75078 .24977 .74995 .24861 Mtetra
.891 .502 .053 r
.74995 .24861 .75078 .24977 .75324 .25733 .75242 .25622 Mtetra
.975 .667 .334 r
.75242 .25622 .75324 .25733 .77055 .46335 .76968 .46225 Mtetra
.648 .192 0 r
.76968 .46225 .77055 .46335 .77285 .46676 .77197 .46564 Mtetra
.386 .634 .953 r
.77197 .46564 .77285 .46676 .77491 .46701 .77403 .46589 Mtetra
.694 .781 .918 r
.77403 .46589 .77491 .46701 .77689 .46618 .77601 .46506 Mtetra
.873 .82 .793 r
.77601 .46506 .77689 .46618 .77875 .46386 .77788 .46273 Mtetra
.978 .767 .552 r
.77788 .46273 .77875 .46386 .78019 .45601 .77932 .45489 Mtetra
.977 .675 .347 r
.77932 .45489 .78019 .45601 .76587 .24762 .76505 .24643 Mtetra
.95 .784 .641 r
.76505 .24643 .76587 .24762 .76742 .24299 .7666 .2418 Mtetra
.746 .772 .874 r
.7666 .2418 .76742 .24299 .76925 .2419 .76843 .24071 Mtetra
.619 .722 .92 r
.76843 .24071 .76925 .2419 .77113 .24145 .77031 .24026 Mtetra
.587 .707 .926 r
.77031 .24026 .77113 .24145 .77302 .24113 .7722 .23994 Mtetra
.748 .771 .872 r
.7722 .23994 .77302 .24113 .77485 .24003 .77403 .23883 Mtetra
.672 .743 .904 r
.77403 .23883 .77485 .24003 .77672 .23935 .7759 .23815 Mtetra
.364 .585 .928 r
.7759 .23815 .77672 .23935 .77867 .23974 .77785 .23853 Mtetra
.824 .417 0 r
.77785 .23853 .77867 .23974 .78109 .24568 .78027 .2444 Mtetra
.973 .663 .318 r
.78027 .2444 .78109 .24568 .80049 .45328 .79962 .45208 Mtetra
.685 .247 0 r
.79962 .45208 .80049 .45328 .8029 .45732 .80203 .45613 Mtetra
.406 .63 .946 r
.80203 .45613 .8029 .45732 .80499 .45766 .80412 .45636 Mtetra
.68 .744 .899 r
.80412 .45636 .80499 .45766 .807 .45689 .80612 .45558 Mtetra
.821 .789 .822 r
.80612 .45558 .807 .45689 .80888 .45474 .80804 .45376 Mtetra
.956 .824 .674 r
.80804 .45376 .80888 .45474 .81031 .44735 .80975 .44961 Mtetra
.964 .741 .298 r
.80975 .44961 .81031 .44735 .79401 .23834 .81032 .4324 Mtetra
.041 0 .431 r
.81032 .4324 .79401 .23834 .7955 .23334 .79506 .23627 Mtetra
.049 0 .179 r
.79506 .23627 .7955 .23334 .79734 .23221 .79674 .23336 Mtetra
0 0 0 r
.79674 .23336 .79734 .23221 .79924 .23177 .79853 .23161 Mtetra
.709 .98 .907 r
.79853 .23161 .79924 .23177 .80117 .23163 .80037 .23042 Mtetra
.688 .749 .898 r
.80037 .23042 .80117 .23163 .80306 .23104 .80224 .22965 Mtetra
.646 .698 .884 r
.80224 .22965 .80306 .23104 .80496 .23044 .80414 .22908 Mtetra
.638 .7 .891 r
.80414 .22908 .80496 .23044 .80684 .22977 .80604 .22855 Mtetra
.754 .77 .867 r
.80604 .22855 .80684 .22977 .80868 .2286 .80788 .22738 Mtetra
.686 .747 .897 r
.80788 .22738 .80868 .2286 .81056 .22783 .80976 .22662 Mtetra
.468 .643 .933 r
.80976 .22662 .81056 .22783 .81252 .22791 .81172 .22671 Mtetra
.773 .358 0 r
.81172 .22671 .81252 .22791 .81498 .23317 .81418 .23197 Mtetra
.971 .657 .298 r
.81418 .23197 .81498 .23317 .83686 .44159 .83602 .44045 Mtetra
.723 .288 0 r
.83602 .44045 .83686 .44159 .83939 .44617 .83855 .44503 Mtetra
.31 .583 .939 r
.83855 .44503 .83939 .44617 .84154 .44665 .8407 .44551 Mtetra
.651 .765 .932 r
.8407 .44551 .84154 .44665 .84358 .44601 .84274 .44486 Mtetra
.831 .821 .839 r
.84274 .44486 .84358 .44601 .84551 .4442 .84467 .44305 Mtetra
.976 .788 .586 r
.84467 .44305 .84551 .4442 .84701 .43803 .84617 .43688 Mtetra
.974 .667 .312 r
.84617 .43688 .84701 .43803 .82824 .22807 .82744 .22687 Mtetra
.974 .775 .575 r
.82744 .22687 .82824 .22807 .82959 .22189 .8288 .22069 Mtetra
.766 .759 .846 r
.21611 .43019 .21715 .43115 .21873 .43004 .21769 .42907 Mtetra
.632 .734 .922 r
.21769 .42907 .21873 .43004 .22024 .42963 .2192 .42867 Mtetra
.493 .686 .953 r
.2192 .42867 .22024 .42963 .22172 .42959 .22068 .42863 Mtetra
.752 .759 .858 r
.22068 .42863 .22172 .42959 .22329 .42859 .22225 .42763 Mtetra
.692 .75 .896 r
.22225 .42763 .22329 .42859 .22483 .42794 .22379 .42698 Mtetra
.439 .664 .957 r
.22379 .42698 .22483 .42794 .22631 .428 .22527 .42705 Mtetra
.937 .583 .32 r
.22527 .42705 .22631 .428 .22735 .43285 .22629 .43207 Mtetra
.938 .682 .524 r
.22629 .43207 .22735 .43285 .21076 .63158 .20962 .63092 Mtetra
.918 .548 .305 r
.20962 .63092 .21076 .63158 .21192 .6362 .21079 .63542 Mtetra
.395 .703 .983 r
.21079 .63542 .21192 .6362 .21349 .63628 .21237 .63547 Mtetra
.724 .799 .911 r
.21237 .63547 .21349 .63628 .21515 .63547 .21403 .63464 Mtetra
.789 .796 .858 r
.21403 .63464 .21515 .63547 .21684 .63422 .21573 .63335 Mtetra
.603 .762 .955 r
.21573 .63335 .21684 .63422 .21848 .6337 .21734 .63299 Mtetra
.631 .806 .967 r
.21734 .63299 .21848 .6337 .22011 .63318 .21897 .63251 Mtetra
.747 .832 .916 r
.21897 .63251 .22011 .63318 .22176 .63246 .22064 .63157 Mtetra
.886 .762 .72 r
.22064 .63157 .22176 .63246 .22349 .63081 .22253 .62822 Mtetra
.879 .67 .615 r
.22253 .62822 .22349 .63081 .22527 .62862 .22489 .6193 Mtetra
.929 .676 .534 r
.22489 .6193 .22527 .62862 .22708 .62601 .24321 .42625 Mtetra
.544 .324 .531 r
.24321 .42625 .22708 .62601 .22877 .62491 .24488 .42432 Mtetra
.54 .321 .53 r
.24488 .42432 .22877 .62491 .23038 .62466 .24641 .42399 Mtetra
.539 .319 .53 r
.24641 .42399 .23038 .62466 .23196 .62474 .24787 .42439 Mtetra
.54 .321 .53 r
.24787 .42439 .23196 .62474 .23358 .62444 .24939 .42415 Mtetra
.541 .321 .53 r
.24939 .42415 .23358 .62444 .23521 .62407 .25093 .42379 Mtetra
.25093 .42379 .23521 .62407 .23684 .62368 .25246 .42341 Mtetra
.25246 .42341 .23684 .62368 .23847 .62325 .25401 .42296 Mtetra
.25401 .42296 .23847 .62325 .2401 .62281 .25555 .42248 Mtetra
.25555 .42248 .2401 .62281 .24174 .62234 .2571 .42199 Mtetra
.543 .323 .531 r
.2571 .42199 .24174 .62234 .24341 .62151 .25872 .42058 Mtetra
.542 .322 .53 r
.25872 .42058 .24341 .62151 .24507 .62084 .2603 .41972 Mtetra
.539 .319 .53 r
.2603 .41972 .24507 .62084 .24668 .62074 .26177 .42023 Mtetra
0 0 .213 r
.26177 .42023 .24668 .62074 .24817 .62214 .2478 .61219 Mtetra
0 0 .381 r
.2478 .61219 .24817 .62214 .24968 .62341 .24873 .62056 Mtetra
0 0 .541 r
.24873 .62056 .24968 .62341 .25123 .62418 .25013 .62319 Mtetra
.334 .623 .957 r
.25013 .62319 .25123 .62418 .25285 .62403 .25172 .62344 Mtetra
.623 .835 .981 r
.25172 .62344 .25285 .62403 .2545 .62353 .25337 .62294 Mtetra
.706 .852 .952 r
.25337 .62294 .2545 .62353 .25616 .6229 .25505 .62218 Mtetra
.62 .803 .97 r
.25505 .62218 .25616 .6229 .25781 .62249 .2567 .62173 Mtetra
.592 .785 .973 r
.2567 .62173 .25781 .62249 .25945 .62214 .25834 .62136 Mtetra
.608 .787 .967 r
.25834 .62136 .25945 .62214 .2611 .62175 .25999 .62095 Mtetra
.664 .796 .945 r
.25999 .62095 .2611 .62175 .26276 .62121 .26165 .62037 Mtetra
.686 .79 .929 r
.26165 .62037 .26276 .62121 .26442 .6206 .26333 .6197 Mtetra
.689 .779 .92 r
.26333 .6197 .26442 .6206 .26609 .61996 .265 .61901 Mtetra
.62 .752 .941 r
.265 .61901 .26609 .61996 .26774 .61969 .26665 .6186 Mtetra
.625 .724 .918 r
.26665 .6186 .26774 .61969 .26939 .61934 .26831 .61818 Mtetra
.681 .728 .886 r
.26831 .61818 .26939 .61934 .27107 .61853 .26998 .61752 Mtetra
.79 .77 .835 r
.26998 .61752 .27107 .61853 .27289 .61585 .27171 .61612 Mtetra
.917 .954 .8 r
.27171 .61612 .27289 .61585 .275 .60924 .27351 .61381 Mtetra
0 0 .055 r
.27351 .61381 .275 .60924 .29095 .41128 .27544 .60967 Mtetra
0 0 .208 r
.27544 .60967 .29095 .41128 .2928 .40682 .29116 .4144 Mtetra
0 0 .004 r
.29116 .4144 .2928 .40682 .29448 .40474 .29332 .4058 Mtetra
.942 .958 .666 r
.29332 .4058 .29448 .40474 .29611 .40339 .29508 .4026 Mtetra
.804 .803 .85 r
.29508 .4026 .29611 .40339 .2977 .40253 .29671 .40126 Mtetra
.67 .694 .864 r
.29671 .40126 .2977 .40253 .29928 .40195 .29828 .40067 Mtetra
.608 .669 .883 r
.29828 .40067 .29928 .40195 .30084 .40152 .29984 .40035 Mtetra
.667 .71 .88 r
.29984 .40035 .30084 .40152 .30243 .40078 .30142 .39979 Mtetra
.681 .748 .902 r
.30142 .39979 .30243 .40078 .30401 .40006 .303 .39917 Mtetra
.621 .754 .941 r
.303 .39917 .30401 .40006 .30558 .39974 .30456 .39878 Mtetra
.382 .64 .957 r
.30456 .39878 .30558 .39974 .30704 .40091 .30609 .39895 Mtetra
.251 .379 .798 r
.30609 .39895 .30704 .40091 .3083 .40512 .30757 .39988 Mtetra
.289 .224 .609 r
.30757 .39988 .3083 .40512 .2967 .60228 .30896 .4022 Mtetra
0 0 .248 r
.30896 .4022 .2967 .60228 .29803 .60699 .29786 .59238 Mtetra
0 0 .371 r
.29786 .59238 .29803 .60699 .29959 .60838 .29868 .60473 Mtetra
0 .07 .59 r
.29868 .60473 .29959 .60838 .3012 .60888 .30015 .60751 Mtetra
.213 .473 .887 r
.30015 .60751 .3012 .60888 .30284 .60902 .30175 .60818 Mtetra
.579 .767 .968 r
.30175 .60818 .30284 .60902 .30451 .60877 .30343 .60786 Mtetra
.727 .788 .901 r
.30343 .60786 .30451 .60877 .30621 .60792 .30513 .60698 Mtetra
.796 .786 .844 r
.30513 .60698 .30621 .60792 .30802 .60552 .30688 .60557 Mtetra
.905 .939 .821 r
.30688 .60557 .30802 .60552 .31003 .59987 .30867 .60343 Mtetra
0 0 0 r
.30867 .60343 .31003 .59987 .32404 .40143 .31055 .59978 Mtetra
0 0 .248 r
.31055 .59978 .32404 .40143 .32594 .3959 .32397 .41041 Mtetra
0 0 .136 r
.32397 .41041 .32594 .3959 .32764 .39368 .32648 .3952 Mtetra
.896 .938 .57 r
.32648 .3952 .32764 .39368 .32928 .39228 .32825 .39166 Mtetra
.825 .839 .859 r
.32825 .39166 .32928 .39228 .33088 .39149 .3299 .39023 Mtetra
.637 .687 .881 r
.3299 .39023 .33088 .39149 .33247 .39107 .33148 .38979 Mtetra
.548 .647 .9 r
.33148 .38979 .33247 .39107 .33404 .39082 .33305 .38969 Mtetra
.592 .694 .913 r
.33305 .38969 .33404 .39082 .33563 .39043 .33463 .38941 Mtetra
.659 .74 .91 r
.33463 .38941 .33563 .39043 .33722 .38986 .33622 .38888 Mtetra
.674 .752 .909 r
.33622 .38888 .33722 .38986 .33883 .38923 .33782 .38829 Mtetra
.751 .774 .872 r
.33782 .38829 .33883 .38923 .34045 .38822 .33945 .38729 Mtetra
.758 .777 .869 r
.33945 .38729 .34045 .38822 .34207 .38718 .34107 .38625 Mtetra
.643 .753 .929 r
.34107 .38625 .34207 .38718 .34367 .3867 .34267 .38577 Mtetra
.672 .165 0 r
.34267 .38577 .34367 .3867 .34514 .38842 .34413 .38759 Mtetra
.951 .685 .495 r
.34413 .38759 .34514 .38842 .33614 .57891 .33482 .58263 Mtetra
.867 .569 .481 r
.33482 .58263 .33614 .57891 .33685 .59628 .33577 .59566 Mtetra
.707 .175 0 r
.33577 .59566 .33685 .59628 .33843 .59812 .33735 .59741 Mtetra
.569 .797 .985 r
.33735 .59741 .33843 .59812 .34012 .59778 .33904 .59707 Mtetra
.732 .834 .927 r
.33904 .59707 .34012 .59778 .34185 .59687 .34077 .59617 Mtetra
.717 .834 .938 r
.34077 .59617 .34185 .59687 .34358 .59604 .3425 .59535 Mtetra
.642 .822 .969 r
.3425 .59535 .34358 .59604 .34529 .5955 .34421 .5948 Mtetra
.641 .821 .969 r
.34421 .5948 .34529 .5955 .347 .59495 .34592 .59425 Mtetra
.635 .818 .971 r
.34592 .59425 .347 .59495 .34871 .59443 .34763 .59372 Mtetra
.629 .816 .972 r
.34763 .59372 .34871 .59443 .35042 .59392 .34935 .59321 Mtetra
.628 .816 .973 r
.34935 .59321 .35042 .59392 .35214 .59342 .35106 .59271 Mtetra
.566 .796 .986 r
.35106 .59271 .35214 .59342 .35385 .59301 .35277 .59237 Mtetra
.529 .801 .996 r
.35277 .59237 .35385 .59301 .35555 .59263 .35447 .59208 Mtetra
.658 .863 .977 r
.35447 .59208 .35555 .59263 .35727 .59206 .3562 .59144 Mtetra
.859 .843 .828 r
.3562 .59144 .35727 .59206 .35902 .59091 .35798 .58955 Mtetra
.892 .731 .675 r
.35798 .58955 .35902 .59091 .36081 .58896 .35989 .58507 Mtetra
.95 .686 .502 r
.35989 .58507 .36081 .58896 .36262 .58651 .37077 .39341 Mtetra
.564 .34 .534 r
.37077 .39341 .36262 .58651 .36439 .58491 .37292 .38187 Mtetra
.541 .321 .53 r
.37292 .38187 .36439 .58491 .36609 .58486 .37454 .38126 Mtetra
.54 .32 .53 r
.37454 .38126 .36609 .58486 .36781 .58431 .37614 .38126 Mtetra
.544 .324 .531 r
.37614 .38126 .36781 .58431 .36971 .58003 .37783 .37916 Mtetra
.547 .326 .531 r
.37783 .37916 .36971 .58003 .38039 .3808 .37959 .37581 Mtetra
.691 .513 .641 r
.37959 .37581 .38039 .3808 .38224 .37513 .38129 .37344 Mtetra
.753 .673 .772 r
.38129 .37344 .38224 .37513 .38394 .37288 .38295 .37202 Mtetra
.686 .783 .924 r
.38295 .37202 .38394 .37288 .38557 .37214 .38458 .37136 Mtetra
.614 .785 .963 r
.38458 .37136 .38557 .37214 .38719 .37181 .3862 .37095 Mtetra
.598 .76 .956 r
.3862 .37095 .38719 .37181 .3888 .37156 .38782 .3706 Mtetra
.62 .745 .936 r
.38782 .3706 .3888 .37156 .39042 .37117 .38944 .3702 Mtetra
.62 .743 .934 r
.38944 .3702 .39042 .37117 .39204 .37078 .39106 .3698 Mtetra
.638 .745 .926 r
.39106 .3698 .39204 .37078 .39367 .37035 .39269 .36934 Mtetra
.663 .747 .913 r
.39269 .36934 .39367 .37035 .39529 .36982 .39432 .36878 Mtetra
.676 .745 .903 r
.39432 .36878 .39529 .36982 .39693 .36923 .39595 .36817 Mtetra
.714 .749 .88 r
.39595 .36817 .39693 .36923 .39856 .36852 .39759 .36735 Mtetra
.737 .737 .851 r
.39759 .36735 .39856 .36852 .40021 .36768 .39924 .36636 Mtetra
.679 .695 .858 r
.39924 .36636 .40021 .36768 .40185 .367 .40088 .36569 Mtetra
.398 .571 .907 r
.40088 .36569 .40185 .367 .40347 .36681 .40248 .366 Mtetra
.824 .353 0 r
.40248 .366 .40347 .36681 .40506 .36743 .404 .36864 Mtetra
.922 .615 .444 r
.404 .36864 .40506 .36743 .40663 .36851 .40508 .38298 Mtetra
.935 .661 .495 r
.40508 .38298 .40663 .36851 .40823 .36917 .39979 .5705 Mtetra
.538 .314 .523 r
.39979 .5705 .40823 .36917 .40989 .36815 .40153 .57015 Mtetra
.537 .313 .523 r
.40153 .57015 .40989 .36815 .41153 .36749 .4033 .56898 Mtetra
.54 .316 .524 r
.4033 .56898 .41153 .36749 .41309 .36932 .405 .56966 Mtetra
.544 .319 .524 r
.405 .56966 .41309 .36932 .40787 .56779 .40663 .57244 Mtetra
.622 .308 .417 r
.40663 .57244 .40787 .56779 .40938 .57398 .40831 .57405 Mtetra
.403 0 0 r
.40831 .57405 .40938 .57398 .41106 .57567 .41002 .5746 Mtetra
.649 .746 .921 r
.41002 .5746 .41106 .57567 .41281 .57527 .41178 .57406 Mtetra
.7 .735 .878 r
.41178 .57406 .41281 .57527 .41457 .57439 .41354 .57325 Mtetra
.671 .741 .902 r
.41354 .57325 .41457 .57439 .41634 .57354 .4153 .57261 Mtetra
.493 .719 .972 r
.4153 .57261 .41634 .57354 .41809 .57326 .41704 .57252 Mtetra
.59 .801 .98 r
.41704 .57252 .41809 .57326 .41984 .57284 .4188 .57211 Mtetra
.805 .842 .879 r
.4188 .57211 .41984 .57284 .42161 .57195 .42058 .57074 Mtetra
.899 .752 .689 r
.42058 .57074 .42161 .57195 .42341 .57006 .42245 .5667 Mtetra
.908 .671 .568 r
.42245 .5667 .42341 .57006 .42523 .56761 .42461 .55257 Mtetra
.942 .671 .497 r
.42461 .55257 .42523 .56761 .42704 .56537 .43194 .36127 Mtetra
.542 .322 .53 r
.43194 .36127 .42704 .56537 .42879 .5653 .4336 .36038 Mtetra
.54 .32 .53 r
.4336 .36038 .42879 .5653 .43054 .56488 .43525 .36025 Mtetra
.542 .322 .53 r
.43525 .36025 .43054 .56488 .43237 .56204 .43693 .35899 Mtetra
.547 .326 .531 r
.43693 .35899 .43237 .56204 .43948 .36194 .43867 .3556 Mtetra
.669 .482 .622 r
.43867 .3556 .43948 .36194 .44131 .35521 .44038 .35313 Mtetra
.75 .641 .741 r
.44038 .35313 .44131 .35521 .44302 .35247 .44206 .35147 Mtetra
.698 .764 .903 r
.44206 .35147 .44302 .35247 .44469 .35161 .44373 .35075 Mtetra
.639 .778 .947 r
.44373 .35075 .44469 .35161 .44635 .35117 .44539 .35026 Mtetra
.621 .758 .944 r
.44539 .35026 .44635 .35117 .448 .35089 .44705 .34984 Mtetra
.664 .743 .909 r
.44705 .34984 .448 .35089 .44967 .35035 .44871 .34926 Mtetra
.664 .735 .903 r
.44871 .34926 .44967 .35035 .45133 .34982 .45037 .34868 Mtetra
.664 .726 .895 r
.45037 .34868 .45133 .34982 .45299 .34929 .45204 .3481 Mtetra
.665 .718 .888 r
.45204 .3481 .45299 .34929 .45466 .34873 .45371 .34752 Mtetra
.663 .712 .884 r
.45371 .34752 .45466 .34873 .45632 .34816 .45537 .34694 Mtetra
.672 .712 .878 r
.45537 .34694 .45632 .34816 .45799 .34757 .45704 .34631 Mtetra
.706 .718 .858 r
.45704 .34631 .45799 .34757 .45966 .34688 .45872 .34548 Mtetra
.657 .68 .86 r
.45872 .34548 .45966 .34688 .46133 .3463 .46039 .34491 Mtetra
.501 .611 .893 r
.46039 .34491 .46133 .3463 .463 .34604 .46205 .34497 Mtetra
.659 .18 0 r
.46205 .34497 .463 .34604 .46465 .34663 .46367 .34719 Mtetra
.911 .563 .368 r
.46367 .34719 .46465 .34663 .46629 .34768 .46519 .35462 Mtetra
.953 .673 .47 r
.46519 .35462 .46629 .34768 .46794 .34896 .46328 .55101 Mtetra
.54 .316 .524 r
.46328 .55101 .46794 .34896 .46961 .34878 .46504 .55168 Mtetra
.537 .314 .523 r
.46504 .55168 .46961 .34878 .47129 .34803 .46683 .55079 Mtetra
.536 .313 .523 r
.46683 .55079 .47129 .34803 .47297 .34709 .46864 .54919 Mtetra
.538 .314 .523 r
.46864 .54919 .47297 .34709 .47466 .34649 .47043 .5486 Mtetra
.47043 .5486 .47466 .34649 .47634 .34589 .47222 .54799 Mtetra
.47222 .54799 .47634 .34589 .47802 .3453 .47401 .54738 Mtetra
.47401 .54738 .47802 .3453 .4797 .34472 .4758 .54683 Mtetra
.4758 .54683 .4797 .34472 .48139 .34416 .47759 .54629 Mtetra
.47759 .54629 .48139 .34416 .48307 .3436 .47938 .54579 Mtetra
.47938 .54579 .48307 .3436 .48476 .34306 .48118 .54532 Mtetra
.48118 .54532 .48476 .34306 .48645 .34252 .48297 .54486 Mtetra
.48297 .54486 .48645 .34252 .48814 .34202 .48477 .54446 Mtetra
.54 .316 .524 r
.48477 .54446 .48814 .34202 .48982 .34187 .48656 .54501 Mtetra
.538 .314 .523 r
.48656 .54501 .48982 .34187 .49151 .34141 .48835 .54463 Mtetra
.535 .312 .523 r
.48835 .54463 .49151 .34141 .49321 .34028 .49017 .54235 Mtetra
0 0 .324 r
.49017 .54235 .49321 .34028 .49492 .33768 .49392 .34265 Mtetra
0 0 0 r
.49392 .34265 .49492 .33768 .49663 .33552 .49568 .33569 Mtetra
.961 .926 .718 r
.49568 .33569 .49663 .33552 .49833 .33386 .4974 .33262 Mtetra
.727 .73 .853 r
.4974 .33262 .49833 .33386 .50003 .3331 .4991 .33166 Mtetra
.641 .668 .86 r
.4991 .33166 .50003 .3331 .50172 .33257 .50079 .33116 Mtetra
.585 .649 .88 r
.50079 .33116 .50172 .33257 .50342 .33217 .50248 .33091 Mtetra
.621 .691 .894 r
.50248 .33091 .50342 .33217 .50511 .33172 .50418 .33051 Mtetra
.619 .699 .902 r
.50418 .33051 .50511 .33172 .50681 .33127 .50588 .33012 Mtetra
.63 .715 .908 r
.50588 .33012 .50681 .33127 .50851 .33076 .50758 .32967 Mtetra
.686 .748 .898 r
.50758 .32967 .50851 .33076 .51021 .33004 .50928 .32898 Mtetra
.698 .758 .898 r
.50928 .32898 .51021 .33004 .51191 .32927 .51098 .32823 Mtetra
.7 .762 .9 r
.51098 .32823 .51191 .32927 .51362 .32851 .51269 .32748 Mtetra
.715 .767 .894 r
.51269 .32748 .51362 .32851 .51532 .32754 .51439 .32665 Mtetra
.682 .788 .93 r
.51439 .32665 .51532 .32754 .51703 .32685 .5161 .32598 Mtetra
.598 .767 .96 r
.5161 .32598 .51703 .32685 .51873 .32665 .5178 .3256 Mtetra
.302 .58 .938 r
.5178 .3256 .51873 .32665 .52043 .32861 .51951 .32599 Mtetra
.296 .346 .745 r
.51951 .32599 .52043 .32861 .52214 .33585 .52121 .32725 Mtetra
.352 .235 .579 r
.52121 .32725 .52214 .33585 .52378 .53561 .52292 .33069 Mtetra
0 0 .351 r
.52292 .33069 .52378 .53561 .52561 .53832 .52462 .53064 Mtetra
.088 .061 .528 r
.52462 .53064 .52561 .53832 .52744 .53932 .52645 .53652 Mtetra
.107 .222 .701 r
.52645 .53652 .52744 .53932 .52927 .53958 .52828 .53859 Mtetra
.462 .695 .968 r
.52828 .53859 .52927 .53958 .5311 .53928 .53011 .53858 Mtetra
.638 .837 .977 r
.53011 .53858 .5311 .53928 .53293 .5387 .53195 .53799 Mtetra
.715 .851 .947 r
.53195 .53799 .53293 .5387 .53477 .53799 .53378 .53711 Mtetra
.598 .781 .968 r
.53378 .53711 .53477 .53799 .5366 .53776 .53562 .53669 Mtetra
.635 .751 .932 r
.53562 .53669 .5366 .53776 .53844 .53734 .53745 .53618 Mtetra
.698 .755 .896 r
.53745 .53618 .53844 .53734 .54027 .53638 .53929 .53538 Mtetra
.814 .804 .842 r
.53929 .53538 .54027 .53638 .5421 .53319 .54112 .53377 Mtetra
.865 .984 .7 r
.54112 .53377 .5421 .53319 .54389 .52524 .54295 .53125 Mtetra
.094 0 .275 r
.54295 .53125 .54389 .52524 .54448 .32346 .54477 .52668 Mtetra
0 0 .347 r
.54477 .52668 .54448 .32346 .54618 .31955 .54531 .32561 Mtetra
0 0 .13 r
.54531 .32561 .54618 .31955 .54789 .31751 .54699 .31821 Mtetra
.916 .96 .636 r
.54699 .31821 .54789 .31751 .54961 .31617 .5487 .31515 Mtetra
.754 .783 .877 r
.5487 .31515 .54961 .31617 .55134 .31542 .55042 .31409 Mtetra
.627 .683 .883 r
.55042 .31409 .55134 .31542 .55307 .31495 .55215 .31365 Mtetra
.566 .662 .902 r
.55215 .31365 .55307 .31495 .5548 .31459 .55388 .31346 Mtetra
.701 .748 .888 r
.55388 .31346 .5548 .31459 .55652 .31364 .55561 .31268 Mtetra
.713 .786 .909 r
.55561 .31268 .55652 .31364 .55825 .31277 .55734 .31186 Mtetra
.654 .78 .94 r
.55734 .31186 .55825 .31277 .55998 .31235 .55907 .31129 Mtetra
.399 .632 .948 r
.55907 .31129 .55998 .31235 .56174 .31384 .56081 .31149 Mtetra
.322 .387 .774 r
.56081 .31149 .56174 .31384 .56355 .31917 .56257 .31254 Mtetra
.345 .251 .604 r
.56257 .31254 .56355 .31917 .56789 .52081 .56435 .31533 Mtetra
0 0 .37 r
.56435 .31533 .56789 .52081 .56979 .52441 .56871 .51445 Mtetra
.086 .043 .507 r
.56871 .51445 .56979 .52441 .57168 .52558 .57068 .52232 Mtetra
.133 .21 .678 r
.57068 .52232 .57168 .52558 .57355 .52591 .57258 .52469 Mtetra
.396 .614 .938 r
.57258 .52469 .57355 .52591 .57542 .52585 .57445 .52495 Mtetra
.655 .799 .951 r
.57445 .52495 .57542 .52585 .57728 .52531 .57631 .52433 Mtetra
.766 .808 .887 r
.57631 .52433 .57728 .52531 .57913 .52414 .57817 .52314 Mtetra
.814 .811 .848 r
.57817 .52314 .57913 .52414 .58095 .52111 .58001 .52156 Mtetra
.848 .99 .727 r
.58001 .52156 .58095 .52111 .5827 .51363 .58185 .51925 Mtetra
.141 0 .287 r
.58185 .51925 .5827 .51363 .58095 .31156 .58365 .51524 Mtetra
0 0 .365 r
.58365 .51524 .58095 .31156 .58264 .30727 .5819 .31548 Mtetra
0 0 .22 r
.5819 .31548 .58264 .30727 .58435 .30516 .58349 .30622 Mtetra
.851 .921 .527 r
.58349 .30622 .58435 .30516 .58609 .30377 .58519 .30289 Mtetra
.789 .82 .877 r
.58519 .30289 .58609 .30377 .58783 .30299 .58693 .30163 Mtetra
.628 .682 .882 r
.58693 .30163 .58783 .30299 .58959 .30254 .58868 .30119 Mtetra
.555 .65 .898 r
.58868 .30119 .58959 .30254 .59134 .30224 .59044 .30104 Mtetra
.655 .722 .898 r
.59044 .30104 .59134 .30224 .59309 .30148 .5922 .30047 Mtetra
.686 .772 .917 r
.5922 .30047 .59309 .30148 .59484 .30069 .59395 .29977 Mtetra
.634 .773 .947 r
.59395 .29977 .59484 .30069 .5966 .30032 .59571 .29927 Mtetra
.436 .655 .952 r
.59571 .29927 .5966 .30032 .5984 .30169 .59748 .29938 Mtetra
.36 .416 .783 r
.59748 .29938 .5984 .30169 .60031 .30717 .59927 .30028 Mtetra
.39 .281 .609 r
.59927 .30028 .60031 .30717 .60705 .50866 .6011 .30268 Mtetra
0 0 .389 r
.6011 .30268 .60705 .50866 .60904 .51223 .60778 .49897 Mtetra
.11 .046 .497 r
.60778 .49897 .60904 .51223 .61096 .51329 .60994 .5093 Mtetra
.183 .21 .654 r
.60994 .5093 .61096 .51329 .61287 .51361 .61191 .51201 Mtetra
.226 .441 .861 r
.61191 .51201 .61287 .51361 .61478 .51387 .61383 .51294 Mtetra
.482 .722 .976 r
.61383 .51294 .61478 .51387 .61668 .51376 .61574 .51285 Mtetra
.738 .822 .917 r
.61574 .51285 .61668 .51376 .61856 .51287 .61762 .51184 Mtetra
.927 .795 .695 r
.61762 .51184 .61856 .51287 .62036 .50914 .61941 .50797 Mtetra
.974 .687 .418 r
.61941 .50797 .62036 .50914 .61635 .30669 .61542 .30419 Mtetra
.935 .693 .549 r
.61542 .30419 .61635 .30669 .61777 .29418 .61688 .29286 Mtetra
.847 .757 .764 r
.61688 .29286 .61777 .29418 .61949 .29187 .6186 .29061 Mtetra
.646 .708 .892 r
.6186 .29061 .61949 .29187 .62126 .2913 .62037 .29008 Mtetra
.506 .653 .924 r
.62037 .29008 .62126 .2913 .62305 .29125 .62216 .29006 Mtetra
.578 .696 .922 r
.62216 .29006 .62305 .29125 .62483 .29094 .62395 .2898 Mtetra
.659 .736 .907 r
.62395 .2898 .62483 .29094 .62661 .29033 .62572 .28921 Mtetra
.674 .747 .906 r
.62572 .28921 .62661 .29033 .62838 .28965 .6275 .28855 Mtetra
.754 .776 .871 r
.6275 .28855 .62838 .28965 .63014 .28854 .62926 .28745 Mtetra
.756 .777 .87 r
.62926 .28745 .63014 .28854 .6319 .28744 .63102 .28633 Mtetra
.648 .741 .917 r
.63102 .28633 .6319 .28744 .63368 .2869 .6328 .28579 Mtetra
0 .09 .62 r
.6328 .28579 .63368 .2869 .63554 .28868 .63466 .28758 Mtetra
.974 .678 .392 r
.63466 .28758 .63554 .28868 .64435 .48256 .64346 .48246 Mtetra
.957 .623 .332 r
.64346 .48246 .64435 .48256 .64696 .50138 .64603 .50033 Mtetra
0 .077 .592 r
.64603 .50033 .64696 .50138 .64897 .50335 .64803 .50219 Mtetra
.572 .715 .939 r
.64803 .50219 .64897 .50335 .65089 .50316 .64995 .5019 Mtetra
.732 .756 .872 r
.64995 .5019 .65089 .50316 .65278 .50203 .65185 .50084 Mtetra
.796 .785 .843 r
.65185 .50084 .65278 .50203 .65462 .49945 .65373 .49932 Mtetra
.888 .974 .828 r
.65373 .49932 .65462 .49945 .65633 .49372 .65558 .49724 Mtetra
0 0 .158 r
.65558 .49724 .65633 .49372 .65008 .29023 .65739 .49385 Mtetra
.518 .299 .521 r
.65739 .49385 .65008 .29023 .65166 .28432 .65885 .48204 Mtetra
0 0 .387 r
.65885 .48204 .65166 .28432 .65338 .28205 .65265 .28429 Mtetra
0 0 0 r
.65265 .28429 .65338 .28205 .65514 .28058 .6543 .28017 Mtetra
.88 .93 .851 r
.6543 .28017 .65514 .28058 .65692 .2796 .65604 .27835 Mtetra
.687 .729 .882 r
.65604 .27835 .65692 .2796 .65871 .27893 .65783 .2776 Mtetra
.624 .691 .891 r
.65783 .2776 .65871 .27893 .66051 .27838 .65963 .27716 Mtetra
.709 .744 .879 r
.65963 .27716 .66051 .27838 .66229 .27743 .66142 .2763 Mtetra
.758 .774 .866 r
.66142 .2763 .66229 .27743 .66406 .27629 .66319 .27516 Mtetra
.663 .743 .91 r
.66319 .27516 .66406 .27629 .66586 .27567 .66499 .27454 Mtetra
0 .282 .779 r
.66499 .27454 .66586 .27567 .66775 .27699 .66688 .27586 Mtetra
.942 .581 .2 r
.66688 .27586 .66775 .27699 .67005 .28715 .66919 .28612 Mtetra
.975 .676 .377 r
.66919 .28612 .67005 .28715 .68148 .49001 .68056 .48893 Mtetra
0 0 .468 r
.68056 .48893 .68148 .49001 .68356 .4925 .68264 .49133 Mtetra
.556 .707 .941 r
.68264 .49133 .68356 .4925 .68552 .49239 .68459 .4911 Mtetra
.734 .756 .87 r
.68459 .4911 .68552 .49239 .68743 .49126 .6865 .49001 Mtetra
.81 .782 .827 r
.6865 .49001 .68743 .49126 .68927 .48864 .68839 .48832 Mtetra
.919 .937 .801 r
.68839 .48832 .68927 .48864 .69091 .48229 .69024 .48591 Mtetra
0 0 .12 r
.69024 .48591 .69091 .48229 .68248 .27762 .69199 .48159 Mtetra
0 0 .399 r
.69199 .48159 .68248 .27762 .68403 .27188 .68359 .27904 Mtetra
0 0 .237 r
.68359 .27904 .68403 .27188 .68574 .26933 .68499 .27038 Mtetra
.72 .863 .444 r
.68499 .27038 .68574 .26933 .68752 .26806 .68668 .26741 Mtetra
.436 .762 .996 r
.68668 .26741 .68752 .26806 .6894 .26873 .68853 .26729 Mtetra
.816 .415 0 r
.68853 .26729 .6894 .26873 .69158 .27499 .69066 .27257 Mtetra
.976 .675 .363 r
.69066 .27257 .69158 .27499 .70469 .48179 .70376 .4802 Mtetra
.623 .219 0 r
.70376 .4802 .70469 .48179 .70686 .48521 .70594 .48401 Mtetra
.407 .626 .942 r
.70594 .48401 .70686 .48521 .70885 .48541 .70794 .48424 Mtetra
.715 .773 .898 r
.70794 .48424 .70885 .48541 .71079 .48446 .70988 .48331 Mtetra
.9 .803 .744 r
.70988 .48331 .71079 .48446 .71261 .4815 .7117 .48035 Mtetra
.978 .736 .499 r
.7117 .48035 .71261 .4815 .71387 .46892 .71295 .46752 Mtetra
.977 .681 .379 r
.71295 .46752 .71387 .46892 .70407 .26586 .70322 .26467 Mtetra
.915 .786 .703 r
.70322 .26467 .70407 .26586 .70573 .26245 .70488 .26128 Mtetra
.715 .758 .886 r
.70488 .26128 .70573 .26245 .70754 .26156 .70669 .26039 Mtetra
.593 .71 .925 r
.70669 .26039 .70754 .26156 .70939 .26122 .70854 .26005 Mtetra
.628 .726 .918 r
.70854 .26005 .70939 .26122 .71122 .26074 .71038 .25958 Mtetra
.736 .767 .878 r
.71038 .25958 .71122 .26074 .71303 .25972 .71218 .25856 Mtetra
.645 .735 .914 r
.71218 .25856 .71303 .25972 .71486 .25917 .71402 .25801 Mtetra
.08 .412 .863 r
.71402 .25801 .71486 .25917 .71679 .26015 .71595 .25901 Mtetra
.918 .541 .122 r
.71595 .25901 .71679 .26015 .7192 .26868 .71837 .2677 Mtetra
.975 .671 .353 r
.71837 .2677 .7192 .26868 .73407 .47338 .73318 .47233 Mtetra
.62 .151 0 r
.73318 .47233 .73407 .47338 .73627 .4763 .73538 .47529 Mtetra
.453 .694 .969 r
.73538 .47529 .73627 .4763 .73827 .4762 .73739 .4753 Mtetra
.715 .832 .937 r
.73739 .4753 .73827 .4762 .74022 .4753 .73934 .47437 Mtetra
.859 .849 .832 r
.73934 .47437 .74022 .4753 .74215 .47398 .74123 .4724 Mtetra
.904 .756 .687 r
.74123 .4724 .74215 .47398 .74407 .47254 .74299 .46851 Mtetra
.912 .662 .546 r
.74299 .46851 .74407 .47254 .74594 .47032 .74422 .45681 Mtetra
.969 .667 .394 r
.74422 .45681 .74594 .47032 .74764 .46567 .73277 .25748 Mtetra
.546 .325 .531 r
.73277 .25748 .74764 .46567 .73567 .26115 .73442 .25387 Mtetra
.641 .452 .613 r
.73442 .25387 .73567 .26115 .73709 .25418 .73616 .25174 Mtetra
.709 .61 .744 r
.73616 .25174 .73709 .25418 .73879 .25149 .73796 .25039 Mtetra
.687 .766 .912 r
.73796 .25039 .73879 .25149 .74062 .25059 .7398 .24965 Mtetra
.629 .778 .952 r
.7398 .24965 .74062 .25059 .74248 .25014 .74166 .24913 Mtetra
.66 .776 .935 r
.74166 .24913 .74248 .25014 .74434 .24964 .74351 .24851 Mtetra
.75 .78 .878 r
.74351 .24851 .74434 .24964 .74615 .24855 .74532 .24741 Mtetra
.665 .749 .913 r
.74532 .24741 .74615 .24855 .74801 .24792 .74718 .24677 Mtetra
.227 .511 .909 r
.74718 .24677 .74801 .24792 .74995 .24861 .74913 .24745 Mtetra
.892 .503 .055 r
.74913 .24745 .74995 .24861 .75242 .25622 .75159 .25511 Mtetra
.975 .667 .334 r
.75159 .25511 .75242 .25622 .76968 .46225 .7688 .46114 Mtetra
.647 .191 0 r
.7688 .46114 .76968 .46225 .77197 .46564 .7711 .46452 Mtetra
.387 .634 .953 r
.7711 .46452 .77197 .46564 .77403 .46589 .77316 .46477 Mtetra
.694 .781 .918 r
.77316 .46477 .77403 .46589 .77601 .46506 .77514 .46393 Mtetra
.873 .82 .793 r
.77514 .46393 .77601 .46506 .77788 .46273 .77701 .46161 Mtetra
.978 .767 .552 r
.77701 .46161 .77788 .46273 .77932 .45489 .77845 .45376 Mtetra
.977 .675 .347 r
.77845 .45376 .77932 .45489 .76505 .24643 .76423 .24525 Mtetra
.95 .784 .641 r
.76423 .24525 .76505 .24643 .7666 .2418 .76578 .24062 Mtetra
.746 .772 .874 r
.76578 .24062 .7666 .2418 .76843 .24071 .76761 .23952 Mtetra
.62 .722 .92 r
.76761 .23952 .76843 .24071 .77031 .24026 .76949 .23907 Mtetra
.588 .707 .926 r
.76949 .23907 .77031 .24026 .7722 .23994 .77138 .23875 Mtetra
.748 .771 .872 r
.77138 .23875 .7722 .23994 .77403 .23883 .77321 .23764 Mtetra
.673 .744 .904 r
.77321 .23764 .77403 .23883 .7759 .23815 .77508 .23695 Mtetra
.366 .587 .929 r
.77508 .23695 .7759 .23815 .77785 .23853 .77704 .23733 Mtetra
.821 .412 0 r
.77704 .23733 .77785 .23853 .78027 .2444 .77944 .24312 Mtetra
.973 .663 .318 r
.77944 .24312 .78027 .2444 .79962 .45208 .79876 .45087 Mtetra
.685 .248 0 r
.79876 .45087 .79962 .45208 .80203 .45613 .80116 .45493 Mtetra
.453 .655 .947 r
.80116 .45493 .80203 .45613 .80412 .45636 .80324 .45503 Mtetra
.68 .738 .894 r
.80324 .45503 .80412 .45636 .80612 .45558 .80525 .45424 Mtetra
.777 .772 .849 r
.80525 .45424 .80612 .45558 .80804 .45376 .8072 .45281 Mtetra
.842 .855 .854 r
.8072 .45281 .80804 .45376 .80975 .44961 .80912 .45102 Mtetra
0 0 0 r
.80912 .45102 .80975 .44961 .81032 .4324 .81095 .44827 Mtetra
.399 .183 .466 r
.81095 .44827 .81032 .4324 .79506 .23627 .81256 .44288 Mtetra
.054 0 .435 r
.81256 .44288 .79506 .23627 .79674 .23336 .79647 .23823 Mtetra
0 0 .228 r
.79647 .23823 .79674 .23336 .79853 .23161 .79787 .23203 Mtetra
.857 .953 .603 r
.79787 .23203 .79853 .23161 .80037 .23042 .79956 .22921 Mtetra
.726 .765 .883 r
.79956 .22921 .80037 .23042 .80224 .22965 .80142 .22823 Mtetra
.639 .691 .882 r
.80142 .22823 .80224 .22965 .80414 .22908 .80331 .2277 Mtetra
.606 .681 .895 r
.80331 .2277 .80414 .22908 .80604 .22855 .80523 .22731 Mtetra
.752 .769 .867 r
.80523 .22731 .80604 .22855 .80788 .22738 .80707 .22616 Mtetra
.684 .745 .897 r
.80707 .22616 .80788 .22738 .80976 .22662 .80896 .2254 Mtetra
.466 .641 .932 r
.80896 .2254 .80976 .22662 .81172 .22671 .81092 .2255 Mtetra
.772 .357 0 r
.81092 .2255 .81172 .22671 .81418 .23197 .81337 .23076 Mtetra
.971 .657 .298 r
.81337 .23076 .81418 .23197 .83602 .44045 .83517 .4393 Mtetra
.722 .287 0 r
.83517 .4393 .83602 .44045 .83855 .44503 .83771 .44388 Mtetra
.31 .583 .939 r
.83771 .44388 .83855 .44503 .8407 .44551 .83986 .44436 Mtetra
.651 .765 .932 r
.83986 .44436 .8407 .44551 .84274 .44486 .8419 .44371 Mtetra
.831 .821 .839 r
.8419 .44371 .84274 .44486 .84467 .44305 .84383 .4419 Mtetra
.976 .788 .586 r
.84383 .4419 .84467 .44305 .84617 .43688 .84534 .43573 Mtetra
.974 .667 .312 r
.84534 .43573 .84617 .43688 .82744 .22687 .82665 .22567 Mtetra
.974 .776 .575 r
.82665 .22567 .82744 .22687 .8288 .22069 .828 .21948 Mtetra
.766 .76 .847 r
.21506 .42922 .21611 .43019 .21769 .42907 .21664 .42811 Mtetra
.63 .735 .923 r
.21664 .42811 .21769 .42907 .2192 .42867 .21816 .42771 Mtetra
.489 .686 .954 r
.21816 .42771 .2192 .42867 .22068 .42863 .21964 .42768 Mtetra
.749 .76 .862 r
.21964 .42768 .22068 .42863 .22225 .42763 .22121 .4267 Mtetra
.691 .757 .902 r
.22121 .4267 .22225 .42763 .22379 .42698 .22275 .42606 Mtetra
.445 .677 .963 r
.22275 .42606 .22379 .42698 .22527 .42705 .22423 .4261 Mtetra
.932 .565 .289 r
.22423 .4261 .22527 .42705 .22629 .43207 .2253 .43057 Mtetra
.939 .683 .524 r
.2253 .43057 .22629 .43207 .20962 .63092 .2086 .62898 Mtetra
.94 .579 .189 r
.2086 .62898 .20962 .63092 .21079 .63542 .20973 .63393 Mtetra
.44 .571 .889 r
.20973 .63393 .21079 .63542 .21237 .63547 .21129 .63417 Mtetra
.673 .699 .866 r
.21129 .63417 .21237 .63547 .21403 .63464 .21293 .63354 Mtetra
.747 .747 .852 r
.21293 .63354 .21403 .63464 .21573 .63335 .21461 .63247 Mtetra
.526 .734 .969 r
.21461 .63247 .21573 .63335 .21734 .63299 .21621 .63231 Mtetra
.614 .809 .975 r
.21621 .63231 .21734 .63299 .21897 .63251 .21783 .63187 Mtetra
.784 .836 .892 r
.21783 .63187 .21897 .63251 .22064 .63157 .21953 .63071 Mtetra
.912 .743 .659 r
.21953 .63071 .22064 .63157 .22253 .62822 .2216 .6252 Mtetra
.936 .684 .531 r
.2216 .6252 .22253 .62822 .22489 .6193 .24064 .4258 Mtetra
.553 .331 .533 r
.24064 .4258 .22489 .6193 .24321 .42625 .24265 .4199 Mtetra
.624 .449 .625 r
.24265 .4199 .24321 .42625 .24488 .42432 .24426 .41856 Mtetra
.581 .424 .633 r
.24426 .41856 .24488 .42432 .24641 .42399 .24579 .41811 Mtetra
.554 .403 .63 r
.24579 .41811 .24641 .42399 .24787 .42439 .2473 .41805 Mtetra
.575 .413 .624 r
.2473 .41805 .24787 .42439 .24939 .42415 .24883 .41764 Mtetra
.578 .413 .622 r
.24883 .41764 .24939 .42415 .25093 .42379 .25037 .41716 Mtetra
.577 .412 .62 r
.25037 .41716 .25093 .42379 .25246 .42341 .25191 .41668 Mtetra
.579 .412 .619 r
.25191 .41668 .25246 .42341 .25401 .42296 .25346 .41617 Mtetra
.579 .411 .618 r
.25346 .41617 .25401 .42296 .25555 .42248 .25501 .41564 Mtetra
.25501 .41564 .25555 .42248 .2571 .42199 .25656 .41511 Mtetra
.599 .426 .618 r
.25656 .41511 .2571 .42199 .25872 .42058 .25814 .41418 Mtetra
.59 .423 .624 r
.25814 .41418 .25872 .42058 .2603 .41972 .2597 .41349 Mtetra
.552 .397 .625 r
.2597 .41349 .2603 .41972 .26177 .42023 .26122 .41345 Mtetra
.197 .128 .548 r
.26122 .41345 .26177 .42023 .2478 .61219 .26243 .41707 Mtetra
0 0 .175 r
.26243 .41707 .2478 .61219 .24873 .62056 .24794 .61572 Mtetra
0 0 .234 r
.24794 .61572 .24873 .62056 .25013 .62319 .24909 .6215 Mtetra
.297 .461 .855 r
.24909 .6215 .25013 .62319 .25172 .62344 .25065 .62217 Mtetra
.644 .696 .883 r
.25065 .62217 .25172 .62344 .25337 .62294 .2523 .62168 Mtetra
.72 .719 .849 r
.2523 .62168 .25337 .62294 .25505 .62218 .25399 .62076 Mtetra
.667 .68 .853 r
.25399 .62076 .25505 .62218 .2567 .62173 .25565 .62013 Mtetra
.645 .649 .84 r
.25565 .62013 .2567 .62173 .25834 .62136 .25731 .61961 Mtetra
.642 .629 .822 r
.25731 .61961 .25834 .62136 .25999 .62095 .25896 .61908 Mtetra
.637 .614 .81 r
.25896 .61908 .25999 .62095 .26165 .62037 .26062 .61857 Mtetra
.637 .622 .818 r
.26062 .61857 .26165 .62037 .26333 .6197 .26228 .61807 Mtetra
.64 .643 .837 r
.26228 .61807 .26333 .6197 .265 .61901 .26394 .61757 Mtetra
.638 .667 .862 r
.26394 .61757 .265 .61901 .26665 .6186 .2656 .61709 Mtetra
.639 .659 .853 r
.2656 .61709 .26665 .6186 .26831 .61818 .26726 .61661 Mtetra
.647 .653 .841 r
.26726 .61661 .26831 .61818 .26998 .61752 .26893 .61607 Mtetra
.602 .653 .873 r
.26893 .61607 .26998 .61752 .27171 .61612 .27058 .61576 Mtetra
.588 .88 .993 r
.27058 .61576 .27171 .61612 .27351 .61381 .27224 .61524 Mtetra
0 0 0 r
.27224 .61524 .27351 .61381 .27544 .60967 .27396 .61406 Mtetra
.27396 .61406 .27544 .60967 .29116 .4144 .27592 .60943 Mtetra
0 0 .18 r
.27592 .60943 .29116 .4144 .29332 .4058 .29197 .4094 Mtetra
.898 .853 .402 r
.29197 .4094 .29332 .4058 .29508 .4026 .294 .40247 Mtetra
.888 .913 .837 r
.294 .40247 .29508 .4026 .29671 .40126 .29567 .40063 Mtetra
.675 .828 .957 r
.29567 .40063 .29671 .40126 .29828 .40067 .29724 .40002 Mtetra
.513 .779 .992 r
.29724 .40002 .29828 .40067 .29984 .40035 .29879 .39982 Mtetra
.609 .839 .987 r
.29879 .39982 .29984 .40035 .30142 .39979 .30036 .39937 Mtetra
.652 .878 .982 r
.30036 .39937 .30142 .39979 .303 .39917 .30194 .39877 Mtetra
.631 .878 .987 r
.30194 .39877 .303 .39917 .30456 .39878 .30352 .39822 Mtetra
.705 .852 .953 r
.30352 .39822 .30456 .39878 .30609 .39895 .30511 .3975 Mtetra
.66 .662 .841 r
.30511 .3975 .30609 .39895 .30757 .39988 .30669 .39692 Mtetra
.555 .479 .725 r
.30669 .39692 .30757 .39988 .30896 .4022 .30824 .39689 Mtetra
.258 .2 .599 r
.30824 .39689 .30896 .4022 .29786 .59238 .30961 .39945 Mtetra
0 0 .207 r
.30961 .39945 .29786 .59238 .29868 .60473 .29807 .59676 Mtetra
0 0 .285 r
.29807 .59676 .29868 .60473 .30015 .60751 .29915 .60534 Mtetra
.126 .29 .76 r
.29915 .60534 .30015 .60751 .30175 .60818 .30071 .60668 Mtetra
.6 .646 .868 r
.30071 .60668 .30175 .60818 .30343 .60786 .30238 .60638 Mtetra
.695 .685 .836 r
.30238 .60638 .30343 .60786 .30513 .60698 .30408 .60556 Mtetra
.642 .674 .866 r
.30408 .60556 .30513 .60698 .30688 .60557 .30577 .60506 Mtetra
.585 .847 .994 r
.30577 .60506 .30688 .60557 .30867 .60343 .30745 .60461 Mtetra
0 0 0 r
.30745 .60461 .30867 .60343 .31055 .59978 .30918 .60355 Mtetra
.30918 .60355 .31055 .59978 .32397 .41041 .31107 .59979 Mtetra
0 0 .19 r
.31107 .59979 .32397 .41041 .32648 .3952 .32502 .40153 Mtetra
.738 .721 .192 r
.32502 .40153 .32648 .3952 .32825 .39166 .32718 .39179 Mtetra
.923 .936 .794 r
.32718 .39179 .32825 .39166 .3299 .39023 .32888 .38952 Mtetra
.691 .814 .941 r
.32888 .38952 .3299 .39023 .33148 .38979 .33048 .38886 Mtetra
.553 .722 .952 r
.33048 .38886 .33148 .38979 .33305 .38969 .33205 .38866 Mtetra
.598 .718 .928 r
.33205 .38866 .33305 .38969 .33463 .38941 .33363 .38835 Mtetra
.655 .729 .904 r
.33363 .38835 .33463 .38941 .33622 .38888 .33522 .38783 Mtetra
.657 .733 .906 r
.33522 .38783 .33622 .38888 .33782 .38829 .33682 .38731 Mtetra
.727 .764 .883 r
.33682 .38731 .33782 .38829 .33945 .38729 .33844 .38645 Mtetra
.738 .796 .898 r
.33844 .38645 .33945 .38729 .34107 .38625 .34005 .38556 Mtetra
.584 .796 .98 r
.34005 .38556 .34107 .38625 .34267 .38577 .34164 .38521 Mtetra
.772 .264 0 r
.34164 .38521 .34267 .38577 .34413 .38759 .3431 .38714 Mtetra
.951 .684 .496 r
.3431 .38714 .34413 .38759 .33482 .58263 .3337 .58262 Mtetra
.934 .621 .425 r
.3337 .58262 .33482 .58263 .33577 .59566 .33472 .59432 Mtetra
0 .029 .569 r
.33472 .59432 .33577 .59566 .33735 .59741 .3363 .59601 Mtetra
.61 .668 .881 r
.3363 .59601 .33735 .59741 .33904 .59707 .338 .59566 Mtetra
.708 .702 .842 r
.338 .59566 .33904 .59707 .34077 .59617 .33973 .59476 Mtetra
.698 .699 .847 r
.33973 .59476 .34077 .59617 .3425 .59535 .34145 .59394 Mtetra
.652 .683 .866 r
.34145 .59394 .3425 .59535 .34421 .5948 .34317 .59338 Mtetra
.651 .681 .865 r
.34317 .59338 .34421 .5948 .34592 .59425 .34488 .59282 Mtetra
.647 .678 .866 r
.34488 .59282 .34592 .59425 .34763 .59372 .34659 .59229 Mtetra
.642 .676 .867 r
.34659 .59229 .34763 .59372 .34935 .59321 .34831 .59178 Mtetra
.34831 .59178 .34935 .59321 .35106 .59271 .35002 .59128 Mtetra
.589 .655 .883 r
.35002 .59128 .35106 .59271 .35277 .59237 .35172 .59101 Mtetra
.569 .659 .898 r
.35172 .59101 .35277 .59237 .35447 .59208 .35342 .59082 Mtetra
.685 .718 .874 r
.35342 .59082 .35447 .59208 .3562 .59144 .35515 .5901 Mtetra
.849 .737 .739 r
.35515 .5901 .3562 .59144 .35798 .58955 .35698 .58741 Mtetra
.916 .693 .585 r
.35698 .58741 .35798 .58955 .35989 .58507 .35923 .57591 Mtetra
.943 .679 .506 r
.35923 .57591 .35989 .58507 .37077 .39341 .37047 .37814 Mtetra
.616 .406 .574 r
.37047 .37814 .37077 .39341 .37292 .38187 .37221 .37501 Mtetra
.591 .42 .619 r
.37221 .37501 .37292 .38187 .37454 .38126 .37384 .37424 Mtetra
.562 .398 .616 r
.37384 .37424 .37454 .38126 .37614 .38126 .37544 .374 Mtetra
.566 .399 .614 r
.37544 .374 .37614 .38126 .37783 .37916 .37705 .37367 Mtetra
.599 .442 .64 r
.37705 .37367 .37783 .37916 .37959 .37581 .37868 .37294 Mtetra
.638 .535 .722 r
.37868 .37294 .37959 .37581 .38129 .37344 .38032 .37221 Mtetra
.678 .709 .871 r
.38032 .37221 .38129 .37344 .38295 .37202 .38194 .37156 Mtetra
.623 .87 .989 r
.38194 .37156 .38295 .37202 .38458 .37136 .38357 .37102 Mtetra
.586 .884 .992 r
.38357 .37102 .38458 .37136 .3862 .37095 .38519 .37051 Mtetra
.61 .869 .991 r
.38519 .37051 .3862 .37095 .38782 .3706 .38682 .36999 Mtetra
.644 .836 .974 r
.38682 .36999 .38782 .3706 .38944 .3702 .38845 .36945 Mtetra
.658 .804 .953 r
.38845 .36945 .38944 .3702 .39106 .3698 .39007 .36889 Mtetra
.67 .77 .925 r
.39007 .36889 .39106 .3698 .39269 .36934 .39171 .3683 Mtetra
.677 .745 .902 r
.39171 .3683 .39269 .36934 .39432 .36878 .39334 .36768 Mtetra
.676 .732 .893 r
.39334 .36768 .39432 .36878 .39595 .36817 .39497 .36706 Mtetra
.706 .739 .877 r
.39497 .36706 .39595 .36817 .39759 .36735 .39662 .36628 Mtetra
.73 .752 .87 r
.39662 .36628 .39759 .36735 .39924 .36636 .39826 .36536 Mtetra
.639 .742 .924 r
.39826 .36536 .39924 .36636 .40088 .36569 .3999 .3649 Mtetra
0 .242 .697 r
.3999 .3649 .40088 .36569 .40248 .366 .40147 .36589 Mtetra
.928 .584 .361 r
.40147 .36589 .40248 .366 .404 .36864 .40281 .37328 Mtetra
.95 .677 .485 r
.40281 .37328 .404 .36864 .40508 .38298 .39689 .57314 Mtetra
.544 .319 .524 r
.39689 .57314 .40508 .38298 .39979 .5705 .39851 .57608 Mtetra
.503 .209 .4 r
.39851 .57608 .39979 .5705 .40153 .57015 .40024 .57588 Mtetra
.455 .168 .387 r
.40024 .57588 .40153 .57015 .4033 .56898 .402 .57504 Mtetra
.458 .175 .394 r
.402 .57504 .4033 .56898 .405 .56966 .40377 .57418 Mtetra
.482 .173 .365 r
.40377 .57418 .405 .56966 .40663 .57244 .40551 .57385 Mtetra
.33 0 .027 r
.40551 .57385 .40663 .57244 .40831 .57405 .40725 .57352 Mtetra
.551 .838 .998 r
.40725 .57352 .40831 .57405 .41002 .5746 .409 .57313 Mtetra
.643 .674 .865 r
.409 .57313 .41002 .5746 .41178 .57406 .41076 .5726 Mtetra
.652 .68 .864 r
.41076 .5726 .41178 .57406 .41354 .57325 .41251 .57203 Mtetra
.623 .709 .907 r
.41251 .57203 .41354 .57325 .4153 .57261 .41427 .5716 Mtetra
.528 .716 .958 r
.41427 .5716 .4153 .57261 .41704 .57252 .41601 .57145 Mtetra
.669 .753 .914 r
.41601 .57145 .41704 .57252 .4188 .57211 .41777 .57082 Mtetra
.825 .748 .778 r
.41777 .57082 .4188 .57211 .42058 .57074 .41958 .56875 Mtetra
.914 .701 .601 r
.41958 .56875 .42058 .57074 .42245 .5667 .42159 .56006 Mtetra
.953 .683 .488 r
.42159 .56006 .42245 .5667 .42461 .55257 .42938 .35861 Mtetra
.548 .327 .531 r
.42938 .35861 .42461 .55257 .43194 .36127 .43114 .35462 Mtetra
.6 .429 .622 r
.43114 .35462 .43194 .36127 .4336 .36038 .4328 .35369 Mtetra
.569 .407 .621 r
.4328 .35369 .4336 .36038 .43525 .36025 .43445 .35333 Mtetra
.563 .4 .618 r
.43445 .35333 .43525 .36025 .43693 .35899 .4361 .35308 Mtetra
.596 .435 .633 r
.4361 .35308 .43693 .35899 .43867 .3556 .43776 .35233 Mtetra
.631 .516 .704 r
.43776 .35233 .43867 .3556 .44038 .35313 .43943 .35158 Mtetra
.675 .663 .83 r
.43943 .35158 .44038 .35313 .44206 .35147 .44109 .35087 Mtetra
.655 .845 .973 r
.44109 .35087 .44206 .35147 .44373 .35075 .44275 .35028 Mtetra
.623 .87 .989 r
.44275 .35028 .44373 .35075 .44539 .35026 .44442 .34972 Mtetra
.625 .855 .986 r
.44442 .34972 .44539 .35026 .44705 .34984 .44608 .34919 Mtetra
.639 .83 .974 r
.44608 .34919 .44705 .34984 .44871 .34926 .44774 .34865 Mtetra
.636 .839 .979 r
.44774 .34865 .44871 .34926 .45037 .34868 .44941 .34811 Mtetra
.638 .85 .981 r
.44941 .34811 .45037 .34868 .45204 .3481 .45107 .34756 Mtetra
.65 .859 .979 r
.45107 .34756 .45204 .3481 .45371 .34752 .45274 .34696 Mtetra
.653 .857 .977 r
.45274 .34696 .45371 .34752 .45537 .34694 .45441 .34636 Mtetra
.677 .857 .968 r
.45441 .34636 .45537 .34694 .45704 .34631 .45608 .34568 Mtetra
.751 .858 .929 r
.45608 .34568 .45704 .34631 .45872 .34548 .45776 .34473 Mtetra
.658 .81 .956 r
.45776 .34473 .45872 .34548 .46039 .34491 .45943 .34415 Mtetra
.18 .582 .939 r
.45943 .34415 .46039 .34491 .46205 .34497 .46108 .34453 Mtetra
.915 .522 .235 r
.46108 .34453 .46205 .34497 .46367 .34719 .46265 .34946 Mtetra
.959 .68 .464 r
.46265 .34946 .46367 .34719 .46519 .35462 .46045 .55202 Mtetra
.547 .321 .524 r
.46045 .55202 .46519 .35462 .46328 .55101 .46214 .55648 Mtetra
.52 .222 .401 r
.46214 .55648 .46328 .55101 .46504 .55168 .46392 .55653 Mtetra
.452 .152 .365 r
.46392 .55653 .46504 .55168 .46683 .55079 .46571 .55582 Mtetra
.426 .132 .361 r
.46571 .55582 .46683 .55079 .46864 .54919 .46751 .55479 Mtetra
.477 .185 .391 r
.46751 .55479 .46864 .54919 .47043 .5486 .4693 .55423 Mtetra
.476 .185 .392 r
.4693 .55423 .47043 .5486 .47222 .54799 .4711 .55366 Mtetra
.477 .186 .393 r
.4711 .55366 .47222 .54799 .47401 .54738 .47289 .55309 Mtetra
.479 .188 .394 r
.47289 .55309 .47401 .54738 .4758 .54683 .47469 .55253 Mtetra
.479 .189 .394 r
.47469 .55253 .4758 .54683 .47759 .54629 .47649 .55199 Mtetra
.48 .189 .394 r
.47649 .55199 .47759 .54629 .47938 .54579 .47828 .55145 Mtetra
.481 .19 .394 r
.47828 .55145 .47938 .54579 .48118 .54532 .48008 .55093 Mtetra
.48 .188 .392 r
.48008 .55093 .48118 .54532 .48297 .54486 .48188 .55041 Mtetra
.481 .189 .391 r
.48188 .55041 .48297 .54486 .48477 .54446 .48368 .54992 Mtetra
.514 .216 .399 r
.48368 .54992 .48477 .54446 .48656 .54501 .48548 .54988 Mtetra
.474 .172 .372 r
.48548 .54988 .48656 .54501 .48835 .54463 .48728 .5494 Mtetra
.381 .089 .338 r
.48728 .5494 .48835 .54463 .49017 .54235 .4891 .548 Mtetra
0 0 .067 r
.4891 .548 .49017 .54235 .49392 .34265 .49097 .54102 Mtetra
0 0 .307 r
.49097 .54102 .49392 .34265 .49568 .33569 .49472 .33711 Mtetra
.96 .898 .52 r
.49472 .33711 .49568 .33569 .4974 .33262 .49645 .33202 Mtetra
.783 .872 .914 r
.49645 .33202 .4974 .33262 .4991 .33166 .49815 .33089 Mtetra
.622 .799 .967 r
.49815 .33089 .4991 .33166 .50079 .33116 .49985 .33042 Mtetra
.477 .751 .99 r
.49985 .33042 .50079 .33116 .50248 .33091 .50154 .3303 Mtetra
.64 .843 .978 r
.50154 .3303 .50248 .33091 .50418 .33051 .50324 .32973 Mtetra
.652 .806 .957 r
.50324 .32973 .50418 .33051 .50588 .33012 .50494 .32917 Mtetra
.658 .769 .931 r
.50494 .32917 .50588 .33012 .50758 .32967 .50664 .3286 Mtetra
.662 .744 .911 r
.50664 .3286 .50758 .32967 .50928 .32898 .50834 .32802 Mtetra
.664 .768 .927 r
.50834 .32802 .50928 .32898 .51098 .32823 .51005 .32743 Mtetra
.663 .805 .951 r
.51005 .32743 .51098 .32823 .51269 .32748 .51175 .32683 Mtetra
.671 .845 .966 r
.51175 .32683 .51269 .32748 .51439 .32665 .51346 .32618 Mtetra
.645 .882 .984 r
.51346 .32618 .51439 .32665 .5161 .32598 .51516 .32554 Mtetra
.62 .882 .989 r
.51516 .32554 .5161 .32598 .5178 .3256 .51687 .32495 Mtetra
.723 .856 .945 r
.51687 .32495 .5178 .3256 .51951 .32599 .51858 .32411 Mtetra
.633 .609 .808 r
.51858 .32411 .51951 .32599 .52121 .32725 .52029 .3236 Mtetra
.531 .44 .697 r
.52029 .3236 .52121 .32725 .52292 .33069 .522 .32379 Mtetra
.153 .111 .553 r
.522 .32379 .52292 .33069 .52462 .53064 .52371 .3285 Mtetra
0 0 .34 r
.52371 .3285 .52462 .53064 .52645 .53652 .52546 .532 Mtetra
0 0 .495 r
.52546 .532 .52645 .53652 .52828 .53859 .52729 .53687 Mtetra
.455 .554 .867 r
.52729 .53687 .52828 .53859 .53011 .53858 .52912 .53716 Mtetra
.658 .694 .872 r
.52912 .53716 .53011 .53858 .53195 .53799 .53096 .53654 Mtetra
.72 .713 .843 r
.53096 .53654 .53195 .53799 .53378 .53711 .53279 .53552 Mtetra
.64 .662 .856 r
.53279 .53552 .53378 .53711 .53562 .53669 .53463 .53498 Mtetra
.632 .643 .843 r
.53463 .53498 .53562 .53669 .53745 .53618 .53646 .53447 Mtetra
.642 .649 .841 r
.53646 .53447 .53745 .53618 .53929 .53538 .5383 .53391 Mtetra
.594 .662 .886 r
.5383 .53391 .53929 .53538 .54112 .53377 .54014 .5336 Mtetra
.53 .904 .956 r
.54014 .5336 .54112 .53377 .54295 .53125 .54198 .53297 Mtetra
.052 0 0 r
.54198 .53297 .54295 .53125 .54477 .52668 .54382 .5316 Mtetra
0 0 .118 r
.54382 .5316 .54477 .52668 .54531 .32561 .54563 .52601 Mtetra
0 0 .334 r
.54563 .52601 .54531 .32561 .54699 .31821 .5461 .32102 Mtetra
.789 .78 .276 r
.5461 .32102 .54699 .31821 .5487 .31515 .54778 .3148 Mtetra
.853 .929 .878 r
.54778 .3148 .5487 .31515 .55042 .31409 .54951 .31322 Mtetra
.664 .794 .944 r
.54951 .31322 .55042 .31409 .55215 .31365 .55123 .31262 Mtetra
.56 .716 .945 r
.55123 .31262 .55215 .31365 .55388 .31346 .55297 .31239 Mtetra
.658 .746 .914 r
.55297 .31239 .55388 .31346 .55561 .31268 .5547 .31182 Mtetra
.671 .796 .942 r
.5547 .31182 .55561 .31268 .55734 .31186 .55643 .31118 Mtetra
.647 .834 .972 r
.55643 .31118 .55734 .31186 .55907 .31129 .55816 .3106 Mtetra
.714 .847 .945 r
.55816 .3106 .55907 .31129 .56081 .31149 .55989 .30977 Mtetra
.648 .637 .825 r
.55989 .30977 .56081 .31149 .56257 .31254 .56163 .30919 Mtetra
.547 .463 .712 r
.56163 .30919 .56257 .31254 .56435 .31533 .56337 .30923 Mtetra
.25 .193 .595 r
.56337 .30923 .56435 .31533 .56871 .51445 .56516 .3127 Mtetra
0 0 .358 r
.56516 .3127 .56871 .51445 .57068 .52232 .56964 .51642 Mtetra
0 0 .477 r
.56964 .51642 .57068 .52232 .57258 .52469 .57159 .52272 Mtetra
.341 .456 .832 r
.57159 .52272 .57258 .52469 .57445 .52495 .57347 .52351 Mtetra
.629 .683 .882 r
.57347 .52351 .57445 .52495 .57631 .52433 .57534 .52303 Mtetra
.719 .74 .868 r
.57534 .52303 .57631 .52433 .57817 .52314 .5772 .52206 Mtetra
.614 .744 .938 r
.5772 .52206 .57817 .52314 .58001 .52156 .57906 .52162 Mtetra
.346 .824 .835 r
.57906 .52162 .58001 .52156 .58185 .51925 .58093 .52106 Mtetra
.135 0 .014 r
.58093 .52106 .58185 .51925 .58365 .51524 .58279 .51982 Mtetra
0 0 .163 r
.58279 .51982 .58365 .51524 .5819 .31548 .58458 .51512 Mtetra
0 0 .35 r
.58458 .51512 .5819 .31548 .58349 .30622 .58268 .31024 Mtetra
0 0 0 r
.58268 .31024 .58349 .30622 .58519 .30289 .58431 .30271 Mtetra
.891 .956 .837 r
.58431 .30271 .58519 .30289 .58693 .30163 .58603 .3008 Mtetra
.673 .806 .946 r
.58603 .3008 .58693 .30163 .58868 .30119 .58778 .30014 Mtetra
.559 .716 .945 r
.58778 .30014 .58868 .30119 .59044 .30104 .58954 .29992 Mtetra
.637 .729 .915 r
.58954 .29992 .59044 .30104 .5922 .30047 .5913 .29943 Mtetra
.669 .758 .917 r
.5913 .29943 .5922 .30047 .59395 .29977 .59305 .2988 Mtetra
.66 .772 .932 r
.59305 .2988 .59395 .29977 .59571 .29927 .59481 .29821 Mtetra
.713 .769 .896 r
.59481 .29821 .59571 .29927 .59748 .29938 .59656 .29736 Mtetra
.655 .611 .792 r
.59656 .29736 .59748 .29938 .59927 .30028 .59832 .29667 Mtetra
.562 .464 .7 r
.59832 .29667 .59927 .30028 .6011 .30268 .60009 .29657 Mtetra
.323 .245 .611 r
.60009 .29657 .6011 .30268 .60778 .49897 .60193 .29942 Mtetra
0 0 .37 r
.60193 .29942 .60778 .49897 .60994 .5093 .60885 .50303 Mtetra
0 0 .446 r
.60885 .50303 .60994 .5093 .61191 .51201 .61094 .51041 Mtetra
.011 .298 .792 r
.61094 .51041 .61191 .51201 .61383 .51294 .61288 .51186 Mtetra
.543 .718 .954 r
.61288 .51186 .61383 .51294 .61574 .51285 .61478 .51166 Mtetra
.762 .774 .862 r
.61478 .51166 .61574 .51285 .61762 .51184 .61665 .51041 Mtetra
.903 .756 .689 r
.61665 .51041 .61762 .51184 .61941 .50797 .61845 .50649 Mtetra
.974 .687 .418 r
.61845 .50649 .61941 .50797 .61542 .30419 .61456 .30419 Mtetra
.989 .761 .498 r
.61456 .30419 .61542 .30419 .61688 .29286 .61601 .29225 Mtetra
.909 .869 .787 r
.61601 .29225 .61688 .29286 .6186 .29061 .61772 .28989 Mtetra
.678 .839 .96 r
.61772 .28989 .6186 .29061 .62037 .29008 .61949 .28919 Mtetra
.532 .743 .972 r
.61949 .28919 .62037 .29008 .62216 .29006 .62128 .28899 Mtetra
.603 .729 .933 r
.62128 .28899 .62216 .29006 .62395 .2898 .62306 .28861 Mtetra
.658 .728 .901 r
.62306 .28861 .62395 .2898 .62572 .28921 .62484 .28802 Mtetra
.661 .73 .9 r
.62484 .28802 .62572 .28921 .6275 .28855 .62661 .28742 Mtetra
.734 .765 .878 r
.62661 .28742 .6275 .28855 .62926 .28745 .62838 .28644 Mtetra
.739 .79 .894 r
.62838 .28644 .62926 .28745 .63102 .28633 .63014 .28545 Mtetra
.606 .776 .962 r
.63014 .28545 .63102 .28633 .6328 .28579 .63193 .28503 Mtetra
.583 .066 0 r
.63193 .28503 .6328 .28579 .63466 .28758 .6338 .28701 Mtetra
.974 .678 .394 r
.6338 .28701 .63466 .28758 .64346 .48246 .64273 .4871 Mtetra
.861 .532 .427 r
.64273 .4871 .64346 .48246 .64603 .50033 .6451 .49938 Mtetra
0 .132 .63 r
.6451 .49938 .64603 .50033 .64803 .50219 .64709 .50101 Mtetra
.601 .724 .931 r
.64709 .50101 .64803 .50219 .64995 .5019 .64901 .50062 Mtetra
.718 .749 .876 r
.64901 .50062 .64995 .5019 .65185 .50084 .65091 .49965 Mtetra
.661 .745 .912 r
.65091 .49965 .65185 .50084 .65373 .49932 .65282 .499 Mtetra
.458 .854 .974 r
.65282 .499 .65373 .49932 .65558 .49724 .65474 .49857 Mtetra
.097 0 0 r
.65474 .49857 .65558 .49724 .65739 .49385 .65665 .49755 Mtetra
.017 0 .177 r
.65665 .49755 .65739 .49385 .65885 .48204 .65845 .4941 Mtetra
.983 .697 .37 r
.65845 .4941 .65885 .48204 .65265 .28429 .65222 .29394 Mtetra
0 0 .168 r
.65222 .29394 .65265 .28429 .6543 .28017 .65346 .27981 Mtetra
.942 .904 .756 r
.65346 .27981 .6543 .28017 .65604 .27835 .65516 .27709 Mtetra
.7 .733 .876 r
.65516 .27709 .65604 .27835 .65783 .2776 .65695 .27627 Mtetra
.6 .679 .897 r
.65695 .27627 .65783 .2776 .65963 .27716 .65876 .27594 Mtetra
.677 .731 .891 r
.65876 .27594 .65963 .27716 .66142 .2763 .66055 .27525 Mtetra
.741 .785 .888 r
.66055 .27525 .66142 .2763 .66319 .27516 .66234 .27423 Mtetra
.627 .777 .952 r
.66234 .27423 .66319 .27516 .66499 .27454 .66414 .27374 Mtetra
0 .14 .624 r
.66414 .27374 .66499 .27454 .66688 .27586 .66604 .27522 Mtetra
.955 .609 .277 r
.66604 .27522 .66688 .27586 .66919 .28612 .66851 .28908 Mtetra
.972 .671 .387 r
.66851 .28908 .66919 .28612 .68056 .48893 .67965 .488 Mtetra
.515 .019 0 r
.67965 .488 .68056 .48893 .68264 .49133 .68171 .49014 Mtetra
.591 .72 .933 r
.68171 .49014 .68264 .49133 .68459 .4911 .68366 .48979 Mtetra
.725 .749 .871 r
.68366 .48979 .68459 .4911 .6865 .49001 .68558 .48875 Mtetra
.71 .753 .886 r
.68558 .48875 .6865 .49001 .68839 .48832 .6875 .48783 Mtetra
.593 .883 .992 r
.6875 .48783 .68839 .48832 .69024 .48591 .68944 .48721 Mtetra
.013 0 0 r
.68944 .48721 .69024 .48591 .69199 .48159 .69135 .48597 Mtetra
0 0 .208 r
.69135 .48597 .69199 .48159 .68359 .27904 .6931 .48162 Mtetra
0 0 .391 r
.6931 .48162 .68359 .27904 .68499 .27038 .68437 .27379 Mtetra
0 0 0 r
.68437 .27379 .68499 .27038 .68668 .26741 .68588 .26736 Mtetra
.58 .941 .903 r
.68588 .26736 .68668 .26741 .68853 .26729 .68769 .26648 Mtetra
.872 .447 .025 r
.68769 .26648 .68853 .26729 .69066 .27257 .68981 .27159 Mtetra
.975 .674 .367 r
.68981 .27159 .69066 .27257 .70376 .4802 .70284 .47894 Mtetra
.717 .277 0 r
.70284 .47894 .70376 .4802 .70594 .48401 .70503 .48279 Mtetra
.405 .621 .94 r
.70503 .48279 .70594 .48401 .70794 .48424 .70703 .48304 Mtetra
.708 .764 .896 r
.70703 .48304 .70794 .48424 .70988 .48331 .70897 .48213 Mtetra
.897 .801 .744 r
.70897 .48213 .70988 .48331 .7117 .48035 .71079 .47919 Mtetra
.979 .735 .497 r
.71079 .47919 .7117 .48035 .71295 .46752 .71203 .46605 Mtetra
.977 .681 .379 r
.71203 .46605 .71295 .46752 .70322 .26467 .70236 .26348 Mtetra
.915 .786 .704 r
.70236 .26348 .70322 .26467 .70488 .26128 .70403 .26011 Mtetra
.714 .758 .887 r
.70403 .26011 .70488 .26128 .70669 .26039 .70584 .25922 Mtetra
.592 .71 .925 r
.70584 .25922 .70669 .26039 .70854 .26005 .70769 .25889 Mtetra
.627 .726 .918 r
.70769 .25889 .70854 .26005 .71038 .25958 .70953 .25841 Mtetra
.735 .767 .878 r
.70953 .25841 .71038 .25958 .71218 .25856 .71133 .2574 Mtetra
.644 .735 .914 r
.71133 .2574 .71218 .25856 .71402 .25801 .71317 .25686 Mtetra
.075 .409 .861 r
.71317 .25686 .71402 .25801 .71595 .25901 .7151 .25786 Mtetra
.92 .544 .127 r
.7151 .25786 .71595 .25901 .71837 .2677 .71753 .26672 Mtetra
.975 .671 .353 r
.71753 .26672 .71837 .2677 .73318 .47233 .73229 .47127 Mtetra
.625 .157 0 r
.73229 .47127 .73318 .47233 .73538 .47529 .73449 .47426 Mtetra
.415 .671 .967 r
.73449 .47426 .73538 .47529 .73739 .4753 .73651 .47438 Mtetra
.721 .829 .932 r
.73651 .47438 .73739 .4753 .73934 .47437 .73846 .47343 Mtetra
.901 .841 .776 r
.73846 .47343 .73934 .47437 .74123 .4724 .74031 .47082 Mtetra
.962 .74 .555 r
.74031 .47082 .74123 .4724 .74299 .46851 .74175 .46219 Mtetra
.975 .674 .377 r
.74175 .46219 .74299 .46851 .74422 .45681 .72999 .25541 Mtetra
.547 .326 .53 r
.72999 .25541 .74422 .45681 .73277 .25748 .73159 .25125 Mtetra
.609 .442 .63 r
.73159 .25125 .73277 .25748 .73442 .25387 .73341 .25013 Mtetra
.598 .485 .695 r
.73341 .25013 .73442 .25387 .73616 .25174 .73526 .24962 Mtetra
.598 .577 .801 r
.73526 .24962 .73616 .25174 .73796 .25039 .73713 .24929 Mtetra
.655 .754 .923 r
.73713 .24929 .73796 .25039 .7398 .24965 .73898 .24869 Mtetra
.646 .784 .947 r
.73898 .24869 .7398 .24965 .74166 .24913 .74083 .24812 Mtetra
.688 .785 .924 r
.74083 .24812 .74166 .24913 .74351 .24851 .74268 .24737 Mtetra
.751 .781 .877 r
.74268 .24737 .74351 .24851 .74532 .24741 .74449 .24626 Mtetra
.667 .749 .912 r
.74449 .24626 .74532 .24741 .74718 .24677 .74635 .24561 Mtetra
.23 .512 .91 r
.74635 .24561 .74718 .24677 .74913 .24745 .7483 .24629 Mtetra
.893 .504 .057 r
.7483 .24629 .74913 .24745 .75159 .25511 .75076 .254 Mtetra
.975 .667 .334 r
.75076 .254 .75159 .25511 .7688 .46114 .76793 .46002 Mtetra
.645 .189 0 r
.76793 .46002 .7688 .46114 .7711 .46452 .77022 .4634 Mtetra
.387 .635 .953 r
.77022 .4634 .7711 .46452 .77316 .46477 .77228 .46364 Mtetra
.694 .781 .918 r
.77228 .46364 .77316 .46477 .77514 .46393 .77426 .46281 Mtetra
.873 .82 .793 r
.77426 .46281 .77514 .46393 .77701 .46161 .77613 .46048 Mtetra
.978 .767 .552 r
.77613 .46048 .77701 .46161 .77845 .45376 .77758 .45263 Mtetra
.977 .675 .347 r
.77758 .45263 .77845 .45376 .76423 .24525 .7634 .24406 Mtetra
.95 .784 .641 r
.7634 .24406 .76423 .24525 .76578 .24062 .76496 .23943 Mtetra
.747 .772 .873 r
.76496 .23943 .76578 .24062 .76761 .23952 .76679 .23833 Mtetra
.62 .722 .919 r
.76679 .23833 .76761 .23952 .76949 .23907 .76867 .23788 Mtetra
.588 .707 .926 r
.76867 .23788 .76949 .23907 .77138 .23875 .77056 .23755 Mtetra
.748 .772 .872 r
.77056 .23755 .77138 .23875 .77321 .23764 .77239 .23644 Mtetra
.673 .744 .904 r
.77239 .23644 .77321 .23764 .77508 .23695 .77426 .23575 Mtetra
.369 .588 .929 r
.77426 .23575 .77508 .23695 .77704 .23733 .77622 .23612 Mtetra
.818 .408 0 r
.77622 .23612 .77704 .23733 .77944 .24312 .77862 .24184 Mtetra
.973 .663 .318 r
.77862 .24184 .77944 .24312 .79876 .45087 .79789 .44966 Mtetra
.686 .249 0 r
.79789 .44966 .79876 .45087 .80116 .45493 .8003 .45373 Mtetra
.494 .678 .947 r
.8003 .45373 .80116 .45493 .80324 .45503 .80236 .4537 Mtetra
.682 .74 .895 r
.80236 .4537 .80324 .45503 .80525 .45424 .80437 .4529 Mtetra
.728 .757 .876 r
.80437 .4529 .80525 .45424 .8072 .45281 .80635 .45183 Mtetra
.546 .754 .973 r
.80635 .45183 .8072 .45281 .80912 .45102 .8084 .45155 Mtetra
0 0 0 r
.8084 .45155 .80912 .45102 .81095 .44827 .81042 .45081 Mtetra
.193 0 .167 r
.81042 .45081 .81095 .44827 .81256 .44288 .81234 .44902 Mtetra
0 0 .257 r
.81234 .44902 .81256 .44288 .79647 .23823 .81375 .44143 Mtetra
.031 0 .428 r
.81375 .44143 .79647 .23823 .79787 .23203 .79725 .23295 Mtetra
.906 .862 .42 r
.79725 .23295 .79787 .23203 .79956 .22921 .79875 .228 Mtetra
.755 .774 .868 r
.79875 .228 .79956 .22921 .80142 .22823 .80059 .22684 Mtetra
.633 .692 .887 r
.80059 .22684 .80142 .22823 .80331 .2277 .80249 .22633 Mtetra
.575 .669 .902 r
.80249 .22633 .80331 .2277 .80523 .22731 .80442 .22608 Mtetra
.751 .769 .867 r
.80442 .22608 .80523 .22731 .80707 .22616 .80627 .22493 Mtetra
.683 .744 .898 r
.80627 .22493 .80707 .22616 .80896 .2254 .80815 .22418 Mtetra
.463 .639 .932 r
.80815 .22418 .80896 .2254 .81092 .2255 .81012 .22428 Mtetra
.771 .357 0 r
.81012 .22428 .81092 .2255 .81337 .23076 .81257 .22954 Mtetra
.971 .657 .298 r
.81257 .22954 .81337 .23076 .83517 .4393 .83433 .43814 Mtetra
.721 .287 0 r
.83433 .43814 .83517 .4393 .83771 .44388 .83686 .44273 Mtetra
.31 .582 .939 r
.83686 .44273 .83771 .44388 .83986 .44436 .83901 .44321 Mtetra
.651 .765 .932 r
.83901 .44321 .83986 .44436 .8419 .44371 .84106 .44256 Mtetra
.831 .821 .839 r
.84106 .44256 .8419 .44371 .84383 .4419 .84299 .44075 Mtetra
.976 .788 .586 r
.84299 .44075 .84383 .4419 .84534 .43573 .8445 .43458 Mtetra
.974 .667 .312 r
.8445 .43458 .84534 .43573 .82665 .22567 .82585 .22448 Mtetra
.974 .776 .574 r
.82585 .22448 .82665 .22567 .828 .21948 .82721 .21828 Mtetra
.766 .76 .848 r
.21402 .42826 .21506 .42922 .21664 .42811 .2156 .42715 Mtetra
.628 .736 .925 r
.2156 .42715 .21664 .42811 .21816 .42771 .21711 .42676 Mtetra
.486 .687 .956 r
.21711 .42676 .21816 .42771 .21964 .42768 .21859 .42673 Mtetra
.732 .76 .875 r
.21859 .42673 .21964 .42768 .22121 .4267 .22015 .42587 Mtetra
.689 .777 .919 r
.22015 .42587 .22121 .4267 .22275 .42606 .22169 .42524 Mtetra
.514 .731 .972 r
.22169 .42524 .22275 .42606 .22423 .4261 .22319 .42511 Mtetra
.816 .345 0 r
.22319 .42511 .22423 .4261 .2253 .43057 .22446 .42733 Mtetra
.98 .686 .355 r
.22446 .42733 .2253 .43057 .2086 .62898 .22499 .43772 Mtetra
0 0 .16 r
.22499 .43772 .2086 .62898 .20973 .63393 .20903 .62848 Mtetra
.317 .243 .613 r
.20903 .62848 .20973 .63393 .21129 .63417 .21041 .63061 Mtetra
.443 .387 .7 r
.21041 .63061 .21129 .63417 .21293 .63354 .21193 .63137 Mtetra
.518 .522 .799 r
.21193 .63137 .21293 .63354 .21461 .63247 .2135 .63149 Mtetra
.388 .65 .961 r
.2135 .63149 .21461 .63247 .21621 .63231 .21507 .63164 Mtetra
.607 .81 .978 r
.21507 .63164 .21621 .63231 .21783 .63187 .2167 .63122 Mtetra
.803 .831 .873 r
.2167 .63122 .21783 .63187 .21953 .63071 .2184 .62991 Mtetra
.918 .741 .647 r
.2184 .62991 .21953 .63071 .2216 .6252 .22054 .6237 Mtetra
.938 .686 .53 r
.22054 .6237 .2216 .6252 .24064 .4258 .23973 .42337 Mtetra
.848 .659 .646 r
.23973 .42337 .24064 .4258 .24265 .4199 .24169 .41807 Mtetra
.733 .645 .762 r
.24169 .41807 .24265 .4199 .24426 .41856 .24329 .41678 Mtetra
.633 .608 .807 r
.24329 .41678 .24426 .41856 .24579 .41811 .24483 .41633 Mtetra
.56 .573 .824 r
.24483 .41633 .24579 .41811 .2473 .41805 .24634 .41624 Mtetra
.626 .601 .806 r
.24634 .41624 .2473 .41805 .24883 .41764 .24787 .41582 Mtetra
.635 .605 .802 r
.24787 .41582 .24883 .41764 .25037 .41716 .24941 .41534 Mtetra
.636 .605 .802 r
.24941 .41534 .25037 .41716 .25191 .41668 .25095 .41486 Mtetra
.641 .607 .8 r
.25095 .41486 .25191 .41668 .25346 .41617 .2525 .41434 Mtetra
.643 .608 .799 r
.2525 .41434 .25346 .41617 .25501 .41564 .25405 .41381 Mtetra
.644 .608 .799 r
.25405 .41381 .25501 .41564 .25656 .41511 .2556 .41328 Mtetra
.683 .625 .785 r
.2556 .41328 .25656 .41511 .25814 .41418 .25717 .41246 Mtetra
.665 .629 .804 r
.25717 .41246 .25814 .41418 .2597 .41349 .25873 .41181 Mtetra
.586 .598 .831 r
.25873 .41181 .2597 .41349 .26122 .41345 .26026 .4116 Mtetra
0 0 .573 r
.26026 .4116 .26122 .41345 .26243 .41707 .26161 .41348 Mtetra
.925 .628 .152 r
.26161 .41348 .26243 .41707 .24794 .61572 .26254 .42072 Mtetra
0 0 .186 r
.26254 .42072 .24794 .61572 .24909 .6215 .24837 .61576 Mtetra
.418 .312 .626 r
.24837 .61576 .24909 .6215 .25065 .62217 .24986 .61722 Mtetra
.591 .449 .656 r
.24986 .61722 .25065 .62217 .2523 .62168 .25152 .6167 Mtetra
.637 .48 .653 r
.25152 .6167 .2523 .62168 .25399 .62076 .25323 .61546 Mtetra
.622 .465 .648 r
.25323 .61546 .25399 .62076 .25565 .62013 .25492 .61441 Mtetra
.599 .442 .64 r
.25492 .61441 .25565 .62013 .25731 .61961 .2566 .61366 Mtetra
.564 .414 .636 r
.2566 .61366 .25731 .61961 .25896 .61908 .25823 .61345 Mtetra
.438 .328 .632 r
.25823 .61345 .25896 .61908 .26062 .61857 .25975 .61471 Mtetra
.373 .33 .681 r
.25975 .61471 .26062 .61857 .26228 .61807 .26127 .61596 Mtetra
.328 .423 .806 r
.26127 .61596 .26228 .61807 .26394 .61757 .26284 .61674 Mtetra
.478 .731 .982 r
.26284 .61674 .26394 .61757 .2656 .61709 .26447 .61665 Mtetra
.593 .863 .994 r
.26447 .61665 .2656 .61709 .26726 .61661 .26613 .61616 Mtetra
.655 .878 .981 r
.26613 .61616 .26726 .61661 .26893 .61607 .2678 .61552 Mtetra
.504 .809 1 r
.2678 .61552 .26893 .61607 .27058 .61576 .26945 .61526 Mtetra
.532 .829 .999 r
.26945 .61526 .27058 .61576 .27224 .61524 .2711 .61492 Mtetra
.699 .911 .969 r
.2711 .61492 .27224 .61524 .27396 .61406 .27279 .61411 Mtetra
.936 .892 .762 r
.27279 .61411 .27396 .61406 .27592 .60943 .27463 .61124 Mtetra
.996 .854 .575 r
.27463 .61124 .27592 .60943 .29197 .4094 .27681 .6037 Mtetra
0 0 .186 r
.27681 .6037 .29197 .4094 .294 .40247 .29264 .40626 Mtetra
.005 0 .127 r
.29264 .40626 .294 .40247 .29567 .40063 .29437 .4035 Mtetra
.414 .07 .271 r
.29437 .4035 .29567 .40063 .29724 .40002 .29595 .40299 Mtetra
.477 .135 .308 r
.29595 .40299 .29724 .40002 .29879 .39982 .29749 .40285 Mtetra
.185 0 .169 r
.29749 .40285 .29879 .39982 .30036 .39937 .29915 .40125 Mtetra
0 0 0 r
.29915 .40125 .30036 .39937 .30194 .39877 .30083 .39925 Mtetra
.817 1 .808 r
.30083 .39925 .30194 .39877 .30352 .39822 .30248 .39759 Mtetra
.808 .836 .872 r
.30248 .39759 .30352 .39822 .30511 .3975 .30411 .3963 Mtetra
.719 .72 .85 r
.30411 .3963 .30511 .3975 .30669 .39692 .30571 .39543 Mtetra
.616 .639 .851 r
.30571 .39543 .30669 .39692 .30824 .39689 .30728 .39508 Mtetra
.111 .31 .784 r
.30728 .39508 .30824 .39689 .30961 .39945 .30875 .39622 Mtetra
0 0 .275 r
.30875 .39622 .30961 .39945 .29807 .59676 .31001 .40039 Mtetra
0 0 .217 r
.31001 .40039 .29807 .59676 .29915 .60534 .2985 .59781 Mtetra
.135 .082 .528 r
.2985 .59781 .29915 .60534 .30071 .60668 .29984 .60244 Mtetra
.399 .335 .67 r
.29984 .60244 .30071 .60668 .30238 .60638 .30141 .60368 Mtetra
.479 .459 .758 r
.30141 .60368 .30238 .60638 .30408 .60556 .30304 .60408 Mtetra
.451 .582 .893 r
.30304 .60408 .30408 .60556 .30577 .60506 .30468 .60429 Mtetra
.476 .745 .988 r
.30468 .60429 .30577 .60506 .30745 .60461 .30634 .60418 Mtetra
.67 .887 .977 r
.30634 .60418 .30745 .60461 .30918 .60355 .30804 .60348 Mtetra
.912 .912 .806 r
.30804 .60348 .30918 .60355 .31107 .59979 .30984 .60117 Mtetra
.99 .891 .603 r
.30984 .60117 .31107 .59979 .32502 .40153 .31185 .59562 Mtetra
0 0 .206 r
.31185 .59562 .32502 .40153 .32718 .39179 .32579 .39703 Mtetra
0 0 .025 r
.32579 .39703 .32718 .39179 .32888 .38952 .32769 .39147 Mtetra
0 0 0 r
.32769 .39147 .32888 .38952 .33048 .38886 .32938 .38937 Mtetra
.668 .967 .777 r
.32938 .38937 .33048 .38886 .33205 .38866 .33102 .38805 Mtetra
.733 .847 .934 r
.33102 .38805 .33205 .38866 .33363 .38835 .33264 .38721 Mtetra
.661 .717 .89 r
.33264 .38721 .33363 .38835 .33522 .38783 .33423 .38666 Mtetra
.626 .7 .898 r
.33423 .38666 .33522 .38783 .33682 .38731 .33582 .38626 Mtetra
.692 .743 .891 r
.33582 .38626 .33682 .38731 .33844 .38645 .33743 .38558 Mtetra
.717 .785 .905 r
.33743 .38558 .33844 .38645 .34005 .38556 .33904 .38479 Mtetra
.608 .783 .965 r
.33904 .38479 .34005 .38556 .34164 .38521 .34063 .3844 Mtetra
0 .103 .565 r
.34063 .3844 .34164 .38521 .3431 .38714 .34213 .38558 Mtetra
.941 .576 .207 r
.34213 .38558 .3431 .38714 .3337 .58262 .3434 .39102 Mtetra
0 0 .227 r
.3434 .39102 .3337 .58262 .33472 .59432 .33394 .58819 Mtetra
.274 .205 .594 r
.33394 .58819 .33472 .59432 .3363 .59601 .33545 .59107 Mtetra
.576 .44 .658 r
.33545 .59107 .3363 .59601 .338 .59566 .33715 .59075 Mtetra
.629 .476 .656 r
.33715 .59075 .338 .59566 .33973 .59476 .33889 .58965 Mtetra
.621 .467 .653 r
.33889 .58965 .33973 .59476 .34145 .59394 .34062 .58863 Mtetra
.593 .445 .65 r
.34062 .58863 .34145 .59394 .34317 .59338 .34233 .58803 Mtetra
.592 .444 .649 r
.34233 .58803 .34317 .59338 .34488 .59282 .34405 .58744 Mtetra
.589 .441 .648 r
.34405 .58744 .34488 .59282 .34659 .59229 .34576 .5869 Mtetra
.586 .439 .648 r
.34576 .5869 .34659 .59229 .34831 .59178 .34747 .5864 Mtetra
.585 .439 .648 r
.34747 .5864 .34831 .59178 .35002 .59128 .34918 .58591 Mtetra
.556 .418 .649 r
.34918 .58591 .35002 .59128 .35172 .59101 .35088 .58583 Mtetra
.549 .417 .653 r
.35088 .58583 .35172 .59101 .35342 .59082 .35256 .58586 Mtetra
.611 .463 .657 r
.35256 .58586 .35342 .59082 .35515 .5901 .3543 .58503 Mtetra
.762 .564 .63 r
.3543 .58503 .35515 .5901 .35698 .58741 .35622 .58044 Mtetra
.946 .682 .504 r
.35622 .58044 .35698 .58741 .35923 .57591 .36769 .38104 Mtetra
.551 .33 .532 r
.36769 .38104 .35923 .57591 .37047 .37814 .36956 .37536 Mtetra
.749 .602 .693 r
.36956 .37536 .37047 .37814 .37221 .37501 .37126 .37316 Mtetra
.668 .622 .794 r
.37126 .37316 .37221 .37501 .37384 .37424 .37289 .37243 Mtetra
.604 .598 .818 r
.37289 .37243 .37384 .37424 .37544 .374 .3745 .37212 Mtetra
.591 .583 .812 r
.3745 .37212 .37544 .374 .37705 .37367 .3761 .37187 Mtetra
.616 .604 .816 r
.3761 .37187 .37705 .37367 .37868 .37294 .37772 .3715 Mtetra
.618 .653 .862 r
.37772 .3715 .37868 .37294 .38032 .37221 .37933 .37113 Mtetra
.631 .721 .912 r
.37933 .37113 .38032 .37221 .38194 .37156 .38095 .3707 Mtetra
.652 .776 .939 r
.38095 .3707 .38194 .37156 .38357 .37102 .38258 .37018 Mtetra
.668 .785 .936 r
.38258 .37018 .38357 .37102 .38519 .37051 .3842 .3696 Mtetra
.686 .774 .918 r
.3842 .3696 .38519 .37051 .38682 .36999 .38584 .36894 Mtetra
.696 .748 .892 r
.38584 .36894 .38682 .36999 .38845 .36945 .38747 .36823 Mtetra
.692 .716 .867 r
.38747 .36823 .38845 .36945 .39007 .36889 .38911 .3675 Mtetra
.69 .689 .844 r
.38911 .3675 .39007 .36889 .39171 .3683 .39075 .36675 Mtetra
.683 .664 .825 r
.39075 .36675 .39171 .3683 .39334 .36768 .39239 .36601 Mtetra
.651 .636 .821 r
.39239 .36601 .39334 .36768 .39497 .36706 .39402 .36543 Mtetra
.592 .616 .844 r
.39402 .36543 .39497 .36706 .39662 .36628 .39564 .36518 Mtetra
.376 .607 .939 r
.39564 .36518 .39662 .36628 .39826 .36536 .39724 .36543 Mtetra
.614 .059 0 r
.39724 .36543 .39826 .36536 .3999 .3649 .39882 .36645 Mtetra
.812 .451 .374 r
.39882 .36645 .3999 .3649 .40147 .36589 .40028 .37027 Mtetra
.95 .677 .485 r
.40028 .37027 .40147 .36589 .40281 .37328 .39423 .56946 Mtetra
.548 .322 .525 r
.39423 .56946 .40281 .37328 .39689 .57314 .39576 .57461 Mtetra
.675 .265 .26 r
.39576 .57461 .39689 .57314 .39851 .57608 .39743 .57608 Mtetra
.231 .749 .83 r
.39743 .57608 .39851 .57608 .40024 .57588 .39917 .5758 Mtetra
.589 .932 .95 r
.39917 .5758 .40024 .57588 .402 .57504 .40092 .57505 Mtetra
.597 .943 .927 r
.40092 .57505 .402 .57504 .40377 .57418 .40269 .57422 Mtetra
.425 .868 .887 r
.40269 .57422 .40377 .57418 .40551 .57385 .40444 .57364 Mtetra
.544 .899 .973 r
.40444 .57364 .40551 .57385 .40725 .57352 .40619 .57307 Mtetra
.584 .866 .995 r
.40619 .57307 .40725 .57352 .409 .57313 .40795 .57256 Mtetra
.558 .832 .997 r
.40795 .57256 .409 .57313 .41076 .5726 .4097 .57216 Mtetra
.6 .875 .993 r
.4097 .57216 .41076 .5726 .41251 .57203 .41145 .57161 Mtetra
.713 .905 .963 r
.41145 .57161 .41251 .57203 .41427 .5716 .41322 .57072 Mtetra
.808 .812 .854 r
.41322 .57072 .41427 .5716 .41601 .57145 .41501 .56925 Mtetra
.784 .657 .722 r
.41501 .56925 .41601 .57145 .41777 .57082 .41683 .56693 Mtetra
.809 .611 .635 r
.41683 .56693 .41777 .57082 .41958 .56875 .41873 .56177 Mtetra
.952 .683 .489 r
.41873 .56177 .41958 .56875 .42159 .56006 .42667 .36103 Mtetra
.551 .329 .531 r
.42667 .36103 .42159 .56006 .42938 .35861 .42848 .35519 Mtetra
.74 .576 .671 r
.42848 .35519 .42938 .35861 .43114 .35462 .4302 .35269 Mtetra
.68 .623 .785 r
.4302 .35269 .43114 .35462 .4328 .35369 .43186 .35185 Mtetra
.622 .605 .813 r
.43186 .35185 .4328 .35369 .43445 .35333 .43351 .35143 Mtetra
.599 .587 .811 r
.43351 .35143 .43445 .35333 .4361 .35308 .43516 .35113 Mtetra
.639 .602 .796 r
.43516 .35113 .4361 .35308 .43776 .35233 .43682 .35059 Mtetra
.643 .627 .818 r
.43682 .35059 .43776 .35233 .43943 .35158 .43848 .35005 Mtetra
.655 .659 .842 r
.43848 .35005 .43943 .35158 .44109 .35087 .44014 .34947 Mtetra
.678 .686 .851 r
.44014 .34947 .44109 .35087 .44275 .35028 .4418 .34879 Mtetra
.654 .663 .847 r
.4418 .34879 .44275 .35028 .44442 .34972 .44347 .34822 Mtetra
.586 .632 .864 r
.44347 .34822 .44442 .34972 .44608 .34919 .44512 .34799 Mtetra
.246 .511 .907 r
.44512 .34799 .44608 .34919 .44774 .34865 .44676 .34856 Mtetra
.566 0 0 r
.44676 .34856 .44774 .34865 .44941 .34811 .44839 .34956 Mtetra
.637 .22 .236 r
.44839 .34956 .44941 .34811 .45107 .34756 .45002 .35066 Mtetra
.463 .125 .306 r
.45002 .35066 .45107 .34756 .45274 .34696 .45168 .35039 Mtetra
.405 .083 .302 r
.45168 .35039 .45274 .34696 .45441 .34636 .45335 .34963 Mtetra
.355 .032 .273 r
.45335 .34963 .45441 .34636 .45608 .34568 .45504 .34859 Mtetra
.289 0 .22 r
.45504 .34859 .45608 .34568 .45776 .34473 .45672 .34736 Mtetra
.392 .039 .243 r
.45672 .34736 .45776 .34473 .45943 .34415 .4584 .34677 Mtetra
.613 .254 .337 r
.4584 .34677 .45943 .34415 .46108 .34453 .46004 .34785 Mtetra
.957 .679 .466 r
.46004 .34785 .46108 .34453 .46265 .34946 .45776 .54571 Mtetra
.554 .327 .525 r
.45776 .54571 .46265 .34946 .46045 .55202 .45937 .55417 Mtetra
.716 .342 .34 r
.45937 .55417 .46045 .55202 .46214 .55648 .4611 .5565 Mtetra
.095 .652 .752 r
.4611 .5565 .46214 .55648 .46392 .55653 .46288 .55636 Mtetra
.566 .916 .963 r
.46288 .55636 .46392 .55653 .46571 .55582 .46468 .55569 Mtetra
.653 .949 .952 r
.46468 .55569 .46571 .55582 .46751 .55479 .46648 .5548 Mtetra
.416 .863 .888 r
.46648 .5548 .46751 .55479 .4693 .55423 .46827 .55424 Mtetra
.42 .865 .89 r
.46827 .55424 .4693 .55423 .4711 .55366 .47007 .55367 Mtetra
.416 .863 .887 r
.47007 .55367 .4711 .55366 .47289 .55309 .47186 .5531 Mtetra
.404 .856 .882 r
.47186 .5531 .47289 .55309 .47469 .55253 .47366 .55255 Mtetra
.4 .854 .881 r
.47366 .55255 .47469 .55253 .47649 .55199 .47546 .552 Mtetra
.396 .852 .881 r
.47546 .552 .47649 .55199 .47828 .55145 .47726 .55146 Mtetra
.388 .848 .88 r
.47726 .55146 .47828 .55145 .48008 .55093 .47906 .55093 Mtetra
.393 .85 .884 r
.47906 .55093 .48008 .55093 .48188 .55041 .48086 .55041 Mtetra
.383 .844 .884 r
.48086 .55041 .48188 .55041 .48368 .54992 .48266 .5499 Mtetra
.157 .697 .8 r
.48266 .5499 .48368 .54992 .48548 .54988 .48446 .54971 Mtetra
.462 .872 .952 r
.48446 .54971 .48548 .54988 .48728 .5494 .48627 .54922 Mtetra
.742 .961 .94 r
.48627 .54922 .48728 .5494 .4891 .548 .48808 .54809 Mtetra
.973 .885 .683 r
.48808 .54809 .4891 .548 .49097 .54102 .48992 .5441 Mtetra
.994 .805 .436 r
.48992 .5441 .49097 .54102 .49472 .33711 .49186 .53031 Mtetra
0 0 .314 r
.49186 .53031 .49472 .33711 .49645 .33202 .49548 .33507 Mtetra
.309 0 .241 r
.49548 .33507 .49645 .33202 .49815 .33089 .49718 .33384 Mtetra
.453 .11 .292 r
.49718 .33384 .49815 .33089 .49985 .33042 .49888 .33354 Mtetra
.472 .133 .309 r
.49888 .33354 .49985 .33042 .50154 .3303 .50057 .33333 Mtetra
.027 0 .122 r
.50057 .33333 .50154 .3303 .50324 .32973 .50229 .33085 Mtetra
.571 .831 .471 r
.50229 .33085 .50324 .32973 .50494 .32917 .504 .32877 Mtetra
.858 .91 .867 r
.504 .32877 .50494 .32917 .50664 .3286 .50571 .32715 Mtetra
.669 .679 .85 r
.50571 .32715 .50664 .3286 .50834 .32802 .50741 .3265 Mtetra
.623 .649 .855 r
.50741 .3265 .50834 .32802 .51005 .32743 .50911 .32608 Mtetra
.599 .666 .886 r
.50911 .32608 .51005 .32743 .51175 .32683 .51082 .32577 Mtetra
.655 .743 .915 r
.51082 .32577 .51175 .32683 .51346 .32618 .51252 .32522 Mtetra
.667 .77 .927 r
.51252 .32522 .51346 .32618 .51516 .32554 .51423 .32461 Mtetra
.678 .78 .927 r
.51423 .32461 .51516 .32554 .51687 .32495 .51594 .32396 Mtetra
.757 .786 .877 r
.51594 .32396 .51687 .32495 .51858 .32411 .51765 .32289 Mtetra
.707 .732 .87 r
.51765 .32289 .51858 .32411 .52029 .3236 .51936 .32207 Mtetra
.602 .64 .86 r
.51936 .32207 .52029 .3236 .522 .32379 .52107 .32175 Mtetra
0 .092 .647 r
.52107 .32175 .522 .32379 .52371 .3285 .52278 .32393 Mtetra
.764 .504 0 r
.52278 .32393 .52371 .3285 .52546 .532 .52449 .33327 Mtetra
0 0 .344 r
.52449 .33327 .52546 .532 .52729 .53687 .5263 .53109 Mtetra
.51 .383 .643 r
.5263 .53109 .52729 .53687 .52912 .53716 .52813 .53166 Mtetra
.601 .449 .648 r
.52813 .53166 .52912 .53716 .53096 .53654 .52996 .53088 Mtetra
.609 .453 .645 r
.52996 .53088 .53096 .53654 .53279 .53552 .53179 .52992 Mtetra
.445 .342 .643 r
.53179 .52992 .53279 .53552 .53463 .53498 .53363 .53124 Mtetra
.404 .365 .701 r
.53363 .53124 .53463 .53498 .53646 .53447 .53547 .53241 Mtetra
.379 .467 .824 r
.53547 .53241 .53646 .53447 .5383 .53391 .53732 .5331 Mtetra
.375 .695 .982 r
.53732 .5331 .5383 .53391 .54014 .5336 .53916 .53318 Mtetra
.519 .858 .994 r
.53916 .53318 .54014 .5336 .54198 .53297 .541 .53275 Mtetra
.724 .957 .946 r
.541 .53275 .54198 .53297 .54382 .5316 .54284 .53167 Mtetra
.958 .928 .726 r
.54284 .53167 .54382 .5316 .54563 .52601 .54467 .52849 Mtetra
.937 .839 .396 r
.54467 .52849 .54563 .52601 .5461 .32102 .54647 .52063 Mtetra
0 0 .338 r
.54647 .52063 .5461 .32102 .54778 .3148 .5469 .31842 Mtetra
0 0 .09 r
.5469 .31842 .54778 .3148 .54951 .31322 .5486 .31447 Mtetra
0 0 0 r
.5486 .31447 .54951 .31322 .55123 .31262 .55032 .31243 Mtetra
.804 .968 .908 r
.55032 .31243 .55123 .31262 .55297 .31239 .55205 .3111 Mtetra
.69 .716 .869 r
.55205 .3111 .55297 .31239 .5547 .31182 .55378 .31035 Mtetra
.634 .665 .863 r
.55378 .31035 .5547 .31182 .55643 .31118 .55551 .30987 Mtetra
.611 .682 .892 r
.55551 .30987 .55643 .31118 .55816 .3106 .55725 .30951 Mtetra
.731 .765 .88 r
.55725 .30951 .55816 .3106 .55989 .30977 .55898 .30856 Mtetra
.713 .738 .87 r
.55898 .30856 .55989 .30977 .56163 .30919 .56071 .30769 Mtetra
.622 .655 .861 r
.56071 .30769 .56163 .30919 .56337 .30923 .56245 .30727 Mtetra
.102 .288 .767 r
.56245 .30727 .56337 .30923 .56516 .3127 .56421 .30876 Mtetra
0 0 .393 r
.56421 .30876 .56516 .3127 .56964 .51642 .56603 .31424 Mtetra
0 0 .361 r
.56603 .31424 .56964 .51642 .57159 .52272 .57055 .51619 Mtetra
.273 .208 .6 r
.57055 .51619 .57159 .52272 .57347 .52351 .57246 .51968 Mtetra
.417 .371 .699 r
.57246 .51968 .57347 .52351 .57534 .52303 .57435 .52081 Mtetra
.479 .509 .811 r
.57435 .52081 .57534 .52303 .5772 .52206 .57623 .52114 Mtetra
.414 .691 .977 r
.57623 .52114 .5772 .52206 .57906 .52162 .57811 .52121 Mtetra
.48 .843 .992 r
.57811 .52121 .57906 .52162 .58093 .52106 .57998 .52083 Mtetra
.692 .952 .954 r
.57998 .52083 .58093 .52106 .58279 .51982 .58184 .51983 Mtetra
.945 .944 .751 r
.58184 .51983 .58279 .51982 .58458 .51512 .58367 .51699 Mtetra
.94 .858 .429 r
.58367 .51699 .58458 .51512 .58268 .31024 .58543 .51034 Mtetra
0 0 .353 r
.58543 .51034 .58268 .31024 .58431 .30271 .5835 .30706 Mtetra
0 0 .158 r
.5835 .30706 .58431 .30271 .58603 .3008 .58518 .30248 Mtetra
0 0 0 r
.58518 .30248 .58603 .3008 .58778 .30014 .58691 .30041 Mtetra
.667 .97 .797 r
.58691 .30041 .58778 .30014 .58954 .29992 .58865 .29908 Mtetra
.725 .82 .924 r
.58865 .29908 .58954 .29992 .5913 .29943 .59039 .29821 Mtetra
.665 .722 .891 r
.59039 .29821 .5913 .29943 .59305 .2988 .59215 .29759 Mtetra
.642 .715 .9 r
.59215 .29759 .59305 .2988 .59481 .29821 .59391 .29708 Mtetra
.748 .766 .867 r
.59391 .29708 .59481 .29821 .59656 .29736 .59566 .296 Mtetra
.729 .722 .844 r
.59566 .296 .59656 .29736 .59832 .29667 .5974 .29498 Mtetra
.617 .629 .84 r
.5974 .29498 .59832 .29667 .60009 .29657 .59917 .29457 Mtetra
0 .051 .618 r
.59917 .29457 .60009 .29657 .60193 .29942 .601 .29704 Mtetra
.974 .682 .404 r
.601 .29704 .60193 .29942 .60885 .50303 .60787 .50068 Mtetra
.906 .556 .088 r
.60787 .50068 .60885 .50303 .61094 .51041 .61 .50969 Mtetra
0 .154 .605 r
.61 .50969 .61094 .51041 .61288 .51186 .61194 .51106 Mtetra
.581 .798 .982 r
.61194 .51106 .61288 .51186 .61478 .51166 .61383 .51065 Mtetra
.785 .811 .873 r
.61383 .51065 .61478 .51166 .61665 .51041 .6157 .5093 Mtetra
.891 .797 .749 r
.6157 .5093 .61665 .51041 .61845 .50649 .61753 .50645 Mtetra
.991 .829 .585 r
.61753 .50645 .61845 .50649 .61456 .30419 .61926 .50014 Mtetra
0 0 .36 r
.61926 .50014 .61456 .30419 .61601 .29225 .61528 .29686 Mtetra
0 0 .171 r
.61528 .29686 .61601 .29225 .61772 .28989 .61692 .2918 Mtetra
0 0 0 r
.61692 .2918 .61772 .28989 .61949 .28919 .61865 .28966 Mtetra
.562 .905 .68 r
.61865 .28966 .61949 .28919 .62128 .28899 .6204 .28828 Mtetra
.732 .856 .939 r
.6204 .28828 .62128 .28899 .62306 .28861 .62217 .28736 Mtetra
.666 .719 .889 r
.62217 .28736 .62306 .28861 .62484 .28802 .62394 .28673 Mtetra
.636 .7 .892 r
.62394 .28673 .62484 .28802 .62661 .28742 .62572 .28624 Mtetra
.72 .751 .877 r
.62572 .28624 .62661 .28742 .62838 .28644 .62749 .28532 Mtetra
.731 .768 .882 r
.62749 .28532 .62838 .28644 .63014 .28545 .62926 .28436 Mtetra
.606 .727 .931 r
.62926 .28436 .63014 .28545 .63193 .28503 .63105 .28398 Mtetra
0 0 .472 r
.63105 .28398 .63193 .28503 .6338 .28701 .63293 .28617 Mtetra
.974 .678 .393 r
.63293 .28617 .6338 .28701 .64273 .4871 .64191 .48919 Mtetra
.893 .54 .37 r
.64191 .48919 .64273 .4871 .6451 .49938 .64418 .49886 Mtetra
.469 0 0 r
.64418 .49886 .6451 .49938 .64709 .50101 .64616 .50027 Mtetra
.621 .829 .98 r
.64616 .50027 .64709 .50101 .64901 .50062 .64808 .4997 Mtetra
.751 .827 .911 r
.64808 .4997 .64901 .50062 .65091 .49965 .64997 .49861 Mtetra
.621 .761 .946 r
.64997 .49861 .65091 .49965 .65282 .499 .65189 .49812 Mtetra
.467 .728 .983 r
.65189 .49812 .65282 .499 .65474 .49857 .65383 .49804 Mtetra
.623 .879 .989 r
.65383 .49804 .65474 .49857 .65665 .49755 .65575 .49738 Mtetra
.951 .927 .743 r
.65575 .49738 .65665 .49755 .65845 .4941 .65757 .49438 Mtetra
.994 .761 .469 r
.65757 .49438 .65845 .4941 .65222 .29394 .65895 .48036 Mtetra
0 0 .362 r
.65895 .48036 .65222 .29394 .65346 .27981 .65259 .27889 Mtetra
.916 .815 .732 r
.65259 .27889 .65346 .27981 .65516 .27709 .65429 .2759 Mtetra
.704 .746 .884 r
.65429 .2759 .65516 .27709 .65695 .27627 .65608 .27507 Mtetra
.585 .696 .919 r
.65608 .27507 .65695 .27627 .65876 .27594 .65789 .27477 Mtetra
.67 .74 .902 r
.65789 .27477 .65876 .27594 .66055 .27525 .65968 .27412 Mtetra
.735 .769 .88 r
.65968 .27412 .66055 .27525 .66234 .27423 .66147 .27312 Mtetra
.625 .733 .924 r
.66147 .27312 .66234 .27423 .66414 .27374 .66327 .27266 Mtetra
0 .156 .676 r
.66327 .27266 .66414 .27374 .66604 .27522 .66518 .27429 Mtetra
.975 .675 .378 r
.66518 .27429 .66604 .27522 .66851 .28908 .67598 .46978 Mtetra
.57 .338 .525 r
.67598 .46978 .66851 .28908 .67965 .488 .67876 .48751 Mtetra
.603 .053 0 r
.67876 .48751 .67965 .488 .68171 .49014 .68081 .4894 Mtetra
.612 .828 .983 r
.68081 .4894 .68171 .49014 .68366 .48979 .68275 .48885 Mtetra
.763 .83 .904 r
.68275 .48885 .68366 .48979 .68558 .48875 .68466 .48767 Mtetra
.705 .786 .914 r
.68466 .48767 .68558 .48875 .6875 .48783 .68659 .4868 Mtetra
.566 .744 .96 r
.68659 .4868 .6875 .48783 .68944 .48721 .68854 .48649 Mtetra
.666 .855 .972 r
.68854 .48649 .68944 .48721 .69135 .48597 .69048 .48576 Mtetra
.935 .944 .773 r
.69048 .48576 .69135 .48597 .6931 .48162 .69232 .4831 Mtetra
.985 .81 .414 r
.69232 .4831 .6931 .48162 .68437 .27379 .69378 .47317 Mtetra
0 0 .393 r
.69378 .47317 .68437 .27379 .68588 .26736 .68524 .27042 Mtetra
.291 0 .248 r
.68524 .27042 .68588 .26736 .68769 .26648 .68702 .26895 Mtetra
.973 .67 .377 r
.68702 .26895 .68769 .26648 .68981 .27159 .69898 .45968 Mtetra
.571 .339 .525 r
.69898 .45968 .68981 .27159 .70284 .47894 .70199 .47897 Mtetra
.767 .257 0 r
.70199 .47897 .70284 .47894 .70503 .48279 .70411 .48155 Mtetra
.433 .631 .938 r
.70411 .48155 .70503 .48279 .70703 .48304 .70611 .48173 Mtetra
.693 .74 .887 r
.70611 .48173 .70703 .48304 .70897 .48213 .70805 .48089 Mtetra
.89 .792 .747 r
.70805 .48089 .70897 .48213 .71079 .47919 .70988 .47802 Mtetra
.979 .733 .494 r
.70988 .47802 .71079 .47919 .71203 .46605 .7111 .46447 Mtetra
.977 .681 .38 r
.7111 .46447 .71203 .46605 .70236 .26348 .70151 .26228 Mtetra
.913 .785 .705 r
.70151 .26228 .70236 .26348 .70403 .26011 .70318 .25893 Mtetra
.713 .757 .887 r
.70318 .25893 .70403 .26011 .70584 .25922 .70499 .25805 Mtetra
.591 .709 .925 r
.70499 .25805 .70584 .25922 .70769 .25889 .70684 .25772 Mtetra
.626 .725 .918 r
.70684 .25772 .70769 .25889 .70953 .25841 .70868 .25725 Mtetra
.735 .767 .879 r
.70868 .25725 .70953 .25841 .71133 .2574 .71049 .25624 Mtetra
.644 .734 .915 r
.71049 .25624 .71133 .2574 .71317 .25686 .71232 .2557 Mtetra
.072 .406 .859 r
.71232 .2557 .71317 .25686 .7151 .25786 .71426 .25671 Mtetra
.921 .546 .13 r
.71426 .25671 .7151 .25786 .71753 .26672 .71669 .2657 Mtetra
.975 .671 .352 r
.71669 .2657 .71753 .26672 .73229 .47127 .7314 .4702 Mtetra
.622 .155 0 r
.7314 .4702 .73229 .47127 .73449 .47426 .7336 .4732 Mtetra
.41 .659 .961 r
.7336 .4732 .73449 .47426 .73651 .47438 .73562 .47335 Mtetra
.72 .805 .918 r
.73562 .47335 .73651 .47438 .73846 .47343 .73757 .47239 Mtetra
.904 .826 .76 r
.73757 .47239 .73846 .47343 .74031 .47082 .73941 .4696 Mtetra
.979 .74 .505 r
.73941 .4696 .74031 .47082 .74175 .46219 .74066 .45799 Mtetra
.976 .676 .372 r
.74066 .45799 .74175 .46219 .72999 .25541 .72905 .25282 Mtetra
.835 .661 .667 r
.72905 .25282 .72999 .25541 .73159 .25125 .7307 .2492 Mtetra
.665 .619 .793 r
.7307 .2492 .73159 .25125 .73341 .25013 .73253 .2484 Mtetra
.569 .606 .851 r
.73253 .2484 .73341 .25013 .73526 .24962 .73441 .24823 Mtetra
.526 .636 .902 r
.73441 .24823 .73526 .24962 .73713 .24929 .7363 .24818 Mtetra
.645 .748 .924 r
.7363 .24818 .73713 .24929 .73898 .24869 .73815 .24763 Mtetra
.656 .761 .928 r
.73815 .24763 .73898 .24869 .74083 .24812 .74 .24702 Mtetra
.697 .771 .909 r
.74 .24702 .74083 .24812 .74268 .24737 .74184 .24623 Mtetra
.752 .78 .876 r
.74184 .24623 .74268 .24737 .74449 .24626 .74366 .24511 Mtetra
.668 .749 .911 r
.74366 .24511 .74449 .24626 .74635 .24561 .74551 .24445 Mtetra
.232 .513 .91 r
.74551 .24445 .74635 .24561 .7483 .24629 .74746 .24512 Mtetra
.893 .505 .059 r
.74746 .24512 .7483 .24629 .75076 .254 .74993 .25288 Mtetra
.975 .667 .334 r
.74993 .25288 .75076 .254 .76793 .46002 .76705 .45891 Mtetra
.644 .188 0 r
.76705 .45891 .76793 .46002 .77022 .4634 .76934 .46228 Mtetra
.388 .635 .953 r
.76934 .46228 .77022 .4634 .77228 .46364 .7714 .46252 Mtetra
.694 .781 .918 r
.7714 .46252 .77228 .46364 .77426 .46281 .77339 .46168 Mtetra
.873 .82 .793 r
.77339 .46168 .77426 .46281 .77613 .46048 .77526 .45935 Mtetra
.978 .767 .552 r
.77526 .45935 .77613 .46048 .77758 .45263 .7767 .4515 Mtetra
.977 .675 .347 r
.7767 .4515 .77758 .45263 .7634 .24406 .76257 .24287 Mtetra
.95 .784 .641 r
.76257 .24287 .7634 .24406 .76496 .23943 .76413 .23824 Mtetra
.747 .772 .873 r
.76413 .23824 .76496 .23943 .76679 .23833 .76596 .23714 Mtetra
.62 .722 .919 r
.76596 .23714 .76679 .23833 .76867 .23788 .76784 .23669 Mtetra
.589 .708 .926 r
.76784 .23669 .76867 .23788 .77056 .23755 .76974 .23636 Mtetra
.748 .772 .872 r
.76974 .23636 .77056 .23755 .77239 .23644 .77157 .23524 Mtetra
.674 .744 .904 r
.77157 .23524 .77239 .23644 .77426 .23575 .77344 .23455 Mtetra
.371 .59 .929 r
.77344 .23455 .77426 .23575 .77622 .23612 .77539 .23491 Mtetra
.815 .405 0 r
.77539 .23491 .77622 .23612 .77862 .24184 .77779 .24058 Mtetra
.973 .663 .318 r
.77779 .24058 .77862 .24184 .79789 .44966 .79702 .44847 Mtetra
.691 .253 0 r
.79702 .44847 .79789 .44966 .8003 .45373 .79943 .45255 Mtetra
.506 .688 .949 r
.79943 .45255 .8003 .45373 .80236 .4537 .80149 .45247 Mtetra
.685 .761 .909 r
.80149 .45247 .80236 .4537 .80437 .4529 .8035 .45167 Mtetra
.715 .77 .896 r
.8035 .45167 .80437 .4529 .80635 .45183 .80549 .4507 Mtetra
.442 .664 .956 r
.80549 .4507 .80635 .45183 .8084 .45155 .80758 .4508 Mtetra
.537 .805 .995 r
.80758 .4508 .8084 .45155 .81042 .45081 .80963 .45043 Mtetra
.787 .966 .919 r
.80963 .45043 .81042 .45081 .81234 .44902 .81158 .44901 Mtetra
.999 .843 .526 r
.81158 .44901 .81234 .44902 .81375 .44143 .8131 .44259 Mtetra
.976 .672 .322 r
.8131 .44259 .81375 .44143 .79725 .23295 .7965 .2325 Mtetra
.995 .827 .564 r
.7965 .2325 .79725 .23295 .79875 .228 .79794 .22676 Mtetra
.76 .769 .861 r
.79794 .22676 .79875 .228 .80059 .22684 .79977 .22554 Mtetra
.629 .709 .904 r
.79977 .22554 .80059 .22684 .80249 .22633 .80168 .22505 Mtetra
.559 .678 .919 r
.80168 .22505 .80249 .22633 .80442 .22608 .80361 .22484 Mtetra
.75 .769 .868 r
.80361 .22484 .80442 .22608 .80627 .22493 .80546 .2237 Mtetra
.681 .745 .899 r
.80546 .2237 .80627 .22493 .80815 .22418 .80734 .22296 Mtetra
.461 .639 .933 r
.80734 .22296 .80815 .22418 .81012 .22428 .80931 .22307 Mtetra
.771 .356 0 r
.80931 .22307 .81012 .22428 .81257 .22954 .81176 .22832 Mtetra
.971 .657 .298 r
.81176 .22832 .81257 .22954 .83433 .43814 .83348 .43698 Mtetra
.722 .287 0 r
.83348 .43698 .83433 .43814 .83686 .44273 .83602 .44157 Mtetra
.309 .582 .938 r
.83602 .44157 .83686 .44273 .83901 .44321 .83817 .44205 Mtetra
.651 .764 .932 r
.83817 .44205 .83901 .44321 .84106 .44256 .84022 .44141 Mtetra
.831 .821 .839 r
.84022 .44141 .84106 .44256 .84299 .44075 .84215 .4396 Mtetra
.976 .788 .587 r
.84215 .4396 .84299 .44075 .8445 .43458 .84366 .43344 Mtetra
.974 .667 .312 r
.84366 .43344 .8445 .43458 .82585 .22448 .82506 .22328 Mtetra
.975 .776 .574 r
.82506 .22328 .82585 .22448 .82721 .21828 .82642 .21707 Mtetra
.765 .76 .849 r
.21297 .4273 .21402 .42826 .2156 .42715 .21455 .4262 Mtetra
.626 .736 .926 r
.21455 .4262 .2156 .42715 .21711 .42676 .21607 .42581 Mtetra
.483 .687 .957 r
.21607 .42581 .21711 .42676 .21859 .42673 .21755 .42579 Mtetra
.706 .757 .892 r
.21755 .42579 .21859 .42673 .22015 .42587 .21909 .42507 Mtetra
.684 .785 .927 r
.21909 .42507 .22015 .42587 .22169 .42524 .22063 .42447 Mtetra
.603 .771 .96 r
.22063 .42447 .22169 .42524 .22319 .42511 .22215 .42412 Mtetra
.257 .565 .936 r
.22215 .42412 .22319 .42511 .22446 .42733 .22359 .42449 Mtetra
.292 .317 .716 r
.22359 .42449 .22446 .42733 .22499 .43772 .22497 .42567 Mtetra
.408 .249 .552 r
.22497 .42567 .22499 .43772 .20903 .62848 .22617 .4288 Mtetra
0 0 .178 r
.22617 .4288 .20903 .62848 .21041 .63061 .20996 .62239 Mtetra
0 0 .445 r
.20996 .62239 .21041 .63061 .21193 .63137 .21099 .6284 Mtetra
.001 .124 .64 r
.21099 .6284 .21193 .63137 .2135 .63149 .21239 .63048 Mtetra
.181 .532 .923 r
.21239 .63048 .2135 .63149 .21507 .63164 .21393 .63096 Mtetra
.606 .806 .977 r
.21393 .63096 .21507 .63164 .2167 .63122 .21556 .63054 Mtetra
.813 .824 .859 r
.21556 .63054 .2167 .63122 .2184 .62991 .21727 .62912 Mtetra
.918 .743 .65 r
.21727 .62912 .2184 .62991 .22054 .6237 .2194 .62309 Mtetra
.939 .687 .529 r
.2194 .62309 .22054 .6237 .23973 .42337 .23867 .42263 Mtetra
.917 .745 .654 r
.23867 .42263 .23973 .42337 .24169 .41807 .24064 .41718 Mtetra
.791 .776 .839 r
.24064 .41718 .24169 .41807 .24329 .41678 .24225 .41588 Mtetra
.639 .753 .931 r
.24225 .41588 .24329 .41678 .24483 .41633 .24379 .41543 Mtetra
.496 .707 .964 r
.24379 .41543 .24483 .41633 .24634 .41624 .24529 .41537 Mtetra
.627 .757 .94 r
.24529 .41537 .24634 .41624 .24787 .41582 .24683 .41496 Mtetra
.645 .764 .935 r
.24683 .41496 .24787 .41582 .24941 .41534 .24837 .41449 Mtetra
.647 .767 .936 r
.24837 .41449 .24941 .41534 .25095 .41486 .24991 .41401 Mtetra
.656 .771 .933 r
.24991 .41401 .25095 .41486 .2525 .41434 .25146 .4135 Mtetra
.661 .773 .932 r
.25146 .4135 .2525 .41434 .25405 .41381 .253 .41298 Mtetra
.664 .774 .931 r
.253 .41298 .25405 .41381 .2556 .41328 .25456 .41244 Mtetra
.706 .781 .91 r
.25456 .41244 .2556 .41328 .25717 .41246 .25612 .41172 Mtetra
.686 .802 .937 r
.25612 .41172 .25717 .41246 .25873 .41181 .25768 .4111 Mtetra
.603 .79 .97 r
.25768 .4111 .25873 .41181 .26026 .4116 .25922 .41073 Mtetra
0 .413 .845 r
.25922 .41073 .26026 .4116 .26161 .41348 .26068 .41139 Mtetra
0 .17 .696 r
.26068 .41139 .26161 .41348 .26254 .42072 .26206 .41297 Mtetra
.342 .225 .572 r
.26206 .41297 .26254 .42072 .24837 .61576 .26335 .41577 Mtetra
.536 .317 .529 r
.26335 .41577 .24837 .61576 .24986 .61722 .26476 .41702 Mtetra
.541 .321 .53 r
.26476 .41702 .24986 .61722 .25152 .6167 .26634 .41629 Mtetra
.542 .322 .53 r
.26634 .41629 .25152 .6167 .25323 .61546 .26798 .4148 Mtetra
.543 .322 .53 r
.26798 .4148 .25323 .61546 .25492 .61441 .26963 .41309 Mtetra
.541 .321 .53 r
.26963 .41309 .25492 .61441 .2566 .61366 .27123 .41208 Mtetra
.538 .319 .529 r
.27123 .41208 .2566 .61366 .25823 .61345 .27273 .41245 Mtetra
0 0 .223 r
.27273 .41245 .25823 .61345 .25975 .61471 .25943 .60372 Mtetra
0 0 .377 r
.25943 .60372 .25975 .61471 .26127 .61596 .26034 .61294 Mtetra
0 0 .543 r
.26034 .61294 .26127 .61596 .26284 .61674 .26175 .61568 Mtetra
.289 .583 .942 r
.26175 .61568 .26284 .61674 .26447 .61665 .26334 .61604 Mtetra
.615 .829 .982 r
.26334 .61604 .26447 .61665 .26613 .61616 .265 .61557 Mtetra
.71 .85 .949 r
.265 .61557 .26613 .61616 .2678 .61552 .26669 .61478 Mtetra
.623 .8 .967 r
.26669 .61478 .2678 .61552 .26945 .61526 .26835 .61432 Mtetra
.628 .756 .939 r
.26835 .61432 .26945 .61526 .2711 .61492 .27001 .61387 Mtetra
.691 .751 .897 r
.27001 .61387 .2711 .61492 .27279 .61411 .2717 .61316 Mtetra
.82 .781 .815 r
.2717 .61316 .27279 .61411 .27463 .61124 .27345 .61145 Mtetra
.937 .921 .771 r
.27345 .61145 .27463 .61124 .27681 .6037 .27528 .60874 Mtetra
0 0 .147 r
.27528 .60874 .27681 .6037 .29264 .40626 .2772 .60485 Mtetra
.535 .311 .522 r
.2772 .60485 .29264 .40626 .29437 .4035 .27895 .60309 Mtetra
.538 .314 .523 r
.27895 .60309 .29437 .4035 .29595 .40299 .28059 .60311 Mtetra
.537 .313 .523 r
.28059 .60311 .29595 .40299 .29749 .40285 .28227 .60237 Mtetra
0 0 .241 r
.28227 .60237 .29749 .40285 .29915 .40125 .29708 .41519 Mtetra
0 0 .119 r
.29708 .41519 .29915 .40125 .30083 .39925 .29964 .40073 Mtetra
.932 .942 .596 r
.29964 .40073 .30083 .39925 .30248 .39759 .30144 .39699 Mtetra
.851 .833 .828 r
.30144 .39699 .30248 .39759 .30411 .3963 .3031 .39527 Mtetra
.723 .752 .875 r
.3031 .39527 .30411 .3963 .30571 .39543 .3047 .39443 Mtetra
.613 .728 .928 r
.3047 .39443 .30571 .39543 .30728 .39508 .30627 .39407 Mtetra
.381 .629 .951 r
.30627 .39407 .30728 .39508 .30875 .39622 .3078 .39427 Mtetra
.252 .381 .8 r
.3078 .39427 .30875 .39622 .31001 .40039 .30928 .39519 Mtetra
.29 .225 .61 r
.30928 .39519 .31001 .40039 .2985 .59781 .31068 .39748 Mtetra
0 0 .266 r
.31068 .39748 .2985 .59781 .29984 .60244 .30009 .58132 Mtetra
0 0 .341 r
.30009 .58132 .29984 .60244 .30141 .60368 .30053 .59955 Mtetra
.034 .086 .586 r
.30053 .59955 .30141 .60368 .30304 .60408 .30199 .60249 Mtetra
.194 .419 .851 r
.30199 .60249 .30304 .60408 .30468 .60429 .30359 .60333 Mtetra
.521 .718 .962 r
.30359 .60333 .30468 .60429 .30634 .60418 .30526 .60319 Mtetra
.689 .766 .91 r
.30526 .60319 .30634 .60418 .30804 .60348 .30696 .60249 Mtetra
.784 .78 .849 r
.30696 .60249 .30804 .60348 .30984 .60117 .3087 .60117 Mtetra
.903 .933 .824 r
.3087 .60117 .30984 .60117 .31185 .59562 .3105 .59905 Mtetra
0 0 0 r
.3105 .59905 .31185 .59562 .32579 .39703 .31238 .59548 Mtetra
.506 .287 .516 r
.31238 .59548 .32579 .39703 .32769 .39147 .31501 .57969 Mtetra
0 0 .221 r
.31501 .57969 .32769 .39147 .32938 .38937 .32819 .39135 Mtetra
.815 .89 .468 r
.32819 .39135 .32938 .38937 .33102 .38805 .32998 .38763 Mtetra
.851 .876 .858 r
.32998 .38763 .33102 .38805 .33264 .38721 .33164 .38605 Mtetra
.671 .716 .882 r
.33164 .38605 .33264 .38721 .33423 .38666 .33324 .38546 Mtetra
.592 .68 .902 r
.33324 .38546 .33423 .38666 .33582 .38626 .33482 .38519 Mtetra
.648 .725 .905 r
.33482 .38519 .33582 .38626 .33743 .38558 .33642 .3847 Mtetra
.693 .778 .916 r
.33642 .3847 .33743 .38558 .33904 .38479 .33803 .38402 Mtetra
.634 .79 .957 r
.33803 .38402 .33904 .38479 .34063 .3844 .33962 .38356 Mtetra
.262 .608 .955 r
.33962 .38356 .34063 .3844 .34213 .38558 .34117 .38386 Mtetra
0 .241 .752 r
.34117 .38386 .34213 .38558 .3434 .39102 .34267 .3852 Mtetra
.312 .231 .602 r
.34267 .3852 .3434 .39102 .33394 .58819 .34411 .38764 Mtetra
.534 .315 .529 r
.34411 .38764 .33394 .58819 .33545 .59107 .34556 .38986 Mtetra
.54 .32 .53 r
.34556 .38986 .33545 .59107 .33715 .59075 .34716 .38941 Mtetra
.542 .322 .53 r
.34716 .38941 .33715 .59075 .33889 .58965 .34883 .38788 Mtetra
.542 .321 .53 r
.34883 .38788 .33889 .58965 .34062 .58863 .35048 .38669 Mtetra
.541 .32 .53 r
.35048 .38669 .34062 .58863 .34233 .58803 .3521 .386 Mtetra
.54 .32 .53 r
.3521 .386 .34233 .58803 .34405 .58744 .35371 .38534 Mtetra
.35371 .38534 .34405 .58744 .34576 .5869 .35533 .38475 Mtetra
.35533 .38475 .34576 .5869 .34747 .5864 .35694 .38422 Mtetra
.35694 .38422 .34747 .5864 .34918 .58591 .35856 .38371 Mtetra
.539 .319 .529 r
.35856 .38371 .34918 .58591 .35088 .58583 .36015 .38367 Mtetra
.36015 .38367 .35088 .58583 .35256 .58586 .36173 .38391 Mtetra
.541 .321 .53 r
.36173 .38391 .35256 .58586 .3543 .58503 .36336 .38304 Mtetra
.546 .325 .531 r
.36336 .38304 .3543 .58503 .35622 .58044 .36512 .37969 Mtetra
.36512 .37969 .35622 .58044 .36769 .38104 .36689 .37615 Mtetra
.696 .518 .642 r
.36689 .37615 .36769 .38104 .36956 .37536 .3686 .37372 Mtetra
.755 .678 .776 r
.3686 .37372 .36956 .37536 .37126 .37316 .37026 .3723 Mtetra
.684 .784 .926 r
.37026 .3723 .37126 .37316 .37289 .37243 .37189 .37166 Mtetra
.609 .783 .965 r
.37189 .37166 .37289 .37243 .3745 .37212 .3735 .37126 Mtetra
.593 .758 .957 r
.3735 .37126 .3745 .37212 .3761 .37187 .37511 .37093 Mtetra
.613 .744 .939 r
.37511 .37093 .3761 .37187 .37772 .3715 .37673 .37055 Mtetra
.37673 .37055 .37772 .3715 .37933 .37113 .37834 .37017 Mtetra
.633 .749 .932 r
.37834 .37017 .37933 .37113 .38095 .3707 .37996 .36973 Mtetra
.661 .753 .919 r
.37996 .36973 .38095 .3707 .38258 .37018 .38159 .36917 Mtetra
.677 .752 .908 r
.38159 .36917 .38258 .37018 .3842 .3696 .38322 .36856 Mtetra
.694 .749 .894 r
.38322 .36856 .3842 .3696 .38584 .36894 .38486 .36785 Mtetra
.707 .742 .879 r
.38486 .36785 .38584 .36894 .38747 .36823 .38649 .36707 Mtetra
.704 .73 .871 r
.38649 .36707 .38747 .36823 .38911 .3675 .38813 .36629 Mtetra
.712 .723 .859 r
.38813 .36629 .38911 .3675 .39075 .36675 .38978 .36545 Mtetra
.71 .708 .847 r
.38978 .36545 .39075 .36675 .39239 .36601 .39142 .3646 Mtetra
.65 .671 .857 r
.39142 .3646 .39239 .36601 .39402 .36543 .39305 .36407 Mtetra
.393 .56 .9 r
.39305 .36407 .39402 .36543 .39564 .36518 .39465 .36441 Mtetra
.776 .282 0 r
.39465 .36441 .39564 .36518 .39724 .36543 .39617 .36665 Mtetra
.9 .575 .424 r
.39617 .36665 .39724 .36543 .39882 .36645 .39743 .37558 Mtetra
.943 .67 .491 r
.39743 .37558 .39882 .36645 .40028 .37027 .39138 .57048 Mtetra
.544 .319 .524 r
.39138 .57048 .40028 .37027 .39423 .56946 .39299 .57345 Mtetra
.607 .281 .392 r
.39299 .57345 .39423 .56946 .39576 .57461 .39467 .57468 Mtetra
.262 0 0 r
.39467 .57468 .39576 .57461 .39743 .57608 .39639 .57498 Mtetra
.613 .728 .927 r
.39639 .57498 .39743 .57608 .39917 .5758 .39813 .57458 Mtetra
.674 .726 .889 r
.39813 .57458 .39917 .5758 .40092 .57505 .39988 .57392 Mtetra
.681 .744 .899 r
.39988 .57392 .40092 .57505 .40269 .57422 .40164 .57323 Mtetra
.642 .762 .936 r
.40164 .57323 .40269 .57422 .40444 .57364 .40339 .57271 Mtetra
.64 .773 .944 r
.40339 .57271 .40444 .57364 .40619 .57307 .40515 .57219 Mtetra
.605 .775 .962 r
.40515 .57219 .40619 .57307 .40795 .57256 .4069 .57178 Mtetra
.535 .772 .985 r
.4069 .57178 .40795 .57256 .4097 .57216 .40864 .57153 Mtetra
.639 .841 .978 r
.40864 .57153 .4097 .57216 .41145 .57161 .4104 .57095 Mtetra
.817 .855 .877 r
.4104 .57095 .41145 .57161 .41322 .57072 .41219 .5695 Mtetra
.89 .752 .703 r
.41219 .5695 .41322 .57072 .41501 .56925 .41405 .56585 Mtetra
.888 .662 .589 r
.41405 .56585 .41501 .56925 .41683 .56693 .41613 .55535 Mtetra
.946 .676 .494 r
.41613 .55535 .41683 .56693 .41873 .56177 .42409 .35894 Mtetra
.547 .325 .531 r
.42409 .35894 .41873 .56177 .42667 .36103 .42585 .35523 Mtetra
.666 .485 .63 r
.42585 .35523 .42667 .36103 .42848 .35519 .42755 .35307 Mtetra
.725 .628 .75 r
.42755 .35307 .42848 .35519 .4302 .35269 .42923 .35171 Mtetra
.697 .766 .905 r
.42923 .35171 .4302 .35269 .43186 .35185 .43089 .35099 Mtetra
.637 .776 .947 r
.43089 .35099 .43186 .35185 .43351 .35143 .43254 .35051 Mtetra
.623 .757 .942 r
.43254 .35051 .43351 .35143 .43516 .35113 .4342 .35008 Mtetra
.667 .743 .907 r
.4342 .35008 .43516 .35113 .43682 .35059 .43586 .34949 Mtetra
.666 .734 .9 r
.43586 .34949 .43682 .35059 .43848 .35005 .43752 .3489 Mtetra
.678 .729 .888 r
.43752 .3489 .43848 .35005 .44014 .34947 .43918 .34825 Mtetra
.708 .725 .863 r
.43918 .34825 .44014 .34947 .4418 .34879 .44085 .34743 Mtetra
.656 .685 .866 r
.44085 .34743 .4418 .34879 .44347 .34822 .44251 .34687 Mtetra
.472 .605 .902 r
.44251 .34687 .44347 .34822 .44512 .34799 .44416 .347 Mtetra
.707 .22 0 r
.44416 .347 .44512 .34799 .44676 .34856 .44575 .34926 Mtetra
.907 .564 .381 r
.44575 .34926 .44676 .34856 .44839 .34956 .44722 .35684 Mtetra
.951 .673 .475 r
.44722 .35684 .44839 .34956 .45002 .35066 .4442 .55263 Mtetra
.539 .315 .523 r
.4442 .55263 .45002 .35066 .45168 .35039 .44595 .55323 Mtetra
.536 .313 .523 r
.44595 .55323 .45168 .35039 .45335 .34963 .44774 .55224 Mtetra
.535 .311 .522 r
.44774 .55224 .45335 .34963 .45504 .34859 .44955 .55045 Mtetra
.535 .312 .522 r
.44955 .55045 .45504 .34859 .45672 .34736 .45135 .54899 Mtetra
.537 .313 .523 r
.45135 .54899 .45672 .34736 .4584 .34677 .45313 .54833 Mtetra
.54 .316 .523 r
.45313 .54833 .4584 .34677 .46004 .34785 .45487 .54957 Mtetra
.544 .319 .524 r
.45487 .54957 .46004 .34785 .45776 .54571 .45658 .55272 Mtetra
.608 .317 .449 r
.45658 .55272 .45776 .54571 .45937 .55417 .45832 .55456 Mtetra
.571 .031 0 r
.45832 .55456 .45937 .55417 .4611 .5565 .46008 .55543 Mtetra
.59 .731 .941 r
.46008 .55543 .4611 .5565 .46288 .55636 .46187 .5551 Mtetra
.665 .72 .89 r
.46187 .5551 .46288 .55636 .46468 .55569 .46366 .55446 Mtetra
.689 .734 .885 r
.46366 .55446 .46468 .55569 .46648 .5548 .46546 .55371 Mtetra
.652 .747 .92 r
.46546 .55371 .46648 .5548 .46827 .55424 .46726 .55314 Mtetra
.652 .747 .919 r
.46726 .55314 .46827 .55424 .47007 .55367 .46905 .55257 Mtetra
.651 .747 .92 r
.46905 .55257 .47007 .55367 .47186 .5531 .47085 .55201 Mtetra
.648 .747 .921 r
.47085 .55201 .47186 .5531 .47366 .55255 .47265 .55145 Mtetra
.647 .746 .922 r
.47265 .55145 .47366 .55255 .47546 .552 .47445 .5509 Mtetra
.646 .745 .922 r
.47445 .5509 .47546 .552 .47726 .55146 .47625 .55036 Mtetra
.643 .744 .922 r
.47625 .55036 .47726 .55146 .47906 .55093 .47805 .54983 Mtetra
.643 .743 .922 r
.47805 .54983 .47906 .55093 .48086 .55041 .47985 .5493 Mtetra
.639 .741 .922 r
.47985 .5493 .48086 .55041 .48266 .5499 .48165 .54878 Mtetra
.59 .721 .934 r
.48165 .54878 .48266 .5499 .48446 .54971 .48345 .54845 Mtetra
.637 .712 .901 r
.48345 .54845 .48446 .54971 .48627 .54922 .48526 .54795 Mtetra
.704 .733 .873 r
.48526 .54795 .48627 .54922 .48808 .54809 .48707 .54709 Mtetra
.857 .798 .793 r
.48707 .54709 .48808 .54809 .48992 .5441 .4889 .54491 Mtetra
.904 .967 .651 r
.4889 .54491 .48992 .5441 .49186 .53031 .49073 .54183 Mtetra
.351 .123 .421 r
.49073 .54183 .49186 .53031 .49548 .33507 .49258 .53754 Mtetra
.538 .314 .523 r
.49258 .53754 .49548 .33507 .49718 .33384 .49438 .5373 Mtetra
.49438 .5373 .49718 .33384 .49888 .33354 .49619 .53724 Mtetra
.536 .312 .522 r
.49619 .53724 .49888 .33354 .50057 .33333 .49801 .53584 Mtetra
0 0 .327 r
.49801 .53584 .50057 .33333 .50229 .33085 .5013 .33599 Mtetra
0 0 .021 r
.5013 .33599 .50229 .33085 .504 .32877 .50305 .32903 Mtetra
.961 .937 .709 r
.50305 .32903 .504 .32877 .50571 .32715 .50477 .32595 Mtetra
.71 .734 .87 r
.50477 .32595 .50571 .32715 .50741 .3265 .50648 .32511 Mtetra
.611 .665 .878 r
.50648 .32511 .50741 .3265 .50911 .32608 .50818 .32475 Mtetra
.547 .646 .9 r
.50818 .32475 .50911 .32608 .51082 .32577 .50988 .32463 Mtetra
.645 .725 .906 r
.50988 .32463 .51082 .32577 .51252 .32522 .51159 .32412 Mtetra
.66 .738 .908 r
.51159 .32412 .51252 .32522 .51423 .32461 .5133 .32355 Mtetra
.673 .749 .908 r
.5133 .32355 .51423 .32461 .51594 .32396 .51501 .32292 Mtetra
.731 .769 .883 r
.51501 .32292 .51594 .32396 .51765 .32289 .51672 .32199 Mtetra
.712 .795 .916 r
.51672 .32199 .51765 .32289 .51936 .32207 .51843 .32118 Mtetra
.641 .779 .947 r
.51843 .32118 .51936 .32207 .52107 .32175 .52014 .32067 Mtetra
.132 .469 .893 r
.52014 .32067 .52107 .32175 .52278 .32393 .52185 .32138 Mtetra
.191 .284 .731 r
.52185 .32138 .52278 .32393 .52449 .33327 .52356 .32298 Mtetra
.418 .273 .576 r
.52356 .32298 .52449 .33327 .5263 .53109 .52528 .32586 Mtetra
.54 .32 .53 r
.52528 .32586 .5263 .53109 .52813 .53166 .527 .32537 Mtetra
.541 .321 .53 r
.527 .32537 .52813 .53166 .52996 .53088 .52872 .32429 Mtetra
.539 .319 .529 r
.52872 .32429 .52996 .53088 .53179 .52992 .53044 .32434 Mtetra
0 0 .357 r
.53044 .32434 .53179 .52992 .53363 .53124 .53263 .52252 Mtetra
.052 .025 .504 r
.53263 .52252 .53363 .53124 .53547 .53241 .53448 .52959 Mtetra
.005 .151 .666 r
.53448 .52959 .53547 .53241 .53732 .5331 .53633 .53204 Mtetra
.366 .631 .956 r
.53633 .53204 .53732 .5331 .53916 .53318 .53817 .53228 Mtetra
.629 .787 .958 r
.53817 .53228 .53916 .53318 .541 .53275 .54002 .53176 Mtetra
.749 .802 .895 r
.54002 .53176 .541 .53275 .54284 .53167 .54186 .53069 Mtetra
.821 .811 .841 r
.54186 .53069 .54284 .53167 .54467 .52849 .5437 .52904 Mtetra
.873 .985 .705 r
.5437 .52904 .54467 .52849 .54647 .52063 .54553 .52649 Mtetra
.072 0 .262 r
.54553 .52649 .54647 .52063 .5469 .31842 .54735 .52187 Mtetra
0 0 .347 r
.54735 .52187 .5469 .31842 .5486 .31447 .54774 .32064 Mtetra
0 0 .136 r
.54774 .32064 .5486 .31447 .55032 .31243 .54942 .31317 Mtetra
.91 .958 .628 r
.54942 .31317 .55032 .31243 .55205 .3111 .55113 .3101 Mtetra
.758 .787 .877 r
.55113 .3101 .55205 .3111 .55378 .31035 .55286 .30901 Mtetra
.628 .683 .883 r
.55286 .30901 .55378 .31035 .55551 .30987 .55459 .30856 Mtetra
.566 .662 .902 r
.55459 .30856 .55551 .30987 .55725 .30951 .55633 .30837 Mtetra
.699 .747 .889 r
.55633 .30837 .55725 .30951 .55898 .30856 .55806 .3076 Mtetra
.713 .786 .909 r
.55806 .3076 .55898 .30856 .56071 .30769 .5598 .30677 Mtetra
.654 .779 .94 r
.5598 .30677 .56071 .30769 .56245 .30727 .56154 .3062 Mtetra
.394 .629 .948 r
.56154 .3062 .56245 .30727 .56421 .30876 .56328 .30641 Mtetra
.309 .38 .773 r
.56328 .30641 .56421 .30876 .56603 .31424 .56505 .30751 Mtetra
.336 .244 .601 r
.56505 .30751 .56603 .31424 .57055 .51619 .56683 .31043 Mtetra
0 0 .37 r
.56683 .31043 .57055 .51619 .57246 .51968 .57137 .50996 Mtetra
.095 .051 .512 r
.57137 .50996 .57246 .51968 .57435 .52081 .57335 .51752 Mtetra
.139 .212 .678 r
.57335 .51752 .57435 .52081 .57623 .52114 .57526 .51989 Mtetra
.347 .579 .928 r
.57526 .51989 .57623 .52114 .57811 .52121 .57714 .52029 Mtetra
.609 .779 .962 r
.57714 .52029 .57811 .52121 .57998 .52083 .57901 .51983 Mtetra
.737 .801 .903 r
.57901 .51983 .57998 .52083 .58184 .51983 .58087 .51882 Mtetra
.812 .809 .848 r
.58087 .51882 .58184 .51983 .58367 .51699 .58273 .51724 Mtetra
.894 .989 .764 r
.58273 .51724 .58367 .51699 .58543 .51034 .58457 .51486 Mtetra
.01 0 .201 r
.58457 .51486 .58543 .51034 .5835 .30706 .58638 .51083 Mtetra
0 0 .37 r
.58638 .51083 .5835 .30706 .58518 .30248 .58452 .31395 Mtetra
0 0 .274 r
.58452 .31395 .58518 .30248 .58691 .30041 .58605 .30186 Mtetra
.752 .852 .41 r
.58605 .30186 .58691 .30041 .58865 .29908 .58775 .29836 Mtetra
.82 .858 .875 r
.58775 .29836 .58865 .29908 .59039 .29821 .58949 .29693 Mtetra
.668 .713 .882 r
.58949 .29693 .59039 .29821 .59215 .29759 .59124 .29629 Mtetra
.61 .686 .897 r
.59124 .29629 .59215 .29759 .59391 .29708 .59301 .29592 Mtetra
.739 .758 .868 r
.59301 .29592 .59391 .29708 .59566 .296 .59476 .2949 Mtetra
.742 .769 .875 r
.59476 .2949 .59566 .296 .5974 .29498 .59651 .29387 Mtetra
.613 .725 .925 r
.59651 .29387 .5974 .29498 .59917 .29457 .59827 .29347 Mtetra
.627 .162 0 r
.59827 .29347 .59917 .29457 .601 .29704 .60011 .29602 Mtetra
.973 .68 .407 r
.60011 .29602 .601 .29704 .60787 .50068 .60693 .50029 Mtetra
.936 .564 .255 r
.60693 .50029 .60787 .50068 .61 .50969 .60905 .50881 Mtetra
0 .27 .736 r
.60905 .50881 .61 .50969 .61194 .51106 .61098 .51001 Mtetra
.636 .762 .939 r
.61098 .51001 .61194 .51106 .61383 .51065 .61287 .50948 Mtetra
.769 .779 .861 r
.61287 .50948 .61383 .51065 .6157 .5093 .61475 .50819 Mtetra
.812 .796 .837 r
.61475 .50819 .6157 .5093 .61753 .50645 .61661 .50654 Mtetra
.887 .989 .797 r
.61661 .50654 .61753 .50645 .61926 .50014 .61846 .50435 Mtetra
.053 0 .209 r
.61846 .50435 .61926 .50014 .61528 .29686 .62027 .50076 Mtetra
.506 .29 .519 r
.62027 .50076 .61528 .29686 .61692 .2918 .62166 .48287 Mtetra
0 0 .372 r
.62166 .48287 .61692 .2918 .61865 .28966 .61785 .29156 Mtetra
0 0 0 r
.61785 .29156 .61865 .28966 .6204 .28828 .61953 .28772 Mtetra
.853 .898 .867 r
.61953 .28772 .6204 .28828 .62217 .28736 .62128 .28609 Mtetra
.676 .72 .882 r
.62128 .28609 .62217 .28736 .62394 .28673 .62305 .2854 Mtetra
.609 .682 .894 r
.62305 .2854 .62394 .28673 .62572 .28624 .62483 .28503 Mtetra
.705 .743 .881 r
.62483 .28503 .62572 .28624 .62749 .28532 .62661 .2842 Mtetra
.729 .765 .881 r
.62661 .2842 .62749 .28532 .62926 .28436 .62837 .28325 Mtetra
.601 .721 .929 r
.62837 .28325 .62926 .28436 .63105 .28398 .63016 .28289 Mtetra
0 0 .46 r
.63016 .28289 .63105 .28398 .63293 .28617 .63205 .28516 Mtetra
.974 .678 .393 r
.63205 .28516 .63293 .28617 .64191 .48919 .641 .48899 Mtetra
.935 .563 .258 r
.641 .48899 .64191 .48919 .64418 .49886 .64325 .49798 Mtetra
0 .229 .704 r
.64325 .49798 .64418 .49886 .64616 .50027 .64523 .49932 Mtetra
.65 .792 .95 r
.64523 .49932 .64616 .50027 .64808 .4997 .64714 .4987 Mtetra
.758 .811 .895 r
.64714 .4987 .64808 .4997 .64997 .49861 .64904 .49755 Mtetra
.63 .761 .941 r
.64904 .49755 .64997 .49861 .65189 .49812 .65096 .49702 Mtetra
.502 .698 .957 r
.65096 .49702 .65189 .49812 .65383 .49804 .6529 .49694 Mtetra
.662 .765 .926 r
.6529 .49694 .65383 .49804 .65575 .49738 .65481 .49628 Mtetra
.901 .803 .741 r
.65481 .49628 .65575 .49738 .65757 .49438 .65664 .49328 Mtetra
.975 .73 .501 r
.65664 .49328 .65757 .49438 .65895 .48036 .658 .47884 Mtetra
.976 .685 .402 r
.658 .47884 .65895 .48036 .65259 .27889 .65171 .27769 Mtetra
.895 .78 .727 r
.65171 .27769 .65259 .27889 .65429 .2759 .65341 .27472 Mtetra
.703 .75 .888 r
.65341 .27472 .65429 .2759 .65608 .27507 .6552 .2739 Mtetra
.579 .703 .927 r
.6552 .2739 .65608 .27507 .65789 .27477 .65701 .27362 Mtetra
.668 .743 .906 r
.65701 .27362 .65789 .27477 .65968 .27412 .65881 .27298 Mtetra
.734 .768 .88 r
.65881 .27298 .65968 .27412 .66147 .27312 .6606 .272 Mtetra
.622 .729 .923 r
.6606 .272 .66147 .27312 .66327 .27266 .6624 .27155 Mtetra
0 .142 .668 r
.6624 .27155 .66327 .27266 .66518 .27429 .66431 .27324 Mtetra
.975 .676 .377 r
.66431 .27324 .66518 .27429 .67598 .46978 .67521 .47184 Mtetra
.925 .582 .368 r
.67521 .47184 .67598 .46978 .67876 .48751 .67784 .48661 Mtetra
0 .075 .569 r
.67784 .48661 .67876 .48751 .68081 .4894 .67989 .48842 Mtetra
.647 .787 .949 r
.67989 .48842 .68081 .4894 .68275 .48885 .68183 .48781 Mtetra
.769 .81 .886 r
.68183 .48781 .68275 .48885 .68466 .48767 .68374 .48657 Mtetra
.727 .787 .9 r
.68374 .48657 .68466 .48767 .68659 .4868 .68566 .48557 Mtetra
.606 .719 .925 r
.68566 .48557 .68659 .4868 .68854 .48649 .68761 .48516 Mtetra
.657 .721 .896 r
.68761 .48516 .68854 .48649 .69048 .48576 .68955 .48452 Mtetra
.809 .785 .831 r
.68955 .48452 .69048 .48576 .69232 .4831 .69144 .48285 Mtetra
.968 .901 .702 r
.69144 .48285 .69232 .4831 .69378 .47317 .69324 .4793 Mtetra
.045 0 .281 r
.69324 .4793 .69378 .47317 .68524 .27042 .69492 .4737 Mtetra
.535 .311 .522 r
.69492 .4737 .68524 .27042 .68702 .26895 .69679 .47163 Mtetra
.546 .32 .523 r
.69679 .47163 .68702 .26895 .69898 .45968 .69902 .47644 Mtetra
.584 .324 .488 r
.69902 .47644 .69898 .45968 .70199 .47897 .70114 .4791 Mtetra
.563 0 0 r
.70114 .4791 .70199 .47897 .70411 .48155 .70319 .48029 Mtetra
.465 .647 .937 r
.70319 .48029 .70411 .48155 .70611 .48173 .70518 .48038 Mtetra
.676 .727 .888 r
.70518 .48038 .70611 .48173 .70805 .48089 .70713 .47963 Mtetra
.884 .79 .752 r
.70713 .47963 .70805 .48089 .70988 .47802 .70897 .47685 Mtetra
.979 .731 .49 r
.70897 .47685 .70988 .47802 .7111 .46447 .71017 .46282 Mtetra
.977 .681 .38 r
.71017 .46282 .7111 .46447 .70151 .26228 .70065 .26109 Mtetra
.913 .785 .707 r
.70065 .26109 .70151 .26228 .70318 .25893 .70233 .25776 Mtetra
.712 .757 .887 r
.70233 .25776 .70318 .25893 .70499 .25805 .70414 .25688 Mtetra
.59 .709 .926 r
.70414 .25688 .70499 .25805 .70684 .25772 .70599 .25655 Mtetra
.626 .725 .918 r
.70599 .25655 .70684 .25772 .70868 .25725 .70783 .25608 Mtetra
.734 .766 .879 r
.70783 .25608 .70868 .25725 .71049 .25624 .70964 .25507 Mtetra
.643 .734 .915 r
.70964 .25507 .71049 .25624 .71232 .2557 .71147 .25453 Mtetra
.069 .404 .858 r
.71147 .25453 .71232 .2557 .71426 .25671 .71341 .25555 Mtetra
.922 .548 .133 r
.71341 .25555 .71426 .25671 .71669 .2657 .71585 .26466 Mtetra
.975 .671 .352 r
.71585 .26466 .71669 .2657 .7314 .4702 .7305 .46912 Mtetra
.618 .152 0 r
.7305 .46912 .7314 .4702 .7336 .4732 .7327 .47211 Mtetra
.412 .656 .959 r
.7327 .47211 .7336 .4732 .73562 .47335 .73472 .47227 Mtetra
.717 .794 .912 r
.73472 .47227 .73562 .47335 .73757 .47239 .73668 .47132 Mtetra
.9 .821 .76 r
.73668 .47132 .73757 .47239 .73941 .4696 .73852 .46855 Mtetra
.982 .746 .504 r
.73852 .46855 .73941 .4696 .74066 .45799 .73979 .4572 Mtetra
.978 .679 .364 r
.73979 .4572 .74066 .45799 .72905 .25282 .72821 .25169 Mtetra
.93 .795 .69 r
.72821 .25169 .72905 .25282 .7307 .2492 .72986 .24805 Mtetra
.694 .758 .901 r
.72986 .24805 .7307 .2492 .73253 .2484 .73169 .24726 Mtetra
.539 .693 .939 r
.73169 .24726 .73253 .2484 .73441 .24823 .73357 .2471 Mtetra
.497 .675 .944 r
.73357 .2471 .73441 .24823 .7363 .24818 .73546 .24707 Mtetra
.646 .747 .923 r
.73546 .24707 .7363 .24818 .73815 .24763 .73732 .24651 Mtetra
.658 .751 .918 r
.73732 .24651 .73815 .24763 .74 .24702 .73917 .24589 Mtetra
.699 .764 .903 r
.73917 .24589 .74 .24702 .74184 .24623 .74101 .24508 Mtetra
.754 .78 .875 r
.74101 .24508 .74184 .24623 .74366 .24511 .74283 .24395 Mtetra
.67 .749 .91 r
.74283 .24395 .74366 .24511 .74551 .24445 .74468 .24329 Mtetra
.234 .514 .91 r
.74468 .24329 .74551 .24445 .74746 .24512 .74663 .24396 Mtetra
.894 .506 .06 r
.74663 .24396 .74746 .24512 .74993 .25288 .7491 .25175 Mtetra
.975 .667 .334 r
.7491 .25175 .74993 .25288 .76705 .45891 .76617 .45779 Mtetra
.642 .186 0 r
.76617 .45779 .76705 .45891 .76934 .46228 .76846 .46115 Mtetra
.389 .635 .953 r
.76846 .46115 .76934 .46228 .7714 .46252 .77052 .46139 Mtetra
.694 .781 .918 r
.77052 .46139 .7714 .46252 .77339 .46168 .77251 .46056 Mtetra
.873 .82 .793 r
.77251 .46056 .77339 .46168 .77526 .45935 .77438 .45822 Mtetra
.978 .767 .552 r
.77438 .45822 .77526 .45935 .7767 .4515 .77583 .45037 Mtetra
.977 .675 .347 r
.77583 .45037 .7767 .4515 .76257 .24287 .76175 .24169 Mtetra
.95 .784 .641 r
.76175 .24169 .76257 .24287 .76413 .23824 .7633 .23705 Mtetra
.747 .772 .873 r
.7633 .23705 .76413 .23824 .76596 .23714 .76514 .23595 Mtetra
.621 .723 .919 r
.76514 .23595 .76596 .23714 .76784 .23669 .76702 .23549 Mtetra
.589 .708 .925 r
.76702 .23549 .76784 .23669 .76974 .23636 .76892 .23516 Mtetra
.749 .772 .872 r
.76892 .23516 .76974 .23636 .77157 .23524 .77075 .23404 Mtetra
.674 .745 .904 r
.77075 .23404 .77157 .23524 .77344 .23455 .77262 .23335 Mtetra
.372 .591 .929 r
.77262 .23335 .77344 .23455 .77539 .23491 .77457 .2337 Mtetra
.813 .403 0 r
.77457 .2337 .77539 .23491 .77779 .24058 .77696 .23933 Mtetra
.973 .663 .318 r
.77696 .23933 .77779 .24058 .79702 .44847 .79615 .44727 Mtetra
.695 .256 0 r
.79615 .44727 .79702 .44847 .79943 .45255 .79856 .45138 Mtetra
.507 .69 .95 r
.79856 .45138 .79943 .45255 .80149 .45247 .80063 .45129 Mtetra
.687 .771 .915 r
.80063 .45129 .80149 .45247 .8035 .45167 .80263 .45048 Mtetra
.717 .78 .902 r
.80263 .45048 .8035 .45167 .80549 .4507 .80463 .4495 Mtetra
.448 .653 .948 r
.80463 .4495 .80549 .4507 .80758 .4508 .80671 .44961 Mtetra
.584 .726 .941 r
.80671 .44961 .80758 .4508 .80963 .45043 .80876 .44925 Mtetra
.784 .803 .868 r
.80876 .44925 .80963 .45043 .81158 .44901 .81072 .44784 Mtetra
.974 .78 .582 r
.81072 .44784 .81158 .44901 .8131 .44259 .81223 .44134 Mtetra
.976 .671 .329 r
.81223 .44134 .8131 .44259 .7965 .2325 .79568 .23118 Mtetra
.961 .769 .6 r
.79568 .23118 .7965 .2325 .79794 .22676 .79712 .2255 Mtetra
.758 .767 .86 r
.79712 .2255 .79794 .22676 .79977 .22554 .79896 .2243 Mtetra
.627 .717 .911 r
.79896 .2243 .79977 .22554 .80168 .22505 .80087 .22381 Mtetra
.555 .684 .925 r
.80087 .22381 .80168 .22505 .80361 .22484 .8028 .22361 Mtetra
.749 .769 .869 r
.8028 .22361 .80361 .22484 .80546 .2237 .80465 .22248 Mtetra
.68 .745 .9 r
.80465 .22248 .80546 .2237 .80734 .22296 .80654 .22174 Mtetra
.46 .638 .933 r
.80654 .22174 .80734 .22296 .80931 .22307 .8085 .22185 Mtetra
.77 .356 0 r
.8085 .22185 .80931 .22307 .81176 .22832 .81096 .22709 Mtetra
.971 .657 .298 r
.81096 .22709 .81176 .22832 .83348 .43698 .83263 .43582 Mtetra
.722 .288 0 r
.83263 .43582 .83348 .43698 .83602 .44157 .83517 .44042 Mtetra
.309 .582 .938 r
.83517 .44042 .83602 .44157 .83817 .44205 .83732 .4409 Mtetra
.651 .764 .932 r
.83732 .4409 .83817 .44205 .84022 .44141 .83937 .44025 Mtetra
.831 .821 .84 r
.83937 .44025 .84022 .44141 .84215 .4396 .84131 .43844 Mtetra
.976 .788 .587 r
.84131 .43844 .84215 .4396 .84366 .43344 .84282 .43229 Mtetra
.974 .667 .312 r
.84282 .43229 .84366 .43344 .82506 .22328 .82426 .22209 Mtetra
.975 .776 .573 r
.82426 .22209 .82506 .22328 .82642 .21707 .82562 .21587 Mtetra
.764 .761 .85 r
.21192 .42634 .21297 .4273 .21455 .4262 .2135 .42525 Mtetra
.624 .735 .927 r
.2135 .42525 .21455 .4262 .21607 .42581 .21502 .42487 Mtetra
.48 .686 .957 r
.21502 .42487 .21607 .42581 .21755 .42579 .2165 .42485 Mtetra
.675 .751 .908 r
.2165 .42485 .21755 .42579 .21909 .42507 .21803 .42427 Mtetra
.678 .783 .929 r
.21803 .42427 .21909 .42507 .22063 .42447 .21957 .42369 Mtetra
.67 .787 .936 r
.21957 .42369 .22063 .42447 .22215 .42412 .2211 .42313 Mtetra
.731 .753 .87 r
.2211 .42313 .22215 .42412 .22359 .42449 .22267 .42226 Mtetra
.634 .567 .762 r
.22267 .42226 .22359 .42449 .22497 .42567 .2242 .42172 Mtetra
.535 .426 .677 r
.2242 .42172 .22497 .42567 .22617 .4288 .22567 .42187 Mtetra
.058 .021 .496 r
.22567 .42187 .22617 .4288 .20996 .62239 .22675 .42638 Mtetra
0 0 .15 r
.22675 .42638 .20996 .62239 .21099 .6284 .21014 .62458 Mtetra
0 0 .18 r
.21014 .62458 .21099 .6284 .21239 .63048 .21128 .62947 Mtetra
0 .386 .834 r
.21128 .62947 .21239 .63048 .21393 .63096 .2128 .63024 Mtetra
.609 .798 .972 r
.2128 .63024 .21393 .63096 .21556 .63054 .21442 .62982 Mtetra
.817 .815 .848 r
.21442 .62982 .21556 .63054 .21727 .62912 .21615 .62832 Mtetra
.915 .747 .659 r
.21615 .62832 .21727 .62912 .2194 .62309 .21823 .62279 Mtetra
.94 .688 .529 r
.21823 .62279 .2194 .62309 .23867 .42263 .23754 .42264 Mtetra
.95 .784 .642 r
.23754 .42264 .23867 .42263 .24064 .41718 .23956 .41668 Mtetra
.82 .854 .874 r
.23956 .41668 .24064 .41718 .24225 .41588 .24118 .41535 Mtetra
.603 .835 .988 r
.24118 .41535 .24225 .41588 .24379 .41543 .24271 .41493 Mtetra
.354 .742 .986 r
.24271 .41493 .24379 .41543 .24529 .41537 .24421 .4149 Mtetra
.573 .842 .996 r
.24421 .4149 .24529 .41537 .24683 .41496 .24575 .41452 Mtetra
.601 .856 .992 r
.24575 .41452 .24683 .41496 .24837 .41449 .24729 .41406 Mtetra
.603 .86 .992 r
.24729 .41406 .24837 .41449 .24991 .41401 .24883 .4136 Mtetra
.617 .867 .99 r
.24883 .4136 .24991 .41401 .25146 .4135 .25037 .4131 Mtetra
.627 .871 .988 r
.25037 .4131 .25146 .4135 .253 .41298 .25192 .41257 Mtetra
.635 .874 .986 r
.25192 .41257 .253 .41298 .25456 .41244 .25347 .41202 Mtetra
.657 .876 .98 r
.25347 .41202 .25456 .41244 .25612 .41172 .25503 .41142 Mtetra
.636 .898 .985 r
.25503 .41142 .25612 .41172 .25768 .4111 .25659 .41083 Mtetra
.611 .899 .987 r
.25659 .41083 .25768 .4111 .25922 .41073 .25815 .41027 Mtetra
.572 .845 .996 r
.25815 .41027 .25922 .41073 .26068 .41139 .25969 .40988 Mtetra
.613 .634 .848 r
.25969 .40988 .26068 .41139 .26206 .41297 .26123 .40955 Mtetra
.591 .481 .698 r
.26123 .40955 .26206 .41297 .26335 .41577 .26277 .4092 Mtetra
.58 .414 .621 r
.26277 .4092 .26335 .41577 .26476 .41702 .26432 .40867 Mtetra
.576 .397 .602 r
.26432 .40867 .26476 .41702 .26634 .41629 .26589 .40806 Mtetra
.577 .399 .603 r
.26589 .40806 .26634 .41629 .26798 .4148 .26746 .40743 Mtetra
.597 .42 .613 r
.26746 .40743 .26798 .4148 .26963 .41309 .26905 .40646 Mtetra
.591 .422 .621 r
.26905 .40646 .26963 .41309 .27123 .41208 .27063 .40571 Mtetra
.556 .398 .623 r
.27063 .40571 .27123 .41208 .27273 .41245 .27216 .40561 Mtetra
.252 .168 .563 r
.27216 .40561 .27273 .41245 .25943 .60372 .27342 .40886 Mtetra
0 0 .181 r
.27342 .40886 .25943 .60372 .26034 .61294 .25958 .60757 Mtetra
0 0 .237 r
.25958 .60757 .26034 .61294 .26175 .61568 .26071 .6139 Mtetra
.247 .419 .836 r
.26071 .6139 .26175 .61568 .26334 .61604 .26227 .61472 Mtetra
.639 .688 .88 r
.26227 .61472 .26334 .61604 .265 .61557 .26393 .61425 Mtetra
.716 .712 .845 r
.26393 .61425 .265 .61557 .26669 .61478 .26563 .61333 Mtetra
.662 .676 .853 r
.26563 .61333 .26669 .61478 .26835 .61432 .2673 .61272 Mtetra
.635 .647 .845 r
.2673 .61272 .26835 .61432 .27001 .61387 .26897 .61225 Mtetra
.642 .647 .839 r
.26897 .61225 .27001 .61387 .2717 .61316 .27064 .61174 Mtetra
.675 .685 .852 r
.27064 .61174 .2717 .61316 .27345 .61145 .27232 .61106 Mtetra
.689 .896 .972 r
.27232 .61106 .27345 .61145 .27528 .60874 .274 .6103 Mtetra
.179 0 0 r
.274 .6103 .27528 .60874 .2772 .60485 .27569 .60954 Mtetra
.494 .188 .376 r
.27569 .60954 .2772 .60485 .27895 .60309 .27734 .60934 Mtetra
.504 .218 .413 r
.27734 .60934 .27895 .60309 .28059 .60311 .279 .6091 Mtetra
.452 .167 .389 r
.279 .6091 .28059 .60311 .28227 .60237 .2807 .60822 Mtetra
.022 0 .203 r
.2807 .60822 .28227 .60237 .29708 .41519 .28263 .60405 Mtetra
0 0 .161 r
.28263 .60405 .29708 .41519 .29964 .40073 .29831 .40418 Mtetra
.952 .864 .448 r
.29831 .40418 .29964 .40073 .30144 .39699 .30039 .39639 Mtetra
.872 .824 .798 r
.30039 .39639 .30144 .39699 .3031 .39527 .30208 .39435 Mtetra
.699 .767 .905 r
.30208 .39435 .3031 .39527 .3047 .39443 .30367 .39365 Mtetra
.557 .761 .973 r
.30367 .39365 .3047 .39443 .30627 .39407 .30523 .3934 Mtetra
.667 .82 .957 r
.30523 .3934 .30627 .39407 .3078 .39427 .30681 .39282 Mtetra
.663 .665 .842 r
.30681 .39282 .3078 .39427 .30928 .39519 .3084 .39223 Mtetra
.556 .481 .726 r
.3084 .39223 .30928 .39519 .31068 .39748 .30995 .39219 Mtetra
.27 .21 .603 r
.30995 .39219 .31068 .39748 .30009 .58132 .31134 .39465 Mtetra
0 0 .188 r
.31134 .39465 .30009 .58132 .30053 .59955 .2999 .5918 Mtetra
0 0 .229 r
.2999 .5918 .30053 .59955 .30199 .60249 .30095 .60085 Mtetra
0 .212 .737 r
.30095 .60085 .30199 .60249 .30359 .60333 .30252 .60225 Mtetra
.589 .718 .933 r
.30252 .60225 .30359 .60333 .30526 .60319 .30419 .60195 Mtetra
.706 .724 .864 r
.30419 .60195 .30526 .60319 .30696 .60249 .3059 .60112 Mtetra
.643 .683 .873 r
.3059 .60112 .30696 .60249 .3087 .60117 .3076 .60061 Mtetra
.579 .836 .994 r
.3076 .60061 .3087 .60117 .3105 .59905 .30928 .60019 Mtetra
0 0 0 r
.30928 .60019 .3105 .59905 .31238 .59548 .31101 .59917 Mtetra
.31101 .59917 .31238 .59548 .31501 .57969 .3129 .59554 Mtetra
.968 .712 .492 r
.3129 .59554 .31501 .57969 .32819 .39135 .32673 .3978 Mtetra
.79 .748 .227 r
.32673 .3978 .32819 .39135 .32998 .38763 .32894 .38723 Mtetra
.901 .852 .784 r
.32894 .38723 .32998 .38763 .33164 .38605 .33064 .3849 Mtetra
.68 .721 .88 r
.33064 .3849 .33164 .38605 .33324 .38546 .33225 .38426 Mtetra
.56 .669 .911 r
.33225 .38426 .33324 .38546 .33482 .38519 .33382 .3841 Mtetra
.599 .706 .919 r
.33382 .3841 .33482 .38519 .33642 .3847 .33541 .38379 Mtetra
.664 .766 .926 r
.33541 .38379 .33642 .3847 .33803 .38402 .33701 .38324 Mtetra
.655 .792 .947 r
.33701 .38324 .33803 .38402 .33962 .38356 .33861 .38271 Mtetra
.629 .769 .947 r
.33861 .38271 .33962 .38356 .34117 .38386 .34021 .38227 Mtetra
.615 .628 .84 r
.34021 .38227 .34117 .38386 .34267 .3852 .3418 .38191 Mtetra
.594 .49 .706 r
.3418 .38191 .34267 .3852 .34411 .38764 .34339 .38154 Mtetra
.58 .42 .629 r
.34339 .38154 .34411 .38764 .34556 .38986 .345 .38105 Mtetra
.574 .393 .599 r
.345 .38105 .34556 .38986 .34716 .38941 .34661 .38043 Mtetra
.575 .393 .598 r
.34661 .38043 .34716 .38941 .34883 .38788 .34822 .37977 Mtetra
.577 .4 .605 r
.34822 .37977 .34883 .38788 .35048 .38669 .34983 .37914 Mtetra
.578 .405 .611 r
.34983 .37914 .35048 .38669 .3521 .386 .35145 .37855 Mtetra
.578 .405 .612 r
.35145 .37855 .3521 .386 .35371 .38534 .35306 .37796 Mtetra
.577 .406 .612 r
.35306 .37796 .35371 .38534 .35533 .38475 .35467 .3774 Mtetra
.577 .405 .613 r
.35467 .3774 .35533 .38475 .35694 .38422 .35628 .37684 Mtetra
.576 .405 .612 r
.35628 .37684 .35694 .38422 .35856 .38371 .3579 .37629 Mtetra
.574 .403 .612 r
.3579 .37629 .35856 .38371 .36015 .38367 .35951 .37578 Mtetra
.572 .398 .607 r
.35951 .37578 .36015 .38367 .36173 .38391 .36112 .37528 Mtetra
.571 .392 .6 r
.36112 .37528 .36173 .38391 .36336 .38304 .36274 .37475 Mtetra
.578 .399 .604 r
.36274 .37475 .36336 .38304 .36512 .37969 .36436 .37409 Mtetra
.601 .441 .637 r
.36436 .37409 .36512 .37969 .36689 .37615 .36599 .37331 Mtetra
.644 .54 .722 r
.36599 .37331 .36689 .37615 .3686 .37372 .36762 .37253 Mtetra
.683 .718 .875 r
.36762 .37253 .3686 .37372 .37026 .3723 .36924 .37186 Mtetra
.619 .872 .99 r
.36924 .37186 .37026 .3723 .37189 .37166 .37086 .37132 Mtetra
.576 .883 .992 r
.37086 .37132 .37189 .37166 .3735 .37126 .37248 .37083 Mtetra
.601 .868 .993 r
.37248 .37083 .3735 .37126 .37511 .37093 .3741 .37033 Mtetra
.636 .836 .977 r
.3741 .37033 .37511 .37093 .37673 .37055 .37573 .36981 Mtetra
.652 .804 .956 r
.37573 .36981 .37673 .37055 .37834 .37017 .37735 .36927 Mtetra
.666 .771 .928 r
.37735 .36927 .37834 .37017 .37996 .36973 .37898 .3687 Mtetra
.674 .746 .905 r
.37898 .3687 .37996 .36973 .38159 .36917 .38061 .36809 Mtetra
.676 .735 .895 r
.38061 .36809 .38159 .36917 .38322 .36856 .38224 .36746 Mtetra
.677 .735 .894 r
.38224 .36746 .38322 .36856 .38486 .36785 .38387 .36684 Mtetra
.677 .751 .907 r
.38387 .36684 .38486 .36785 .38649 .36707 .3855 .36622 Mtetra
.676 .785 .932 r
.3855 .36622 .38649 .36707 .38813 .36629 .38714 .3656 Mtetra
.72 .832 .934 r
.38714 .3656 .38813 .36629 .38978 .36545 .38878 .3648 Mtetra
.751 .845 .922 r
.38878 .3648 .38978 .36545 .39142 .3646 .39043 .36386 Mtetra
.638 .803 .962 r
.39043 .36386 .39142 .3646 .39305 .36407 .39206 .36336 Mtetra
0 .235 .671 r
.39206 .36336 .39305 .36407 .39465 .36441 .39363 .36431 Mtetra
.923 .573 .351 r
.39363 .36431 .39465 .36441 .39617 .36665 .39497 .371 Mtetra
.95 .677 .486 r
.39497 .371 .39617 .36665 .39743 .37558 .38854 .57145 Mtetra
.544 .319 .523 r
.38854 .57145 .39743 .37558 .39138 .57048 .39013 .57464 Mtetra
.515 .196 .364 r
.39013 .57464 .39138 .57048 .39299 .57345 .39185 .57472 Mtetra
.21 0 0 r
.39185 .57472 .39299 .57345 .39467 .57468 .3936 .57415 Mtetra
.676 .875 .973 r
.3936 .57415 .39467 .57468 .39639 .57498 .39536 .57343 Mtetra
.641 .662 .855 r
.39536 .57343 .39639 .57498 .39813 .57458 .39711 .57291 Mtetra
.648 .648 .837 r
.39711 .57291 .39813 .57458 .39988 .57392 .39886 .57234 Mtetra
.651 .661 .847 r
.39886 .57234 .39988 .57392 .40164 .57323 .40061 .57175 Mtetra
.648 .676 .862 r
.40061 .57175 .40164 .57323 .40339 .57271 .40237 .5712 Mtetra
.648 .67 .858 r
.40237 .5712 .40339 .57271 .40515 .57219 .40412 .57064 Mtetra
.614 .651 .863 r
.40412 .57064 .40515 .57219 .4069 .57178 .40587 .57026 Mtetra
.552 .629 .881 r
.40587 .57026 .4069 .57178 .40864 .57153 .40761 .57014 Mtetra
.657 .694 .873 r
.40761 .57014 .40864 .57153 .4104 .57095 .40937 .56955 Mtetra
.816 .735 .774 r
.40937 .56955 .4104 .57095 .41219 .5695 .41118 .56752 Mtetra
.91 .701 .607 r
.41118 .56752 .41219 .5695 .41405 .56585 .41319 .55937 Mtetra
.952 .683 .489 r
.41319 .55937 .41405 .56585 .41613 .55535 .4215 .35743 Mtetra
.548 .326 .531 r
.4215 .35743 .41613 .55535 .42409 .35894 .42327 .35325 Mtetra
.621 .454 .636 r
.42327 .35325 .42409 .35894 .42585 .35523 .42494 .35209 Mtetra
.617 .512 .712 r
.42494 .35209 .42585 .35523 .42755 .35307 .4266 .35151 Mtetra
.619 .637 .847 r
.4266 .35151 .42755 .35307 .42923 .35171 .42825 .35112 Mtetra
.654 .846 .974 r
.42825 .35112 .42923 .35171 .43089 .35099 .4299 .35052 Mtetra
.621 .869 .989 r
.4299 .35052 .43089 .35099 .43254 .35051 .43156 .34998 Mtetra
.625 .855 .986 r
.43156 .34998 .43254 .35051 .4342 .35008 .43322 .34944 Mtetra
.646 .834 .972 r
.43322 .34944 .4342 .35008 .43586 .34949 .43488 .34888 Mtetra
.643 .841 .976 r
.43488 .34888 .43586 .34949 .43752 .3489 .43654 .34833 Mtetra
.674 .856 .969 r
.43654 .34833 .43752 .3489 .43918 .34825 .43821 .34766 Mtetra
.749 .865 .933 r
.43821 .34766 .43918 .34825 .44085 .34743 .43988 .34672 Mtetra
.652 .817 .963 r
.43988 .34672 .44085 .34743 .44251 .34687 .44154 .34616 Mtetra
.062 .517 .895 r
.44154 .34616 .44251 .34687 .44416 .347 .44318 .34666 Mtetra
.918 .535 .268 r
.44318 .34666 .44416 .347 .44575 .34926 .4447 .3519 Mtetra
.957 .68 .469 r
.4447 .3519 .44575 .34926 .44722 .35684 .44135 .55424 Mtetra
.545 .32 .524 r
.44135 .55424 .44722 .35684 .4442 .55263 .44301 .55836 Mtetra
.518 .223 .405 r
.44301 .55836 .4442 .55263 .44595 .55323 .44478 .55836 Mtetra
.454 .157 .372 r
.44478 .55836 .44595 .55323 .44774 .55224 .44657 .55763 Mtetra
.433 .143 .371 r
.44657 .55763 .44774 .55224 .44955 .55045 .44836 .5566 Mtetra
.478 .193 .401 r
.44836 .5566 .44955 .55045 .45135 .54899 .45015 .55599 Mtetra
.487 .209 .417 r
.45015 .55599 .45135 .54899 .45313 .54833 .45193 .5554 Mtetra
.493 .214 .42 r
.45193 .5554 .45313 .54833 .45487 .54957 .45372 .55489 Mtetra
.492 .194 .388 r
.45372 .55489 .45487 .54957 .45658 .55272 .4555 .55457 Mtetra
.389 0 .138 r
.4555 .55457 .45658 .55272 .45832 .55456 .45729 .55427 Mtetra
.441 .843 .974 r
.45729 .55427 .45832 .55456 .46008 .55543 .45907 .55391 Mtetra
.644 .671 .861 r
.45907 .55391 .46008 .55543 .46187 .5551 .46086 .55337 Mtetra
.648 .645 .833 r
.46086 .55337 .46187 .5551 .46366 .55446 .46266 .55277 Mtetra
.652 .652 .837 r
.46266 .55277 .46366 .55446 .46546 .55371 .46445 .55216 Mtetra
.648 .669 .856 r
.46445 .55216 .46546 .55371 .46726 .55314 .46625 .55159 Mtetra
.647 .668 .856 r
.46625 .55159 .46726 .55314 .46905 .55257 .46804 .55102 Mtetra
.646 .668 .857 r
.46804 .55102 .46905 .55257 .47085 .55201 .46984 .55046 Mtetra
.645 .668 .858 r
.46984 .55046 .47085 .55201 .47265 .55145 .47164 .5499 Mtetra
.644 .668 .858 r
.47164 .5499 .47265 .55145 .47445 .5509 .47344 .54935 Mtetra
.643 .667 .858 r
.47344 .54935 .47445 .5509 .47625 .55036 .47524 .54881 Mtetra
.642 .667 .858 r
.47524 .54881 .47625 .55036 .47805 .54983 .47704 .54826 Mtetra
.641 .665 .858 r
.47704 .54826 .47805 .54983 .47985 .5493 .47884 .54773 Mtetra
.64 .664 .858 r
.47884 .54773 .47985 .5493 .48165 .54878 .48065 .5472 Mtetra
.632 .659 .859 r
.48065 .5472 .48165 .54878 .48345 .54845 .48245 .54671 Mtetra
.634 .64 .838 r
.48245 .54671 .48345 .54845 .48526 .54795 .48426 .5462 Mtetra
.643 .643 .835 r
.48426 .5462 .48526 .54795 .48707 .54709 .48607 .54563 Mtetra
.68 .696 .859 r
.48607 .54563 .48707 .54709 .4889 .54491 .48788 .54489 Mtetra
.558 .929 .925 r
.48788 .54489 .4889 .54491 .49073 .54183 .48969 .5441 Mtetra
.327 0 .161 r
.48969 .5441 .49073 .54183 .49258 .53754 .4915 .54335 Mtetra
.515 .221 .405 r
.4915 .54335 .49258 .53754 .49438 .5373 .49331 .54332 Mtetra
.491 .202 .402 r
.49331 .54332 .49438 .5373 .49619 .53724 .49512 .5429 Mtetra
.423 .139 .375 r
.49512 .5429 .49619 .53724 .49801 .53584 .49695 .54167 Mtetra
0 0 .115 r
.49695 .54167 .49801 .53584 .5013 .33599 .49881 .53503 Mtetra
0 0 .31 r
.49881 .53503 .5013 .33599 .50305 .32903 .5021 .33074 Mtetra
.938 .885 .475 r
.5021 .33074 .50305 .32903 .50477 .32595 .50383 .32538 Mtetra
.795 .881 .909 r
.50383 .32538 .50477 .32595 .50648 .32511 .50554 .32418 Mtetra
.642 .769 .94 r
.50554 .32418 .50648 .32511 .50818 .32475 .50724 .32367 Mtetra
.542 .695 .939 r
.50724 .32367 .50818 .32475 .50988 .32463 .50895 .32351 Mtetra
.652 .73 .907 r
.50895 .32351 .50988 .32463 .51159 .32412 .51066 .32297 Mtetra
.654 .725 .902 r
.51066 .32297 .51159 .32412 .5133 .32355 .51236 .32242 Mtetra
.656 .732 .905 r
.51236 .32242 .5133 .32355 .51501 .32292 .51407 .32186 Mtetra
.676 .753 .909 r
.51407 .32186 .51501 .32292 .51672 .32199 .51578 .32122 Mtetra
.672 .816 .953 r
.51578 .32122 .51672 .32199 .51843 .32118 .51749 .32058 Mtetra
.649 .851 .977 r
.51749 .32058 .51843 .32118 .52014 .32067 .51921 .31998 Mtetra
.599 .813 .982 r
.51921 .31998 .52014 .32067 .52185 .32138 .52092 .31954 Mtetra
.614 .606 .819 r
.52092 .31954 .52185 .32138 .52356 .32298 .52263 .31916 Mtetra
.589 .472 .688 r
.52263 .31916 .52356 .32298 .52528 .32586 .52435 .31876 Mtetra
.599 .425 .617 r
.52435 .31876 .52528 .32586 .527 .32537 .52607 .31774 Mtetra
.584 .409 .611 r
.52607 .31774 .527 .32537 .52872 .32429 .52778 .31698 Mtetra
.552 .389 .614 r
.52778 .31698 .52872 .32429 .53044 .32434 .5295 .3169 Mtetra
.241 .167 .569 r
.5295 .3169 .53044 .32434 .53263 .52252 .53123 .32111 Mtetra
0 0 .34 r
.53123 .32111 .53263 .52252 .53448 .52959 .53348 .52497 Mtetra
0 0 .466 r
.53348 .52497 .53448 .52959 .53633 .53204 .53534 .53026 Mtetra
.401 .517 .86 r
.53534 .53026 .53633 .53204 .53817 .53228 .53718 .53075 Mtetra
.637 .671 .866 r
.53718 .53075 .53817 .53228 .54002 .53176 .53903 .53023 Mtetra
.711 .7 .838 r
.53903 .53023 .54002 .53176 .54186 .53069 .54087 .52924 Mtetra
.614 .676 .885 r
.54087 .52924 .54186 .53069 .5437 .52904 .54272 .52884 Mtetra
.551 .911 .962 r
.54272 .52884 .5437 .52904 .54553 .52649 .54456 .52818 Mtetra
.033 0 0 r
.54456 .52818 .54553 .52649 .54735 .52187 .54641 .52678 Mtetra
0 0 .123 r
.54641 .52678 .54735 .52187 .54774 .32064 .54822 .52128 Mtetra
0 0 .334 r
.54822 .52128 .54774 .32064 .54942 .31317 .54853 .31607 Mtetra
.777 .769 .262 r
.54853 .31607 .54942 .31317 .55113 .3101 .55022 .30975 Mtetra
.858 .931 .873 r
.55022 .30975 .55113 .3101 .55286 .30901 .55194 .30814 Mtetra
.665 .794 .943 r
.55194 .30814 .55286 .30901 .55459 .30856 .55368 .30752 Mtetra
.56 .715 .945 r
.55368 .30752 .55459 .30856 .55633 .30837 .55541 .3073 Mtetra
.656 .745 .916 r
.55541 .3073 .55633 .30837 .55806 .3076 .55715 .30673 Mtetra
.671 .796 .942 r
.55715 .30673 .55806 .3076 .5598 .30677 .55889 .30609 Mtetra
.647 .835 .973 r
.55889 .30609 .5598 .30677 .56154 .3062 .56063 .3055 Mtetra
.709 .847 .948 r
.56063 .3055 .56154 .3062 .56328 .30641 .56236 .3047 Mtetra
.646 .638 .828 r
.56236 .3047 .56328 .30641 .56505 .30751 .5641 .30413 Mtetra
.545 .461 .712 r
.5641 .30413 .56505 .30751 .56683 .31043 .56585 .30418 Mtetra
.258 .196 .594 r
.56585 .30418 .56683 .31043 .57137 .50996 .56765 .30765 Mtetra
0 0 .358 r
.56765 .30765 .57137 .50996 .57335 .51752 .57231 .51163 Mtetra
0 0 .48 r
.57231 .51163 .57335 .51752 .57526 .51989 .57427 .51788 Mtetra
.33 .446 .827 r
.57427 .51788 .57526 .51989 .57714 .52029 .57616 .51872 Mtetra
.622 .662 .868 r
.57616 .51872 .57714 .52029 .57901 .51983 .57803 .51827 Mtetra
.703 .696 .841 r
.57803 .51827 .57901 .51983 .58087 .51882 .5799 .51733 Mtetra
.625 .675 .878 r
.5799 .51733 .58087 .51882 .58273 .51724 .58177 .51687 Mtetra
.56 .886 .989 r
.58177 .51687 .58273 .51724 .58457 .51486 .58365 .51629 Mtetra
.022 0 0 r
.58365 .51629 .58457 .51486 .58638 .51083 .58551 .51505 Mtetra
0 0 .13 r
.58551 .51505 .58638 .51083 .58452 .31395 .58731 .51049 Mtetra
0 0 .344 r
.58731 .51049 .58452 .31395 .58605 .30186 .58524 .30559 Mtetra
.738 .711 .178 r
.58524 .30559 .58605 .30186 .58775 .29836 .58685 .29764 Mtetra
.876 .854 .817 r
.58685 .29764 .58775 .29836 .58949 .29693 .58858 .29566 Mtetra
.674 .716 .881 r
.58858 .29566 .58949 .29693 .59124 .29629 .59034 .29499 Mtetra
.576 .67 .904 r
.59034 .29499 .59124 .29629 .59301 .29592 .5921 .29475 Mtetra
.709 .748 .883 r
.5921 .29475 .59301 .29592 .59476 .2949 .59386 .29391 Mtetra
.722 .788 .904 r
.59386 .29391 .59476 .2949 .59651 .29387 .59561 .29303 Mtetra
.556 .764 .975 r
.59561 .29303 .59651 .29387 .59827 .29347 .59738 .29275 Mtetra
.732 .234 0 r
.59738 .29275 .59827 .29347 .60011 .29602 .59922 .2953 Mtetra
.973 .68 .407 r
.59922 .2953 .60011 .29602 .60693 .50029 .60596 .49853 Mtetra
.926 .562 .138 r
.60596 .49853 .60693 .50029 .60905 .50881 .60808 .50719 Mtetra
.115 .366 .828 r
.60808 .50719 .60905 .50881 .61098 .51001 .61001 .5084 Mtetra
.62 .657 .865 r
.61001 .5084 .61098 .51001 .61287 .50948 .61191 .50796 Mtetra
.711 .708 .845 r
.61191 .50796 .61287 .50948 .61475 .50819 .61379 .50697 Mtetra
.645 .732 .912 r
.61379 .50697 .61475 .50819 .61661 .50654 .61569 .5064 Mtetra
.42 .857 .926 r
.61569 .5064 .61661 .50654 .61846 .50435 .61759 .5059 Mtetra
.116 0 0 r
.61759 .5059 .61846 .50435 .62027 .50076 .61947 .50478 Mtetra
0 0 .167 r
.61947 .50478 .62027 .50076 .62166 .48287 .62127 .50086 Mtetra
.985 .705 .371 r
.62127 .50086 .62166 .48287 .61785 .29156 .61717 .29753 Mtetra
0 0 .011 r
.61717 .29753 .61785 .29156 .61953 .28772 .61866 .28717 Mtetra
.913 .882 .79 r
.61866 .28717 .61953 .28772 .62128 .28609 .62038 .28482 Mtetra
.685 .724 .88 r
.62038 .28482 .62128 .28609 .62305 .2854 .62216 .28409 Mtetra
.582 .673 .902 r
.62216 .28409 .62305 .2854 .62483 .28503 .62394 .28383 Mtetra
.688 .737 .888 r
.62394 .28383 .62483 .28503 .62661 .2842 .62572 .28309 Mtetra
.724 .766 .886 r
.62572 .28309 .62661 .2842 .62837 .28325 .62749 .28217 Mtetra
.598 .727 .935 r
.62749 .28217 .62837 .28325 .63016 .28289 .62928 .28181 Mtetra
0 0 .507 r
.62928 .28181 .63016 .28289 .63205 .28516 .63116 .28391 Mtetra
.974 .678 .392 r
.63116 .28391 .63205 .28516 .641 .48899 .63998 .48553 Mtetra
.856 .54 .014 r
.63998 .48553 .641 .48899 .64325 .49798 .64228 .49625 Mtetra
.037 .295 .787 r
.64228 .49625 .64325 .49798 .64523 .49932 .64427 .49779 Mtetra
.617 .669 .878 r
.64427 .49779 .64523 .49932 .64714 .4987 .64619 .49735 Mtetra
.716 .738 .869 r
.64619 .49735 .64714 .4987 .64904 .49755 .6481 .49638 Mtetra
.631 .739 .925 r
.6481 .49638 .64904 .49755 .65096 .49702 .65002 .49586 Mtetra
.554 .707 .942 r
.65002 .49586 .65096 .49702 .6529 .49694 .65195 .49564 Mtetra
.691 .737 .886 r
.65195 .49564 .6529 .49694 .65481 .49628 .65386 .49482 Mtetra
.883 .759 .72 r
.65386 .49482 .65481 .49628 .65664 .49328 .65568 .4916 Mtetra
.972 .707 .47 r
.65568 .4916 .65664 .49328 .658 .47884 .65669 .46825 Mtetra
.967 .674 .421 r
.65669 .46825 .658 .47884 .65171 .27769 .65083 .27638 Mtetra
.881 .767 .732 r
.65083 .27638 .65171 .27769 .65341 .27472 .65254 .27356 Mtetra
.699 .75 .892 r
.65254 .27356 .65341 .27472 .6552 .2739 .65433 .27276 Mtetra
.577 .706 .93 r
.65433 .27276 .6552 .2739 .65701 .27362 .65614 .27248 Mtetra
.663 .743 .909 r
.65614 .27248 .65701 .27362 .65881 .27298 .65794 .27186 Mtetra
.729 .769 .885 r
.65794 .27186 .65881 .27298 .6606 .272 .65973 .2709 Mtetra
.621 .736 .929 r
.65973 .2709 .6606 .272 .6624 .27155 .66154 .27045 Mtetra
0 .187 .703 r
.66154 .27045 .6624 .27155 .66431 .27324 .66344 .27201 Mtetra
.962 .629 .282 r
.66344 .27201 .66431 .27324 .67521 .47184 .66609 .29007 Mtetra
0 0 .381 r
.66609 .29007 .67521 .47184 .67784 .48661 .67688 .48478 Mtetra
0 .189 .72 r
.67688 .48478 .67784 .48661 .67989 .48842 .67894 .48681 Mtetra
.615 .659 .87 r
.67894 .48681 .67989 .48842 .68183 .48781 .68089 .48638 Mtetra
.725 .731 .856 r
.68089 .48638 .68183 .48781 .68374 .48657 .68281 .48532 Mtetra
.728 .761 .879 r
.68281 .48532 .68374 .48657 .68566 .48557 .68473 .48428 Mtetra
.666 .732 .899 r
.68473 .48428 .68566 .48557 .68761 .48516 .68667 .4836 Mtetra
.669 .69 .86 r
.68667 .4836 .68761 .48516 .68955 .48452 .68861 .48286 Mtetra
.694 .687 .839 r
.68861 .48286 .68955 .48452 .69144 .48285 .69053 .48194 Mtetra
.755 .837 .914 r
.69053 .48194 .69144 .48285 .69324 .4793 .69245 .48082 Mtetra
.139 0 0 r
.69245 .48082 .69324 .4793 .69492 .4737 .69438 .47974 Mtetra
.479 .191 .399 r
.69438 .47974 .69492 .4737 .69679 .47163 .69632 .47911 Mtetra
.517 .237 .428 r
.69632 .47911 .69679 .47163 .69902 .47644 .6983 .479 Mtetra
.473 .1 .249 r
.6983 .479 .69902 .47644 .70114 .4791 .70028 .47897 Mtetra
.041 .606 .783 r
.70028 .47897 .70114 .4791 .70319 .48029 .70227 .47903 Mtetra
.494 .662 .936 r
.70227 .47903 .70319 .48029 .70518 .48038 .70426 .47903 Mtetra
.659 .721 .895 r
.70426 .47903 .70518 .48038 .70713 .47963 .70621 .47837 Mtetra
.88 .791 .758 r
.70621 .47837 .70713 .47963 .70897 .47685 .70805 .47568 Mtetra
.979 .73 .486 r
.70805 .47568 .70897 .47685 .71017 .46282 .70923 .46112 Mtetra
.977 .681 .38 r
.70923 .46112 .71017 .46282 .70065 .26109 .6998 .25989 Mtetra
.912 .786 .708 r
.6998 .25989 .70065 .26109 .70233 .25776 .70147 .25658 Mtetra
.711 .757 .888 r
.70147 .25658 .70233 .25776 .70414 .25688 .70329 .2557 Mtetra
.59 .709 .926 r
.70329 .2557 .70414 .25688 .70599 .25655 .70513 .25538 Mtetra
.625 .725 .919 r
.70513 .25538 .70599 .25655 .70783 .25608 .70697 .25491 Mtetra
.733 .766 .879 r
.70697 .25491 .70783 .25608 .70964 .25507 .70878 .25391 Mtetra
.642 .733 .915 r
.70878 .25391 .70964 .25507 .71147 .25453 .71062 .25337 Mtetra
.067 .402 .857 r
.71062 .25337 .71147 .25453 .71341 .25555 .71256 .25439 Mtetra
.923 .55 .135 r
.71256 .25439 .71341 .25555 .71585 .26466 .715 .2636 Mtetra
.975 .671 .352 r
.715 .2636 .71585 .26466 .7305 .46912 .72961 .46804 Mtetra
.614 .148 0 r
.72961 .46804 .7305 .46912 .7327 .47211 .7318 .47101 Mtetra
.417 .656 .958 r
.7318 .47101 .7327 .47211 .73472 .47227 .73383 .47116 Mtetra
.714 .789 .91 r
.73383 .47116 .73472 .47227 .73668 .47132 .73578 .47023 Mtetra
.893 .818 .767 r
.73578 .47023 .73668 .47132 .73852 .46855 .73763 .46756 Mtetra
.982 .757 .524 r
.73763 .46756 .73852 .46855 .73979 .4572 .73902 .45787 Mtetra
.978 .68 .36 r
.73902 .45787 .73979 .4572 .72821 .25169 .72741 .25116 Mtetra
.971 .857 .669 r
.72741 .25116 .72821 .25169 .72986 .24805 .72904 .24727 Mtetra
.722 .851 .943 r
.72904 .24727 .72986 .24805 .73169 .24726 .73087 .24637 Mtetra
.551 .757 .973 r
.73087 .24637 .73169 .24726 .73357 .2471 .73274 .24609 Mtetra
.519 .713 .96 r
.73274 .24609 .73357 .2471 .73546 .24707 .73463 .24595 Mtetra
.653 .749 .92 r
.73463 .24595 .73546 .24707 .73732 .24651 .73648 .24535 Mtetra
.659 .745 .914 r
.73648 .24535 .73732 .24651 .73917 .24589 .73833 .24474 Mtetra
.697 .76 .9 r
.73833 .24474 .73917 .24589 .74101 .24508 .74018 .24393 Mtetra
.755 .78 .873 r
.74018 .24393 .74101 .24508 .74283 .24395 .74199 .24279 Mtetra
.671 .748 .909 r
.74199 .24279 .74283 .24395 .74468 .24329 .74385 .24212 Mtetra
.235 .514 .91 r
.74385 .24212 .74468 .24329 .74663 .24396 .7458 .24279 Mtetra
.894 .507 .061 r
.7458 .24279 .74663 .24396 .7491 .25175 .74827 .25062 Mtetra
.975 .667 .334 r
.74827 .25062 .7491 .25175 .76617 .45779 .76529 .45667 Mtetra
.641 .185 0 r
.76529 .45667 .76617 .45779 .76846 .46115 .76758 .46003 Mtetra
.39 .636 .953 r
.76758 .46003 .76846 .46115 .77052 .46139 .76964 .46027 Mtetra
.694 .781 .918 r
.76964 .46027 .77052 .46139 .77251 .46056 .77163 .45943 Mtetra
.873 .82 .793 r
.77163 .45943 .77251 .46056 .77438 .45822 .7735 .45709 Mtetra
.978 .767 .552 r
.7735 .45709 .77438 .45822 .77583 .45037 .77495 .44923 Mtetra
.977 .675 .347 r
.77495 .44923 .77583 .45037 .76175 .24169 .76092 .2405 Mtetra
.95 .784 .641 r
.76092 .2405 .76175 .24169 .7633 .23705 .76248 .23586 Mtetra
.747 .772 .873 r
.76248 .23586 .7633 .23705 .76514 .23595 .76431 .23475 Mtetra
.621 .723 .919 r
.76431 .23475 .76514 .23595 .76702 .23549 .7662 .2343 Mtetra
.59 .708 .925 r
.7662 .2343 .76702 .23549 .76892 .23516 .76809 .23396 Mtetra
.749 .772 .872 r
.76809 .23396 .76892 .23516 .77075 .23404 .76993 .23284 Mtetra
.674 .745 .904 r
.76993 .23284 .77075 .23404 .77262 .23335 .77179 .23214 Mtetra
.374 .592 .93 r
.77179 .23214 .77262 .23335 .77457 .2337 .77375 .2325 Mtetra
.812 .401 0 r
.77375 .2325 .77457 .2337 .77696 .23933 .77614 .23808 Mtetra
.973 .663 .318 r
.77614 .23808 .77696 .23933 .79615 .44727 .79528 .44608 Mtetra
.699 .26 0 r
.79528 .44608 .79615 .44727 .79856 .45138 .79769 .45021 Mtetra
.503 .69 .952 r
.79769 .45021 .79856 .45138 .80063 .45129 .79976 .45014 Mtetra
.689 .776 .918 r
.79976 .45014 .80063 .45129 .80263 .45048 .80177 .44931 Mtetra
.728 .788 .9 r
.80177 .44931 .80263 .45048 .80463 .4495 .80376 .44828 Mtetra
.497 .675 .944 r
.80376 .44828 .80463 .4495 .80671 .44961 .80583 .44824 Mtetra
.623 .708 .907 r
.80583 .44824 .80671 .44961 .80876 .44925 .80787 .44774 Mtetra
.78 .749 .825 r
.80787 .44774 .80876 .44925 .81072 .44784 .80982 .44618 Mtetra
.959 .749 .577 r
.80982 .44618 .81072 .44784 .81223 .44134 .81128 .43912 Mtetra
.976 .67 .332 r
.81128 .43912 .81223 .44134 .79568 .23118 .79482 .22949 Mtetra
.936 .745 .619 r
.79482 .22949 .79568 .23118 .79712 .2255 .79631 .22424 Mtetra
.753 .765 .863 r
.79631 .22424 .79712 .2255 .79896 .2243 .79815 .22307 Mtetra
.626 .721 .915 r
.79815 .22307 .79896 .2243 .80087 .22381 .80006 .22259 Mtetra
.556 .689 .928 r
.80006 .22259 .80087 .22381 .8028 .22361 .80199 .22238 Mtetra
.748 .769 .87 r
.80199 .22238 .8028 .22361 .80465 .22248 .80384 .22125 Mtetra
.68 .745 .901 r
.80384 .22125 .80465 .22248 .80654 .22174 .80573 .22052 Mtetra
.459 .638 .933 r
.80573 .22052 .80654 .22174 .8085 .22185 .8077 .22063 Mtetra
.769 .355 0 r
.8077 .22063 .8085 .22185 .81096 .22709 .81015 .22587 Mtetra
.971 .657 .298 r
.81015 .22587 .81096 .22709 .83263 .43582 .83179 .43466 Mtetra
.722 .288 0 r
.83179 .43466 .83263 .43582 .83517 .44042 .83432 .43926 Mtetra
.309 .581 .938 r
.83432 .43926 .83517 .44042 .83732 .4409 .83648 .43974 Mtetra
.651 .764 .932 r
.83648 .43974 .83732 .4409 .83937 .44025 .83853 .4391 Mtetra
.831 .821 .84 r
.83853 .4391 .83937 .44025 .84131 .43844 .84046 .43729 Mtetra
.976 .789 .587 r
.84046 .43729 .84131 .43844 .84282 .43229 .84198 .43114 Mtetra
.974 .667 .312 r
.84198 .43114 .84282 .43229 .82426 .22209 .82346 .2209 Mtetra
.975 .776 .573 r
.82346 .2209 .82426 .22209 .82562 .21587 .82482 .21467 Mtetra
.763 .76 .85 r
.21087 .42538 .21192 .42634 .2135 .42525 .21246 .42429 Mtetra
.622 .734 .927 r
.21246 .42429 .2135 .42525 .21502 .42487 .21397 .42391 Mtetra
.476 .683 .957 r
.21397 .42391 .21502 .42487 .2165 .42485 .21545 .42391 Mtetra
.662 .748 .914 r
.21545 .42391 .2165 .42485 .21803 .42427 .21698 .42339 Mtetra
.675 .762 .917 r
.21698 .42339 .21803 .42427 .21957 .42369 .21852 .42281 Mtetra
.686 .768 .913 r
.21852 .42281 .21957 .42369 .2211 .42313 .22006 .42219 Mtetra
.78 .766 .841 r
.22006 .42219 .2211 .42313 .22267 .42226 .22165 .42097 Mtetra
.715 .7 .835 r
.22165 .42097 .22267 .42226 .2242 .42172 .22322 .4201 Mtetra
.581 .604 .84 r
.22322 .4201 .2242 .42172 .22567 .42187 .22472 .41992 Mtetra
.871 .494 .012 r
.22472 .41992 .22567 .42187 .22675 .42638 .22587 .42358 Mtetra
.941 .686 .522 r
.22587 .42358 .22675 .42638 .21014 .62458 .20913 .62247 Mtetra
.958 .617 .257 r
.20913 .62247 .21014 .62458 .21128 .62947 .21016 .62858 Mtetra
0 .312 .76 r
.21016 .62858 .21128 .62947 .2128 .63024 .21167 .62942 Mtetra
.617 .778 .958 r
.21167 .62942 .2128 .63024 .21442 .62982 .21329 .629 Mtetra
.813 .797 .838 r
.21329 .629 .21442 .62982 .21615 .62832 .21502 .62748 Mtetra
.912 .746 .662 r
.21502 .62748 .21615 .62832 .21823 .62279 .21709 .62212 Mtetra
.939 .687 .53 r
.21709 .62212 .21823 .62279 .23754 .42264 .23646 .42205 Mtetra
.926 .747 .641 r
.23646 .42205 .23754 .42264 .23956 .41668 .23851 .41585 Mtetra
.8 .788 .842 r
.23851 .41585 .23956 .41668 .24118 .41535 .24013 .41451 Mtetra
.627 .764 .945 r
.24013 .41451 .24118 .41535 .24271 .41493 .24166 .4141 Mtetra
.447 .703 .976 r
.24166 .4141 .24271 .41493 .24421 .4149 .24316 .4141 Mtetra
.611 .769 .955 r
.24316 .4141 .24421 .4149 .24575 .41452 .24469 .41373 Mtetra
.633 .778 .951 r
.24469 .41373 .24575 .41452 .24729 .41406 .24623 .41329 Mtetra
.638 .782 .951 r
.24623 .41329 .24729 .41406 .24883 .4136 .24777 .41283 Mtetra
.65 .788 .948 r
.24777 .41283 .24883 .4136 .25037 .4131 .24932 .41233 Mtetra
.659 .791 .945 r
.24932 .41233 .25037 .4131 .25192 .41257 .25087 .4118 Mtetra
.666 .792 .941 r
.25087 .4118 .25192 .41257 .25347 .41202 .25242 .41125 Mtetra
.67 .791 .939 r
.25242 .41125 .25347 .41202 .25503 .41142 .25398 .41068 Mtetra
.676 .8 .941 r
.25398 .41068 .25503 .41142 .25659 .41083 .25554 .41009 Mtetra
.686 .803 .937 r
.25554 .41009 .25659 .41083 .25815 .41027 .2571 .40946 Mtetra
.707 .79 .916 r
.2571 .40946 .25815 .41027 .25969 .40988 .25867 .40875 Mtetra
.701 .724 .868 r
.25867 .40875 .25969 .40988 .26123 .40955 .26024 .40801 Mtetra
.682 .658 .82 r
.26024 .40801 .26123 .40955 .26277 .4092 .26181 .40729 Mtetra
.657 .607 .787 r
.26181 .40729 .26277 .4092 .26432 .40867 .26338 .40665 Mtetra
.647 .592 .779 r
.26338 .40665 .26432 .40867 .26589 .40806 .26494 .40605 Mtetra
.644 .592 .782 r
.26494 .40605 .26589 .40806 .26746 .40743 .2665 .40548 Mtetra
.68 .615 .776 r
.2665 .40548 .26746 .40743 .26905 .40646 .26809 .40465 Mtetra
.667 .622 .794 r
.26809 .40465 .26905 .40646 .27063 .40571 .26966 .40395 Mtetra
.594 .594 .821 r
.26966 .40395 .27063 .40571 .27216 .40561 .2712 .4037 Mtetra
0 .092 .65 r
.2712 .4037 .27216 .40561 .27342 .40886 .27259 .4054 Mtetra
.884 .587 .074 r
.27259 .4054 .27342 .40886 .25958 .60757 .27362 .41178 Mtetra
0 0 .192 r
.27362 .41178 .25958 .60757 .26071 .6139 .26 .60794 Mtetra
.413 .305 .621 r
.26 .60794 .26071 .6139 .26227 .61472 .2615 .60951 Mtetra
.595 .447 .65 r
.2615 .60951 .26227 .61472 .26393 .61425 .26317 .60889 Mtetra
.615 .459 .647 r
.26317 .60889 .26393 .61425 .26563 .61333 .26487 .60794 Mtetra
.468 .354 .641 r
.26487 .60794 .26563 .61333 .2673 .61272 .26642 .60886 Mtetra
.38 .335 .682 r
.26642 .60886 .2673 .61272 .26897 .61225 .26796 .61007 Mtetra
.343 .423 .8 r
.26796 .61007 .26897 .61225 .27064 .61174 .26953 .61084 Mtetra
.472 .711 .974 r
.26953 .61084 .27064 .61174 .27232 .61106 .27117 .61079 Mtetra
.527 .876 .987 r
.27117 .61079 .27232 .61106 .274 .6103 .27284 .61034 Mtetra
.493 .899 .918 r
.27284 .61034 .274 .6103 .27569 .60954 .27452 .60972 Mtetra
0 0 0 r
.27452 .60972 .27569 .60954 .27734 .60934 .27616 .60956 Mtetra
.27616 .60956 .27734 .60934 .279 .6091 .27782 .60929 Mtetra
.598 .95 .89 r
.27782 .60929 .279 .6091 .2807 .60822 .27953 .60839 Mtetra
.957 .859 .701 r
.27953 .60839 .2807 .60822 .28263 .60405 .28145 .60441 Mtetra
.947 .69 .515 r
.28145 .60441 .28263 .60405 .29831 .40418 .29722 .40415 Mtetra
.955 .756 .595 r
.29722 .40415 .29831 .40418 .30039 .39639 .2994 .39507 Mtetra
.817 .722 .76 r
.2994 .39507 .30039 .39639 .30208 .39435 .30108 .39305 Mtetra
.66 .687 .865 r
.30108 .39305 .30208 .39435 .30367 .39365 .30266 .3925 Mtetra
.539 .669 .921 r
.30266 .3925 .30367 .39365 .30523 .3934 .30422 .39239 Mtetra
.708 .752 .887 r
.30422 .39239 .30523 .3934 .30681 .39282 .30581 .39163 Mtetra
.727 .725 .849 r
.30581 .39163 .30681 .39282 .3084 .39223 .30742 .39071 Mtetra
.619 .638 .848 r
.30742 .39071 .3084 .39223 .30995 .39219 .30899 .39034 Mtetra
0 0 .522 r
.30899 .39034 .30995 .39219 .31134 .39465 .3104 .39244 Mtetra
.95 .686 .501 r
.3104 .39244 .31134 .39465 .2999 .5918 .299 .58797 Mtetra
.976 .68 .308 r
.299 .58797 .2999 .5918 .30095 .60085 .29985 .60019 Mtetra
.607 .054 0 r
.29985 .60019 .30095 .60085 .30252 .60225 .30141 .60161 Mtetra
.613 .825 .981 r
.30141 .60161 .30252 .60225 .30419 .60195 .3031 .60113 Mtetra
.751 .81 .9 r
.3031 .60113 .30419 .60195 .3059 .60112 .30482 .60013 Mtetra
.591 .738 .946 r
.30482 .60013 .3059 .60112 .3076 .60061 .3065 .5998 Mtetra
.448 .724 .984 r
.3065 .5998 .3076 .60061 .30928 .60019 .30817 .59976 Mtetra
.651 .884 .983 r
.30817 .59976 .30928 .60019 .31101 .59917 .30987 .59911 Mtetra
.942 .867 .736 r
.30987 .59911 .31101 .59917 .3129 .59554 .31174 .59583 Mtetra
.95 .691 .508 r
.31174 .59583 .3129 .59554 .32673 .3978 .32547 .40071 Mtetra
.996 .793 .513 r
.32547 .40071 .32673 .3978 .32894 .38723 .32795 .38589 Mtetra
.836 .724 .741 r
.32795 .38589 .32894 .38723 .33064 .3849 .32966 .38349 Mtetra
.652 .668 .853 r
.32966 .38349 .33064 .3849 .33225 .38426 .33126 .38296 Mtetra
.512 .628 .902 r
.33126 .38296 .33225 .38426 .33382 .3841 .33283 .38296 Mtetra
.552 .679 .922 r
.33283 .38296 .33382 .3841 .33541 .38379 .3344 .38281 Mtetra
.644 .744 .922 r
.3344 .38281 .33541 .38379 .33701 .38324 .336 .38233 Mtetra
.66 .765 .928 r
.336 .38233 .33701 .38324 .33861 .38271 .3376 .38179 Mtetra
.686 .77 .915 r
.3376 .38179 .33861 .38271 .34021 .38227 .33921 .38114 Mtetra
.698 .731 .876 r
.33921 .38114 .34021 .38227 .3418 .38191 .34082 .38041 Mtetra
.685 .669 .829 r
.34082 .38041 .3418 .38191 .34339 .38154 .34244 .37967 Mtetra
.662 .617 .793 r
.34244 .37967 .34339 .38154 .345 .38105 .34405 .37899 Mtetra
.648 .593 .779 r
.34405 .37899 .345 .38105 .34661 .38043 .34566 .37836 Mtetra
.645 .591 .78 r
.34566 .37836 .34661 .38043 .34822 .37977 .34728 .37776 Mtetra
.645 .596 .785 r
.34728 .37776 .34822 .37977 .34983 .37914 .34889 .37717 Mtetra
.646 .601 .789 r
.34889 .37717 .34983 .37914 .35145 .37855 .3505 .37659 Mtetra
.644 .601 .79 r
.3505 .37659 .35145 .37855 .35306 .37796 .35211 .37601 Mtetra
.643 .601 .791 r
.35211 .37601 .35306 .37796 .35467 .3774 .35372 .37544 Mtetra
.642 .6 .792 r
.35372 .37544 .35467 .3774 .35628 .37684 .35534 .37488 Mtetra
.641 .599 .791 r
.35534 .37488 .35628 .37684 .3579 .37629 .35695 .37433 Mtetra
.641 .598 .791 r
.35695 .37433 .3579 .37629 .35951 .37578 .35856 .37377 Mtetra
.639 .594 .788 r
.35856 .37377 .35951 .37578 .36112 .37528 .36018 .37323 Mtetra
.634 .587 .784 r
.36018 .37323 .36112 .37528 .36274 .37475 .36179 .3727 Mtetra
.625 .583 .787 r
.36179 .3727 .36274 .37475 .36436 .37409 .36341 .37224 Mtetra
.619 .6 .809 r
.36341 .37224 .36436 .37409 .36599 .37331 .36502 .37184 Mtetra
.623 .651 .857 r
.36502 .37184 .36599 .37331 .36762 .37253 .36663 .37144 Mtetra
.636 .722 .91 r
.36663 .37144 .36762 .37253 .36924 .37186 .36824 .37099 Mtetra
.652 .775 .939 r
.36824 .37099 .36924 .37186 .37086 .37132 .36986 .37047 Mtetra
.66 .781 .938 r
.36986 .37047 .37086 .37132 .37248 .37083 .37149 .36992 Mtetra
.662 .77 .929 r
.37149 .36992 .37248 .37083 .3741 .37033 .37311 .36937 Mtetra
.663 .757 .92 r
.37311 .36937 .3741 .37033 .37573 .36981 .37474 .36881 Mtetra
.671 .751 .911 r
.37474 .36881 .37573 .36981 .37735 .36927 .37636 .36821 Mtetra
.7 .748 .889 r
.37636 .36821 .37735 .36927 .37898 .3687 .378 .36748 Mtetra
.714 .722 .857 r
.378 .36748 .37898 .3687 .38061 .36809 .37964 .36663 Mtetra
.678 .674 .839 r
.37964 .36663 .38061 .36809 .38224 .36746 .38127 .36593 Mtetra
.575 .621 .861 r
.38127 .36593 .38224 .36746 .38387 .36684 .38289 .36575 Mtetra
.175 .496 .906 r
.38289 .36575 .38387 .36684 .3855 .36622 .38447 .36634 Mtetra
.62 .073 0 r
.38447 .36634 .3855 .36622 .38714 .3656 .38603 .36736 Mtetra
.541 .138 .227 r
.38603 .36736 .38714 .3656 .38878 .3648 .38762 .36779 Mtetra
.326 0 .238 r
.38762 .36779 .38878 .3648 .39043 .36386 .38928 .36676 Mtetra
.397 .055 .264 r
.38928 .36676 .39043 .36386 .39206 .36336 .39091 .36613 Mtetra
.688 .343 .384 r
.39091 .36613 .39206 .36336 .39363 .36431 .39244 .36823 Mtetra
.95 .678 .486 r
.39244 .36823 .39363 .36431 .39497 .371 .38591 .56703 Mtetra
.549 .323 .524 r
.38591 .56703 .39497 .371 .38854 .57145 .38738 .57301 Mtetra
.681 .278 .275 r
.38738 .57301 .38854 .57145 .39013 .57464 .38905 .57457 Mtetra
.384 .839 .91 r
.38905 .57457 .39013 .57464 .39185 .57472 .39079 .57414 Mtetra
.726 .872 .949 r
.39079 .57414 .39185 .57472 .3936 .57415 .39255 .57325 Mtetra
.71 .795 .917 r
.39255 .57325 .3936 .57415 .39536 .57343 .39431 .57243 Mtetra
.576 .736 .951 r
.39431 .57243 .39536 .57343 .39711 .57291 .39605 .57213 Mtetra
.604 .798 .974 r
.39605 .57213 .39711 .57291 .39886 .57234 .3978 .5717 Mtetra
.735 .859 .939 r
.3978 .5717 .39886 .57234 .40061 .57175 .39957 .57077 Mtetra
.833 .791 .811 r
.39957 .57077 .40061 .57175 .40237 .5712 .40137 .5689 Mtetra
.782 .65 .717 r
.40137 .5689 .40237 .5712 .40412 .57064 .40319 .56654 Mtetra
.694 .536 .669 r
.40319 .56654 .40412 .57064 .40587 .57026 .40499 .56456 Mtetra
.554 .412 .643 r
.40499 .56456 .40587 .57026 .40761 .57014 .40673 .5645 Mtetra
.58 .432 .644 r
.40673 .5645 .40761 .57014 .40937 .56955 .40849 .56405 Mtetra
.708 .522 .635 r
.40849 .56405 .40937 .56955 .41118 .56752 .41033 .56094 Mtetra
.952 .683 .49 r
.41033 .56094 .41118 .56752 .41319 .55937 .41875 .36055 Mtetra
.552 .33 .531 r
.41875 .36055 .41319 .55937 .4215 .35743 .42061 .35395 Mtetra
.743 .576 .668 r
.42061 .35395 .4215 .35743 .42327 .35325 .42233 .35135 Mtetra
.664 .619 .794 r
.42233 .35135 .42327 .35325 .42494 .35209 .42398 .35064 Mtetra
.597 .646 .87 r
.42398 .35064 .42494 .35209 .4266 .35151 .42563 .35036 Mtetra
.587 .696 .917 r
.42563 .35036 .4266 .35151 .42825 .35112 .42728 .35008 Mtetra
.709 .759 .892 r
.42728 .35008 .42825 .35112 .4299 .35052 .42894 .3493 Mtetra
.682 .715 .874 r
.42894 .3493 .4299 .35052 .43156 .34998 .4306 .34862 Mtetra
.602 .663 .882 r
.4306 .34862 .43156 .34998 .43322 .34944 .43226 .34831 Mtetra
.247 .528 .917 r
.43226 .34831 .43322 .34944 .43488 .34888 .43388 .34883 Mtetra
.558 0 0 r
.43388 .34883 .43488 .34888 .43654 .34833 .4355 .34978 Mtetra
.599 .177 .213 r
.4355 .34978 .43654 .34833 .43821 .34766 .43713 .35059 Mtetra
.344 .008 .243 r
.43713 .35059 .43821 .34766 .43988 .34672 .43881 .34965 Mtetra
.394 .053 .265 r
.43881 .34965 .43988 .34672 .44154 .34616 .44048 .34898 Mtetra
.613 .262 .35 r
.44048 .34898 .44154 .34616 .44318 .34666 .4421 .35009 Mtetra
.956 .679 .471 r
.4421 .35009 .44318 .34666 .4447 .3519 .43868 .54861 Mtetra
.552 .325 .524 r
.43868 .54861 .4447 .3519 .44135 .55424 .44024 .55629 Mtetra
.709 .331 .33 r
.44024 .55629 .44135 .55424 .44301 .55836 .44196 .55845 Mtetra
.078 .638 .712 r
.44196 .55845 .44301 .55836 .44478 .55836 .44373 .55827 Mtetra
.542 .915 .945 r
.44373 .55827 .44478 .55836 .44657 .55763 .44552 .5576 Mtetra
.593 .94 .933 r
.44552 .5576 .44657 .55763 .44836 .5566 .44731 .55677 Mtetra
.219 .74 .752 r
.44731 .55677 .44836 .5566 .45015 .55599 .44909 .55635 Mtetra
0 0 0 r
.44909 .55635 .45015 .55599 .45193 .5554 .45087 .5559 Mtetra
.45087 .5559 .45193 .5554 .45372 .55489 .45266 .55539 Mtetra
.45266 .55539 .45372 .55489 .4555 .55457 .45445 .5547 Mtetra
.457 .887 .858 r
.45445 .5547 .4555 .55457 .45729 .55427 .45625 .55397 Mtetra
.626 .915 .98 r
.45625 .55397 .45729 .55427 .45907 .55391 .45804 .55326 Mtetra
.642 .843 .977 r
.45804 .55326 .45907 .55391 .46086 .55337 .45984 .55266 Mtetra
.638 .828 .974 r
.45984 .55266 .46086 .55337 .46266 .55277 .46163 .55208 Mtetra
.631 .831 .978 r
.46163 .55208 .46266 .55277 .46445 .55216 .46342 .55153 Mtetra
.628 .844 .983 r
.46342 .55153 .46445 .55216 .46625 .55159 .46522 .55096 Mtetra
.625 .844 .984 r
.46522 .55096 .46625 .55159 .46804 .55102 .46702 .5504 Mtetra
.623 .845 .984 r
.46702 .5504 .46804 .55102 .46984 .55046 .46882 .54984 Mtetra
.622 .845 .985 r
.46882 .54984 .46984 .55046 .47164 .5499 .47062 .54928 Mtetra
.62 .845 .985 r
.47062 .54928 .47164 .5499 .47344 .54935 .47242 .54873 Mtetra
.619 .844 .985 r
.47242 .54873 .47344 .54935 .47524 .54881 .47422 .54818 Mtetra
.619 .843 .985 r
.47422 .54818 .47524 .54881 .47704 .54826 .47602 .54763 Mtetra
.618 .842 .985 r
.47602 .54763 .47704 .54826 .47884 .54773 .47782 .54709 Mtetra
.618 .84 .985 r
.47782 .54709 .47884 .54773 .48065 .5472 .47963 .54655 Mtetra
.618 .837 .984 r
.47963 .54655 .48065 .5472 .48245 .54671 .48144 .54601 Mtetra
.622 .826 .979 r
.48144 .54601 .48245 .54671 .48426 .5462 .48324 .54548 Mtetra
.62 .821 .978 r
.48324 .54548 .48426 .5462 .48607 .54563 .48505 .54496 Mtetra
.606 .828 .985 r
.48505 .54496 .48607 .54563 .48788 .54489 .48686 .54446 Mtetra
.557 .869 .995 r
.48686 .54446 .48788 .54489 .48969 .5441 .48867 .54396 Mtetra
.445 .867 .941 r
.48867 .54396 .48969 .5441 .4915 .54335 .49048 .54347 Mtetra
0 0 0 r
.49048 .54347 .4915 .54335 .49331 .54332 .49229 .54331 Mtetra
.348 .824 .872 r
.49229 .54331 .49331 .54332 .49512 .5429 .49411 .54285 Mtetra
.682 .968 .929 r
.49411 .54285 .49512 .5429 .49695 .54167 .49593 .54181 Mtetra
.969 .907 .7 r
.49593 .54181 .49695 .54167 .49881 .53503 .49777 .53818 Mtetra
.963 .825 .398 r
.49777 .53818 .49881 .53503 .5021 .33074 .49966 .52791 Mtetra
0 0 .316 r
.49966 .52791 .5021 .33074 .50383 .32538 .50287 .32835 Mtetra
0 0 .021 r
.50287 .32835 .50383 .32538 .50554 .32418 .50459 .32514 Mtetra
.562 .849 .52 r
.50459 .32514 .50554 .32418 .50724 .32367 .5063 .32328 Mtetra
.802 .923 .917 r
.5063 .32328 .50724 .32367 .50895 .32351 .50801 .32204 Mtetra
.687 .684 .842 r
.50801 .32204 .50895 .32351 .51066 .32297 .50972 .32127 Mtetra
.64 .634 .828 r
.50972 .32127 .51066 .32297 .51236 .32242 .51143 .32074 Mtetra
.616 .626 .837 r
.51143 .32074 .51236 .32242 .51407 .32186 .51314 .32035 Mtetra
.628 .654 .856 r
.51314 .32035 .51407 .32186 .51578 .32122 .51485 .3199 Mtetra
.632 .687 .883 r
.51485 .3199 .51578 .32122 .51749 .32058 .51656 .31944 Mtetra
.644 .726 .908 r
.51656 .31944 .51749 .32058 .51921 .31998 .51827 .31894 Mtetra
.69 .761 .906 r
.51827 .31894 .51921 .31998 .52092 .31954 .51999 .31822 Mtetra
.692 .71 .862 r
.51999 .31822 .52092 .31954 .52263 .31916 .5217 .31746 Mtetra
.677 .652 .818 r
.5217 .31746 .52263 .31916 .52435 .31876 .52342 .3167 Mtetra
.688 .62 .774 r
.52342 .3167 .52435 .31876 .52607 .31774 .52514 .31573 Mtetra
.659 .611 .789 r
.52514 .31573 .52607 .31774 .52778 .31698 .52686 .31502 Mtetra
.582 .577 .812 r
.52686 .31502 .52778 .31698 .5295 .3169 .52857 .3148 Mtetra
0 .182 .704 r
.52857 .3148 .5295 .3169 .53123 .32111 .5303 .3167 Mtetra
0 0 .23 r
.5303 .3167 .53123 .32111 .53348 .52497 .53204 .32402 Mtetra
0 0 .345 r
.53204 .32402 .53348 .52497 .53534 .53026 .53434 .52448 Mtetra
.307 .243 .62 r
.53434 .52448 .53534 .53026 .53718 .53075 .53619 .5272 Mtetra
.428 .389 .713 r
.53619 .5272 .53718 .53075 .53903 .53023 .53804 .52815 Mtetra
.492 .531 .825 r
.53804 .52815 .53903 .53023 .54087 .52924 .53988 .52838 Mtetra
.418 .706 .982 r
.53988 .52838 .54087 .52924 .54272 .52884 .54173 .52841 Mtetra
.524 .858 .995 r
.54173 .52841 .54272 .52884 .54456 .52818 .54358 .52796 Mtetra
.722 .959 .945 r
.54358 .52796 .54456 .52818 .54641 .52678 .54543 .52688 Mtetra
.957 .933 .726 r
.54543 .52688 .54641 .52678 .54822 .52128 .54726 .52372 Mtetra
.937 .84 .397 r
.54726 .52372 .54822 .52128 .54853 .31607 .54906 .51591 Mtetra
0 0 .338 r
.54906 .51591 .54853 .31607 .55022 .30975 .54933 .31334 Mtetra
0 0 .082 r
.54933 .31334 .55022 .30975 .55194 .30814 .55104 .30937 Mtetra
0 0 0 r
.55104 .30937 .55194 .30814 .55368 .30752 .55277 .30735 Mtetra
.799 .97 .91 r
.55277 .30735 .55368 .30752 .55541 .3073 .5545 .30603 Mtetra
.691 .721 .873 r
.5545 .30603 .55541 .3073 .55715 .30673 .55623 .30527 Mtetra
.634 .668 .866 r
.55623 .30527 .55715 .30673 .55889 .30609 .55797 .3048 Mtetra
.61 .686 .896 r
.55797 .3048 .55889 .30609 .56063 .3055 .55971 .30443 Mtetra
.731 .769 .884 r
.55971 .30443 .56063 .3055 .56236 .3047 .56145 .30349 Mtetra
.715 .74 .871 r
.56145 .30349 .56236 .3047 .5641 .30413 .56318 .3026 Mtetra
.624 .654 .858 r
.56318 .3026 .5641 .30413 .56585 .30418 .56493 .30217 Mtetra
.116 .292 .766 r
.56493 .30217 .56585 .30418 .56765 .30765 .5667 .30366 Mtetra
0 0 .386 r
.5667 .30366 .56765 .30765 .57231 .51163 .56853 .30928 Mtetra
0 0 .361 r
.56853 .30928 .57231 .51163 .57427 .51788 .57322 .5114 Mtetra
.289 .221 .604 r
.57322 .5114 .57427 .51788 .57616 .51872 .57514 .5147 Mtetra
.444 .381 .693 r
.57514 .5147 .57616 .51872 .57803 .51827 .57704 .51567 Mtetra
.508 .494 .776 r
.57704 .51567 .57803 .51827 .5799 .51733 .57892 .51591 Mtetra
.427 .591 .911 r
.57892 .51591 .5799 .51733 .58177 .51687 .58081 .51618 Mtetra
.463 .773 .997 r
.58081 .51618 .58177 .51687 .58365 .51629 .58269 .516 Mtetra
.695 .944 .96 r
.58269 .516 .58365 .51629 .58551 .51505 .58456 .51503 Mtetra
.978 .884 .666 r
.58456 .51503 .58551 .51505 .58731 .51049 .58637 .51084 Mtetra
.974 .69 .425 r
.58637 .51084 .58731 .51049 .58524 .30559 .58436 .3057 Mtetra
.991 .782 .525 r
.58436 .3057 .58524 .30559 .58685 .29764 .58594 .29617 Mtetra
.819 .732 .769 r
.58594 .29617 .58685 .29764 .58858 .29566 .58767 .29417 Mtetra
.646 .671 .859 r
.58767 .29417 .58858 .29566 .59034 .29499 .58943 .29362 Mtetra
.531 .638 .901 r
.58943 .29362 .59034 .29499 .5921 .29475 .5912 .29356 Mtetra
.671 .731 .895 r
.5912 .29356 .5921 .29475 .59386 .29391 .59296 .29291 Mtetra
.704 .78 .911 r
.59296 .29291 .59386 .29391 .59561 .29303 .59472 .29212 Mtetra
.593 .762 .959 r
.59472 .29212 .59561 .29303 .59738 .29275 .59648 .29175 Mtetra
0 .208 .709 r
.59648 .29175 .59738 .29275 .59922 .2953 .59829 .29311 Mtetra
.779 .423 0 r
.59829 .29311 .59922 .2953 .60596 .49853 .60021 .29868 Mtetra
0 0 .371 r
.60021 .29868 .60596 .49853 .60808 .50719 .60698 .50067 Mtetra
.276 .212 .603 r
.60698 .50067 .60808 .50719 .61001 .5084 .60898 .50418 Mtetra
.448 .379 .687 r
.60898 .50418 .61001 .5084 .61191 .50796 .61091 .50518 Mtetra
.508 .483 .763 r
.61091 .50518 .61191 .50796 .61379 .50697 .61282 .50545 Mtetra
.449 .586 .897 r
.61282 .50545 .61379 .50697 .61569 .5064 .61474 .50569 Mtetra
.436 .754 .995 r
.61474 .50569 .61569 .5064 .61759 .5059 .61665 .50558 Mtetra
.651 .931 .971 r
.61665 .50558 .61759 .5059 .61947 .50478 .61854 .50473 Mtetra
.967 .916 .705 r
.61854 .50473 .61947 .50478 .62127 .50086 .62036 .50127 Mtetra
.985 .724 .443 r
.62036 .50127 .62127 .50086 .61717 .29753 .62147 .4737 Mtetra
0 0 .35 r
.62147 .4737 .61717 .29753 .61866 .28717 .61777 .28618 Mtetra
.891 .805 .758 r
.61777 .28618 .61866 .28717 .62038 .28482 .61949 .28361 Mtetra
.686 .735 .888 r
.61949 .28361 .62038 .28482 .62216 .28409 .62126 .28288 Mtetra
.564 .685 .921 r
.62126 .28288 .62216 .28409 .62394 .28383 .62305 .28267 Mtetra
.666 .737 .903 r
.62305 .28267 .62394 .28383 .62572 .28309 .62483 .28204 Mtetra
.713 .776 .901 r
.62483 .28204 .62572 .28309 .62749 .28217 .62661 .28119 Mtetra
.615 .758 .947 r
.62661 .28119 .62749 .28217 .62928 .28181 .6284 .28075 Mtetra
0 .343 .817 r
.6284 .28075 .62928 .28181 .63116 .28391 .63024 .28185 Mtetra
.699 .34 0 r
.63024 .28185 .63116 .28391 .63998 .48553 .63221 .28664 Mtetra
0 0 .381 r
.63221 .28664 .63998 .48553 .64228 .49625 .64113 .4892 Mtetra
.247 .187 .59 r
.64113 .4892 .64228 .49625 .64427 .49779 .64321 .49339 Mtetra
.445 .372 .681 r
.64321 .49339 .64427 .49779 .64619 .49735 .64519 .49447 Mtetra
.509 .478 .757 r
.64519 .49447 .64619 .49735 .6481 .49638 .64714 .49475 Mtetra
.497 .596 .883 r
.64714 .49475 .6481 .49638 .65002 .49586 .64908 .49485 Mtetra
.529 .73 .966 r
.64908 .49485 .65002 .49586 .65195 .49564 .65102 .49465 Mtetra
.719 .808 .92 r
.65102 .49465 .65195 .49564 .65386 .49482 .65293 .49372 Mtetra
.913 .8 .722 r
.65293 .49372 .65386 .49482 .65568 .4916 .65474 .49039 Mtetra
.976 .685 .402 r
.65474 .49039 .65568 .4916 .65669 .46825 .64905 .29826 Mtetra
.588 .356 .533 r
.64905 .29826 .65669 .46825 .65083 .27638 .64995 .27517 Mtetra
.886 .779 .737 r
.64995 .27517 .65083 .27638 .65254 .27356 .65166 .27238 Mtetra
.695 .748 .892 r
.65166 .27238 .65254 .27356 .65433 .27276 .65345 .2716 Mtetra
.574 .702 .929 r
.65345 .2716 .65433 .27276 .65614 .27248 .65527 .27134 Mtetra
.646 .735 .914 r
.65527 .27134 .65614 .27248 .65794 .27186 .65707 .27079 Mtetra
.717 .776 .899 r
.65707 .27079 .65794 .27186 .65973 .2709 .65886 .26991 Mtetra
.633 .764 .942 r
.65886 .26991 .65973 .2709 .66154 .27045 .66067 .26941 Mtetra
.124 .47 .893 r
.66067 .26941 .66154 .27045 .66344 .27201 .66253 .27018 Mtetra
0 0 .366 r
.66253 .27018 .66344 .27201 .66609 .29007 .66454 .27396 Mtetra
.98 .687 .331 r
.66454 .27396 .66609 .29007 .67688 .48478 .67562 .47621 Mtetra
.206 .144 .562 r
.67562 .47621 .67688 .48478 .67894 .48681 .67784 .48194 Mtetra
.444 .36 .667 r
.67784 .48194 .67894 .48681 .68089 .48638 .67987 .48316 Mtetra
.514 .463 .737 r
.67987 .48316 .68089 .48638 .68281 .48532 .68185 .48345 Mtetra
.587 .611 .843 r
.68185 .48345 .68281 .48532 .68473 .48428 .68381 .48317 Mtetra
.661 .765 .926 r
.68381 .48317 .68473 .48428 .68667 .4836 .68575 .4825 Mtetra
.699 .782 .916 r
.68575 .4825 .68667 .4836 .68861 .48286 .68768 .48166 Mtetra
.682 .756 .907 r
.68768 .48166 .68861 .48286 .69053 .48194 .68962 .4809 Mtetra
.636 .771 .945 r
.68962 .4809 .69053 .48194 .69245 .48082 .69157 .48034 Mtetra
.555 .87 .995 r
.69157 .48034 .69245 .48082 .69438 .47974 .69352 .4798 Mtetra
.317 .806 .815 r
.69352 .4798 .69438 .47974 .69632 .47911 .69547 .47924 Mtetra
.291 .787 .771 r
.69547 .47924 .69632 .47911 .6983 .479 .69742 .47864 Mtetra
.539 .887 .983 r
.69742 .47864 .6983 .479 .70028 .47897 .69938 .47806 Mtetra
.531 .758 .98 r
.69938 .47806 .70028 .47897 .70227 .47903 .70135 .47781 Mtetra
.494 .668 .94 r
.70135 .47781 .70227 .47903 .70426 .47903 .70334 .47779 Mtetra
.651 .738 .913 r
.70334 .47779 .70426 .47903 .70621 .47837 .7053 .47718 Mtetra
.883 .8 .762 r
.7053 .47718 .70621 .47837 .70805 .47568 .70714 .47451 Mtetra
.979 .729 .483 r
.70714 .47451 .70805 .47568 .70923 .46112 .70829 .45951 Mtetra
.977 .681 .38 r
.70829 .45951 .70923 .46112 .6998 .25989 .69894 .2587 Mtetra
.912 .787 .709 r
.69894 .2587 .6998 .25989 .70147 .25658 .70062 .2554 Mtetra
.711 .757 .888 r
.70062 .2554 .70147 .25658 .70329 .2557 .70243 .25453 Mtetra
.589 .709 .926 r
.70243 .25453 .70329 .2557 .70513 .25538 .70428 .2542 Mtetra
.624 .725 .919 r
.70428 .2542 .70513 .25538 .70697 .25491 .70612 .25374 Mtetra
.733 .766 .879 r
.70612 .25374 .70697 .25491 .70878 .25391 .70793 .25274 Mtetra
.641 .733 .915 r
.70793 .25274 .70878 .25391 .71062 .25337 .70977 .2522 Mtetra
.065 .401 .856 r
.70977 .2522 .71062 .25337 .71256 .25439 .71171 .25323 Mtetra
.924 .551 .137 r
.71171 .25323 .71256 .25439 .715 .2636 .71416 .26251 Mtetra
.975 .671 .352 r
.71416 .26251 .715 .2636 .72961 .46804 .72871 .46694 Mtetra
.611 .146 0 r
.72871 .46694 .72961 .46804 .7318 .47101 .7309 .46991 Mtetra
.417 .656 .958 r
.7309 .46991 .7318 .47101 .73383 .47116 .73293 .47006 Mtetra
.713 .79 .912 r
.73293 .47006 .73383 .47116 .73578 .47023 .73489 .46913 Mtetra
.892 .819 .769 r
.73489 .46913 .73578 .47023 .73763 .46756 .73674 .46649 Mtetra
.979 .757 .531 r
.73674 .46649 .73763 .46756 .73902 .45787 .73815 .45715 Mtetra
.978 .679 .364 r
.73815 .45715 .73902 .45787 .72741 .25116 .72658 .25015 Mtetra
.945 .804 .674 r
.72658 .25015 .72741 .25116 .72904 .24727 .72821 .24619 Mtetra
.722 .783 .9 r
.72821 .24619 .72904 .24727 .73087 .24637 .73003 .24527 Mtetra
.576 .72 .941 r
.73003 .24527 .73087 .24637 .73274 .24609 .73191 .24497 Mtetra
.536 .697 .943 r
.73191 .24497 .73274 .24609 .73463 .24595 .73379 .24481 Mtetra
.655 .747 .918 r
.73379 .24481 .73463 .24595 .73648 .24535 .73564 .24421 Mtetra
.66 .748 .915 r
.73564 .24421 .73648 .24535 .73833 .24474 .7375 .24358 Mtetra
.699 .761 .9 r
.7375 .24358 .73833 .24474 .74018 .24393 .73934 .24277 Mtetra
.756 .779 .872 r
.73934 .24277 .74018 .24393 .74199 .24279 .74116 .24163 Mtetra
.672 .748 .908 r
.74116 .24163 .74199 .24279 .74385 .24212 .74301 .24095 Mtetra
.236 .514 .91 r
.74301 .24095 .74385 .24212 .7458 .24279 .74496 .24162 Mtetra
.895 .508 .062 r
.74496 .24162 .7458 .24279 .74827 .25062 .74744 .24948 Mtetra
.975 .667 .334 r
.74744 .24948 .74827 .25062 .76529 .45667 .76441 .45555 Mtetra
.64 .184 0 r
.76441 .45555 .76529 .45667 .76758 .46003 .7667 .4589 Mtetra
.39 .636 .953 r
.7667 .4589 .76758 .46003 .76964 .46027 .76876 .45914 Mtetra
.694 .781 .918 r
.76876 .45914 .76964 .46027 .77163 .45943 .77075 .45829 Mtetra
.873 .82 .793 r
.77075 .45829 .77163 .45943 .7735 .45709 .77263 .45596 Mtetra
.978 .767 .552 r
.77263 .45596 .7735 .45709 .77495 .44923 .77408 .4481 Mtetra
.977 .675 .347 r
.77408 .4481 .77495 .44923 .76092 .2405 .76009 .2393 Mtetra
.95 .784 .641 r
.76009 .2393 .76092 .2405 .76248 .23586 .76165 .23466 Mtetra
.747 .772 .873 r
.76165 .23466 .76248 .23586 .76431 .23475 .76348 .23356 Mtetra
.621 .723 .919 r
.76348 .23356 .76431 .23475 .7662 .2343 .76537 .2331 Mtetra
.59 .708 .925 r
.76537 .2331 .7662 .2343 .76809 .23396 .76727 .23276 Mtetra
.749 .772 .872 r
.76727 .23276 .76809 .23396 .76993 .23284 .7691 .23164 Mtetra
.675 .745 .904 r
.7691 .23164 .76993 .23284 .77179 .23214 .77097 .23094 Mtetra
.375 .593 .93 r
.77097 .23094 .77179 .23214 .77375 .2325 .77293 .23129 Mtetra
.81 .399 0 r
.77293 .23129 .77375 .2325 .77614 .23808 .77531 .23684 Mtetra
.973 .663 .318 r
.77531 .23684 .77614 .23808 .79528 .44608 .79441 .4449 Mtetra
.702 .263 0 r
.79441 .4449 .79528 .44608 .79769 .45021 .79682 .44905 Mtetra
.503 .69 .952 r
.79682 .44905 .79769 .45021 .79976 .45014 .79889 .44897 Mtetra
.691 .775 .916 r
.79889 .44897 .79976 .45014 .80177 .44931 .8009 .44814 Mtetra
.73 .788 .898 r
.8009 .44814 .80177 .44931 .80376 .44828 .80289 .44709 Mtetra
.5 .684 .949 r
.80289 .44709 .80376 .44828 .80583 .44824 .80496 .44703 Mtetra
.625 .739 .929 r
.80496 .44703 .80583 .44824 .80787 .44774 .807 .44651 Mtetra
.802 .798 .848 r
.807 .44651 .80787 .44774 .80982 .44618 .80894 .44491 Mtetra
.975 .769 .564 r
.80894 .44491 .80982 .44618 .81128 .43912 .8104 .43767 Mtetra
.976 .671 .33 r
.8104 .43767 .81128 .43912 .79482 .22949 .794 .22815 Mtetra
.954 .772 .619 r
.794 .22815 .79482 .22949 .79631 .22424 .79549 .223 Mtetra
.752 .768 .866 r
.79549 .223 .79631 .22424 .79815 .22307 .79734 .22184 Mtetra
.625 .72 .915 r
.79734 .22184 .79815 .22307 .80006 .22259 .79925 .22136 Mtetra
.555 .687 .927 r
.79925 .22136 .80006 .22259 .80199 .22238 .80118 .22116 Mtetra
.748 .77 .871 r
.80118 .22116 .80199 .22238 .80384 .22125 .80303 .22003 Mtetra
.679 .745 .901 r
.80303 .22003 .80384 .22125 .80573 .22052 .80492 .2193 Mtetra
.459 .638 .933 r
.80492 .2193 .80573 .22052 .8077 .22063 .80689 .21942 Mtetra
.769 .355 0 r
.80689 .21942 .8077 .22063 .81015 .22587 .80934 .22464 Mtetra
.971 .657 .298 r
.80934 .22464 .81015 .22587 .83179 .43466 .83094 .43349 Mtetra
.723 .289 0 r
.83094 .43349 .83179 .43466 .83432 .43926 .83348 .4381 Mtetra
.308 .581 .938 r
.83348 .4381 .83432 .43926 .83648 .43974 .83563 .43859 Mtetra
.65 .764 .932 r
.83563 .43859 .83648 .43974 .83853 .4391 .83768 .43794 Mtetra
.83 .821 .84 r
.83768 .43794 .83853 .4391 .84046 .43729 .83962 .43613 Mtetra
.976 .789 .588 r
.83962 .43613 .84046 .43729 .84198 .43114 .84113 .43 Mtetra
.974 .667 .312 r
.84113 .43 .84198 .43114 .82346 .2209 .82266 .21971 Mtetra
.975 .776 .573 r
.82266 .21971 .82346 .2209 .82482 .21467 .82403 .21346 Mtetra
.763 .76 .85 r
.20982 .42442 .21087 .42538 .21246 .42429 .21141 .42333 Mtetra
.62 .733 .927 r
.21141 .42333 .21246 .42429 .21397 .42391 .21292 .42296 Mtetra
.472 .681 .957 r
.21292 .42296 .21397 .42391 .21545 .42391 .2144 .42296 Mtetra
.659 .747 .915 r
.2144 .42296 .21545 .42391 .21698 .42339 .21593 .42245 Mtetra
.672 .753 .911 r
.21593 .42245 .21698 .42339 .21852 .42281 .21746 .42189 Mtetra
.685 .757 .907 r
.21746 .42189 .21852 .42281 .22006 .42219 .21901 .42127 Mtetra
.783 .77 .841 r
.21901 .42127 .22006 .42219 .22165 .42097 .22061 .42003 Mtetra
.735 .763 .875 r
.22061 .42003 .22165 .42097 .22322 .4201 .22217 .41915 Mtetra
.559 .715 .945 r
.22217 .41915 .22322 .4201 .22472 .41992 .22368 .41895 Mtetra
.92 .528 .221 r
.22368 .41895 .22472 .41992 .22587 .42358 .22482 .42265 Mtetra
.939 .683 .523 r
.22482 .42265 .22587 .42358 .20913 .62247 .208 .6217 Mtetra
.933 .59 .36 r
.208 .6217 .20913 .62247 .21016 .62858 .20903 .62772 Mtetra
0 .307 .748 r
.20903 .62772 .21016 .62858 .21167 .62942 .21054 .62855 Mtetra
.62 .768 .951 r
.21054 .62855 .21167 .62942 .21329 .629 .21217 .62813 Mtetra
.808 .789 .834 r
.21217 .62813 .21329 .629 .21502 .62748 .2139 .62662 Mtetra
.91 .745 .664 r
.2139 .62662 .21502 .62748 .21709 .62212 .21596 .62135 Mtetra
.939 .687 .53 r
.21596 .62135 .21709 .62212 .23646 .42205 .2354 .42129 Mtetra
.921 .738 .638 r
.2354 .42129 .23646 .42205 .23851 .41585 .23746 .41494 Mtetra
.795 .775 .834 r
.23746 .41494 .23851 .41585 .24013 .41451 .23908 .4136 Mtetra
.627 .748 .934 r
.23908 .4136 .24013 .41451 .24166 .4141 .24061 .4132 Mtetra
.453 .688 .966 r
.24061 .4132 .24166 .4141 .24316 .4141 .24211 .41322 Mtetra
.612 .75 .944 r
.24211 .41322 .24316 .4141 .24469 .41373 .24365 .41285 Mtetra
.634 .759 .938 r
.24365 .41285 .24469 .41373 .24623 .41329 .24518 .41242 Mtetra
.639 .763 .938 r
.24518 .41242 .24623 .41329 .24777 .41283 .24673 .41197 Mtetra
.653 .768 .933 r
.24673 .41197 .24777 .41283 .24932 .41233 .24827 .41147 Mtetra
.662 .77 .929 r
.24827 .41147 .24932 .41233 .25087 .4118 .24982 .41094 Mtetra
.67 .77 .925 r
.24982 .41094 .25087 .4118 .25242 .41125 .25138 .41038 Mtetra
.672 .769 .923 r
.25138 .41038 .25242 .41125 .25398 .41068 .25293 .40981 Mtetra
.679 .769 .919 r
.25293 .40981 .25398 .41068 .25554 .41009 .25449 .40921 Mtetra
.688 .77 .914 r
.25449 .40921 .25554 .41009 .2571 .40946 .25606 .40857 Mtetra
.708 .772 .902 r
.25606 .40857 .2571 .40946 .25867 .40875 .25763 .40784 Mtetra
.712 .769 .897 r
.25763 .40784 .25867 .40875 .26024 .40801 .2592 .40708 Mtetra
.708 .764 .896 r
.2592 .40708 .26024 .40801 .26181 .40729 .26078 .40634 Mtetra
.686 .757 .906 r
.26078 .40634 .26181 .40729 .26338 .40665 .26234 .40571 Mtetra
.674 .756 .913 r
.26234 .40571 .26338 .40665 .26494 .40605 .26391 .40513 Mtetra
.669 .758 .917 r
.26391 .40513 .26494 .40605 .2665 .40548 .26547 .40457 Mtetra
.705 .768 .901 r
.26547 .40457 .2665 .40548 .26809 .40465 .26704 .40384 Mtetra
.69 .79 .926 r
.26704 .40384 .26809 .40465 .26966 .40395 .26861 .4032 Mtetra
.614 .783 .962 r
.26861 .4032 .26966 .40395 .2712 .4037 .27017 .4028 Mtetra
.059 .469 .886 r
.27017 .4028 .2712 .4037 .27259 .4054 .27164 .40338 Mtetra
0 .194 .713 r
.27164 .40338 .27259 .4054 .27362 .41178 .27305 .40488 Mtetra
.324 .222 .581 r
.27305 .40488 .27362 .41178 .26 .60794 .27437 .40754 Mtetra
.538 .318 .528 r
.27437 .40754 .26 .60794 .2615 .60951 .27587 .40789 Mtetra
.541 .32 .529 r
.27587 .40789 .2615 .60951 .26317 .60889 .27748 .40679 Mtetra
.539 .319 .529 r
.27748 .40679 .26317 .60889 .26487 .60794 .27903 .40655 Mtetra
0 0 .228 r
.27903 .40655 .26487 .60794 .26642 .60886 .26613 .59732 Mtetra
0 0 .38 r
.26613 .59732 .26642 .60886 .26796 .61007 .26703 .60691 Mtetra
0 0 .549 r
.26703 .60691 .26796 .61007 .26953 .61084 .26845 .6097 Mtetra
.277 .56 .931 r
.26845 .6097 .26953 .61084 .27117 .61079 .27005 .61012 Mtetra
.616 .817 .977 r
.27005 .61012 .27117 .61079 .27284 .61034 .27172 .60965 Mtetra
.709 .833 .941 r
.27172 .60965 .27284 .61034 .27452 .60972 .27341 .60887 Mtetra
.55 .754 .972 r
.27341 .60887 .27452 .60972 .27616 .60956 .27507 .60863 Mtetra
.573 .744 .958 r
.27507 .60863 .27616 .60956 .27782 .60929 .27672 .60835 Mtetra
.734 .781 .89 r
.27672 .60835 .27782 .60929 .27953 .60839 .27843 .60742 Mtetra
.9 .756 .693 r
.27843 .60742 .27953 .60839 .28145 .60441 .28036 .60334 Mtetra
.946 .688 .516 r
.28036 .60334 .28145 .60441 .29722 .40415 .29625 .40243 Mtetra
.906 .697 .609 r
.29625 .40243 .29722 .40415 .2994 .39507 .29839 .39388 Mtetra
.823 .738 .771 r
.29839 .39388 .2994 .39507 .30108 .39305 .30007 .39192 Mtetra
.652 .714 .893 r
.30007 .39192 .30108 .39305 .30266 .3925 .30165 .39141 Mtetra
.514 .672 .935 r
.30165 .39141 .30266 .3925 .30422 .39239 .3032 .39136 Mtetra
.703 .746 .886 r
.3032 .39136 .30422 .39239 .30581 .39163 .3048 .39062 Mtetra
.736 .757 .87 r
.3048 .39062 .30581 .39163 .30742 .39071 .30641 .3897 Mtetra
.616 .727 .925 r
.30641 .3897 .30742 .39071 .30899 .39034 .30798 .38933 Mtetra
.758 .275 0 r
.30798 .38933 .30899 .39034 .3104 .39244 .30939 .39149 Mtetra
.948 .684 .503 r
.30939 .39149 .3104 .39244 .299 .58797 .29785 .58814 Mtetra
.927 .617 .436 r
.29785 .58814 .299 .58797 .29985 .60019 .29875 .59941 Mtetra
.539 0 0 r
.29875 .59941 .29985 .60019 .30141 .60161 .30032 .60077 Mtetra
.647 .788 .949 r
.30032 .60077 .30141 .60161 .3031 .60113 .30201 .60023 Mtetra
.757 .795 .883 r
.30201 .60023 .3031 .60113 .30482 .60013 .30374 .59916 Mtetra
.599 .747 .948 r
.30374 .59916 .30482 .60013 .3065 .5998 .30542 .59881 Mtetra
.484 .696 .962 r
.30542 .59881 .3065 .5998 .30817 .59976 .30708 .59877 Mtetra
.679 .763 .914 r
.30708 .59877 .30817 .59976 .30987 .59911 .30879 .59811 Mtetra
.888 .763 .719 r
.30879 .59811 .30987 .59911 .31174 .59583 .31066 .59474 Mtetra
.949 .689 .509 r
.31066 .59474 .31174 .59583 .32547 .40071 .32462 .39706 Mtetra
.885 .655 .585 r
.32462 .39706 .32547 .40071 .32795 .38589 .32696 .38463 Mtetra
.838 .733 .748 r
.32696 .38463 .32795 .38589 .32966 .38349 .32867 .3823 Mtetra
.647 .704 .888 r
.32867 .3823 .32966 .38349 .33126 .38296 .33026 .38181 Mtetra
.475 .644 .931 r
.33026 .38181 .33126 .38296 .33283 .38296 .33182 .38187 Mtetra
.53 .68 .933 r
.33182 .38187 .33283 .38296 .3344 .38281 .3334 .38177 Mtetra
.634 .729 .916 r
.3334 .38177 .3344 .38281 .336 .38233 .33499 .38133 Mtetra
.652 .743 .916 r
.33499 .38133 .336 .38233 .3376 .38179 .33659 .38082 Mtetra
.682 .758 .909 r
.33659 .38082 .3376 .38179 .33921 .38114 .3382 .38019 Mtetra
.702 .766 .901 r
.3382 .38019 .33921 .38114 .34082 .38041 .33982 .37946 Mtetra
.705 .768 .901 r
.33982 .37946 .34082 .38041 .34244 .37967 .34143 .37872 Mtetra
.692 .765 .908 r
.34143 .37872 .34244 .37967 .34405 .37899 .34305 .37804 Mtetra
.676 .763 .916 r
.34305 .37804 .34405 .37899 .34566 .37836 .34466 .37743 Mtetra
.671 .764 .92 r
.34466 .37743 .34566 .37836 .34728 .37776 .34627 .37685 Mtetra
.67 .767 .923 r
.34627 .37685 .34728 .37776 .34889 .37717 .34788 .37626 Mtetra
.67 .768 .924 r
.34788 .37626 .34889 .37717 .3505 .37659 .34949 .37568 Mtetra
.668 .768 .925 r
.34949 .37568 .3505 .37659 .35211 .37601 .3511 .3751 Mtetra
.667 .768 .925 r
.3511 .3751 .35211 .37601 .35372 .37544 .35272 .37453 Mtetra
.666 .767 .925 r
.35272 .37453 .35372 .37544 .35534 .37488 .35433 .37396 Mtetra
.664 .766 .925 r
.35433 .37396 .35534 .37488 .35695 .37433 .35595 .3734 Mtetra
.665 .764 .924 r
.35595 .3734 .35695 .37433 .35856 .37377 .35756 .37284 Mtetra
.664 .762 .922 r
.35756 .37284 .35856 .37377 .36018 .37323 .35918 .37227 Mtetra
.658 .757 .923 r
.35918 .37227 .36018 .37323 .36179 .3727 .3608 .37173 Mtetra
.64 .749 .927 r
.3608 .37173 .36179 .3727 .36341 .37224 .36241 .37126 Mtetra
.621 .741 .932 r
.36241 .37126 .36341 .37224 .36502 .37184 .36402 .37086 Mtetra
.62 .74 .933 r
.36402 .37086 .36502 .37184 .36663 .37144 .36563 .37046 Mtetra
.637 .746 .927 r
.36563 .37046 .36663 .37144 .36824 .37099 .36725 .37 Mtetra
.659 .75 .917 r
.36725 .37 .36824 .37099 .36986 .37047 .36887 .36946 Mtetra
.668 .747 .91 r
.36887 .36946 .36986 .37047 .37149 .36992 .3705 .36888 Mtetra
.669 .742 .905 r
.3705 .36888 .37149 .36992 .37311 .36937 .37212 .3683 Mtetra
.668 .737 .901 r
.37212 .3683 .37311 .36937 .37474 .36881 .37375 .36771 Mtetra
.675 .734 .895 r
.37375 .36771 .37474 .36881 .37636 .36821 .37538 .3671 Mtetra
.716 .74 .87 r
.37538 .3671 .37636 .36821 .378 .36748 .37702 .36625 Mtetra
.735 .727 .844 r
.37702 .36625 .378 .36748 .37964 .36663 .37867 .36525 Mtetra
.677 .687 .852 r
.37867 .36525 .37964 .36663 .38127 .36593 .3803 .36459 Mtetra
.365 .549 .901 r
.3803 .36459 .38127 .36593 .38289 .36575 .38189 .36498 Mtetra
.838 .374 0 r
.38189 .36498 .38289 .36575 .38447 .36634 .38337 .36768 Mtetra
.925 .626 .457 r
.38337 .36768 .38447 .36634 .38603 .36736 .38422 .38519 Mtetra
.928 .656 .502 r
.38422 .38519 .38603 .36736 .38762 .36779 .37786 .56907 Mtetra
.537 .312 .522 r
.37786 .56907 .38762 .36779 .38928 .36676 .3796 .56859 Mtetra
.535 .311 .522 r
.3796 .56859 .38928 .36676 .39091 .36613 .38137 .56737 Mtetra
.539 .315 .522 r
.38137 .56737 .39091 .36613 .39244 .36823 .38304 .56845 Mtetra
.543 .318 .523 r
.38304 .56845 .39244 .36823 .38591 .56703 .38464 .57136 Mtetra
.628 .308 .409 r
.38464 .57136 .38591 .56703 .38738 .57301 .38629 .57301 Mtetra
.353 0 0 r
.38629 .57301 .38738 .57301 .38905 .57457 .388 .5735 Mtetra
.653 .748 .919 r
.388 .5735 .38905 .57457 .39079 .57414 .38974 .57294 Mtetra
.703 .738 .878 r
.38974 .57294 .39079 .57414 .39255 .57325 .3915 .57212 Mtetra
.664 .741 .907 r
.3915 .57212 .39255 .57325 .39431 .57243 .39326 .57151 Mtetra
.495 .724 .974 r
.39326 .57151 .39431 .57243 .39605 .57213 .39499 .57141 Mtetra
.595 .807 .981 r
.39499 .57141 .39605 .57213 .3978 .5717 .39674 .57098 Mtetra
.816 .842 .869 r
.39674 .57098 .3978 .5717 .39957 .57077 .39853 .56951 Mtetra
.896 .746 .687 r
.39853 .56951 .39957 .57077 .40137 .5689 .40041 .56542 Mtetra
.907 .669 .568 r
.40041 .56542 .40137 .5689 .40319 .56654 .40268 .55064 Mtetra
.939 .67 .501 r
.40268 .55064 .40319 .56654 .40499 .56456 .41121 .36041 Mtetra
.54 .32 .529 r
.41121 .36041 .40499 .56456 .40673 .5645 .41287 .35962 Mtetra
.539 .318 .529 r
.41287 .35962 .40673 .5645 .40849 .56405 .4145 .35954 Mtetra
.542 .321 .529 r
.4145 .35954 .40849 .56405 .41033 .56094 .41619 .35796 Mtetra
.546 .324 .53 r
.41619 .35796 .41033 .56094 .41875 .36055 .41795 .35441 Mtetra
.674 .487 .625 r
.41795 .35441 .41875 .36055 .42061 .35395 .41966 .35191 Mtetra
.745 .643 .746 r
.41966 .35191 .42061 .35395 .42233 .35135 .42135 .35034 Mtetra
.665 .751 .915 r
.42135 .35034 .42233 .35135 .42398 .35064 .42301 .34977 Mtetra
.592 .758 .958 r
.42301 .34977 .42398 .35064 .42563 .35036 .42466 .34943 Mtetra
.629 .758 .94 r
.42466 .34943 .42563 .35036 .42728 .35008 .42631 .34898 Mtetra
.735 .752 .866 r
.42631 .34898 .42728 .35008 .42894 .3493 .42798 .34802 Mtetra
.685 .708 .866 r
.42798 .34802 .42894 .3493 .4306 .34862 .42964 .34732 Mtetra
.49 .623 .909 r
.42964 .34732 .4306 .34862 .43226 .34831 .43128 .34738 Mtetra
.73 .239 0 r
.43128 .34738 .43226 .34831 .43388 .34883 .43286 .34964 Mtetra
.905 .565 .39 r
.43286 .34964 .43388 .34883 .4355 .34978 .43429 .35743 Mtetra
.949 .672 .478 r
.43429 .35743 .4355 .34978 .43713 .35059 .43048 .55257 Mtetra
.537 .313 .522 r
.43048 .55257 .43713 .35059 .43881 .34965 .43224 .55252 Mtetra
.536 .312 .522 r
.43224 .55252 .43881 .34965 .44048 .34898 .43403 .55147 Mtetra
.538 .314 .522 r
.43403 .55147 .44048 .34898 .4421 .35009 .43578 .55176 Mtetra
.543 .318 .523 r
.43578 .55176 .4421 .35009 .43868 .54861 .43746 .55482 Mtetra
.612 .314 .439 r
.43746 .55482 .43868 .54861 .44024 .55629 .43918 .55662 Mtetra
.545 0 0 r
.43918 .55662 .44024 .55629 .44196 .55845 .44093 .55742 Mtetra
.595 .738 .944 r
.44093 .55742 .44196 .55845 .44373 .55827 .44271 .55706 Mtetra
.664 .728 .897 r
.44271 .55706 .44373 .55827 .44552 .5576 .44449 .55644 Mtetra
.674 .741 .901 r
.44449 .55644 .44552 .5576 .44731 .55677 .44628 .55577 Mtetra
.597 .746 .948 r
.44628 .55577 .44731 .55677 .44909 .55635 .44806 .55539 Mtetra
.599 .759 .955 r
.44806 .55539 .44909 .55635 .45087 .5559 .44985 .55501 Mtetra
.62 .779 .957 r
.44985 .55501 .45087 .5559 .45266 .55539 .45163 .55454 Mtetra
.674 .805 .945 r
.45163 .55454 .45266 .55539 .45445 .5547 .45342 .55386 Mtetra
.686 .811 .942 r
.45342 .55386 .45445 .5547 .45625 .55397 .45522 .55314 Mtetra
.683 .811 .944 r
.45522 .55314 .45625 .55397 .45804 .55326 .45701 .55243 Mtetra
.652 .803 .956 r
.45701 .55243 .45804 .55326 .45984 .55266 .45881 .55183 Mtetra
.642 .803 .96 r
.45881 .55183 .45984 .55266 .46163 .55208 .4606 .55127 Mtetra
.637 .804 .963 r
.4606 .55127 .46163 .55208 .46342 .55153 .4624 .55072 Mtetra
.641 .808 .963 r
.4624 .55072 .46342 .55153 .46522 .55096 .4642 .55016 Mtetra
.639 .809 .964 r
.4642 .55016 .46522 .55096 .46702 .5504 .46599 .5496 Mtetra
.638 .809 .965 r
.46599 .5496 .46702 .5504 .46882 .54984 .46779 .54904 Mtetra
.638 .81 .965 r
.46779 .54904 .46882 .54984 .47062 .54928 .46959 .54849 Mtetra
.637 .81 .966 r
.46959 .54849 .47062 .54928 .47242 .54873 .47139 .54793 Mtetra
.637 .809 .966 r
.47139 .54793 .47242 .54873 .47422 .54818 .4732 .54738 Mtetra
.637 .809 .965 r
.4732 .54738 .47422 .54818 .47602 .54763 .475 .54683 Mtetra
.637 .808 .965 r
.475 .54683 .47602 .54763 .47782 .54709 .47681 .54628 Mtetra
.637 .806 .964 r
.47681 .54628 .47782 .54709 .47963 .54655 .47861 .54572 Mtetra
.637 .804 .963 r
.47861 .54572 .47963 .54655 .48144 .54601 .48042 .54517 Mtetra
.638 .801 .961 r
.48042 .54517 .48144 .54601 .48324 .54548 .48223 .54462 Mtetra
.638 .797 .959 r
.48223 .54462 .48324 .54548 .48505 .54496 .48404 .54407 Mtetra
.639 .791 .955 r
.48404 .54407 .48505 .54496 .48686 .54446 .48585 .54353 Mtetra
.641 .781 .948 r
.48585 .54353 .48686 .54446 .48867 .54396 .48766 .54298 Mtetra
.64 .77 .941 r
.48766 .54298 .48867 .54396 .49048 .54347 .48947 .54244 Mtetra
.581 .739 .951 r
.48947 .54244 .49048 .54347 .49229 .54331 .49129 .54212 Mtetra
.632 .724 .914 r
.49129 .54212 .49229 .54331 .49411 .54285 .4931 .54163 Mtetra
.699 .742 .884 r
.4931 .54163 .49411 .54285 .49593 .54181 .49492 .54081 Mtetra
.828 .803 .827 r
.49492 .54081 .49593 .54181 .49777 .53818 .49675 .53905 Mtetra
.847 .965 .637 r
.49675 .53905 .49777 .53818 .49966 .52791 .49859 .53628 Mtetra
.163 0 .333 r
.49859 .53628 .49966 .52791 .50287 .32835 .50044 .53086 Mtetra
0 0 .324 r
.50044 .53086 .50287 .32835 .50459 .32514 .50361 .32955 Mtetra
0 0 .002 r
.50361 .32955 .50459 .32514 .5063 .32328 .50536 .32362 Mtetra
.944 .96 .721 r
.50536 .32362 .5063 .32328 .50801 .32204 .50708 .32082 Mtetra
.733 .739 .856 r
.50708 .32082 .50801 .32204 .50972 .32127 .50879 .31982 Mtetra
.643 .67 .861 r
.50879 .31982 .50972 .32127 .51143 .32074 .5105 .3193 Mtetra
.585 .647 .878 r
.5105 .3193 .51143 .32074 .51314 .32035 .5122 .31906 Mtetra
.617 .686 .892 r
.5122 .31906 .51314 .32035 .51485 .3199 .51392 .31867 Mtetra
.617 .697 .901 r
.51392 .31867 .51485 .3199 .51656 .31944 .51563 .31827 Mtetra
.627 .714 .908 r
.51563 .31827 .51656 .31944 .51827 .31894 .51734 .31784 Mtetra
.682 .746 .9 r
.51734 .31784 .51827 .31894 .51999 .31822 .51906 .31715 Mtetra
.697 .757 .898 r
.51906 .31715 .51999 .31822 .5217 .31746 .52077 .3164 Mtetra
.699 .76 .899 r
.52077 .3164 .5217 .31746 .52342 .3167 .52249 .31564 Mtetra
.714 .765 .892 r
.52249 .31564 .52342 .3167 .52514 .31573 .52421 .3148 Mtetra
.684 .784 .926 r
.52421 .3148 .52514 .31573 .52686 .31502 .52593 .31412 Mtetra
.602 .765 .957 r
.52593 .31412 .52686 .31502 .52857 .3148 .52765 .31373 Mtetra
.301 .577 .937 r
.52765 .31373 .52857 .3148 .5303 .3167 .52937 .31413 Mtetra
.274 .337 .747 r
.52937 .31413 .5303 .3167 .53204 .32402 .53109 .31544 Mtetra
.337 .225 .576 r
.53109 .31544 .53204 .32402 .53434 .52448 .53283 .31906 Mtetra
0 0 .353 r
.53283 .31906 .53434 .52448 .53619 .5272 .53518 .51946 Mtetra
.105 .073 .534 r
.53518 .51946 .53619 .5272 .53804 .52815 .53704 .52523 Mtetra
.136 .234 .702 r
.53704 .52523 .53804 .52815 .53988 .52838 .5389 .52728 Mtetra
.385 .634 .953 r
.5389 .52728 .53988 .52838 .54173 .52841 .54075 .5275 Mtetra
.629 .788 .958 r
.54075 .5275 .54173 .52841 .54358 .52796 .5426 .52698 Mtetra
.749 .803 .896 r
.5426 .52698 .54358 .52796 .54543 .52688 .54444 .5259 Mtetra
.823 .812 .84 r
.54444 .5259 .54543 .52688 .54726 .52372 .54629 .52423 Mtetra
.884 .985 .713 r
.54629 .52423 .54726 .52372 .54906 .51591 .54813 .52166 Mtetra
.053 0 .251 r
.54813 .52166 .54906 .51591 .54933 .31334 .54995 .51699 Mtetra
0 0 .347 r
.54995 .51699 .54933 .31334 .55104 .30937 .55018 .31564 Mtetra
0 0 .143 r
.55018 .31564 .55104 .30937 .55277 .30735 .55186 .30812 Mtetra
.902 .956 .618 r
.55186 .30812 .55277 .30735 .5545 .30603 .55358 .30504 Mtetra
.762 .792 .878 r
.55358 .30504 .5545 .30603 .55623 .30527 .55531 .30393 Mtetra
.627 .683 .884 r
.55531 .30393 .55623 .30527 .55797 .3048 .55705 .30349 Mtetra
.564 .662 .903 r
.55705 .30349 .55797 .3048 .55971 .30443 .55879 .3033 Mtetra
.699 .749 .891 r
.55879 .3033 .55971 .30443 .56145 .30349 .56053 .30252 Mtetra
.717 .788 .908 r
.56053 .30252 .56145 .30349 .56318 .3026 .56227 .30168 Mtetra
.659 .781 .939 r
.56227 .30168 .56318 .3026 .56493 .30217 .56401 .30109 Mtetra
.393 .626 .947 r
.56401 .30109 .56493 .30217 .5667 .30366 .56577 .30131 Mtetra
.303 .376 .772 r
.56577 .30131 .5667 .30366 .56853 .30928 .56754 .30242 Mtetra
.34 .246 .6 r
.56754 .30242 .56853 .30928 .57322 .5114 .56934 .30534 Mtetra
0 0 .372 r
.56934 .30534 .57322 .5114 .57514 .5147 .57403 .50388 Mtetra
.115 .058 .509 r
.57403 .50388 .57514 .5147 .57704 .51567 .57603 .512 Mtetra
.178 .22 .668 r
.57603 .512 .57704 .51567 .57892 .51591 .57794 .51445 Mtetra
.226 .466 .88 r
.57794 .51445 .57892 .51591 .58081 .51618 .57984 .51526 Mtetra
.505 .737 .978 r
.57984 .51526 .58081 .51618 .58269 .516 .58172 .5151 Mtetra
.754 .825 .907 r
.58172 .5151 .58269 .516 .58456 .51503 .58359 .514 Mtetra
.933 .787 .676 r
.58359 .514 .58456 .51503 .58637 .51084 .5854 .50967 Mtetra
.972 .688 .428 r
.5854 .50967 .58637 .51084 .58436 .3057 .58343 .30383 Mtetra
.938 .712 .571 r
.58343 .30383 .58436 .3057 .58594 .29617 .58503 .29486 Mtetra
.826 .753 .783 r
.58503 .29486 .58594 .29617 .58767 .29417 .58676 .29292 Mtetra
.638 .706 .895 r
.58676 .29292 .58767 .29417 .58943 .29362 .58853 .29242 Mtetra
.502 .655 .928 r
.58853 .29242 .58943 .29362 .5912 .29356 .5903 .29241 Mtetra
.639 .726 .911 r
.5903 .29241 .5912 .29356 .59296 .29291 .59206 .29191 Mtetra
.687 .774 .917 r
.59206 .29191 .59296 .29291 .59472 .29212 .59382 .29119 Mtetra
.633 .774 .948 r
.59382 .29119 .59472 .29212 .59648 .29175 .59558 .29069 Mtetra
.429 .652 .952 r
.59558 .29069 .59648 .29175 .59829 .29311 .59737 .29082 Mtetra
.345 .409 .785 r
.59737 .29082 .59829 .29311 .60021 .29868 .59917 .29176 Mtetra
.381 .275 .607 r
.59917 .29176 .60021 .29868 .60698 .50067 .60101 .29426 Mtetra
0 0 .387 r
.60101 .29426 .60698 .50067 .60898 .50418 .60772 .49107 Mtetra
.117 .051 .499 r
.60772 .49107 .60898 .50418 .61091 .50518 .60987 .5011 Mtetra
.193 .214 .654 r
.60987 .5011 .61091 .50518 .61282 .50545 .61185 .50379 Mtetra
.233 .437 .856 r
.61185 .50379 .61282 .50545 .61474 .50569 .61379 .50473 Mtetra
.472 .714 .975 r
.61379 .50473 .61474 .50569 .61665 .50558 .6157 .50467 Mtetra
.726 .821 .924 r
.6157 .50467 .61665 .50558 .61854 .50473 .61759 .50372 Mtetra
.921 .802 .712 r
.61759 .50372 .61854 .50473 .62036 .50127 .61941 .50017 Mtetra
.974 .687 .416 r
.61941 .50017 .62036 .50127 .62147 .4737 .61579 .30935 Mtetra
.592 .36 .534 r
.61579 .30935 .62147 .4737 .61777 .28618 .61688 .28497 Mtetra
.873 .776 .751 r
.61688 .28497 .61777 .28618 .61949 .28361 .6186 .28243 Mtetra
.683 .739 .893 r
.6186 .28243 .61949 .28361 .62126 .28288 .62037 .28172 Mtetra
.556 .691 .93 r
.62037 .28172 .62126 .28288 .62305 .28267 .62216 .28152 Mtetra
.64 .73 .914 r
.62216 .28152 .62305 .28267 .62483 .28204 .62395 .28101 Mtetra
.695 .774 .912 r
.62395 .28101 .62483 .28204 .62661 .28119 .62573 .28025 Mtetra
.643 .776 .945 r
.62573 .28025 .62661 .28119 .6284 .28075 .62751 .27971 Mtetra
.468 .675 .954 r
.62751 .27971 .6284 .28075 .63024 .28185 .62932 .27973 Mtetra
.36 .437 .805 r
.62932 .27973 .63024 .28185 .63221 .28664 .63115 .28054 Mtetra
.386 .29 .623 r
.63115 .28054 .63221 .28664 .64113 .4892 .63304 .28273 Mtetra
.007 0 .405 r
.63304 .28273 .64113 .4892 .64321 .49339 .64163 .47422 Mtetra
.089 .018 .473 r
.64163 .47422 .64321 .49339 .64519 .49447 .64413 .48996 Mtetra
.207 .21 .642 r
.64413 .48996 .64519 .49447 .64714 .49475 .64617 .49291 Mtetra
.27 .433 .84 r
.64617 .49291 .64714 .49475 .64908 .49485 .64815 .49388 Mtetra
.502 .727 .973 r
.64815 .49388 .64908 .49485 .65102 .49465 .65009 .49374 Mtetra
.741 .828 .918 r
.65009 .49374 .65102 .49465 .65293 .49372 .65199 .4927 Mtetra
.921 .808 .718 r
.65199 .4927 .65293 .49372 .65474 .49039 .65381 .48927 Mtetra
.976 .685 .402 r
.65381 .48927 .65474 .49039 .64905 .29826 .64804 .29419 Mtetra
.939 .672 .504 r
.64804 .29419 .64905 .29826 .64995 .27517 .64907 .27398 Mtetra
.888 .782 .739 r
.64907 .27398 .64995 .27517 .65166 .27238 .65078 .27121 Mtetra
.693 .748 .893 r
.65078 .27121 .65166 .27238 .65345 .2716 .65257 .27044 Mtetra
.571 .701 .929 r
.65257 .27044 .65345 .2716 .65527 .27134 .65439 .27019 Mtetra
.623 .726 .92 r
.65439 .27019 .65527 .27134 .65707 .27079 .6562 .26974 Mtetra
.697 .772 .91 r
.6562 .26974 .65707 .27079 .65886 .26991 .65799 .26896 Mtetra
.653 .78 .941 r
.65799 .26896 .65886 .26991 .66067 .26941 .6598 .26837 Mtetra
.509 .7 .955 r
.6598 .26837 .66067 .26941 .66253 .27018 .66163 .26827 Mtetra
.385 .478 .832 r
.66163 .26827 .66253 .27018 .66454 .27396 .66349 .26891 Mtetra
.399 .318 .649 r
.66349 .26891 .66454 .27396 .67562 .47621 .66541 .27063 Mtetra
.525 .308 .528 r
.66541 .27063 .67562 .47621 .67784 .48194 .66758 .27789 Mtetra
0 0 .404 r
.66758 .27789 .67784 .48194 .67987 .48316 .67873 .47759 Mtetra
.215 .19 .614 r
.67873 .47759 .67987 .48316 .68185 .48345 .68087 .48125 Mtetra
.359 .444 .813 r
.68087 .48125 .68185 .48345 .68381 .48317 .68289 .48211 Mtetra
.636 .768 .943 r
.68289 .48211 .68381 .48317 .68575 .4825 .68483 .48155 Mtetra
.727 .82 .923 r
.68483 .48155 .68575 .4825 .68768 .48166 .68676 .48058 Mtetra
.707 .786 .914 r
.68676 .48058 .68768 .48166 .68962 .4809 .68869 .47969 Mtetra
.633 .736 .922 r
.68869 .47969 .68962 .4809 .69157 .48034 .69065 .47916 Mtetra
.627 .74 .929 r
.69065 .47916 .69157 .48034 .69352 .4798 .6926 .47865 Mtetra
.638 .75 .93 r
.6926 .47865 .69352 .4798 .69547 .47924 .69455 .47809 Mtetra
.653 .756 .925 r
.69455 .47809 .69547 .47924 .69742 .47864 .6965 .47747 Mtetra
.651 .75 .922 r
.6965 .47747 .69742 .47864 .69938 .47806 .69846 .47685 Mtetra
.563 .706 .937 r
.69846 .47685 .69938 .47806 .70135 .47781 .70043 .47659 Mtetra
.483 .666 .943 r
.70043 .47659 .70135 .47781 .70334 .47779 .70242 .4766 Mtetra
.645 .746 .923 r
.70242 .4766 .70334 .47779 .7053 .47718 .70438 .47601 Mtetra
.885 .804 .764 r
.70438 .47601 .7053 .47718 .70714 .47451 .70623 .47335 Mtetra
.98 .728 .48 r
.70623 .47335 .70714 .47451 .70829 .45951 .70736 .45793 Mtetra
.977 .681 .38 r
.70736 .45793 .70829 .45951 .69894 .2587 .69808 .25751 Mtetra
.912 .787 .71 r
.69808 .25751 .69894 .2587 .70062 .2554 .69976 .25422 Mtetra
.71 .757 .889 r
.69976 .25422 .70062 .2554 .70243 .25453 .70158 .25335 Mtetra
.588 .708 .926 r
.70158 .25335 .70243 .25453 .70428 .2542 .70343 .25303 Mtetra
.624 .725 .919 r
.70343 .25303 .70428 .2542 .70612 .25374 .70527 .25257 Mtetra
.733 .766 .88 r
.70527 .25257 .70612 .25374 .70793 .25274 .70708 .25157 Mtetra
.641 .733 .915 r
.70708 .25157 .70793 .25274 .70977 .2522 .70892 .25103 Mtetra
.063 .399 .855 r
.70892 .25103 .70977 .2522 .71171 .25323 .71086 .25207 Mtetra
.924 .552 .139 r
.71086 .25207 .71171 .25323 .71416 .26251 .71331 .26142 Mtetra
.975 .671 .352 r
.71331 .26142 .71416 .26251 .72871 .46694 .72781 .46584 Mtetra
.608 .144 0 r
.72781 .46584 .72871 .46694 .7309 .46991 .73 .46881 Mtetra
.417 .655 .958 r
.73 .46881 .7309 .46991 .73293 .47006 .73203 .46896 Mtetra
.712 .789 .912 r
.73203 .46896 .73293 .47006 .73489 .46913 .73399 .46803 Mtetra
.891 .818 .77 r
.73399 .46803 .73489 .46913 .73674 .46649 .73584 .4654 Mtetra
.979 .757 .534 r
.73584 .4654 .73674 .46649 .73815 .45715 .73727 .4562 Mtetra
.978 .679 .364 r
.73727 .4562 .73815 .45715 .72658 .25015 .72574 .24904 Mtetra
.939 .794 .672 r
.72574 .24904 .72658 .25015 .72821 .24619 .72736 .24505 Mtetra
.721 .77 .892 r
.72736 .24505 .72821 .24619 .73003 .24527 .72919 .24412 Mtetra
.579 .712 .934 r
.72919 .24412 .73003 .24527 .73191 .24497 .73107 .24383 Mtetra
.538 .693 .939 r
.73107 .24383 .73191 .24497 .73379 .24481 .73295 .24366 Mtetra
.656 .746 .916 r
.73295 .24366 .73379 .24481 .73564 .24421 .7348 .24306 Mtetra
.661 .747 .914 r
.7348 .24306 .73564 .24421 .7375 .24358 .73666 .24243 Mtetra
.7 .761 .899 r
.73666 .24243 .7375 .24358 .73934 .24277 .7385 .24161 Mtetra
.756 .778 .871 r
.7385 .24161 .73934 .24277 .74116 .24163 .74032 .24046 Mtetra
.672 .748 .907 r
.74032 .24046 .74116 .24163 .74301 .24095 .74218 .23977 Mtetra
.237 .514 .91 r
.74218 .23977 .74301 .24095 .74496 .24162 .74413 .24044 Mtetra
.895 .509 .063 r
.74413 .24044 .74496 .24162 .74744 .24948 .7466 .24834 Mtetra
.975 .667 .334 r
.7466 .24834 .74744 .24948 .76441 .45555 .76353 .45443 Mtetra
.639 .183 0 r
.76353 .45443 .76441 .45555 .7667 .4589 .76582 .45777 Mtetra
.391 .636 .953 r
.76582 .45777 .7667 .4589 .76876 .45914 .76788 .458 Mtetra
.694 .781 .918 r
.76788 .458 .76876 .45914 .77075 .45829 .76987 .45716 Mtetra
.873 .82 .793 r
.76987 .45716 .77075 .45829 .77263 .45596 .77175 .45483 Mtetra
.978 .767 .552 r
.77175 .45483 .77263 .45596 .77408 .4481 .7732 .44696 Mtetra
.977 .675 .347 r
.7732 .44696 .77408 .4481 .76009 .2393 .75926 .23811 Mtetra
.95 .784 .641 r
.75926 .23811 .76009 .2393 .76165 .23466 .76082 .23347 Mtetra
.747 .772 .873 r
.76082 .23347 .76165 .23466 .76348 .23356 .76266 .23236 Mtetra
.621 .723 .919 r
.76266 .23236 .76348 .23356 .76537 .2331 .76454 .2319 Mtetra
.59 .709 .925 r
.76454 .2319 .76537 .2331 .76727 .23276 .76644 .23156 Mtetra
.749 .772 .872 r
.76644 .23156 .76727 .23276 .7691 .23164 .76828 .23044 Mtetra
.675 .745 .904 r
.76828 .23044 .7691 .23164 .77097 .23094 .77015 .22974 Mtetra
.376 .594 .93 r
.77015 .22974 .77097 .23094 .77293 .23129 .7721 .23008 Mtetra
.809 .397 0 r
.7721 .23008 .77293 .23129 .77531 .23684 .77448 .23561 Mtetra
.973 .663 .318 r
.77448 .23561 .77531 .23684 .79441 .4449 .79354 .44372 Mtetra
.705 .265 0 r
.79354 .44372 .79441 .4449 .79682 .44905 .79595 .44789 Mtetra
.504 .691 .952 r
.79595 .44789 .79682 .44905 .79889 .44897 .79802 .4478 Mtetra
.692 .776 .916 r
.79802 .4478 .79889 .44897 .8009 .44814 .80003 .44697 Mtetra
.731 .789 .898 r
.80003 .44697 .8009 .44814 .80289 .44709 .80202 .44591 Mtetra
.499 .686 .95 r
.80202 .44591 .80289 .44709 .80496 .44703 .80409 .44585 Mtetra
.624 .746 .934 r
.80409 .44585 .80496 .44703 .807 .44651 .80613 .44532 Mtetra
.806 .808 .852 r
.80613 .44532 .807 .44651 .80894 .44491 .80808 .44372 Mtetra
.978 .772 .559 r
.80808 .44372 .80894 .44491 .8104 .43767 .80953 .4364 Mtetra
.976 .671 .329 r
.80953 .4364 .8104 .43767 .794 .22815 .79318 .22687 Mtetra
.957 .778 .62 r
.79318 .22687 .794 .22815 .79549 .223 .79468 .22177 Mtetra
.752 .77 .868 r
.79468 .22177 .79549 .223 .79734 .22184 .79652 .22061 Mtetra
.624 .72 .916 r
.79652 .22061 .79734 .22184 .79925 .22136 .79843 .22014 Mtetra
.555 .688 .928 r
.79843 .22014 .79925 .22136 .80118 .22116 .80037 .21993 Mtetra
.747 .771 .872 r
.80037 .21993 .80118 .22116 .80303 .22003 .80222 .21881 Mtetra
.678 .746 .902 r
.80222 .21881 .80303 .22003 .80492 .2193 .80411 .21808 Mtetra
.458 .638 .934 r
.80411 .21808 .80492 .2193 .80689 .21942 .80608 .2182 Mtetra
.769 .354 0 r
.80608 .2182 .80689 .21942 .80934 .22464 .80853 .22342 Mtetra
.971 .657 .298 r
.80853 .22342 .80934 .22464 .83094 .43349 .83009 .43233 Mtetra
.724 .29 0 r
.83009 .43233 .83094 .43349 .83348 .4381 .83262 .43694 Mtetra
.308 .581 .938 r
.83262 .43694 .83348 .4381 .83563 .43859 .83478 .43743 Mtetra
.65 .764 .933 r
.83478 .43743 .83563 .43859 .83768 .43794 .83683 .43678 Mtetra
.83 .821 .84 r
.83683 .43678 .83768 .43794 .83962 .43613 .83877 .43497 Mtetra
.976 .789 .588 r
.83877 .43497 .83962 .43613 .84113 .43 .84029 .42884 Mtetra
.974 .667 .312 r
.84029 .42884 .84113 .43 .82266 .21971 .82186 .21852 Mtetra
.975 .776 .572 r
.82186 .21852 .82266 .21971 .82403 .21346 .82323 .21225 Mtetra
.762 .76 .851 r
.20877 .42345 .20982 .42442 .21141 .42333 .21036 .42237 Mtetra
.618 .732 .928 r
.21036 .42237 .21141 .42333 .21292 .42296 .21187 .422 Mtetra
.467 .678 .957 r
.21187 .422 .21292 .42296 .2144 .42296 .21335 .42201 Mtetra
.661 .747 .914 r
.21335 .42201 .2144 .42296 .21593 .42245 .21488 .4215 Mtetra
.67 .748 .909 r
.21488 .4215 .21593 .42245 .21746 .42189 .21641 .42094 Mtetra
.676 .751 .907 r
.21641 .42094 .21746 .42189 .21901 .42127 .21795 .42035 Mtetra
.769 .77 .853 r
.21795 .42035 .21901 .42127 .22061 .42003 .21954 .41924 Mtetra
.72 .791 .908 r
.21954 .41924 .22061 .42003 .22217 .41915 .2211 .41847 Mtetra
.456 .744 .991 r
.2211 .41847 .22217 .41915 .22368 .41895 .22259 .41839 Mtetra
.914 .54 .301 r
.22259 .41839 .22368 .41895 .22482 .42265 .2237 .42247 Mtetra
.938 .682 .523 r
.2237 .42247 .22482 .42265 .208 .6217 .20681 .62148 Mtetra
.909 .562 .371 r
.20681 .62148 .208 .6217 .20903 .62772 .2079 .62687 Mtetra
0 .336 .771 r
.2079 .62687 .20903 .62772 .21054 .62855 .20942 .62765 Mtetra
.622 .763 .946 r
.20942 .62765 .21054 .62855 .21217 .62813 .21104 .62723 Mtetra
.805 .785 .834 r
.21104 .62723 .21217 .62813 .2139 .62662 .21277 .62574 Mtetra
.909 .745 .666 r
.21277 .62574 .2139 .62662 .21596 .62135 .21483 .62054 Mtetra
.939 .687 .53 r
.21483 .62054 .21596 .62135 .2354 .42129 .23434 .42052 Mtetra
.921 .737 .636 r
.23434 .42052 .2354 .42129 .23746 .41494 .23642 .41403 Mtetra
.795 .774 .834 r
.23642 .41403 .23746 .41494 .23908 .4136 .23804 .41269 Mtetra
.625 .747 .934 r
.23804 .41269 .23908 .4136 .24061 .4132 .23957 .41229 Mtetra
.447 .683 .965 r
.23957 .41229 .24061 .4132 .24211 .41322 .24107 .41232 Mtetra
.61 .747 .943 r
.24107 .41232 .24211 .41322 .24365 .41285 .2426 .41197 Mtetra
.633 .756 .936 r
.2426 .41197 .24365 .41285 .24518 .41242 .24414 .41154 Mtetra
.639 .758 .935 r
.24414 .41154 .24518 .41242 .24673 .41197 .24568 .41109 Mtetra
.655 .763 .929 r
.24568 .41109 .24673 .41197 .24827 .41147 .24723 .41058 Mtetra
.665 .764 .923 r
.24723 .41058 .24827 .41147 .24982 .41094 .24878 .41004 Mtetra
.672 .763 .919 r
.24878 .41004 .24982 .41094 .25138 .41038 .25034 .40947 Mtetra
.677 .762 .915 r
.25034 .40947 .25138 .41038 .25293 .40981 .25189 .40888 Mtetra
.68 .759 .911 r
.25189 .40888 .25293 .40981 .25449 .40921 .25345 .40827 Mtetra
.682 .758 .909 r
.25345 .40827 .25449 .40921 .25606 .40857 .25502 .40766 Mtetra
.684 .764 .912 r
.25502 .40766 .25606 .40857 .25763 .40784 .25658 .40703 Mtetra
.685 .788 .928 r
.25658 .40703 .25763 .40784 .2592 .40708 .25814 .40641 Mtetra
.681 .819 .949 r
.25814 .40641 .2592 .40708 .26078 .40634 .25971 .40579 Mtetra
.665 .845 .969 r
.25971 .40579 .26078 .40634 .26234 .40571 .26127 .40521 Mtetra
.656 .855 .976 r
.26127 .40521 .26234 .40571 .26391 .40513 .26283 .40463 Mtetra
.653 .857 .978 r
.26283 .40463 .26391 .40513 .26547 .40457 .2644 .40406 Mtetra
.667 .858 .972 r
.2644 .40406 .26547 .40457 .26704 .40384 .26596 .40346 Mtetra
.65 .883 .983 r
.26596 .40346 .26704 .40384 .26861 .4032 .26753 .40286 Mtetra
.621 .888 .989 r
.26753 .40286 .26861 .4032 .27017 .4028 .2691 .40231 Mtetra
.582 .841 .994 r
.2691 .40231 .27017 .4028 .27164 .40338 .27065 .40191 Mtetra
.612 .64 .854 r
.27065 .40191 .27164 .40338 .27305 .40488 .2722 .40157 Mtetra
.59 .486 .703 r
.2722 .40157 .27305 .40488 .27437 .40754 .27375 .40124 Mtetra
.6 .432 .625 r
.27375 .40124 .27437 .40754 .27587 .40789 .27534 .40037 Mtetra
.587 .411 .61 r
.27534 .40037 .27587 .40789 .27748 .40679 .27693 .39958 Mtetra
.558 .392 .612 r
.27693 .39958 .27748 .40679 .27903 .40655 .27847 .39939 Mtetra
.298 .199 .57 r
.27847 .39939 .27903 .40655 .26613 .59732 .27977 .4024 Mtetra
0 0 .185 r
.27977 .4024 .26613 .59732 .26703 .60691 .2663 .60105 Mtetra
0 0 .245 r
.2663 .60105 .26703 .60691 .26845 .6097 .26742 .60783 Mtetra
.197 .376 .815 r
.26742 .60783 .26845 .6097 .27005 .61012 .26898 .60881 Mtetra
.622 .684 .888 r
.26898 .60881 .27005 .61012 .27172 .60965 .27064 .60841 Mtetra
.711 .723 .859 r
.27064 .60841 .27172 .60965 .27341 .60887 .27234 .60754 Mtetra
.594 .671 .893 r
.27234 .60754 .27341 .60887 .27507 .60863 .274 .60725 Mtetra
.597 .665 .886 r
.274 .60725 .27507 .60863 .27672 .60835 .27566 .60696 Mtetra
.716 .703 .837 r
.27566 .60696 .27672 .60835 .27843 .60742 .27737 .60601 Mtetra
.876 .722 .688 r
.27737 .60601 .27843 .60742 .28036 .60334 .2793 .60198 Mtetra
.945 .688 .516 r
.2793 .60198 .28036 .60334 .29625 .40243 .29518 .40206 Mtetra
.946 .746 .601 r
.29518 .40206 .29625 .40243 .29839 .39388 .29734 .39332 Mtetra
.876 .831 .799 r
.29734 .39332 .29839 .39388 .30007 .39192 .29903 .39126 Mtetra
.686 .826 .951 r
.29903 .39126 .30007 .39192 .30165 .39141 .30062 .39061 Mtetra
.539 .751 .974 r
.30062 .39061 .30165 .39141 .3032 .39136 .30218 .39041 Mtetra
.699 .764 .902 r
.30218 .39041 .3032 .39136 .3048 .39062 .30377 .38971 Mtetra
.718 .774 .896 r
.30377 .38971 .3048 .39062 .30641 .3897 .30538 .38891 Mtetra
.56 .761 .972 r
.30538 .38891 .30641 .3897 .30798 .38933 .30694 .38866 Mtetra
.807 .319 0 r
.30694 .38866 .30798 .38933 .30939 .39149 .30835 .39081 Mtetra
.948 .684 .503 r
.30835 .39081 .30939 .39149 .29785 .58814 .29685 .58592 Mtetra
.97 .662 .375 r
.29685 .58592 .29785 .58814 .29875 .59941 .2977 .59788 Mtetra
0 .155 .694 r
.2977 .59788 .29875 .59941 .30032 .60077 .29926 .59936 Mtetra
.613 .667 .878 r
.29926 .59936 .30032 .60077 .30201 .60023 .30094 .59899 Mtetra
.716 .727 .859 r
.30094 .59899 .30201 .60023 .30374 .59916 .30266 .59809 Mtetra
.61 .728 .929 r
.30266 .59809 .30374 .59916 .30542 .59881 .30434 .59771 Mtetra
.553 .703 .939 r
.30434 .59771 .30542 .59881 .30708 .59877 .30602 .59752 Mtetra
.7 .723 .868 r
.30602 .59752 .30708 .59877 .30879 .59811 .30773 .59672 Mtetra
.866 .728 .708 r
.30773 .59672 .30879 .59811 .31066 .59474 .30961 .59331 Mtetra
.948 .689 .51 r
.30961 .59331 .31066 .59474 .32462 .39706 .32358 .39658 Mtetra
.949 .729 .571 r
.32358 .39658 .32462 .39706 .32696 .38463 .32592 .38405 Mtetra
.891 .822 .773 r
.32592 .38405 .32696 .38463 .32867 .3823 .32764 .38164 Mtetra
.68 .827 .954 r
.32764 .38164 .32867 .3823 .33026 .38181 .32924 .38101 Mtetra
.501 .736 .978 r
.32924 .38101 .33026 .38181 .33182 .38187 .33082 .38089 Mtetra
.56 .716 .945 r
.33082 .38089 .33182 .38187 .3334 .38177 .3324 .38068 Mtetra
.634 .719 .909 r
.3324 .38068 .3334 .38177 .33499 .38133 .33399 .38024 Mtetra
.637 .721 .908 r
.33399 .38024 .33499 .38133 .33659 .38082 .33559 .3798 Mtetra
.651 .738 .913 r
.33559 .3798 .33659 .38082 .3382 .38019 .33719 .37929 Mtetra
.665 .769 .927 r
.33719 .37929 .3382 .38019 .33982 .37946 .3388 .37873 Mtetra
.669 .808 .95 r
.3388 .37873 .33982 .37946 .34143 .37872 .34041 .37814 Mtetra
.661 .844 .97 r
.34041 .37814 .34143 .37872 .34305 .37804 .34202 .37755 Mtetra
.651 .863 .98 r
.34202 .37755 .34305 .37804 .34466 .37743 .34363 .37696 Mtetra
.649 .868 .981 r
.34363 .37696 .34466 .37743 .34627 .37685 .34524 .37637 Mtetra
.649 .867 .981 r
.34524 .37637 .34627 .37685 .34788 .37626 .34685 .37578 Mtetra
.648 .866 .981 r
.34685 .37578 .34788 .37626 .34949 .37568 .34846 .3752 Mtetra
.647 .866 .982 r
.34846 .3752 .34949 .37568 .3511 .3751 .35008 .37461 Mtetra
.645 .865 .982 r
.35008 .37461 .3511 .3751 .35272 .37453 .35169 .37404 Mtetra
.644 .863 .982 r
.35169 .37404 .35272 .37453 .35433 .37396 .35331 .37346 Mtetra
.644 .861 .982 r
.35331 .37346 .35433 .37396 .35595 .3734 .35492 .37289 Mtetra
.645 .859 .981 r
.35492 .37289 .35595 .3734 .35756 .37284 .35654 .37232 Mtetra
.645 .858 .981 r
.35654 .37232 .35756 .37284 .35918 .37227 .35816 .37175 Mtetra
.644 .857 .981 r
.35816 .37175 .35918 .37227 .3608 .37173 .35977 .37119 Mtetra
.642 .85 .979 r
.35977 .37119 .3608 .37173 .36241 .37126 .36139 .37063 Mtetra
.646 .83 .971 r
.36139 .37063 .36241 .37126 .36402 .37086 .36301 .37009 Mtetra
.656 .798 .951 r
.36301 .37009 .36402 .37086 .36563 .37046 .36463 .36954 Mtetra
.663 .766 .927 r
.36463 .36954 .36563 .37046 .36725 .37 .36626 .36898 Mtetra
.668 .746 .909 r
.36626 .36898 .36725 .37 .36887 .36946 .36788 .3684 Mtetra
.67 .739 .902 r
.36788 .3684 .36887 .36946 .3705 .36888 .36951 .36781 Mtetra
.674 .737 .898 r
.36951 .36781 .3705 .36888 .37212 .3683 .37113 .36719 Mtetra
.677 .733 .892 r
.37113 .36719 .37212 .3683 .37375 .36771 .37276 .36657 Mtetra
.676 .724 .886 r
.37276 .36657 .37375 .36771 .37538 .3671 .37439 .36594 Mtetra
.71 .732 .868 r
.37439 .36594 .37538 .3671 .37702 .36625 .37603 .36513 Mtetra
.727 .742 .863 r
.37603 .36513 .37702 .36625 .37867 .36525 .37768 .36421 Mtetra
.635 .733 .919 r
.37768 .36421 .37867 .36525 .3803 .36459 .3793 .36376 Mtetra
0 .159 .625 r
.3793 .36376 .3803 .36459 .38189 .36498 .38086 .3649 Mtetra
.93 .594 .379 r
.38086 .3649 .38189 .36498 .38337 .36768 .3821 .37302 Mtetra
.948 .676 .49 r
.3821 .37302 .38337 .36768 .38422 .38519 .37491 .57223 Mtetra
.543 .317 .523 r
.37491 .57223 .38422 .38519 .37786 .56907 .37651 .57491 Mtetra
.499 .208 .402 r
.37651 .57491 .37786 .56907 .3796 .56859 .37824 .57466 Mtetra
.455 .171 .391 r
.37824 .57466 .3796 .56859 .38137 .56737 .38 .57379 Mtetra
.465 .183 .401 r
.38 .57379 .38137 .56737 .38304 .56845 .38175 .57297 Mtetra
.484 .174 .364 r
.38175 .57297 .38304 .56845 .38464 .57136 .38349 .5727 Mtetra
.328 0 .007 r
.38349 .5727 .38464 .57136 .38629 .57301 .38522 .57241 Mtetra
.557 .825 .996 r
.38522 .57241 .38629 .57301 .388 .5735 .38696 .57203 Mtetra
.644 .675 .864 r
.38696 .57203 .388 .5735 .38974 .57294 .38871 .5715 Mtetra
.654 .683 .865 r
.38871 .5715 .38974 .57294 .3915 .57212 .39046 .57091 Mtetra
.617 .709 .911 r
.39046 .57091 .3915 .57212 .39326 .57151 .39221 .57051 Mtetra
.53 .718 .959 r
.39221 .57051 .39326 .57151 .39499 .57141 .39394 .57034 Mtetra
.673 .756 .913 r
.39394 .57034 .39499 .57141 .39674 .57098 .3957 .56969 Mtetra
.834 .749 .769 r
.3957 .56969 .39674 .57098 .39853 .56951 .39752 .56748 Mtetra
.914 .698 .597 r
.39752 .56748 .39853 .56951 .40041 .56542 .3996 .55825 Mtetra
.951 .682 .493 r
.3996 .55825 .40041 .56542 .40268 .55064 .40867 .35727 Mtetra
.546 .325 .53 r
.40867 .35727 .40268 .55064 .41121 .36041 .41044 .3535 Mtetra
.595 .423 .618 r
.41044 .3535 .41121 .36041 .41287 .35962 .4121 .35261 Mtetra
.566 .401 .617 r
.4121 .35261 .41287 .35962 .4145 .35954 .41374 .35228 Mtetra
.563 .396 .614 r
.41374 .35228 .4145 .35954 .41619 .35796 .41538 .35199 Mtetra
.597 .434 .632 r
.41538 .35199 .41619 .35796 .41795 .35441 .41704 .3512 Mtetra
.635 .521 .706 r
.41704 .3512 .41795 .35441 .41966 .35191 .41871 .35041 Mtetra
.679 .672 .836 r
.41871 .35041 .41966 .35191 .42135 .35034 .42037 .34969 Mtetra
.654 .832 .969 r
.42037 .34969 .42135 .35034 .42301 .34977 .42202 .34911 Mtetra
.64 .828 .973 r
.42202 .34911 .42301 .34977 .42466 .34943 .42368 .34858 Mtetra
.68 .792 .934 r
.42368 .34858 .42466 .34943 .42631 .34898 .42534 .34794 Mtetra
.731 .763 .878 r
.42534 .34794 .42631 .34898 .42798 .34802 .42701 .34702 Mtetra
.651 .749 .922 r
.42701 .34702 .42798 .34802 .42964 .34732 .42867 .34649 Mtetra
.038 .472 .881 r
.42867 .34649 .42964 .34732 .43128 .34738 .43029 .34711 Mtetra
.921 .547 .293 r
.43029 .34711 .43128 .34738 .43286 .34964 .43177 .35274 Mtetra
.956 .679 .473 r
.43177 .35274 .43286 .34964 .43429 .35743 .4276 .55481 Mtetra
.544 .318 .523 r
.4276 .55481 .43429 .35743 .43048 .55257 .42925 .55862 Mtetra
.513 .222 .409 r
.42925 .55862 .43048 .55257 .43224 .55252 .43101 .55854 Mtetra
.464 .178 .393 r
.43101 .55854 .43224 .55252 .43403 .55147 .4328 .55777 Mtetra
.457 .175 .396 r
.4328 .55777 .43403 .55147 .43578 .55176 .43458 .55686 Mtetra
.49 .189 .382 r
.43458 .55686 .43578 .55176 .43746 .55482 .43636 .55657 Mtetra
.38 0 .114 r
.43636 .55657 .43746 .55482 .43918 .55662 .43813 .55628 Mtetra
.46 .843 .984 r
.43813 .55628 .43918 .55662 .44093 .55742 .43991 .55593 Mtetra
.64 .674 .867 r
.43991 .55593 .44093 .55742 .44271 .55706 .44169 .55541 Mtetra
.645 .654 .844 r
.44169 .55541 .44271 .55706 .44449 .55644 .44348 .55484 Mtetra
.649 .663 .85 r
.44348 .55484 .44449 .55644 .44628 .55577 .44526 .55426 Mtetra
.646 .674 .863 r
.44526 .55426 .44628 .55577 .44806 .55539 .44705 .55371 Mtetra
.643 .648 .841 r
.44705 .55371 .44806 .55539 .44985 .55501 .44884 .55315 Mtetra
.64 .627 .822 r
.44884 .55315 .44985 .55501 .45163 .55454 .45063 .55259 Mtetra
.64 .618 .812 r
.45063 .55259 .45163 .55454 .45342 .55386 .45242 .55202 Mtetra
.642 .63 .823 r
.45242 .55202 .45342 .55386 .45522 .55314 .45421 .55145 Mtetra
.645 .649 .839 r
.45421 .55145 .45522 .55314 .45701 .55243 .456 .55087 Mtetra
.646 .668 .857 r
.456 .55087 .45701 .55243 .45881 .55183 .45779 .55031 Mtetra
.646 .673 .862 r
.45779 .55031 .45881 .55183 .4606 .55127 .45959 .54976 Mtetra
.646 .674 .862 r
.45959 .54976 .4606 .55127 .4624 .55072 .46139 .5492 Mtetra
.646 .673 .862 r
.46139 .5492 .4624 .55072 .4642 .55016 .46318 .54864 Mtetra
.646 .674 .862 r
.46318 .54864 .4642 .55016 .46599 .5496 .46498 .54809 Mtetra
.646 .674 .863 r
.46498 .54809 .46599 .5496 .46779 .54904 .46678 .54753 Mtetra
.645 .674 .863 r
.46678 .54753 .46779 .54904 .46959 .54849 .46858 .54697 Mtetra
.46858 .54697 .46959 .54849 .47139 .54793 .47038 .54642 Mtetra
.47038 .54642 .47139 .54793 .4732 .54738 .47219 .54586 Mtetra
.646 .674 .862 r
.47219 .54586 .4732 .54738 .475 .54683 .47399 .5453 Mtetra
.646 .673 .862 r
.47399 .5453 .475 .54683 .47681 .54628 .4758 .54474 Mtetra
.646 .672 .861 r
.4758 .54474 .47681 .54628 .47861 .54572 .4776 .54418 Mtetra
.648 .671 .859 r
.4776 .54418 .47861 .54572 .48042 .54517 .47941 .5436 Mtetra
.647 .668 .856 r
.47941 .5436 .48042 .54517 .48223 .54462 .48122 .54303 Mtetra
.644 .664 .854 r
.48122 .54303 .48223 .54462 .48404 .54407 .48303 .54248 Mtetra
.636 .66 .856 r
.48303 .54248 .48404 .54407 .48585 .54353 .48484 .54196 Mtetra
.635 .664 .861 r
.48484 .54196 .48585 .54353 .48766 .54298 .48665 .54146 Mtetra
.635 .67 .866 r
.48665 .54146 .48766 .54298 .48947 .54244 .48847 .54095 Mtetra
.631 .674 .872 r
.48847 .54095 .48947 .54244 .49129 .54212 .49028 .54047 Mtetra
.637 .653 .849 r
.49028 .54047 .49129 .54212 .4931 .54163 .4921 .53995 Mtetra
.648 .654 .842 r
.4921 .53995 .4931 .54163 .49492 .54081 .49392 .53936 Mtetra
.596 .664 .887 r
.49392 .53936 .49492 .54081 .49675 .53905 .49573 .53904 Mtetra
.517 .912 .913 r
.49573 .53904 .49675 .53905 .49859 .53628 .49755 .53831 Mtetra
.063 0 .002 r
.49755 .53831 .49859 .53628 .50044 .53086 .49938 .53677 Mtetra
0 0 .097 r
.49938 .53677 .50044 .53086 .50361 .32955 .50125 .52974 Mtetra
0 0 .312 r
.50125 .52974 .50361 .32955 .50536 .32362 .5044 .32537 Mtetra
.917 .883 .461 r
.5044 .32537 .50536 .32362 .50708 .32082 .50613 .32023 Mtetra
.794 .878 .908 r
.50613 .32023 .50708 .32082 .50879 .31982 .50785 .31903 Mtetra
.629 .799 .964 r
.50785 .31903 .50879 .31982 .5105 .3193 .50956 .31854 Mtetra
.487 .749 .987 r
.50956 .31854 .5105 .3193 .5122 .31906 .51127 .3184 Mtetra
.63 .832 .978 r
.51127 .3184 .5122 .31906 .51392 .31867 .51298 .31787 Mtetra
.647 .802 .958 r
.51298 .31787 .51392 .31867 .51563 .31827 .51469 .31732 Mtetra
.654 .767 .933 r
.51469 .31732 .51563 .31827 .51734 .31784 .51641 .31676 Mtetra
.661 .744 .912 r
.51641 .31676 .51734 .31784 .51906 .31715 .51812 .31618 Mtetra
.663 .767 .927 r
.51812 .31618 .51906 .31715 .52077 .3164 .51984 .31558 Mtetra
.663 .803 .95 r
.51984 .31558 .52077 .3164 .52249 .31564 .52156 .31498 Mtetra
.671 .843 .966 r
.52156 .31498 .52249 .31564 .52421 .3148 .52327 .31432 Mtetra
.646 .88 .984 r
.52327 .31432 .52421 .3148 .52593 .31412 .52499 .31367 Mtetra
.617 .881 .99 r
.52499 .31367 .52593 .31412 .52765 .31373 .52672 .31309 Mtetra
.711 .857 .952 r
.52672 .31309 .52765 .31373 .52937 .31413 .52844 .31228 Mtetra
.631 .613 .814 r
.52844 .31228 .52937 .31413 .53109 .31544 .53016 .31178 Mtetra
.53 .44 .698 r
.53016 .31178 .53109 .31544 .53283 .31906 .53189 .31196 Mtetra
.194 .138 .562 r
.53189 .31196 .53283 .31906 .53518 .51946 .53363 .31643 Mtetra
0 0 .343 r
.53363 .31643 .53518 .51946 .53704 .52523 .53604 .52044 Mtetra
0 0 .499 r
.53604 .52044 .53704 .52523 .5389 .52728 .5379 .52547 Mtetra
.402 .514 .857 r
.5379 .52547 .5389 .52728 .54075 .5275 .53976 .52597 Mtetra
.638 .672 .866 r
.53976 .52597 .54075 .5275 .5426 .52698 .54161 .52544 Mtetra
.712 .701 .838 r
.54161 .52544 .5426 .52698 .54444 .5259 .54345 .52444 Mtetra
.622 .678 .883 r
.54345 .52444 .54444 .5259 .54629 .52423 .54531 .524 Mtetra
.569 .914 .968 r
.54531 .524 .54629 .52423 .54813 .52166 .54716 .52332 Mtetra
.023 0 0 r
.54716 .52332 .54813 .52166 .54995 .51699 .54901 .52192 Mtetra
0 0 .131 r
.54901 .52192 .54995 .51699 .55018 .31564 .55083 .51651 Mtetra
0 0 .335 r
.55083 .51651 .55018 .31564 .55186 .30812 .55098 .31116 Mtetra
.759 .755 .242 r
.55098 .31116 .55186 .30812 .55358 .30504 .55266 .30471 Mtetra
.862 .935 .869 r
.55266 .30471 .55358 .30504 .55531 .30393 .55439 .30306 Mtetra
.664 .794 .944 r
.55439 .30306 .55531 .30393 .55705 .30349 .55613 .30244 Mtetra
.558 .715 .945 r
.55613 .30244 .55705 .30349 .55879 .3033 .55788 .30222 Mtetra
.656 .745 .916 r
.55788 .30222 .55879 .3033 .56053 .30252 .55962 .30165 Mtetra
.675 .797 .94 r
.55962 .30165 .56053 .30252 .56227 .30168 .56136 .30099 Mtetra
.652 .836 .971 r
.56136 .30099 .56227 .30168 .56401 .30109 .5631 .30039 Mtetra
.711 .848 .948 r
.5631 .30039 .56401 .30109 .56577 .30131 .56485 .29957 Mtetra
.647 .637 .826 r
.56485 .29957 .56577 .30131 .56754 .30242 .56659 .29899 Mtetra
.546 .46 .709 r
.56659 .29899 .56754 .30242 .56934 .30534 .56835 .29903 Mtetra
.268 .202 .595 r
.56835 .29903 .56934 .30534 .57403 .50388 .57015 .30242 Mtetra
0 0 .356 r
.57015 .30242 .57403 .50388 .57603 .512 .57499 .50664 Mtetra
0 0 .449 r
.57499 .50664 .57603 .512 .57794 .51445 .57697 .51297 Mtetra
.053 .351 .826 r
.57697 .51297 .57794 .51445 .57984 .51526 .57887 .51418 Mtetra
.567 .728 .95 r
.57887 .51418 .57984 .51526 .58172 .5151 .58075 .5139 Mtetra
.773 .773 .852 r
.58075 .5139 .58172 .5151 .58359 .514 .58261 .51256 Mtetra
.91 .751 .673 r
.58261 .51256 .58359 .514 .5854 .50967 .58442 .5082 Mtetra
.972 .688 .429 r
.58442 .5082 .5854 .50967 .58343 .30383 .58254 .30343 Mtetra
.981 .767 .543 r
.58254 .30343 .58343 .30383 .58503 .29486 .58414 .29422 Mtetra
.886 .868 .815 r
.58414 .29422 .58503 .29486 .58676 .29292 .58587 .29217 Mtetra
.666 .828 .961 r
.58587 .29217 .58676 .29292 .58853 .29242 .58762 .29152 Mtetra
.527 .739 .972 r
.58762 .29152 .58853 .29242 .5903 .29241 .58939 .29133 Mtetra
.629 .739 .927 r
.58939 .29133 .5903 .29241 .59206 .29191 .59116 .29086 Mtetra
.669 .761 .919 r
.59116 .29086 .59206 .29191 .59382 .29119 .59292 .29023 Mtetra
.66 .775 .934 r
.59292 .29023 .59382 .29119 .59558 .29069 .59468 .28963 Mtetra
.709 .769 .899 r
.59468 .28963 .59558 .29069 .59737 .29082 .59644 .2888 Mtetra
.653 .611 .794 r
.59644 .2888 .59737 .29082 .59917 .29176 .59821 .28812 Mtetra
.561 .462 .699 r
.59821 .28812 .59917 .29176 .60101 .29426 .59999 .28802 Mtetra
.334 .251 .611 r
.59999 .28802 .60101 .29426 .60772 .49107 .60184 .29078 Mtetra
0 0 .369 r
.60184 .29078 .60772 .49107 .60987 .5011 .60878 .4945 Mtetra
0 0 .446 r
.60878 .4945 .60987 .5011 .61185 .50379 .61088 .50213 Mtetra
0 .281 .781 r
.61088 .50213 .61185 .50379 .61379 .50473 .61283 .50366 Mtetra
.525 .714 .958 r
.61283 .50366 .61379 .50473 .6157 .50467 .61474 .5035 Mtetra
.757 .779 .871 r
.61474 .5035 .6157 .50467 .61759 .50372 .61663 .5023 Mtetra
.903 .76 .693 r
.61663 .5023 .61759 .50372 .61941 .50017 .61844 .49848 Mtetra
.974 .686 .416 r
.61844 .49848 .61941 .50017 .61579 .30935 .61456 .29677 Mtetra
.777 .529 .56 r
.61456 .29677 .61579 .30935 .61688 .28497 .61598 .28369 Mtetra
.861 .766 .756 r
.61598 .28369 .61688 .28497 .6186 .28243 .6177 .28127 Mtetra
.68 .742 .898 r
.6177 .28127 .6186 .28243 .62037 .28172 .61948 .28057 Mtetra
.555 .695 .933 r
.61948 .28057 .62037 .28172 .62216 .28152 .62127 .28037 Mtetra
.615 .721 .921 r
.62127 .28037 .62216 .28152 .62395 .28101 .62306 .27996 Mtetra
.675 .765 .918 r
.62306 .27996 .62395 .28101 .62573 .28025 .62484 .27929 Mtetra
.669 .783 .934 r
.62484 .27929 .62573 .28025 .62751 .27971 .62663 .27865 Mtetra
.71 .774 .902 r
.62663 .27865 .62751 .27971 .62932 .27973 .6284 .27781 Mtetra
.666 .629 .802 r
.6284 .27781 .62932 .27973 .63115 .28054 .63019 .27705 Mtetra
.573 .476 .706 r
.63019 .27705 .63115 .28054 .63304 .28273 .63199 .27684 Mtetra
.378 .288 .626 r
.63199 .27684 .63304 .28273 .64163 .47422 .63387 .27903 Mtetra
0 0 .377 r
.63387 .27903 .64163 .47422 .64413 .48996 .6429 .48104 Mtetra
0 0 .441 r
.6429 .48104 .64413 .48996 .64617 .49291 .6452 .49104 Mtetra
0 .227 .743 r
.6452 .49104 .64617 .49291 .64815 .49388 .64721 .4929 Mtetra
.486 .716 .973 r
.64721 .4929 .64815 .49388 .65009 .49374 .64915 .49281 Mtetra
.758 .827 .906 r
.64915 .49281 .65009 .49374 .65199 .4927 .65106 .49167 Mtetra
.923 .805 .713 r
.65106 .49167 .65199 .4927 .65381 .48927 .65287 .48814 Mtetra
.976 .685 .402 r
.65287 .48814 .65381 .48927 .64804 .29419 .6471 .29145 Mtetra
.955 .691 .497 r
.6471 .29145 .64804 .29419 .64907 .27398 .64819 .2728 Mtetra
.888 .784 .741 r
.64819 .2728 .64907 .27398 .65078 .27121 .6499 .27005 Mtetra
.692 .749 .895 r
.6499 .27005 .65078 .27121 .65257 .27044 .6517 .26928 Mtetra
.57 .701 .93 r
.6517 .26928 .65257 .27044 .65439 .27019 .65351 .26903 Mtetra
.601 .716 .925 r
.65351 .26903 .65439 .27019 .6562 .26974 .65532 .26867 Mtetra
.676 .763 .916 r
.65532 .26867 .6562 .26974 .65799 .26896 .65713 .26799 Mtetra
.672 .784 .933 r
.65713 .26799 .65799 .26896 .6598 .26837 .65893 .26732 Mtetra
.706 .778 .908 r
.65893 .26732 .6598 .26837 .66163 .26827 .66073 .2665 Mtetra
.68 .653 .816 r
.66073 .2665 .66163 .26827 .66349 .26891 .66252 .26567 Mtetra
.588 .497 .718 r
.66252 .26567 .66349 .26891 .66541 .27063 .66434 .26533 Mtetra
.427 .332 .645 r
.66434 .26533 .66541 .27063 .66758 .27789 .66625 .26684 Mtetra
0 0 .429 r
.66625 .26684 .66758 .27789 .67873 .47759 .66867 .27933 Mtetra
0 0 .397 r
.66867 .27933 .67873 .47759 .68087 .48125 .67989 .47893 Mtetra
.029 .216 .722 r
.67989 .47893 .68087 .48125 .68289 .48211 .68197 .48108 Mtetra
.609 .761 .952 r
.68197 .48108 .68289 .48211 .68483 .48155 .68392 .48062 Mtetra
.753 .829 .911 r
.68392 .48062 .68483 .48155 .68676 .48058 .68584 .4795 Mtetra
.747 .799 .894 r
.68584 .4795 .68676 .48058 .68869 .47969 .68776 .47838 Mtetra
.671 .731 .895 r
.68776 .47838 .68869 .47969 .69065 .47916 .68971 .47766 Mtetra
.659 .696 .873 r
.68971 .47766 .69065 .47916 .6926 .47865 .69165 .47699 Mtetra
.64 .665 .858 r
.69165 .47699 .6926 .47865 .69455 .47809 .69361 .47642 Mtetra
.622 .654 .861 r
.69361 .47642 .69455 .47809 .6965 .47747 .69557 .47594 Mtetra
.613 .673 .883 r
.69557 .47594 .6965 .47747 .69846 .47685 .69753 .47551 Mtetra
.534 .667 .923 r
.69753 .47551 .69846 .47685 .70043 .47659 .69951 .4754 Mtetra
.467 .661 .946 r
.69951 .4754 .70043 .47659 .70242 .4766 .7015 .47545 Mtetra
.642 .751 .928 r
.7015 .47545 .70242 .4766 .70438 .47601 .70346 .47487 Mtetra
.887 .807 .764 r
.70346 .47487 .70438 .47601 .70623 .47335 .70531 .4722 Mtetra
.98 .727 .478 r
.70531 .4722 .70623 .47335 .70736 .45793 .70643 .45641 Mtetra
.977 .681 .379 r
.70643 .45641 .70736 .45793 .69808 .25751 .69722 .25632 Mtetra
.912 .788 .711 r
.69722 .25632 .69808 .25751 .69976 .25422 .6989 .25305 Mtetra
.71 .757 .889 r
.6989 .25305 .69976 .25422 .70158 .25335 .70072 .25218 Mtetra
.588 .708 .926 r
.70072 .25218 .70158 .25335 .70343 .25303 .70257 .25186 Mtetra
.623 .724 .919 r
.70257 .25186 .70343 .25303 .70527 .25257 .70441 .2514 Mtetra
.732 .766 .88 r
.70441 .2514 .70527 .25257 .70708 .25157 .70623 .2504 Mtetra
.64 .732 .915 r
.70623 .2504 .70708 .25157 .70892 .25103 .70807 .24986 Mtetra
.062 .398 .855 r
.70807 .24986 .70892 .25103 .71086 .25207 .71001 .2509 Mtetra
.925 .553 .14 r
.71001 .2509 .71086 .25207 .71331 .26142 .71246 .2603 Mtetra
.975 .671 .352 r
.71246 .2603 .71331 .26142 .72781 .46584 .72691 .46474 Mtetra
.606 .142 0 r
.72691 .46474 .72781 .46584 .73 .46881 .7291 .4677 Mtetra
.417 .655 .957 r
.7291 .4677 .73 .46881 .73203 .46896 .73113 .46785 Mtetra
.712 .788 .911 r
.73113 .46785 .73203 .46896 .73399 .46803 .73309 .46692 Mtetra
.89 .818 .77 r
.73309 .46692 .73399 .46803 .73584 .4654 .73494 .4643 Mtetra
.978 .758 .536 r
.73494 .4643 .73584 .4654 .73727 .4562 .73638 .45523 Mtetra
.978 .679 .364 r
.73638 .45523 .73727 .4562 .72574 .24904 .72489 .24793 Mtetra
.94 .794 .671 r
.72489 .24793 .72574 .24904 .72736 .24505 .72652 .24391 Mtetra
.722 .771 .892 r
.72652 .24391 .72736 .24505 .72919 .24412 .72835 .24298 Mtetra
.579 .712 .934 r
.72835 .24298 .72919 .24412 .73107 .24383 .73023 .24268 Mtetra
.54 .693 .939 r
.73023 .24268 .73107 .24383 .73295 .24366 .73211 .24251 Mtetra
.657 .745 .915 r
.73211 .24251 .73295 .24366 .7348 .24306 .73396 .2419 Mtetra
.662 .746 .912 r
.73396 .2419 .7348 .24306 .73666 .24243 .73582 .24126 Mtetra
.7 .76 .898 r
.73582 .24126 .73666 .24243 .7385 .24161 .73766 .24044 Mtetra
.757 .778 .87 r
.73766 .24044 .7385 .24161 .74032 .24046 .73948 .23928 Mtetra
.673 .748 .907 r
.73948 .23928 .74032 .24046 .74218 .23977 .74134 .23859 Mtetra
.238 .514 .91 r
.74134 .23859 .74218 .23977 .74413 .24044 .74329 .23926 Mtetra
.896 .509 .064 r
.74329 .23926 .74413 .24044 .7466 .24834 .74577 .24718 Mtetra
.975 .667 .334 r
.74577 .24718 .7466 .24834 .76353 .45443 .76264 .4533 Mtetra
.638 .182 0 r
.76264 .4533 .76353 .45443 .76582 .45777 .76493 .45664 Mtetra
.391 .636 .953 r
.76493 .45664 .76582 .45777 .76788 .458 .767 .45687 Mtetra
.695 .781 .918 r
.767 .45687 .76788 .458 .76987 .45716 .76899 .45603 Mtetra
.873 .82 .793 r
.76899 .45603 .76987 .45716 .77175 .45483 .77086 .45369 Mtetra
.978 .767 .552 r
.77086 .45369 .77175 .45483 .7732 .44696 .77232 .44582 Mtetra
.977 .675 .347 r
.77232 .44582 .7732 .44696 .75926 .23811 .75843 .23692 Mtetra
.95 .784 .641 r
.75843 .23692 .75926 .23811 .76082 .23347 .75999 .23227 Mtetra
.747 .772 .873 r
.75999 .23227 .76082 .23347 .76266 .23236 .76183 .23117 Mtetra
.621 .723 .919 r
.76183 .23117 .76266 .23236 .76454 .2319 .76371 .2307 Mtetra
.59 .709 .925 r
.76371 .2307 .76454 .2319 .76644 .23156 .76561 .23036 Mtetra
.749 .772 .872 r
.76561 .23036 .76644 .23156 .76828 .23044 .76745 .22924 Mtetra
.675 .746 .904 r
.76745 .22924 .76828 .23044 .77015 .22974 .76932 .22854 Mtetra
.376 .594 .931 r
.76932 .22854 .77015 .22974 .7721 .23008 .77128 .22888 Mtetra
.808 .396 0 r
.77128 .22888 .7721 .23008 .77448 .23561 .77366 .23438 Mtetra
.973 .663 .318 r
.77366 .23438 .77448 .23561 .79354 .44372 .79267 .44255 Mtetra
.707 .267 0 r
.79267 .44255 .79354 .44372 .79595 .44789 .79508 .44672 Mtetra
.504 .692 .953 r
.79508 .44672 .79595 .44789 .79802 .4478 .79715 .44664 Mtetra
.692 .777 .916 r
.79715 .44664 .79802 .4478 .80003 .44697 .79916 .4458 Mtetra
.732 .79 .899 r
.79916 .4458 .80003 .44697 .80202 .44591 .80115 .44473 Mtetra
.499 .687 .951 r
.80115 .44473 .80202 .44591 .80409 .44585 .80323 .44467 Mtetra
.625 .747 .934 r
.80323 .44467 .80409 .44585 .80613 .44532 .80527 .44414 Mtetra
.807 .808 .852 r
.80527 .44414 .80613 .44532 .80808 .44372 .80721 .44252 Mtetra
.978 .771 .558 r
.80721 .44252 .80808 .44372 .80953 .4364 .80865 .43512 Mtetra
.976 .671 .329 r
.80865 .43512 .80953 .4364 .79318 .22687 .79235 .22561 Mtetra
.957 .779 .621 r
.79235 .22561 .79318 .22687 .79468 .22177 .79386 .22054 Mtetra
.752 .771 .869 r
.79386 .22054 .79468 .22177 .79652 .22061 .79571 .21939 Mtetra
.624 .721 .916 r
.79571 .21939 .79652 .22061 .79843 .22014 .79762 .21891 Mtetra
.554 .688 .929 r
.79762 .21891 .79843 .22014 .80037 .21993 .79956 .21871 Mtetra
.747 .771 .873 r
.79956 .21871 .80037 .21993 .80222 .21881 .80141 .21759 Mtetra
.678 .746 .902 r
.80141 .21759 .80222 .21881 .80411 .21808 .8033 .21686 Mtetra
.457 .638 .934 r
.8033 .21686 .80411 .21808 .80608 .2182 .80527 .21698 Mtetra
.769 .354 0 r
.80527 .21698 .80608 .2182 .80853 .22342 .80772 .22219 Mtetra
.971 .657 .298 r
.80772 .22219 .80853 .22342 .83009 .43233 .82923 .43116 Mtetra
.724 .29 0 r
.82923 .43116 .83009 .43233 .83262 .43694 .83177 .43578 Mtetra
.307 .581 .938 r
.83177 .43578 .83262 .43694 .83478 .43743 .83393 .43626 Mtetra
.65 .764 .933 r
.83393 .43626 .83478 .43743 .83683 .43678 .83598 .43562 Mtetra
.83 .821 .84 r
.83598 .43562 .83683 .43678 .83877 .43497 .83792 .43381 Mtetra
.975 .789 .588 r
.83792 .43381 .83877 .43497 .84029 .42884 .83945 .42769 Mtetra
.974 .667 .312 r
.83945 .42769 .84029 .42884 .82186 .21852 .82106 .21732 Mtetra
.975 .776 .572 r
.82106 .21732 .82186 .21852 .82323 .21225 .82243 .21104 Mtetra
.762 .76 .851 r
.20772 .42248 .20877 .42345 .21036 .42237 .2093 .4214 Mtetra
.617 .731 .928 r
.2093 .4214 .21036 .42237 .21187 .422 .21082 .42104 Mtetra
.464 .676 .957 r
.21082 .42104 .21187 .422 .21335 .42201 .2123 .42106 Mtetra
.66 .746 .914 r
.2123 .42106 .21335 .42201 .21488 .4215 .21383 .42054 Mtetra
.668 .749 .91 r
.21383 .42054 .21488 .4215 .21641 .42094 .21536 .41999 Mtetra
.674 .751 .909 r
.21536 .41999 .21641 .42094 .21795 .42035 .2169 .41942 Mtetra
.766 .767 .854 r
.2169 .41942 .21795 .42035 .21954 .41924 .21849 .41832 Mtetra
.712 .765 .894 r
.21849 .41832 .21954 .41924 .2211 .41847 .22004 .41757 Mtetra
.489 .703 .965 r
.22004 .41757 .2211 .41847 .22259 .41839 .22154 .41752 Mtetra
.926 .552 .277 r
.22154 .41752 .22259 .41839 .2237 .42247 .22263 .42172 Mtetra
.939 .682 .523 r
.22263 .42172 .2237 .42247 .20681 .62148 .20567 .62077 Mtetra
.926 .571 .334 r
.20567 .62077 .20681 .62148 .2079 .62687 .20677 .626 Mtetra
0 .356 .793 r
.20677 .626 .2079 .62687 .20942 .62765 .20829 .62676 Mtetra
.623 .763 .946 r
.20829 .62676 .20942 .62765 .21104 .62723 .20992 .62633 Mtetra
.804 .785 .835 r
.20992 .62633 .21104 .62723 .21277 .62574 .21164 .62485 Mtetra
.908 .745 .667 r
.21164 .62485 .21277 .62574 .21483 .62054 .2137 .61971 Mtetra
.939 .687 .53 r
.2137 .61971 .21483 .62054 .23434 .42052 .23328 .4197 Mtetra
.919 .733 .635 r
.23328 .4197 .23434 .42052 .23642 .41403 .23537 .4131 Mtetra
.794 .77 .831 r
.23537 .4131 .23642 .41403 .23804 .41269 .23699 .41175 Mtetra
.625 .741 .931 r
.23699 .41175 .23804 .41269 .23957 .41229 .23852 .41135 Mtetra
.45 .677 .962 r
.23852 .41135 .23957 .41229 .24107 .41232 .24002 .41139 Mtetra
.611 .74 .937 r
.24002 .41139 .24107 .41232 .2426 .41197 .24155 .41104 Mtetra
.635 .747 .929 r
.24155 .41104 .2426 .41197 .24414 .41154 .24309 .4106 Mtetra
.643 .748 .925 r
.24309 .4106 .24414 .41154 .24568 .41109 .24464 .41014 Mtetra
.658 .749 .918 r
.24464 .41014 .24568 .41109 .24723 .41058 .24619 .40963 Mtetra
.67 .751 .911 r
.24619 .40963 .24723 .41058 .24878 .41004 .24774 .40907 Mtetra
.682 .75 .903 r
.24774 .40907 .24878 .41004 .25034 .40947 .2493 .40845 Mtetra
.7 .745 .886 r
.2493 .40845 .25034 .40947 .25189 .40888 .25087 .40774 Mtetra
.701 .723 .867 r
.25087 .40774 .25189 .40888 .25345 .40827 .25244 .407 Mtetra
.693 .699 .851 r
.25244 .407 .25345 .40827 .25502 .40766 .25401 .40628 Mtetra
.676 .678 .843 r
.25401 .40628 .25502 .40766 .25658 .40703 .25558 .40562 Mtetra
.667 .67 .844 r
.25558 .40562 .25658 .40703 .25814 .40641 .25714 .40502 Mtetra
.659 .671 .851 r
.25714 .40502 .25814 .40641 .25971 .40579 .2587 .40447 Mtetra
.643 .675 .866 r
.2587 .40447 .25971 .40579 .26127 .40521 .26026 .404 Mtetra
.637 .693 .886 r
.26026 .404 .26127 .40521 .26283 .40463 .26181 .40357 Mtetra
.638 .72 .908 r
.26181 .40357 .26283 .40463 .2644 .40406 .26336 .40313 Mtetra
.654 .753 .922 r
.26336 .40313 .2644 .40406 .26596 .40346 .26492 .40262 Mtetra
.667 .779 .932 r
.26492 .40262 .26596 .40346 .26753 .40286 .26649 .40207 Mtetra
.68 .79 .933 r
.26649 .40207 .26753 .40286 .2691 .40231 .26805 .40146 Mtetra
.701 .782 .914 r
.26805 .40146 .2691 .40231 .27065 .40191 .26963 .40076 Mtetra
.698 .723 .869 r
.26963 .40076 .27065 .40191 .2722 .40157 .27121 .40003 Mtetra
.68 .658 .821 r
.27121 .40003 .2722 .40157 .27375 .40124 .27279 .39932 Mtetra
.688 .621 .776 r
.27279 .39932 .27375 .40124 .27534 .40037 .27439 .39842 Mtetra
.667 .61 .781 r
.27439 .39842 .27534 .40037 .27693 .39958 .27597 .39769 Mtetra
.598 .582 .806 r
.27597 .39769 .27693 .39958 .27847 .39939 .27752 .39741 Mtetra
0 .209 .724 r
.27752 .39741 .27847 .39939 .27977 .4024 .27894 .39885 Mtetra
.749 .478 0 r
.27894 .39885 .27977 .4024 .2663 .60105 .28007 .40414 Mtetra
0 0 .195 r
.28007 .40414 .2663 .60105 .26742 .60783 .26671 .60162 Mtetra
.158 .116 .557 r
.26671 .60162 .26742 .60783 .26898 .60881 .26808 .6052 Mtetra
.384 .349 .696 r
.26808 .6052 .26898 .60881 .27064 .60841 .26963 .6063 Mtetra
.471 .507 .814 r
.26963 .6063 .27064 .60841 .27234 .60754 .27124 .60661 Mtetra
.47 .703 .97 r
.27124 .60661 .27234 .60754 .274 .60725 .27288 .60657 Mtetra
.613 .815 .978 r
.27288 .60657 .274 .60725 .27566 .60696 .27455 .60611 Mtetra
.76 .803 .888 r
.27455 .60611 .27566 .60696 .27737 .60601 .27627 .60504 Mtetra
.874 .769 .743 r
.27627 .60504 .27737 .60601 .2793 .60198 .27812 .6022 Mtetra
.964 .788 .618 r
.27812 .6022 .2793 .60198 .29518 .40206 .28028 .59485 Mtetra
0 0 .179 r
.28028 .59485 .29518 .40206 .29734 .39332 .296 .39687 Mtetra
0 0 0 r
.296 .39687 .29734 .39332 .29903 .39126 .29784 .39269 Mtetra
.29784 .39269 .29903 .39126 .30062 .39061 .29953 .3907 Mtetra
.801 .981 .898 r
.29953 .3907 .30062 .39061 .30218 .39041 .30116 .3894 Mtetra
.746 .76 .863 r
.30116 .3894 .30218 .39041 .30377 .38971 .30278 .38841 Mtetra
.676 .693 .858 r
.30278 .38841 .30377 .38971 .30538 .38891 .30437 .38777 Mtetra
.544 .673 .922 r
.30437 .38777 .30538 .38891 .30694 .38866 .30593 .38764 Mtetra
0 .087 .588 r
.30593 .38764 .30694 .38866 .30835 .39081 .30739 .38893 Mtetra
.909 .536 .093 r
.30739 .38893 .30835 .39081 .29685 .58592 .30864 .39347 Mtetra
0 0 .202 r
.30864 .39347 .29685 .58592 .2977 .59788 .29701 .59092 Mtetra
.135 .089 .537 r
.29701 .59092 .2977 .59788 .29926 .59936 .29838 .59517 Mtetra
.408 .344 .673 r
.29838 .59517 .29926 .59936 .30094 .59899 .29996 .59631 Mtetra
.49 .469 .761 r
.29996 .59631 .30094 .59899 .30266 .59809 .3016 .59664 Mtetra
.489 .608 .897 r
.3016 .59664 .30266 .59809 .30434 .59771 .30326 .59673 Mtetra
.563 .731 .954 r
.30326 .59673 .30434 .59771 .30602 .59752 .30493 .59648 Mtetra
.713 .763 .891 r
.30493 .59648 .30602 .59752 .30773 .59672 .30665 .59565 Mtetra
.855 .764 .761 r
.30665 .59565 .30773 .59672 .30961 .59331 .30847 .59319 Mtetra
.956 .79 .637 r
.30847 .59319 .30961 .59331 .32358 .39658 .31053 .58698 Mtetra
0 0 .189 r
.31053 .58698 .32358 .39658 .32592 .38405 .32458 .38831 Mtetra
0 0 0 r
.32458 .38831 .32592 .38405 .32764 .38164 .32645 .38348 Mtetra
.32645 .38348 .32764 .38164 .32924 .38101 .32814 .38152 Mtetra
.626 .951 .768 r
.32814 .38152 .32924 .38101 .33082 .38089 .32978 .38029 Mtetra
.717 .848 .944 r
.32978 .38029 .33082 .38089 .3324 .38068 .3314 .3795 Mtetra
.647 .708 .892 r
.3314 .3795 .3324 .38068 .33399 .38024 .333 .37902 Mtetra
.611 .685 .895 r
.333 .37902 .33399 .38024 .33559 .3798 .33459 .37868 Mtetra
.627 .711 .907 r
.33459 .37868 .33559 .3798 .33719 .37929 .33619 .37827 Mtetra
.654 .74 .913 r
.33619 .37827 .33719 .37929 .3388 .37873 .33779 .37775 Mtetra
.66 .751 .918 r
.33779 .37775 .3388 .37873 .34041 .37814 .3394 .37721 Mtetra
.665 .763 .923 r
.3394 .37721 .34041 .37814 .34202 .37755 .341 .37664 Mtetra
.669 .77 .925 r
.341 .37664 .34202 .37755 .34363 .37696 .34262 .37606 Mtetra
.672 .772 .926 r
.34262 .37606 .34363 .37696 .34524 .37637 .34423 .37547 Mtetra
.671 .772 .926 r
.34423 .37547 .34524 .37637 .34685 .37578 .34584 .37488 Mtetra
.67 .772 .926 r
.34584 .37488 .34685 .37578 .34846 .3752 .34745 .3743 Mtetra
.67 .771 .926 r
.34745 .3743 .34846 .3752 .35008 .37461 .34907 .37371 Mtetra
.669 .77 .926 r
.34907 .37371 .35008 .37461 .35169 .37404 .35068 .37313 Mtetra
.669 .769 .925 r
.35068 .37313 .35169 .37404 .35331 .37346 .3523 .37254 Mtetra
.669 .768 .924 r
.3523 .37254 .35331 .37346 .35492 .37289 .35392 .37196 Mtetra
.667 .765 .923 r
.35392 .37196 .35492 .37289 .35654 .37232 .35553 .37139 Mtetra
.667 .764 .923 r
.35553 .37139 .35654 .37232 .35816 .37175 .35715 .37081 Mtetra
.672 .765 .92 r
.35715 .37081 .35816 .37175 .35977 .37119 .35877 .37022 Mtetra
.685 .762 .91 r
.35877 .37022 .35977 .37119 .36139 .37063 .3604 .36957 Mtetra
.695 .744 .889 r
.3604 .36957 .36139 .37063 .36301 .37009 .36203 .36886 Mtetra
.689 .713 .866 r
.36203 .36886 .36301 .37009 .36463 .36954 .36366 .36815 Mtetra
.676 .682 .848 r
.36366 .36815 .36463 .36954 .36626 .36898 .36528 .36748 Mtetra
.663 .662 .839 r
.36528 .36748 .36626 .36898 .36788 .3684 .36691 .36687 Mtetra
.66 .656 .836 r
.36691 .36687 .36788 .3684 .36951 .36781 .36854 .36627 Mtetra
.671 .661 .831 r
.36854 .36627 .36951 .36781 .37113 .36719 .37017 .3656 Mtetra
.677 .656 .821 r
.37017 .3656 .37113 .36719 .37276 .36657 .3718 .36487 Mtetra
.65 .633 .82 r
.3718 .36487 .37276 .36657 .37439 .36594 .37343 .36431 Mtetra
.592 .615 .843 r
.37343 .36431 .37439 .36594 .37603 .36513 .37504 .36405 Mtetra
.379 .614 .943 r
.37504 .36405 .37603 .36513 .37768 .36421 .37664 .36428 Mtetra
.609 .054 0 r
.37664 .36428 .37768 .36421 .3793 .36376 .37819 .36528 Mtetra
.819 .46 .378 r
.37819 .36528 .3793 .36376 .38086 .3649 .37962 .36927 Mtetra
.949 .677 .489 r
.37962 .36927 .38086 .3649 .3821 .37302 .37226 .56864 Mtetra
.546 .32 .523 r
.37226 .56864 .3821 .37302 .37491 .57223 .37375 .57364 Mtetra
.666 .25 .246 r
.37375 .57364 .37491 .57223 .37651 .57491 .3754 .575 Mtetra
.199 .728 .782 r
.3754 .575 .37651 .57491 .37824 .57466 .37714 .57469 Mtetra
.559 .93 .92 r
.37714 .57469 .37824 .57466 .38 .57379 .37889 .57392 Mtetra
.543 .928 .887 r
.37889 .57392 .38 .57379 .38175 .57297 .38065 .57309 Mtetra
.387 .848 .849 r
.38065 .57309 .38175 .57297 .38349 .5727 .3824 .57251 Mtetra
.538 .9 .969 r
.3824 .57251 .38349 .5727 .38522 .57241 .38414 .57193 Mtetra
.586 .862 .995 r
.38414 .57193 .38522 .57241 .38696 .57203 .38589 .57143 Mtetra
.569 .829 .994 r
.38589 .57143 .38696 .57203 .38871 .5715 .38764 .57102 Mtetra
.612 .871 .991 r
.38764 .57102 .38871 .5715 .39046 .57091 .38939 .57046 Mtetra
.718 .897 .96 r
.38939 .57046 .39046 .57091 .39221 .57051 .39115 .56957 Mtetra
.801 .8 .851 r
.39115 .56957 .39221 .57051 .39394 .57034 .39294 .56812 Mtetra
.781 .654 .722 r
.39294 .56812 .39394 .57034 .3957 .56969 .39476 .56583 Mtetra
.812 .614 .634 r
.39476 .56583 .3957 .56969 .39752 .56748 .39669 .56052 Mtetra
.951 .683 .493 r
.39669 .56052 .39752 .56748 .3996 .55825 .40594 .35962 Mtetra
.55 .327 .53 r
.40594 .35962 .3996 .55825 .40867 .35727 .40778 .3539 Mtetra
.738 .576 .674 r
.40778 .3539 .40867 .35727 .41044 .3535 .4095 .35149 Mtetra
.673 .612 .779 r
.4095 .35149 .41044 .3535 .4121 .35261 .41115 .35067 Mtetra
.616 .592 .803 r
.41115 .35067 .4121 .35261 .41374 .35228 .4128 .35027 Mtetra
.599 .576 .8 r
.4128 .35027 .41374 .35228 .41538 .35199 .41444 .34997 Mtetra
.636 .594 .79 r
.41444 .34997 .41538 .35199 .41704 .3512 .41609 .34943 Mtetra
.642 .622 .815 r
.41609 .34943 .41704 .3512 .41871 .35041 .41775 .34889 Mtetra
.657 .661 .842 r
.41775 .34889 .41871 .35041 .42037 .34969 .4194 .3483 Mtetra
.678 .688 .852 r
.4194 .3483 .42037 .34969 .42202 .34911 .42106 .34762 Mtetra
.653 .663 .847 r
.42106 .34762 .42202 .34911 .42368 .34858 .42272 .34706 Mtetra
.6 .637 .859 r
.42272 .34706 .42368 .34858 .42534 .34794 .42437 .34676 Mtetra
.433 .621 .93 r
.42437 .34676 .42534 .34794 .42701 .34702 .42601 .34692 Mtetra
.508 0 0 r
.42601 .34692 .42701 .34702 .42867 .34649 .42762 .34777 Mtetra
.789 .402 .321 r
.42762 .34777 .42867 .34649 .43029 .34711 .42918 .35069 Mtetra
.955 .678 .474 r
.42918 .35069 .43029 .34711 .43177 .35274 .42491 .55053 Mtetra
.549 .322 .523 r
.42491 .55053 .43177 .35274 .4276 .55481 .42647 .55693 Mtetra
.69 .311 .325 r
.42647 .55693 .4276 .55481 .42925 .55862 .42818 .55883 Mtetra
.071 0 0 r
.42818 .55883 .42925 .55862 .43101 .55854 .42994 .55876 Mtetra
.311 .8 .775 r
.42994 .55876 .43101 .55854 .4328 .55777 .43172 .55817 Mtetra
.344 .807 .705 r
.43172 .55817 .4328 .55777 .43458 .55686 .43351 .55737 Mtetra
0 0 0 r
.43351 .55737 .43458 .55686 .43636 .55657 .43529 .55669 Mtetra
.46 .888 .861 r
.43529 .55669 .43636 .55657 .43813 .55628 .43708 .55597 Mtetra
.612 .908 .983 r
.43708 .55597 .43813 .55628 .43991 .55593 .43887 .5553 Mtetra
.582 .83 .992 r
.43887 .5553 .43991 .55593 .44169 .55541 .44065 .55486 Mtetra
.612 .857 .99 r
.44065 .55486 .44169 .55541 .44348 .55484 .44243 .55431 Mtetra
.716 .885 .959 r
.44243 .55431 .44348 .55484 .44526 .55426 .44423 .55342 Mtetra
.84 .824 .832 r
.44423 .55342 .44526 .55426 .44705 .55371 .44604 .55163 Mtetra
.789 .669 .732 r
.44604 .55163 .44705 .55371 .44884 .55315 .44787 .54938 Mtetra
.724 .564 .672 r
.44787 .54938 .44884 .55315 .45063 .55259 .4497 .54698 Mtetra
.61 .454 .644 r
.4497 .54698 .45063 .55259 .45242 .55202 .4515 .54602 Mtetra
.576 .424 .638 r
.4515 .54602 .45242 .55202 .45421 .55145 .45328 .54559 Mtetra
.564 .418 .641 r
.45328 .54559 .45421 .55145 .456 .55087 .45507 .54537 Mtetra
.587 .439 .648 r
.45507 .54537 .456 .55087 .45779 .55031 .45686 .54481 Mtetra
.586 .439 .648 r
.45686 .54481 .45779 .55031 .45959 .54976 .45865 .54427 Mtetra
.45865 .54427 .45959 .54976 .46139 .5492 .46045 .54372 Mtetra
.587 .44 .648 r
.46045 .54372 .46139 .5492 .46318 .54864 .46224 .54317 Mtetra
.46224 .54317 .46318 .54864 .46498 .54809 .46404 .54261 Mtetra
.46404 .54261 .46498 .54809 .46678 .54753 .46584 .54205 Mtetra
.46584 .54205 .46678 .54753 .46858 .54697 .46764 .54149 Mtetra
.46764 .54149 .46858 .54697 .47038 .54642 .46944 .54093 Mtetra
.588 .44 .648 r
.46944 .54093 .47038 .54642 .47219 .54586 .47124 .54036 Mtetra
.47124 .54036 .47219 .54586 .47399 .5453 .47304 .53978 Mtetra
.47304 .53978 .47399 .5453 .4758 .54474 .47485 .5392 Mtetra
.589 .44 .647 r
.47485 .5392 .4758 .54474 .4776 .54418 .47665 .5386 Mtetra
.61 .454 .645 r
.47665 .5386 .4776 .54418 .47941 .5436 .47846 .53765 Mtetra
.588 .434 .639 r
.47846 .53765 .47941 .5436 .48122 .54303 .48027 .53701 Mtetra
.547 .404 .638 r
.48027 .53701 .48122 .54303 .48303 .54248 .48207 .53704 Mtetra
.419 .325 .643 r
.48207 .53704 .48303 .54248 .48484 .54196 .48386 .53854 Mtetra
.39 .369 .715 r
.48386 .53854 .48484 .54196 .48665 .54146 .48565 .53965 Mtetra
.361 .489 .854 r
.48565 .53965 .48665 .54146 .48847 .54095 .48745 .54026 Mtetra
.543 .804 .994 r
.48745 .54026 .48847 .54095 .49028 .54047 .48927 .53993 Mtetra
.612 .863 .99 r
.48927 .53993 .49028 .54047 .4921 .53995 .49108 .53936 Mtetra
.66 .866 .977 r
.49108 .53936 .4921 .53995 .49392 .53936 .4929 .53867 Mtetra
.468 .771 .996 r
.4929 .53867 .49392 .53936 .49573 .53904 .49472 .5385 Mtetra
.57 .849 .997 r
.49472 .5385 .49573 .53904 .49755 .53831 .49654 .53803 Mtetra
.728 .945 .953 r
.49654 .53803 .49755 .53831 .49938 .53677 .49837 .53699 Mtetra
.975 .902 .679 r
.49837 .53699 .49938 .53677 .50125 .52974 .50021 .53304 Mtetra
.987 .807 .415 r
.50021 .53304 .50125 .52974 .5044 .32537 .50212 .51974 Mtetra
0 0 .316 r
.50212 .51974 .5044 .32537 .50613 .32023 .50517 .32313 Mtetra
.263 0 .209 r
.50517 .32313 .50613 .32023 .50785 .31903 .50689 .32176 Mtetra
.437 .083 .267 r
.50689 .32176 .50785 .31903 .50956 .31854 .5086 .32141 Mtetra
.468 .118 .289 r
.5086 .32141 .50956 .31854 .51127 .3184 .51031 .32124 Mtetra
.043 0 .111 r
.51031 .32124 .51127 .3184 .51298 .31787 .51203 .31897 Mtetra
.545 .819 .463 r
.51203 .31897 .51298 .31787 .51469 .31732 .51375 .31694 Mtetra
.856 .921 .873 r
.51375 .31694 .51469 .31732 .51641 .31676 .51547 .31535 Mtetra
.676 .69 .856 r
.51547 .31535 .51641 .31676 .51812 .31618 .51719 .31465 Mtetra
.624 .652 .857 r
.51719 .31465 .51812 .31618 .51984 .31558 .5189 .31423 Mtetra
.599 .668 .888 r
.5189 .31423 .51984 .31558 .52156 .31498 .52062 .31391 Mtetra
.649 .744 .919 r
.52062 .31391 .52156 .31498 .52327 .31432 .52234 .31338 Mtetra
.664 .776 .933 r
.52234 .31338 .52327 .31432 .52499 .31367 .52406 .31278 Mtetra
.675 .79 .935 r
.52406 .31278 .52499 .31367 .52672 .31309 .52578 .31213 Mtetra
.759 .796 .883 r
.52578 .31213 .52672 .31309 .52844 .31228 .52751 .31105 Mtetra
.712 .734 .869 r
.52751 .31105 .52844 .31228 .53016 .31178 .52923 .31019 Mtetra
.608 .636 .853 r
.52923 .31019 .53016 .31178 .53189 .31196 .53095 .30983 Mtetra
0 .194 .711 r
.53095 .30983 .53189 .31196 .53363 .31643 .53269 .3117 Mtetra
0 0 .242 r
.53269 .3117 .53363 .31643 .53604 .52044 .53444 .31933 Mtetra
0 0 .346 r
.53444 .31933 .53604 .52044 .5379 .52547 .5369 .51979 Mtetra
.309 .247 .623 r
.5369 .51979 .5379 .52547 .53976 .52597 .53876 .52244 Mtetra
.434 .394 .715 r
.53876 .52244 .53976 .52597 .54161 .52544 .54061 .52334 Mtetra
.499 .533 .822 r
.54061 .52334 .54161 .52544 .54345 .52444 .54247 .52354 Mtetra
.433 .704 .979 r
.54247 .52354 .54345 .52444 .54531 .524 .54432 .52355 Mtetra
.526 .855 .996 r
.54432 .52355 .54531 .524 .54716 .52332 .54618 .52311 Mtetra
.717 .959 .946 r
.54618 .52311 .54716 .52332 .54901 .52192 .54803 .52203 Mtetra
.956 .937 .725 r
.54803 .52203 .54901 .52192 .55083 .51651 .54987 .51889 Mtetra
.939 .841 .401 r
.54987 .51889 .55083 .51651 .55098 .31116 .55167 .51115 Mtetra
0 0 .338 r
.55167 .51115 .55098 .31116 .55266 .30471 .55178 .30834 Mtetra
0 0 .098 r
.55178 .30834 .55266 .30471 .55439 .30306 .5535 .30447 Mtetra
0 0 0 r
.5535 .30447 .55439 .30306 .55613 .30244 .55522 .30257 Mtetra
.705 .985 .862 r
.55522 .30257 .55613 .30244 .55788 .30222 .55696 .30132 Mtetra
.716 .803 .919 r
.55696 .30132 .55788 .30222 .55962 .30165 .5587 .30049 Mtetra
.665 .732 .9 r
.5587 .30049 .55962 .30165 .56136 .30099 .56044 .29987 Mtetra
.643 .733 .914 r
.56044 .29987 .56136 .30099 .5631 .30039 .56219 .29936 Mtetra
.76 .786 .874 r
.56219 .29936 .5631 .30039 .56485 .29957 .56393 .29824 Mtetra
.721 .723 .851 r
.56393 .29824 .56485 .29957 .56659 .29899 .56567 .29728 Mtetra
.601 .619 .841 r
.56567 .29728 .56659 .29899 .56835 .29903 .56742 .29696 Mtetra
0 0 .523 r
.56742 .29696 .56835 .29903 .57015 .30242 .56922 .29986 Mtetra
.973 .683 .414 r
.56922 .29986 .57015 .30242 .57499 .50664 .574 .50458 Mtetra
.904 .541 .081 r
.574 .50458 .57499 .50664 .57697 .51297 .576 .51225 Mtetra
0 .26 .695 r
.576 .51225 .57697 .51297 .57887 .51418 .5779 .51335 Mtetra
.608 .801 .974 r
.5779 .51335 .57887 .51418 .58075 .5139 .57978 .51287 Mtetra
.794 .807 .862 r
.57978 .51287 .58075 .5139 .58261 .51256 .58164 .51145 Mtetra
.897 .79 .734 r
.58164 .51145 .58261 .51256 .58442 .5082 .58348 .50835 Mtetra
.993 .818 .563 r
.58348 .50835 .58442 .5082 .58254 .30343 .58523 .50103 Mtetra
0 0 .347 r
.58523 .50103 .58254 .30343 .58414 .29422 .58332 .29802 Mtetra
0 0 .11 r
.58332 .29802 .58414 .29422 .58587 .29217 .58501 .2938 Mtetra
0 0 0 r
.58501 .2938 .58587 .29217 .58762 .29152 .58675 .29183 Mtetra
.628 .953 .777 r
.58675 .29183 .58762 .29152 .58939 .29133 .58849 .29054 Mtetra
.723 .832 .932 r
.58849 .29054 .58939 .29133 .59116 .29086 .59025 .28967 Mtetra
.668 .729 .895 r
.59025 .28967 .59116 .29086 .59292 .29023 .59201 .28903 Mtetra
.646 .721 .903 r
.59201 .28903 .59292 .29023 .59468 .28963 .59378 .28849 Mtetra
.747 .767 .869 r
.59378 .28849 .59468 .28963 .59644 .2888 .59554 .28742 Mtetra
.73 .721 .842 r
.59554 .28742 .59644 .2888 .59821 .28812 .59729 .28638 Mtetra
.624 .627 .834 r
.59729 .28638 .59821 .28812 .59999 .28802 .59906 .28593 Mtetra
0 .142 .68 r
.59906 .28593 .59999 .28802 .60184 .29078 .6009 .2881 Mtetra
.975 .682 .4 r
.6009 .2881 .60184 .29078 .60878 .4945 .60771 .48909 Mtetra
.732 .483 0 r
.60771 .48909 .60878 .4945 .61088 .50213 .60992 .50086 Mtetra
0 .148 .677 r
.60992 .50086 .61088 .50213 .61283 .50366 .61188 .50261 Mtetra
.528 .72 .961 r
.61188 .50261 .61283 .50366 .61474 .5035 .61379 .50244 Mtetra
.774 .801 .875 r
.61379 .50244 .61474 .5035 .61663 .5023 .61567 .50115 Mtetra
.925 .783 .685 r
.61567 .50115 .61663 .5023 .61844 .49848 .61748 .49706 Mtetra
.974 .686 .416 r
.61748 .49706 .61844 .49848 .61456 .29677 .61356 .29212 Mtetra
.873 .632 .571 r
.61356 .29212 .61456 .29677 .61598 .28369 .61507 .28204 Mtetra
.823 .717 .747 r
.61507 .28204 .61598 .28369 .6177 .28127 .6168 .27979 Mtetra
.65 .677 .862 r
.6168 .27979 .6177 .28127 .61948 .28057 .61858 .27922 Mtetra
.532 .643 .904 r
.61858 .27922 .61948 .28057 .62127 .28037 .62038 .27915 Mtetra
.588 .693 .915 r
.62038 .27915 .62127 .28037 .62306 .27996 .62217 .27885 Mtetra
.663 .747 .913 r
.62217 .27885 .62306 .27996 .62484 .27929 .62395 .27823 Mtetra
.677 .763 .916 r
.62395 .27823 .62484 .27929 .62663 .27865 .62574 .27755 Mtetra
.753 .779 .874 r
.62574 .27755 .62663 .27865 .6284 .27781 .62751 .27645 Mtetra
.742 .731 .842 r
.62751 .27645 .6284 .27781 .63019 .27705 .62928 .27533 Mtetra
.642 .64 .833 r
.62928 .27533 .63019 .27705 .63199 .27684 .63107 .27477 Mtetra
.088 .268 .752 r
.63107 .27477 .63199 .27684 .63387 .27903 .63294 .27645 Mtetra
.966 .647 .272 r
.63294 .27645 .63387 .27903 .6429 .48104 .63551 .29776 Mtetra
0 0 .374 r
.63551 .29776 .6429 .48104 .6452 .49104 .64425 .48969 Mtetra
0 .05 .597 r
.64425 .48969 .6452 .49104 .64721 .4929 .64627 .49186 Mtetra
.49 .705 .965 r
.64627 .49186 .64721 .4929 .64915 .49281 .64821 .49178 Mtetra
.763 .81 .89 r
.64821 .49178 .64915 .49281 .65106 .49167 .65012 .49058 Mtetra
.925 .798 .702 r
.65012 .49058 .65106 .49167 .65287 .48814 .65192 .48686 Mtetra
.976 .685 .402 r
.65192 .48686 .65287 .48814 .6471 .29145 .64595 .28369 Mtetra
.838 .586 .558 r
.64595 .28369 .6471 .29145 .64819 .2728 .64729 .27116 Mtetra
.845 .725 .732 r
.64729 .27116 .64819 .2728 .6499 .27005 .64901 .26856 Mtetra
.662 .683 .859 r
.64901 .26856 .6499 .27005 .6517 .26928 .65081 .26792 Mtetra
.547 .649 .902 r
.65081 .26792 .6517 .26928 .65351 .26903 .65263 .26779 Mtetra
.574 .686 .917 r
.65263 .26779 .65351 .26903 .65532 .26867 .65445 .26754 Mtetra
.663 .747 .912 r
.65445 .26754 .65532 .26867 .65713 .26799 .65625 .26692 Mtetra
.678 .764 .915 r
.65625 .26692 .65713 .26799 .65893 .26732 .65806 .26622 Mtetra
.745 .779 .881 r
.65806 .26622 .65893 .26732 .66073 .2665 .65984 .26517 Mtetra
.75 .741 .844 r
.65984 .26517 .66073 .2665 .66252 .26567 .66163 .264 Mtetra
.661 .656 .834 r
.66163 .264 .66252 .26567 .66434 .26533 .66343 .26333 Mtetra
.265 .392 .805 r
.66343 .26333 .66434 .26533 .66625 .26684 .66532 .26443 Mtetra
.822 .477 0 r
.66532 .26443 .66625 .26684 .66867 .27933 .66751 .27195 Mtetra
.979 .681 .357 r
.66751 .27195 .66867 .27933 .67989 .47893 .67895 .47741 Mtetra
0 0 .553 r
.67895 .47741 .67989 .47893 .68197 .48108 .68104 .48001 Mtetra
.607 .755 .949 r
.68104 .48001 .68197 .48108 .68392 .48062 .683 .47956 Mtetra
.759 .808 .892 r
.683 .47956 .68392 .48062 .68584 .4795 .68492 .47838 Mtetra
.759 .796 .883 r
.68492 .47838 .68584 .4795 .68776 .47838 .68684 .47717 Mtetra
.685 .756 .906 r
.68684 .47717 .68776 .47838 .68971 .47766 .68878 .4764 Mtetra
.673 .741 .901 r
.68878 .4764 .68971 .47766 .69165 .47699 .69072 .47567 Mtetra
.645 .72 .903 r
.69072 .47567 .69165 .47699 .69361 .47642 .69268 .47509 Mtetra
.611 .704 .911 r
.69268 .47509 .69361 .47642 .69557 .47594 .69464 .47466 Mtetra
.597 .706 .92 r
.69464 .47466 .69557 .47594 .69753 .47551 .69661 .47428 Mtetra
.511 .676 .94 r
.69661 .47428 .69753 .47551 .69951 .4754 .69859 .47421 Mtetra
.456 .658 .948 r
.69859 .47421 .69951 .4754 .7015 .47545 .70058 .47429 Mtetra
.639 .75 .929 r
.70058 .47429 .7015 .47545 .70346 .47487 .70255 .47372 Mtetra
.887 .807 .764 r
.70255 .47372 .70346 .47487 .70531 .4722 .7044 .47105 Mtetra
.98 .726 .476 r
.7044 .47105 .70531 .4722 .70643 .45641 .7055 .45493 Mtetra
.977 .681 .379 r
.7055 .45493 .70643 .45641 .69722 .25632 .69636 .25513 Mtetra
.912 .788 .711 r
.69636 .25513 .69722 .25632 .6989 .25305 .69804 .25187 Mtetra
.709 .757 .89 r
.69804 .25187 .6989 .25305 .70072 .25218 .69986 .251 Mtetra
.587 .708 .927 r
.69986 .251 .70072 .25218 .70257 .25186 .70171 .25068 Mtetra
.623 .724 .919 r
.70171 .25068 .70257 .25186 .70441 .2514 .70356 .25022 Mtetra
.732 .766 .88 r
.70356 .25022 .70441 .2514 .70623 .2504 .70537 .24922 Mtetra
.64 .732 .915 r
.70537 .24922 .70623 .2504 .70807 .24986 .70722 .24869 Mtetra
.061 .398 .854 r
.70722 .24869 .70807 .24986 .71001 .2509 .70915 .24973 Mtetra
.925 .554 .141 r
.70915 .24973 .71001 .2509 .71246 .2603 .7116 .25918 Mtetra
.975 .671 .352 r
.7116 .25918 .71246 .2603 .72691 .46474 .726 .46363 Mtetra
.604 .141 0 r
.726 .46363 .72691 .46474 .7291 .4677 .7282 .46658 Mtetra
.418 .654 .957 r
.7282 .46658 .7291 .4677 .73113 .46785 .73023 .46673 Mtetra
.711 .788 .911 r
.73023 .46673 .73113 .46785 .73309 .46692 .73219 .46581 Mtetra
.889 .817 .771 r
.73219 .46581 .73309 .46692 .73494 .4643 .73405 .4632 Mtetra
.978 .758 .538 r
.73405 .4632 .73494 .4643 .73638 .45523 .73549 .45421 Mtetra
.977 .679 .364 r
.73549 .45421 .73638 .45523 .72489 .24793 .72405 .24679 Mtetra
.939 .791 .67 r
.72405 .24679 .72489 .24793 .72652 .24391 .72568 .24275 Mtetra
.721 .768 .889 r
.72568 .24275 .72652 .24391 .72835 .24298 .72751 .24182 Mtetra
.58 .71 .932 r
.72751 .24182 .72835 .24298 .73023 .24268 .72938 .24151 Mtetra
.541 .691 .937 r
.72938 .24151 .73023 .24268 .73211 .24251 .73127 .24135 Mtetra
.657 .744 .914 r
.73127 .24135 .73211 .24251 .73396 .2419 .73312 .24073 Mtetra
.663 .745 .911 r
.73312 .24073 .73396 .2419 .73582 .24126 .73498 .24009 Mtetra
.701 .759 .897 r
.73498 .24009 .73582 .24126 .73766 .24044 .73682 .23927 Mtetra
.757 .777 .87 r
.73682 .23927 .73766 .24044 .73948 .23928 .73864 .2381 Mtetra
.673 .747 .906 r
.73864 .2381 .73948 .23928 .74134 .23859 .7405 .23741 Mtetra
.239 .515 .91 r
.7405 .23741 .74134 .23859 .74329 .23926 .74245 .23808 Mtetra
.896 .51 .065 r
.74245 .23808 .74329 .23926 .74577 .24718 .74493 .24602 Mtetra
.975 .667 .334 r
.74493 .24602 .74577 .24718 .76264 .4533 .76176 .45217 Mtetra
.637 .181 0 r
.76176 .45217 .76264 .4533 .76493 .45664 .76405 .4555 Mtetra
.391 .636 .953 r
.76405 .4555 .76493 .45664 .767 .45687 .76611 .45574 Mtetra
.695 .781 .918 r
.76611 .45574 .767 .45687 .76899 .45603 .7681 .45489 Mtetra
.873 .82 .793 r
.7681 .45489 .76899 .45603 .77086 .45369 .76998 .45255 Mtetra
.978 .767 .552 r
.76998 .45255 .77086 .45369 .77232 .44582 .77144 .44468 Mtetra
.977 .675 .347 r
.77144 .44468 .77232 .44582 .75843 .23692 .75759 .23572 Mtetra
.95 .784 .641 r
.75759 .23572 .75843 .23692 .75999 .23227 .75916 .23108 Mtetra
.747 .772 .873 r
.75916 .23108 .75999 .23227 .76183 .23117 .761 .22997 Mtetra
.622 .723 .919 r
.761 .22997 .76183 .23117 .76371 .2307 .76289 .2295 Mtetra
.591 .709 .926 r
.76289 .2295 .76371 .2307 .76561 .23036 .76478 .22916 Mtetra
.749 .773 .872 r
.76478 .22916 .76561 .23036 .76745 .22924 .76662 .22804 Mtetra
.675 .746 .904 r
.76662 .22804 .76745 .22924 .76932 .22854 .76849 .22733 Mtetra
.377 .595 .931 r
.76849 .22733 .76932 .22854 .77128 .22888 .77045 .22767 Mtetra
.807 .395 0 r
.77045 .22767 .77128 .22888 .77366 .23438 .77283 .23315 Mtetra
.973 .663 .318 r
.77283 .23315 .77366 .23438 .79267 .44255 .79179 .44138 Mtetra
.709 .269 0 r
.79179 .44138 .79267 .44255 .79508 .44672 .79421 .44557 Mtetra
.504 .693 .953 r
.79421 .44557 .79508 .44672 .79715 .44664 .79628 .44548 Mtetra
.693 .778 .916 r
.79628 .44548 .79715 .44664 .79916 .4458 .79829 .44463 Mtetra
.733 .791 .899 r
.79829 .44463 .79916 .4458 .80115 .44473 .80028 .44356 Mtetra
.499 .688 .952 r
.80028 .44356 .80115 .44473 .80323 .44467 .80236 .4435 Mtetra
.625 .749 .936 r
.80236 .4435 .80323 .44467 .80527 .44414 .8044 .44296 Mtetra
.809 .811 .852 r
.8044 .44296 .80527 .44414 .80721 .44252 .80635 .44134 Mtetra
.979 .772 .556 r
.80635 .44134 .80721 .44252 .80865 .43512 .80779 .43389 Mtetra
.976 .671 .329 r
.80779 .43389 .80865 .43512 .79235 .22561 .79153 .22436 Mtetra
.957 .781 .622 r
.79153 .22436 .79235 .22561 .79386 .22054 .79304 .21931 Mtetra
.751 .772 .87 r
.79304 .21931 .79386 .22054 .79571 .21939 .79489 .21817 Mtetra
.623 .721 .917 r
.79489 .21817 .79571 .21939 .79762 .21891 .79681 .21769 Mtetra
.554 .688 .929 r
.79681 .21769 .79762 .21891 .79956 .21871 .79874 .21749 Mtetra
.747 .771 .873 r
.79874 .21749 .79956 .21871 .80141 .21759 .8006 .21637 Mtetra
.678 .746 .902 r
.8006 .21637 .80141 .21759 .8033 .21686 .80249 .21564 Mtetra
.457 .638 .934 r
.80249 .21564 .8033 .21686 .80527 .21698 .80446 .21576 Mtetra
.769 .354 0 r
.80446 .21576 .80527 .21698 .80772 .22219 .80691 .22097 Mtetra
.971 .657 .298 r
.80691 .22097 .80772 .22219 .82923 .43116 .82838 .42999 Mtetra
.725 .29 0 r
.82838 .42999 .82923 .43116 .83177 .43578 .83092 .43462 Mtetra
.307 .581 .938 r
.83092 .43462 .83177 .43578 .83393 .43626 .83308 .4351 Mtetra
.65 .764 .933 r
.83308 .4351 .83393 .43626 .83598 .43562 .83513 .43446 Mtetra
.83 .821 .84 r
.83513 .43446 .83598 .43562 .83792 .43381 .83707 .43265 Mtetra
.975 .789 .589 r
.83707 .43265 .83792 .43381 .83945 .42769 .8386 .42653 Mtetra
.974 .667 .312 r
.8386 .42653 .83945 .42769 .82106 .21732 .82026 .21612 Mtetra
.975 .776 .572 r
.82026 .21612 .82106 .21732 .82243 .21104 .82163 .20983 Mtetra
.762 .759 .851 r
.20667 .42151 .20772 .42248 .2093 .4214 .20825 .42043 Mtetra
.615 .731 .928 r
.20825 .42043 .2093 .4214 .21082 .42104 .20977 .42007 Mtetra
.461 .675 .956 r
.20977 .42007 .21082 .42104 .2123 .42106 .21124 .4201 Mtetra
.658 .744 .914 r
.21124 .4201 .2123 .42106 .21383 .42054 .21277 .41959 Mtetra
.667 .748 .911 r
.21277 .41959 .21383 .42054 .21536 .41999 .21431 .41904 Mtetra
.673 .75 .909 r
.21431 .41904 .21536 .41999 .2169 .41942 .21585 .41847 Mtetra
.765 .765 .853 r
.21585 .41847 .2169 .41942 .21849 .41832 .21744 .41737 Mtetra
.711 .759 .89 r
.21744 .41737 .21849 .41832 .22004 .41757 .21899 .41662 Mtetra
.495 .694 .957 r
.21899 .41662 .22004 .41757 .22154 .41752 .22049 .41657 Mtetra
.929 .556 .273 r
.22049 .41657 .22154 .41752 .22263 .42172 .22157 .42084 Mtetra
.939 .683 .523 r
.22157 .42084 .22263 .42172 .20567 .62077 .20454 .61994 Mtetra
.93 .572 .323 r
.20454 .61994 .20567 .62077 .20677 .626 .20564 .6251 Mtetra
0 .365 .802 r
.20564 .6251 .20677 .626 .20829 .62676 .20716 .62586 Mtetra
.623 .762 .945 r
.20716 .62586 .20829 .62676 .20992 .62633 .20879 .62543 Mtetra
.804 .784 .835 r
.20879 .62543 .20992 .62633 .21164 .62485 .21052 .62395 Mtetra
.907 .744 .668 r
.21052 .62395 .21164 .62485 .2137 .61971 .21257 .61884 Mtetra
.939 .687 .53 r
.21257 .61884 .2137 .61971 .23328 .4197 .23223 .41883 Mtetra
.918 .731 .634 r
.23223 .41883 .23328 .4197 .23537 .4131 .23433 .41215 Mtetra
.793 .767 .829 r
.23433 .41215 .23537 .4131 .23699 .41175 .23595 .41079 Mtetra
.625 .738 .928 r
.23595 .41079 .23699 .41175 .23852 .41135 .23748 .4104 Mtetra
.453 .674 .959 r
.23748 .4104 .23852 .41135 .24002 .41139 .23898 .41043 Mtetra
.614 .735 .932 r
.23898 .41043 .24002 .41139 .24155 .41104 .24051 .41007 Mtetra
.639 .741 .922 r
.24051 .41007 .24155 .41104 .24309 .4106 .24205 .40963 Mtetra
.648 .74 .917 r
.24205 .40963 .24309 .4106 .24464 .41014 .2436 .40915 Mtetra
.662 .741 .908 r
.2436 .40915 .24464 .41014 .24619 .40963 .24515 .40862 Mtetra
.675 .74 .9 r
.24515 .40862 .24619 .40963 .24774 .40907 .24671 .40803 Mtetra
.686 .738 .89 r
.24671 .40803 .24774 .40907 .2493 .40845 .24827 .40738 Mtetra
.706 .737 .875 r
.24827 .40738 .2493 .40845 .25087 .40774 .24984 .40663 Mtetra
.709 .73 .867 r
.24984 .40663 .25087 .40774 .25244 .407 .25142 .40585 Mtetra
.703 .721 .864 r
.25142 .40585 .25244 .407 .25401 .40628 .25299 .40509 Mtetra
.685 .711 .868 r
.25299 .40509 .25401 .40628 .25558 .40562 .25456 .40443 Mtetra
.672 .706 .872 r
.25456 .40443 .25558 .40562 .25714 .40502 .25612 .40383 Mtetra
.66 .703 .878 r
.25612 .40383 .25714 .40502 .2587 .40447 .25768 .40329 Mtetra
.636 .698 .89 r
.25768 .40329 .2587 .40447 .26026 .404 .25923 .40286 Mtetra
.624 .701 .901 r
.25923 .40286 .26026 .404 .26181 .40357 .26078 .40248 Mtetra
.623 .711 .909 r
.26078 .40248 .26181 .40357 .26336 .40313 .26233 .40209 Mtetra
.645 .729 .91 r
.26233 .40209 .26336 .40313 .26492 .40262 .26389 .40163 Mtetra
.661 .741 .909 r
.26389 .40163 .26492 .40262 .26649 .40207 .26545 .40109 Mtetra
.675 .75 .907 r
.26545 .40109 .26649 .40207 .26805 .40146 .26702 .4005 Mtetra
.697 .758 .899 r
.26702 .4005 .26805 .40146 .26963 .40076 .2686 .39981 Mtetra
.705 .761 .896 r
.2686 .39981 .26963 .40076 .27121 .40003 .27018 .39908 Mtetra
.703 .761 .897 r
.27018 .39908 .27121 .40003 .27279 .39932 .27176 .39836 Mtetra
.717 .763 .889 r
.27176 .39836 .27279 .39932 .27439 .39842 .27335 .39757 Mtetra
.697 .781 .916 r
.27335 .39757 .27439 .39842 .27597 .39769 .27493 .39689 Mtetra
.62 .775 .955 r
.27493 .39689 .27597 .39769 .27752 .39741 .27649 .39648 Mtetra
.301 .608 .953 r
.27649 .39648 .27752 .39741 .27894 .39885 .27799 .39676 Mtetra
.177 .316 .768 r
.27799 .39676 .27894 .39885 .28007 .40414 .27944 .3979 Mtetra
.253 .179 .575 r
.27944 .3979 .28007 .40414 .26671 .60162 .28075 .40085 Mtetra
0 0 .214 r
.28075 .40085 .26671 .60162 .26808 .6052 .26762 .59566 Mtetra
0 0 .424 r
.26762 .59566 .26808 .6052 .26963 .6063 .2687 .60309 Mtetra
.001 .11 .625 r
.2687 .60309 .26963 .6063 .27124 .60661 .27016 .60542 Mtetra
.319 .572 .931 r
.27016 .60542 .27124 .60661 .27288 .60657 .27177 .60579 Mtetra
.649 .799 .955 r
.27177 .60579 .27288 .60657 .27455 .60611 .27345 .60524 Mtetra
.764 .799 .881 r
.27345 .60524 .27455 .60611 .27627 .60504 .27517 .60413 Mtetra
.813 .791 .832 r
.27517 .60413 .27627 .60504 .27812 .6022 .27692 .60256 Mtetra
.916 .966 .794 r
.27692 .60256 .27812 .6022 .28028 .59485 .27873 .60022 Mtetra
0 0 .152 r
.27873 .60022 .28028 .59485 .296 .39687 .28068 .59604 Mtetra
0 0 .208 r
.28068 .59604 .296 .39687 .29784 .39269 .29622 .40008 Mtetra
0 0 .014 r
.29622 .40008 .29784 .39269 .29953 .3907 .29835 .39184 Mtetra
.926 .961 .65 r
.29835 .39184 .29953 .3907 .30116 .3894 .30012 .38867 Mtetra
.817 .817 .85 r
.30012 .38867 .30116 .3894 .30278 .38841 .30177 .38725 Mtetra
.666 .716 .885 r
.30177 .38725 .30278 .38841 .30437 .38777 .30336 .38668 Mtetra
.525 .678 .935 r
.30336 .38668 .30437 .38777 .30593 .38764 .30491 .38659 Mtetra
.324 .591 .941 r
.30491 .38659 .30593 .38764 .30739 .38893 .30644 .3869 Mtetra
.274 .386 .796 r
.30644 .3869 .30739 .38893 .30864 .39347 .30793 .3878 Mtetra
.33 .246 .607 r
.30793 .3878 .30864 .39347 .29701 .59092 .30934 .38998 Mtetra
0 0 .268 r
.30934 .38998 .29701 .59092 .29838 .59517 .29873 .57263 Mtetra
0 0 .335 r
.29873 .57263 .29838 .59517 .29996 .59631 .29909 .59208 Mtetra
.049 .093 .587 r
.29909 .59208 .29996 .59631 .3016 .59664 .30056 .59502 Mtetra
.243 .444 .858 r
.30056 .59502 .3016 .59664 .30326 .59673 .30217 .59578 Mtetra
.572 .741 .956 r
.30217 .59578 .30326 .59673 .30493 .59648 .30385 .5955 Mtetra
.716 .773 .897 r
.30385 .5955 .30493 .59648 .30665 .59565 .30557 .59465 Mtetra
.79 .78 .844 r
.30557 .59465 .30665 .59565 .30847 .59319 .30732 .59326 Mtetra
.903 .946 .823 r
.30732 .59326 .30847 .59319 .31053 .58698 .30912 .59114 Mtetra
0 0 .074 r
.30912 .59114 .31053 .58698 .32458 .38831 .31101 .58754 Mtetra
0 0 .281 r
.31101 .58754 .32458 .38831 .32645 .38348 .32375 .4097 Mtetra
0 0 .189 r
.32375 .4097 .32645 .38348 .32814 .38152 .32694 .3835 Mtetra
.799 .885 .462 r
.32694 .3835 .32814 .38152 .32978 .38029 .32874 .37987 Mtetra
.85 .88 .861 r
.32874 .37987 .32978 .38029 .3314 .3795 .3304 .37831 Mtetra
.663 .708 .881 r
.3304 .37831 .3314 .3795 .333 .37902 .332 .37774 Mtetra
.583 .665 .895 r
.332 .37774 .333 .37902 .33459 .37868 .33359 .37751 Mtetra
.603 .694 .907 r
.33359 .37751 .33459 .37868 .33619 .37827 .33518 .37719 Mtetra
.65 .728 .905 r
.33518 .37719 .33619 .37827 .33779 .37775 .33679 .37669 Mtetra
.655 .732 .906 r
.33679 .37669 .33779 .37775 .3394 .37721 .33839 .37617 Mtetra
.662 .738 .906 r
.33839 .37617 .3394 .37721 .341 .37664 .34 .37561 Mtetra
.668 .742 .906 r
.34 .37561 .341 .37664 .34262 .37606 .34161 .37504 Mtetra
.671 .744 .906 r
.34161 .37504 .34262 .37606 .34423 .37547 .34322 .37445 Mtetra
.671 .745 .906 r
.34322 .37445 .34423 .37547 .34584 .37488 .34484 .37385 Mtetra
.67 .744 .906 r
.34484 .37385 .34584 .37488 .34745 .3743 .34645 .37327 Mtetra
.671 .744 .905 r
.34645 .37327 .34745 .3743 .34907 .37371 .34807 .37267 Mtetra
.67 .743 .905 r
.34807 .37267 .34907 .37371 .35068 .37313 .34968 .37209 Mtetra
.67 .742 .904 r
.34968 .37209 .35068 .37313 .3523 .37254 .3513 .3715 Mtetra
.67 .741 .903 r
.3513 .3715 .3523 .37254 .35392 .37196 .35292 .3709 Mtetra
.669 .738 .902 r
.35292 .3709 .35392 .37196 .35553 .37139 .35454 .37032 Mtetra
.668 .736 .901 r
.35454 .37032 .35553 .37139 .35715 .37081 .35616 .36974 Mtetra
.675 .736 .897 r
.35616 .36974 .35715 .37081 .35877 .37022 .35778 .36912 Mtetra
.69 .737 .886 r
.35778 .36912 .35877 .37022 .3604 .36957 .35941 .36843 Mtetra
.703 .733 .874 r
.35941 .36843 .3604 .36957 .36203 .36886 .36104 .36766 Mtetra
.7 .723 .867 r
.36104 .36766 .36203 .36886 .36366 .36815 .36267 .3669 Mtetra
.688 .71 .865 r
.36267 .3669 .36366 .36815 .36528 .36748 .3643 .3662 Mtetra
.673 .7 .866 r
.3643 .3662 .36528 .36748 .36691 .36687 .36593 .36556 Mtetra
.668 .695 .866 r
.36593 .36556 .36691 .36687 .36854 .36627 .36756 .36496 Mtetra
.69 .701 .855 r
.36756 .36496 .36854 .36627 .37017 .3656 .36919 .36422 Mtetra
.7 .695 .842 r
.36919 .36422 .37017 .3656 .3718 .36487 .37083 .36341 Mtetra
.644 .662 .852 r
.37083 .36341 .3718 .36487 .37343 .36431 .37245 .36291 Mtetra
.37 .542 .894 r
.37245 .36291 .37343 .36431 .37504 .36405 .37404 .3633 Mtetra
.79 .3 0 r
.37404 .3633 .37504 .36405 .37664 .36428 .37553 .36557 Mtetra
.898 .577 .43 r
.37553 .36557 .37664 .36428 .37819 .36528 .37672 .37475 Mtetra
.941 .669 .495 r
.37672 .37475 .37819 .36528 .37962 .36927 .36941 .56935 Mtetra
.542 .317 .522 r
.36941 .56935 .37962 .36927 .37226 .56864 .37098 .57236 Mtetra
.611 .279 .384 r
.37098 .57236 .37226 .56864 .37375 .57364 .37264 .57361 Mtetra
.208 0 0 r
.37264 .57361 .37375 .57364 .3754 .575 .37435 .5739 Mtetra
.617 .73 .927 r
.37435 .5739 .3754 .575 .37714 .57469 .37609 .57349 Mtetra
.677 .73 .89 r
.37609 .57349 .37714 .57469 .37889 .57392 .37784 .57281 Mtetra
.681 .749 .903 r
.37784 .57281 .37889 .57392 .38065 .57309 .37959 .57212 Mtetra
.642 .766 .938 r
.37959 .57212 .38065 .57309 .3824 .57251 .38134 .5716 Mtetra
.64 .777 .946 r
.38134 .5716 .3824 .57251 .38414 .57193 .38308 .57108 Mtetra
.599 .777 .965 r
.38308 .57108 .38414 .57193 .38589 .57143 .38483 .57068 Mtetra
.538 .779 .987 r
.38483 .57068 .38589 .57143 .38764 .57102 .38656 .57041 Mtetra
.644 .847 .978 r
.38656 .57041 .38764 .57102 .38939 .57046 .38832 .5698 Mtetra
.826 .854 .868 r
.38832 .5698 .38939 .57046 .39115 .56957 .39011 .56828 Mtetra
.886 .746 .701 r
.39011 .56828 .39115 .56957 .39294 .56812 .39199 .5646 Mtetra
.886 .659 .589 r
.39199 .5646 .39294 .56812 .39476 .56583 .39414 .5538 Mtetra
.944 .676 .498 r
.39414 .5538 .39476 .56583 .39669 .56052 .40335 .35778 Mtetra
.545 .324 .529 r
.40335 .35778 .39669 .56052 .40594 .35962 .40513 .35403 Mtetra
.67 .49 .633 r
.40513 .35403 .40594 .35962 .40778 .3539 .40684 .35185 Mtetra
.727 .635 .755 r
.40684 .35185 .40778 .3539 .4095 .35149 .40851 .3505 Mtetra
.694 .764 .905 r
.40851 .3505 .4095 .35149 .41115 .35067 .41017 .34979 Mtetra
.634 .771 .946 r
.41017 .34979 .41115 .35067 .4128 .35027 .41182 .34932 Mtetra
.625 .752 .938 r
.41182 .34932 .4128 .35027 .41444 .34997 .41347 .34889 Mtetra
.666 .739 .904 r
.41347 .34889 .41444 .34997 .41609 .34943 .41512 .34831 Mtetra
.665 .73 .897 r
.41512 .34831 .41609 .34943 .41775 .34889 .41678 .34772 Mtetra
.68 .725 .884 r
.41678 .34772 .41775 .34889 .4194 .3483 .41843 .34706 Mtetra
.705 .72 .861 r
.41843 .34706 .4194 .3483 .42106 .34762 .4201 .34625 Mtetra
.652 .681 .865 r
.4201 .34625 .42106 .34762 .42272 .34706 .42176 .3457 Mtetra
.463 .6 .902 r
.42176 .3457 .42272 .34706 .42437 .34676 .42339 .34585 Mtetra
.665 .16 0 r
.42339 .34585 .42437 .34676 .42601 .34692 .42497 .34781 Mtetra
.89 .541 .379 r
.42497 .34781 .42601 .34692 .42762 .34777 .42642 .35426 Mtetra
.951 .674 .478 r
.42642 .35426 .42762 .34777 .42918 .35069 .42203 .55234 Mtetra
.543 .317 .522 r
.42203 .55234 .42918 .35069 .42491 .55053 .42368 .55585 Mtetra
.604 .297 .421 r
.42368 .55585 .42491 .55053 .42647 .55693 .42539 .55731 Mtetra
.463 0 0 r
.42539 .55731 .42647 .55693 .42818 .55883 .42714 .55784 Mtetra
.532 .723 .961 r
.42714 .55784 .42818 .55883 .42994 .55876 .42891 .55766 Mtetra
.63 .738 .926 r
.42891 .55766 .42994 .55876 .43172 .55817 .43068 .55718 Mtetra
.668 .772 .928 r
.43068 .55718 .43172 .55817 .43351 .55737 .43247 .55654 Mtetra
.672 .809 .948 r
.43247 .55654 .43351 .55737 .43529 .55669 .43425 .55588 Mtetra
.684 .814 .945 r
.43425 .55588 .43529 .55669 .43708 .55597 .43604 .55516 Mtetra
.664 .811 .954 r
.43604 .55516 .43708 .55597 .43887 .5553 .43782 .55452 Mtetra
.548 .781 .985 r
.43782 .55452 .43887 .5553 .44065 .55486 .4396 .55423 Mtetra
.624 .842 .983 r
.4396 .55423 .44065 .55486 .44243 .55431 .44139 .55367 Mtetra
.793 .868 .904 r
.44139 .55367 .44243 .55431 .44423 .55342 .44319 .5524 Mtetra
.906 .777 .708 r
.44319 .5524 .44423 .55342 .44604 .55163 .44506 .54876 Mtetra
.892 .673 .599 r
.44506 .54876 .44604 .55163 .44787 .54938 .44703 .54003 Mtetra
.953 .68 .482 r
.44703 .54003 .44787 .54938 .4497 .54698 .45328 .34234 Mtetra
.541 .32 .529 r
.45328 .34234 .4497 .54698 .4515 .54602 .45499 .34057 Mtetra
.538 .318 .528 r
.45499 .34057 .4515 .54602 .45328 .54559 .45666 .34029 Mtetra
.537 .317 .528 r
.45666 .34029 .45328 .54559 .45507 .54537 .45833 .34066 Mtetra
.539 .318 .528 r
.45833 .34066 .45507 .54537 .45686 .54481 .46001 .34009 Mtetra
.46001 .34009 .45686 .54481 .45865 .54427 .4617 .33954 Mtetra
.4617 .33954 .45865 .54427 .46045 .54372 .46339 .339 Mtetra
.46339 .339 .46045 .54372 .46224 .54317 .46507 .33842 Mtetra
.46507 .33842 .46224 .54317 .46404 .54261 .46676 .33784 Mtetra
.46676 .33784 .46404 .54261 .46584 .54205 .46846 .33725 Mtetra
.46846 .33725 .46584 .54205 .46764 .54149 .47015 .33667 Mtetra
.47015 .33667 .46764 .54149 .46944 .54093 .47184 .33607 Mtetra
.47184 .33607 .46944 .54093 .47124 .54036 .47353 .33546 Mtetra
.47353 .33546 .47124 .54036 .47304 .53978 .47523 .33482 Mtetra
.47523 .33482 .47304 .53978 .47485 .5392 .47693 .33418 Mtetra
.47693 .33418 .47485 .5392 .47665 .5386 .47863 .33348 Mtetra
.541 .32 .528 r
.47863 .33348 .47665 .5386 .47846 .53765 .48034 .33186 Mtetra
.539 .319 .528 r
.48034 .33186 .47846 .53765 .48027 .53701 .48204 .33114 Mtetra
.535 .316 .528 r
.48204 .33114 .48027 .53701 .48207 .53704 .48372 .33231 Mtetra
0 0 .331 r
.48372 .33231 .48207 .53704 .48386 .53854 .48292 .53126 Mtetra
.016 .012 .506 r
.48292 .53126 .48386 .53854 .48565 .53965 .48465 .53723 Mtetra
0 .147 .678 r
.48465 .53723 .48565 .53965 .48745 .54026 .48644 .53941 Mtetra
.486 .739 .983 r
.48644 .53941 .48745 .54026 .48927 .53993 .48825 .53928 Mtetra
.642 .848 .979 r
.48825 .53928 .48927 .53993 .49108 .53936 .49007 .53867 Mtetra
.714 .855 .949 r
.49007 .53867 .49108 .53936 .4929 .53867 .49189 .5378 Mtetra
.581 .775 .972 r
.49189 .5378 .4929 .53867 .49472 .5385 .49371 .53743 Mtetra
.641 .753 .93 r
.49371 .53743 .49472 .5385 .49654 .53803 .49553 .53689 Mtetra
.708 .76 .893 r
.49553 .53689 .49654 .53803 .49837 .53699 .49736 .53603 Mtetra
.863 .808 .795 r
.49736 .53603 .49837 .53699 .50021 .53304 .49919 .53383 Mtetra
.913 .965 .651 r
.49919 .53383 .50021 .53304 .50212 .51974 .50104 .53066 Mtetra
.317 .092 .406 r
.50104 .53066 .50212 .51974 .50517 .32313 .50289 .52601 Mtetra
.536 .311 .521 r
.50289 .52601 .50517 .32313 .50689 .32176 .50471 .52552 Mtetra
.537 .312 .521 r
.50471 .52552 .50689 .32176 .5086 .32141 .50653 .5255 Mtetra
.535 .31 .521 r
.50653 .5255 .5086 .32141 .51031 .32124 .50836 .52422 Mtetra
0 0 .33 r
.50836 .52422 .51031 .32124 .51203 .31897 .51106 .32434 Mtetra
0 0 .049 r
.51106 .32434 .51203 .31897 .51375 .31694 .51281 .31729 Mtetra
.959 .945 .698 r
.51281 .31729 .51375 .31694 .51547 .31535 .51453 .31416 Mtetra
.723 .744 .869 r
.51453 .31416 .51547 .31535 .51719 .31465 .51625 .31324 Mtetra
.613 .665 .877 r
.51625 .31324 .51719 .31465 .5189 .31423 .51797 .31287 Mtetra
.546 .644 .898 r
.51797 .31287 .5189 .31423 .52062 .31391 .51969 .31276 Mtetra
.635 .72 .909 r
.51969 .31276 .52062 .31391 .52234 .31338 .52141 .31228 Mtetra
.656 .74 .912 r
.52141 .31228 .52234 .31338 .52406 .31278 .52313 .31172 Mtetra
.671 .752 .912 r
.52313 .31172 .52406 .31278 .52578 .31213 .52485 .31109 Mtetra
.735 .775 .885 r
.52485 .31109 .52578 .31213 .52751 .31105 .52657 .31014 Mtetra
.72 .797 .912 r
.52657 .31014 .52751 .31105 .52923 .31019 .5283 .30929 Mtetra
.649 .78 .944 r
.5283 .30929 .52923 .31019 .53095 .30983 .53002 .30874 Mtetra
.33 .587 .938 r
.53002 .30874 .53095 .30983 .53269 .3117 .53175 .30909 Mtetra
.274 .334 .744 r
.53175 .30909 .53269 .3117 .53444 .31933 .53349 .31042 Mtetra
.335 .221 .573 r
.53349 .31042 .53444 .31933 .5369 .51979 .53523 .31419 Mtetra
0 0 .353 r
.53523 .31419 .5369 .51979 .53876 .52244 .53774 .51473 Mtetra
.115 .08 .538 r
.53774 .51473 .53876 .52244 .54061 .52334 .53961 .52038 Mtetra
.149 .24 .703 r
.53961 .52038 .54061 .52334 .54247 .52354 .54148 .52241 Mtetra
.386 .629 .95 r
.54148 .52241 .54247 .52354 .54432 .52355 .54333 .52264 Mtetra
.628 .787 .958 r
.54333 .52264 .54432 .52355 .54618 .52311 .54519 .52212 Mtetra
.748 .803 .897 r
.54519 .52212 .54618 .52311 .54803 .52203 .54704 .52104 Mtetra
.824 .812 .839 r
.54704 .52104 .54803 .52203 .54987 .51889 .54889 .51936 Mtetra
.89 .986 .72 r
.54889 .51936 .54987 .51889 .55167 .51115 .55074 .51678 Mtetra
.057 0 .249 r
.55074 .51678 .55167 .51115 .55178 .30834 .55256 .51224 Mtetra
0 0 .35 r
.55256 .51224 .55178 .30834 .5535 .30447 .55265 .31217 Mtetra
0 0 .204 r
.55265 .31217 .5535 .30447 .55522 .30257 .55433 .30371 Mtetra
.823 .914 .517 r
.55433 .30371 .55522 .30257 .55696 .30132 .55604 .3005 Mtetra
.794 .833 .881 r
.55604 .3005 .55696 .30132 .5587 .30049 .55778 .29923 Mtetra
.664 .714 .886 r
.55778 .29923 .5587 .30049 .56044 .29987 .55952 .29861 Mtetra
.609 .692 .902 r
.55952 .29861 .56044 .29987 .56219 .29936 .56127 .29824 Mtetra
.751 .768 .867 r
.56127 .29824 .56219 .29936 .56393 .29824 .56301 .29715 Mtetra
.735 .769 .88 r
.56301 .29715 .56393 .29824 .56567 .29728 .56475 .29618 Mtetra
.591 .717 .931 r
.56475 .29618 .56567 .29728 .56742 .29696 .56651 .29586 Mtetra
.735 .276 0 r
.56651 .29586 .56742 .29696 .56922 .29986 .56831 .29885 Mtetra
.971 .682 .418 r
.56831 .29885 .56922 .29986 .574 .50458 .57304 .50409 Mtetra
.93 .549 .235 r
.57304 .50409 .574 .50458 .576 .51225 .57503 .51139 Mtetra
0 .382 .818 r
.57503 .51139 .576 .51225 .5779 .51335 .57692 .51231 Mtetra
.652 .768 .935 r
.57692 .51231 .5779 .51335 .57978 .51287 .5788 .51171 Mtetra
.777 .78 .856 r
.5788 .51171 .57978 .51287 .58164 .51145 .58067 .51036 Mtetra
.819 .799 .833 r
.58067 .51036 .58164 .51145 .58348 .50835 .58253 .50866 Mtetra
.883 .991 .755 r
.58253 .50866 .58348 .50835 .58523 .50103 .58438 .50628 Mtetra
.102 0 .26 r
.58438 .50628 .58523 .50103 .58332 .29802 .5862 .50228 Mtetra
0 0 .368 r
.5862 .50228 .58332 .29802 .58501 .2938 .58433 .30461 Mtetra
0 0 .271 r
.58433 .30461 .58501 .2938 .58675 .29183 .58589 .29336 Mtetra
.719 .832 .384 r
.58589 .29336 .58675 .29183 .58849 .29054 .5876 .28986 Mtetra
.827 .871 .878 r
.5876 .28986 .58849 .29054 .59025 .28967 .58934 .28841 Mtetra
.673 .72 .884 r
.58934 .28841 .59025 .28967 .59201 .28903 .59111 .28774 Mtetra
.617 .692 .897 r
.59111 .28774 .59201 .28903 .59378 .28849 .59288 .28733 Mtetra
.739 .759 .869 r
.59288 .28733 .59378 .28849 .59554 .28742 .59463 .2863 Mtetra
.746 .769 .872 r
.59463 .2863 .59554 .28742 .59729 .28638 .59639 .28524 Mtetra
.628 .727 .918 r
.59639 .28524 .59729 .28638 .59906 .28593 .59816 .28478 Mtetra
0 0 .491 r
.59816 .28478 .59906 .28593 .6009 .2881 .6 .28694 Mtetra
.973 .68 .404 r
.6 .28694 .6009 .2881 .60771 .48909 .60676 .48798 Mtetra
.953 .604 .26 r
.60676 .48798 .60771 .48909 .60992 .50086 .60896 .4998 Mtetra
0 .103 .616 r
.60896 .4998 .60992 .50086 .61188 .50261 .61092 .50154 Mtetra
.534 .718 .957 r
.61092 .50154 .61188 .50261 .61379 .50244 .61283 .50135 Mtetra
.776 .798 .87 r
.61283 .50135 .61379 .50244 .61567 .50115 .61471 .50004 Mtetra
.93 .786 .68 r
.61471 .50004 .61567 .50115 .61748 .49706 .61652 .49583 Mtetra
.974 .687 .415 r
.61652 .49583 .61748 .49706 .61356 .29212 .61263 .29004 Mtetra
.937 .706 .564 r
.61263 .29004 .61356 .29212 .61507 .28204 .61417 .2807 Mtetra
.842 .756 .767 r
.61417 .2807 .61507 .28204 .6168 .27979 .6159 .27851 Mtetra
.644 .706 .892 r
.6159 .27851 .6168 .27979 .61858 .27922 .61768 .27798 Mtetra
.509 .653 .923 r
.61768 .27798 .61858 .27922 .62038 .27915 .61948 .27795 Mtetra
.575 .694 .922 r
.61948 .27795 .62038 .27915 .62217 .27885 .62128 .27769 Mtetra
.658 .736 .907 r
.62128 .27769 .62217 .27885 .62395 .27823 .62306 .2771 Mtetra
.674 .747 .905 r
.62306 .2771 .62395 .27823 .62574 .27755 .62485 .27643 Mtetra
.753 .773 .87 r
.62485 .27643 .62574 .27755 .62751 .27645 .62662 .27532 Mtetra
.757 .773 .867 r
.62662 .27532 .62751 .27645 .62928 .27533 .62839 .27419 Mtetra
.653 .738 .911 r
.62839 .27419 .62928 .27533 .63107 .27477 .63018 .27361 Mtetra
0 .142 .67 r
.63018 .27361 .63107 .27477 .63294 .27645 .63205 .27529 Mtetra
.966 .641 .315 r
.63205 .27529 .63294 .27645 .63551 .29776 .6346 .29626 Mtetra
.975 .678 .388 r
.6346 .29626 .63551 .29776 .64425 .48969 .64331 .48861 Mtetra
0 0 .508 r
.64331 .48861 .64425 .48969 .64627 .49186 .64533 .49078 Mtetra
.499 .701 .96 r
.64533 .49078 .64627 .49186 .64821 .49178 .64727 .49069 Mtetra
.763 .798 .881 r
.64727 .49069 .64821 .49178 .65012 .49058 .64917 .48947 Mtetra
.925 .794 .697 r
.64917 .48947 .65012 .49058 .65192 .48686 .65098 .48566 Mtetra
.976 .685 .402 r
.65098 .48566 .65192 .48686 .64595 .28369 .64501 .28111 Mtetra
.937 .693 .543 r
.64501 .28111 .64595 .28369 .64729 .27116 .6464 .2698 Mtetra
.863 .761 .748 r
.6464 .2698 .64729 .27116 .64901 .26856 .64812 .26727 Mtetra
.658 .713 .888 r
.64812 .26727 .64901 .26856 .65081 .26792 .64992 .26667 Mtetra
.526 .661 .922 r
.64992 .26667 .65081 .26792 .65263 .26779 .65175 .26658 Mtetra
.561 .687 .924 r
.65175 .26658 .65263 .26779 .65445 .26754 .65357 .26637 Mtetra
.658 .737 .908 r
.65357 .26637 .65445 .26754 .65625 .26692 .65538 .26577 Mtetra
.675 .747 .905 r
.65538 .26577 .65625 .26692 .65806 .26622 .65718 .26509 Mtetra
.743 .772 .876 r
.65718 .26509 .65806 .26622 .65984 .26517 .65897 .26403 Mtetra
.763 .776 .864 r
.65897 .26403 .65984 .26517 .66163 .264 .66075 .26285 Mtetra
.676 .747 .904 r
.66075 .26285 .66163 .264 .66343 .26333 .66256 .26216 Mtetra
.006 .362 .833 r
.66256 .26216 .66343 .26333 .66532 .26443 .66445 .26327 Mtetra
.915 .533 .117 r
.66445 .26327 .66532 .26443 .66751 .27195 .66664 .27084 Mtetra
.975 .675 .374 r
.66664 .27084 .66751 .27195 .67895 .47741 .67802 .47636 Mtetra
.58 .103 0 r
.67802 .47636 .67895 .47741 .68104 .48001 .68012 .47894 Mtetra
.613 .755 .946 r
.68012 .47894 .68104 .48001 .683 .47956 .68207 .47847 Mtetra
.762 .8 .884 r
.68207 .47847 .683 .47956 .68492 .47838 .68399 .47725 Mtetra
.765 .795 .878 r
.68399 .47725 .68492 .47838 .68684 .47717 .68591 .476 Mtetra
.693 .766 .908 r
.68591 .476 .68684 .47717 .68878 .4764 .68785 .47518 Mtetra
.68 .754 .907 r
.68785 .47518 .68878 .4764 .69072 .47567 .68979 .47442 Mtetra
.646 .734 .913 r
.68979 .47442 .69072 .47567 .69268 .47509 .69175 .47383 Mtetra
.603 .714 .923 r
.69175 .47383 .69268 .47509 .69464 .47466 .69371 .47342 Mtetra
.586 .712 .93 r
.69371 .47342 .69464 .47466 .69661 .47428 .69568 .47308 Mtetra
.498 .676 .945 r
.69568 .47308 .69661 .47428 .69859 .47421 .69767 .47304 Mtetra
.447 .657 .95 r
.69767 .47304 .69859 .47421 .70058 .47429 .69967 .47314 Mtetra
.636 .75 .931 r
.69967 .47314 .70058 .47429 .70255 .47372 .70163 .47258 Mtetra
.888 .808 .765 r
.70163 .47258 .70255 .47372 .7044 .47105 .70348 .46991 Mtetra
.98 .726 .474 r
.70348 .46991 .7044 .47105 .7055 .45493 .70458 .4535 Mtetra
.977 .681 .379 r
.70458 .4535 .7055 .45493 .69636 .25513 .6955 .25395 Mtetra
.912 .789 .712 r
.6955 .25395 .69636 .25513 .69804 .25187 .69718 .25069 Mtetra
.709 .757 .89 r
.69718 .25069 .69804 .25187 .69986 .251 .699 .24983 Mtetra
.587 .708 .927 r
.699 .24983 .69986 .251 .70171 .25068 .70086 .24951 Mtetra
.623 .724 .919 r
.70086 .24951 .70171 .25068 .70356 .25022 .7027 .24905 Mtetra
.732 .766 .88 r
.7027 .24905 .70356 .25022 .70537 .24922 .70452 .24805 Mtetra
.64 .732 .915 r
.70452 .24805 .70537 .24922 .70722 .24869 .70636 .24752 Mtetra
.06 .397 .854 r
.70636 .24752 .70722 .24869 .70915 .24973 .7083 .24855 Mtetra
.925 .554 .142 r
.7083 .24855 .70915 .24973 .7116 .25918 .71075 .25804 Mtetra
.975 .671 .352 r
.71075 .25804 .7116 .25918 .726 .46363 .7251 .46252 Mtetra
.603 .139 0 r
.7251 .46252 .726 .46363 .7282 .46658 .7273 .46547 Mtetra
.418 .654 .957 r
.7273 .46547 .7282 .46658 .73023 .46673 .72932 .46562 Mtetra
.711 .787 .911 r
.72932 .46562 .73023 .46673 .73219 .46581 .73129 .46469 Mtetra
.889 .817 .771 r
.73129 .46469 .73219 .46581 .73405 .4632 .73315 .46209 Mtetra
.978 .758 .539 r
.73315 .46209 .73405 .4632 .73549 .45421 .7346 .45315 Mtetra
.977 .679 .364 r
.7346 .45315 .73549 .45421 .72405 .24679 .7232 .24564 Mtetra
.938 .789 .67 r
.7232 .24564 .72405 .24679 .72568 .24275 .72483 .24159 Mtetra
.721 .766 .888 r
.72483 .24159 .72568 .24275 .72751 .24182 .72666 .24065 Mtetra
.58 .709 .931 r
.72666 .24065 .72751 .24182 .72938 .24151 .72854 .24035 Mtetra
.541 .69 .936 r
.72854 .24035 .72938 .24151 .73127 .24135 .73042 .24018 Mtetra
.658 .743 .913 r
.73042 .24018 .73127 .24135 .73312 .24073 .73228 .23956 Mtetra
.663 .745 .91 r
.73228 .23956 .73312 .24073 .73498 .24009 .73414 .23892 Mtetra
.701 .759 .896 r
.73414 .23892 .73498 .24009 .73682 .23927 .73598 .23809 Mtetra
.757 .777 .869 r
.73598 .23809 .73682 .23927 .73864 .2381 .7378 .23692 Mtetra
.674 .747 .906 r
.7378 .23692 .73864 .2381 .7405 .23741 .73966 .23623 Mtetra
.239 .515 .91 r
.73966 .23623 .7405 .23741 .74245 .23808 .74161 .23689 Mtetra
.896 .51 .065 r
.74161 .23689 .74245 .23808 .74493 .24602 .74409 .24485 Mtetra
.975 .667 .334 r
.74409 .24485 .74493 .24602 .76176 .45217 .76087 .45103 Mtetra
.636 .181 0 r
.76087 .45103 .76176 .45217 .76405 .4555 .76316 .45437 Mtetra
.392 .636 .953 r
.76316 .45437 .76405 .4555 .76611 .45574 .76523 .4546 Mtetra
.695 .781 .918 r
.76523 .4546 .76611 .45574 .7681 .45489 .76722 .45375 Mtetra
.873 .82 .793 r
.76722 .45375 .7681 .45489 .76998 .45255 .7691 .45141 Mtetra
.978 .767 .552 r
.7691 .45141 .76998 .45255 .77144 .44468 .77056 .44354 Mtetra
.977 .675 .347 r
.77056 .44354 .77144 .44468 .75759 .23572 .75676 .23453 Mtetra
.95 .784 .641 r
.75676 .23453 .75759 .23572 .75916 .23108 .75833 .22988 Mtetra
.747 .772 .873 r
.75833 .22988 .75916 .23108 .761 .22997 .76017 .22877 Mtetra
.622 .723 .919 r
.76017 .22877 .761 .22997 .76289 .2295 .76206 .2283 Mtetra
.591 .709 .926 r
.76206 .2283 .76289 .2295 .76478 .22916 .76395 .22796 Mtetra
.749 .773 .872 r
.76395 .22796 .76478 .22916 .76662 .22804 .76579 .22684 Mtetra
.676 .746 .904 r
.76579 .22684 .76662 .22804 .76849 .22733 .76767 .22613 Mtetra
.377 .595 .931 r
.76767 .22613 .76849 .22733 .77045 .22767 .76962 .22646 Mtetra
.807 .394 0 r
.76962 .22646 .77045 .22767 .77283 .23315 .772 .23193 Mtetra
.973 .663 .318 r
.772 .23193 .77283 .23315 .79179 .44138 .79092 .44021 Mtetra
.711 .27 0 r
.79092 .44021 .79179 .44138 .79421 .44557 .79334 .44441 Mtetra
.504 .693 .954 r
.79334 .44441 .79421 .44557 .79628 .44548 .79541 .44432 Mtetra
.694 .779 .917 r
.79541 .44432 .79628 .44548 .79829 .44463 .79742 .44347 Mtetra
.734 .792 .899 r
.79742 .44347 .79829 .44463 .80028 .44356 .79941 .4424 Mtetra
.498 .689 .953 r
.79941 .4424 .80028 .44356 .80236 .4435 .80149 .44233 Mtetra
.625 .75 .937 r
.80149 .44233 .80236 .4435 .8044 .44296 .80353 .4418 Mtetra
.809 .812 .853 r
.80353 .4418 .8044 .44296 .80635 .44134 .80548 .44017 Mtetra
.979 .772 .555 r
.80548 .44017 .80635 .44134 .80779 .43389 .80692 .43268 Mtetra
.976 .671 .329 r
.80692 .43268 .80779 .43389 .79153 .22436 .79071 .22312 Mtetra
.958 .782 .622 r
.79071 .22312 .79153 .22436 .79304 .21931 .79223 .21809 Mtetra
.751 .772 .87 r
.79223 .21809 .79304 .21931 .79489 .21817 .79408 .21694 Mtetra
.623 .722 .918 r
.79408 .21694 .79489 .21817 .79681 .21769 .79599 .21647 Mtetra
.553 .689 .929 r
.79599 .21647 .79681 .21769 .79874 .21749 .79793 .21626 Mtetra
.746 .772 .874 r
.79793 .21626 .79874 .21749 .8006 .21637 .79979 .21515 Mtetra
.677 .746 .903 r
.79979 .21515 .8006 .21637 .80249 .21564 .80168 .21442 Mtetra
.457 .638 .934 r
.80168 .21442 .80249 .21564 .80446 .21576 .80365 .21454 Mtetra
.769 .353 0 r
.80365 .21454 .80446 .21576 .80691 .22097 .8061 .21975 Mtetra
.971 .657 .298 r
.8061 .21975 .80691 .22097 .82838 .42999 .82753 .42882 Mtetra
.725 .291 0 r
.82753 .42882 .82838 .42999 .83092 .43462 .83007 .43346 Mtetra
.307 .58 .938 r
.83007 .43346 .83092 .43462 .83308 .4351 .83223 .43394 Mtetra
.65 .764 .933 r
.83223 .43394 .83308 .4351 .83513 .43446 .83428 .43329 Mtetra
.83 .821 .84 r
.83428 .43329 .83513 .43446 .83707 .43265 .83622 .43148 Mtetra
.975 .789 .589 r
.83622 .43148 .83707 .43265 .8386 .42653 .83775 .42537 Mtetra
.974 .667 .312 r
.83775 .42537 .8386 .42653 .82026 .21612 .81946 .21491 Mtetra
.975 .775 .572 r
.81946 .21491 .82026 .21612 .82163 .20983 .82082 .20861 Mtetra
.761 .759 .851 r
.20561 .42054 .20667 .42151 .20825 .42043 .2072 .41946 Mtetra
.614 .73 .928 r
.2072 .41946 .20825 .42043 .20977 .42007 .20871 .41911 Mtetra
.459 .673 .956 r
.20871 .41911 .20977 .42007 .21124 .4201 .21019 .41914 Mtetra
.657 .744 .914 r
.21019 .41914 .21124 .4201 .21277 .41959 .21172 .41863 Mtetra
.666 .747 .91 r
.21172 .41863 .21277 .41959 .21431 .41904 .21326 .41809 Mtetra
.672 .749 .908 r
.21326 .41809 .21431 .41904 .21585 .41847 .21479 .41752 Mtetra
.764 .764 .852 r
.21479 .41752 .21585 .41847 .21744 .41737 .21638 .41642 Mtetra
.71 .758 .89 r
.21638 .41642 .21744 .41737 .21899 .41662 .21794 .41568 Mtetra
.491 .692 .957 r
.21794 .41568 .21899 .41662 .22049 .41657 .21943 .41563 Mtetra
.93 .558 .278 r
.21943 .41563 .22049 .41657 .22157 .42084 .22052 .41996 Mtetra
.939 .683 .523 r
.22052 .41996 .22157 .42084 .20454 .61994 .2034 .6191 Mtetra
.93 .57 .319 r
.2034 .6191 .20454 .61994 .20564 .6251 .20452 .6242 Mtetra
0 .371 .809 r
.20452 .6242 .20564 .6251 .20716 .62586 .20604 .62495 Mtetra
.624 .76 .944 r
.20604 .62495 .20716 .62586 .20879 .62543 .20767 .62452 Mtetra
.803 .783 .835 r
.20767 .62452 .20879 .62543 .21052 .62395 .20939 .62304 Mtetra
.907 .744 .668 r
.20939 .62304 .21052 .62395 .21257 .61884 .21145 .61796 Mtetra
.939 .687 .53 r
.21145 .61796 .21257 .61884 .23223 .41883 .23117 .41792 Mtetra
.917 .729 .633 r
.23117 .41792 .23223 .41883 .23433 .41215 .23328 .41118 Mtetra
.793 .765 .828 r
.23328 .41118 .23433 .41215 .23595 .41079 .2349 .40982 Mtetra
.626 .736 .926 r
.2349 .40982 .23595 .41079 .23748 .4104 .23644 .40942 Mtetra
.459 .673 .956 r
.23644 .40942 .23748 .4104 .23898 .41043 .23793 .40945 Mtetra
.619 .732 .927 r
.23793 .40945 .23898 .41043 .24051 .41007 .23947 .40908 Mtetra
.645 .736 .916 r
.23947 .40908 .24051 .41007 .24205 .40963 .24101 .40861 Mtetra
.653 .735 .91 r
.24101 .40861 .24205 .40963 .2436 .40915 .24256 .40812 Mtetra
.672 .736 .898 r
.24256 .40812 .2436 .40915 .24515 .40862 .24412 .40754 Mtetra
.679 .73 .888 r
.24412 .40754 .24515 .40862 .24671 .40803 .24568 .40693 Mtetra
.681 .726 .883 r
.24568 .40693 .24671 .40803 .24827 .40738 .24724 .4063 Mtetra
.676 .728 .889 r
.24724 .4063 .24827 .40738 .24984 .40663 .2488 .4057 Mtetra
.677 .759 .913 r
.2488 .4057 .24984 .40663 .25142 .40585 .25036 .4051 Mtetra
.675 .8 .942 r
.25036 .4051 .25142 .40585 .25299 .40509 .25192 .40451 Mtetra
.668 .84 .966 r
.25192 .40451 .25299 .40509 .25456 .40443 .25348 .40392 Mtetra
.66 .857 .975 r
.25348 .40392 .25456 .40443 .25612 .40383 .25505 .40334 Mtetra
.656 .859 .977 r
.25505 .40334 .25612 .40383 .25768 .40329 .25661 .40276 Mtetra
.656 .849 .974 r
.25661 .40276 .25768 .40329 .25923 .40286 .25817 .40219 Mtetra
.662 .817 .958 r
.25817 .40219 .25923 .40286 .26078 .40248 .25973 .40164 Mtetra
.664 .776 .933 r
.25973 .40164 .26078 .40248 .26233 .40209 .2613 .40109 Mtetra
.659 .74 .909 r
.2613 .40109 .26233 .40209 .26389 .40163 .26286 .40056 Mtetra
.658 .728 .901 r
.26286 .40056 .26389 .40163 .26545 .40109 .26442 .40004 Mtetra
.659 .731 .902 r
.26442 .40004 .26545 .40109 .26702 .4005 .26599 .39951 Mtetra
.668 .746 .909 r
.26599 .39951 .26702 .4005 .2686 .39981 .26755 .39895 Mtetra
.673 .775 .927 r
.26755 .39895 .2686 .39981 .27018 .39908 .26912 .39837 Mtetra
.673 .81 .948 r
.26912 .39837 .27018 .39908 .27176 .39836 .2707 .39778 Mtetra
.68 .842 .961 r
.2707 .39778 .27176 .39836 .27335 .39757 .27227 .39715 Mtetra
.661 .879 .979 r
.27227 .39715 .27335 .39757 .27493 .39689 .27385 .39653 Mtetra
.627 .886 .988 r
.27385 .39653 .27493 .39689 .27649 .39648 .27542 .39597 Mtetra
.704 .863 .958 r
.27542 .39597 .27649 .39648 .27799 .39676 .27701 .39524 Mtetra
.648 .65 .838 r
.27701 .39524 .27799 .39676 .27944 .3979 .27858 .39472 Mtetra
.538 .459 .713 r
.27858 .39472 .27944 .3979 .28075 .40085 .2801 .3948 Mtetra
.201 .144 .565 r
.2801 .3948 .28075 .40085 .26762 .59566 .28139 .39801 Mtetra
0 0 .192 r
.28139 .39801 .26762 .59566 .2687 .60309 .26797 .59708 Mtetra
0 0 .305 r
.26797 .59708 .2687 .60309 .27016 .60542 .26913 .60349 Mtetra
.208 .375 .811 r
.26913 .60349 .27016 .60542 .27177 .60579 .27069 .60447 Mtetra
.624 .685 .887 r
.27069 .60447 .27177 .60579 .27345 .60524 .27236 .60406 Mtetra
.722 .736 .862 r
.27236 .60406 .27345 .60524 .27517 .60413 .27407 .60314 Mtetra
.648 .753 .926 r
.27407 .60314 .27517 .60413 .27692 .60256 .27575 .60261 Mtetra
.44 .875 .898 r
.27575 .60261 .27692 .60256 .27873 .60022 .27744 .60206 Mtetra
.056 0 0 r
.27744 .60206 .27873 .60022 .28068 .59604 .27917 .60084 Mtetra
0 0 .051 r
.27917 .60084 .28068 .59604 .29622 .40008 .28113 .5964 Mtetra
0 0 .183 r
.28113 .5964 .29622 .40008 .29835 .39184 .29698 .39586 Mtetra
.864 .831 .358 r
.29698 .39586 .29835 .39184 .30012 .38867 .29904 .3886 Mtetra
.903 .916 .82 r
.29904 .3886 .30012 .38867 .30177 .38725 .30073 .38658 Mtetra
.698 .824 .943 r
.30073 .38658 .30177 .38725 .30336 .38668 .30232 .38588 Mtetra
.555 .757 .972 r
.30232 .38588 .30336 .38668 .30491 .38659 .30389 .38564 Mtetra
.664 .754 .917 r
.30389 .38564 .30491 .38659 .30644 .3869 .30548 .38508 Mtetra
.65 .616 .802 r
.30548 .38508 .30644 .3869 .30793 .3878 .30707 .3845 Mtetra
.556 .465 .707 r
.30707 .3845 .30793 .3878 .30934 .38998 .30863 .38445 Mtetra
.297 .224 .603 r
.30863 .38445 .30934 .38998 .29873 .57263 .31002 .38681 Mtetra
0 0 .182 r
.31002 .38681 .29873 .57263 .29909 .59208 .2985 .58367 Mtetra
0 0 .228 r
.2985 .58367 .29909 .59208 .30056 .59502 .29951 .59336 Mtetra
0 .189 .721 r
.29951 .59336 .30056 .59502 .30217 .59578 .30108 .59482 Mtetra
.581 .743 .953 r
.30108 .59482 .30217 .59578 .30385 .5955 .30276 .59451 Mtetra
.718 .774 .897 r
.30276 .59451 .30385 .5955 .30557 .59465 .30448 .59366 Mtetra
.648 .757 .928 r
.30448 .59366 .30557 .59465 .30732 .59326 .30618 .59313 Mtetra
.434 .858 .947 r
.30618 .59313 .30732 .59326 .30912 .59114 .30787 .59271 Mtetra
.071 0 0 r
.30787 .59271 .30912 .59114 .31101 .58754 .3096 .59169 Mtetra
0 0 .068 r
.3096 .59169 .31101 .58754 .32375 .4097 .3115 .58807 Mtetra
0 0 .146 r
.3115 .58807 .32375 .4097 .32694 .3835 .32547 .38991 Mtetra
.785 .746 .226 r
.32547 .38991 .32694 .3835 .32874 .37987 .32769 .37948 Mtetra
.903 .853 .783 r
.32769 .37948 .32874 .37987 .3304 .37831 .3294 .37712 Mtetra
.678 .715 .876 r
.3294 .37712 .3304 .37831 .332 .37774 .33101 .37648 Mtetra
.558 .657 .902 r
.33101 .37648 .332 .37774 .33359 .37751 .33259 .37633 Mtetra
.583 .683 .91 r
.33259 .37633 .33359 .37751 .33518 .37719 .33418 .37608 Mtetra
.647 .72 .901 r
.33418 .37608 .33518 .37719 .33679 .37669 .33578 .37559 Mtetra
.651 .724 .902 r
.33578 .37559 .33679 .37669 .33839 .37617 .33739 .37508 Mtetra
.658 .73 .902 r
.33739 .37508 .33839 .37617 .34 .37561 .339 .37455 Mtetra
.666 .735 .901 r
.339 .37455 .34 .37561 .34161 .37504 .34061 .37397 Mtetra
.669 .737 .901 r
.34061 .37397 .34161 .37504 .34322 .37445 .34222 .37339 Mtetra
.67 .739 .901 r
.34222 .37339 .34322 .37445 .34484 .37385 .34383 .3728 Mtetra
.671 .739 .901 r
.34383 .3728 .34484 .37385 .34645 .37327 .34545 .37221 Mtetra
.671 .738 .901 r
.34545 .37221 .34645 .37327 .34807 .37267 .34707 .37161 Mtetra
.671 .737 .9 r
.34707 .37161 .34807 .37267 .34968 .37209 .34868 .37101 Mtetra
.671 .736 .899 r
.34868 .37101 .34968 .37209 .3513 .3715 .3503 .37042 Mtetra
.672 .735 .898 r
.3503 .37042 .3513 .3715 .35292 .3709 .35192 .36982 Mtetra
.673 .734 .896 r
.35192 .36982 .35292 .3709 .35454 .37032 .35354 .36921 Mtetra
.674 .73 .892 r
.35354 .36921 .35454 .37032 .35616 .36974 .35516 .3686 Mtetra
.673 .725 .888 r
.35516 .3686 .35616 .36974 .35778 .36912 .35679 .36799 Mtetra
.672 .725 .889 r
.35679 .36799 .35778 .36912 .35941 .36843 .35841 .36738 Mtetra
.672 .742 .903 r
.35841 .36738 .35941 .36843 .36104 .36766 .36003 .36678 Mtetra
.673 .778 .929 r
.36003 .36678 .36104 .36766 .36267 .3669 .36166 .36618 Mtetra
.674 .816 .951 r
.36166 .36618 .36267 .3669 .3643 .3662 .36328 .36556 Mtetra
.675 .837 .961 r
.36328 .36556 .3643 .3662 .36593 .36556 .36491 .36493 Mtetra
.674 .836 .961 r
.36491 .36493 .36593 .36556 .36756 .36496 .36654 .3643 Mtetra
.723 .839 .936 r
.36654 .3643 .36756 .36496 .36919 .36422 .36818 .36348 Mtetra
.74 .822 .915 r
.36818 .36348 .36919 .36422 .37083 .36341 .36982 .36258 Mtetra
.627 .778 .954 r
.36982 .36258 .37083 .36341 .37245 .36291 .37145 .36214 Mtetra
0 .162 .615 r
.37145 .36214 .37245 .36291 .37404 .3633 .373 .36323 Mtetra
.924 .58 .364 r
.373 .36323 .37404 .3633 .37553 .36557 .37427 .37027 Mtetra
.948 .677 .49 r
.37427 .37027 .37553 .36557 .37672 .37475 .36654 .57047 Mtetra
.542 .316 .522 r
.36654 .57047 .37672 .37475 .36941 .56935 .36811 .57347 Mtetra
.514 .193 .361 r
.36811 .57347 .36941 .56935 .37098 .57236 .36982 .57356 Mtetra
.195 0 0 r
.36982 .57356 .37098 .57236 .37264 .57361 .37156 .57302 Mtetra
.669 .857 .971 r
.37156 .57302 .37264 .57361 .37435 .5739 .37331 .57234 Mtetra
.641 .661 .853 r
.37331 .57234 .37435 .5739 .37609 .57349 .37506 .57181 Mtetra
.649 .649 .837 r
.37506 .57181 .37609 .57349 .37784 .57281 .3768 .57123 Mtetra
.651 .663 .848 r
.3768 .57123 .37784 .57281 .37959 .57212 .37855 .57065 Mtetra
.648 .676 .863 r
.37855 .57065 .37959 .57212 .38134 .5716 .3803 .5701 Mtetra
.647 .672 .86 r
.3803 .5701 .38134 .5716 .38308 .57108 .38205 .56954 Mtetra
.607 .652 .868 r
.38205 .56954 .38308 .57108 .38483 .57068 .38379 .56919 Mtetra
.555 .637 .886 r
.38379 .56919 .38483 .57068 .38656 .57041 .38552 .56905 Mtetra
.664 .702 .875 r
.38552 .56905 .38656 .57041 .38832 .5698 .38728 .56843 Mtetra
.826 .738 .766 r
.38728 .56843 .38832 .5698 .39011 .56828 .3891 .56624 Mtetra
.91 .698 .604 r
.3891 .56624 .39011 .56828 .39199 .5646 .39117 .55764 Mtetra
.95 .683 .494 r
.39117 .55764 .39199 .5646 .39414 .5538 .40077 .35607 Mtetra
.546 .324 .529 r
.40077 .35607 .39414 .5538 .40335 .35778 .40255 .3521 Mtetra
.62 .454 .635 r
.40255 .3521 .40335 .35778 .40513 .35403 .40422 .35093 Mtetra
.619 .515 .714 r
.40422 .35093 .40513 .35403 .40684 .35185 .40587 .35033 Mtetra
.627 .649 .852 r
.40587 .35033 .40684 .35185 .40851 .3505 .40752 .34991 Mtetra
.654 .847 .974 r
.40752 .34991 .40851 .3505 .41017 .34979 .40917 .34931 Mtetra
.62 .866 .989 r
.40917 .34931 .41017 .34979 .41182 .34932 .41082 .34877 Mtetra
.627 .851 .985 r
.41082 .34877 .41182 .34932 .41347 .34889 .41247 .34824 Mtetra
.648 .832 .971 r
.41247 .34824 .41347 .34889 .41512 .34831 .41413 .34768 Mtetra
.645 .837 .974 r
.41413 .34768 .41512 .34831 .41678 .34772 .41578 .34712 Mtetra
.684 .853 .963 r
.41578 .34712 .41678 .34772 .41843 .34706 .41744 .34643 Mtetra
.746 .856 .931 r
.41744 .34643 .41843 .34706 .4201 .34625 .41911 .3455 Mtetra
.645 .809 .962 r
.41911 .3455 .4201 .34625 .42176 .3457 .42077 .34497 Mtetra
0 .452 .853 r
.42077 .34497 .42176 .3457 .42339 .34585 .42239 .34559 Mtetra
.918 .541 .288 r
.42239 .34559 .42339 .34585 .42497 .34781 .42386 .35097 Mtetra
.955 .679 .474 r
.42386 .35097 .42497 .34781 .42642 .35426 .41918 .55321 Mtetra
.544 .318 .522 r
.41918 .55321 .42642 .35426 .42203 .55234 .42081 .55722 Mtetra
.53 .221 .388 r
.42081 .55722 .42203 .55234 .42368 .55585 .42256 .55747 Mtetra
.32 0 .057 r
.42256 .55747 .42368 .55585 .42539 .55731 .42433 .55703 Mtetra
.621 .915 .979 r
.42433 .55703 .42539 .55731 .42714 .55784 .42611 .55632 Mtetra
.638 .67 .864 r
.42611 .55632 .42714 .55784 .42891 .55766 .42789 .55581 Mtetra
.643 .629 .821 r
.42789 .55581 .42891 .55766 .43068 .55718 .42967 .55523 Mtetra
.643 .619 .81 r
.42967 .55523 .43068 .55718 .43247 .55654 .43145 .55463 Mtetra
.638 .621 .816 r
.43145 .55463 .43247 .55654 .43425 .55588 .43324 .55408 Mtetra
.641 .634 .828 r
.43324 .55408 .43425 .55588 .43604 .55516 .43502 .55352 Mtetra
.628 .648 .85 r
.43502 .55352 .43604 .55516 .43782 .55452 .4368 .55305 Mtetra
.553 .639 .89 r
.4368 .55305 .43782 .55452 .4396 .55423 .43858 .55291 Mtetra
.65 .706 .888 r
.43858 .55291 .4396 .55423 .44139 .55367 .44036 .55235 Mtetra
.797 .746 .806 r
.44036 .55235 .44139 .55367 .44319 .5524 .44218 .55068 Mtetra
.912 .716 .624 r
.44218 .55068 .44319 .5524 .44506 .54876 .44411 .544 Mtetra
.958 .686 .477 r
.44411 .544 .44506 .54876 .44703 .54003 .45067 .34009 Mtetra
.548 .325 .529 r
.45067 .34009 .44703 .54003 .45328 .34234 .45246 .33505 Mtetra
.602 .424 .614 r
.45246 .33505 .45328 .34234 .45499 .34057 .45415 .33393 Mtetra
.573 .409 .622 r
.45415 .33393 .45499 .34057 .45666 .34029 .45583 .33349 Mtetra
.557 .397 .62 r
.45583 .33349 .45666 .34029 .45833 .34066 .4575 .33332 Mtetra
.576 .406 .613 r
.4575 .33332 .45833 .34066 .46001 .34009 .45918 .33274 Mtetra
.576 .405 .613 r
.45918 .33274 .46001 .34009 .4617 .33954 .46087 .33217 Mtetra
.46087 .33217 .4617 .33954 .46339 .339 .46255 .33161 Mtetra
.46255 .33161 .46339 .339 .46507 .33842 .46424 .33103 Mtetra
.46424 .33103 .46507 .33842 .46676 .33784 .46592 .33044 Mtetra
.46592 .33044 .46676 .33784 .46846 .33725 .46761 .32986 Mtetra
.46761 .32986 .46846 .33725 .47015 .33667 .4693 .32927 Mtetra
.4693 .32927 .47015 .33667 .47184 .33607 .47099 .32869 Mtetra
.577 .406 .613 r
.47099 .32869 .47184 .33607 .47353 .33546 .47268 .32809 Mtetra
.578 .406 .613 r
.47268 .32809 .47353 .33546 .47523 .33482 .47438 .32749 Mtetra
.578 .407 .614 r
.47438 .32749 .47523 .33482 .47693 .33418 .47607 .32688 Mtetra
.579 .408 .614 r
.47607 .32688 .47693 .33418 .47863 .33348 .47776 .32625 Mtetra
.599 .423 .615 r
.47776 .32625 .47863 .33348 .48034 .33186 .47947 .32521 Mtetra
.583 .417 .622 r
.47947 .32521 .48034 .33186 .48204 .33114 .48116 .32457 Mtetra
.536 .385 .622 r
.48116 .32457 .48204 .33114 .48372 .33231 .48285 .32475 Mtetra
.104 .065 .525 r
.48285 .32475 .48372 .33231 .48292 .53126 .48447 .33017 Mtetra
0 0 .316 r
.48447 .33017 .48292 .53126 .48465 .53723 .48367 .53348 Mtetra
0 0 .468 r
.48367 .53348 .48465 .53723 .48644 .53941 .48543 .53785 Mtetra
.501 .603 .887 r
.48543 .53785 .48644 .53941 .48825 .53928 .48724 .53792 Mtetra
.667 .707 .878 r
.48724 .53792 .48825 .53928 .49007 .53867 .48906 .53725 Mtetra
.723 .719 .846 r
.48906 .53725 .49007 .53867 .49189 .5378 .49088 .53622 Mtetra
.632 .662 .861 r
.49088 .53622 .49189 .5378 .49371 .53743 .4927 .53573 Mtetra
.636 .647 .844 r
.4927 .53573 .49371 .53743 .49553 .53689 .49453 .5352 Mtetra
.647 .653 .842 r
.49453 .5352 .49553 .53689 .49736 .53603 .49635 .53461 Mtetra
.692 .708 .86 r
.49635 .53461 .49736 .53603 .49919 .53383 .49818 .53379 Mtetra
.601 .945 .929 r
.49818 .53379 .49919 .53383 .50104 .53066 .5 .53291 Mtetra
.297 0 .142 r
.5 .53291 .50104 .53066 .50289 .52601 .50183 .53205 Mtetra
.511 .219 .406 r
.50183 .53205 .50289 .52601 .50471 .52552 .50366 .53197 Mtetra
.493 .207 .408 r
.50366 .53197 .50471 .52552 .50653 .5255 .50549 .53156 Mtetra
.433 .152 .384 r
.50549 .53156 .50653 .5255 .50836 .52422 .50732 .53038 Mtetra
0 0 .17 r
.50732 .53038 .50836 .52422 .51106 .32434 .50918 .52406 Mtetra
0 0 .313 r
.50918 .52406 .51106 .32434 .51281 .31729 .51186 .31918 Mtetra
.921 .872 .443 r
.51186 .31918 .51281 .31729 .51453 .31416 .51359 .31361 Mtetra
.812 .887 .899 r
.51359 .31361 .51453 .31416 .51625 .31324 .51531 .3123 Mtetra
.643 .768 .939 r
.51531 .3123 .51625 .31324 .51797 .31287 .51703 .31178 Mtetra
.538 .693 .94 r
.51703 .31178 .51797 .31287 .51969 .31276 .51875 .31163 Mtetra
.641 .728 .912 r
.51875 .31163 .51969 .31276 .52141 .31228 .52047 .31113 Mtetra
.65 .727 .905 r
.52047 .31113 .52141 .31228 .52313 .31172 .52219 .31059 Mtetra
.654 .734 .908 r
.52219 .31059 .52313 .31172 .52485 .31109 .52392 .31003 Mtetra
.682 .757 .908 r
.52392 .31003 .52485 .31109 .52657 .31014 .52564 .30935 Mtetra
.681 .818 .949 r
.52564 .30935 .52657 .31014 .5283 .30929 .52737 .30867 Mtetra
.655 .853 .976 r
.52737 .30867 .5283 .30929 .53002 .30874 .52909 .30804 Mtetra
.713 .848 .947 r
.52909 .30804 .53002 .30874 .53175 .30909 .53082 .30723 Mtetra
.631 .613 .814 r
.53082 .30723 .53175 .30909 .53349 .31042 .53255 .30673 Mtetra
.53 .439 .697 r
.53255 .30673 .53349 .31042 .53523 .31419 .53428 .30691 Mtetra
.211 .148 .564 r
.53428 .30691 .53523 .31419 .53774 .51473 .53603 .31132 Mtetra
0 0 .343 r
.53603 .31132 .53774 .51473 .53961 .52038 .53861 .51549 Mtetra
0 0 .501 r
.53861 .51549 .53961 .52038 .54148 .52241 .54048 .52057 Mtetra
.394 .506 .853 r
.54048 .52057 .54148 .52241 .54333 .52264 .54234 .5211 Mtetra
.636 .672 .867 r
.54234 .5211 .54333 .52264 .54519 .52212 .5442 .52057 Mtetra
.711 .701 .839 r
.5442 .52057 .54519 .52212 .54704 .52104 .54605 .51958 Mtetra
.623 .679 .882 r
.54605 .51958 .54704 .52104 .54889 .51936 .54791 .51913 Mtetra
.561 .911 .968 r
.54791 .51913 .54889 .51936 .55074 .51678 .54977 .51846 Mtetra
.037 0 0 r
.54977 .51846 .55074 .51678 .55256 .51224 .55163 .51709 Mtetra
0 0 .135 r
.55163 .51709 .55256 .51224 .55265 .31217 .55345 .51185 Mtetra
0 0 .332 r
.55345 .51185 .55265 .31217 .55433 .30371 .55344 .30638 Mtetra
.849 .806 .317 r
.55344 .30638 .55433 .30371 .55604 .3005 .55512 .29968 Mtetra
.844 .834 .836 r
.55512 .29968 .55604 .3005 .55778 .29923 .55686 .29797 Mtetra
.665 .715 .885 r
.55686 .29797 .55778 .29923 .55952 .29861 .5586 .29734 Mtetra
.57 .674 .91 r
.5586 .29734 .55952 .29861 .56127 .29824 .56035 .29712 Mtetra
.725 .761 .881 r
.56035 .29712 .56127 .29824 .56301 .29715 .5621 .2962 Mtetra
.716 .792 .912 r
.5621 .2962 .56301 .29715 .56475 .29618 .56384 .29536 Mtetra
.526 .757 .981 r
.56384 .29536 .56475 .29618 .56651 .29586 .56559 .29514 Mtetra
.803 .327 0 r
.56559 .29514 .56651 .29586 .56831 .29885 .56739 .29814 Mtetra
.971 .681 .418 r
.56739 .29814 .56831 .29885 .57304 .50409 .57205 .50247 Mtetra
.918 .544 .12 r
.57205 .50247 .57304 .50409 .57503 .51139 .57404 .50981 Mtetra
.212 .437 .861 r
.57404 .50981 .57503 .51139 .57692 .51231 .57594 .51073 Mtetra
.632 .667 .865 r
.57594 .51073 .57692 .51231 .5788 .51171 .57782 .51022 Mtetra
.719 .715 .845 r
.57782 .51022 .5788 .51171 .58067 .51036 .57969 .50919 Mtetra
.635 .738 .922 r
.57969 .50919 .58067 .51036 .58253 .50866 .58158 .50867 Mtetra
.388 .848 .868 r
.58158 .50867 .58253 .50866 .58438 .50628 .58346 .50809 Mtetra
.13 0 .004 r
.58346 .50809 .58438 .50628 .5862 .50228 .58533 .50685 Mtetra
0 0 .174 r
.58533 .50685 .5862 .50228 .58433 .30461 .58714 .50238 Mtetra
0 0 .344 r
.58714 .50238 .58433 .30461 .58589 .29336 .58508 .29737 Mtetra
.708 .688 .148 r
.58508 .29737 .58589 .29336 .5876 .28986 .5867 .28919 Mtetra
.884 .863 .814 r
.5867 .28919 .5876 .28986 .58934 .28841 .58843 .28714 Mtetra
.68 .722 .881 r
.58843 .28714 .58934 .28841 .59111 .28774 .5902 .28644 Mtetra
.585 .676 .903 r
.5902 .28644 .59111 .28774 .59288 .28733 .59197 .28616 Mtetra
.714 .751 .881 r
.59197 .28616 .59288 .28733 .59463 .2863 .59373 .28528 Mtetra
.73 .786 .897 r
.59373 .28528 .59463 .2863 .59639 .28524 .59549 .28435 Mtetra
.581 .763 .965 r
.59549 .28435 .59639 .28524 .59816 .28478 .59727 .284 Mtetra
.687 .184 0 r
.59727 .284 .59816 .28478 .6 .28694 .59911 .28637 Mtetra
.973 .679 .405 r
.59911 .28637 .6 .28694 .60676 .48798 .60585 .48912 Mtetra
.915 .558 .346 r
.60585 .48912 .60676 .48798 .60896 .4998 .608 .49881 Mtetra
0 .128 .627 r
.608 .49881 .60896 .4998 .61092 .50154 .60996 .50043 Mtetra
.548 .716 .951 r
.60996 .50043 .61092 .50154 .61283 .50135 .61187 .50021 Mtetra
.772 .787 .865 r
.61187 .50021 .61283 .50135 .61471 .50004 .61375 .4989 Mtetra
.924 .785 .689 r
.61375 .4989 .61471 .50004 .61652 .49583 .61556 .4949 Mtetra
.975 .687 .415 r
.61556 .4949 .61652 .49583 .61263 .29004 .6118 .29116 Mtetra
.999 .794 .459 r
.6118 .29116 .61263 .29004 .61417 .2807 .61329 .2801 Mtetra
.91 .874 .789 r
.61329 .2801 .61417 .2807 .6159 .27851 .61502 .27774 Mtetra
.675 .828 .957 r
.61502 .27774 .6159 .27851 .61768 .27798 .6168 .27705 Mtetra
.531 .735 .968 r
.6168 .27705 .61768 .27798 .61948 .27795 .61859 .27685 Mtetra
.598 .725 .933 r
.61859 .27685 .61948 .27795 .62128 .27769 .62038 .27649 Mtetra
.658 .729 .901 r
.62038 .27649 .62128 .27769 .62306 .2771 .62217 .27589 Mtetra
.663 .73 .899 r
.62217 .27589 .62306 .2771 .62485 .27643 .62396 .27527 Mtetra
.734 .763 .876 r
.62396 .27527 .62485 .27643 .62662 .27532 .62573 .27428 Mtetra
.742 .787 .889 r
.62573 .27428 .62662 .27532 .62839 .27419 .62751 .27327 Mtetra
.617 .774 .956 r
.62751 .27327 .62839 .27419 .63018 .27361 .6293 .27281 Mtetra
.522 .009 0 r
.6293 .27281 .63018 .27361 .63205 .27529 .63118 .27465 Mtetra
.974 .677 .391 r
.63118 .27465 .63205 .27529 .6346 .29626 .6399 .47272 Mtetra
.565 .333 .523 r
.6399 .47272 .6346 .29626 .64331 .48861 .64237 .48764 Mtetra
0 .006 .511 r
.64237 .48764 .64331 .48861 .64533 .49078 .64438 .48966 Mtetra
.514 .701 .954 r
.64438 .48966 .64533 .49078 .64727 .49069 .64633 .48954 Mtetra
.759 .787 .875 r
.64633 .48954 .64727 .49069 .64917 .48947 .64823 .48833 Mtetra
.919 .793 .706 r
.64823 .48833 .64917 .48947 .65098 .48566 .65004 .48469 Mtetra
.976 .685 .401 r
.65004 .48469 .65098 .48566 .64501 .28111 .64428 .2841 Mtetra
.973 .772 .345 r
.64428 .2841 .64501 .28111 .6464 .2698 .64554 .26921 Mtetra
.93 .871 .759 r
.64554 .26921 .6464 .2698 .64812 .26727 .64726 .2665 Mtetra
.692 .836 .952 r
.64726 .2665 .64812 .26727 .64992 .26667 .64905 .26574 Mtetra
.547 .745 .968 r
.64905 .26574 .64992 .26667 .65175 .26658 .65087 .26549 Mtetra
.586 .724 .938 r
.65087 .26549 .65175 .26658 .65357 .26637 .65269 .26517 Mtetra
.66 .731 .902 r
.65269 .26517 .65357 .26637 .65538 .26577 .65449 .26455 Mtetra
.666 .731 .898 r
.65449 .26455 .65538 .26577 .65718 .26509 .6563 .26391 Mtetra
.725 .76 .88 r
.6563 .26391 .65718 .26509 .65897 .26403 .6581 .26296 Mtetra
.748 .786 .884 r
.6581 .26296 .65897 .26403 .66075 .26285 .65989 .2619 Mtetra
.648 .781 .945 r
.65989 .2619 .66075 .26285 .66256 .26216 .6617 .26133 Mtetra
0 .245 .719 r
.6617 .26133 .66256 .26216 .66445 .26327 .66359 .26258 Mtetra
.937 .563 .205 r
.66359 .26258 .66445 .26327 .66664 .27084 .66584 .27153 Mtetra
.974 .673 .379 r
.66584 .27153 .66664 .27084 .67802 .47636 .67711 .47549 Mtetra
.595 .091 0 r
.67711 .47549 .67802 .47636 .68012 .47894 .67919 .47785 Mtetra
.621 .757 .943 r
.67919 .47785 .68012 .47894 .68207 .47847 .68114 .47735 Mtetra
.763 .797 .881 r
.68114 .47735 .68207 .47847 .68399 .47725 .68306 .47612 Mtetra
.769 .796 .875 r
.68306 .47612 .68399 .47725 .68591 .476 .68498 .47484 Mtetra
.703 .772 .905 r
.68498 .47484 .68591 .476 .68785 .47518 .68692 .47397 Mtetra
.689 .757 .904 r
.68692 .47397 .68785 .47518 .68979 .47442 .68886 .47316 Mtetra
.648 .734 .911 r
.68886 .47316 .68979 .47442 .69175 .47383 .69082 .47256 Mtetra
.596 .71 .923 r
.69082 .47256 .69175 .47383 .69371 .47342 .69278 .47219 Mtetra
.575 .707 .932 r
.69278 .47219 .69371 .47342 .69568 .47308 .69476 .47189 Mtetra
.485 .672 .946 r
.69476 .47189 .69568 .47308 .69767 .47304 .69675 .47188 Mtetra
.439 .655 .951 r
.69675 .47188 .69767 .47304 .69967 .47314 .69875 .47199 Mtetra
.634 .751 .933 r
.69875 .47199 .69967 .47314 .70163 .47258 .70071 .47144 Mtetra
.888 .809 .765 r
.70071 .47144 .70163 .47258 .70348 .46991 .70256 .46877 Mtetra
.98 .725 .472 r
.70256 .46877 .70348 .46991 .70458 .4535 .70365 .45212 Mtetra
.977 .681 .379 r
.70365 .45212 .70458 .4535 .6955 .25395 .69464 .25277 Mtetra
.912 .789 .712 r
.69464 .25277 .6955 .25395 .69718 .25069 .69632 .24951 Mtetra
.709 .757 .89 r
.69632 .24951 .69718 .25069 .699 .24983 .69814 .24865 Mtetra
.587 .708 .927 r
.69814 .24865 .699 .24983 .70086 .24951 .7 .24833 Mtetra
.623 .724 .919 r
.7 .24833 .70086 .24951 .7027 .24905 .70184 .24787 Mtetra
.732 .766 .88 r
.70184 .24787 .7027 .24905 .70452 .24805 .70366 .24687 Mtetra
.64 .732 .915 r
.70366 .24687 .70452 .24805 .70636 .24752 .7055 .24634 Mtetra
.06 .396 .854 r
.7055 .24634 .70636 .24752 .7083 .24855 .70744 .24738 Mtetra
.926 .554 .142 r
.70744 .24738 .7083 .24855 .71075 .25804 .70989 .25688 Mtetra
.975 .671 .352 r
.70989 .25688 .71075 .25804 .7251 .46252 .7242 .4614 Mtetra
.602 .139 0 r
.7242 .4614 .7251 .46252 .7273 .46547 .72639 .46435 Mtetra
.418 .654 .957 r
.72639 .46435 .7273 .46547 .72932 .46562 .72842 .4645 Mtetra
.711 .787 .911 r
.72842 .4645 .72932 .46562 .73129 .46469 .73038 .46357 Mtetra
.888 .816 .771 r
.73038 .46357 .73129 .46469 .73315 .46209 .73224 .46097 Mtetra
.977 .758 .54 r
.73224 .46097 .73315 .46209 .7346 .45315 .7337 .45206 Mtetra
.977 .679 .365 r
.7337 .45206 .7346 .45315 .7232 .24564 .72235 .24447 Mtetra
.938 .788 .669 r
.72235 .24447 .7232 .24564 .72483 .24159 .72399 .24041 Mtetra
.721 .765 .887 r
.72399 .24041 .72483 .24159 .72666 .24065 .72582 .23947 Mtetra
.581 .708 .93 r
.72582 .23947 .72666 .24065 .72854 .24035 .72769 .23917 Mtetra
.541 .689 .935 r
.72769 .23917 .72854 .24035 .73042 .24018 .72958 .239 Mtetra
.658 .742 .912 r
.72958 .239 .73042 .24018 .73228 .23956 .73144 .23839 Mtetra
.664 .744 .91 r
.73144 .23839 .73228 .23956 .73414 .23892 .73329 .23774 Mtetra
.701 .758 .896 r
.73329 .23774 .73414 .23892 .73598 .23809 .73514 .23691 Mtetra
.757 .776 .868 r
.73514 .23691 .73598 .23809 .7378 .23692 .73696 .23574 Mtetra
.674 .747 .905 r
.73696 .23574 .7378 .23692 .73966 .23623 .73882 .23504 Mtetra
.24 .515 .91 r
.73882 .23504 .73966 .23623 .74161 .23689 .74077 .23571 Mtetra
.896 .51 .065 r
.74077 .23571 .74161 .23689 .74409 .24485 .74325 .24368 Mtetra
.975 .667 .334 r
.74325 .24368 .74409 .24485 .76087 .45103 .75998 .4499 Mtetra
.635 .18 0 r
.75998 .4499 .76087 .45103 .76316 .45437 .76227 .45323 Mtetra
.392 .636 .953 r
.76227 .45323 .76316 .45437 .76523 .4546 .76434 .45346 Mtetra
.695 .781 .918 r
.76434 .45346 .76523 .4546 .76722 .45375 .76633 .45261 Mtetra
.873 .82 .793 r
.76633 .45261 .76722 .45375 .7691 .45141 .76821 .45027 Mtetra
.978 .767 .552 r
.76821 .45027 .7691 .45141 .77056 .44354 .76968 .44239 Mtetra
.977 .675 .347 r
.76968 .44239 .77056 .44354 .75676 .23453 .75593 .23333 Mtetra
.95 .784 .641 r
.75593 .23333 .75676 .23453 .75833 .22988 .7575 .22868 Mtetra
.747 .772 .873 r
.7575 .22868 .75833 .22988 .76017 .22877 .75934 .22757 Mtetra
.622 .723 .919 r
.75934 .22757 .76017 .22877 .76206 .2283 .76122 .2271 Mtetra
.591 .709 .926 r
.76122 .2271 .76206 .2283 .76395 .22796 .76312 .22676 Mtetra
.749 .773 .872 r
.76312 .22676 .76395 .22796 .76579 .22684 .76496 .22563 Mtetra
.676 .746 .904 r
.76496 .22563 .76579 .22684 .76767 .22613 .76684 .22492 Mtetra
.378 .595 .931 r
.76684 .22492 .76767 .22613 .76962 .22646 .7688 .22526 Mtetra
.806 .393 0 r
.7688 .22526 .76962 .22646 .772 .23193 .77117 .23072 Mtetra
.973 .663 .318 r
.77117 .23072 .772 .23193 .79092 .44021 .79005 .43905 Mtetra
.712 .271 0 r
.79005 .43905 .79092 .44021 .79334 .44441 .79247 .44325 Mtetra
.504 .694 .954 r
.79247 .44325 .79334 .44441 .79541 .44432 .79454 .44316 Mtetra
.694 .779 .917 r
.79454 .44316 .79541 .44432 .79742 .44347 .79655 .44231 Mtetra
.734 .793 .899 r
.79655 .44231 .79742 .44347 .79941 .4424 .79854 .44123 Mtetra
.498 .69 .953 r
.79854 .44123 .79941 .4424 .80149 .44233 .80062 .44116 Mtetra
.625 .751 .937 r
.80062 .44116 .80149 .44233 .80353 .4418 .80266 .44063 Mtetra
.81 .813 .853 r
.80266 .44063 .80353 .4418 .80548 .44017 .80461 .439 Mtetra
.979 .772 .554 r
.80461 .439 .80548 .44017 .80692 .43268 .80605 .43148 Mtetra
.976 .671 .329 r
.80605 .43148 .80692 .43268 .79071 .22312 .78989 .22188 Mtetra
.958 .783 .623 r
.78989 .22188 .79071 .22312 .79223 .21809 .79141 .21687 Mtetra
.751 .773 .871 r
.79141 .21687 .79223 .21809 .79408 .21694 .79326 .21572 Mtetra
.623 .722 .918 r
.79326 .21572 .79408 .21694 .79599 .21647 .79517 .21525 Mtetra
.553 .689 .93 r
.79517 .21525 .79599 .21647 .79793 .21626 .79711 .21504 Mtetra
.746 .772 .874 r
.79711 .21504 .79793 .21626 .79979 .21515 .79897 .21393 Mtetra
.677 .746 .903 r
.79897 .21393 .79979 .21515 .80168 .21442 .80087 .2132 Mtetra
.456 .638 .934 r
.80087 .2132 .80168 .21442 .80365 .21454 .80284 .21332 Mtetra
.768 .353 0 r
.80284 .21332 .80365 .21454 .8061 .21975 .80528 .21852 Mtetra
.971 .657 .298 r
.80528 .21852 .8061 .21975 .82753 .42882 .82667 .42766 Mtetra
.725 .291 0 r
.82667 .42766 .82753 .42882 .83007 .43346 .82921 .43229 Mtetra
.307 .58 .938 r
.82921 .43229 .83007 .43346 .83223 .43394 .83137 .43277 Mtetra
.649 .764 .933 r
.83137 .43277 .83223 .43394 .83428 .43329 .83343 .43213 Mtetra
.83 .821 .84 r
.83343 .43213 .83428 .43329 .83622 .43148 .83537 .43032 Mtetra
.975 .789 .589 r
.83537 .43032 .83622 .43148 .83775 .42537 .8369 .42421 Mtetra
.974 .667 .312 r
.8369 .42421 .83775 .42537 .81946 .21491 .81865 .2137 Mtetra
.975 .775 .572 r
.81865 .2137 .81946 .21491 .82082 .20861 .82002 .2074 Mtetra
.761 .759 .851 r
.20456 .41956 .20561 .42054 .2072 .41946 .20614 .41848 Mtetra
.614 .729 .928 r
.20614 .41848 .2072 .41946 .20871 .41911 .20766 .41813 Mtetra
.457 .672 .956 r
.20766 .41813 .20871 .41911 .21019 .41914 .20914 .41817 Mtetra
.656 .743 .913 r
.20914 .41817 .21019 .41914 .21172 .41863 .21067 .41766 Mtetra
.665 .745 .91 r
.21067 .41766 .21172 .41863 .21326 .41809 .2122 .41712 Mtetra
.671 .748 .908 r
.2122 .41712 .21326 .41809 .21479 .41752 .21374 .41656 Mtetra
.764 .763 .851 r
.21374 .41656 .21479 .41752 .21638 .41642 .21533 .41546 Mtetra
.71 .756 .889 r
.21533 .41546 .21638 .41642 .21794 .41568 .21689 .41472 Mtetra
.492 .69 .955 r
.21689 .41472 .21794 .41568 .21943 .41563 .21838 .41467 Mtetra
.931 .56 .279 r
.21838 .41467 .21943 .41563 .22052 .41996 .21946 .41904 Mtetra
.939 .683 .523 r
.21946 .41904 .22052 .41996 .2034 .6191 .20227 .61823 Mtetra
.93 .57 .315 r
.20227 .61823 .2034 .6191 .20452 .6242 .20339 .62329 Mtetra
0 .376 .813 r
.20339 .62329 .20452 .6242 .20604 .62495 .20491 .62403 Mtetra
.624 .76 .943 r
.20491 .62403 .20604 .62495 .20767 .62452 .20654 .6236 Mtetra
.802 .782 .834 r
.20654 .6236 .20767 .62452 .20939 .62304 .20827 .62212 Mtetra
.906 .744 .669 r
.20827 .62212 .20939 .62304 .21145 .61796 .21032 .61706 Mtetra
.939 .687 .53 r
.21032 .61706 .21145 .61796 .23117 .41792 .23012 .41699 Mtetra
.916 .728 .633 r
.23012 .41699 .23117 .41792 .23328 .41118 .23223 .41021 Mtetra
.793 .763 .826 r
.23223 .41021 .23328 .41118 .2349 .40982 .23386 .40884 Mtetra
.628 .734 .923 r
.23386 .40884 .2349 .40982 .23644 .40942 .23539 .40843 Mtetra
.467 .673 .954 r
.23539 .40843 .23644 .40942 .23793 .40945 .23689 .40845 Mtetra
.623 .729 .922 r
.23689 .40845 .23793 .40945 .23947 .40908 .23843 .40807 Mtetra
.65 .734 .911 r
.23843 .40807 .23947 .40908 .24101 .40861 .23997 .40758 Mtetra
.663 .733 .902 r
.23997 .40758 .24101 .40861 .24256 .40812 .24153 .40704 Mtetra
.719 .738 .867 r
.24153 .40704 .24256 .40812 .24412 .40754 .2431 .40621 Mtetra
.701 .693 .839 r
.2431 .40621 .24412 .40754 .24568 .40693 .24468 .40543 Mtetra
.659 .655 .834 r
.24468 .40543 .24568 .40693 .24724 .4063 .24624 .40485 Mtetra
.411 .551 .885 r
.24624 .40485 .24724 .4063 .2488 .4057 .24772 .40515 Mtetra
.42 0 0 r
.24772 .40515 .2488 .4057 .25036 .4051 .24916 .40602 Mtetra
.688 .258 .221 r
.24916 .40602 .25036 .4051 .25192 .40451 .25056 .40729 Mtetra
.555 .207 .333 r
.25056 .40729 .25192 .40451 .25348 .40392 .25204 .40777 Mtetra
.448 .131 .334 r
.25204 .40777 .25348 .40392 .25505 .40334 .25359 .40729 Mtetra
.323 .017 .282 r
.25359 .40729 .25505 .40334 .25661 .40276 .25522 .40595 Mtetra
0 0 .068 r
.25522 .40595 .25661 .40276 .25817 .40219 .25693 .40364 Mtetra
.612 .857 .498 r
.25693 .40364 .25817 .40219 .25973 .40164 .25863 .40152 Mtetra
.872 .922 .857 r
.25863 .40152 .25973 .40164 .2613 .40109 .26028 .39985 Mtetra
.719 .712 .843 r
.26028 .39985 .2613 .40109 .26286 .40056 .26187 .39896 Mtetra
.649 .639 .826 r
.26187 .39896 .26286 .40056 .26442 .40004 .26344 .39843 Mtetra
.621 .625 .834 r
.26344 .39843 .26442 .40004 .26599 .39951 .26499 .39805 Mtetra
.626 .648 .852 r
.26499 .39805 .26599 .39951 .26755 .39895 .26655 .39765 Mtetra
.629 .674 .874 r
.26655 .39765 .26755 .39895 .26912 .39837 .2681 .39724 Mtetra
.633 .706 .899 r
.2681 .39724 .26912 .39837 .2707 .39778 .26966 .39681 Mtetra
.653 .747 .919 r
.26966 .39681 .2707 .39778 .27227 .39715 .27123 .39631 Mtetra
.669 .779 .932 r
.27123 .39631 .27227 .39715 .27385 .39653 .2728 .39574 Mtetra
.68 .794 .935 r
.2728 .39574 .27385 .39653 .27542 .39597 .27438 .39513 Mtetra
.753 .793 .885 r
.27438 .39513 .27542 .39597 .27701 .39524 .27598 .39416 Mtetra
.725 .742 .865 r
.27598 .39416 .27701 .39524 .27858 .39472 .27758 .39328 Mtetra
.63 .654 .855 r
.27758 .39328 .27858 .39472 .2801 .3948 .27914 .39286 Mtetra
.009 .227 .736 r
.27914 .39286 .2801 .3948 .28139 .39801 .28057 .39425 Mtetra
.717 .461 0 r
.28057 .39425 .28139 .39801 .26797 .59708 .2817 .39963 Mtetra
0 0 .196 r
.2817 .39963 .26797 .59708 .26913 .60349 .26841 .59738 Mtetra
.161 .121 .561 r
.26841 .59738 .26913 .60349 .27069 .60447 .26979 .60087 Mtetra
.391 .354 .697 r
.26979 .60087 .27069 .60447 .27236 .60406 .27135 .60193 Mtetra
.472 .506 .812 r
.27135 .60193 .27236 .60406 .27407 .60314 .27297 .60223 Mtetra
.408 .683 .974 r
.27297 .60223 .27407 .60314 .27575 .60261 .2746 .6023 Mtetra
.443 .835 .983 r
.2746 .6023 .27575 .60261 .27744 .60206 .27627 .602 Mtetra
.683 .955 .951 r
.27627 .602 .27744 .60206 .27917 .60084 .27798 .60109 Mtetra
.936 .931 .773 r
.27798 .60109 .27917 .60084 .28113 .5964 .27982 .59841 Mtetra
.992 .88 .563 r
.27982 .59841 .28113 .5964 .29698 .39586 .28195 .59166 Mtetra
0 0 .186 r
.28195 .59166 .29698 .39586 .29904 .3886 .29767 .39242 Mtetra
0 0 0 r
.29767 .39242 .29904 .3886 .30073 .38658 .29954 .38797 Mtetra
.555 .824 .467 r
.29954 .38797 .30073 .38658 .30232 .38588 .30123 .38596 Mtetra
.806 .98 .897 r
.30123 .38596 .30232 .38588 .30389 .38564 .30287 .38464 Mtetra
.772 .766 .848 r
.30287 .38464 .30389 .38564 .30548 .38508 .3045 .38346 Mtetra
.695 .656 .808 r
.3045 .38346 .30548 .38508 .30707 .3845 .30611 .38261 Mtetra
.583 .577 .812 r
.30611 .38261 .30707 .3845 .30863 .38445 .30768 .38241 Mtetra
0 0 .573 r
.30768 .38241 .30863 .38445 .31002 .38681 .30909 .38449 Mtetra
.951 .686 .5 r
.30909 .38449 .31002 .38681 .2985 .58367 .29772 .57807 Mtetra
.968 .693 .273 r
.29772 .57807 .2985 .58367 .29951 .59336 .2984 .59267 Mtetra
.641 .095 0 r
.2984 .59267 .29951 .59336 .30108 .59482 .29996 .5942 Mtetra
.598 .828 .987 r
.29996 .5942 .30108 .59482 .30276 .59451 .30165 .59375 Mtetra
.75 .824 .91 r
.30165 .59375 .30276 .59451 .30448 .59366 .30338 .59276 Mtetra
.587 .758 .96 r
.30338 .59276 .30448 .59366 .30618 .59313 .30507 .59242 Mtetra
.41 .733 .991 r
.30507 .59242 .30618 .59313 .30787 .59271 .30674 .59239 Mtetra
.624 .902 .985 r
.30674 .59239 .30787 .59271 .3096 .59169 .30845 .59175 Mtetra
.947 .886 .74 r
.30845 .59175 .3096 .59169 .3115 .58807 .31032 .58854 Mtetra
.951 .691 .507 r
.31032 .58854 .3115 .58807 .32547 .38991 .32411 .39449 Mtetra
.999 .807 .47 r
.32411 .39449 .32547 .38991 .32769 .37948 .32669 .37815 Mtetra
.841 .727 .738 r
.32669 .37815 .32769 .37948 .3294 .37712 .32842 .37567 Mtetra
.656 .666 .848 r
.32842 .37567 .3294 .37712 .33101 .37648 .33002 .37512 Mtetra
.522 .624 .893 r
.33002 .37512 .33101 .37648 .33259 .37633 .33159 .3751 Mtetra
.556 .663 .908 r
.33159 .3751 .33259 .37633 .33418 .37608 .33318 .37495 Mtetra
.643 .714 .9 r
.33318 .37495 .33418 .37608 .33578 .37559 .33478 .37447 Mtetra
.655 .722 .898 r
.33478 .37447 .33578 .37559 .33739 .37508 .33639 .37394 Mtetra
.676 .724 .886 r
.33639 .37394 .33739 .37508 .339 .37455 .338 .37332 Mtetra
.688 .713 .868 r
.338 .37332 .339 .37455 .34061 .37397 .33962 .37262 Mtetra
.685 .691 .85 r
.33962 .37262 .34061 .37397 .34222 .37339 .34124 .37191 Mtetra
.672 .669 .838 r
.34124 .37191 .34222 .37339 .34383 .3728 .34286 .37125 Mtetra
.661 .655 .834 r
.34286 .37125 .34383 .3728 .34545 .37221 .34447 .37065 Mtetra
.658 .652 .833 r
.34447 .37065 .34545 .37221 .34707 .37161 .34609 .37006 Mtetra
.658 .654 .834 r
.34609 .37006 .34707 .37161 .34868 .37101 .34771 .36946 Mtetra
.66 .655 .834 r
.34771 .36946 .34868 .37101 .3503 .37042 .34933 .36886 Mtetra
.659 .654 .834 r
.34933 .36886 .3503 .37042 .35192 .36982 .35095 .36826 Mtetra
.671 .659 .829 r
.35095 .36826 .35192 .36982 .35354 .36921 .35257 .36759 Mtetra
.673 .651 .82 r
.35257 .36759 .35354 .36921 .35516 .3686 .3542 .36689 Mtetra
.645 .629 .82 r
.3542 .36689 .35516 .3686 .35679 .36799 .35582 .36635 Mtetra
.541 .591 .853 r
.35582 .36635 .35679 .36799 .35841 .36738 .35741 .36631 Mtetra
.132 .476 .896 r
.35741 .36631 .35841 .36738 .36003 .36678 .35897 .36694 Mtetra
.623 .081 0 r
.35897 .36694 .36003 .36678 .36166 .36618 .36051 .36794 Mtetra
.569 .169 .243 r
.36051 .36794 .36166 .36618 .36328 .36556 .36208 .36855 Mtetra
.418 .076 .276 r
.36208 .36855 .36328 .36556 .36491 .36493 .36371 .36805 Mtetra
.36 .027 .258 r
.36371 .36805 .36491 .36493 .36654 .3643 .36535 .36716 Mtetra
.279 0 .203 r
.36535 .36716 .36654 .3643 .36818 .36348 .36701 .36599 Mtetra
.249 0 .156 r
.36701 .36599 .36818 .36348 .36982 .36258 .36867 .36487 Mtetra
.4 .026 .21 r
.36867 .36487 .36982 .36258 .37145 .36214 .37029 .36447 Mtetra
.724 .37 .377 r
.37029 .36447 .37145 .36214 .373 .36323 .37177 .36695 Mtetra
.949 .678 .49 r
.37177 .36695 .373 .36323 .37427 .37027 .36392 .56606 Mtetra
.548 .321 .523 r
.36392 .56606 .37427 .37027 .36654 .57047 .36535 .57199 Mtetra
.672 .265 .265 r
.36535 .57199 .36654 .57047 .36811 .57347 .367 .57345 Mtetra
.37 .835 .891 r
.367 .57345 .36811 .57347 .36982 .57356 .36874 .57301 Mtetra
.729 .876 .949 r
.36874 .57301 .36982 .57356 .37156 .57302 .3705 .5721 Mtetra
.704 .791 .919 r
.3705 .5721 .37156 .57302 .37331 .57234 .37225 .57131 Mtetra
.582 .733 .947 r
.37225 .57131 .37331 .57234 .37506 .57181 .37399 .571 Mtetra
.613 .792 .968 r
.37399 .571 .37506 .57181 .3768 .57123 .37573 .57055 Mtetra
.743 .849 .929 r
.37573 .57055 .3768 .57123 .37855 .57065 .37749 .56958 Mtetra
.825 .777 .807 r
.37749 .56958 .37855 .57065 .3803 .5701 .3793 .56774 Mtetra
.775 .644 .717 r
.3793 .56774 .3803 .5701 .38205 .56954 .38112 .56545 Mtetra
.682 .529 .672 r
.38112 .56545 .38205 .56954 .38379 .56919 .38292 .5637 Mtetra
.553 .415 .647 r
.38292 .5637 .38379 .56919 .38552 .56905 .38465 .56364 Mtetra
.584 .438 .649 r
.38465 .56364 .38552 .56905 .38728 .56843 .3864 .56314 Mtetra
.724 .535 .635 r
.3864 .56314 .38728 .56843 .3891 .56624 .38826 .5597 Mtetra
.951 .683 .494 r
.38826 .5597 .3891 .56624 .39117 .55764 .398 .35903 Mtetra
.551 .328 .53 r
.398 .35903 .39117 .55764 .40077 .35607 .39988 .35263 Mtetra
.739 .575 .671 r
.39988 .35263 .40077 .35607 .40255 .3521 .4016 .35014 Mtetra
.659 .612 .79 r
.4016 .35014 .40255 .3521 .40422 .35093 .40326 .34946 Mtetra
.593 .64 .867 r
.40326 .34946 .40422 .35093 .40587 .35033 .40489 .34919 Mtetra
.595 .699 .916 r
.40489 .34919 .40587 .35033 .40752 .34991 .40653 .34888 Mtetra
.707 .761 .894 r
.40653 .34888 .40752 .34991 .40917 .34931 .40819 .34811 Mtetra
.68 .719 .879 r
.40819 .34811 .40917 .34931 .41082 .34877 .40985 .34745 Mtetra
.592 .665 .889 r
.40985 .34745 .41082 .34877 .41247 .34824 .41149 .34717 Mtetra
.228 .534 .922 r
.41149 .34717 .41247 .34824 .41413 .34768 .41311 .34767 Mtetra
.551 0 0 r
.41311 .34767 .41413 .34768 .41578 .34712 .41472 .34856 Mtetra
.568 .141 .192 r
.41472 .34856 .41578 .34712 .41744 .34643 .41634 .34919 Mtetra
.325 0 .218 r
.41634 .34919 .41744 .34643 .41911 .3455 .41801 .34825 Mtetra
.388 .038 .245 r
.41801 .34825 .41911 .3455 .42077 .34497 .41967 .34763 Mtetra
.64 .283 .35 r
.41967 .34763 .42077 .34497 .42239 .34559 .42127 .34902 Mtetra
.954 .679 .475 r
.42127 .34902 .42239 .34559 .42386 .35097 .41651 .54814 Mtetra
.55 .322 .523 r
.41651 .54814 .42386 .35097 .41918 .55321 .41804 .55537 Mtetra
.698 .323 .333 r
.41804 .55537 .41918 .55321 .42081 .55722 .41973 .55742 Mtetra
.048 0 0 r
.41973 .55742 .42081 .55722 .42256 .55747 .42149 .55733 Mtetra
.587 .925 .961 r
.42149 .55733 .42256 .55747 .42433 .55703 .42327 .55661 Mtetra
.789 .913 .924 r
.42327 .55661 .42433 .55703 .42611 .55632 .42507 .55537 Mtetra
.83 .803 .825 r
.42507 .55537 .42611 .55632 .42789 .55581 .42689 .55361 Mtetra
.778 .656 .728 r
.42689 .55361 .42789 .55581 .42967 .55523 .42871 .55141 Mtetra
.714 .556 .674 r
.42871 .55141 .42967 .55523 .43145 .55463 .43054 .5492 Mtetra
.606 .453 .648 r
.43054 .5492 .43145 .55463 .43324 .55408 .43233 .54834 Mtetra
.574 .426 .643 r
.43233 .54834 .43324 .55408 .43502 .55352 .4341 .54796 Mtetra
.555 .416 .647 r
.4341 .54796 .43502 .55352 .4368 .55305 .43587 .54788 Mtetra
.537 .41 .655 r
.43587 .54788 .4368 .55305 .43858 .55291 .43764 .54803 Mtetra
.591 .453 .662 r
.43764 .54803 .43858 .55291 .44036 .55235 .43943 .5475 Mtetra
.695 .523 .65 r
.43943 .5475 .44036 .55235 .44218 .55068 .44126 .5451 Mtetra
.957 .685 .479 r
.44126 .5451 .44218 .55068 .44411 .544 .44788 .34542 Mtetra
.556 .332 .53 r
.44788 .34542 .44411 .544 .45067 .34009 .44978 .3361 Mtetra
.749 .568 .65 r
.44978 .3361 .45067 .34009 .45246 .33505 .45152 .33294 Mtetra
.684 .612 .77 r
.45152 .33294 .45246 .33505 .45415 .33393 .4532 .332 Mtetra
.627 .6 .803 r
.4532 .332 .45415 .33393 .45583 .33349 .45488 .33152 Mtetra
.596 .581 .807 r
.45488 .33152 .45583 .33349 .4575 .33332 .45656 .33123 Mtetra
.639 .591 .784 r
.45656 .33123 .4575 .33332 .45918 .33274 .45824 .33064 Mtetra
.638 .59 .784 r
.45824 .33064 .45918 .33274 .46087 .33217 .45993 .33007 Mtetra
.638 .589 .784 r
.45993 .33007 .46087 .33217 .46255 .33161 .46161 .32949 Mtetra
.638 .589 .783 r
.46161 .32949 .46255 .33161 .46424 .33103 .4633 .32891 Mtetra
.638 .589 .782 r
.4633 .32891 .46424 .33103 .46592 .33044 .46498 .32832 Mtetra
.638 .589 .783 r
.46498 .32832 .46592 .33044 .46761 .32986 .46667 .32774 Mtetra
.46667 .32774 .46761 .32986 .4693 .32927 .46836 .32716 Mtetra
.638 .59 .783 r
.46836 .32716 .4693 .32927 .47099 .32869 .47005 .32658 Mtetra
.639 .591 .784 r
.47005 .32658 .47099 .32869 .47268 .32809 .47174 .32599 Mtetra
.641 .592 .784 r
.47174 .32599 .47268 .32809 .47438 .32749 .47344 .32539 Mtetra
.641 .593 .785 r
.47344 .32539 .47438 .32749 .47607 .32688 .47513 .32479 Mtetra
.644 .595 .784 r
.47513 .32479 .47607 .32688 .47776 .32625 .47683 .32417 Mtetra
.681 .614 .774 r
.47683 .32417 .47776 .32625 .47947 .32521 .47853 .32326 Mtetra
.65 .611 .797 r
.47853 .32326 .47947 .32521 .48116 .32457 .48022 .32262 Mtetra
.552 .562 .818 r
.48022 .32262 .48116 .32457 .48285 .32475 .48191 .32256 Mtetra
0 0 .566 r
.48191 .32256 .48285 .32475 .48447 .33017 .48357 .32513 Mtetra
.951 .663 .218 r
.48357 .32513 .48447 .33017 .48367 .53348 .48506 .34181 Mtetra
0 0 .322 r
.48506 .34181 .48367 .53348 .48543 .53785 .48446 .53253 Mtetra
.536 .408 .653 r
.48446 .53253 .48543 .53785 .48724 .53792 .48627 .5327 Mtetra
.605 .456 .654 r
.48627 .5327 .48724 .53792 .48906 .53725 .48809 .53189 Mtetra
.611 .458 .65 r
.48809 .53189 .48906 .53725 .49088 .53622 .48991 .53095 Mtetra
.433 .339 .649 r
.48991 .53095 .49088 .53622 .4927 .53573 .49171 .53226 Mtetra
.409 .38 .715 r
.49171 .53226 .4927 .53573 .49453 .5352 .49352 .53327 Mtetra
.388 .49 .842 r
.49352 .53327 .49453 .5352 .49635 .53461 .49534 .53385 Mtetra
.549 .791 .988 r
.49534 .53385 .49635 .53461 .49818 .53379 .49716 .53352 Mtetra
.532 .891 .977 r
.49716 .53352 .49818 .53379 .5 .53291 .49899 .53296 Mtetra
.457 .886 .881 r
.49899 .53296 .5 .53291 .50183 .53205 .50082 .53228 Mtetra
0 0 0 r
.50082 .53228 .50183 .53205 .50366 .53197 .50264 .53208 Mtetra
.274 .779 .797 r
.50264 .53208 .50366 .53197 .50549 .53156 .50447 .53161 Mtetra
.635 .962 .901 r
.50447 .53161 .50549 .53156 .50732 .53038 .50631 .53058 Mtetra
.968 .92 .699 r
.50631 .53058 .50732 .53038 .50918 .52406 .50816 .52703 Mtetra
.963 .827 .401 r
.50816 .52703 .50918 .52406 .51186 .31918 .51003 .51706 Mtetra
0 0 .318 r
.51003 .51706 .51186 .31918 .51359 .31361 .51264 .31652 Mtetra
0 0 .001 r
.51264 .31652 .51359 .31361 .51531 .3123 .51437 .31323 Mtetra
.551 .845 .522 r
.51437 .31323 .51531 .3123 .51703 .31178 .51609 .31141 Mtetra
.788 .93 .927 r
.51609 .31141 .51703 .31178 .51875 .31163 .51781 .31022 Mtetra
.669 .689 .86 r
.51781 .31022 .51875 .31163 .52047 .31113 .51954 .30957 Mtetra
.618 .645 .854 r
.51954 .30957 .52047 .31113 .52219 .31059 .52126 .30917 Mtetra
.593 .655 .88 r
.52126 .30917 .52219 .31059 .52392 .31003 .52298 .30888 Mtetra
.647 .725 .906 r
.52298 .30888 .52392 .31003 .52564 .30935 .52471 .30835 Mtetra
.666 .763 .922 r
.52471 .30835 .52564 .30935 .52737 .30867 .52643 .30774 Mtetra
.679 .783 .929 r
.52643 .30774 .52737 .30867 .52909 .30804 .52816 .30707 Mtetra
.76 .795 .881 r
.52816 .30707 .52909 .30804 .53082 .30723 .52989 .30598 Mtetra
.714 .732 .865 r
.52989 .30598 .53082 .30723 .53255 .30673 .53162 .3051 Mtetra
.612 .633 .848 r
.53162 .3051 .53255 .30673 .53428 .30691 .53335 .30472 Mtetra
.022 .208 .716 r
.53335 .30472 .53428 .30691 .53603 .31132 .53509 .30656 Mtetra
0 0 .254 r
.53509 .30656 .53603 .31132 .53861 .51549 .53685 .31411 Mtetra
0 0 .346 r
.53685 .31411 .53861 .51549 .54048 .52057 .53947 .51484 Mtetra
.325 .257 .625 r
.53947 .51484 .54048 .52057 .54234 .5211 .54134 .51736 Mtetra
.458 .401 .706 r
.54134 .51736 .54234 .5211 .5442 .52057 .5432 .51813 Mtetra
.524 .515 .788 r
.5432 .51813 .5442 .52057 .54605 .51958 .54506 .51825 Mtetra
.418 .603 .923 r
.54506 .51825 .54605 .51958 .54791 .51913 .54693 .51849 Mtetra
.482 .795 .999 r
.54693 .51849 .54791 .51913 .54977 .51846 .54879 .51825 Mtetra
.711 .959 .947 r
.54879 .51825 .54977 .51846 .55163 .51709 .55065 .51719 Mtetra
.984 .873 .642 r
.55065 .51719 .55163 .51709 .55345 .51185 .55248 .51248 Mtetra
.972 .691 .435 r
.55248 .51248 .55345 .51185 .55344 .30638 .55252 .30619 Mtetra
.983 .785 .561 r
.55252 .30619 .55344 .30638 .55512 .29968 .5542 .29823 Mtetra
.798 .728 .787 r
.5542 .29823 .55512 .29968 .55686 .29797 .55593 .29651 Mtetra
.638 .672 .866 r
.55593 .29651 .55686 .29797 .5586 .29734 .55768 .29601 Mtetra
.522 .64 .907 r
.55768 .29601 .5586 .29734 .56035 .29712 .55943 .29597 Mtetra
.69 .743 .892 r
.55943 .29597 .56035 .29712 .5621 .2962 .56118 .29523 Mtetra
.699 .784 .917 r
.56118 .29523 .5621 .2962 .56384 .29536 .56293 .29447 Mtetra
.572 .758 .966 r
.56293 .29447 .56384 .29536 .56559 .29514 .56468 .29415 Mtetra
0 .072 .584 r
.56468 .29415 .56559 .29514 .56739 .29814 .56646 .2958 Mtetra
.858 .509 0 r
.56646 .2958 .56739 .29814 .57205 .50247 .56832 .30264 Mtetra
0 0 .356 r
.56832 .30264 .57205 .50247 .57404 .50981 .57299 .50389 Mtetra
.301 .238 .618 r
.57299 .50389 .57404 .50981 .57594 .51073 .57492 .50677 Mtetra
.457 .393 .697 r
.57492 .50677 .57594 .51073 .57782 .51022 .57682 .50761 Mtetra
.518 .5 .776 r
.57682 .50761 .57782 .51022 .57969 .50919 .57871 .50779 Mtetra
.433 .599 .914 r
.57871 .50779 .57969 .50919 .58158 .50867 .58061 .50802 Mtetra
.44 .774 .997 r
.58061 .50802 .58158 .50867 .58346 .50809 .5825 .50786 Mtetra
.659 .947 .957 r
.5825 .50786 .58346 .50809 .58533 .50685 .58438 .50694 Mtetra
.976 .907 .677 r
.58438 .50694 .58533 .50685 .58714 .50238 .5862 .50307 Mtetra
.974 .69 .423 r
.5862 .50307 .58714 .50238 .58508 .29737 .58426 .30085 Mtetra
.953 .787 .336 r
.58426 .30085 .58508 .29737 .5867 .28919 .58579 .2882 Mtetra
.873 .806 .781 r
.58579 .2882 .5867 .28919 .58843 .28714 .58752 .28595 Mtetra
.682 .737 .892 r
.58752 .28595 .58843 .28714 .5902 .28644 .58929 .28524 Mtetra
.566 .69 .924 r
.58929 .28524 .5902 .28644 .59197 .28616 .59106 .28502 Mtetra
.707 .754 .889 r
.59106 .28502 .59197 .28616 .59373 .28528 .59283 .28419 Mtetra
.722 .767 .888 r
.59283 .28419 .59373 .28528 .59549 .28435 .59459 .28328 Mtetra
.585 .724 .939 r
.59459 .28328 .59549 .28435 .59727 .284 .59636 .28296 Mtetra
.619 .144 0 r
.59636 .28296 .59727 .284 .59911 .28637 .59821 .28539 Mtetra
.973 .68 .404 r
.59821 .28539 .59911 .28637 .60585 .48912 .6049 .48851 Mtetra
.941 .575 .25 r
.6049 .48851 .60585 .48912 .608 .49881 .60704 .49777 Mtetra
0 .187 .687 r
.60704 .49777 .608 .49881 .60996 .50043 .60899 .49927 Mtetra
.573 .717 .94 r
.60899 .49927 .60996 .50043 .61187 .50021 .6109 .49898 Mtetra
.758 .769 .862 r
.6109 .49898 .61187 .50021 .61375 .4989 .61279 .49775 Mtetra
.889 .793 .748 r
.61279 .49775 .61375 .4989 .61556 .4949 .61463 .49488 Mtetra
.992 .823 .573 r
.61463 .49488 .61556 .4949 .6118 .29116 .61637 .48812 Mtetra
0 0 .356 r
.61637 .48812 .6118 .29116 .61329 .2801 .61253 .2841 Mtetra
0 0 .117 r
.61253 .2841 .61329 .2801 .61502 .27774 .6142 .27942 Mtetra
0 0 0 r
.6142 .27942 .61502 .27774 .6168 .27705 .61594 .27742 Mtetra
.577 .924 .73 r
.61594 .27742 .6168 .27705 .61859 .27685 .61771 .27612 Mtetra
.725 .852 .942 r
.61771 .27612 .61859 .27685 .62038 .27649 .61948 .27523 Mtetra
.667 .721 .889 r
.61948 .27523 .62038 .27649 .62217 .27589 .62127 .27459 Mtetra
.64 .701 .89 r
.62127 .27459 .62217 .27589 .62396 .27527 .62306 .27407 Mtetra
.718 .748 .876 r
.62306 .27407 .62396 .27527 .62573 .27428 .62484 .27315 Mtetra
.733 .768 .881 r
.62484 .27315 .62573 .27428 .62751 .27327 .62662 .27217 Mtetra
.617 .733 .929 r
.62662 .27217 .62751 .27327 .6293 .27281 .62841 .27174 Mtetra
0 .046 .574 r
.62841 .27174 .6293 .27281 .63118 .27465 .63029 .27362 Mtetra
.974 .678 .39 r
.63029 .27362 .63118 .27465 .6399 .47272 .639 .47262 Mtetra
.95 .604 .309 r
.639 .47262 .6399 .47272 .64237 .48764 .64142 .48657 Mtetra
0 .065 .583 r
.64142 .48657 .64237 .48764 .64438 .48966 .64344 .48848 Mtetra
.544 .702 .943 r
.64344 .48848 .64438 .48966 .64633 .48954 .64538 .48829 Mtetra
.745 .765 .869 r
.64538 .48829 .64633 .48954 .64823 .48833 .64728 .48713 Mtetra
.881 .794 .759 r
.64728 .48713 .64823 .48833 .65004 .48469 .64913 .48445 Mtetra
.989 .823 .585 r
.64913 .48445 .65004 .48469 .64428 .2841 .65084 .47814 Mtetra
0 0 .363 r
.65084 .47814 .64428 .2841 .64554 .26921 .64486 .27348 Mtetra
0 0 .133 r
.64486 .27348 .64554 .26921 .64726 .2665 .64649 .26826 Mtetra
0 0 0 r
.64649 .26826 .64726 .2665 .64905 .26574 .64823 .26619 Mtetra
.534 .891 .672 r
.64823 .26619 .64905 .26574 .65087 .26549 .65001 .26484 Mtetra
.73 .877 .949 r
.65001 .26484 .65087 .26549 .65269 .26517 .6518 .26391 Mtetra
.673 .726 .889 r
.6518 .26391 .65269 .26517 .65449 .26455 .65361 .26323 Mtetra
.646 .703 .888 r
.65361 .26323 .65449 .26455 .6563 .26391 .65542 .26268 Mtetra
.707 .743 .88 r
.65542 .26268 .6563 .26391 .6581 .26296 .65722 .26182 Mtetra
.74 .77 .877 r
.65722 .26182 .6581 .26296 .65989 .2619 .65901 .26078 Mtetra
.644 .743 .921 r
.65901 .26078 .65989 .2619 .6617 .26133 .66082 .26024 Mtetra
0 .283 .777 r
.66082 .26024 .6617 .26133 .66359 .26258 .66272 .26153 Mtetra
.937 .569 .186 r
.66272 .26153 .66359 .26258 .66584 .27153 .66499 .27097 Mtetra
.975 .675 .376 r
.66499 .27097 .66584 .27153 .67711 .47549 .67618 .47445 Mtetra
0 0 .475 r
.67618 .47445 .67711 .47549 .67919 .47785 .67826 .47676 Mtetra
.625 .758 .942 r
.67826 .47676 .67919 .47785 .68114 .47735 .68022 .47625 Mtetra
.765 .8 .881 r
.68022 .47625 .68114 .47735 .68306 .47612 .68214 .475 Mtetra
.773 .8 .874 r
.68214 .475 .68306 .47612 .68498 .47484 .68405 .4737 Mtetra
.71 .778 .905 r
.68405 .4737 .68498 .47484 .68692 .47397 .68599 .47278 Mtetra
.696 .766 .906 r
.68599 .47278 .68692 .47397 .68886 .47316 .68793 .47195 Mtetra
.65 .743 .917 r
.68793 .47195 .68886 .47316 .69082 .47256 .68989 .47133 Mtetra
.588 .715 .931 r
.68989 .47133 .69082 .47256 .69278 .47219 .69186 .47098 Mtetra
.565 .709 .938 r
.69186 .47098 .69278 .47219 .69476 .47189 .69383 .47071 Mtetra
.474 .671 .95 r
.69383 .47071 .69476 .47189 .69675 .47188 .69582 .47073 Mtetra
.432 .654 .953 r
.69582 .47073 .69675 .47188 .69875 .47199 .69782 .47085 Mtetra
.632 .752 .934 r
.69782 .47085 .69875 .47199 .70071 .47144 .69979 .47031 Mtetra
.889 .81 .765 r
.69979 .47031 .70071 .47144 .70256 .46877 .70164 .46764 Mtetra
.98 .725 .471 r
.70164 .46764 .70256 .46877 .70365 .45212 .70273 .45079 Mtetra
.977 .681 .379 r
.70273 .45079 .70365 .45212 .69464 .25277 .69377 .25159 Mtetra
.912 .789 .712 r
.69377 .25159 .69464 .25277 .69632 .24951 .69546 .24834 Mtetra
.709 .757 .89 r
.69546 .24834 .69632 .24951 .69814 .24865 .69728 .24747 Mtetra
.587 .708 .927 r
.69728 .24747 .69814 .24865 .7 .24833 .69914 .24715 Mtetra
.622 .724 .92 r
.69914 .24715 .7 .24833 .70184 .24787 .70098 .24669 Mtetra
.731 .766 .88 r
.70098 .24669 .70184 .24787 .70366 .24687 .7028 .24569 Mtetra
.639 .732 .915 r
.7028 .24569 .70366 .24687 .7055 .24634 .70465 .24516 Mtetra
.06 .396 .854 r
.70465 .24516 .7055 .24634 .70744 .24738 .70659 .2462 Mtetra
.926 .555 .143 r
.70659 .2462 .70744 .24738 .70989 .25688 .70904 .25572 Mtetra
.975 .671 .352 r
.70904 .25572 .70989 .25688 .7242 .4614 .72329 .46028 Mtetra
.601 .138 0 r
.72329 .46028 .7242 .4614 .72639 .46435 .72549 .46322 Mtetra
.418 .654 .956 r
.72549 .46322 .72639 .46435 .72842 .4645 .72751 .46337 Mtetra
.71 .786 .911 r
.72751 .46337 .72842 .4645 .73038 .46357 .72948 .46245 Mtetra
.888 .816 .772 r
.72948 .46245 .73038 .46357 .73224 .46097 .73134 .45985 Mtetra
.977 .758 .54 r
.73134 .45985 .73224 .46097 .7337 .45206 .7328 .45096 Mtetra
.977 .679 .365 r
.7328 .45096 .7337 .45206 .72235 .24447 .72151 .2433 Mtetra
.938 .788 .669 r
.72151 .2433 .72235 .24447 .72399 .24041 .72314 .23923 Mtetra
.721 .764 .887 r
.72314 .23923 .72399 .24041 .72582 .23947 .72497 .23829 Mtetra
.581 .707 .929 r
.72497 .23829 .72582 .23947 .72769 .23917 .72685 .23799 Mtetra
.542 .689 .935 r
.72685 .23799 .72769 .23917 .72958 .239 .72873 .23782 Mtetra
.658 .741 .911 r
.72873 .23782 .72958 .239 .73144 .23839 .73059 .2372 Mtetra
.664 .743 .909 r
.73059 .2372 .73144 .23839 .73329 .23774 .73245 .23656 Mtetra
.702 .758 .895 r
.73245 .23656 .73329 .23774 .73514 .23691 .7343 .23572 Mtetra
.757 .776 .868 r
.7343 .23572 .73514 .23691 .73696 .23574 .73612 .23455 Mtetra
.674 .746 .905 r
.73612 .23455 .73696 .23574 .73882 .23504 .73798 .23385 Mtetra
.24 .515 .91 r
.73798 .23385 .73882 .23504 .74077 .23571 .73993 .23452 Mtetra
.896 .51 .065 r
.73993 .23452 .74077 .23571 .74325 .24368 .74241 .2425 Mtetra
.975 .667 .334 r
.74241 .2425 .74325 .24368 .75998 .4499 .75909 .44876 Mtetra
.635 .18 0 r
.75909 .44876 .75998 .4499 .76227 .45323 .76138 .45209 Mtetra
.392 .636 .953 r
.76138 .45209 .76227 .45323 .76434 .45346 .76345 .45232 Mtetra
.695 .781 .918 r
.76345 .45232 .76434 .45346 .76633 .45261 .76544 .45147 Mtetra
.873 .82 .793 r
.76544 .45147 .76633 .45261 .76821 .45027 .76733 .44913 Mtetra
.978 .767 .552 r
.76733 .44913 .76821 .45027 .76968 .44239 .7688 .44125 Mtetra
.977 .675 .347 r
.7688 .44125 .76968 .44239 .75593 .23333 .75509 .23213 Mtetra
.95 .784 .641 r
.75509 .23213 .75593 .23333 .7575 .22868 .75666 .22748 Mtetra
.748 .772 .873 r
.75666 .22748 .7575 .22868 .75934 .22757 .7585 .22637 Mtetra
.622 .724 .919 r
.7585 .22637 .75934 .22757 .76122 .2271 .76039 .2259 Mtetra
.591 .709 .926 r
.76039 .2259 .76122 .2271 .76312 .22676 .76229 .22555 Mtetra
.749 .773 .872 r
.76229 .22555 .76312 .22676 .76496 .22563 .76413 .22443 Mtetra
.676 .746 .904 r
.76413 .22443 .76496 .22563 .76684 .22492 .76601 .22372 Mtetra
.378 .596 .931 r
.76601 .22372 .76684 .22492 .7688 .22526 .76797 .22405 Mtetra
.806 .393 0 r
.76797 .22405 .7688 .22526 .77117 .23072 .77034 .2295 Mtetra
.973 .663 .318 r
.77034 .2295 .77117 .23072 .79005 .43905 .78917 .43789 Mtetra
.713 .272 0 r
.78917 .43789 .79005 .43905 .79247 .44325 .79159 .44209 Mtetra
.504 .694 .954 r
.79159 .44209 .79247 .44325 .79454 .44316 .79366 .442 Mtetra
.694 .78 .917 r
.79366 .442 .79454 .44316 .79655 .44231 .79568 .44115 Mtetra
.734 .793 .9 r
.79568 .44115 .79655 .44231 .79854 .44123 .79767 .44007 Mtetra
.497 .69 .954 r
.79767 .44007 .79854 .44123 .80062 .44116 .79975 .44 Mtetra
.625 .751 .938 r
.79975 .44 .80062 .44116 .80266 .44063 .80179 .43946 Mtetra
.81 .814 .853 r
.80179 .43946 .80266 .44063 .80461 .439 .80374 .43783 Mtetra
.98 .772 .553 r
.80374 .43783 .80461 .439 .80605 .43148 .80518 .43029 Mtetra
.976 .671 .329 r
.80518 .43029 .80605 .43148 .78989 .22188 .78907 .22066 Mtetra
.958 .783 .623 r
.78907 .22066 .78989 .22188 .79141 .21687 .79059 .21565 Mtetra
.751 .773 .871 r
.79059 .21565 .79141 .21687 .79326 .21572 .79244 .2145 Mtetra
.623 .723 .918 r
.79244 .2145 .79326 .21572 .79517 .21525 .79436 .21403 Mtetra
.553 .689 .93 r
.79436 .21403 .79517 .21525 .79711 .21504 .7963 .21382 Mtetra
.746 .772 .874 r
.7963 .21382 .79711 .21504 .79897 .21393 .79816 .21271 Mtetra
.677 .747 .903 r
.79816 .21271 .79897 .21393 .80087 .2132 .80005 .21198 Mtetra
.456 .638 .934 r
.80005 .21198 .80087 .2132 .80284 .21332 .80203 .21209 Mtetra
.768 .353 0 r
.80203 .21209 .80284 .21332 .80528 .21852 .80447 .2173 Mtetra
.971 .657 .298 r
.80447 .2173 .80528 .21852 .82667 .42766 .82582 .42649 Mtetra
.726 .291 0 r
.82582 .42649 .82667 .42766 .82921 .43229 .82836 .43112 Mtetra
.306 .58 .938 r
.82836 .43112 .82921 .43229 .83137 .43277 .83052 .43161 Mtetra
.649 .764 .933 r
.83052 .43161 .83137 .43277 .83343 .43213 .83257 .43096 Mtetra
.83 .821 .841 r
.83257 .43096 .83343 .43213 .83537 .43032 .83452 .42915 Mtetra
.975 .789 .589 r
.83452 .42915 .83537 .43032 .8369 .42421 .83605 .42305 Mtetra
.974 .667 .312 r
.83605 .42305 .8369 .42421 .81865 .2137 .81785 .21249 Mtetra
.975 .775 .571 r
.81785 .21249 .81865 .2137 .82002 .2074 .81922 .20618 Mtetra
.761 .759 .851 r
.2035 .41859 .20456 .41956 .20614 .41848 .20509 .41751 Mtetra
.613 .729 .928 r
.20509 .41751 .20614 .41848 .20766 .41813 .2066 .41716 Mtetra
.456 .671 .956 r
.2066 .41716 .20766 .41813 .20914 .41817 .20808 .41719 Mtetra
.656 .742 .913 r
.20808 .41719 .20914 .41817 .21067 .41766 .20961 .41669 Mtetra
.665 .745 .91 r
.20961 .41669 .21067 .41766 .2122 .41712 .21115 .41615 Mtetra
.67 .746 .907 r
.21115 .41615 .2122 .41712 .21374 .41656 .21269 .41559 Mtetra
.764 .762 .851 r
.21269 .41559 .21374 .41656 .21533 .41546 .21428 .41449 Mtetra
.709 .755 .888 r
.21428 .41449 .21533 .41546 .21689 .41472 .21584 .41375 Mtetra
.492 .688 .954 r
.21584 .41375 .21689 .41472 .21838 .41467 .21733 .41371 Mtetra
.931 .561 .28 r
.21733 .41371 .21838 .41467 .21946 .41904 .2184 .4181 Mtetra
.939 .683 .523 r
.2184 .4181 .21946 .41904 .20227 .61823 .20114 .61734 Mtetra
.931 .569 .312 r
.20114 .61734 .20227 .61823 .20339 .62329 .20226 .62237 Mtetra
0 .379 .817 r
.20226 .62237 .20339 .62329 .20491 .62403 .20378 .62311 Mtetra
.625 .759 .943 r
.20378 .62311 .20491 .62403 .20654 .6236 .20541 .62268 Mtetra
.802 .782 .834 r
.20541 .62268 .20654 .6236 .20827 .62212 .20714 .6212 Mtetra
.906 .744 .669 r
.20714 .6212 .20827 .62212 .21032 .61706 .20919 .61615 Mtetra
.939 .687 .53 r
.20919 .61615 .21032 .61706 .23012 .41699 .22907 .41603 Mtetra
.915 .726 .632 r
.22907 .41603 .23012 .41699 .23223 .41021 .23119 .40922 Mtetra
.793 .762 .825 r
.23119 .40922 .23223 .41021 .23386 .40884 .23281 .40785 Mtetra
.631 .733 .921 r
.23281 .40785 .23386 .40884 .23539 .40843 .23435 .40743 Mtetra
.476 .674 .951 r
.23435 .40743 .23539 .40843 .23689 .40845 .23585 .40744 Mtetra
.63 .727 .918 r
.23585 .40744 .23689 .40845 .23843 .40807 .23739 .40703 Mtetra
.657 .731 .904 r
.23739 .40703 .23843 .40807 .23997 .40758 .23894 .40651 Mtetra
.669 .729 .894 r
.23894 .40651 .23997 .40758 .24153 .40704 .24049 .40595 Mtetra
.745 .74 .847 r
.24049 .40595 .24153 .40704 .2431 .40621 .24209 .40493 Mtetra
.715 .704 .839 r
.24209 .40493 .2431 .40621 .24468 .40543 .24367 .40406 Mtetra
.634 .666 .863 r
.24367 .40406 .24468 .40543 .24624 .40485 .24522 .40364 Mtetra
0 0 .501 r
.24522 .40364 .24624 .40485 .24772 .40515 .24659 .40518 Mtetra
.9 .549 .37 r
.24659 .40518 .24772 .40515 .24916 .40602 .24768 .41015 Mtetra
.935 .676 .52 r
.24768 .41015 .24916 .40602 .25056 .40729 .23257 .60509 Mtetra
.542 .316 .522 r
.23257 .60509 .25056 .40729 .25204 .40777 .23394 .60781 Mtetra
.536 .311 .521 r
.23394 .60781 .25204 .40777 .25359 .40729 .23558 .60754 Mtetra
.531 .307 .52 r
.23558 .60754 .25359 .40729 .25522 .40595 .23739 .60517 Mtetra
0 0 .187 r
.23739 .60517 .25522 .40595 .25693 .40364 .25514 .41171 Mtetra
0 0 0 r
.25514 .41171 .25693 .40364 .25863 .40152 .25744 .40225 Mtetra
.967 .926 .7 r
.25744 .40225 .25863 .40152 .26028 .39985 .25925 .39884 Mtetra
.78 .76 .835 r
.25925 .39884 .26028 .39985 .26187 .39896 .26087 .39757 Mtetra
.657 .671 .852 r
.26087 .39757 .26187 .39896 .26344 .39843 .26244 .39702 Mtetra
.592 .643 .871 r
.26244 .39702 .26344 .39843 .26499 .39805 .26398 .39677 Mtetra
.608 .672 .886 r
.26398 .39677 .26499 .39805 .26655 .39765 .26553 .39645 Mtetra
.613 .689 .897 r
.26553 .39645 .26655 .39765 .2681 .39724 .26708 .39611 Mtetra
.614 .701 .907 r
.26708 .39611 .2681 .39724 .26966 .39681 .26863 .39576 Mtetra
.639 .724 .91 r
.26863 .39576 .26966 .39681 .27123 .39631 .2702 .39531 Mtetra
.66 .741 .91 r
.2702 .39531 .27123 .39631 .2728 .39574 .27176 .39478 Mtetra
.676 .753 .909 r
.27176 .39478 .2728 .39574 .27438 .39513 .27334 .39418 Mtetra
.731 .767 .882 r
.27334 .39418 .27438 .39513 .27598 .39416 .27494 .39331 Mtetra
.729 .789 .9 r
.27494 .39331 .27598 .39416 .27758 .39328 .27654 .39247 Mtetra
.668 .786 .937 r
.27654 .39247 .27758 .39328 .27914 .39286 .27811 .3919 Mtetra
.351 .627 .956 r
.27811 .3919 .27914 .39286 .28057 .39425 .27963 .39212 Mtetra
.178 .313 .765 r
.27963 .39212 .28057 .39425 .2817 .39963 .28108 .39328 Mtetra
.245 .171 .571 r
.28108 .39328 .2817 .39963 .26841 .59738 .28238 .39634 Mtetra
0 0 .214 r
.28238 .39634 .26841 .59738 .26979 .60087 .26932 .59139 Mtetra
0 0 .43 r
.26932 .59139 .26979 .60087 .27135 .60193 .27042 .59867 Mtetra
.005 .111 .625 r
.27042 .59867 .27135 .60193 .27297 .60223 .27188 .60101 Mtetra
.245 .526 .916 r
.27188 .60101 .27297 .60223 .2746 .6023 .27349 .60153 Mtetra
.589 .786 .974 r
.27349 .60153 .2746 .6023 .27627 .602 .27516 .60115 Mtetra
.737 .803 .905 r
.27516 .60115 .27627 .602 .27798 .60109 .27687 .60022 Mtetra
.813 .8 .839 r
.27687 .60022 .27798 .60109 .27982 .59841 .27863 .59867 Mtetra
.924 .949 .791 r
.27863 .59867 .27982 .59841 .28195 .59166 .28045 .59624 Mtetra
0 0 .019 r
.28045 .59624 .28195 .59166 .29767 .39242 .28242 .59183 Mtetra
0 0 .207 r
.28242 .59183 .29767 .39242 .29954 .38797 .29792 .39533 Mtetra
0 0 .011 r
.29792 .39533 .29954 .38797 .30123 .38596 .30005 .3871 Mtetra
.926 .961 .649 r
.30005 .3871 .30123 .38596 .30287 .38464 .30183 .38393 Mtetra
.842 .815 .823 r
.30183 .38393 .30287 .38464 .3045 .38346 .3035 .38222 Mtetra
.713 .714 .85 r
.3035 .38222 .3045 .38346 .30611 .38261 .30511 .38137 Mtetra
.536 .651 .909 r
.30511 .38137 .30611 .38261 .30768 .38241 .30667 .38128 Mtetra
.739 .264 0 r
.30667 .38128 .30768 .38241 .30909 .38449 .30807 .38348 Mtetra
.949 .685 .501 r
.30807 .38348 .30909 .38449 .29772 .57807 .29651 .57884 Mtetra
.919 .616 .453 r
.29651 .57884 .29772 .57807 .2984 .59267 .29729 .59193 Mtetra
.599 .053 0 r
.29729 .59193 .2984 .59267 .29996 .5942 .29886 .59339 Mtetra
.635 .794 .958 r
.29886 .59339 .29996 .5942 .30165 .59375 .30056 .59289 Mtetra
.756 .803 .891 r
.30056 .59289 .30165 .59375 .30338 .59276 .30229 .59183 Mtetra
.599 .757 .954 r
.30229 .59183 .30338 .59276 .30507 .59242 .30398 .59146 Mtetra
.47 .7 .969 r
.30398 .59146 .30507 .59242 .30674 .59239 .30565 .59143 Mtetra
.676 .772 .922 r
.30565 .59143 .30674 .59239 .30845 .59175 .30736 .59078 Mtetra
.889 .769 .723 r
.30736 .59078 .30845 .59175 .31032 .58854 .30924 .58749 Mtetra
.949 .689 .508 r
.30924 .58749 .31032 .58854 .32411 .39449 .32329 .39018 Mtetra
.879 .645 .582 r
.32329 .39018 .32411 .39449 .32669 .37815 .3257 .37685 Mtetra
.84 .73 .743 r
.3257 .37685 .32669 .37815 .32842 .37567 .32742 .37444 Mtetra
.654 .7 .88 r
.32742 .37444 .32842 .37567 .33002 .37512 .32902 .37391 Mtetra
.499 .644 .921 r
.32902 .37391 .33002 .37512 .33159 .3751 .33059 .37392 Mtetra
.547 .67 .918 r
.33059 .37392 .33159 .3751 .33318 .37495 .33217 .37378 Mtetra
.643 .709 .895 r
.33217 .37378 .33318 .37495 .33478 .37447 .33378 .37331 Mtetra
.658 .714 .889 r
.33378 .37331 .33478 .37447 .33639 .37394 .33539 .37276 Mtetra
.681 .718 .877 r
.33539 .37276 .33639 .37394 .338 .37332 .337 .37211 Mtetra
.696 .717 .865 r
.337 .37211 .338 .37332 .33962 .37262 .33862 .37136 Mtetra
.696 .709 .859 r
.33862 .37136 .33962 .37262 .34124 .37191 .34025 .37061 Mtetra
.682 .699 .859 r
.34025 .37061 .34124 .37191 .34286 .37125 .34187 .36993 Mtetra
.669 .69 .862 r
.34187 .36993 .34286 .37125 .34447 .37065 .34349 .36932 Mtetra
.664 .688 .862 r
.34349 .36932 .34447 .37065 .34609 .37006 .3451 .36872 Mtetra
.665 .688 .862 r
.3451 .36872 .34609 .37006 .34771 .36946 .34672 .36813 Mtetra
.667 .688 .861 r
.34672 .36813 .34771 .36946 .34933 .36886 .34834 .36752 Mtetra
.665 .687 .861 r
.34834 .36752 .34933 .36886 .35095 .36826 .34996 .36692 Mtetra
.69 .696 .85 r
.34996 .36692 .35095 .36826 .35257 .36759 .35159 .36618 Mtetra
.694 .687 .839 r
.35159 .36618 .35257 .36759 .3542 .36689 .35322 .3654 Mtetra
.636 .654 .85 r
.35322 .3654 .3542 .36689 .35582 .36635 .35484 .36494 Mtetra
.267 .48 .88 r
.35484 .36494 .35582 .36635 .35741 .36631 .35639 .36555 Mtetra
.857 .403 .044 r
.35639 .36555 .35741 .36631 .35897 .36694 .35784 .3684 Mtetra
.951 .681 .49 r
.35784 .3684 .35897 .36694 .36051 .36794 .3499 .55224 Mtetra
.57 .339 .526 r
.3499 .55224 .36051 .36794 .36208 .36855 .3507 .56968 Mtetra
.536 .311 .521 r
.3507 .56968 .36208 .36855 .36371 .36805 .3524 .56968 Mtetra
.533 .309 .52 r
.3524 .56968 .36371 .36805 .36535 .36716 .35417 .56827 Mtetra
.532 .308 .52 r
.35417 .56827 .36535 .36716 .36701 .36599 .35598 .56621 Mtetra
.533 .308 .52 r
.35598 .56621 .36701 .36599 .36867 .36487 .35777 .56448 Mtetra
.535 .311 .521 r
.35777 .56448 .36867 .36487 .37029 .36447 .35949 .56414 Mtetra
.541 .316 .522 r
.35949 .56414 .37029 .36447 .37177 .36695 .36106 .56698 Mtetra
.542 .316 .522 r
.36106 .56698 .37177 .36695 .36392 .56606 .36262 .57017 Mtetra
.636 .312 .406 r
.36262 .57017 .36392 .56606 .36535 .57199 .36425 .57191 Mtetra
.307 0 0 r
.36425 .57191 .36535 .57199 .367 .57345 .36594 .57238 Mtetra
.656 .749 .918 r
.36594 .57238 .367 .57345 .36874 .57301 .36768 .57181 Mtetra
.705 .739 .878 r
.36768 .57181 .36874 .57301 .3705 .5721 .36944 .57098 Mtetra
.657 .74 .911 r
.36944 .57098 .3705 .5721 .37225 .57131 .37118 .5704 Mtetra
.499 .728 .975 r
.37118 .5704 .37225 .57131 .37399 .571 .37291 .57028 Mtetra
.603 .81 .979 r
.37291 .57028 .37399 .571 .37573 .57055 .37465 .56983 Mtetra
.826 .839 .858 r
.37465 .56983 .37573 .57055 .37749 .56958 .37645 .56826 Mtetra
.893 .74 .685 r
.37645 .56826 .37749 .56958 .3793 .56774 .37835 .56409 Mtetra
.907 .668 .565 r
.37835 .56409 .3793 .56774 .38112 .56545 .38077 .54792 Mtetra
.935 .667 .506 r
.38077 .54792 .38112 .56545 .38292 .5637 .39045 .35951 Mtetra
.539 .318 .528 r
.39045 .35951 .38292 .5637 .38465 .56364 .3921 .3588 Mtetra
.537 .316 .527 r
.3921 .3588 .38465 .56364 .3864 .56314 .39372 .35876 Mtetra
.541 .32 .528 r
.39372 .35876 .3864 .56314 .38826 .5597 .39543 .35683 Mtetra
.545 .323 .529 r
.39543 .35683 .38826 .5597 .398 .35903 .3972 .35318 Mtetra
.68 .494 .628 r
.3972 .35318 .398 .35903 .39988 .35263 .39893 .35065 Mtetra
.746 .648 .752 r
.39893 .35065 .39988 .35263 .4016 .35014 .40062 .34913 Mtetra
.661 .749 .916 r
.40062 .34913 .4016 .35014 .40326 .34946 .40227 .34857 Mtetra
.588 .754 .957 r
.40227 .34857 .40326 .34946 .40489 .34919 .40391 .34824 Mtetra
.637 .758 .935 r
.40391 .34824 .40489 .34919 .40653 .34888 .40556 .34777 Mtetra
.732 .749 .866 r
.40556 .34777 .40653 .34888 .40819 .34811 .40722 .34682 Mtetra
.681 .705 .866 r
.40722 .34682 .40819 .34811 .40985 .34745 .40888 .34614 Mtetra
.458 .607 .911 r
.40888 .34614 .40985 .34745 .41149 .34717 .41051 .34628 Mtetra
.758 .268 0 r
.41051 .34628 .41149 .34717 .41311 .34767 .41206 .3486 Mtetra
.903 .568 .401 r
.41206 .3486 .41311 .34767 .41472 .34856 .41342 .35669 Mtetra
.947 .671 .483 r
.41342 .35669 .41472 .34856 .41634 .34919 .40834 .55112 Mtetra
.536 .311 .521 r
.40834 .55112 .41634 .34919 .41801 .34825 .41009 .551 Mtetra
.534 .31 .52 r
.41009 .551 .41801 .34825 .41967 .34763 .41188 .54995 Mtetra
.537 .312 .521 r
.41188 .54995 .41967 .34763 .42127 .34902 .4136 .55067 Mtetra
.542 .316 .522 r
.4136 .55067 .42127 .34902 .41651 .54814 .41525 .55385 Mtetra
.618 .314 .432 r
.41525 .55385 .41651 .54814 .41804 .55537 .41695 .55566 Mtetra
.553 0 0 r
.41695 .55566 .41804 .55537 .41973 .55742 .41868 .55649 Mtetra
.484 .72 .975 r
.41868 .55649 .41973 .55742 .42149 .55733 .42044 .55641 Mtetra
.669 .788 .938 r
.42044 .55641 .42149 .55733 .42327 .55661 .42222 .55576 Mtetra
.814 .823 .857 r
.42222 .55576 .42327 .55661 .42507 .55537 .42403 .55425 Mtetra
.899 .765 .705 r
.42403 .55425 .42507 .55537 .42689 .55361 .4259 .55058 Mtetra
.887 .668 .6 r
.4259 .55058 .42689 .55361 .42871 .55141 .42792 .54181 Mtetra
.951 .679 .487 r
.42792 .54181 .42871 .55141 .43054 .5492 .43526 .3447 Mtetra
.541 .319 .528 r
.43526 .3447 .43054 .5492 .43233 .54834 .43696 .34301 Mtetra
.537 .317 .527 r
.43696 .34301 .43233 .54834 .4341 .54796 .43863 .34288 Mtetra
.536 .315 .527 r
.43863 .34288 .4341 .54796 .43587 .54788 .44027 .34359 Mtetra
.536 .316 .527 r
.44027 .34359 .43587 .54788 .43764 .54803 .44192 .34411 Mtetra
.538 .317 .527 r
.44192 .34411 .43764 .54803 .43943 .5475 .4436 .34371 Mtetra
.543 .321 .528 r
.4436 .34371 .43943 .5475 .44126 .5451 .44533 .34104 Mtetra
.546 .324 .529 r
.44533 .34104 .44126 .5451 .44788 .34542 .4471 .33668 Mtetra
.651 .451 .6 r
.4471 .33668 .44788 .34542 .44978 .3361 .44884 .33381 Mtetra
.756 .633 .724 r
.44884 .33381 .44978 .3361 .45152 .33294 .45055 .33193 Mtetra
.707 .766 .899 r
.45055 .33193 .45152 .33294 .4532 .332 .45224 .33114 Mtetra
.641 .784 .95 r
.45224 .33114 .4532 .332 .45488 .33152 .45392 .33063 Mtetra
.611 .766 .954 r
.45392 .33063 .45488 .33152 .45656 .33123 .45559 .33022 Mtetra
.664 .757 .92 r
.45559 .33022 .45656 .33123 .45824 .33064 .45728 .32964 Mtetra
.663 .757 .919 r
.45728 .32964 .45824 .33064 .45993 .33007 .45896 .32905 Mtetra
.663 .755 .919 r
.45896 .32905 .45993 .33007 .46161 .32949 .46065 .32847 Mtetra
.663 .754 .917 r
.46065 .32847 .46161 .32949 .4633 .32891 .46234 .32788 Mtetra
.663 .753 .917 r
.46234 .32788 .4633 .32891 .46498 .32832 .46402 .3273 Mtetra
.662 .753 .918 r
.46402 .3273 .46498 .32832 .46667 .32774 .46571 .32672 Mtetra
.661 .753 .919 r
.46571 .32672 .46667 .32774 .46836 .32716 .4674 .32614 Mtetra
.661 .754 .919 r
.4674 .32614 .46836 .32716 .47005 .32658 .46909 .32557 Mtetra
.662 .756 .92 r
.46909 .32557 .47005 .32658 .47174 .32599 .47079 .32499 Mtetra
.665 .758 .92 r
.47079 .32499 .47174 .32599 .47344 .32539 .47248 .32439 Mtetra
.666 .76 .921 r
.47248 .32439 .47344 .32539 .47513 .32479 .47417 .32379 Mtetra
.669 .762 .92 r
.47417 .32379 .47513 .32479 .47683 .32417 .47587 .32318 Mtetra
.708 .775 .904 r
.47587 .32318 .47683 .32417 .47853 .32326 .47757 .32239 Mtetra
.673 .792 .938 r
.47757 .32239 .47853 .32326 .48022 .32262 .47927 .32176 Mtetra
.573 .76 .967 r
.47927 .32176 .48022 .32262 .48191 .32256 .48096 .32145 Mtetra
0 .376 .84 r
.48096 .32145 .48191 .32256 .48357 .32513 .48264 .32238 Mtetra
.14 .234 .701 r
.48264 .32238 .48357 .32513 .48506 .34181 .48431 .32422 Mtetra
.458 .28 .551 r
.48431 .32422 .48506 .34181 .48446 .53253 .48597 .32754 Mtetra
.539 .318 .528 r
.48597 .32754 .48446 .53253 .48627 .5327 .48768 .3267 Mtetra
.48768 .3267 .48627 .5327 .48809 .53189 .48939 .32561 Mtetra
.536 .316 .527 r
.48939 .32561 .48809 .53189 .48991 .53095 .49109 .32591 Mtetra
0 0 .333 r
.49109 .32591 .48991 .53095 .49171 .53226 .49076 .52493 Mtetra
.044 .032 .516 r
.49076 .52493 .49171 .53226 .49352 .53327 .49252 .53073 Mtetra
0 .161 .682 r
.49252 .53073 .49352 .53327 .49534 .53385 .49432 .53292 Mtetra
.498 .729 .975 r
.49432 .53292 .49534 .53385 .49716 .53352 .49614 .53279 Mtetra
.651 .832 .97 r
.49614 .53279 .49716 .53352 .49899 .53296 .49797 .53216 Mtetra
.718 .832 .936 r
.49797 .53216 .49899 .53296 .50082 .53228 .4998 .53127 Mtetra
.59 .75 .954 r
.4998 .53127 .50082 .53228 .50264 .53208 .50163 .53091 Mtetra
.636 .732 .917 r
.50163 .53091 .50264 .53208 .50447 .53161 .50346 .53039 Mtetra
.701 .745 .886 r
.50346 .53039 .50447 .53161 .50631 .53058 .5053 .52955 Mtetra
.828 .801 .826 r
.5053 .52955 .50631 .53058 .50816 .52703 .50714 .52778 Mtetra
.877 .973 .664 r
.50714 .52778 .50816 .52703 .51003 .51706 .50899 .52496 Mtetra
.129 0 .314 r
.50899 .52496 .51003 .51706 .51264 .31652 .51084 .5195 Mtetra
0 0 .326 r
.51084 .5195 .51264 .31652 .51437 .31323 .51341 .31785 Mtetra
0 0 .031 r
.51341 .31785 .51437 .31323 .51609 .31141 .51515 .31185 Mtetra
.934 .968 .707 r
.51515 .31185 .51609 .31141 .51781 .31022 .51688 .30905 Mtetra
.721 .746 .872 r
.51688 .30905 .51781 .31022 .51954 .30957 .5186 .30814 Mtetra
.608 .662 .877 r
.5186 .30814 .51954 .30957 .52126 .30917 .52032 .30779 Mtetra
.54 .639 .897 r
.52032 .30779 .52126 .30917 .52298 .30888 .52205 .3077 Mtetra
.632 .715 .907 r
.52205 .3077 .52298 .30888 .52471 .30835 .52377 .30723 Mtetra
.657 .737 .909 r
.52377 .30723 .52471 .30835 .52643 .30774 .5255 .30666 Mtetra
.673 .751 .909 r
.5255 .30666 .52643 .30774 .52816 .30707 .52723 .30602 Mtetra
.736 .774 .883 r
.52723 .30602 .52816 .30707 .52989 .30598 .52895 .30505 Mtetra
.724 .795 .908 r
.52895 .30505 .52989 .30598 .53162 .3051 .53068 .30418 Mtetra
.655 .779 .939 r
.53068 .30418 .53162 .3051 .53335 .30472 .53241 .3036 Mtetra
.338 .587 .936 r
.53241 .3036 .53335 .30472 .53509 .30656 .53415 .30395 Mtetra
.275 .336 .745 r
.53415 .30395 .53509 .30656 .53685 .31411 .53589 .30527 Mtetra
.343 .228 .575 r
.53589 .30527 .53685 .31411 .53947 .51484 .53764 .30888 Mtetra
0 0 .355 r
.53764 .30888 .53947 .51484 .54134 .51736 .54031 .50868 Mtetra
.137 .086 .532 r
.54031 .50868 .54134 .51736 .5432 .51813 .5422 .51479 Mtetra
.186 .241 .688 r
.5422 .51479 .5432 .51813 .54506 .51825 .54407 .51692 Mtetra
.236 .5 .901 r
.54407 .51692 .54506 .51825 .54693 .51849 .54594 .5176 Mtetra
.531 .754 .978 r
.54594 .5176 .54693 .51849 .54879 .51825 .5478 .51736 Mtetra
.769 .828 .898 r
.5478 .51736 .54879 .51825 .55065 .51719 .54966 .51617 Mtetra
.937 .779 .659 r
.54966 .51617 .55065 .51719 .55248 .51248 .55149 .51133 Mtetra
.971 .689 .438 r
.55149 .51133 .55248 .51248 .55252 .30619 .55159 .30455 Mtetra
.935 .722 .591 r
.55159 .30455 .55252 .30619 .5542 .29823 .55327 .29692 Mtetra
.803 .748 .802 r
.55327 .29692 .5542 .29823 .55593 .29651 .55501 .29526 Mtetra
.627 .702 .899 r
.55501 .29526 .55593 .29651 .55768 .29601 .55676 .29481 Mtetra
.491 .651 .93 r
.55676 .29481 .55768 .29601 .55943 .29597 .55851 .29483 Mtetra
.657 .736 .908 r
.55851 .29483 .55943 .29597 .56118 .29523 .56026 .29425 Mtetra
.685 .777 .921 r
.56026 .29425 .56118 .29523 .56293 .29447 .56201 .29355 Mtetra
.623 .772 .952 r
.56201 .29355 .56293 .29447 .56468 .29415 .56376 .29308 Mtetra
.378 .622 .948 r
.56376 .29308 .56468 .29415 .56646 .2958 .56552 .29332 Mtetra
.317 .375 .764 r
.56552 .29332 .56646 .2958 .56832 .30264 .5673 .29443 Mtetra
.375 .256 .588 r
.5673 .29443 .56832 .30264 .57299 .50389 .56911 .2974 Mtetra
0 0 .37 r
.56911 .2974 .57299 .50389 .57492 .50677 .57381 .49637 Mtetra
.134 .074 .518 r
.57381 .49637 .57492 .50677 .57682 .50761 .5758 .50388 Mtetra
.192 .227 .669 r
.5758 .50388 .57682 .50761 .57871 .50779 .57773 .50628 Mtetra
.233 .464 .876 r
.57773 .50628 .57871 .50779 .58061 .50802 .57964 .50709 Mtetra
.491 .731 .978 r
.57964 .50709 .58061 .50802 .5825 .50786 .58153 .50697 Mtetra
.741 .826 .918 r
.58153 .50697 .5825 .50786 .58438 .50694 .58341 .50594 Mtetra
.928 .796 .695 r
.58341 .50594 .58438 .50694 .5862 .50307 .58523 .50203 Mtetra
.973 .688 .426 r
.58523 .50203 .5862 .50307 .58426 .30085 .58334 .29974 Mtetra
.968 .729 .523 r
.58334 .29974 .58426 .30085 .58579 .2882 .58488 .28705 Mtetra
.859 .78 .773 r
.58488 .28705 .58579 .2882 .58752 .28595 .58661 .2848 Mtetra
.681 .743 .898 r
.58661 .2848 .58752 .28595 .58929 .28524 .58838 .2841 Mtetra
.559 .697 .932 r
.58838 .2841 .58929 .28524 .59106 .28502 .59015 .28389 Mtetra
.706 .756 .892 r
.59015 .28389 .59106 .28502 .59283 .28419 .59192 .28307 Mtetra
.72 .763 .886 r
.59192 .28307 .59283 .28419 .59459 .28328 .59368 .28216 Mtetra
.586 .715 .932 r
.59368 .28216 .59459 .28328 .59636 .28296 .59546 .28185 Mtetra
.599 .133 0 r
.59546 .28185 .59636 .28296 .59821 .28539 .5973 .28429 Mtetra
.973 .68 .404 r
.5973 .28429 .59821 .28539 .6049 .48851 .60395 .48756 Mtetra
.941 .574 .223 r
.60395 .48756 .6049 .48851 .60704 .49777 .60608 .49671 Mtetra
0 .239 .733 r
.60608 .49671 .60704 .49777 .60899 .49927 .60803 .49809 Mtetra
.597 .723 .932 r
.60803 .49809 .60899 .49927 .6109 .49898 .60994 .49771 Mtetra
.742 .758 .866 r
.60994 .49771 .6109 .49898 .61279 .49775 .61183 .49658 Mtetra
.807 .79 .837 r
.61183 .49658 .61279 .49775 .61463 .49488 .61371 .49496 Mtetra
.9 .983 .788 r
.61371 .49496 .61463 .49488 .61637 .48812 .61557 .49264 Mtetra
.037 0 .213 r
.61557 .49264 .61637 .48812 .61253 .2841 .61738 .48872 Mtetra
0 0 .382 r
.61738 .48872 .61253 .2841 .6142 .27942 .61375 .29381 Mtetra
0 0 .311 r
.61375 .29381 .6142 .27942 .61594 .27742 .61513 .27924 Mtetra
0 0 0 r
.61513 .27924 .61594 .27742 .61771 .27612 .61683 .27557 Mtetra
.852 .902 .87 r
.61683 .27557 .61771 .27612 .61948 .27523 .61859 .27395 Mtetra
.679 .721 .882 r
.61859 .27395 .61948 .27523 .62127 .27459 .62037 .27324 Mtetra
.615 .685 .892 r
.62037 .27324 .62127 .27459 .62306 .27407 .62216 .27284 Mtetra
.704 .74 .879 r
.62216 .27284 .62306 .27407 .62484 .27315 .62395 .272 Mtetra
.731 .762 .878 r
.62395 .272 .62484 .27315 .62662 .27217 .62572 .27102 Mtetra
.617 .723 .922 r
.62572 .27102 .62662 .27217 .62841 .27174 .62752 .27059 Mtetra
0 .063 .598 r
.62752 .27059 .62841 .27174 .63029 .27362 .6294 .27248 Mtetra
.974 .678 .39 r
.6294 .27248 .63029 .27362 .639 .47262 .63805 .47147 Mtetra
.956 .612 .263 r
.63805 .47147 .639 .47262 .64142 .48657 .64047 .48546 Mtetra
0 .104 .623 r
.64047 .48546 .64142 .48657 .64344 .48848 .64248 .48728 Mtetra
.573 .71 .935 r
.64248 .48728 .64344 .48848 .64538 .48829 .64442 .48699 Mtetra
.731 .753 .87 r
.64442 .48699 .64538 .48829 .64728 .48713 .64633 .48592 Mtetra
.803 .785 .836 r
.64633 .48592 .64728 .48713 .64913 .48445 .64823 .48431 Mtetra
.906 .966 .809 r
.64823 .48431 .64913 .48445 .65084 .47814 .65009 .48204 Mtetra
0 0 .167 r
.65009 .48204 .65084 .47814 .64486 .27348 .6519 .47823 Mtetra
.488 .274 .515 r
.6519 .47823 .64486 .27348 .64649 .26826 .65281 .45149 Mtetra
0 0 .38 r
.65281 .45149 .64649 .26826 .64823 .26619 .64748 .26826 Mtetra
0 0 0 r
.64748 .26826 .64823 .26619 .65001 .26484 .64916 .26443 Mtetra
.875 .931 .856 r
.64916 .26443 .65001 .26484 .6518 .26391 .65092 .26263 Mtetra
.688 .729 .881 r
.65092 .26263 .6518 .26391 .65361 .26323 .65272 .26187 Mtetra
.624 .688 .889 r
.65272 .26187 .65361 .26323 .65542 .26268 .65453 .26142 Mtetra
.69 .733 .883 r
.65453 .26142 .65542 .26268 .65722 .26182 .65634 .26065 Mtetra
.738 .765 .875 r
.65634 .26065 .65722 .26182 .65901 .26078 .65813 .25962 Mtetra
.642 .733 .914 r
.65813 .25962 .65901 .26078 .66082 .26024 .65995 .25908 Mtetra
0 .291 .786 r
.65995 .25908 .66082 .26024 .66272 .26153 .66185 .26038 Mtetra
.936 .57 .181 r
.66185 .26038 .66272 .26153 .66499 .27097 .66412 .26996 Mtetra
.975 .675 .374 r
.66412 .26996 .66499 .27097 .67618 .47445 .67525 .47337 Mtetra
0 0 .496 r
.67525 .47337 .67618 .47445 .67826 .47676 .67733 .47567 Mtetra
.627 .758 .941 r
.67733 .47567 .67826 .47676 .68022 .47625 .67929 .47515 Mtetra
.767 .801 .881 r
.67929 .47515 .68022 .47625 .68214 .475 .68121 .47389 Mtetra
.776 .801 .873 r
.68121 .47389 .68214 .475 .68405 .4737 .68313 .47256 Mtetra
.716 .782 .904 r
.68313 .47256 .68405 .4737 .68599 .47278 .68506 .47162 Mtetra
.701 .771 .906 r
.68506 .47162 .68599 .47278 .68793 .47195 .68701 .47076 Mtetra
.651 .748 .921 r
.68701 .47076 .68793 .47195 .68989 .47133 .68896 .47014 Mtetra
.582 .718 .936 r
.68896 .47014 .68989 .47133 .69186 .47098 .69093 .4698 Mtetra
.558 .71 .943 r
.69093 .4698 .69186 .47098 .69383 .47071 .69291 .46955 Mtetra
.466 .67 .952 r
.69291 .46955 .69383 .47071 .69582 .47073 .6949 .46959 Mtetra
.427 .653 .954 r
.6949 .46959 .69582 .47073 .69782 .47085 .6969 .46972 Mtetra
.631 .753 .935 r
.6969 .46972 .69782 .47085 .69979 .47031 .69887 .46918 Mtetra
.889 .811 .765 r
.69887 .46918 .69979 .47031 .70164 .46764 .70073 .46651 Mtetra
.98 .725 .47 r
.70073 .46651 .70164 .46764 .70273 .45079 .7018 .44949 Mtetra
.977 .681 .379 r
.7018 .44949 .70273 .45079 .69377 .25159 .69291 .2504 Mtetra
.912 .789 .712 r
.69291 .2504 .69377 .25159 .69546 .24834 .6946 .24716 Mtetra
.709 .758 .89 r
.6946 .24716 .69546 .24834 .69728 .24747 .69642 .24629 Mtetra
.587 .708 .927 r
.69642 .24629 .69728 .24747 .69914 .24715 .69828 .24597 Mtetra
.622 .724 .92 r
.69828 .24597 .69914 .24715 .70098 .24669 .70012 .24551 Mtetra
.731 .766 .88 r
.70012 .24551 .70098 .24669 .7028 .24569 .70194 .24451 Mtetra
.639 .732 .915 r
.70194 .24451 .7028 .24569 .70465 .24516 .70379 .24398 Mtetra
.06 .396 .854 r
.70379 .24398 .70465 .24516 .70659 .2462 .70573 .24502 Mtetra
.926 .555 .143 r
.70573 .24502 .70659 .2462 .70904 .25572 .70818 .25455 Mtetra
.975 .671 .352 r
.70818 .25455 .70904 .25572 .72329 .46028 .72238 .45915 Mtetra
.6 .137 0 r
.72238 .45915 .72329 .46028 .72549 .46322 .72458 .4621 Mtetra
.419 .654 .956 r
.72458 .4621 .72549 .46322 .72751 .46337 .72661 .46225 Mtetra
.71 .786 .911 r
.72661 .46225 .72751 .46337 .72948 .46245 .72857 .46133 Mtetra
.888 .816 .772 r
.72857 .46133 .72948 .46245 .73134 .45985 .73044 .45872 Mtetra
.977 .758 .54 r
.73044 .45872 .73134 .45985 .7328 .45096 .7319 .44985 Mtetra
.977 .679 .365 r
.7319 .44985 .7328 .45096 .72151 .2433 .72065 .24212 Mtetra
.937 .787 .669 r
.72065 .24212 .72151 .2433 .72314 .23923 .72229 .23805 Mtetra
.721 .764 .886 r
.72229 .23805 .72314 .23923 .72497 .23829 .72412 .23711 Mtetra
.581 .707 .929 r
.72412 .23711 .72497 .23829 .72685 .23799 .726 .23681 Mtetra
.542 .688 .934 r
.726 .23681 .72685 .23799 .72873 .23782 .72789 .23664 Mtetra
.658 .74 .911 r
.72789 .23664 .72873 .23782 .73059 .2372 .72975 .23602 Mtetra
.664 .743 .909 r
.72975 .23602 .73059 .2372 .73245 .23656 .7316 .23537 Mtetra
.702 .757 .895 r
.7316 .23537 .73245 .23656 .7343 .23572 .73345 .23453 Mtetra
.757 .775 .868 r
.73345 .23453 .7343 .23572 .73612 .23455 .73528 .23336 Mtetra
.674 .746 .905 r
.73528 .23336 .73612 .23455 .73798 .23385 .73713 .23266 Mtetra
.241 .515 .909 r
.73713 .23266 .73798 .23385 .73993 .23452 .73909 .23332 Mtetra
.896 .511 .065 r
.73909 .23332 .73993 .23452 .74241 .2425 .74157 .24131 Mtetra
.975 .667 .334 r
.74157 .24131 .74241 .2425 .75909 .44876 .7582 .44762 Mtetra
.634 .179 0 r
.7582 .44762 .75909 .44876 .76138 .45209 .76049 .45095 Mtetra
.392 .636 .953 r
.76049 .45095 .76138 .45209 .76345 .45232 .76256 .45118 Mtetra
.695 .781 .917 r
.76256 .45118 .76345 .45232 .76544 .45147 .76456 .45033 Mtetra
.873 .82 .793 r
.76456 .45033 .76544 .45147 .76733 .44913 .76644 .44799 Mtetra
.978 .767 .552 r
.76644 .44799 .76733 .44913 .7688 .44125 .76791 .4401 Mtetra
.977 .675 .347 r
.76791 .4401 .7688 .44125 .75509 .23213 .75426 .23093 Mtetra
.951 .785 .641 r
.75426 .23093 .75509 .23213 .75666 .22748 .75583 .22628 Mtetra
.748 .772 .873 r
.75583 .22628 .75666 .22748 .7585 .22637 .75767 .22516 Mtetra
.622 .724 .919 r
.75767 .22516 .7585 .22637 .76039 .2259 .75956 .22469 Mtetra
.591 .71 .926 r
.75956 .22469 .76039 .2259 .76229 .22555 .76146 .22435 Mtetra
.75 .773 .872 r
.76146 .22435 .76229 .22555 .76413 .22443 .7633 .22322 Mtetra
.676 .746 .904 r
.7633 .22322 .76413 .22443 .76601 .22372 .76518 .22251 Mtetra
.378 .596 .931 r
.76518 .22251 .76601 .22372 .76797 .22405 .76714 .22284 Mtetra
.806 .393 0 r
.76714 .22284 .76797 .22405 .77034 .2295 .76951 .22829 Mtetra
.973 .663 .318 r
.76951 .22829 .77034 .2295 .78917 .43789 .7883 .43673 Mtetra
.714 .273 0 r
.7883 .43673 .78917 .43789 .79159 .44209 .79072 .44093 Mtetra
.503 .695 .954 r
.79072 .44093 .79159 .44209 .79366 .442 .79279 .44084 Mtetra
.694 .78 .917 r
.79279 .44084 .79366 .442 .79568 .44115 .7948 .43999 Mtetra
.735 .794 .9 r
.7948 .43999 .79568 .44115 .79767 .44007 .7968 .43891 Mtetra
.497 .69 .954 r
.7968 .43891 .79767 .44007 .79975 .44 .79888 .43884 Mtetra
.625 .752 .938 r
.79888 .43884 .79975 .44 .80179 .43946 .80092 .4383 Mtetra
.811 .814 .853 r
.80092 .4383 .80179 .43946 .80374 .43783 .80287 .43667 Mtetra
.98 .772 .553 r
.80287 .43667 .80374 .43783 .80518 .43029 .80431 .4291 Mtetra
.976 .671 .329 r
.80431 .4291 .80518 .43029 .78907 .22066 .78825 .21943 Mtetra
.958 .783 .623 r
.78825 .21943 .78907 .22066 .79059 .21565 .78977 .21443 Mtetra
.751 .774 .871 r
.78977 .21443 .79059 .21565 .79244 .2145 .79163 .21328 Mtetra
.622 .723 .918 r
.79163 .21328 .79244 .2145 .79436 .21403 .79354 .2128 Mtetra
.553 .689 .93 r
.79354 .2128 .79436 .21403 .7963 .21382 .79548 .2126 Mtetra
.746 .772 .874 r
.79548 .2126 .7963 .21382 .79816 .21271 .79734 .21148 Mtetra
.677 .747 .903 r
.79734 .21148 .79816 .21271 .80005 .21198 .79924 .21076 Mtetra
.456 .638 .934 r
.79924 .21076 .80005 .21198 .80203 .21209 .80121 .21087 Mtetra
.768 .353 0 r
.80121 .21087 .80203 .21209 .80447 .2173 .80366 .21607 Mtetra
.971 .657 .298 r
.80366 .21607 .80447 .2173 .82582 .42649 .82496 .42532 Mtetra
.726 .292 0 r
.82496 .42532 .82582 .42649 .82836 .43112 .8275 .42995 Mtetra
.306 .58 .938 r
.8275 .42995 .82836 .43112 .83052 .43161 .82966 .43044 Mtetra
.649 .764 .933 r
.82966 .43044 .83052 .43161 .83257 .43096 .83172 .42979 Mtetra
.83 .821 .841 r
.83172 .42979 .83257 .43096 .83452 .42915 .83367 .42798 Mtetra
.975 .789 .589 r
.83367 .42798 .83452 .42915 .83605 .42305 .8352 .42188 Mtetra
.974 .667 .312 r
.8352 .42188 .83605 .42305 .81785 .21249 .81704 .21127 Mtetra
.975 .775 .571 r
.81704 .21127 .81785 .21249 .81922 .20618 .81841 .20495 Mtetra
.761 .759 .851 r
.20245 .41761 .2035 .41859 .20509 .41751 .20403 .41653 Mtetra
.613 .728 .928 r
.20403 .41653 .20509 .41751 .2066 .41716 .20555 .41618 Mtetra
.455 .67 .956 r
.20555 .41618 .2066 .41716 .20808 .41719 .20702 .41622 Mtetra
.655 .741 .913 r
.20702 .41622 .20808 .41719 .20961 .41669 .20856 .41572 Mtetra
.664 .744 .909 r
.20856 .41572 .20961 .41669 .21115 .41615 .21009 .41518 Mtetra
.67 .746 .907 r
.21009 .41518 .21115 .41615 .21269 .41559 .21163 .41462 Mtetra
.764 .761 .85 r
.21163 .41462 .21269 .41559 .21428 .41449 .21322 .41352 Mtetra
.709 .754 .887 r
.21322 .41352 .21428 .41449 .21584 .41375 .21478 .41277 Mtetra
.492 .687 .954 r
.21478 .41277 .21584 .41375 .21733 .41371 .21627 .41273 Mtetra
.932 .562 .28 r
.21627 .41273 .21733 .41371 .2184 .4181 .21734 .41714 Mtetra
.939 .683 .523 r
.21734 .41714 .2184 .4181 .20114 .61734 .20001 .61644 Mtetra
.931 .569 .309 r
.20001 .61644 .20114 .61734 .20226 .62237 .20113 .62145 Mtetra
0 .382 .82 r
.20113 .62145 .20226 .62237 .20378 .62311 .20265 .62219 Mtetra
.625 .758 .942 r
.20265 .62219 .20378 .62311 .20541 .62268 .20428 .62175 Mtetra
.802 .781 .834 r
.20428 .62175 .20541 .62268 .20714 .6212 .20601 .62028 Mtetra
.906 .743 .669 r
.20601 .62028 .20714 .6212 .20919 .61615 .20807 .61522 Mtetra
.939 .687 .53 r
.20807 .61522 .20919 .61615 .22907 .41603 .22802 .41505 Mtetra
.915 .725 .632 r
.22802 .41505 .22907 .41603 .23119 .40922 .23014 .40823 Mtetra
.793 .761 .824 r
.23014 .40823 .23119 .40922 .23281 .40785 .23176 .40684 Mtetra
.634 .732 .919 r
.23176 .40684 .23281 .40785 .23435 .40743 .2333 .40642 Mtetra
.485 .676 .949 r
.2333 .40642 .23435 .40743 .23585 .40744 .23481 .40641 Mtetra
.643 .729 .911 r
.23481 .40641 .23585 .40744 .23739 .40703 .23635 .40595 Mtetra
.664 .726 .895 r
.23635 .40595 .23739 .40703 .23894 .40651 .2379 .4054 Mtetra
.666 .72 .889 r
.2379 .4054 .23894 .40651 .24049 .40595 .23946 .40485 Mtetra
.739 .739 .851 r
.23946 .40485 .24049 .40595 .24209 .40493 .24105 .40388 Mtetra
.702 .739 .88 r
.24105 .40388 .24209 .40493 .24367 .40406 .24262 .40315 Mtetra
.513 .711 .961 r
.24262 .40315 .24367 .40406 .24522 .40364 .24414 .40304 Mtetra
.898 .492 .222 r
.24414 .40304 .24522 .40364 .24659 .40518 .24536 .40637 Mtetra
.939 .68 .518 r
.24536 .40637 .24659 .40518 .24768 .41015 .22979 .60478 Mtetra
.549 .322 .523 r
.22979 .60478 .24768 .41015 .23257 .60509 .23084 .61124 Mtetra
.581 .288 .436 r
.23084 .61124 .23257 .60509 .23394 .60781 .23237 .61229 Mtetra
.472 .161 .357 r
.23237 .61229 .23394 .60781 .23558 .60754 .23401 .61192 Mtetra
.326 .024 .289 r
.23401 .61192 .23558 .60754 .23739 .60517 .23575 .61046 Mtetra
0 0 .016 r
.23575 .61046 .23739 .60517 .25514 .41171 .23779 .60536 Mtetra
0 0 .141 r
.23779 .60536 .25514 .41171 .25744 .40225 .2561 .40489 Mtetra
.972 .889 .52 r
.2561 .40489 .25744 .40225 .25925 .39884 .25816 .39844 Mtetra
.856 .87 .849 r
.25816 .39844 .25925 .39884 .26087 .39757 .25981 .39681 Mtetra
.662 .795 .946 r
.25981 .39681 .26087 .39757 .26244 .39702 .26138 .39626 Mtetra
.505 .747 .982 r
.26138 .39626 .26244 .39702 .26398 .39677 .26291 .39612 Mtetra
.601 .806 .978 r
.26291 .39612 .26398 .39677 .26553 .39645 .26447 .39572 Mtetra
.642 .799 .958 r
.26447 .39572 .26553 .39645 .26708 .39611 .26603 .39523 Mtetra
.647 .766 .936 r
.26603 .39523 .26708 .39611 .26863 .39576 .2676 .39475 Mtetra
.651 .737 .913 r
.2676 .39475 .26863 .39576 .2702 .39531 .26917 .39425 Mtetra
.655 .729 .904 r
.26917 .39425 .2702 .39531 .27176 .39478 .27073 .39374 Mtetra
.661 .734 .904 r
.27073 .39374 .27176 .39478 .27334 .39418 .27231 .3932 Mtetra
.683 .752 .903 r
.27231 .3932 .27334 .39418 .27494 .39331 .27389 .39256 Mtetra
.689 .805 .937 r
.27389 .39256 .27494 .39331 .27654 .39247 .27547 .39191 Mtetra
.666 .848 .97 r
.27547 .39191 .27654 .39247 .27811 .3919 .27705 .39132 Mtetra
.706 .847 .95 r
.27705 .39132 .27811 .3919 .27963 .39212 .27864 .39059 Mtetra
.646 .648 .838 r
.27864 .39059 .27963 .39212 .28108 .39328 .28021 .39008 Mtetra
.536 .457 .713 r
.28021 .39008 .28108 .39328 .28238 .39634 .28174 .39017 Mtetra
.213 .151 .566 r
.28174 .39017 .28238 .39634 .26932 .59139 .28304 .39335 Mtetra
0 0 .193 r
.28304 .39335 .26932 .59139 .27042 .59867 .26969 .59264 Mtetra
0 0 .305 r
.26969 .59264 .27042 .59867 .27188 .60101 .27085 .59907 Mtetra
.18 .357 .804 r
.27085 .59907 .27188 .60101 .27349 .60153 .27242 .60012 Mtetra
.614 .668 .879 r
.27242 .60012 .27349 .60153 .27516 .60115 .27409 .59975 Mtetra
.706 .7 .842 r
.27409 .59975 .27516 .60115 .27687 .60022 .2758 .59886 Mtetra
.654 .691 .872 r
.2758 .59886 .27687 .60022 .27863 .59867 .27749 .5983 Mtetra
.625 .889 .988 r
.27749 .5983 .27863 .59867 .28045 .59624 .27918 .5977 Mtetra
0 0 0 r
.27918 .5977 .28045 .59624 .28242 .59183 .28092 .59643 Mtetra
0 0 .019 r
.28092 .59643 .28242 .59183 .29792 .39533 .28289 .59198 Mtetra
0 0 .183 r
.28289 .59198 .29792 .39533 .30005 .3871 .29867 .39113 Mtetra
.862 .829 .356 r
.29867 .39113 .30005 .3871 .30183 .38393 .30074 .38387 Mtetra
.919 .902 .792 r
.30074 .38387 .30183 .38393 .3035 .38222 .30245 .38153 Mtetra
.746 .829 .915 r
.30245 .38153 .3035 .38222 .30511 .38137 .30407 .38062 Mtetra
.436 .724 .986 r
.30407 .38062 .30511 .38137 .30667 .38128 .30562 .38059 Mtetra
.806 .319 0 r
.30562 .38059 .30667 .38128 .30807 .38348 .30703 .38276 Mtetra
.948 .684 .502 r
.30703 .38276 .30807 .38348 .29651 .57884 .29555 .57592 Mtetra
.976 .678 .381 r
.29555 .57592 .29651 .57884 .29729 .59193 .29624 .59042 Mtetra
0 .093 .64 r
.29624 .59042 .29729 .59193 .29886 .59339 .29779 .59202 Mtetra
.606 .672 .887 r
.29779 .59202 .29886 .59339 .30056 .59289 .29948 .59168 Mtetra
.715 .734 .866 r
.29948 .59168 .30056 .59289 .30229 .59183 .3012 .59079 Mtetra
.611 .736 .935 r
.3012 .59079 .30229 .59183 .30398 .59146 .3029 .5904 Mtetra
.545 .709 .947 r
.3029 .5904 .30398 .59146 .30565 .59143 .30458 .59022 Mtetra
.699 .73 .875 r
.30458 .59022 .30565 .59143 .30736 .59078 .3063 .58943 Mtetra
.867 .732 .712 r
.3063 .58943 .30736 .59078 .30924 .58749 .30818 .58608 Mtetra
.949 .689 .508 r
.30818 .58608 .30924 .58749 .32329 .39018 .32224 .38962 Mtetra
.948 .725 .567 r
.32224 .38962 .32329 .39018 .3257 .37685 .32466 .37622 Mtetra
.891 .813 .765 r
.32466 .37622 .3257 .37685 .32742 .37444 .32639 .37373 Mtetra
.693 .819 .942 r
.32639 .37373 .32742 .37444 .32902 .37391 .328 .37305 Mtetra
.535 .736 .968 r
.328 .37305 .32902 .37391 .33059 .37392 .32958 .37286 Mtetra
.586 .712 .93 r
.32958 .37286 .33059 .37392 .33217 .37378 .33117 .37259 Mtetra
.652 .707 .887 r
.33117 .37259 .33217 .37378 .33378 .37331 .33278 .37207 Mtetra
.653 .7 .881 r
.33278 .37207 .33378 .37331 .33539 .37276 .33439 .37155 Mtetra
.657 .705 .882 r
.33439 .37155 .33539 .37276 .337 .37211 .336 .371 Mtetra
.664 .728 .897 r
.336 .371 .337 .37211 .33862 .37136 .33761 .37044 Mtetra
.668 .766 .923 r
.33761 .37044 .33862 .37136 .34025 .37061 .33922 .36986 Mtetra
.67 .806 .948 r
.33922 .36986 .34025 .37061 .34187 .36993 .34084 .36926 Mtetra
.67 .827 .959 r
.34084 .36926 .34187 .36993 .34349 .36932 .34246 .36865 Mtetra
.671 .829 .959 r
.34246 .36865 .34349 .36932 .3451 .36872 .34408 .36804 Mtetra
.673 .824 .956 r
.34408 .36804 .3451 .36872 .34672 .36813 .3457 .36743 Mtetra
.672 .819 .954 r
.3457 .36743 .34672 .36813 .34834 .36752 .34732 .36681 Mtetra
.67 .817 .954 r
.34732 .36681 .34834 .36752 .34996 .36692 .34894 .36621 Mtetra
.722 .826 .929 r
.34894 .36621 .34996 .36692 .35159 .36618 .35057 .3654 Mtetra
.732 .811 .913 r
.35057 .3654 .35159 .36618 .35322 .3654 .35221 .36454 Mtetra
.613 .765 .953 r
.35221 .36454 .35322 .3654 .35484 .36494 .35382 .36414 Mtetra
.502 0 0 r
.35382 .36414 .35484 .36494 .35639 .36555 .35534 .36546 Mtetra
.931 .603 .394 r
.35534 .36546 .35639 .36555 .35784 .3684 .35648 .37421 Mtetra
.945 .675 .495 r
.35648 .37421 .35784 .3684 .3499 .55224 .34771 .5729 Mtetra
.575 .325 .5 r
.34771 .5729 .3499 .55224 .3507 .56968 .34928 .57536 Mtetra
.497 .202 .396 r
.34928 .57536 .3507 .56968 .3524 .56968 .351 .57512 Mtetra
.44 .148 .37 r
.351 .57512 .3524 .56968 .35417 .56827 .35275 .57423 Mtetra
.445 .159 .384 r
.35275 .57423 .35417 .56827 .35598 .56621 .35451 .57329 Mtetra
.481 .203 .414 r
.35451 .57329 .35598 .56621 .35777 .56448 .35625 .57265 Mtetra
.492 .22 .43 r
.35625 .57265 .35777 .56448 .35949 .56414 .35798 .57206 Mtetra
.501 .226 .43 r
.35798 .57206 .35949 .56414 .36106 .56698 .35972 .57166 Mtetra
.491 .182 .369 r
.35972 .57166 .36106 .56698 .36262 .57017 .36144 .57146 Mtetra
.343 0 .001 r
.36144 .57146 .36262 .57017 .36425 .57191 .36316 .57125 Mtetra
.554 .808 .993 r
.36316 .57125 .36425 .57191 .36594 .57238 .36489 .5709 Mtetra
.644 .674 .864 r
.36489 .5709 .36594 .57238 .36768 .57181 .36664 .57037 Mtetra
.656 .684 .865 r
.36664 .57037 .36768 .57181 .36944 .57098 .36838 .56978 Mtetra
.611 .709 .914 r
.36838 .56978 .36944 .57098 .37118 .5704 .37012 .56939 Mtetra
.534 .719 .958 r
.37012 .56939 .37118 .5704 .37291 .57028 .37185 .56922 Mtetra
.679 .757 .911 r
.37185 .56922 .37291 .57028 .37465 .56983 .3736 .56854 Mtetra
.842 .748 .76 r
.3736 .56854 .37465 .56983 .37645 .56826 .37543 .56615 Mtetra
.915 .696 .592 r
.37543 .56615 .37645 .56826 .37835 .56409 .37759 .55613 Mtetra
.948 .681 .497 r
.37759 .55613 .37835 .56409 .38077 .54792 .38794 .35588 Mtetra
.545 .323 .528 r
.38794 .35588 .38077 .54792 .39045 .35951 .38971 .35235 Mtetra
.591 .417 .615 r
.38971 .35235 .39045 .35951 .3921 .3588 .39137 .3515 Mtetra
.563 .395 .613 r
.39137 .3515 .3921 .3588 .39372 .35876 .393 .3512 Mtetra
.563 .394 .61 r
.393 .3512 .39372 .35876 .39543 .35683 .39464 .35086 Mtetra
.599 .435 .631 r
.39464 .35086 .39543 .35683 .3972 .35318 .3963 .35003 Mtetra
.64 .526 .708 r
.3963 .35003 .3972 .35318 .39893 .35065 .39796 .3492 Mtetra
.683 .68 .841 r
.39796 .3492 .39893 .35065 .40062 .34913 .39962 .34847 Mtetra
.652 .83 .969 r
.39962 .34847 .40062 .34913 .40227 .34857 .40127 .3479 Mtetra
.637 .824 .972 r
.40127 .3479 .40227 .34857 .40391 .34824 .40292 .34738 Mtetra
.684 .789 .93 r
.40292 .34738 .40391 .34824 .40556 .34777 .40457 .34672 Mtetra
.729 .761 .878 r
.40457 .34672 .40556 .34777 .40722 .34682 .40624 .34581 Mtetra
.646 .746 .922 r
.40624 .34581 .40722 .34682 .40888 .34614 .40789 .3453 Mtetra
0 .398 .83 r
.40789 .3453 .40888 .34614 .41051 .34628 .4095 .34605 Mtetra
.923 .558 .315 r
.4095 .34605 .41051 .34628 .41206 .3486 .41092 .35207 Mtetra
.954 .679 .478 r
.41092 .35207 .41206 .3486 .41342 .35669 .40542 .55394 Mtetra
.543 .316 .521 r
.40542 .55394 .41342 .35669 .40834 .55112 .40704 .55745 Mtetra
.51 .221 .411 r
.40704 .55745 .40834 .55112 .41009 .551 .4088 .55734 Mtetra
.465 .181 .397 r
.4088 .55734 .41009 .551 .41188 .54995 .41057 .55656 Mtetra
.464 .183 .401 r
.41057 .55656 .41188 .54995 .4136 .55067 .41236 .55572 Mtetra
.495 .191 .38 r
.41236 .55572 .4136 .55067 .41525 .55385 .41412 .55552 Mtetra
.388 0 .104 r
.41412 .55552 .41525 .55385 .41695 .55566 .41588 .5553 Mtetra
.381 .801 .974 r
.41588 .5553 .41695 .55566 .41868 .55649 .41765 .55509 Mtetra
.555 .652 .9 r
.41765 .55509 .41868 .55649 .42044 .55641 .41941 .55493 Mtetra
.662 .685 .861 r
.41941 .55493 .42044 .55641 .42222 .55576 .42119 .55429 Mtetra
.802 .727 .782 r
.42119 .55429 .42222 .55576 .42403 .55425 .42301 .55242 Mtetra
.91 .709 .62 r
.42301 .55242 .42403 .55425 .4259 .55058 .42499 .54538 Mtetra
.956 .685 .482 r
.42499 .54538 .4259 .55058 .42792 .54181 .43268 .34182 Mtetra
.547 .324 .529 r
.43268 .34182 .42792 .54181 .43526 .3447 .43447 .3371 Mtetra
.597 .418 .61 r
.43447 .3371 .43526 .3447 .43696 .34301 .43616 .33605 Mtetra
.568 .403 .617 r
.43616 .33605 .43696 .34301 .43863 .34288 .43782 .33566 Mtetra
.554 .39 .614 r
.43782 .33566 .43863 .34288 .44027 .34359 .43949 .33552 Mtetra
.569 .394 .605 r
.43949 .33552 .44027 .34359 .44192 .34411 .44116 .33502 Mtetra
.567 .387 .597 r
.44116 .33502 .44192 .34411 .4436 .34371 .44284 .3345 Mtetra
.571 .389 .596 r
.44284 .3345 .4436 .34371 .44533 .34104 .44451 .33387 Mtetra
.591 .417 .615 r
.44451 .33387 .44533 .34104 .4471 .33668 .4462 .33301 Mtetra
.632 .503 .688 r
.4462 .33301 .4471 .33668 .44884 .33381 .44789 .33213 Mtetra
.684 .654 .814 r
.44789 .33213 .44884 .33381 .45055 .33193 .44957 .33133 Mtetra
.653 .85 .976 r
.44957 .33133 .45055 .33193 .45224 .33114 .45126 .33072 Mtetra
.606 .88 .991 r
.45126 .33072 .45224 .33114 .45392 .33063 .45294 .33017 Mtetra
.607 .871 .992 r
.45294 .33017 .45392 .33063 .45559 .33022 .45462 .32963 Mtetra
.645 .851 .979 r
.45462 .32963 .45559 .33022 .45728 .32964 .4563 .32905 Mtetra
.646 .851 .978 r
.4563 .32905 .45728 .32964 .45896 .32905 .45799 .32846 Mtetra
.647 .85 .978 r
.45799 .32846 .45896 .32905 .46065 .32847 .45968 .32787 Mtetra
.646 .849 .978 r
.45968 .32787 .46065 .32847 .46234 .32788 .46137 .32728 Mtetra
.645 .849 .978 r
.46137 .32728 .46234 .32788 .46402 .3273 .46305 .3267 Mtetra
.644 .848 .978 r
.46305 .3267 .46402 .3273 .46571 .32672 .46474 .32612 Mtetra
.641 .848 .979 r
.46474 .32612 .46571 .32672 .4674 .32614 .46643 .32554 Mtetra
.46643 .32554 .4674 .32614 .46909 .32557 .46813 .32497 Mtetra
.641 .849 .979 r
.46813 .32497 .46909 .32557 .47079 .32499 .46982 .32439 Mtetra
.643 .851 .979 r
.46982 .32439 .47079 .32499 .47248 .32439 .47151 .32381 Mtetra
.645 .853 .98 r
.47151 .32381 .47248 .32439 .47417 .32379 .47321 .32322 Mtetra
.648 .856 .979 r
.47321 .32322 .47417 .32379 .47587 .32318 .47491 .32261 Mtetra
.663 .863 .975 r
.47491 .32261 .47587 .32318 .47757 .32239 .4766 .32196 Mtetra
.635 .888 .986 r
.4766 .32196 .47757 .32239 .47927 .32176 .4783 .32133 Mtetra
.609 .882 .991 r
.4783 .32133 .47927 .32176 .48096 .32145 .48 .32077 Mtetra
.572 .805 .987 r
.48 .32077 .48096 .32145 .48264 .32238 .4817 .3204 Mtetra
.6 .585 .807 r
.4817 .3204 .48264 .32238 .48431 .32422 .4834 .32008 Mtetra
.582 .458 .676 r
.4834 .32008 .48431 .32422 .48597 .32754 .4851 .31972 Mtetra
.595 .415 .609 r
.4851 .31972 .48597 .32754 .48768 .3267 .48681 .31866 Mtetra
.579 .402 .606 r
.48681 .31866 .48768 .3267 .48939 .32561 .48851 .31794 Mtetra
.545 .38 .609 r
.48851 .31794 .48939 .32561 .49109 .32591 .49021 .31796 Mtetra
.158 .1 .537 r
.49021 .31796 .49109 .32591 .49076 .52493 .49186 .32316 Mtetra
0 0 .319 r
.49186 .32316 .49076 .52493 .49252 .53073 .49154 .52673 Mtetra
0 0 .471 r
.49154 .52673 .49252 .53073 .49432 .53292 .49331 .53129 Mtetra
.487 .587 .88 r
.49331 .53129 .49432 .53292 .49614 .53279 .49513 .53142 Mtetra
.659 .706 .882 r
.49513 .53142 .49614 .53279 .49797 .53216 .49696 .5308 Mtetra
.722 .728 .855 r
.49696 .5308 .49797 .53216 .4998 .53127 .4988 .52979 Mtetra
.639 .68 .873 r
.4988 .52979 .4998 .53127 .50163 .53091 .50063 .52926 Mtetra
.642 .658 .85 r
.50063 .52926 .50163 .53091 .50346 .53039 .50246 .5287 Mtetra
.653 .657 .841 r
.50246 .5287 .50346 .53039 .5053 .52955 .50429 .52806 Mtetra
.607 .665 .88 r
.50429 .52806 .5053 .52955 .50714 .52778 .50613 .52769 Mtetra
.555 .923 .938 r
.50613 .52769 .50714 .52778 .50899 .52496 .50796 .52694 Mtetra
.053 0 0 r
.50796 .52694 .50899 .52496 .51084 .5195 .5098 .52541 Mtetra
0 0 .131 r
.5098 .52541 .51084 .5195 .51341 .31785 .51167 .51884 Mtetra
0 0 .316 r
.51167 .51884 .51341 .31785 .51515 .31185 .5142 .3139 Mtetra
.881 .858 .406 r
.5142 .3139 .51515 .31185 .51688 .30905 .51594 .3085 Mtetra
.813 .89 .899 r
.51594 .3085 .51688 .30905 .5186 .30814 .51766 .30718 Mtetra
.639 .764 .939 r
.51766 .30718 .5186 .30814 .52032 .30779 .51938 .30668 Mtetra
.533 .688 .938 r
.51938 .30668 .52032 .30779 .52205 .3077 .52111 .30654 Mtetra
.636 .723 .91 r
.52111 .30654 .52205 .3077 .52377 .30723 .52284 .30606 Mtetra
.649 .724 .903 r
.52284 .30606 .52377 .30723 .5255 .30666 .52456 .30552 Mtetra
.655 .732 .906 r
.52456 .30552 .5255 .30666 .52723 .30602 .52629 .30495 Mtetra
.685 .757 .906 r
.52629 .30495 .52723 .30602 .52895 .30505 .52802 .30425 Mtetra
.687 .818 .945 r
.52802 .30425 .52895 .30505 .53068 .30418 .52975 .30355 Mtetra
.663 .853 .972 r
.52975 .30355 .53068 .30418 .53241 .3036 .53148 .30289 Mtetra
.715 .846 .944 r
.53148 .30289 .53241 .3036 .53415 .30395 .53322 .30207 Mtetra
.634 .613 .812 r
.53322 .30207 .53415 .30395 .53589 .30527 .53495 .30154 Mtetra
.533 .44 .696 r
.53495 .30154 .53589 .30527 .53764 .30888 .53669 .3017 Mtetra
.226 .16 .569 r
.53669 .3017 .53764 .30888 .54031 .50868 .53844 .30589 Mtetra
0 0 .342 r
.53844 .30589 .54031 .50868 .5422 .51479 .54119 .51029 Mtetra
0 0 .46 r
.54119 .51029 .5422 .51479 .54407 .51692 .54307 .51557 Mtetra
.11 .417 .864 r
.54307 .51557 .54407 .51692 .54594 .5176 .54494 .51653 Mtetra
.592 .739 .946 r
.54494 .51653 .54594 .5176 .5478 .51736 .54681 .51616 Mtetra
.783 .772 .843 r
.54681 .51616 .5478 .51736 .54966 .51617 .54867 .51473 Mtetra
.915 .747 .659 r
.54867 .51473 .54966 .51617 .55149 .51133 .5505 .50988 Mtetra
.97 .689 .439 r
.5505 .50988 .55149 .51133 .55159 .30455 .55067 .30402 Mtetra
.973 .772 .573 r
.55067 .30402 .55159 .30455 .55327 .29692 .55235 .29625 Mtetra
.86 .865 .842 r
.55235 .29625 .55327 .29692 .55501 .29526 .55409 .29449 Mtetra
.651 .816 .963 r
.55409 .29449 .55501 .29526 .55676 .29481 .55584 .2939 Mtetra
.516 .729 .97 r
.55584 .2939 .55676 .29481 .55851 .29483 .55759 .29375 Mtetra
.642 .742 .921 r
.55759 .29375 .55851 .29483 .56026 .29425 .55934 .29323 Mtetra
.669 .765 .922 r
.55934 .29323 .56026 .29425 .56201 .29355 .56109 .2926 Mtetra
.658 .776 .936 r
.56109 .2926 .56201 .29355 .56376 .29308 .56284 .29201 Mtetra
.707 .765 .897 r
.56284 .29201 .56376 .29308 .56552 .29332 .56459 .29119 Mtetra
.639 .593 .786 r
.56459 .29119 .56552 .29332 .5673 .29443 .56634 .29058 Mtetra
.548 .446 .691 r
.56634 .29058 .5673 .29443 .56911 .2974 .56811 .2906 Mtetra
.295 .214 .592 r
.56811 .2906 .56911 .2974 .57381 .49637 .56992 .29395 Mtetra
0 0 .355 r
.56992 .29395 .57381 .49637 .5758 .50388 .57476 .49842 Mtetra
0 0 .451 r
.57476 .49842 .5758 .50388 .57773 .50628 .57675 .50477 Mtetra
.033 .334 .816 r
.57675 .50477 .57773 .50628 .57964 .50709 .57866 .50604 Mtetra
.547 .727 .958 r
.57866 .50604 .57964 .50709 .58153 .50697 .58055 .50581 Mtetra
.767 .78 .864 r
.58055 .50581 .58153 .50697 .58341 .50594 .58243 .50453 Mtetra
.908 .756 .681 r
.58243 .50453 .58341 .50594 .58523 .50203 .58425 .50036 Mtetra
.972 .687 .427 r
.58425 .50036 .58523 .50203 .58334 .29974 .58238 .2962 Mtetra
.901 .662 .567 r
.58238 .2962 .58334 .29974 .58488 .28705 .58397 .28582 Mtetra
.849 .77 .775 r
.58397 .28582 .58488 .28705 .58661 .2848 .5857 .28366 Mtetra
.678 .745 .902 r
.5857 .28366 .58661 .2848 .58838 .2841 .58747 .28297 Mtetra
.557 .7 .936 r
.58747 .28297 .58838 .2841 .59015 .28389 .58925 .28276 Mtetra
.704 .757 .893 r
.58925 .28276 .59015 .28389 .59192 .28307 .59101 .28195 Mtetra
.719 .763 .887 r
.59101 .28195 .59192 .28307 .59368 .28216 .59278 .28105 Mtetra
.583 .715 .934 r
.59278 .28105 .59368 .28216 .59546 .28185 .59455 .28075 Mtetra
.607 .14 0 r
.59455 .28075 .59546 .28185 .5973 .28429 .5964 .28321 Mtetra
.973 .68 .404 r
.5964 .28321 .5973 .28429 .60395 .48756 .60299 .48661 Mtetra
.941 .573 .22 r
.60299 .48661 .60395 .48756 .60608 .49671 .60512 .49564 Mtetra
0 .285 .77 r
.60512 .49564 .60608 .49671 .60803 .49809 .60706 .4969 Mtetra
.617 .73 .927 r
.60706 .4969 .60803 .49809 .60994 .49771 .60897 .49645 Mtetra
.726 .755 .875 r
.60897 .49645 .60994 .49771 .61183 .49658 .61086 .49543 Mtetra
.656 .751 .92 r
.61086 .49543 .61183 .49658 .61371 .49496 .61277 .4948 Mtetra
.45 .871 .937 r
.61277 .4948 .61371 .49496 .61557 .49264 .61468 .49425 Mtetra
.112 0 0 r
.61468 .49425 .61557 .49264 .61738 .48872 .61657 .49309 Mtetra
.006 0 .195 r
.61657 .49309 .61738 .48872 .61375 .29381 .61839 .48911 Mtetra
0 0 .352 r
.61839 .48911 .61375 .29381 .61513 .27924 .61443 .28487 Mtetra
0 0 0 r
.61443 .28487 .61513 .27924 .61683 .27557 .61595 .27505 Mtetra
.916 .887 .789 r
.61595 .27505 .61683 .27557 .61859 .27395 .61768 .27267 Mtetra
.689 .727 .879 r
.61768 .27267 .61859 .27395 .62037 .27324 .61947 .27191 Mtetra
.591 .677 .9 r
.61947 .27191 .62037 .27324 .62216 .27284 .62127 .27161 Mtetra
.691 .736 .885 r
.62127 .27161 .62216 .27284 .62395 .272 .62305 .27084 Mtetra
.729 .762 .879 r
.62305 .27084 .62395 .272 .62572 .27102 .62483 .26987 Mtetra
.614 .722 .923 r
.62483 .26987 .62572 .27102 .62752 .27059 .62663 .26945 Mtetra
0 .061 .595 r
.62663 .26945 .62752 .27059 .6294 .27248 .62851 .27134 Mtetra
.974 .678 .39 r
.62851 .27134 .6294 .27248 .63805 .47147 .63711 .47035 Mtetra
.956 .611 .266 r
.63711 .47035 .63805 .47147 .64047 .48546 .63953 .48435 Mtetra
0 .136 .652 r
.63953 .48435 .64047 .48546 .64248 .48728 .64153 .48607 Mtetra
.597 .721 .931 r
.64153 .48607 .64248 .48728 .64442 .48699 .64347 .48569 Mtetra
.719 .75 .877 r
.64347 .48569 .64442 .48699 .64633 .48592 .64538 .4847 Mtetra
.673 .749 .908 r
.64538 .4847 .64633 .48592 .64823 .48431 .64731 .48399 Mtetra
.49 .871 .976 r
.64731 .48399 .64823 .48431 .65009 .48204 .64924 .48349 Mtetra
.098 0 0 r
.64924 .48349 .65009 .48204 .6519 .47823 .65116 .48239 Mtetra
.059 0 .211 r
.65116 .48239 .6519 .47823 .65281 .45149 .65298 .47883 Mtetra
.981 .704 .322 r
.65298 .47883 .65281 .45149 .64748 .26826 .64695 .27607 Mtetra
0 0 .12 r
.64695 .27607 .64748 .26826 .64916 .26443 .64831 .26406 Mtetra
.941 .907 .759 r
.64831 .26406 .64916 .26443 .65092 .26263 .65003 .26136 Mtetra
.701 .734 .876 r
.65003 .26136 .65092 .26263 .65272 .26187 .65183 .26052 Mtetra
.603 .681 .896 r
.65183 .26052 .65272 .26187 .65453 .26142 .65365 .26016 Mtetra
.674 .727 .89 r
.65365 .26016 .65453 .26142 .65634 .26065 .65546 .25947 Mtetra
.736 .764 .876 r
.65546 .25947 .65634 .26065 .65813 .25962 .65725 .25845 Mtetra
.64 .732 .915 r
.65725 .25845 .65813 .25962 .65995 .25908 .65907 .25793 Mtetra
0 .286 .782 r
.65907 .25793 .65995 .25908 .66185 .26038 .66097 .25924 Mtetra
.937 .572 .184 r
.66097 .25924 .66185 .26038 .66412 .26996 .66325 .26896 Mtetra
.975 .675 .374 r
.66325 .26896 .66412 .26996 .67525 .47337 .67432 .47229 Mtetra
0 0 .501 r
.67432 .47229 .67525 .47337 .67733 .47567 .6764 .47457 Mtetra
.628 .757 .94 r
.6764 .47457 .67733 .47567 .67929 .47515 .67836 .47404 Mtetra
.768 .801 .88 r
.67836 .47404 .67929 .47515 .68121 .47389 .68028 .47278 Mtetra
.778 .802 .872 r
.68028 .47278 .68121 .47389 .68313 .47256 .6822 .47144 Mtetra
.72 .785 .903 r
.6822 .47144 .68313 .47256 .68506 .47162 .68413 .47047 Mtetra
.705 .775 .907 r
.68413 .47047 .68506 .47162 .68701 .47076 .68608 .46958 Mtetra
.652 .752 .923 r
.68608 .46958 .68701 .47076 .68896 .47014 .68803 .46895 Mtetra
.577 .719 .94 r
.68803 .46895 .68896 .47014 .69093 .4698 .69 .46863 Mtetra
.551 .711 .946 r
.69 .46863 .69093 .4698 .69291 .46955 .69198 .4684 Mtetra
.459 .669 .954 r
.69198 .4684 .69291 .46955 .6949 .46959 .69398 .46845 Mtetra
.423 .653 .955 r
.69398 .46845 .6949 .46959 .6969 .46972 .69598 .46859 Mtetra
.63 .753 .936 r
.69598 .46859 .6969 .46972 .69887 .46918 .69795 .46805 Mtetra
.889 .811 .765 r
.69795 .46805 .69887 .46918 .70073 .46651 .69981 .46538 Mtetra
.981 .724 .469 r
.69981 .46538 .70073 .46651 .7018 .44949 .70088 .44823 Mtetra
.977 .681 .379 r
.70088 .44823 .7018 .44949 .69291 .2504 .69204 .24922 Mtetra
.912 .79 .713 r
.69204 .24922 .69291 .2504 .6946 .24716 .69374 .24598 Mtetra
.708 .758 .891 r
.69374 .24598 .6946 .24716 .69642 .24629 .69556 .24511 Mtetra
.587 .708 .927 r
.69556 .24511 .69642 .24629 .69828 .24597 .69741 .24479 Mtetra
.622 .724 .92 r
.69741 .24479 .69828 .24597 .70012 .24551 .69926 .24433 Mtetra
.731 .766 .88 r
.69926 .24433 .70012 .24551 .70194 .24451 .70108 .24333 Mtetra
.639 .731 .915 r
.70108 .24333 .70194 .24451 .70379 .24398 .70293 .2428 Mtetra
.06 .396 .854 r
.70293 .2428 .70379 .24398 .70573 .24502 .70487 .24384 Mtetra
.926 .555 .143 r
.70487 .24384 .70573 .24502 .70818 .25455 .70732 .25337 Mtetra
.975 .671 .352 r
.70732 .25337 .70818 .25455 .72238 .45915 .72147 .45802 Mtetra
.6 .137 0 r
.72147 .45802 .72238 .45915 .72458 .4621 .72367 .46097 Mtetra
.419 .653 .956 r
.72367 .46097 .72458 .4621 .72661 .46225 .7257 .46112 Mtetra
.71 .786 .911 r
.7257 .46112 .72661 .46225 .72857 .46133 .72767 .4602 Mtetra
.888 .816 .772 r
.72767 .4602 .72857 .46133 .73044 .45872 .72953 .45759 Mtetra
.977 .758 .541 r
.72953 .45759 .73044 .45872 .7319 .44985 .731 .44872 Mtetra
.977 .679 .365 r
.731 .44872 .7319 .44985 .72065 .24212 .7198 .24094 Mtetra
.937 .787 .669 r
.7198 .24094 .72065 .24212 .72229 .23805 .72144 .23686 Mtetra
.721 .763 .886 r
.72144 .23686 .72229 .23805 .72412 .23711 .72327 .23592 Mtetra
.581 .706 .928 r
.72327 .23592 .72412 .23711 .726 .23681 .72515 .23562 Mtetra
.542 .687 .934 r
.72515 .23562 .726 .23681 .72789 .23664 .72704 .23545 Mtetra
.658 .74 .91 r
.72704 .23545 .72789 .23664 .72975 .23602 .7289 .23483 Mtetra
.664 .742 .908 r
.7289 .23483 .72975 .23602 .7316 .23537 .73076 .23418 Mtetra
.702 .757 .894 r
.73076 .23418 .7316 .23537 .73345 .23453 .73261 .23334 Mtetra
.757 .775 .867 r
.73261 .23334 .73345 .23453 .73528 .23336 .73443 .23216 Mtetra
.674 .746 .905 r
.73443 .23216 .73528 .23336 .73713 .23266 .73629 .23147 Mtetra
.241 .515 .909 r
.73629 .23147 .73713 .23266 .73909 .23332 .73825 .23213 Mtetra
.896 .511 .065 r
.73825 .23213 .73909 .23332 .74157 .24131 .74072 .24012 Mtetra
.975 .667 .334 r
.74072 .24012 .74157 .24131 .7582 .44762 .75731 .44648 Mtetra
.634 .179 0 r
.75731 .44648 .7582 .44762 .76049 .45095 .7596 .44981 Mtetra
.392 .636 .953 r
.7596 .44981 .76049 .45095 .76256 .45118 .76167 .45004 Mtetra
.695 .781 .917 r
.76167 .45004 .76256 .45118 .76456 .45033 .76367 .44919 Mtetra
.873 .82 .793 r
.76367 .44919 .76456 .45033 .76644 .44799 .76555 .44684 Mtetra
.978 .767 .552 r
.76555 .44684 .76644 .44799 .76791 .4401 .76703 .43895 Mtetra
.977 .675 .347 r
.76703 .43895 .76791 .4401 .75426 .23093 .75342 .22973 Mtetra
.951 .785 .641 r
.75342 .22973 .75426 .23093 .75583 .22628 .75499 .22507 Mtetra
.748 .772 .873 r
.75499 .22507 .75583 .22628 .75767 .22516 .75683 .22396 Mtetra
.622 .724 .919 r
.75683 .22396 .75767 .22516 .75956 .22469 .75873 .22349 Mtetra
.591 .71 .926 r
.75873 .22349 .75956 .22469 .76146 .22435 .76063 .22314 Mtetra
.75 .773 .872 r
.76063 .22314 .76146 .22435 .7633 .22322 .76247 .22201 Mtetra
.676 .746 .904 r
.76247 .22201 .7633 .22322 .76518 .22251 .76435 .2213 Mtetra
.378 .596 .931 r
.76435 .2213 .76518 .22251 .76714 .22284 .76631 .22163 Mtetra
.806 .393 0 r
.76631 .22163 .76714 .22284 .76951 .22829 .76868 .22708 Mtetra
.973 .663 .318 r
.76868 .22708 .76951 .22829 .7883 .43673 .78742 .43557 Mtetra
.715 .274 0 r
.78742 .43557 .7883 .43673 .79072 .44093 .78984 .43978 Mtetra
.503 .695 .955 r
.78984 .43978 .79072 .44093 .79279 .44084 .79191 .43968 Mtetra
.695 .781 .917 r
.79191 .43968 .79279 .44084 .7948 .43999 .79393 .43883 Mtetra
.735 .794 .9 r
.79393 .43883 .7948 .43999 .7968 .43891 .79592 .43775 Mtetra
.497 .691 .954 r
.79592 .43775 .7968 .43891 .79888 .43884 .798 .43767 Mtetra
.625 .752 .938 r
.798 .43767 .79888 .43884 .80092 .4383 .80005 .43714 Mtetra
.811 .815 .853 r
.80005 .43714 .80092 .4383 .80287 .43667 .802 .4355 Mtetra
.98 .772 .552 r
.802 .4355 .80287 .43667 .80431 .4291 .80345 .42793 Mtetra
.976 .671 .329 r
.80345 .42793 .80431 .4291 .78825 .21943 .78743 .21821 Mtetra
.959 .784 .623 r
.78743 .21821 .78825 .21943 .78977 .21443 .78895 .21321 Mtetra
.751 .774 .872 r
.78895 .21321 .78977 .21443 .79163 .21328 .79081 .21206 Mtetra
.622 .723 .919 r
.79081 .21206 .79163 .21328 .79354 .2128 .79272 .21158 Mtetra
.553 .69 .93 r
.79272 .21158 .79354 .2128 .79548 .2126 .79466 .21138 Mtetra
.746 .773 .874 r
.79466 .21138 .79548 .2126 .79734 .21148 .79653 .21026 Mtetra
.677 .747 .903 r
.79653 .21026 .79734 .21148 .79924 .21076 .79842 .20953 Mtetra
.456 .638 .935 r
.79842 .20953 .79924 .21076 .80121 .21087 .8004 .20965 Mtetra
.768 .353 0 r
.8004 .20965 .80121 .21087 .80366 .21607 .80284 .21485 Mtetra
.971 .657 .298 r
.80284 .21485 .80366 .21607 .82496 .42532 .8241 .42414 Mtetra
.726 .292 0 r
.8241 .42414 .82496 .42532 .8275 .42995 .82664 .42878 Mtetra
.306 .58 .938 r
.82664 .42878 .8275 .42995 .82966 .43044 .8288 .42927 Mtetra
.649 .764 .933 r
.8288 .42927 .82966 .43044 .83172 .42979 .83086 .42862 Mtetra
.829 .821 .841 r
.83086 .42862 .83172 .42979 .83367 .42798 .83281 .42681 Mtetra
.975 .789 .59 r
.83281 .42681 .83367 .42798 .8352 .42188 .83435 .42071 Mtetra
.974 .667 .312 r
.83435 .42071 .8352 .42188 .81704 .21127 .81623 .21005 Mtetra
.975 .775 .571 r
.81623 .21005 .81704 .21127 .81841 .20495 .81761 .20372 Mtetra
.76 .758 .851 r
.20139 .41663 .20245 .41761 .20403 .41653 .20298 .41555 Mtetra
.612 .728 .928 r
.20298 .41555 .20403 .41653 .20555 .41618 .20449 .4152 Mtetra
.455 .669 .955 r
.20449 .4152 .20555 .41618 .20702 .41622 .20597 .41524 Mtetra
.655 .741 .913 r
.20597 .41524 .20702 .41622 .20856 .41572 .2075 .41474 Mtetra
.664 .743 .909 r
.2075 .41474 .20856 .41572 .21009 .41518 .20904 .4142 Mtetra
.67 .745 .907 r
.20904 .4142 .21009 .41518 .21163 .41462 .21058 .41364 Mtetra
.763 .76 .85 r
.21058 .41364 .21163 .41462 .21322 .41352 .21217 .41254 Mtetra
.709 .753 .887 r
.21217 .41254 .21322 .41352 .21478 .41277 .21373 .41179 Mtetra
.492 .686 .953 r
.21373 .41179 .21478 .41277 .21627 .41273 .21522 .41175 Mtetra
.932 .563 .281 r
.21522 .41175 .21627 .41273 .21734 .41714 .21629 .41618 Mtetra
.939 .683 .523 r
.21629 .41618 .21734 .41714 .20001 .61644 .19888 .61553 Mtetra
.931 .569 .308 r
.19888 .61553 .20001 .61644 .20113 .62145 .19999 .62052 Mtetra
0 .384 .821 r
.19999 .62052 .20113 .62145 .20265 .62219 .20151 .62126 Mtetra
.626 .758 .942 r
.20151 .62126 .20265 .62219 .20428 .62175 .20315 .62082 Mtetra
.802 .781 .834 r
.20315 .62082 .20428 .62175 .20601 .62028 .20488 .61934 Mtetra
.906 .743 .669 r
.20488 .61934 .20601 .62028 .20807 .61522 .20694 .61429 Mtetra
.939 .687 .53 r
.20694 .61429 .20807 .61522 .22802 .41505 .22696 .41405 Mtetra
.914 .725 .632 r
.22696 .41405 .22802 .41505 .23014 .40823 .22909 .40723 Mtetra
.793 .76 .822 r
.22909 .40723 .23014 .40823 .23176 .40684 .23072 .40583 Mtetra
.637 .731 .916 r
.23072 .40583 .23176 .40684 .2333 .40642 .23226 .4054 Mtetra
.491 .677 .947 r
.23226 .4054 .2333 .40642 .23481 .40641 .23376 .40537 Mtetra
.672 .736 .898 r
.23376 .40537 .23481 .40641 .23635 .40595 .23532 .40479 Mtetra
.672 .713 .879 r
.23532 .40479 .23635 .40595 .2379 .4054 .23688 .4042 Mtetra
.631 .692 .888 r
.23688 .4042 .2379 .4054 .23946 .40485 .23842 .40379 Mtetra
.523 .682 .938 r
.23842 .40379 .23946 .40485 .24105 .40388 .23993 .4037 Mtetra
.302 0 0 r
.23993 .4037 .24105 .40388 .24262 .40315 .2414 .40415 Mtetra
.719 .308 .267 r
.2414 .40415 .24262 .40315 .24414 .40304 .24277 .40574 Mtetra
.937 .678 .52 r
.24277 .40574 .24414 .40304 .24536 .40637 .22773 .59624 Mtetra
.561 .332 .525 r
.22773 .59624 .24536 .40637 .22979 .60478 .22824 .60886 Mtetra
.693 .378 .438 r
.22824 .60886 .22979 .60478 .23084 .61124 .2296 .61168 Mtetra
.506 0 0 r
.2296 .61168 .23084 .61124 .23237 .61229 .23117 .61221 Mtetra
.416 .853 .932 r
.23117 .61221 .23237 .61229 .23401 .61192 .23282 .6118 Mtetra
.787 .948 .926 r
.23282 .6118 .23401 .61192 .23575 .61046 .23454 .61059 Mtetra
.946 .878 .737 r
.23454 .61059 .23575 .61046 .23779 .60536 .23643 .6073 Mtetra
.994 .83 .572 r
.23643 .6073 .23779 .60536 .2561 .40489 .23881 .59824 Mtetra
0 0 .153 r
.23881 .59824 .2561 .40489 .25816 .39844 .25679 .40147 Mtetra
0 0 .056 r
.25679 .40147 .25816 .39844 .25981 .39681 .25849 .39929 Mtetra
.401 .036 .227 r
.25849 .39929 .25981 .39681 .26138 .39626 .26005 .39886 Mtetra
.468 .109 .273 r
.26005 .39886 .26138 .39626 .26291 .39612 .26158 .39875 Mtetra
.054 0 .056 r
.26158 .39875 .26291 .39612 .26447 .39572 .26325 .39703 Mtetra
.59 .859 .52 r
.26325 .39703 .26447 .39572 .26603 .39523 .26493 .3951 Mtetra
.858 .928 .872 r
.26493 .3951 .26603 .39523 .2676 .39475 .26658 .39355 Mtetra
.703 .716 .859 r
.26658 .39355 .2676 .39475 .26917 .39425 .26817 .39277 Mtetra
.627 .648 .851 r
.26817 .39277 .26917 .39425 .27073 .39374 .26973 .39237 Mtetra
.6 .654 .875 r
.26973 .39237 .27073 .39374 .27231 .3932 .27128 .39208 Mtetra
.642 .713 .9 r
.27128 .39208 .27231 .3932 .27389 .39256 .27285 .39162 Mtetra
.669 .756 .916 r
.27285 .39162 .27389 .39256 .27547 .39191 .27443 .39105 Mtetra
.681 .777 .923 r
.27443 .39105 .27547 .39191 .27705 .39132 .27601 .39043 Mtetra
.749 .784 .881 r
.27601 .39043 .27705 .39132 .27864 .39059 .27762 .38947 Mtetra
.723 .735 .861 r
.27762 .38947 .27864 .39059 .28021 .39008 .27922 .38859 Mtetra
.629 .648 .85 r
.27922 .38859 .28021 .39008 .28174 .39017 .28079 .38817 Mtetra
.038 .239 .74 r
.28079 .38817 .28174 .39017 .28304 .39335 .28222 .38954 Mtetra
.713 .459 0 r
.28222 .38954 .28304 .39335 .26969 .59264 .28335 .39497 Mtetra
0 0 .195 r
.28335 .39497 .26969 .59264 .27085 .59907 .27012 .59304 Mtetra
.153 .117 .56 r
.27012 .59304 .27085 .59907 .27242 .60012 .27151 .59653 Mtetra
.394 .357 .699 r
.27151 .59653 .27242 .60012 .27409 .59975 .27307 .59756 Mtetra
.478 .504 .806 r
.27307 .59756 .27409 .59975 .2758 .59886 .2747 .59785 Mtetra
.439 .672 .962 r
.2747 .59785 .2758 .59886 .27749 .5983 .27634 .59791 Mtetra
.475 .833 .995 r
.27634 .59791 .27749 .5983 .27918 .5977 .27801 .5976 Mtetra
.689 .952 .954 r
.27801 .5976 .27918 .5977 .28092 .59643 .27973 .59669 Mtetra
.935 .935 .774 r
.27973 .59669 .28092 .59643 .28289 .59198 .28157 .59402 Mtetra
.992 .88 .561 r
.28157 .59402 .28289 .59198 .29867 .39113 .2837 .58724 Mtetra
0 0 .185 r
.2837 .58724 .29867 .39113 .30074 .38387 .29938 .38764 Mtetra
0 0 0 r
.29938 .38764 .30074 .38387 .30245 .38153 .30127 .38285 Mtetra
.635 .875 .523 r
.30127 .38285 .30245 .38153 .30407 .38062 .30297 .38074 Mtetra
.698 .977 .912 r
.30297 .38074 .30407 .38062 .30562 .38059 .30459 .37972 Mtetra
0 .351 .798 r
.30459 .37972 .30562 .38059 .30703 .38276 .30609 .3805 Mtetra
.796 .44 0 r
.30609 .3805 .30703 .38276 .29555 .57592 .30739 .38442 Mtetra
0 0 .192 r
.30739 .38442 .29555 .57592 .29624 .59042 .29556 .58319 Mtetra
.056 .028 .505 r
.29556 .58319 .29624 .59042 .29779 .59202 .29689 .58813 Mtetra
.374 .332 .682 r
.29689 .58813 .29779 .59202 .29948 .59168 .29847 .58938 Mtetra
.464 .486 .796 r
.29847 .58938 .29948 .59168 .3012 .59079 .30011 .58975 Mtetra
.464 .679 .958 r
.30011 .58975 .3012 .59079 .3029 .5904 .30178 .58976 Mtetra
.564 .813 .992 r
.30178 .58976 .3029 .5904 .30458 .59022 .30347 .5894 Mtetra
.741 .812 .907 r
.30347 .5894 .30458 .59022 .3063 .58943 .3052 .58844 Mtetra
.864 .775 .761 r
.3052 .58844 .3063 .58943 .30818 .58608 .30704 .58591 Mtetra
.955 .786 .634 r
.30704 .58591 .30818 .58608 .32224 .38962 .30911 .57957 Mtetra
0 0 .182 r
.30911 .57957 .32224 .38962 .32466 .37622 .32333 .38015 Mtetra
0 0 0 r
.32333 .38015 .32466 .37622 .32639 .37373 .32521 .37527 Mtetra
.32521 .37527 .32639 .37373 .328 .37305 .32691 .37321 Mtetra
.792 .991 .882 r
.32691 .37321 .328 .37305 .32958 .37286 .32857 .37186 Mtetra
.741 .766 .872 r
.32857 .37186 .32958 .37286 .33117 .37259 .3302 .3709 Mtetra
.667 .64 .814 r
.3302 .3709 .33117 .37259 .33278 .37207 .33182 .37023 Mtetra
.614 .6 .813 r
.33182 .37023 .33278 .37207 .33439 .37155 .33342 .36986 Mtetra
.5 .562 .85 r
.33342 .36986 .33439 .37155 .336 .371 .33499 .36998 Mtetra
.078 .452 .882 r
.33499 .36998 .336 .371 .33761 .37044 .33653 .37064 Mtetra
.636 .104 0 r
.33653 .37064 .33761 .37044 .33922 .36986 .33805 .37167 Mtetra
.56 .162 .244 r
.33805 .37167 .33922 .36986 .34084 .36926 .3396 .37222 Mtetra
.418 .074 .273 r
.3396 .37222 .34084 .36926 .34246 .36865 .34121 .37173 Mtetra
.357 .022 .252 r
.34121 .37173 .34246 .36865 .34408 .36804 .34285 .37087 Mtetra
.348 .003 .23 r
.34285 .37087 .34408 .36804 .3457 .36743 .34448 .37005 Mtetra
.366 .01 .222 r
.34448 .37005 .3457 .36743 .34732 .36681 .34611 .36939 Mtetra
.365 .007 .218 r
.34611 .36939 .34732 .36681 .34894 .36621 .34773 .36874 Mtetra
.283 0 .173 r
.34773 .36874 .34894 .36621 .35057 .3654 .34938 .36776 Mtetra
.242 0 .134 r
.34938 .36776 .35057 .3654 .35221 .36454 .35103 .36671 Mtetra
.409 .028 .201 r
.35103 .36671 .35221 .36454 .35382 .36414 .35264 .3664 Mtetra
.747 .396 .386 r
.35264 .3664 .35382 .36414 .35534 .36546 .35408 .36928 Mtetra
.947 .678 .494 r
.35408 .36928 .35534 .36546 .35648 .37421 .34511 .56859 Mtetra
.546 .319 .522 r
.34511 .56859 .35648 .37421 .34771 .5729 .34652 .57413 Mtetra
.673 .246 .226 r
.34652 .57413 .34771 .5729 .34928 .57536 .34815 .57551 Mtetra
.183 .716 .753 r
.34815 .57551 .34928 .57536 .351 .57512 .34987 .57518 Mtetra
.558 .931 .915 r
.34987 .57518 .351 .57512 .35275 .57423 .35162 .57439 Mtetra
.512 .914 .871 r
.35162 .57439 .35275 .57423 .35451 .57329 .35337 .5736 Mtetra
.263 .763 .721 r
.35337 .5736 .35451 .57329 .35625 .57265 .35511 .57303 Mtetra
.223 .73 .672 r
.35511 .57303 .35625 .57265 .35798 .57206 .35685 .57245 Mtetra
0 0 0 r
.35685 .57245 .35798 .57206 .35972 .57166 .35859 .57188 Mtetra
.316 .804 .783 r
.35859 .57188 .35972 .57166 .36144 .57146 .36033 .57132 Mtetra
.513 .895 .959 r
.36033 .57132 .36144 .57146 .36316 .57125 .36207 .57076 Mtetra
.58 .856 .995 r
.36207 .57076 .36316 .57125 .36489 .5709 .36381 .57028 Mtetra
.577 .824 .992 r
.36381 .57028 .36489 .5709 .36664 .57037 .36555 .56986 Mtetra
.622 .866 .988 r
.36555 .56986 .36664 .57037 .36838 .56978 .36729 .56929 Mtetra
.723 .889 .956 r
.36729 .56929 .36838 .56978 .37012 .56939 .36905 .56839 Mtetra
.794 .787 .846 r
.36905 .56839 .37012 .56939 .37185 .56922 .37084 .56695 Mtetra
.779 .651 .721 r
.37084 .56695 .37185 .56922 .3736 .56854 .37267 .56467 Mtetra
.817 .617 .631 r
.37267 .56467 .3736 .56854 .37543 .56615 .37464 .5591 Mtetra
.949 .682 .497 r
.37464 .5591 .37543 .56615 .37759 .55613 .38519 .35806 Mtetra
.548 .325 .529 r
.38519 .35806 .37759 .55613 .38794 .35588 .38705 .35254 Mtetra
.734 .575 .676 r
.38705 .35254 .38794 .35588 .38971 .35235 .38877 .35024 Mtetra
.666 .601 .773 r
.38877 .35024 .38971 .35235 .39137 .3515 .39042 .34945 Mtetra
.61 .579 .793 r
.39042 .34945 .39137 .3515 .393 .3512 .39206 .34907 Mtetra
.598 .566 .789 r
.39206 .34907 .393 .3512 .39464 .35086 .3937 .34876 Mtetra
.633 .586 .783 r
.3937 .34876 .39464 .35086 .3963 .35003 .39534 .34823 Mtetra
.64 .619 .813 r
.39534 .34823 .3963 .35003 .39796 .3492 .39699 .34769 Mtetra
.657 .663 .844 r
.39699 .34769 .39796 .3492 .39962 .34847 .39864 .34711 Mtetra
.677 .691 .856 r
.39864 .34711 .39962 .34847 .40127 .3479 .4003 .34643 Mtetra
.651 .666 .852 r
.4003 .34643 .40127 .3479 .40292 .34738 .40195 .34588 Mtetra
.598 .64 .864 r
.40195 .34588 .40292 .34738 .40457 .34672 .40359 .34559 Mtetra
.43 .631 .939 r
.40359 .34559 .40457 .34672 .40624 .34581 .40522 .34573 Mtetra
.508 0 0 r
.40522 .34573 .40624 .34581 .40789 .3453 .40682 .34656 Mtetra
.796 .412 .327 r
.40682 .34656 .40789 .3453 .4095 .34605 .40834 .34961 Mtetra
.953 .679 .478 r
.40834 .34961 .4095 .34605 .41092 .35207 .40273 .5498 Mtetra
.547 .32 .522 r
.40273 .5498 .41092 .35207 .40542 .55394 .40426 .55596 Mtetra
.685 .302 .316 r
.40426 .55596 .40542 .55394 .40704 .55745 .40594 .55777 Mtetra
.108 0 0 r
.40594 .55777 .40704 .55745 .4088 .55734 .4077 .55767 Mtetra
.247 .75 .699 r
.4077 .55767 .4088 .55734 .41057 .55656 .40947 .55708 Mtetra
0 0 0 r
.40947 .55708 .41057 .55656 .41236 .55572 .41125 .55633 Mtetra
.41125 .55633 .41236 .55572 .41412 .55552 .41303 .5558 Mtetra
.367 .832 .774 r
.41303 .5558 .41412 .55552 .41588 .5553 .41481 .55509 Mtetra
.703 .946 .958 r
.41481 .55509 .41588 .5553 .41765 .55509 .4166 .55413 Mtetra
.788 .801 .864 r
.4166 .55413 .41765 .55509 .41941 .55493 .4184 .55279 Mtetra
.772 .658 .737 r
.4184 .55279 .41941 .55493 .42119 .55429 .42023 .55076 Mtetra
.795 .611 .652 r
.42023 .55076 .42119 .55429 .42301 .55242 .42211 .54668 Mtetra
.955 .684 .483 r
.42211 .54668 .42301 .55242 .42499 .54538 .42991 .34537 Mtetra
.552 .328 .529 r
.42991 .34537 .42499 .54538 .43268 .34182 .43179 .33777 Mtetra
.735 .558 .653 r
.43179 .33777 .43268 .34182 .43447 .3371 .43353 .33493 Mtetra
.677 .603 .766 r
.43353 .33493 .43447 .3371 .43616 .33605 .43521 .33403 Mtetra
.619 .588 .797 r
.43521 .33403 .43616 .33605 .43782 .33566 .43688 .3336 Mtetra
.592 .57 .798 r
.43688 .3336 .43782 .33566 .43949 .33552 .43855 .33332 Mtetra
.634 .579 .776 r
.43855 .33332 .43949 .33552 .44116 .33502 .44022 .33275 Mtetra
.629 .571 .771 r
.44022 .33275 .44116 .33502 .44284 .3345 .4419 .33221 Mtetra
.624 .567 .77 r
.4419 .33221 .44284 .3345 .44451 .33387 .44357 .33171 Mtetra
.615 .573 .783 r
.44357 .33171 .44451 .33387 .4462 .33301 .44525 .33128 Mtetra
.621 .62 .829 r
.44525 .33128 .4462 .33301 .44789 .33213 .44692 .33085 Mtetra
.631 .692 .889 r
.44692 .33085 .44789 .33213 .44957 .33133 .4486 .33041 Mtetra
.649 .771 .938 r
.4486 .33041 .44957 .33133 .45126 .33072 .45028 .32987 Mtetra
.66 .791 .944 r
.45028 .32987 .45126 .33072 .45294 .33017 .45197 .32929 Mtetra
.675 .788 .935 r
.45197 .32929 .45294 .33017 .45462 .32963 .45365 .32866 Mtetra
.692 .772 .913 r
.45365 .32866 .45462 .32963 .4563 .32905 .45534 .32795 Mtetra
.691 .747 .894 r
.45534 .32795 .4563 .32905 .45799 .32846 .45703 .32723 Mtetra
.683 .72 .878 r
.45703 .32723 .45799 .32846 .45968 .32787 .45872 .32653 Mtetra
.666 .697 .869 r
.45872 .32653 .45968 .32787 .46137 .32728 .46041 .32591 Mtetra
.658 .688 .867 r
.46041 .32591 .46137 .32728 .46305 .3267 .4621 .32533 Mtetra
.649 .685 .87 r
.4621 .32533 .46305 .3267 .46474 .32612 .46379 .32479 Mtetra
.634 .686 .882 r
.46379 .32479 .46474 .32612 .46643 .32554 .46548 .32433 Mtetra
.63 .705 .9 r
.46548 .32433 .46643 .32554 .46813 .32497 .46717 .32388 Mtetra
.633 .731 .919 r
.46717 .32388 .46813 .32497 .46982 .32439 .46886 .32342 Mtetra
.654 .763 .93 r
.46886 .32342 .46982 .32439 .47151 .32381 .47055 .32287 Mtetra
.661 .773 .932 r
.47055 .32287 .47151 .32381 .47321 .32322 .47225 .32229 Mtetra
.666 .776 .932 r
.47225 .32229 .47321 .32322 .47491 .32261 .47395 .32168 Mtetra
.662 .775 .933 r
.47395 .32168 .47491 .32261 .4766 .32196 .47564 .3211 Mtetra
.668 .792 .94 r
.47564 .3211 .4766 .32196 .4783 .32133 .47734 .32048 Mtetra
.679 .798 .938 r
.47734 .32048 .4783 .32133 .48 .32077 .47905 .31982 Mtetra
.703 .784 .914 r
.47905 .31982 .48 .32077 .4817 .3204 .48075 .31906 Mtetra
.693 .706 .858 r
.48075 .31906 .4817 .3204 .4834 .32008 .48245 .31828 Mtetra
.673 .638 .807 r
.48245 .31828 .4834 .32008 .4851 .31972 .48416 .31752 Mtetra
.685 .607 .763 r
.48416 .31752 .4851 .31972 .48681 .31866 .48587 .31652 Mtetra
.652 .596 .779 r
.48587 .31652 .48681 .31866 .48851 .31794 .48757 .31584 Mtetra
.568 .556 .8 r
.48757 .31584 .48851 .31794 .49021 .31796 .48928 .31569 Mtetra
0 .088 .641 r
.48928 .31569 .49021 .31796 .49186 .32316 .49095 .31795 Mtetra
.767 .522 0 r
.49095 .31795 .49186 .32316 .49154 .52673 .49255 .32815 Mtetra
0 0 .324 r
.49255 .32815 .49154 .52673 .49331 .53129 .49234 .52604 Mtetra
.339 .275 .637 r
.49234 .52604 .49331 .53129 .49513 .53142 .49414 .52818 Mtetra
.442 .412 .73 r
.49414 .52818 .49513 .53142 .49696 .5308 .49596 .52892 Mtetra
.517 .567 .846 r
.49596 .52892 .49696 .5308 .4988 .52979 .49778 .52899 Mtetra
.614 .805 .973 r
.49778 .52899 .4988 .52979 .50063 .52926 .49961 .52849 Mtetra
.683 .833 .956 r
.49961 .52849 .50063 .52926 .50246 .5287 .50145 .52775 Mtetra
.706 .8 .923 r
.50145 .52775 .50246 .5287 .50429 .52806 .50328 .52692 Mtetra
.507 .686 .947 r
.50328 .52692 .50429 .52806 .50613 .52769 .50512 .52684 Mtetra
.555 .773 .98 r
.50512 .52684 .50613 .52769 .50796 .52694 .50695 .52653 Mtetra
.694 .915 .97 r
.50695 .52653 .50796 .52694 .5098 .52541 .50879 .52565 Mtetra
.967 .925 .699 r
.50879 .52565 .5098 .52541 .51167 .51884 .51064 .52213 Mtetra
.948 .819 .375 r
.51064 .52213 .51167 .51884 .5142 .3139 .51252 .51195 Mtetra
0 0 .318 r
.51252 .51195 .5142 .3139 .51594 .3085 .51498 .31134 Mtetra
0 0 0 r
.51498 .31134 .51594 .3085 .51766 .30718 .51672 .3081 Mtetra
.545 .845 .527 r
.51672 .3081 .51766 .30718 .51938 .30668 .51844 .30631 Mtetra
.782 .932 .931 r
.51844 .30631 .51938 .30668 .52111 .30654 .52017 .30515 Mtetra
.668 .692 .863 r
.52017 .30515 .52111 .30654 .52284 .30606 .5219 .3045 Mtetra
.617 .645 .856 r
.5219 .3045 .52284 .30606 .52456 .30552 .52363 .30409 Mtetra
.594 .656 .881 r
.52363 .30409 .52456 .30552 .52629 .30495 .52536 .3038 Mtetra
.651 .729 .906 r
.52536 .3038 .52629 .30495 .52802 .30425 .52709 .30325 Mtetra
.672 .767 .922 r
.52709 .30325 .52802 .30425 .52975 .30355 .52882 .30261 Mtetra
.685 .786 .927 r
.52882 .30261 .52975 .30355 .53148 .30289 .53055 .30192 Mtetra
.779 .798 .869 r
.53055 .30192 .53148 .30289 .53322 .30207 .53228 .3007 Mtetra
.717 .714 .847 r
.53228 .3007 .53322 .30207 .53495 .30154 .53401 .29975 Mtetra
.588 .602 .833 r
.53401 .29975 .53495 .30154 .53669 .3017 .53575 .29949 Mtetra
0 0 .406 r
.53575 .29949 .53669 .3017 .53844 .30589 .5375 .30297 Mtetra
.972 .685 .424 r
.5375 .30297 .53844 .30589 .54119 .51029 .54019 .50846 Mtetra
.893 .516 .057 r
.54019 .50846 .54119 .51029 .54307 .51557 .54208 .51486 Mtetra
0 .388 .796 r
.54208 .51486 .54307 .51557 .54494 .51653 .54395 .51567 Mtetra
.635 .804 .964 r
.54395 .51567 .54494 .51653 .54681 .51616 .54582 .51511 Mtetra
.802 .802 .851 r
.54582 .51511 .54681 .51616 .54867 .51473 .54767 .5136 Mtetra
.903 .784 .72 r
.54767 .5136 .54867 .51473 .5505 .50988 .54952 .51023 Mtetra
.994 .804 .542 r
.54952 .51023 .5505 .50988 .55067 .30402 .55132 .50154 Mtetra
0 0 .332 r
.55132 .50154 .55067 .30402 .55235 .29625 .55147 .29948 Mtetra
0 0 .052 r
.55147 .29948 .55235 .29625 .55409 .29449 .55319 .29588 Mtetra
0 0 0 r
.55319 .29588 .55409 .29449 .55584 .2939 .55493 .29407 Mtetra
.668 .975 .848 r
.55493 .29407 .55584 .2939 .55759 .29375 .55667 .29287 Mtetra
.713 .808 .924 r
.55667 .29287 .55759 .29375 .55934 .29323 .55842 .29204 Mtetra
.665 .729 .897 r
.55842 .29204 .55934 .29323 .56109 .2926 .56017 .29142 Mtetra
.646 .725 .906 r
.56017 .29142 .56109 .2926 .56284 .29201 .56192 .29088 Mtetra
.756 .77 .864 r
.56192 .29088 .56284 .29201 .56459 .29119 .56367 .28976 Mtetra
.721 .71 .839 r
.56367 .28976 .56459 .29119 .56634 .29058 .56542 .28876 Mtetra
.61 .611 .827 r
.56542 .28876 .56634 .29058 .56811 .2906 .56717 .28839 Mtetra
0 .036 .604 r
.56717 .28839 .56811 .2906 .56992 .29395 .56898 .29098 Mtetra
.974 .684 .411 r
.56898 .29098 .56992 .29395 .57476 .49842 .57374 .49446 Mtetra
.781 .491 0 r
.57374 .49446 .57476 .49842 .57675 .50477 .57577 .50356 Mtetra
0 .235 .742 r
.57577 .50356 .57675 .50477 .57866 .50604 .57768 .505 Mtetra
.555 .733 .958 r
.57768 .505 .57866 .50604 .58055 .50581 .57957 .50473 Mtetra
.782 .799 .866 r
.57957 .50473 .58055 .50581 .58243 .50453 .58145 .50338 Mtetra
.925 .778 .679 r
.58145 .50338 .58243 .50453 .58425 .50036 .58327 .49913 Mtetra
.973 .688 .426 r
.58327 .49913 .58425 .50036 .58238 .2962 .58146 .29458 Mtetra
.95 .72 .556 r
.58146 .29458 .58238 .2962 .58397 .28582 .58305 .28465 Mtetra
.852 .779 .78 r
.58305 .28465 .58397 .28582 .5857 .28366 .58479 .28251 Mtetra
.676 .744 .902 r
.58479 .28251 .5857 .28366 .58747 .28297 .58656 .28184 Mtetra
.556 .698 .935 r
.58656 .28184 .58747 .28297 .58925 .28276 .58834 .28163 Mtetra
.704 .757 .893 r
.58834 .28163 .58925 .28276 .59101 .28195 .5901 .28082 Mtetra
.718 .761 .887 r
.5901 .28082 .59101 .28195 .59278 .28105 .59187 .27993 Mtetra
.577 .709 .933 r
.59187 .27993 .59278 .28105 .59455 .28075 .59365 .27965 Mtetra
.653 .188 0 r
.59365 .27965 .59455 .28075 .5964 .28321 .59549 .28231 Mtetra
.973 .68 .405 r
.59549 .28231 .5964 .28321 .60299 .48661 .60206 .48715 Mtetra
.915 .541 .301 r
.60206 .48715 .60299 .48661 .60512 .49564 .60416 .49504 Mtetra
0 .25 .66 r
.60416 .49504 .60512 .49564 .60706 .4969 .60611 .49611 Mtetra
.641 .825 .971 r
.60611 .49611 .60706 .4969 .60897 .49645 .60801 .49549 Mtetra
.754 .82 .904 r
.60801 .49549 .60897 .49645 .61086 .49543 .6099 .49437 Mtetra
.591 .747 .952 r
.6099 .49437 .61086 .49543 .61277 .4948 .61182 .49399 Mtetra
.465 .748 .991 r
.61182 .49399 .61277 .4948 .61468 .49425 .61374 .49386 Mtetra
.62 .909 .983 r
.61374 .49386 .61468 .49425 .61657 .49309 .61564 .49313 Mtetra
.964 .931 .706 r
.61564 .49313 .61657 .49309 .61839 .48911 .61748 .48976 Mtetra
.989 .733 .443 r
.61748 .48976 .61839 .48911 .61443 .28487 .61873 .46607 Mtetra
0 0 .348 r
.61873 .46607 .61443 .28487 .61595 .27505 .61506 .2741 Mtetra
.899 .814 .756 r
.61506 .2741 .61595 .27505 .61768 .27267 .61679 .27146 Mtetra
.693 .74 .887 r
.61679 .27146 .61768 .27267 .61947 .27191 .61857 .27068 Mtetra
.577 .69 .918 r
.61857 .27068 .61947 .27191 .62127 .27161 .62037 .27042 Mtetra
.687 .742 .894 r
.62037 .27042 .62127 .27161 .62305 .27084 .62216 .26968 Mtetra
.728 .762 .879 r
.62216 .26968 .62305 .27084 .62483 .26987 .62394 .26872 Mtetra
.613 .721 .923 r
.62394 .26872 .62483 .26987 .62663 .26945 .62574 .2683 Mtetra
0 .062 .597 r
.62574 .2683 .62663 .26945 .62851 .27134 .62761 .2702 Mtetra
.974 .678 .39 r
.62761 .2702 .62851 .27134 .63711 .47035 .63616 .46921 Mtetra
.956 .612 .264 r
.63616 .46921 .63711 .47035 .63953 .48435 .63858 .48324 Mtetra
0 .149 .663 r
.63858 .48324 .63953 .48435 .64153 .48607 .64058 .48493 Mtetra
.605 .736 .937 r
.64058 .48493 .64153 .48607 .64347 .48569 .64252 .4845 Mtetra
.719 .77 .893 r
.64252 .4845 .64347 .48569 .64538 .4847 .64443 .48354 Mtetra
.606 .733 .935 r
.64443 .48354 .64538 .4847 .64731 .48399 .64637 .48311 Mtetra
.449 .726 .985 r
.64637 .48311 .64731 .48399 .64924 .48349 .64832 .48305 Mtetra
.597 .895 .988 r
.64832 .48305 .64924 .48349 .65116 .48239 .65026 .48239 Mtetra
.949 .95 .733 r
.65026 .48239 .65116 .48239 .65298 .47883 .6521 .47941 Mtetra
.996 .764 .456 r
.6521 .47941 .65298 .47883 .64695 .27607 .65349 .46497 Mtetra
0 0 .359 r
.65349 .46497 .64695 .27607 .64831 .26406 .64743 .26317 Mtetra
.921 .822 .731 r
.64743 .26317 .64831 .26406 .65003 .26136 .64914 .26013 Mtetra
.706 .745 .882 r
.64914 .26013 .65003 .26136 .65183 .26052 .65094 .25928 Mtetra
.592 .696 .915 r
.65094 .25928 .65183 .26052 .65365 .26016 .65277 .25895 Mtetra
.668 .734 .9 r
.65277 .25895 .65365 .26016 .65546 .25947 .65458 .2583 Mtetra
.735 .764 .876 r
.65458 .2583 .65546 .25947 .65725 .25845 .65637 .25729 Mtetra
.638 .731 .915 r
.65637 .25729 .65725 .25845 .65907 .25793 .65819 .25677 Mtetra
0 .285 .782 r
.65819 .25677 .65907 .25793 .66097 .25924 .66009 .25809 Mtetra
.938 .573 .185 r
.66009 .25809 .66097 .25924 .66325 .26896 .66237 .26787 Mtetra
.975 .675 .374 r
.66237 .26787 .66325 .26896 .67432 .47229 .67339 .47119 Mtetra
0 0 .507 r
.67339 .47119 .67432 .47229 .6764 .47457 .67547 .47346 Mtetra
.629 .757 .939 r
.67547 .47346 .6764 .47457 .67836 .47404 .67743 .47293 Mtetra
.768 .801 .879 r
.67743 .47293 .67836 .47404 .68028 .47278 .67935 .47166 Mtetra
.78 .803 .871 r
.67935 .47166 .68028 .47278 .6822 .47144 .68127 .47031 Mtetra
.723 .786 .902 r
.68127 .47031 .6822 .47144 .68413 .47047 .68321 .46933 Mtetra
.709 .778 .907 r
.68321 .46933 .68413 .47047 .68608 .46958 .68515 .46842 Mtetra
.653 .756 .925 r
.68515 .46842 .68608 .46958 .68803 .46895 .6871 .46779 Mtetra
.573 .721 .943 r
.6871 .46779 .68803 .46895 .69 .46863 .68908 .46748 Mtetra
.546 .711 .948 r
.68908 .46748 .69 .46863 .69198 .4684 .69106 .46726 Mtetra
.454 .668 .955 r
.69106 .46726 .69198 .4684 .69398 .46845 .69305 .46732 Mtetra
.42 .652 .955 r
.69305 .46732 .69398 .46845 .69598 .46859 .69506 .46746 Mtetra
.629 .754 .937 r
.69506 .46746 .69598 .46859 .69795 .46805 .69703 .46693 Mtetra
.889 .811 .765 r
.69703 .46693 .69795 .46805 .69981 .46538 .69888 .46425 Mtetra
.981 .724 .469 r
.69888 .46425 .69981 .46538 .70088 .44823 .69996 .447 Mtetra
.977 .681 .379 r
.69996 .447 .70088 .44823 .69204 .24922 .69118 .24804 Mtetra
.912 .79 .713 r
.69118 .24804 .69204 .24922 .69374 .24598 .69287 .24479 Mtetra
.708 .758 .891 r
.69287 .24479 .69374 .24598 .69556 .24511 .6947 .24393 Mtetra
.587 .708 .927 r
.6947 .24393 .69556 .24511 .69741 .24479 .69655 .24361 Mtetra
.622 .724 .92 r
.69655 .24361 .69741 .24479 .69926 .24433 .6984 .24314 Mtetra
.731 .765 .88 r
.6984 .24314 .69926 .24433 .70108 .24333 .70022 .24214 Mtetra
.639 .731 .915 r
.70022 .24214 .70108 .24333 .70293 .2428 .70207 .24161 Mtetra
.06 .396 .854 r
.70207 .24161 .70293 .2428 .70487 .24384 .70401 .24265 Mtetra
.926 .555 .142 r
.70401 .24265 .70487 .24384 .70732 .25337 .70646 .25218 Mtetra
.975 .671 .352 r
.70646 .25218 .70732 .25337 .72147 .45802 .72056 .45689 Mtetra
.599 .137 0 r
.72056 .45689 .72147 .45802 .72367 .46097 .72276 .45984 Mtetra
.419 .653 .956 r
.72276 .45984 .72367 .46097 .7257 .46112 .72479 .45999 Mtetra
.71 .785 .91 r
.72479 .45999 .7257 .46112 .72767 .4602 .72676 .45906 Mtetra
.888 .816 .771 r
.72676 .45906 .72767 .4602 .72953 .45759 .72862 .45646 Mtetra
.977 .758 .541 r
.72862 .45646 .72953 .45759 .731 .44872 .73009 .44758 Mtetra
.977 .679 .365 r
.73009 .44758 .731 .44872 .7198 .24094 .71895 .23975 Mtetra
.937 .786 .669 r
.71895 .23975 .7198 .24094 .72144 .23686 .72058 .23567 Mtetra
.721 .763 .886 r
.72058 .23567 .72144 .23686 .72327 .23592 .72242 .23473 Mtetra
.581 .706 .928 r
.72242 .23473 .72327 .23592 .72515 .23562 .7243 .23442 Mtetra
.542 .687 .933 r
.7243 .23442 .72515 .23562 .72704 .23545 .72619 .23425 Mtetra
.658 .739 .91 r
.72619 .23425 .72704 .23545 .7289 .23483 .72805 .23363 Mtetra
.664 .742 .908 r
.72805 .23363 .7289 .23483 .73076 .23418 .72991 .23298 Mtetra
.702 .756 .894 r
.72991 .23298 .73076 .23418 .73261 .23334 .73176 .23214 Mtetra
.757 .775 .867 r
.73176 .23214 .73261 .23334 .73443 .23216 .73359 .23097 Mtetra
.674 .746 .905 r
.73359 .23097 .73443 .23216 .73629 .23147 .73545 .23027 Mtetra
.241 .515 .909 r
.73545 .23027 .73629 .23147 .73825 .23213 .7374 .23093 Mtetra
.896 .511 .065 r
.7374 .23093 .73825 .23213 .74072 .24012 .73987 .23892 Mtetra
.975 .667 .334 r
.73987 .23892 .74072 .24012 .75731 .44648 .75642 .44533 Mtetra
.634 .179 0 r
.75642 .44533 .75731 .44648 .7596 .44981 .75871 .44867 Mtetra
.392 .636 .953 r
.75871 .44867 .7596 .44981 .76167 .45004 .76078 .44889 Mtetra
.695 .781 .917 r
.76078 .44889 .76167 .45004 .76367 .44919 .76278 .44804 Mtetra
.873 .82 .793 r
.76278 .44804 .76367 .44919 .76555 .44684 .76466 .4457 Mtetra
.978 .767 .552 r
.76466 .4457 .76555 .44684 .76703 .43895 .76614 .4378 Mtetra
.977 .675 .347 r
.76614 .4378 .76703 .43895 .75342 .22973 .75258 .22852 Mtetra
.951 .785 .641 r
.75258 .22852 .75342 .22973 .75499 .22507 .75416 .22387 Mtetra
.748 .772 .873 r
.75416 .22387 .75499 .22507 .75683 .22396 .756 .22275 Mtetra
.622 .724 .919 r
.756 .22275 .75683 .22396 .75873 .22349 .75789 .22228 Mtetra
.591 .71 .926 r
.75789 .22228 .75873 .22349 .76063 .22314 .75979 .22194 Mtetra
.75 .773 .872 r
.75979 .22194 .76063 .22314 .76247 .22201 .76164 .22081 Mtetra
.676 .747 .904 r
.76164 .22081 .76247 .22201 .76435 .2213 .76352 .22009 Mtetra
.378 .596 .931 r
.76352 .22009 .76435 .2213 .76631 .22163 .76548 .22042 Mtetra
.806 .393 0 r
.76548 .22042 .76631 .22163 .76868 .22708 .76785 .22587 Mtetra
.973 .663 .318 r
.76785 .22587 .76868 .22708 .78742 .43557 .78654 .43441 Mtetra
.716 .274 0 r
.78654 .43441 .78742 .43557 .78984 .43978 .78896 .43862 Mtetra
.503 .695 .955 r
.78896 .43862 .78984 .43978 .79191 .43968 .79104 .43853 Mtetra
.695 .781 .918 r
.79104 .43853 .79191 .43968 .79393 .43883 .79305 .43767 Mtetra
.735 .795 .9 r
.79305 .43767 .79393 .43883 .79592 .43775 .79505 .43658 Mtetra
.497 .691 .955 r
.79505 .43658 .79592 .43775 .798 .43767 .79713 .43651 Mtetra
.625 .753 .938 r
.79713 .43651 .798 .43767 .80005 .43714 .79918 .43597 Mtetra
.811 .815 .853 r
.79918 .43597 .80005 .43714 .802 .4355 .80113 .43434 Mtetra
.98 .772 .552 r
.80113 .43434 .802 .4355 .80345 .42793 .80258 .42675 Mtetra
.976 .671 .329 r
.80258 .42675 .80345 .42793 .78743 .21821 .7866 .21698 Mtetra
.959 .784 .623 r
.7866 .21698 .78743 .21821 .78895 .21321 .78813 .21199 Mtetra
.751 .774 .872 r
.78813 .21199 .78895 .21321 .79081 .21206 .78999 .21084 Mtetra
.622 .723 .919 r
.78999 .21084 .79081 .21206 .79272 .21158 .7919 .21036 Mtetra
.553 .69 .93 r
.7919 .21036 .79272 .21158 .79466 .21138 .79385 .21015 Mtetra
.746 .773 .875 r
.79385 .21015 .79466 .21138 .79653 .21026 .79571 .20904 Mtetra
.677 .747 .904 r
.79571 .20904 .79653 .21026 .79842 .20953 .79761 .20831 Mtetra
.456 .638 .935 r
.79761 .20831 .79842 .20953 .8004 .20965 .79958 .20842 Mtetra
.768 .353 0 r
.79958 .20842 .8004 .20965 .80284 .21485 .80202 .21362 Mtetra
.971 .657 .298 r
.80202 .21362 .80284 .21485 .8241 .42414 .82324 .42297 Mtetra
.726 .292 0 r
.82324 .42297 .8241 .42414 .82664 .42878 .82578 .42761 Mtetra
.306 .58 .938 r
.82578 .42761 .82664 .42878 .8288 .42927 .82795 .4281 Mtetra
.649 .764 .933 r
.82795 .4281 .8288 .42927 .83086 .42862 .83001 .42745 Mtetra
.829 .821 .841 r
.83001 .42745 .83086 .42862 .83281 .42681 .83196 .42564 Mtetra
.975 .789 .59 r
.83196 .42564 .83281 .42681 .83435 .42071 .8335 .41953 Mtetra
.974 .667 .312 r
.8335 .41953 .83435 .42071 .81623 .21005 .81542 .20883 Mtetra
.975 .774 .571 r
.81542 .20883 .81623 .21005 .81761 .20372 .8168 .2025 Mtetra
.76 .758 .851 r
.20033 .41564 .20139 .41663 .20298 .41555 .20192 .41456 Mtetra
.612 .728 .928 r
.20192 .41456 .20298 .41555 .20449 .4152 .20343 .41422 Mtetra
.454 .669 .955 r
.20343 .41422 .20449 .4152 .20597 .41524 .20491 .41426 Mtetra
.654 .74 .913 r
.20491 .41426 .20597 .41524 .2075 .41474 .20644 .41376 Mtetra
.664 .743 .909 r
.20644 .41376 .2075 .41474 .20904 .4142 .20798 .41322 Mtetra
.67 .744 .906 r
.20798 .41322 .20904 .4142 .21058 .41364 .20952 .41266 Mtetra
.763 .76 .85 r
.20952 .41266 .21058 .41364 .21217 .41254 .21111 .41156 Mtetra
.709 .753 .886 r
.21111 .41156 .21217 .41254 .21373 .41179 .21267 .41081 Mtetra
.493 .686 .953 r
.21267 .41081 .21373 .41179 .21522 .41175 .21417 .41077 Mtetra
.932 .563 .281 r
.21417 .41077 .21522 .41175 .21629 .41618 .21523 .41521 Mtetra
.939 .683 .523 r
.21523 .41521 .21629 .41618 .19888 .61553 .19775 .61461 Mtetra
.931 .569 .307 r
.19775 .61461 .19888 .61553 .19999 .62052 .19886 .6196 Mtetra
0 .385 .823 r
.19886 .6196 .19999 .62052 .20151 .62126 .20038 .62033 Mtetra
.626 .758 .941 r
.20038 .62033 .20151 .62126 .20315 .62082 .20201 .61989 Mtetra
.802 .781 .833 r
.20201 .61989 .20315 .62082 .20488 .61934 .20375 .61841 Mtetra
.906 .743 .669 r
.20375 .61841 .20488 .61934 .20694 .61429 .20581 .61335 Mtetra
.939 .687 .53 r
.20581 .61335 .20694 .61429 .22696 .41405 .22591 .41305 Mtetra
.914 .724 .632 r
.22591 .41305 .22696 .41405 .22909 .40723 .22804 .40622 Mtetra
.794 .759 .821 r
.22804 .40622 .22909 .40723 .23072 .40583 .22967 .40482 Mtetra
.64 .731 .915 r
.22967 .40482 .23072 .40583 .23226 .4054 .23121 .40437 Mtetra
.496 .678 .947 r
.23121 .40437 .23226 .4054 .23376 .40537 .23272 .40434 Mtetra
.702 .743 .883 r
.23272 .40434 .23376 .40537 .23532 .40479 .23429 .40362 Mtetra
.681 .712 .872 r
.23429 .40362 .23532 .40479 .23688 .4042 .23585 .40298 Mtetra
.581 .67 .9 r
.23585 .40298 .23688 .4042 .23842 .40379 .23737 .40275 Mtetra
.513 .012 0 r
.23737 .40275 .23842 .40379 .23993 .4037 .23876 .40416 Mtetra
.874 .521 .378 r
.23876 .40416 .23993 .4037 .2414 .40415 .23987 .40861 Mtetra
.934 .675 .521 r
.23987 .40861 .2414 .40415 .24277 .40574 .22428 .60362 Mtetra
.545 .318 .522 r
.22428 .60362 .24277 .40574 .22773 .59624 .22547 .60834 Mtetra
.583 .32 .483 r
.22547 .60834 .22773 .59624 .22824 .60886 .22692 .61014 Mtetra
.597 .165 .191 r
.22692 .61014 .22824 .60886 .2296 .61168 .22847 .61091 Mtetra
.398 .713 .986 r
.22847 .61091 .2296 .61168 .23117 .61221 .23008 .61093 Mtetra
.64 .696 .886 r
.23008 .61093 .23117 .61221 .23282 .6118 .23173 .61045 Mtetra
.718 .709 .841 r
.23173 .61045 .23282 .6118 .23454 .61059 .23343 .60951 Mtetra
.827 .758 .787 r
.23343 .60951 .23454 .61059 .23643 .6073 .23522 .60753 Mtetra
.945 .901 .751 r
.23522 .60753 .23643 .6073 .23881 .59824 .23709 .60449 Mtetra
0 0 .171 r
.23709 .60449 .23881 .59824 .25679 .40147 .2391 .59981 Mtetra
.532 .307 .519 r
.2391 .59981 .25679 .40147 .25849 .39929 .24085 .59819 Mtetra
.536 .311 .52 r
.24085 .59819 .25849 .39929 .26005 .39886 .24245 .59842 Mtetra
.534 .309 .52 r
.24245 .59842 .26005 .39886 .26158 .39875 .24414 .5976 Mtetra
0 0 .188 r
.24414 .5976 .26158 .39875 .26325 .39703 .26156 .40397 Mtetra
0 0 0 r
.26156 .40397 .26325 .39703 .26493 .3951 .26375 .39586 Mtetra
.962 .937 .702 r
.26375 .39586 .26493 .3951 .26658 .39355 .26554 .39259 Mtetra
.771 .77 .852 r
.26554 .39259 .26658 .39355 .26817 .39277 .26716 .39143 Mtetra
.623 .667 .872 r
.26716 .39143 .26817 .39277 .26973 .39237 .26872 .39104 Mtetra
.548 .64 .894 r
.26872 .39104 .26973 .39237 .27128 .39208 .27026 .39094 Mtetra
.618 .702 .904 r
.27026 .39094 .27128 .39208 .27285 .39162 .27182 .39057 Mtetra
.66 .733 .904 r
.27182 .39057 .27285 .39162 .27443 .39105 .27339 .39003 Mtetra
.674 .744 .903 r
.27339 .39003 .27443 .39105 .27601 .39043 .27497 .38944 Mtetra
.726 .759 .879 r
.27497 .38944 .27601 .39043 .27762 .38947 .27657 .38858 Mtetra
.726 .781 .896 r
.27657 .38858 .27762 .38947 .27922 .38859 .27817 .38775 Mtetra
.666 .778 .933 r
.27817 .38775 .27922 .38859 .28079 .38817 .27975 .38719 Mtetra
.353 .622 .953 r
.27975 .38719 .28079 .38817 .28222 .38954 .28128 .38741 Mtetra
.164 .305 .762 r
.28128 .38741 .28222 .38954 .28335 .39497 .28273 .3886 Mtetra
.233 .162 .567 r
.28273 .3886 .28335 .39497 .27012 .59304 .28403 .39174 Mtetra
0 0 .214 r
.28403 .39174 .27012 .59304 .27151 .59653 .27103 .58718 Mtetra
0 0 .435 r
.27103 .58718 .27151 .59653 .27307 .59756 .27214 .59429 Mtetra
.016 .118 .628 r
.27214 .59429 .27307 .59756 .2747 .59785 .27362 .59661 Mtetra
.245 .522 .913 r
.27362 .59661 .2747 .59785 .27634 .59791 .27523 .59713 Mtetra
.587 .787 .975 r
.27523 .59713 .27634 .59791 .27801 .5976 .2769 .59676 Mtetra
.736 .806 .907 r
.2769 .59676 .27801 .5976 .27973 .59669 .27862 .59583 Mtetra
.815 .803 .84 r
.27862 .59583 .27973 .59669 .28157 .59402 .28038 .59428 Mtetra
.925 .948 .79 r
.28038 .59428 .28157 .59402 .2837 .58724 .28221 .59183 Mtetra
0 0 .017 r
.28221 .59183 .2837 .58724 .29938 .38764 .28418 .58739 Mtetra
0 0 .204 r
.28418 .58739 .29938 .38764 .30127 .38285 .29969 .38967 Mtetra
0 0 0 r
.29969 .38967 .30127 .38285 .30297 .38074 .30178 .38199 Mtetra
.871 .96 .622 r
.30178 .38199 .30297 .38074 .30459 .37972 .30354 .3791 Mtetra
.702 .84 .949 r
.30354 .3791 .30459 .37972 .30609 .3805 .30515 .37838 Mtetra
.317 .403 .792 r
.30515 .37838 .30609 .3805 .30739 .38442 .30665 .3792 Mtetra
.218 .174 .592 r
.30665 .3792 .30739 .38442 .29556 .58319 .30803 .3819 Mtetra
0 0 .238 r
.30803 .3819 .29556 .58319 .29689 .58813 .29665 .57442 Mtetra
0 0 .382 r
.29665 .57442 .29689 .58813 .29847 .58938 .29756 .58566 Mtetra
.01 .09 .6 r
.29756 .58566 .29847 .58938 .30011 .58975 .29905 .58836 Mtetra
.245 .491 .893 r
.29905 .58836 .30011 .58975 .30178 .58976 .30067 .58897 Mtetra
.613 .793 .968 r
.30067 .58897 .30178 .58976 .30347 .5894 .30237 .58853 Mtetra
.75 .803 .895 r
.30237 .58853 .30347 .5894 .3052 .58844 .30411 .58751 Mtetra
.808 .793 .839 r
.30411 .58751 .3052 .58844 .30704 .58591 .30588 .58598 Mtetra
.911 .94 .813 r
.30588 .58598 .30704 .58591 .30911 .57957 .30769 .58374 Mtetra
0 0 .034 r
.30769 .58374 .30911 .57957 .32333 .38015 .30961 .57985 Mtetra
0 0 .231 r
.30961 .57985 .32333 .38015 .32521 .37527 .32348 .38567 Mtetra
0 0 .098 r
.32348 .38567 .32521 .37527 .32691 .37321 .32574 .37465 Mtetra
.9 .944 .585 r
.32574 .37465 .32691 .37321 .32857 .37186 .32753 .37119 Mtetra
.849 .826 .825 r
.32753 .37119 .32857 .37186 .3302 .3709 .32921 .36944 Mtetra
.698 .68 .829 r
.32921 .36944 .3302 .3709 .33182 .37023 .33084 .36862 Mtetra
.585 .614 .847 r
.33084 .36862 .33182 .37023 .33342 .36986 .33243 .36839 Mtetra
.122 .383 .839 r
.33243 .36839 .33342 .36986 .33499 .36998 .33395 .36929 Mtetra
.874 .432 .102 r
.33395 .36929 .33499 .36998 .33653 .37064 .33536 .37228 Mtetra
.948 .681 .496 r
.33536 .37228 .33653 .37064 .33805 .37167 .32576 .56234 Mtetra
.556 .328 .524 r
.32576 .56234 .33805 .37167 .3396 .37222 .32681 .57316 Mtetra
.535 .31 .52 r
.32681 .57316 .3396 .37222 .34121 .37173 .3285 .57312 Mtetra
.533 .308 .519 r
.3285 .57312 .34121 .37173 .34285 .37087 .33026 .57169 Mtetra
.33026 .57169 .34285 .37087 .34448 .37005 .33203 .57026 Mtetra
.534 .309 .52 r
.33203 .57026 .34448 .37005 .34611 .36939 .33376 .56952 Mtetra
.33376 .56952 .34611 .36939 .34773 .36874 .3355 .56877 Mtetra
.533 .308 .519 r
.3355 .56877 .34773 .36874 .34938 .36776 .33726 .56741 Mtetra
.532 .307 .519 r
.33726 .56741 .34938 .36776 .35103 .36671 .33905 .56568 Mtetra
.535 .31 .52 r
.33905 .56568 .35103 .36671 .35264 .3664 .34075 .56564 Mtetra
.542 .315 .521 r
.34075 .56564 .35264 .3664 .35408 .36928 .34226 .56894 Mtetra
.34226 .56894 .35408 .36928 .34511 .56859 .34379 .57215 Mtetra
.646 .311 .391 r
.34379 .57215 .34511 .56859 .34652 .57413 .3454 .57389 Mtetra
.252 0 0 r
.3454 .57389 .34652 .57413 .34815 .57551 .34708 .57439 Mtetra
.62 .728 .923 r
.34708 .57439 .34815 .57551 .34987 .57518 .34881 .57396 Mtetra
.679 .729 .888 r
.34881 .57396 .34987 .57518 .35162 .57439 .35055 .57328 Mtetra
.681 .746 .901 r
.35055 .57328 .35162 .57439 .35337 .5736 .35229 .57259 Mtetra
.651 .759 .929 r
.35229 .57259 .35337 .5736 .35511 .57303 .35403 .57204 Mtetra
.649 .762 .932 r
.35403 .57204 .35511 .57303 .35685 .57245 .35577 .57149 Mtetra
.644 .767 .937 r
.35577 .57149 .35685 .57245 .35859 .57188 .35751 .57095 Mtetra
.638 .774 .945 r
.35751 .57095 .35859 .57188 .36033 .57132 .35925 .57044 Mtetra
.635 .784 .953 r
.35925 .57044 .36033 .57132 .36207 .57076 .36099 .56993 Mtetra
.589 .781 .971 r
.36099 .56993 .36207 .57076 .36381 .57028 .36273 .56955 Mtetra
.538 .787 .99 r
.36273 .56955 .36381 .57028 .36555 .56986 .36446 .56926 Mtetra
.651 .853 .977 r
.36446 .56926 .36555 .56986 .36729 .56929 .36621 .56864 Mtetra
.834 .852 .859 r
.36621 .56864 .36729 .56929 .36905 .56839 .368 .56703 Mtetra
.882 .738 .698 r
.368 .56703 .36905 .56839 .37084 .56695 .3699 .56328 Mtetra
.887 .658 .586 r
.3699 .56328 .37084 .56695 .37267 .56467 .37214 .55167 Mtetra
.941 .674 .503 r
.37214 .55167 .37267 .56467 .37464 .5591 .3826 .35648 Mtetra
.544 .322 .528 r
.3826 .35648 .37464 .5591 .38519 .35806 .38438 .35274 Mtetra
.675 .497 .637 r
.38438 .35274 .38519 .35806 .38705 .35254 .3861 .35056 Mtetra
.729 .64 .76 r
.3861 .35056 .38705 .35254 .38877 .35024 .38778 .34923 Mtetra
.689 .758 .904 r
.38778 .34923 .38877 .35024 .39042 .34945 .38943 .34854 Mtetra
.63 .762 .942 r
.38943 .34854 .39042 .34945 .39206 .34907 .39107 .34809 Mtetra
.625 .745 .933 r
.39107 .34809 .39206 .34907 .3937 .34876 .39271 .34766 Mtetra
.664 .733 .901 r
.39271 .34766 .3937 .34876 .39534 .34823 .39436 .34708 Mtetra
.663 .724 .894 r
.39436 .34708 .39534 .34823 .39699 .34769 .39601 .3465 Mtetra
.681 .722 .88 r
.39601 .3465 .39699 .34769 .39864 .34711 .39766 .34583 Mtetra
.701 .714 .859 r
.39766 .34583 .39864 .34711 .4003 .34643 .39932 .34504 Mtetra
.647 .676 .864 r
.39932 .34504 .4003 .34643 .40195 .34588 .40097 .34451 Mtetra
.438 .586 .902 r
.40097 .34451 .40195 .34588 .40359 .34559 .4026 .34473 Mtetra
.695 .188 0 r
.4026 .34473 .40359 .34559 .40522 .34573 .40415 .34671 Mtetra
.888 .543 .388 r
.40415 .34671 .40522 .34573 .40682 .34656 .40554 .3533 Mtetra
.949 .674 .482 r
.40554 .3533 .40682 .34656 .40834 .34961 .39985 .55121 Mtetra
.542 .316 .521 r
.39985 .55121 .40834 .34961 .40273 .5498 .40146 .55477 Mtetra
.609 .296 .414 r
.40146 .55477 .40273 .5498 .40426 .55596 .40316 .55625 Mtetra
.446 0 0 r
.40316 .55625 .40426 .55596 .40594 .55777 .40489 .55678 Mtetra
.528 .725 .964 r
.40489 .55678 .40594 .55777 .4077 .55767 .40665 .55661 Mtetra
.628 .745 .932 r
.40665 .55661 .4077 .55767 .40947 .55708 .40842 .55614 Mtetra
.647 .777 .943 r
.40842 .55614 .40947 .55708 .41125 .55633 .41019 .55558 Mtetra
.59 .802 .981 r
.41019 .55558 .41125 .55633 .41303 .5558 .41196 .55516 Mtetra
.681 .856 .966 r
.41196 .55516 .41303 .5558 .41481 .55509 .41375 .55443 Mtetra
.816 .86 .881 r
.41375 .55443 .41481 .55509 .4166 .55413 .41555 .55298 Mtetra
.887 .766 .722 r
.41555 .55298 .4166 .55413 .4184 .55279 .41742 .54971 Mtetra
.87 .66 .616 r
.41742 .54971 .4184 .55279 .42023 .55076 .41941 .54249 Mtetra
.952 .681 .486 r
.41941 .54249 .42023 .55076 .42211 .54668 .42732 .34267 Mtetra
.546 .323 .528 r
.42732 .34267 .42211 .54668 .42991 .34537 .42912 .33793 Mtetra
.654 .461 .611 r
.42912 .33793 .42991 .34537 .43179 .33777 .43085 .33544 Mtetra
.729 .617 .734 r
.43085 .33544 .43179 .33777 .43353 .33493 .43255 .3339 Mtetra
.7 .761 .899 r
.43255 .3339 .43353 .33493 .43521 .33403 .43423 .33315 Mtetra
.633 .774 .948 r
.43423 .33315 .43521 .33403 .43688 .3336 .4359 .33267 Mtetra
.608 .757 .95 r
.4359 .33267 .43688 .3336 .43855 .33332 .43757 .33228 Mtetra
.662 .75 .915 r
.43757 .33228 .43855 .33332 .44022 .33275 .43925 .33171 Mtetra
.658 .746 .915 r
.43925 .33171 .44022 .33275 .4419 .33221 .44093 .33115 Mtetra
.647 .739 .916 r
.44093 .33115 .4419 .33221 .44357 .33171 .4426 .33063 Mtetra
.622 .728 .923 r
.4426 .33063 .44357 .33171 .44525 .33128 .44428 .33021 Mtetra
.619 .729 .925 r
.44428 .33021 .44525 .33128 .44692 .33085 .44596 .3298 Mtetra
.627 .735 .925 r
.44596 .3298 .44692 .33085 .4486 .33041 .44763 .32936 Mtetra
.653 .746 .918 r
.44763 .32936 .4486 .33041 .45028 .32987 .44932 .32882 Mtetra
.667 .749 .911 r
.44932 .32882 .45028 .32987 .45197 .32929 .451 .32822 Mtetra
.681 .749 .903 r
.451 .32822 .45197 .32929 .45365 .32866 .45269 .32755 Mtetra
.7 .749 .889 r
.45269 .32755 .45365 .32866 .45534 .32795 .45438 .32679 Mtetra
.7 .738 .881 r
.45438 .32679 .45534 .32795 .45703 .32723 .45607 .32602 Mtetra
.691 .726 .876 r
.45607 .32602 .45703 .32723 .45872 .32653 .45776 .32528 Mtetra
.671 .712 .879 r
.45776 .32528 .45872 .32653 .46041 .32591 .45945 .32464 Mtetra
.66 .705 .881 r
.45945 .32464 .46041 .32591 .4621 .32533 .46114 .32406 Mtetra
.647 .701 .886 r
.46114 .32406 .4621 .32533 .46379 .32479 .46283 .32354 Mtetra
.624 .695 .895 r
.46283 .32354 .46379 .32479 .46548 .32433 .46452 .32312 Mtetra
.617 .7 .904 r
.46452 .32312 .46548 .32433 .46717 .32388 .46621 .32272 Mtetra
.621 .712 .911 r
.46621 .32272 .46717 .32388 .46886 .32342 .4679 .32231 Mtetra
.65 .732 .91 r
.4679 .32231 .46886 .32342 .47055 .32287 .46959 .32178 Mtetra
.659 .739 .909 r
.46959 .32178 .47055 .32287 .47225 .32229 .47129 .32121 Mtetra
.664 .744 .909 r
.47129 .32121 .47225 .32229 .47395 .32168 .47299 .32061 Mtetra
.658 .744 .913 r
.47299 .32061 .47395 .32168 .47564 .3211 .47469 .32004 Mtetra
.665 .75 .913 r
.47469 .32004 .47564 .3211 .47734 .32048 .47639 .31944 Mtetra
.676 .757 .912 r
.47639 .31944 .47734 .32048 .47905 .31982 .47809 .3188 Mtetra
.703 .767 .902 r
.47809 .3188 .47905 .31982 .48075 .31906 .47979 .31802 Mtetra
.706 .766 .9 r
.47979 .31802 .48075 .31906 .48245 .31828 .4815 .31724 Mtetra
.703 .763 .899 r
.4815 .31724 .48245 .31828 .48416 .31752 .4832 .31646 Mtetra
.719 .766 .889 r
.4832 .31646 .48416 .31752 .48587 .31652 .48491 .3156 Mtetra
.683 .783 .926 r
.48491 .3156 .48587 .31652 .48757 .31584 .48662 .31492 Mtetra
.592 .756 .957 r
.48662 .31492 .48757 .31584 .48928 .31569 .48832 .31457 Mtetra
.234 .527 .918 r
.48832 .31457 .48928 .31569 .49095 .31795 .49002 .31511 Mtetra
.245 .298 .719 r
.49002 .31511 .49095 .31795 .49255 .32815 .49171 .31663 Mtetra
.352 .217 .554 r
.49171 .31663 .49255 .32815 .49234 .52604 .49337 .32101 Mtetra
0 0 .331 r
.49337 .32101 .49234 .52604 .49414 .52818 .49318 .52142 Mtetra
.106 .084 .547 r
.49318 .52142 .49414 .52818 .49596 .52892 .49496 .52627 Mtetra
.139 .257 .725 r
.49496 .52627 .49596 .52892 .49778 .52899 .49677 .52805 Mtetra
.56 .755 .969 r
.49677 .52805 .49778 .52899 .49961 .52849 .4986 .52776 Mtetra
.702 .846 .951 r
.4986 .52776 .49961 .52849 .50145 .52775 .50043 .52693 Mtetra
.751 .836 .916 r
.50043 .52693 .50145 .52775 .50328 .52692 .50227 .52587 Mtetra
.554 .728 .956 r
.50227 .52587 .50328 .52692 .50512 .52684 .50411 .52563 Mtetra
.59 .708 .925 r
.50411 .52563 .50512 .52684 .50695 .52653 .50594 .5253 Mtetra
.667 .733 .9 r
.50594 .5253 .50695 .52653 .50879 .52565 .50778 .52464 Mtetra
.826 .805 .831 r
.50778 .52464 .50879 .52565 .51064 .52213 .50963 .5229 Mtetra
.873 .972 .658 r
.50963 .5229 .51064 .52213 .51252 .51195 .51148 .52006 Mtetra
.131 0 .317 r
.51148 .52006 .51252 .51195 .51498 .31134 .51333 .51448 Mtetra
0 0 .327 r
.51333 .51448 .51498 .31134 .51672 .3081 .51576 .31275 Mtetra
0 0 .04 r
.51576 .31275 .51672 .3081 .51844 .30631 .5175 .30678 Mtetra
.929 .97 .701 r
.5175 .30678 .51844 .30631 .52017 .30515 .51923 .30399 Mtetra
.723 .751 .874 r
.51923 .30399 .52017 .30515 .5219 .3045 .52096 .30307 Mtetra
.607 .661 .877 r
.52096 .30307 .5219 .3045 .52363 .30409 .52269 .30272 Mtetra
.539 .639 .898 r
.52269 .30272 .52363 .30409 .52536 .3038 .52442 .30262 Mtetra
.636 .719 .907 r
.52442 .30262 .52536 .3038 .52709 .30325 .52615 .30214 Mtetra
.664 .742 .908 r
.52615 .30214 .52709 .30325 .52882 .30261 .52788 .30153 Mtetra
.679 .753 .907 r
.52788 .30153 .52882 .30261 .53055 .30192 .52961 .30086 Mtetra
.776 .782 .858 r
.52961 .30086 .53055 .30192 .53228 .3007 .53135 .29961 Mtetra
.734 .769 .881 r
.53135 .29961 .53228 .3007 .53401 .29975 .53308 .29865 Mtetra
.575 .71 .934 r
.53308 .29865 .53401 .29975 .53575 .29949 .53482 .29838 Mtetra
.82 .379 0 r
.53482 .29838 .53575 .29949 .5375 .30297 .53657 .30197 Mtetra
.97 .683 .428 r
.53657 .30197 .5375 .30297 .54019 .50846 .5392 .50786 Mtetra
.921 .528 .204 r
.5392 .50786 .54019 .50846 .54208 .51486 .54109 .51401 Mtetra
.073 .504 .898 r
.54109 .51401 .54208 .51486 .54395 .51567 .54296 .51463 Mtetra
.669 .774 .928 r
.54296 .51463 .54395 .51567 .54582 .51511 .54482 .51396 Mtetra
.785 .782 .85 r
.54482 .51396 .54582 .51511 .54767 .5136 .54668 .51254 Mtetra
.827 .802 .828 r
.54668 .51254 .54767 .5136 .54952 .51023 .54854 .51077 Mtetra
.873 .985 .706 r
.54854 .51077 .54952 .51023 .55132 .50154 .55039 .50821 Mtetra
.152 0 .306 r
.55039 .50821 .55132 .50154 .55147 .29948 .55223 .50371 Mtetra
0 0 .348 r
.55223 .50371 .55147 .29948 .55319 .29588 .55234 .30353 Mtetra
0 0 .208 r
.55234 .30353 .55319 .29588 .55493 .29407 .55402 .29529 Mtetra
.796 .899 .492 r
.55402 .29529 .55493 .29407 .55667 .29287 .55575 .29208 Mtetra
.799 .842 .883 r
.55575 .29208 .55667 .29287 .55842 .29204 .55749 .29077 Mtetra
.667 .716 .886 r
.55749 .29077 .55842 .29204 .56017 .29142 .55924 .29014 Mtetra
.615 .693 .899 r
.55924 .29014 .56017 .29142 .56192 .29088 .561 .28974 Mtetra
.751 .765 .864 r
.561 .28974 .56192 .29088 .56367 .28976 .56275 .28864 Mtetra
.74 .765 .874 r
.56275 .28864 .56367 .28976 .56542 .28876 .5645 .28762 Mtetra
.611 .718 .921 r
.5645 .28762 .56542 .28876 .56717 .28839 .56625 .28723 Mtetra
.637 .177 0 r
.56625 .28723 .56717 .28839 .56898 .29098 .56806 .28981 Mtetra
.972 .681 .415 r
.56806 .28981 .56898 .29098 .57374 .49446 .57276 .49332 Mtetra
.944 .582 .227 r
.57276 .49332 .57374 .49446 .57577 .50356 .57479 .5025 Mtetra
0 .202 .701 r
.57479 .5025 .57577 .50356 .57768 .505 .5767 .50393 Mtetra
.56 .731 .955 r
.5767 .50393 .57768 .505 .57957 .50473 .5786 .50366 Mtetra
.784 .8 .866 r
.5786 .50366 .57957 .50473 .58145 .50338 .58047 .5023 Mtetra
.93 .784 .679 r
.58047 .5023 .58145 .50338 .58327 .49913 .5823 .49802 Mtetra
.973 .688 .426 r
.5823 .49802 .58327 .49913 .58146 .29458 .58054 .29333 Mtetra
.96 .734 .552 r
.58054 .29333 .58146 .29458 .58305 .28465 .58214 .2835 Mtetra
.852 .782 .782 r
.58214 .2835 .58305 .28465 .58479 .28251 .58388 .28137 Mtetra
.674 .744 .903 r
.58388 .28137 .58479 .28251 .58656 .28184 .58565 .2807 Mtetra
.553 .696 .935 r
.58565 .2807 .58656 .28184 .58834 .28163 .58743 .2805 Mtetra
.703 .757 .893 r
.58743 .2805 .58834 .28163 .5901 .28082 .58919 .27969 Mtetra
.717 .762 .888 r
.58919 .27969 .5901 .28082 .59187 .27993 .59096 .27881 Mtetra
.572 .709 .935 r
.59096 .27881 .59187 .27993 .59365 .27965 .59274 .27854 Mtetra
.677 .214 0 r
.59274 .27854 .59365 .27965 .59549 .28231 .59459 .28132 Mtetra
.973 .68 .405 r
.59459 .28132 .59549 .28231 .60206 .48715 .60111 .48677 Mtetra
.927 .543 .227 r
.60111 .48677 .60206 .48715 .60416 .49504 .6032 .49417 Mtetra
0 .353 .797 r
.6032 .49417 .60416 .49504 .60611 .49611 .60514 .49518 Mtetra
.665 .801 .948 r
.60514 .49518 .60611 .49611 .60801 .49549 .60705 .49449 Mtetra
.762 .813 .893 r
.60705 .49449 .60801 .49549 .6099 .49437 .60894 .49331 Mtetra
.597 .749 .95 r
.60894 .49331 .6099 .49437 .61182 .49399 .61085 .4929 Mtetra
.508 .705 .959 r
.61085 .4929 .61182 .49399 .61374 .49386 .61277 .49279 Mtetra
.675 .775 .926 r
.61277 .49279 .61374 .49386 .61564 .49313 .61468 .49207 Mtetra
.914 .802 .722 r
.61468 .49207 .61564 .49313 .61748 .48976 .61652 .48871 Mtetra
.976 .714 .469 r
.61652 .48871 .61748 .48976 .61873 .46607 .61778 .46493 Mtetra
.975 .687 .413 r
.61778 .46493 .61873 .46607 .61506 .2741 .61416 .27292 Mtetra
.88 .781 .747 r
.61416 .27292 .61506 .2741 .61679 .27146 .61589 .27028 Mtetra
.693 .746 .892 r
.61589 .27028 .61679 .27146 .61857 .27068 .61767 .26951 Mtetra
.571 .699 .928 r
.61767 .26951 .61857 .27068 .62037 .27042 .61947 .26925 Mtetra
.685 .746 .898 r
.61947 .26925 .62037 .27042 .62216 .26968 .62126 .26852 Mtetra
.727 .762 .88 r
.62126 .26852 .62216 .26968 .62394 .26872 .62304 .26756 Mtetra
.612 .721 .923 r
.62304 .26756 .62394 .26872 .62574 .2683 .62484 .26715 Mtetra
0 .062 .597 r
.62484 .26715 .62574 .2683 .62761 .2702 .62672 .26904 Mtetra
.974 .678 .39 r
.62672 .26904 .62761 .2702 .63616 .46921 .63521 .4681 Mtetra
.956 .612 .266 r
.63521 .4681 .63616 .46921 .63858 .48324 .63763 .48213 Mtetra
0 .15 .664 r
.63763 .48213 .63858 .48324 .64058 .48493 .63963 .48381 Mtetra
.606 .744 .942 r
.63963 .48381 .64058 .48493 .64252 .4845 .64157 .48338 Mtetra
.723 .783 .9 r
.64157 .48338 .64252 .4845 .64443 .48354 .64348 .4824 Mtetra
.602 .738 .94 r
.64348 .4824 .64443 .48354 .64637 .48311 .64542 .48199 Mtetra
.484 .686 .956 r
.64542 .48199 .64637 .48311 .64832 .48305 .64738 .48195 Mtetra
.657 .766 .93 r
.64738 .48195 .64832 .48305 .65026 .48239 .64931 .48131 Mtetra
.902 .808 .745 r
.64931 .48131 .65026 .48239 .6521 .47941 .65116 .47833 Mtetra
.977 .731 .498 r
.65116 .47833 .6521 .47941 .65349 .46497 .65255 .46377 Mtetra
.976 .685 .399 r
.65255 .46377 .65349 .46497 .64743 .26317 .64654 .26196 Mtetra
.898 .782 .724 r
.64654 .26196 .64743 .26317 .64914 .26013 .64826 .25894 Mtetra
.706 .75 .886 r
.64826 .25894 .64914 .26013 .65094 .25928 .65006 .25809 Mtetra
.587 .704 .924 r
.65006 .25809 .65094 .25928 .65277 .25895 .65188 .25777 Mtetra
.666 .739 .904 r
.65188 .25777 .65277 .25895 .65458 .2583 .65369 .25713 Mtetra
.734 .764 .877 r
.65369 .25713 .65458 .2583 .65637 .25729 .65549 .25612 Mtetra
.638 .73 .915 r
.65549 .25612 .65637 .25729 .65819 .25677 .65731 .2556 Mtetra
0 .284 .781 r
.65731 .2556 .65819 .25677 .66009 .25809 .65921 .25692 Mtetra
.938 .574 .185 r
.65921 .25692 .66009 .25809 .66237 .26787 .66149 .26674 Mtetra
.975 .675 .374 r
.66149 .26674 .66237 .26787 .67339 .47119 .67246 .47008 Mtetra
0 0 .51 r
.67246 .47008 .67339 .47119 .67547 .47346 .67454 .47236 Mtetra
.629 .756 .939 r
.67454 .47236 .67547 .47346 .67743 .47293 .67649 .47182 Mtetra
.769 .801 .879 r
.67649 .47182 .67743 .47293 .67935 .47166 .67842 .47055 Mtetra
.78 .803 .871 r
.67842 .47055 .67935 .47166 .68127 .47031 .68034 .46919 Mtetra
.725 .788 .902 r
.68034 .46919 .68127 .47031 .68321 .46933 .68227 .46819 Mtetra
.711 .781 .907 r
.68227 .46819 .68321 .46933 .68515 .46842 .68422 .46727 Mtetra
.654 .759 .927 r
.68422 .46727 .68515 .46842 .6871 .46779 .68617 .46664 Mtetra
.57 .723 .946 r
.68617 .46664 .6871 .46779 .68908 .46748 .68815 .46633 Mtetra
.542 .712 .95 r
.68815 .46633 .68908 .46748 .69106 .46726 .69013 .46612 Mtetra
.45 .668 .956 r
.69013 .46612 .69106 .46726 .69305 .46732 .69213 .46619 Mtetra
.418 .652 .956 r
.69213 .46619 .69305 .46732 .69506 .46746 .69413 .46633 Mtetra
.629 .754 .937 r
.69413 .46633 .69506 .46746 .69703 .46693 .6961 .4658 Mtetra
.89 .812 .765 r
.6961 .4658 .69703 .46693 .69888 .46425 .69796 .46312 Mtetra
.981 .724 .468 r
.69796 .46312 .69888 .46425 .69996 .447 .69904 .44578 Mtetra
.977 .681 .379 r
.69904 .44578 .69996 .447 .69118 .24804 .69031 .24686 Mtetra
.912 .79 .713 r
.69031 .24686 .69118 .24804 .69287 .24479 .69201 .24361 Mtetra
.708 .758 .891 r
.69201 .24361 .69287 .24479 .6947 .24393 .69383 .24275 Mtetra
.587 .709 .927 r
.69383 .24275 .6947 .24393 .69655 .24361 .69569 .24242 Mtetra
.622 .724 .92 r
.69569 .24242 .69655 .24361 .6984 .24314 .69754 .24196 Mtetra
.731 .765 .88 r
.69754 .24196 .6984 .24314 .70022 .24214 .69936 .24096 Mtetra
.639 .731 .915 r
.69936 .24096 .70022 .24214 .70207 .24161 .70121 .24043 Mtetra
.06 .396 .854 r
.70121 .24043 .70207 .24161 .70401 .24265 .70315 .24147 Mtetra
.925 .554 .142 r
.70315 .24147 .70401 .24265 .70646 .25218 .70559 .25098 Mtetra
.975 .671 .352 r
.70559 .25098 .70646 .25218 .72056 .45689 .71965 .45576 Mtetra
.599 .137 0 r
.71965 .45576 .72056 .45689 .72276 .45984 .72185 .45871 Mtetra
.419 .653 .956 r
.72185 .45871 .72276 .45984 .72479 .45999 .72388 .45885 Mtetra
.71 .785 .91 r
.72388 .45885 .72479 .45999 .72676 .45906 .72585 .45793 Mtetra
.888 .815 .771 r
.72585 .45793 .72676 .45906 .72862 .45646 .72772 .45532 Mtetra
.977 .758 .541 r
.72772 .45532 .72862 .45646 .73009 .44758 .72919 .44643 Mtetra
.977 .679 .365 r
.72919 .44643 .73009 .44758 .71895 .23975 .71809 .23855 Mtetra
.936 .786 .669 r
.71809 .23855 .71895 .23975 .72058 .23567 .71973 .23447 Mtetra
.721 .762 .885 r
.71973 .23447 .72058 .23567 .72242 .23473 .72157 .23353 Mtetra
.581 .705 .927 r
.72157 .23353 .72242 .23473 .7243 .23442 .72345 .23323 Mtetra
.543 .687 .933 r
.72345 .23323 .7243 .23442 .72619 .23425 .72534 .23306 Mtetra
.658 .739 .909 r
.72534 .23306 .72619 .23425 .72805 .23363 .7272 .23243 Mtetra
.664 .741 .908 r
.7272 .23243 .72805 .23363 .72991 .23298 .72906 .23178 Mtetra
.701 .756 .894 r
.72906 .23178 .72991 .23298 .73176 .23214 .73091 .23094 Mtetra
.757 .774 .867 r
.73091 .23094 .73176 .23214 .73359 .23097 .73274 .22977 Mtetra
.674 .745 .904 r
.73274 .22977 .73359 .23097 .73545 .23027 .7346 .22907 Mtetra
.242 .514 .909 r
.7346 .22907 .73545 .23027 .7374 .23093 .73656 .22973 Mtetra
.896 .51 .065 r
.73656 .22973 .7374 .23093 .73987 .23892 .73903 .23772 Mtetra
.975 .667 .334 r
.73903 .23772 .73987 .23892 .75642 .44533 .75553 .44419 Mtetra
.634 .179 0 r
.75553 .44419 .75642 .44533 .75871 .44867 .75781 .44752 Mtetra
.392 .636 .953 r
.75781 .44752 .75871 .44867 .76078 .44889 .75989 .44775 Mtetra
.695 .781 .917 r
.75989 .44775 .76078 .44889 .76278 .44804 .76188 .44689 Mtetra
.873 .82 .793 r
.76188 .44689 .76278 .44804 .76466 .4457 .76377 .44455 Mtetra
.978 .767 .552 r
.76377 .44455 .76466 .4457 .76614 .4378 .76525 .43665 Mtetra
.977 .675 .347 r
.76525 .43665 .76614 .4378 .75258 .22852 .75174 .22732 Mtetra
.951 .785 .641 r
.75174 .22732 .75258 .22852 .75416 .22387 .75332 .22266 Mtetra
.748 .772 .873 r
.75332 .22266 .75416 .22387 .756 .22275 .75516 .22155 Mtetra
.622 .724 .92 r
.75516 .22155 .756 .22275 .75789 .22228 .75706 .22108 Mtetra
.591 .71 .926 r
.75706 .22108 .75789 .22228 .75979 .22194 .75896 .22073 Mtetra
.75 .773 .872 r
.75896 .22073 .75979 .22194 .76164 .22081 .7608 .2196 Mtetra
.676 .747 .904 r
.7608 .2196 .76164 .22081 .76352 .22009 .76268 .21888 Mtetra
.378 .596 .931 r
.76268 .21888 .76352 .22009 .76548 .22042 .76464 .21921 Mtetra
.806 .393 0 r
.76464 .21921 .76548 .22042 .76785 .22587 .76701 .22466 Mtetra
.973 .663 .318 r
.76701 .22466 .76785 .22587 .78654 .43441 .78567 .43325 Mtetra
.716 .274 0 r
.78567 .43325 .78654 .43441 .78896 .43862 .78808 .43746 Mtetra
.503 .695 .955 r
.78808 .43746 .78896 .43862 .79104 .43853 .79016 .43737 Mtetra
.695 .781 .918 r
.79016 .43737 .79104 .43853 .79305 .43767 .79218 .43651 Mtetra
.735 .795 .9 r
.79218 .43651 .79305 .43767 .79505 .43658 .79417 .43542 Mtetra
.496 .691 .955 r
.79417 .43542 .79505 .43658 .79713 .43651 .79626 .43535 Mtetra
.625 .753 .939 r
.79626 .43535 .79713 .43651 .79918 .43597 .7983 .43481 Mtetra
.811 .815 .854 r
.7983 .43481 .79918 .43597 .80113 .43434 .80026 .43317 Mtetra
.98 .772 .552 r
.80026 .43317 .80113 .43434 .80258 .42675 .80171 .42558 Mtetra
.976 .671 .329 r
.80171 .42558 .80258 .42675 .7866 .21698 .78578 .21576 Mtetra
.959 .784 .623 r
.78578 .21576 .7866 .21698 .78813 .21199 .78731 .21076 Mtetra
.751 .774 .872 r
.78731 .21076 .78813 .21199 .78999 .21084 .78917 .20961 Mtetra
.622 .723 .919 r
.78917 .20961 .78999 .21084 .7919 .21036 .79108 .20914 Mtetra
.553 .69 .93 r
.79108 .20914 .7919 .21036 .79385 .21015 .79303 .20893 Mtetra
.746 .773 .875 r
.79303 .20893 .79385 .21015 .79571 .20904 .79489 .20781 Mtetra
.677 .747 .904 r
.79489 .20781 .79571 .20904 .79761 .20831 .79679 .20708 Mtetra
.456 .638 .935 r
.79679 .20708 .79761 .20831 .79958 .20842 .79877 .2072 Mtetra
.768 .353 0 r
.79877 .2072 .79958 .20842 .80202 .21362 .80121 .21239 Mtetra
.971 .657 .298 r
.80121 .21239 .80202 .21362 .82324 .42297 .82238 .4218 Mtetra
.726 .292 0 r
.82238 .4218 .82324 .42297 .82578 .42761 .82492 .42644 Mtetra
.306 .58 .938 r
.82492 .42644 .82578 .42761 .82795 .4281 .82709 .42692 Mtetra
.649 .764 .933 r
.82709 .42692 .82795 .4281 .83001 .42745 .82915 .42627 Mtetra
.829 .821 .841 r
.82915 .42627 .83001 .42745 .83196 .42564 .8311 .42446 Mtetra
.975 .789 .59 r
.8311 .42446 .83196 .42564 .8335 .41953 .83264 .41836 Mtetra
.974 .667 .312 r
.83264 .41836 .8335 .41953 .81542 .20883 .81461 .2076 Mtetra
.975 .774 .571 r
.81461 .2076 .81542 .20883 .8168 .2025 .81599 .20126 Mtetra
.76 .758 .851 r
.19927 .41466 .20033 .41564 .20192 .41456 .20086 .41358 Mtetra
.612 .728 .928 r
.20086 .41358 .20192 .41456 .20343 .41422 .20237 .41323 Mtetra
.454 .669 .955 r
.20237 .41323 .20343 .41422 .20491 .41426 .20385 .41327 Mtetra
.654 .74 .912 r
.20385 .41327 .20491 .41426 .20644 .41376 .20538 .41277 Mtetra
.663 .742 .909 r
.20538 .41277 .20644 .41376 .20798 .41322 .20692 .41224 Mtetra
.669 .744 .906 r
.20692 .41224 .20798 .41322 .20952 .41266 .20846 .41168 Mtetra
.763 .759 .849 r
.20846 .41168 .20952 .41266 .21111 .41156 .21006 .41057 Mtetra
.709 .752 .886 r
.21006 .41057 .21111 .41156 .21267 .41081 .21162 .40982 Mtetra
.493 .685 .952 r
.21162 .40982 .21267 .41081 .21417 .41077 .21311 .40978 Mtetra
.932 .563 .281 r
.21311 .40978 .21417 .41077 .21523 .41521 .21417 .41422 Mtetra
.939 .683 .523 r
.21417 .41422 .21523 .41521 .19775 .61461 .19661 .61368 Mtetra
.931 .569 .306 r
.19661 .61368 .19775 .61461 .19886 .6196 .19773 .61866 Mtetra
0 .386 .824 r
.19773 .61866 .19886 .6196 .20038 .62033 .19925 .61939 Mtetra
.626 .757 .941 r
.19925 .61939 .20038 .62033 .20201 .61989 .20088 .61896 Mtetra
.802 .78 .833 r
.20088 .61896 .20201 .61989 .20375 .61841 .20261 .61747 Mtetra
.906 .743 .669 r
.20261 .61747 .20375 .61841 .20581 .61335 .20468 .61241 Mtetra
.939 .687 .53 r
.20468 .61241 .20581 .61335 .22591 .41305 .22486 .41203 Mtetra
.914 .724 .632 r
.22486 .41203 .22591 .41305 .22804 .40622 .22699 .40521 Mtetra
.794 .759 .821 r
.22699 .40521 .22804 .40622 .22967 .40482 .22862 .4038 Mtetra
.642 .732 .914 r
.22862 .4038 .22967 .40482 .23121 .40437 .23017 .40335 Mtetra
.499 .679 .946 r
.23017 .40335 .23121 .40437 .23272 .40434 .23167 .40331 Mtetra
.724 .748 .871 r
.23167 .40331 .23272 .40434 .23429 .40362 .23325 .40245 Mtetra
.688 .717 .871 r
.23325 .40245 .23429 .40362 .23585 .40298 .23482 .40178 Mtetra
.524 .652 .916 r
.23482 .40178 .23585 .40298 .23737 .40275 .23633 .40172 Mtetra
.906 .496 .155 r
.23633 .40172 .23737 .40275 .23876 .40416 .23754 .40509 Mtetra
.939 .681 .519 r
.23754 .40509 .23876 .40416 .23987 .40861 .22148 .60344 Mtetra
.548 .321 .522 r
.22148 .60344 .23987 .40861 .22428 .60362 .22252 .60991 Mtetra
.567 .276 .433 r
.22252 .60991 .22428 .60362 .22547 .60834 .22405 .61073 Mtetra
.418 .041 .213 r
.22405 .61073 .22547 .60834 .22692 .61014 .22569 .61043 Mtetra
.444 .879 .821 r
.22569 .61043 .22692 .61014 .22847 .61091 .22737 .6097 Mtetra
.655 .713 .89 r
.22737 .6097 .22847 .61091 .23008 .61093 .22903 .60915 Mtetra
.647 .63 .819 r
.22903 .60915 .23008 .61093 .23173 .61045 .23069 .60858 Mtetra
.657 .625 .806 r
.23069 .60858 .23173 .61045 .23343 .60951 .23236 .60793 Mtetra
.689 .67 .826 r
.23236 .60793 .23343 .60951 .23522 .60753 .23405 .60712 Mtetra
.724 .894 .957 r
.23405 .60712 .23522 .60753 .23709 .60449 .23574 .60624 Mtetra
.174 0 0 r
.23574 .60624 .23709 .60449 .2391 .59981 .23743 .60539 Mtetra
.504 .208 .397 r
.23743 .60539 .2391 .59981 .24085 .59819 .23906 .60526 Mtetra
.505 .224 .421 r
.23906 .60526 .24085 .59819 .24245 .59842 .24071 .60503 Mtetra
.452 .172 .396 r
.24071 .60503 .24245 .59842 .24414 .5976 .24241 .6041 Mtetra
0 0 .177 r
.24241 .6041 .24414 .5976 .26156 .40397 .24443 .59922 Mtetra
0 0 .15 r
.24443 .59922 .26156 .40397 .26375 .39586 .26239 .39869 Mtetra
.958 .887 .496 r
.26239 .39869 .26375 .39586 .26554 .39259 .26445 .39225 Mtetra
.864 .881 .847 r
.26445 .39225 .26554 .39259 .26716 .39143 .26611 .39056 Mtetra
.665 .772 .93 r
.26611 .39056 .26716 .39143 .26872 .39104 .26768 .39001 Mtetra
.544 .697 .939 r
.26768 .39001 .26872 .39104 .27026 .39094 .26923 .38985 Mtetra
.622 .715 .913 r
.26923 .38985 .27026 .39094 .27182 .39057 .27079 .38947 Mtetra
.654 .721 .898 r
.27079 .38947 .27182 .39057 .27339 .39003 .27236 .38896 Mtetra
.658 .727 .9 r
.27236 .38896 .27339 .39003 .27497 .38944 .27394 .38843 Mtetra
.68 .747 .901 r
.27394 .38843 .27497 .38944 .27657 .38858 .27552 .3878 Mtetra
.686 .799 .935 r
.27552 .3878 .27657 .38858 .27817 .38775 .27711 .38716 Mtetra
.663 .841 .968 r
.27711 .38716 .27817 .38775 .27975 .38719 .27869 .38657 Mtetra
.698 .84 .951 r
.27869 .38657 .27975 .38719 .28128 .38741 .28028 .38588 Mtetra
.641 .646 .84 r
.28028 .38588 .28128 .38741 .28273 .3886 .28186 .38539 Mtetra
.533 .454 .713 r
.28186 .38539 .28273 .3886 .28403 .39174 .28339 .3855 Mtetra
.22 .155 .567 r
.28339 .3855 .28403 .39174 .27103 .58718 .2847 .38866 Mtetra
0 0 .193 r
.2847 .38866 .27103 .58718 .27214 .59429 .27141 .58821 Mtetra
0 0 .31 r
.27141 .58821 .27214 .59429 .27362 .59661 .27258 .59465 Mtetra
.168 .347 .799 r
.27258 .59465 .27362 .59661 .27523 .59713 .27415 .59573 Mtetra
.611 .669 .881 r
.27415 .59573 .27523 .59713 .2769 .59676 .27583 .59537 Mtetra
.706 .702 .844 r
.27583 .59537 .2769 .59676 .27862 .59583 .27754 .59449 Mtetra
.659 .695 .873 r
.27754 .59449 .27862 .59583 .28038 .59428 .27924 .5939 Mtetra
.629 .89 .987 r
.27924 .5939 .28038 .59428 .28221 .59183 .28094 .59328 Mtetra
0 0 0 r
.28094 .59328 .28221 .59183 .28418 .58739 .28268 .59201 Mtetra
0 0 .026 r
.28268 .59201 .28418 .58739 .29969 .38967 .28465 .58759 Mtetra
0 0 .186 r
.28465 .58759 .29969 .38967 .30178 .38199 .30038 .38643 Mtetra
.799 .792 .296 r
.30038 .38643 .30178 .38199 .30354 .3791 .30244 .37916 Mtetra
.915 .931 .806 r
.30244 .37916 .30354 .3791 .30515 .37838 .30415 .37698 Mtetra
.676 .68 .846 r
.30415 .37698 .30515 .37838 .30665 .3792 .30575 .37632 Mtetra
.504 .454 .734 r
.30575 .37632 .30665 .3792 .30803 .3819 .30729 .37659 Mtetra
.236 .185 .594 r
.30729 .37659 .30803 .3819 .29665 .57442 .30868 .37922 Mtetra
0 0 .205 r
.30868 .37922 .29665 .57442 .29756 .58566 .29696 .57733 Mtetra
0 0 .285 r
.29696 .57733 .29756 .58566 .29905 .58836 .29803 .58618 Mtetra
.069 .255 .746 r
.29803 .58618 .29905 .58836 .30067 .58897 .2996 .58763 Mtetra
.596 .675 .895 r
.2996 .58763 .30067 .58897 .30237 .58853 .30129 .58733 Mtetra
.711 .735 .87 r
.30129 .58733 .30237 .58853 .30411 .58751 .30302 .58646 Mtetra
.668 .754 .915 r
.30302 .58646 .30411 .58751 .30588 .58598 .30473 .58585 Mtetra
.502 .889 .959 r
.30473 .58585 .30588 .58598 .30769 .58374 .30644 .58532 Mtetra
.012 0 0 r
.30644 .58532 .30769 .58374 .30961 .57985 .30819 .58418 Mtetra
0 0 .066 r
.30819 .58418 .30961 .57985 .32348 .38567 .3101 .58035 Mtetra
0 0 .196 r
.3101 .58035 .32348 .38567 .32574 .37465 .32432 .38009 Mtetra
.786 .761 .248 r
.32432 .38009 .32574 .37465 .32753 .37119 .32645 .37119 Mtetra
.933 .902 .771 r
.32645 .37119 .32753 .37119 .32921 .36944 .32819 .3686 Mtetra
.748 .799 .894 r
.32819 .3686 .32921 .36944 .33084 .36862 .32982 .36765 Mtetra
.51 .701 .956 r
.32982 .36765 .33084 .36862 .33243 .36839 .33141 .36755 Mtetra
.673 .154 0 r
.33141 .36755 .33243 .36839 .33395 .36929 .33288 .36929 Mtetra
.932 .616 .419 r
.33288 .36929 .33395 .36929 .33536 .37228 .33384 .37972 Mtetra
.941 .672 .502 r
.33384 .37972 .33536 .37228 .32576 .56234 .32377 .57668 Mtetra
.583 .323 .488 r
.32377 .57668 .32576 .56234 .32681 .57316 .32533 .57883 Mtetra
.493 .198 .393 r
.32533 .57883 .32681 .57316 .3285 .57312 .32704 .57855 Mtetra
.437 .144 .368 r
.32704 .57855 .3285 .57312 .33026 .57169 .32878 .57764 Mtetra
.45 .162 .384 r
.32878 .57764 .33026 .57169 .33203 .57026 .33052 .57678 Mtetra
.479 .195 .404 r
.33052 .57678 .33203 .57026 .33376 .56952 .33225 .5762 Mtetra
.479 .197 .406 r
.33225 .5762 .33376 .56952 .3355 .56877 .33398 .57561 Mtetra
.479 .198 .409 r
.33398 .57561 .3355 .56877 .33726 .56741 .33571 .57499 Mtetra
.485 .209 .42 r
.33571 .57499 .33726 .56741 .33905 .56568 .33744 .57437 Mtetra
.495 .226 .435 r
.33744 .57437 .33905 .56568 .34075 .56564 .33917 .57382 Mtetra
.504 .23 .433 r
.33917 .57382 .34075 .56564 .34226 .56894 .34089 .57347 Mtetra
.492 .179 .364 r
.34089 .57347 .34226 .56894 .34379 .57215 .3426 .5733 Mtetra
.33 0 0 r
.3426 .5733 .34379 .57215 .3454 .57389 .34431 .57313 Mtetra
.569 .787 .981 r
.34431 .57313 .3454 .57389 .34708 .57439 .34603 .57278 Mtetra
.641 .655 .848 r
.34603 .57278 .34708 .57439 .34881 .57396 .34777 .57225 Mtetra
.648 .645 .833 r
.34777 .57225 .34881 .57396 .35055 .57328 .34951 .57167 Mtetra
.648 .658 .846 r
.34951 .57167 .35055 .57328 .35229 .57259 .35124 .5711 Mtetra
.643 .672 .863 r
.35124 .5711 .35229 .57259 .35403 .57204 .35298 .57057 Mtetra
.643 .676 .867 r
.35298 .57057 .35403 .57204 .35577 .57149 .35472 .57005 Mtetra
.644 .68 .87 r
.35472 .57005 .35577 .57149 .35751 .57095 .35646 .56952 Mtetra
.646 .681 .869 r
.35646 .56952 .35751 .57095 .35925 .57044 .3582 .56898 Mtetra
.646 .678 .866 r
.3582 .56898 .35925 .57044 .36099 .56993 .35994 .56843 Mtetra
.6 .655 .875 r
.35994 .56843 .36099 .56993 .36273 .56955 .36168 .56811 Mtetra
.559 .646 .892 r
.36168 .56811 .36273 .56955 .36446 .56926 .3634 .56795 Mtetra
.672 .71 .877 r
.3634 .56795 .36446 .56926 .36621 .56864 .36515 .56728 Mtetra
.836 .74 .757 r
.36515 .56728 .36621 .56864 .368 .56703 .36699 .56491 Mtetra
.91 .695 .599 r
.36699 .56491 .368 .56703 .3699 .56328 .36914 .55558 Mtetra
.948 .681 .498 r
.36914 .55558 .3699 .56328 .37214 .55167 .38002 .35463 Mtetra
.544 .322 .528 r
.38002 .35463 .37214 .55167 .3826 .35648 .38181 .35088 Mtetra
.621 .456 .637 r
.38181 .35088 .3826 .35648 .38438 .35274 .38348 .34971 Mtetra
.622 .52 .718 r
.38348 .34971 .38438 .35274 .3861 .35056 .38512 .34909 Mtetra
.635 .66 .857 r
.38512 .34909 .3861 .35056 .38778 .34923 .38676 .34862 Mtetra
.653 .844 .974 r
.38676 .34862 .38778 .34923 .38943 .34854 .38841 .34804 Mtetra
.62 .86 .988 r
.38841 .34804 .38943 .34854 .39107 .34809 .39006 .34751 Mtetra
.628 .844 .982 r
.39006 .34751 .39107 .34809 .39271 .34766 .3917 .34698 Mtetra
.649 .826 .968 r
.3917 .34698 .39271 .34766 .39436 .34708 .39335 .34643 Mtetra
.647 .831 .971 r
.39335 .34643 .39436 .34708 .39601 .3465 .395 .34587 Mtetra
.691 .846 .957 r
.395 .34587 .39601 .3465 .39766 .34583 .39666 .34516 Mtetra
.741 .845 .928 r
.39666 .34516 .39766 .34583 .39932 .34504 .39832 .34426 Mtetra
.637 .798 .96 r
.39832 .34426 .39932 .34504 .40097 .34451 .39997 .34376 Mtetra
0 .377 .801 r
.39997 .34376 .40097 .34451 .4026 .34473 .40158 .3445 Mtetra
.919 .55 .307 r
.40158 .3445 .4026 .34473 .40415 .34671 .40299 .35017 Mtetra
.953 .679 .479 r
.40299 .35017 .40415 .34671 .40554 .3533 .39697 .55229 Mtetra
.542 .316 .521 r
.39697 .55229 .40554 .3533 .39985 .55121 .39857 .55606 Mtetra
.529 .219 .385 r
.39857 .55606 .39985 .55121 .40146 .55477 .40031 .55632 Mtetra
.314 0 .037 r
.40031 .55632 .40146 .55477 .40316 .55625 .40208 .5559 Mtetra
.611 .899 .987 r
.40208 .5559 .40316 .55625 .40489 .55678 .40385 .55526 Mtetra
.63 .666 .866 r
.40385 .55526 .40489 .55678 .40665 .55661 .40562 .55479 Mtetra
.639 .631 .826 r
.40562 .55479 .40665 .55661 .40842 .55614 .4074 .55424 Mtetra
.623 .615 .822 r
.4074 .55424 .40842 .55614 .41019 .55558 .40917 .55378 Mtetra
.571 .602 .844 r
.40917 .55378 .41019 .55558 .41196 .55516 .41093 .55359 Mtetra
.656 .67 .851 r
.41093 .55359 .41196 .55516 .41375 .55443 .41271 .55297 Mtetra
.8 .728 .785 r
.41271 .55297 .41375 .55443 .41555 .55298 .41453 .55115 Mtetra
.905 .709 .627 r
.41453 .55115 .41555 .55298 .41742 .54971 .4165 .54456 Mtetra
.956 .685 .484 r
.4165 .54456 .41742 .54971 .41941 .54249 .42471 .34085 Mtetra
.547 .324 .528 r
.42471 .34085 .41941 .54249 .42732 .34267 .42653 .33579 Mtetra
.616 .438 .618 r
.42653 .33579 .42732 .34267 .42912 .33793 .42822 .33444 Mtetra
.621 .502 .697 r
.42822 .33444 .42912 .33793 .43085 .33544 .4299 .33374 Mtetra
.625 .627 .832 r
.4299 .33374 .43085 .33544 .43255 .3339 .43157 .3333 Mtetra
.65 .847 .976 r
.43157 .3333 .43255 .3339 .43423 .33315 .43324 .33271 Mtetra
.599 .872 .993 r
.43324 .33271 .43423 .33315 .4359 .33267 .43491 .33219 Mtetra
.602 .862 .992 r
.43491 .33219 .4359 .33267 .43757 .33228 .43659 .33168 Mtetra
.643 .845 .977 r
.43659 .33168 .43757 .33228 .43925 .33171 .43826 .3311 Mtetra
.644 .846 .978 r
.43826 .3311 .43925 .33171 .44093 .33115 .43994 .33053 Mtetra
.643 .842 .977 r
.43994 .33053 .44093 .33115 .4426 .33063 .44162 .32996 Mtetra
.641 .829 .973 r
.44162 .32996 .4426 .33063 .44428 .33021 .4433 .32941 Mtetra
.65 .8 .955 r
.4433 .32941 .44428 .33021 .44596 .3298 .44498 .32886 Mtetra
.658 .769 .932 r
.44498 .32886 .44596 .3298 .44763 .32936 .44666 .32829 Mtetra
.667 .745 .909 r
.44666 .32829 .44763 .32936 .44932 .32882 .44835 .32769 Mtetra
.668 .734 .899 r
.44835 .32769 .44932 .32882 .451 .32822 .45003 .32708 Mtetra
.669 .732 .897 r
.45003 .32708 .451 .32822 .45269 .32755 .45172 .32647 Mtetra
.668 .742 .906 r
.45172 .32647 .45269 .32755 .45438 .32679 .45341 .32586 Mtetra
.668 .775 .93 r
.45341 .32586 .45438 .32679 .45607 .32602 .4551 .32525 Mtetra
.663 .812 .955 r
.4551 .32525 .45607 .32602 .45776 .32528 .45678 .32464 Mtetra
.651 .842 .974 r
.45678 .32464 .45776 .32528 .45945 .32464 .45847 .32405 Mtetra
.645 .851 .979 r
.45847 .32405 .45945 .32464 .46114 .32406 .46017 .32346 Mtetra
.643 .849 .979 r
.46017 .32346 .46114 .32406 .46283 .32354 .46186 .32288 Mtetra
.645 .835 .973 r
.46186 .32288 .46283 .32354 .46452 .32312 .46355 .32231 Mtetra
.653 .8 .953 r
.46355 .32231 .46452 .32312 .46621 .32272 .46524 .32174 Mtetra
.656 .762 .928 r
.46524 .32174 .46621 .32272 .4679 .32231 .46694 .32118 Mtetra
.655 .731 .905 r
.46694 .32118 .4679 .32231 .46959 .32178 .46863 .32063 Mtetra
.655 .727 .902 r
.46863 .32063 .46959 .32178 .47129 .32121 .47033 .32007 Mtetra
.656 .73 .904 r
.47033 .32007 .47129 .32121 .47299 .32061 .47203 .31951 Mtetra
.658 .738 .909 r
.47203 .31951 .47299 .32061 .47469 .32004 .47373 .31894 Mtetra
.661 .739 .908 r
.47373 .31894 .47469 .32004 .47639 .31944 .47543 .31836 Mtetra
.665 .745 .91 r
.47543 .31836 .47639 .31944 .47809 .3188 .47713 .31776 Mtetra
.673 .757 .914 r
.47713 .31776 .47809 .3188 .47979 .31802 .47883 .31713 Mtetra
.676 .789 .934 r
.47883 .31713 .47979 .31802 .4815 .31724 .48054 .31648 Mtetra
.675 .822 .954 r
.48054 .31648 .4815 .31724 .4832 .31646 .48224 .31583 Mtetra
.682 .852 .964 r
.48224 .31583 .4832 .31646 .48491 .3156 .48395 .31513 Mtetra
.652 .885 .983 r
.48395 .31513 .48491 .3156 .48662 .31492 .48566 .31447 Mtetra
.622 .88 .989 r
.48566 .31447 .48662 .31492 .48832 .31457 .48737 .31387 Mtetra
.707 .844 .948 r
.48737 .31387 .48832 .31457 .49002 .31511 .48908 .31309 Mtetra
.613 .588 .801 r
.48908 .31309 .49002 .31511 .49171 .31663 .49079 .31268 Mtetra
.514 .419 .686 r
.49079 .31268 .49171 .31663 .49337 .32101 .49249 .313 Mtetra
.133 .082 .529 r
.49249 .313 .49337 .32101 .49318 .52142 .49414 .31847 Mtetra
0 0 .321 r
.49414 .31847 .49318 .52142 .49496 .52627 .49397 .52204 Mtetra
0 0 .507 r
.49397 .52204 .49496 .52627 .49677 .52805 .49576 .52643 Mtetra
.492 .591 .881 r
.49576 .52643 .49677 .52805 .4986 .52776 .49758 .52654 Mtetra
.671 .736 .899 r
.49758 .52654 .4986 .52776 .50043 .52693 .49942 .52586 Mtetra
.743 .783 .886 r
.49942 .52586 .50043 .52693 .50227 .52587 .50126 .5248 Mtetra
.634 .752 .933 r
.50126 .5248 .50227 .52587 .50411 .52563 .5031 .52428 Mtetra
.637 .702 .893 r
.5031 .52428 .50411 .52563 .50594 .5253 .50493 .52376 Mtetra
.649 .677 .864 r
.50493 .52376 .50594 .5253 .50778 .52464 .50677 .52317 Mtetra
.606 .67 .885 r
.50677 .52317 .50778 .52464 .50963 .5229 .50861 .52279 Mtetra
.558 .924 .941 r
.50861 .52279 .50963 .5229 .51148 .52006 .51045 .52205 Mtetra
.054 0 0 r
.51045 .52205 .51148 .52006 .51333 .51448 .5123 .52052 Mtetra
0 0 .151 r
.5123 .52052 .51333 .51448 .51576 .31275 .51416 .51407 Mtetra
0 0 .316 r
.51416 .51407 .51576 .31275 .5175 .30678 .51655 .30894 Mtetra
.866 .848 .387 r
.51655 .30894 .5175 .30678 .51923 .30399 .51829 .30346 Mtetra
.818 .896 .897 r
.51829 .30346 .51923 .30399 .52096 .30307 .52002 .30211 Mtetra
.638 .765 .94 r
.52002 .30211 .52096 .30307 .52269 .30272 .52175 .3016 Mtetra
.532 .688 .939 r
.52175 .3016 .52269 .30272 .52442 .30262 .52348 .30147 Mtetra
.641 .725 .91 r
.52348 .30147 .52442 .30262 .52615 .30214 .52521 .30096 Mtetra
.657 .727 .901 r
.52521 .30096 .52615 .30214 .52788 .30153 .52694 .30039 Mtetra
.661 .735 .904 r
.52694 .30039 .52788 .30153 .52961 .30086 .52868 .29979 Mtetra
.755 .777 .871 r
.52868 .29979 .52961 .30086 .53135 .29961 .53041 .29869 Mtetra
.717 .798 .915 r
.53041 .29869 .53135 .29961 .53308 .29865 .53215 .29785 Mtetra
.504 .753 .985 r
.53215 .29785 .53308 .29865 .53482 .29838 .53389 .29768 Mtetra
.858 .409 .026 r
.53389 .29768 .53482 .29838 .53657 .30197 .53564 .30128 Mtetra
.969 .682 .429 r
.53564 .30128 .53657 .30197 .5392 .50786 .5382 .50634 Mtetra
.904 .516 .086 r
.5382 .50634 .5392 .50786 .54109 .51401 .54009 .51248 Mtetra
.316 .51 .888 r
.54009 .51248 .54109 .51401 .54296 .51463 .54196 .51309 Mtetra
.645 .677 .865 r
.54196 .51309 .54296 .51463 .54482 .51396 .54383 .51251 Mtetra
.728 .722 .845 r
.54383 .51251 .54482 .51396 .54668 .51254 .54569 .51142 Mtetra
.627 .744 .931 r
.54569 .51142 .54668 .51254 .54854 .51077 .54756 .51092 Mtetra
.359 .83 .802 r
.54756 .51092 .54854 .51077 .55039 .50821 .54942 .51026 Mtetra
.138 0 .043 r
.54942 .51026 .55039 .50821 .55223 .50371 .55129 .50891 Mtetra
0 0 .177 r
.55129 .50891 .55223 .50371 .55234 .30353 .55312 .5038 Mtetra
0 0 .331 r
.55312 .5038 .55234 .30353 .55402 .29529 .55313 .29819 Mtetra
.825 .788 .288 r
.55313 .29819 .55402 .29529 .55575 .29208 .55483 .29128 Mtetra
.852 .84 .833 r
.55483 .29128 .55575 .29208 .55749 .29077 .55657 .2895 Mtetra
.67 .716 .883 r
.55657 .2895 .55749 .29077 .55924 .29014 .55832 .28884 Mtetra
.579 .675 .906 r
.55832 .28884 .55924 .29014 .561 .28974 .56007 .28859 Mtetra
.729 .758 .876 r
.56007 .28859 .561 .28974 .56275 .28864 .56183 .28763 Mtetra
.724 .785 .9 r
.56183 .28763 .56275 .28864 .5645 .28762 .56358 .28673 Mtetra
.557 .754 .969 r
.56358 .28673 .5645 .28762 .56625 .28723 .56534 .28645 Mtetra
.771 .288 0 r
.56534 .28645 .56625 .28723 .56806 .28981 .56714 .28926 Mtetra
.971 .681 .416 r
.56714 .28926 .56806 .28981 .57276 .49332 .5718 .49353 Mtetra
.923 .552 .295 r
.5718 .49353 .57276 .49332 .57479 .5025 .57381 .5015 Mtetra
0 .222 .71 r
.57381 .5015 .57479 .5025 .5767 .50393 .57572 .50285 Mtetra
.566 .729 .951 r
.57572 .50285 .5767 .50393 .5786 .50366 .57762 .50256 Mtetra
.782 .795 .863 r
.57762 .50256 .5786 .50366 .58047 .5023 .57949 .5012 Mtetra
.929 .783 .678 r
.57949 .5012 .58047 .5023 .5823 .49802 .58132 .4969 Mtetra
.973 .688 .426 r
.58132 .4969 .5823 .49802 .58054 .29333 .57962 .29205 Mtetra
.959 .733 .554 r
.57962 .29205 .58054 .29333 .58214 .2835 .58123 .28234 Mtetra
.852 .781 .782 r
.58123 .28234 .58214 .2835 .58388 .28137 .58297 .28022 Mtetra
.673 .743 .903 r
.58297 .28022 .58388 .28137 .58565 .2807 .58474 .27956 Mtetra
.55 .695 .935 r
.58474 .27956 .58565 .2807 .58743 .2805 .58651 .27937 Mtetra
.698 .755 .896 r
.58651 .27937 .58743 .2805 .58919 .27969 .58828 .27859 Mtetra
.714 .765 .892 r
.58828 .27859 .58919 .27969 .59096 .27881 .59005 .27772 Mtetra
.572 .716 .94 r
.59005 .27772 .59096 .27881 .59274 .27854 .59183 .27745 Mtetra
.637 .17 0 r
.59183 .27745 .59274 .27854 .59459 .28132 .59368 .28002 Mtetra
.973 .68 .404 r
.59368 .28002 .59459 .28132 .60111 .48677 .60011 .48419 Mtetra
.873 .528 .026 r
.60011 .48419 .60111 .48677 .6032 .49417 .60222 .49253 Mtetra
.129 .376 .833 r
.60222 .49253 .6032 .49417 .60514 .49518 .60417 .49371 Mtetra
.632 .688 .884 r
.60417 .49371 .60514 .49518 .60705 .49449 .60607 .49319 Mtetra
.726 .749 .871 r
.60607 .49319 .60705 .49449 .60894 .49331 .60797 .49216 Mtetra
.607 .735 .936 r
.60797 .49216 .60894 .49331 .61085 .4929 .60989 .49174 Mtetra
.559 .711 .942 r
.60989 .49174 .61085 .4929 .61277 .49279 .61181 .49149 Mtetra
.7 .741 .883 r
.61181 .49149 .61277 .49279 .61468 .49207 .61371 .49062 Mtetra
.894 .758 .705 r
.61371 .49062 .61468 .49207 .61652 .48871 .61554 .48705 Mtetra
.974 .686 .414 r
.61554 .48705 .61652 .48871 .61778 .46493 .61185 .28615 Mtetra
.567 .339 .53 r
.61185 .28615 .61778 .46493 .61416 .27292 .61325 .27165 Mtetra
.868 .77 .751 r
.61325 .27165 .61416 .27292 .61589 .27028 .61499 .26911 Mtetra
.691 .748 .896 r
.61499 .26911 .61589 .27028 .61767 .26951 .61677 .26836 Mtetra
.571 .704 .932 r
.61677 .26836 .61767 .26951 .61947 .26925 .61857 .2681 Mtetra
.686 .749 .899 r
.61857 .2681 .61947 .26925 .62126 .26852 .62036 .26737 Mtetra
.727 .762 .881 r
.62036 .26737 .62126 .26852 .62304 .26756 .62214 .26641 Mtetra
.611 .721 .923 r
.62214 .26641 .62304 .26756 .62484 .26715 .62395 .266 Mtetra
0 .06 .595 r
.62395 .266 .62484 .26715 .62672 .26904 .62582 .2679 Mtetra
.974 .678 .39 r
.62582 .2679 .62672 .26904 .63521 .4681 .63426 .46708 Mtetra
.956 .611 .27 r
.63426 .46708 .63521 .4681 .63763 .48213 .63667 .48103 Mtetra
0 .147 .66 r
.63667 .48103 .63763 .48213 .63963 .48381 .63868 .48272 Mtetra
.605 .747 .945 r
.63868 .48272 .63963 .48381 .64157 .48338 .64062 .48228 Mtetra
.728 .79 .902 r
.64062 .48228 .64157 .48338 .64348 .4824 .64253 .48128 Mtetra
.628 .752 .936 r
.64253 .48128 .64348 .4824 .64542 .48199 .64447 .48077 Mtetra
.539 .693 .939 r
.64447 .48077 .64542 .48199 .64738 .48195 .64642 .48059 Mtetra
.681 .727 .885 r
.64642 .48059 .64738 .48195 .64931 .48131 .64835 .47982 Mtetra
.881 .759 .723 r
.64835 .47982 .64931 .48131 .65116 .47833 .65019 .47665 Mtetra
.972 .707 .469 r
.65019 .47665 .65116 .47833 .65255 .46377 .65125 .45336 Mtetra
.968 .674 .418 r
.65125 .45336 .65255 .46377 .64654 .26196 .64565 .26064 Mtetra
.884 .768 .729 r
.64565 .26064 .64654 .26196 .64826 .25894 .64737 .25775 Mtetra
.703 .751 .889 r
.64737 .25775 .64826 .25894 .65006 .25809 .64917 .25692 Mtetra
.587 .709 .927 r
.64917 .25692 .65006 .25809 .65188 .25777 .651 .2566 Mtetra
.667 .741 .906 r
.651 .2566 .65188 .25777 .65369 .25713 .65281 .25595 Mtetra
.733 .764 .877 r
.65281 .25595 .65369 .25713 .65549 .25612 .65461 .25494 Mtetra
.637 .73 .916 r
.65461 .25494 .65549 .25612 .65731 .2556 .65643 .25443 Mtetra
0 .283 .781 r
.65643 .25443 .65731 .2556 .65921 .25692 .65833 .25575 Mtetra
.938 .574 .185 r
.65833 .25575 .65921 .25692 .66149 .26674 .66061 .26558 Mtetra
.975 .675 .374 r
.66061 .26558 .66149 .26674 .67246 .47008 .67152 .46897 Mtetra
0 0 .511 r
.67152 .46897 .67246 .47008 .67454 .47236 .6736 .47124 Mtetra
.629 .756 .938 r
.6736 .47124 .67454 .47236 .67649 .47182 .67556 .47071 Mtetra
.769 .801 .879 r
.67556 .47071 .67649 .47182 .67842 .47055 .67748 .46943 Mtetra
.781 .803 .871 r
.67748 .46943 .67842 .47055 .68034 .46919 .67941 .46807 Mtetra
.727 .789 .901 r
.67941 .46807 .68034 .46919 .68227 .46819 .68134 .46706 Mtetra
.712 .783 .907 r
.68134 .46706 .68227 .46819 .68422 .46727 .68329 .46613 Mtetra
.654 .761 .928 r
.68329 .46613 .68422 .46727 .68617 .46664 .68524 .4655 Mtetra
.567 .724 .947 r
.68524 .4655 .68617 .46664 .68815 .46633 .68722 .4652 Mtetra
.539 .712 .952 r
.68722 .4652 .68815 .46633 .69013 .46612 .6892 .46499 Mtetra
.447 .668 .956 r
.6892 .46499 .69013 .46612 .69213 .46619 .6912 .46506 Mtetra
.417 .652 .956 r
.6912 .46506 .69213 .46619 .69413 .46633 .69321 .46521 Mtetra
.629 .754 .938 r
.69321 .46521 .69413 .46633 .6961 .4658 .69518 .46467 Mtetra
.89 .812 .765 r
.69518 .46467 .6961 .4658 .69796 .46312 .69704 .46199 Mtetra
.981 .724 .468 r
.69704 .46199 .69796 .46312 .69904 .44578 .69812 .44458 Mtetra
.977 .681 .379 r
.69812 .44458 .69904 .44578 .69031 .24686 .68944 .24567 Mtetra
.912 .79 .713 r
.68944 .24567 .69031 .24686 .69201 .24361 .69114 .24243 Mtetra
.708 .758 .891 r
.69114 .24243 .69201 .24361 .69383 .24275 .69297 .24156 Mtetra
.587 .709 .927 r
.69297 .24156 .69383 .24275 .69569 .24242 .69482 .24124 Mtetra
.622 .724 .92 r
.69482 .24124 .69569 .24242 .69754 .24196 .69667 .24077 Mtetra
.731 .765 .88 r
.69667 .24077 .69754 .24196 .69936 .24096 .6985 .23977 Mtetra
.639 .731 .915 r
.6985 .23977 .69936 .24096 .70121 .24043 .70035 .23924 Mtetra
.061 .397 .854 r
.70035 .23924 .70121 .24043 .70315 .24147 .70229 .24028 Mtetra
.925 .554 .141 r
.70229 .24028 .70315 .24147 .70559 .25098 .70473 .24976 Mtetra
.975 .671 .352 r
.70473 .24976 .70559 .25098 .71965 .45576 .71874 .45462 Mtetra
.599 .137 0 r
.71874 .45462 .71965 .45576 .72185 .45871 .72094 .45757 Mtetra
.419 .653 .956 r
.72094 .45757 .72185 .45871 .72388 .45885 .72297 .45772 Mtetra
.71 .785 .91 r
.72297 .45772 .72388 .45885 .72585 .45793 .72494 .45679 Mtetra
.888 .815 .771 r
.72494 .45679 .72585 .45793 .72772 .45532 .72681 .45418 Mtetra
.977 .758 .54 r
.72681 .45418 .72772 .45532 .72919 .44643 .72828 .44526 Mtetra
.977 .679 .365 r
.72828 .44526 .72919 .44643 .71809 .23855 .71724 .23734 Mtetra
.936 .785 .669 r
.71724 .23734 .71809 .23855 .71973 .23447 .71888 .23327 Mtetra
.72 .761 .885 r
.71888 .23327 .71973 .23447 .72157 .23353 .72071 .23233 Mtetra
.581 .704 .927 r
.72071 .23233 .72157 .23353 .72345 .23323 .72259 .23202 Mtetra
.543 .686 .932 r
.72259 .23202 .72345 .23323 .72534 .23306 .72449 .23185 Mtetra
.658 .738 .909 r
.72449 .23185 .72534 .23306 .7272 .23243 .72635 .23123 Mtetra
.664 .74 .907 r
.72635 .23123 .7272 .23243 .72906 .23178 .72821 .23058 Mtetra
.701 .755 .894 r
.72821 .23058 .72906 .23178 .73091 .23094 .73006 .22974 Mtetra
.757 .774 .867 r
.73006 .22974 .73091 .23094 .73274 .22977 .73189 .22857 Mtetra
.674 .745 .904 r
.73189 .22857 .73274 .22977 .7346 .22907 .73375 .22787 Mtetra
.242 .514 .909 r
.73375 .22787 .7346 .22907 .73656 .22973 .73571 .22853 Mtetra
.896 .51 .065 r
.73571 .22853 .73656 .22973 .73903 .23772 .73818 .23651 Mtetra
.975 .667 .334 r
.73818 .23651 .73903 .23772 .75553 .44419 .75463 .44304 Mtetra
.634 .179 0 r
.75463 .44304 .75553 .44419 .75781 .44752 .75692 .44637 Mtetra
.392 .636 .953 r
.75692 .44637 .75781 .44752 .75989 .44775 .75899 .4466 Mtetra
.695 .781 .917 r
.75899 .4466 .75989 .44775 .76188 .44689 .76099 .44575 Mtetra
.873 .82 .793 r
.76099 .44575 .76188 .44689 .76377 .44455 .76288 .4434 Mtetra
.978 .767 .552 r
.76288 .4434 .76377 .44455 .76525 .43665 .76436 .4355 Mtetra
.977 .675 .347 r
.76436 .4355 .76525 .43665 .75174 .22732 .7509 .22611 Mtetra
.951 .785 .641 r
.7509 .22611 .75174 .22732 .75332 .22266 .75248 .22146 Mtetra
.748 .773 .873 r
.75248 .22146 .75332 .22266 .75516 .22155 .75432 .22034 Mtetra
.622 .724 .92 r
.75432 .22034 .75516 .22155 .75706 .22108 .75622 .21987 Mtetra
.591 .71 .926 r
.75622 .21987 .75706 .22108 .75896 .22073 .75812 .21952 Mtetra
.75 .773 .872 r
.75812 .21952 .75896 .22073 .7608 .2196 .75997 .21839 Mtetra
.676 .747 .904 r
.75997 .21839 .7608 .2196 .76268 .21888 .76185 .21767 Mtetra
.377 .596 .932 r
.76185 .21767 .76268 .21888 .76464 .21921 .76381 .218 Mtetra
.807 .393 0 r
.76381 .218 .76464 .21921 .76701 .22466 .76618 .22345 Mtetra
.973 .663 .318 r
.76618 .22345 .76701 .22466 .78567 .43325 .78479 .4321 Mtetra
.717 .274 0 r
.78479 .4321 .78567 .43325 .78808 .43746 .7872 .43631 Mtetra
.503 .696 .955 r
.7872 .43631 .78808 .43746 .79016 .43737 .78928 .43621 Mtetra
.695 .782 .918 r
.78928 .43621 .79016 .43737 .79218 .43651 .7913 .43535 Mtetra
.735 .795 .9 r
.7913 .43535 .79218 .43651 .79417 .43542 .7933 .43426 Mtetra
.496 .692 .955 r
.7933 .43426 .79417 .43542 .79626 .43535 .79538 .43419 Mtetra
.625 .753 .939 r
.79538 .43419 .79626 .43535 .7983 .43481 .79743 .43365 Mtetra
.811 .815 .854 r
.79743 .43365 .7983 .43481 .80026 .43317 .79938 .43201 Mtetra
.98 .772 .552 r
.79938 .43201 .80026 .43317 .80171 .42558 .80083 .42441 Mtetra
.976 .671 .329 r
.80083 .42441 .80171 .42558 .78578 .21576 .78496 .21454 Mtetra
.959 .784 .623 r
.78496 .21454 .78578 .21576 .78731 .21076 .78648 .20954 Mtetra
.751 .774 .872 r
.78648 .20954 .78731 .21076 .78917 .20961 .78834 .20839 Mtetra
.622 .723 .919 r
.78834 .20839 .78917 .20961 .79108 .20914 .79026 .20791 Mtetra
.552 .69 .931 r
.79026 .20791 .79108 .20914 .79303 .20893 .79221 .2077 Mtetra
.746 .773 .875 r
.79221 .2077 .79303 .20893 .79489 .20781 .79407 .20659 Mtetra
.677 .747 .904 r
.79407 .20659 .79489 .20781 .79679 .20708 .79597 .20586 Mtetra
.456 .638 .935 r
.79597 .20586 .79679 .20708 .79877 .2072 .79795 .20597 Mtetra
.768 .353 0 r
.79795 .20597 .79877 .2072 .80121 .21239 .80039 .21117 Mtetra
.971 .657 .298 r
.80039 .21117 .80121 .21239 .82238 .4218 .82152 .42062 Mtetra
.726 .292 0 r
.82152 .42062 .82238 .4218 .82492 .42644 .82406 .42527 Mtetra
.306 .58 .938 r
.82406 .42527 .82492 .42644 .82709 .42692 .82623 .42575 Mtetra
.649 .764 .933 r
.82623 .42575 .82709 .42692 .82915 .42627 .82829 .4251 Mtetra
.829 .821 .841 r
.82829 .4251 .82915 .42627 .8311 .42446 .83024 .42329 Mtetra
.975 .789 .59 r
.83024 .42329 .8311 .42446 .83264 .41836 .83179 .41718 Mtetra
.974 .667 .312 r
.83179 .41718 .83264 .41836 .81461 .2076 .8138 .20637 Mtetra
.975 .774 .571 r
.8138 .20637 .81461 .2076 .81599 .20126 .81518 .20003 Mtetra
.76 .758 .851 r
.19821 .41367 .19927 .41466 .20086 .41358 .1998 .41259 Mtetra
.612 .727 .928 r
.1998 .41259 .20086 .41358 .20237 .41323 .20131 .41224 Mtetra
.454 .668 .955 r
.20131 .41224 .20237 .41323 .20385 .41327 .20279 .41228 Mtetra
.654 .739 .912 r
.20279 .41228 .20385 .41327 .20538 .41277 .20432 .41178 Mtetra
.663 .742 .908 r
.20432 .41178 .20538 .41277 .20692 .41224 .20586 .41125 Mtetra
.669 .743 .906 r
.20586 .41125 .20692 .41224 .20846 .41168 .2074 .41069 Mtetra
.763 .759 .849 r
.2074 .41069 .20846 .41168 .21006 .41057 .209 .40958 Mtetra
.709 .752 .885 r
.209 .40958 .21006 .41057 .21162 .40982 .21056 .40883 Mtetra
.493 .685 .952 r
.21056 .40883 .21162 .40982 .21311 .40978 .21205 .40879 Mtetra
.932 .563 .281 r
.21205 .40879 .21311 .40978 .21417 .41422 .21311 .41324 Mtetra
.939 .683 .523 r
.21311 .41324 .21417 .41422 .19661 .61368 .19548 .61275 Mtetra
.931 .569 .306 r
.19548 .61275 .19661 .61368 .19773 .61866 .19659 .61773 Mtetra
0 .387 .824 r
.19659 .61773 .19773 .61866 .19925 .61939 .19811 .61846 Mtetra
.626 .757 .941 r
.19811 .61846 .19925 .61939 .20088 .61896 .19975 .61802 Mtetra
.802 .78 .833 r
.19975 .61802 .20088 .61896 .20261 .61747 .20148 .61653 Mtetra
.906 .743 .669 r
.20148 .61653 .20261 .61747 .20468 .61241 .20355 .61146 Mtetra
.939 .687 .53 r
.20355 .61146 .20468 .61241 .22486 .41203 .22381 .41101 Mtetra
.914 .724 .632 r
.22381 .41101 .22486 .41203 .22699 .40521 .22594 .40421 Mtetra
.795 .759 .82 r
.22594 .40421 .22699 .40521 .22862 .4038 .22757 .40279 Mtetra
.644 .733 .914 r
.22757 .40279 .22862 .4038 .23017 .40335 .22912 .40233 Mtetra
.501 .682 .947 r
.22912 .40233 .23017 .40335 .23167 .40331 .23062 .40228 Mtetra
.734 .751 .866 r
.23062 .40228 .23167 .40331 .23325 .40245 .23221 .40137 Mtetra
.695 .732 .88 r
.23221 .40137 .23325 .40245 .23482 .40178 .23378 .40067 Mtetra
.485 .656 .936 r
.23378 .40067 .23482 .40178 .23633 .40172 .23528 .40069 Mtetra
.934 .565 .274 r
.23528 .40069 .23633 .40172 .23754 .40509 .23638 .40528 Mtetra
.94 .682 .519 r
.23638 .40528 .23754 .40509 .22148 .60344 .22006 .6059 Mtetra
.799 .474 .438 r
.22006 .6059 .22148 .60344 .22252 .60991 .22124 .61063 Mtetra
.43 0 0 r
.22124 .61063 .22252 .60991 .22405 .61073 .22283 .61088 Mtetra
.603 .95 .909 r
.22283 .61088 .22405 .61073 .22569 .61043 .22452 .61001 Mtetra
.815 .884 .894 r
.22452 .61001 .22569 .61043 .22737 .6097 .22625 .60867 Mtetra
.716 .76 .887 r
.22625 .60867 .22737 .6097 .22903 .60915 .22794 .60783 Mtetra
.669 .699 .869 r
.22794 .60783 .22903 .60915 .23069 .60858 .22961 .6072 Mtetra
.65 .683 .868 r
.22961 .6072 .23069 .60858 .23236 .60793 .23127 .60666 Mtetra
.62 .693 .896 r
.23127 .60666 .23236 .60793 .23405 .60712 .23292 .60627 Mtetra
.584 .766 .966 r
.23292 .60627 .23405 .60712 .23574 .60624 .23457 .60593 Mtetra
.462 .842 .986 r
.23457 .60593 .23574 .60624 .23743 .60539 .23621 .6056 Mtetra
.062 0 0 r
.23621 .6056 .23743 .60539 .23906 .60526 .23784 .60552 Mtetra
0 0 0 r
.23784 .60552 .23906 .60526 .24071 .60503 .23949 .60524 Mtetra
.544 .928 .878 r
.23949 .60524 .24071 .60503 .24241 .6041 .24118 .60442 Mtetra
.945 .919 .755 r
.24118 .60442 .24241 .6041 .24443 .59922 .24305 .60148 Mtetra
.997 .86 .561 r
.24305 .60148 .24443 .59922 .26239 .39869 .24533 .59352 Mtetra
0 0 .157 r
.24533 .59352 .26239 .39869 .26445 .39225 .26307 .39538 Mtetra
0 0 0 r
.26307 .39538 .26445 .39225 .26611 .39056 .2649 .39166 Mtetra
.637 .904 .595 r
.2649 .39166 .26611 .39056 .26768 .39001 .26658 .38985 Mtetra
.799 .942 .92 r
.26658 .38985 .26768 .39001 .26923 .38985 .2682 .38867 Mtetra
.704 .72 .862 r
.2682 .38867 .26923 .38985 .27079 .38947 .2698 .38789 Mtetra
.648 .644 .832 r
.2698 .38789 .27079 .38947 .27236 .38896 .27137 .38736 Mtetra
.622 .63 .838 r
.27137 .38736 .27236 .38896 .27394 .38843 .27294 .38697 Mtetra
.628 .652 .854 r
.27294 .38697 .27394 .38843 .27552 .3878 .27451 .38655 Mtetra
.637 .689 .882 r
.27451 .38655 .27552 .3878 .27711 .38716 .27608 .38611 Mtetra
.645 .729 .91 r
.27608 .38611 .27711 .38716 .27869 .38657 .27765 .38563 Mtetra
.733 .771 .883 r
.27765 .38563 .27869 .38657 .28028 .38588 .27926 .38474 Mtetra
.72 .733 .862 r
.27926 .38474 .28028 .38588 .28186 .38539 .28086 .38388 Mtetra
.628 .645 .848 r
.28086 .38388 .28186 .38539 .28339 .3855 .28244 .38346 Mtetra
.058 .247 .742 r
.28244 .38346 .28339 .3855 .2847 .38866 .28388 .38481 Mtetra
.717 .464 0 r
.28388 .38481 .2847 .38866 .27141 .58821 .28501 .39034 Mtetra
0 0 .195 r
.28501 .39034 .27141 .58821 .27258 .59465 .27184 .58873 Mtetra
.148 .115 .562 r
.27184 .58873 .27258 .59465 .27415 .59573 .27323 .59218 Mtetra
.397 .361 .702 r
.27323 .59218 .27415 .59573 .27583 .59537 .27481 .59318 Mtetra
.478 .504 .806 r
.27481 .59318 .27583 .59537 .27754 .59449 .27644 .59346 Mtetra
.399 .652 .96 r
.27644 .59346 .27754 .59449 .27924 .5939 .27808 .5936 Mtetra
.347 .789 .961 r
.27808 .5936 .27924 .5939 .28094 .59328 .27975 .59342 Mtetra
.545 .927 .898 r
.27975 .59342 .28094 .59328 .28268 .59201 .28146 .59263 Mtetra
.913 .98 .758 r
.28146 .59263 .28268 .59201 .28465 .58759 .2833 .59012 Mtetra
.961 .894 .514 r
.2833 .59012 .28465 .58759 .30038 .38643 .2854 .58383 Mtetra
0 0 .187 r
.2854 .58383 .30038 .38643 .30244 .37916 .30106 .38331 Mtetra
0 0 0 r
.30106 .38331 .30244 .37916 .30415 .37698 .30297 .37816 Mtetra
.713 .925 .59 r
.30297 .37816 .30415 .37698 .30575 .37632 .30468 .37601 Mtetra
.766 .917 .939 r
.30468 .37601 .30575 .37632 .30729 .37659 .30631 .37499 Mtetra
.215 .416 .844 r
.30631 .37499 .30729 .37659 .30868 .37922 .30782 .37578 Mtetra
0 0 .335 r
.30782 .37578 .30868 .37922 .29696 .57733 .3091 .37985 Mtetra
0 0 .208 r
.3091 .37985 .29696 .57733 .29803 .58618 .29734 .57917 Mtetra
.069 .041 .514 r
.29734 .57917 .29803 .58618 .2996 .58763 .29869 .58386 Mtetra
.379 .34 .689 r
.29869 .58386 .2996 .58763 .30129 .58733 .30028 .58504 Mtetra
.463 .487 .798 r
.30028 .58504 .30129 .58733 .30302 .58646 .30193 .58541 Mtetra
.394 .644 .957 r
.30193 .58541 .30302 .58646 .30473 .58585 .30359 .58557 Mtetra
.286 .759 .937 r
.30359 .58557 .30473 .58585 .30644 .58532 .30527 .58544 Mtetra
.504 .909 .89 r
.30527 .58544 .30644 .58532 .30819 .58418 .307 .58472 Mtetra
.908 .982 .768 r
.307 .58472 .30819 .58418 .3101 .58035 .30883 .58229 Mtetra
.987 .889 .557 r
.30883 .58229 .3101 .58035 .32432 .38009 .3109 .57595 Mtetra
0 0 .198 r
.3109 .57595 .32432 .38009 .32645 .37119 .32512 .37524 Mtetra
0 0 0 r
.32512 .37524 .32645 .37119 .32819 .3686 .32698 .37069 Mtetra
.142 0 .044 r
.32698 .37069 .32819 .3686 .32982 .36765 .32863 .3695 Mtetra
.489 .088 .207 r
.32863 .3695 .32982 .36765 .33141 .36755 .3302 .36965 Mtetra
.786 .44 .402 r
.3302 .36965 .33141 .36755 .33288 .36929 .33156 .37335 Mtetra
.945 .677 .499 r
.33156 .37335 .33288 .36929 .33384 .37972 .32118 .57266 Mtetra
.545 .318 .521 r
.32118 .57266 .33384 .37972 .32377 .57668 .32256 .57781 Mtetra
.654 .217 .198 r
.32256 .57781 .32377 .57668 .32533 .57883 .32418 .57901 Mtetra
.193 .722 .746 r
.32418 .57901 .32533 .57883 .32704 .57855 .32589 .57865 Mtetra
.555 .931 .905 r
.32589 .57865 .32704 .57855 .32878 .57764 .32763 .57785 Mtetra
.478 .897 .851 r
.32763 .57785 .32878 .57764 .33052 .57678 .32937 .57709 Mtetra
.27 .769 .73 r
.32937 .57709 .33052 .57678 .33225 .5762 .33109 .57652 Mtetra
.265 .765 .722 r
.33109 .57652 .33225 .5762 .33398 .57561 .33282 .57595 Mtetra
.248 .752 .705 r
.33282 .57595 .33398 .57561 .33571 .57499 .33455 .57538 Mtetra
0 0 0 r
.33455 .57538 .33571 .57499 .33744 .57437 .33628 .57482 Mtetra
.33628 .57482 .33744 .57437 .33917 .57382 .33801 .57426 Mtetra
.33801 .57426 .33917 .57382 .34089 .57347 .33974 .5737 Mtetra
.314 .802 .778 r
.33974 .5737 .34089 .57347 .3426 .5733 .34147 .57314 Mtetra
.528 .897 .967 r
.34147 .57314 .3426 .5733 .34431 .57313 .34321 .57257 Mtetra
.621 .854 .987 r
.34321 .57257 .34431 .57313 .34603 .57278 .34494 .57202 Mtetra
.638 .81 .966 r
.34494 .57202 .34603 .57278 .34777 .57225 .34668 .57148 Mtetra
.637 .808 .965 r
.34668 .57148 .34777 .57225 .34951 .57167 .34841 .57095 Mtetra
.608 .811 .978 r
.34841 .57095 .34951 .57167 .35124 .5711 .35015 .57049 Mtetra
.576 .827 .993 r
.35015 .57049 .35124 .5711 .35298 .57057 .35188 .57007 Mtetra
.623 .866 .988 r
.35188 .57007 .35298 .57057 .35472 .57005 .35362 .56949 Mtetra
.765 .877 .928 r
.35362 .56949 .35472 .57005 .35646 .56952 .35539 .56841 Mtetra
.821 .771 .806 r
.35539 .56841 .35646 .56952 .3582 .56898 .35719 .56659 Mtetra
.769 .64 .718 r
.35719 .56659 .3582 .56898 .35994 .56843 .35902 .56437 Mtetra
.67 .522 .675 r
.35902 .56437 .35994 .56843 .36168 .56811 .36081 .56284 Mtetra
.554 .419 .652 r
.36081 .56284 .36168 .56811 .3634 .56795 .36253 .56276 Mtetra
.591 .446 .653 r
.36253 .56276 .3634 .56795 .36515 .56728 .36428 .56217 Mtetra
.74 .549 .635 r
.36428 .56217 .36515 .56728 .36699 .56491 .36618 .55835 Mtetra
.949 .683 .498 r
.36618 .55835 .36699 .56491 .36914 .55558 .37723 .3574 Mtetra
.549 .326 .528 r
.37723 .3574 .36914 .55558 .38002 .35463 .37913 .35125 Mtetra
.738 .576 .673 r
.37913 .35125 .38002 .35463 .38181 .35088 .38086 .34883 Mtetra
.667 .607 .778 r
.38086 .34883 .38181 .35088 .38348 .34971 .38251 .34805 Mtetra
.614 .624 .837 r
.38251 .34805 .38348 .34971 .38512 .34909 .38415 .34767 Mtetra
.615 .66 .87 r
.38415 .34767 .38512 .34909 .38676 .34862 .38578 .3473 Mtetra
.675 .697 .863 r
.38578 .3473 .38676 .34862 .38841 .34804 .38743 .34664 Mtetra
.649 .677 .863 r
.38743 .34664 .38841 .34804 .39006 .34751 .38908 .34612 Mtetra
.561 .641 .887 r
.38908 .34612 .39006 .34751 .3917 .34698 .39071 .34596 Mtetra
.211 .536 .925 r
.39071 .34596 .3917 .34698 .39335 .34643 .39232 .34645 Mtetra
.533 0 0 r
.39232 .34645 .39335 .34643 .395 .34587 .39391 .34727 Mtetra
.529 .094 .158 r
.39391 .34727 .395 .34587 .39666 .34516 .39552 .3477 Mtetra
.301 0 .183 r
.39552 .3477 .39666 .34516 .39832 .34426 .39719 .34677 Mtetra
.379 .017 .218 r
.39719 .34677 .39832 .34426 .39997 .34376 .39885 .3462 Mtetra
.664 .302 .348 r
.39885 .3462 .39997 .34376 .40158 .3445 .40042 .34784 Mtetra
.953 .679 .479 r
.40042 .34784 .40158 .3445 .40299 .35017 .39432 .5474 Mtetra
.548 .32 .521 r
.39432 .5474 .40299 .35017 .39697 .55229 .3958 .55439 Mtetra
.692 .313 .326 r
.3958 .55439 .39697 .55229 .39857 .55606 .39747 .55632 Mtetra
.06 0 0 r
.39747 .55632 .39857 .55606 .40031 .55632 .39922 .5562 Mtetra
.59 .929 .956 r
.39922 .5562 .40031 .55632 .40208 .5559 .401 .55546 Mtetra
.79 .907 .922 r
.401 .55546 .40208 .5559 .40385 .55526 .4028 .55423 Mtetra
.818 .789 .825 r
.4028 .55423 .40385 .55526 .40562 .55479 .40461 .55253 Mtetra
.768 .649 .73 r
.40461 .55253 .40562 .55479 .4074 .55424 .40644 .55047 Mtetra
.691 .544 .682 r
.40644 .55047 .4074 .55424 .40917 .55378 .40825 .5487 Mtetra
.559 .427 .657 r
.40825 .5487 .40917 .55378 .41093 .55359 .41002 .54856 Mtetra
.584 .445 .658 r
.41002 .54856 .41093 .55359 .41271 .55297 .41179 .54809 Mtetra
.696 .523 .649 r
.41179 .54809 .41271 .55297 .41453 .55115 .41363 .54564 Mtetra
.955 .685 .485 r
.41363 .54564 .41453 .55115 .4165 .54456 .42189 .34568 Mtetra
.555 .33 .529 r
.42189 .34568 .4165 .54456 .42471 .34085 .42383 .33661 Mtetra
.735 .554 .648 r
.42383 .33661 .42471 .34085 .42653 .33579 .42558 .33363 Mtetra
.663 .598 .771 r
.42558 .33363 .42653 .33579 .42822 .33444 .42726 .33285 Mtetra
.598 .628 .852 r
.42726 .33285 .42822 .33444 .4299 .33374 .42892 .33255 Mtetra
.549 .674 .921 r
.42892 .33255 .4299 .33374 .43157 .3333 .43058 .33239 Mtetra
.646 .773 .941 r
.43058 .33239 .43157 .3333 .43324 .33271 .43226 .33187 Mtetra
.655 .791 .947 r
.43226 .33187 .43324 .33271 .43491 .33219 .43393 .33131 Mtetra
.671 .787 .936 r
.43393 .33131 .43491 .33219 .43659 .33168 .43561 .33069 Mtetra
.69 .769 .911 r
.43561 .33069 .43659 .33168 .43826 .3311 .43729 .32999 Mtetra
.69 .743 .892 r
.43729 .32999 .43826 .3311 .43994 .33053 .43897 .32928 Mtetra
.682 .715 .874 r
.43897 .32928 .43994 .33053 .44162 .32996 .44066 .32858 Mtetra
.664 .689 .863 r
.44066 .32858 .44162 .32996 .4433 .32941 .44234 .32797 Mtetra
.659 .676 .855 r
.44234 .32797 .4433 .32941 .44498 .32886 .44402 .32737 Mtetra
.66 .67 .849 r
.44402 .32737 .44498 .32886 .44666 .32829 .44571 .32676 Mtetra
.678 .671 .836 r
.44571 .32676 .44666 .32829 .44835 .32769 .44739 .32603 Mtetra
.655 .645 .828 r
.44739 .32603 .44835 .32769 .45003 .32708 .44908 .32542 Mtetra
.604 .622 .843 r
.44908 .32542 .45003 .32708 .45172 .32647 .45076 .32509 Mtetra
.343 .535 .898 r
.45076 .32509 .45172 .32647 .45341 .32586 .45242 .32554 Mtetra
.415 0 0 r
.45242 .32554 .45341 .32586 .4551 .32525 .45408 .32639 Mtetra
.628 .18 .169 r
.45408 .32639 .4551 .32525 .45678 .32464 .45573 .32741 Mtetra
.497 .14 .291 r
.45573 .32741 .45678 .32464 .45847 .32405 .45741 .32749 Mtetra
.413 .086 .299 r
.45741 .32749 .45847 .32405 .46017 .32346 .45911 .32682 Mtetra
.282 0 .241 r
.45911 .32682 .46017 .32346 .46186 .32288 .46082 .32537 Mtetra
0 0 .01 r
.46082 .32537 .46186 .32288 .46355 .32231 .46255 .32311 Mtetra
.703 .939 .635 r
.46255 .32311 .46355 .32231 .46524 .32174 .46427 .32117 Mtetra
.837 .874 .87 r
.46427 .32117 .46524 .32174 .46694 .32118 .46598 .31965 Mtetra
.678 .674 .838 r
.46598 .31965 .46694 .32118 .46863 .32063 .46768 .31892 Mtetra
.64 .635 .829 r
.46768 .31892 .46863 .32063 .47033 .32007 .46938 .31839 Mtetra
.624 .631 .837 r
.46938 .31839 .47033 .32007 .47203 .31951 .47108 .31796 Mtetra
.651 .659 .845 r
.47108 .31796 .47203 .31951 .47373 .31894 .47278 .31738 Mtetra
.649 .657 .845 r
.47278 .31738 .47373 .31894 .47543 .31836 .47448 .31682 Mtetra
.645 .659 .848 r
.47448 .31682 .47543 .31836 .47713 .31776 .47618 .31628 Mtetra
.633 .662 .86 r
.47618 .31628 .47713 .31776 .47883 .31713 .47788 .3158 Mtetra
.634 .688 .883 r
.47788 .3158 .47883 .31713 .48054 .31648 .47958 .31534 Mtetra
.64 .723 .908 r
.47958 .31534 .48054 .31648 .48224 .31583 .48129 .31484 Mtetra
.661 .764 .926 r
.48129 .31484 .48224 .31583 .48395 .31513 .48299 .31426 Mtetra
.672 .793 .939 r
.48299 .31426 .48395 .31513 .48566 .31447 .4847 .31362 Mtetra
.684 .803 .939 r
.4847 .31362 .48566 .31447 .48737 .31387 .48641 .31294 Mtetra
.768 .801 .88 r
.48641 .31294 .48737 .31387 .48908 .31309 .48813 .31181 Mtetra
.705 .723 .864 r
.48813 .31181 .48908 .31309 .49079 .31268 .48984 .31097 Mtetra
.595 .615 .841 r
.48984 .31097 .49079 .31268 .49249 .313 .49155 .31068 Mtetra
0 .106 .651 r
.49155 .31068 .49249 .313 .49414 .31847 .49323 .31291 Mtetra
.733 .502 0 r
.49323 .31291 .49414 .31847 .49397 .52204 .49484 .32328 Mtetra
0 0 .324 r
.49484 .32328 .49397 .52204 .49576 .52643 .49478 .52124 Mtetra
.341 .277 .64 r
.49478 .52124 .49576 .52643 .49758 .52654 .49659 .52333 Mtetra
.447 .418 .733 r
.49659 .52333 .49758 .52654 .49942 .52586 .49841 .52403 Mtetra
.52 .577 .853 r
.49841 .52403 .49942 .52586 .50126 .5248 .50024 .52407 Mtetra
.603 .821 .983 r
.50024 .52407 .50126 .5248 .5031 .52428 .50208 .52358 Mtetra
.676 .849 .966 r
.50208 .52358 .5031 .52428 .50493 .52376 .50392 .52285 Mtetra
.702 .808 .931 r
.50392 .52285 .50493 .52376 .50677 .52317 .50576 .52203 Mtetra
.505 .687 .949 r
.50576 .52203 .50677 .52317 .50861 .52279 .5076 .52196 Mtetra
.546 .773 .982 r
.5076 .52196 .50861 .52279 .51045 .52205 .50944 .52166 Mtetra
.682 .919 .973 r
.50944 .52166 .51045 .52205 .5123 .52052 .51129 .5208 Mtetra
.965 .932 .698 r
.51129 .5208 .5123 .52052 .51416 .51407 .51314 .51732 Mtetra
.942 .82 .371 r
.51314 .51732 .51416 .51407 .51655 .30894 .51502 .50743 Mtetra
0 0 .318 r
.51502 .50743 .51655 .30894 .51829 .30346 .51734 .30636 Mtetra
0 0 .015 r
.51734 .30636 .51829 .30346 .52002 .30211 .51908 .30322 Mtetra
0 0 0 r
.51908 .30322 .52002 .30211 .52175 .3016 .52081 .30154 Mtetra
.718 .976 .921 r
.52081 .30154 .52175 .3016 .52348 .30147 .52254 .30044 Mtetra
.697 .77 .908 r
.52254 .30044 .52348 .30147 .52521 .30096 .52427 .29969 Mtetra
.651 .706 .888 r
.52427 .29969 .52521 .30096 .52694 .30039 .52601 .29913 Mtetra
.628 .702 .898 r
.52601 .29913 .52694 .30039 .52868 .29979 .52774 .29868 Mtetra
.728 .762 .88 r
.52774 .29868 .52868 .29979 .53041 .29869 .52948 .29774 Mtetra
.702 .787 .917 r
.52948 .29774 .53041 .29869 .53215 .29785 .53121 .29696 Mtetra
.557 .753 .969 r
.53121 .29696 .53215 .29785 .53389 .29768 .53295 .29669 Mtetra
.566 .075 0 r
.53295 .29669 .53389 .29768 .53564 .30128 .5347 .29869 Mtetra
.932 .598 .152 r
.5347 .29869 .53564 .30128 .5382 .50634 .53648 .30839 Mtetra
0 0 .341 r
.53648 .30839 .5382 .50634 .54009 .51248 .53908 .50712 Mtetra
.333 .27 .636 r
.53908 .50712 .54009 .51248 .54196 .51309 .54095 .50939 Mtetra
.469 .41 .709 r
.54095 .50939 .54196 .51309 .54383 .51251 .54282 .51005 Mtetra
.531 .52 .788 r
.54282 .51005 .54383 .51251 .54569 .51142 .54469 .51013 Mtetra
.417 .612 .93 r
.54469 .51013 .54569 .51142 .54756 .51092 .54656 .51035 Mtetra
.449 .796 .998 r
.54656 .51035 .54756 .51092 .54942 .51026 .54844 .51013 Mtetra
.669 .96 .941 r
.54844 .51013 .54942 .51026 .55129 .50891 .5503 .50913 Mtetra
.982 .897 .653 r
.5503 .50913 .55129 .50891 .55312 .5038 .55215 .50481 Mtetra
.973 .691 .433 r
.55215 .50481 .55312 .5038 .55313 .29819 .55223 .29994 Mtetra
.995 .82 .455 r
.55223 .29994 .55313 .29819 .55483 .29128 .5539 .29026 Mtetra
.849 .799 .802 r
.5539 .29026 .55483 .29128 .55657 .2895 .55564 .28831 Mtetra
.672 .732 .895 r
.55564 .28831 .55657 .2895 .55832 .28884 .55739 .28765 Mtetra
.559 .686 .925 r
.55739 .28765 .55832 .28884 .56007 .28859 .55915 .28745 Mtetra
.722 .759 .881 r
.55915 .28745 .56007 .28859 .56183 .28763 .5609 .28653 Mtetra
.715 .765 .892 r
.5609 .28653 .56183 .28763 .56358 .28673 .56266 .28567 Mtetra
.562 .717 .945 r
.56266 .28567 .56358 .28673 .56534 .28645 .56442 .28542 Mtetra
.733 .264 0 r
.56442 .28542 .56534 .28645 .56714 .28926 .56622 .2883 Mtetra
.972 .681 .416 r
.56622 .2883 .56714 .28926 .5718 .49353 .57083 .49278 Mtetra
.934 .556 .219 r
.57083 .49278 .5718 .49353 .57381 .5015 .57283 .50045 Mtetra
0 .244 .735 r
.57283 .50045 .57381 .5015 .57572 .50285 .57474 .50177 Mtetra
.567 .731 .952 r
.57474 .50177 .57572 .50285 .57762 .50256 .57663 .50148 Mtetra
.784 .798 .864 r
.57663 .50148 .57762 .50256 .57949 .5012 .57851 .50011 Mtetra
.93 .783 .677 r
.57851 .50011 .57949 .5012 .58132 .4969 .58034 .49579 Mtetra
.973 .688 .426 r
.58034 .49579 .58132 .4969 .57962 .29205 .5787 .29074 Mtetra
.958 .733 .556 r
.5787 .29074 .57962 .29205 .58123 .28234 .58031 .28118 Mtetra
.85 .779 .783 r
.58031 .28118 .58123 .28234 .58297 .28022 .58205 .27907 Mtetra
.67 .741 .903 r
.58205 .27907 .58297 .28022 .58474 .27956 .58382 .27842 Mtetra
.547 .693 .936 r
.58382 .27842 .58474 .27956 .58651 .27937 .5856 .27824 Mtetra
.68 .749 .903 r
.5856 .27824 .58651 .27937 .58828 .27859 .58737 .27755 Mtetra
.705 .776 .907 r
.58737 .27755 .58828 .27859 .59005 .27772 .58914 .27674 Mtetra
.593 .748 .951 r
.58914 .27674 .59005 .27772 .59183 .27745 .59092 .27637 Mtetra
0 .199 .709 r
.59092 .27637 .59183 .27745 .59368 .28002 .59274 .27779 Mtetra
.821 .465 0 r
.59274 .27779 .59368 .28002 .60011 .48419 .59467 .28401 Mtetra
0 0 .364 r
.59467 .28401 .60011 .48419 .60222 .49253 .60114 .48655 Mtetra
.272 .218 .612 r
.60114 .48655 .60222 .49253 .60417 .49371 .60313 .48974 Mtetra
.459 .395 .698 r
.60313 .48974 .60417 .49371 .60607 .49319 .60507 .49056 Mtetra
.527 .506 .776 r
.60507 .49056 .60607 .49319 .60797 .49216 .607 .49067 Mtetra
.494 .618 .903 r
.607 .49067 .60797 .49216 .60989 .49174 .60892 .49073 Mtetra
.545 .74 .966 r
.60892 .49073 .60989 .49174 .61181 .49149 .61084 .49048 Mtetra
.73 .805 .911 r
.61084 .49048 .61181 .49149 .61371 .49062 .61275 .48948 Mtetra
.918 .79 .705 r
.61275 .48948 .61371 .49062 .61554 .48705 .61458 .48581 Mtetra
.975 .686 .413 r
.61458 .48581 .61554 .48705 .61185 .28615 .61091 .2838 Mtetra
.947 .699 .529 r
.61091 .2838 .61185 .28615 .61325 .27165 .61235 .27046 Mtetra
.873 .781 .756 r
.61235 .27046 .61325 .27165 .61499 .26911 .61408 .26795 Mtetra
.689 .749 .897 r
.61408 .26795 .61499 .26911 .61677 .26836 .61587 .2672 Mtetra
.57 .703 .931 r
.61587 .2672 .61677 .26836 .61857 .2681 .61767 .26694 Mtetra
.685 .749 .9 r
.61767 .26694 .61857 .2681 .62036 .26737 .61946 .26621 Mtetra
.727 .763 .882 r
.61946 .26621 .62036 .26737 .62214 .26641 .62125 .26526 Mtetra
.61 .722 .924 r
.62125 .26526 .62214 .26641 .62395 .266 .62305 .26486 Mtetra
0 .055 .59 r
.62305 .26486 .62395 .266 .62582 .2679 .62493 .26676 Mtetra
.974 .678 .39 r
.62493 .26676 .62582 .2679 .63426 .46708 .63333 .46629 Mtetra
.955 .608 .278 r
.63333 .46629 .63426 .46708 .63667 .48103 .63572 .47996 Mtetra
0 .145 .656 r
.63572 .47996 .63667 .48103 .63868 .48272 .63773 .48163 Mtetra
.607 .75 .946 r
.63773 .48163 .63868 .48272 .64062 .48228 .63967 .48119 Mtetra
.73 .791 .901 r
.63967 .48119 .64062 .48228 .64253 .48128 .64158 .48017 Mtetra
.635 .757 .936 r
.64158 .48017 .64253 .48128 .64447 .48077 .64352 .47962 Mtetra
.544 .711 .949 r
.64352 .47962 .64447 .48077 .64642 .48059 .64547 .47941 Mtetra
.692 .763 .906 r
.64547 .47941 .64642 .48059 .64835 .47982 .6474 .47859 Mtetra
.902 .789 .727 r
.6474 .47859 .64835 .47982 .65019 .47665 .64924 .47536 Mtetra
.976 .685 .4 r
.64924 .47536 .65019 .47665 .65125 .45336 .64374 .28059 Mtetra
.581 .35 .53 r
.64374 .28059 .65125 .45336 .64565 .26064 .64476 .25941 Mtetra
.889 .78 .735 r
.64476 .25941 .64565 .26064 .64737 .25775 .64648 .25656 Mtetra
.702 .752 .89 r
.64648 .25656 .64737 .25775 .64917 .25692 .64829 .25574 Mtetra
.587 .707 .926 r
.64829 .25574 .64917 .25692 .651 .2566 .65011 .25542 Mtetra
.666 .741 .906 r
.65011 .25542 .651 .2566 .65281 .25595 .65193 .25477 Mtetra
.733 .764 .878 r
.65193 .25477 .65281 .25595 .65461 .25494 .65372 .25377 Mtetra
.636 .73 .916 r
.65372 .25377 .65461 .25494 .65643 .25443 .65555 .25326 Mtetra
0 .283 .781 r
.65555 .25326 .65643 .25443 .65833 .25575 .65745 .25458 Mtetra
.938 .574 .185 r
.65745 .25458 .65833 .25575 .66061 .26558 .65972 .26442 Mtetra
.975 .675 .374 r
.65972 .26442 .66061 .26558 .67152 .46897 .67059 .46786 Mtetra
0 0 .512 r
.67059 .46786 .67152 .46897 .6736 .47124 .67267 .47013 Mtetra
.63 .756 .938 r
.67267 .47013 .6736 .47124 .67556 .47071 .67463 .46959 Mtetra
.769 .801 .879 r
.67463 .46959 .67556 .47071 .67748 .46943 .67655 .46832 Mtetra
.781 .803 .87 r
.67655 .46832 .67748 .46943 .67941 .46807 .67847 .46695 Mtetra
.728 .789 .901 r
.67847 .46695 .67941 .46807 .68134 .46706 .68041 .46593 Mtetra
.714 .784 .907 r
.68041 .46593 .68134 .46706 .68329 .46613 .68236 .465 Mtetra
.654 .762 .929 r
.68236 .465 .68329 .46613 .68524 .4655 .68431 .46436 Mtetra
.566 .725 .948 r
.68431 .46436 .68524 .4655 .68722 .4652 .68629 .46406 Mtetra
.538 .712 .953 r
.68629 .46406 .68722 .4652 .6892 .46499 .68828 .46386 Mtetra
.446 .667 .957 r
.68828 .46386 .6892 .46499 .6912 .46506 .69027 .46393 Mtetra
.416 .652 .956 r
.69027 .46393 .6912 .46506 .69321 .46521 .69228 .46408 Mtetra
.629 .754 .938 r
.69228 .46408 .69321 .46521 .69518 .46467 .69425 .46355 Mtetra
.89 .812 .765 r
.69425 .46355 .69518 .46467 .69704 .46199 .69611 .46086 Mtetra
.981 .724 .468 r
.69611 .46086 .69704 .46199 .69812 .44458 .69719 .44339 Mtetra
.977 .681 .379 r
.69719 .44339 .69812 .44458 .68944 .24567 .68857 .24449 Mtetra
.912 .79 .713 r
.68857 .24449 .68944 .24567 .69114 .24243 .69027 .24124 Mtetra
.708 .758 .891 r
.69027 .24124 .69114 .24243 .69297 .24156 .6921 .24037 Mtetra
.587 .709 .927 r
.6921 .24037 .69297 .24156 .69482 .24124 .69396 .24005 Mtetra
.622 .724 .92 r
.69396 .24005 .69482 .24124 .69667 .24077 .69581 .23958 Mtetra
.731 .765 .88 r
.69581 .23958 .69667 .24077 .6985 .23977 .69763 .23858 Mtetra
.639 .731 .915 r
.69763 .23858 .6985 .23977 .70035 .23924 .69948 .23805 Mtetra
.062 .397 .854 r
.69948 .23805 .70035 .23924 .70229 .24028 .70143 .23908 Mtetra
.925 .554 .14 r
.70143 .23908 .70229 .24028 .70473 .24976 .70386 .24854 Mtetra
.975 .671 .352 r
.70386 .24854 .70473 .24976 .71874 .45462 .71782 .45348 Mtetra
.599 .137 0 r
.71782 .45348 .71874 .45462 .72094 .45757 .72002 .45643 Mtetra
.42 .653 .955 r
.72002 .45643 .72094 .45757 .72297 .45772 .72206 .45658 Mtetra
.711 .785 .91 r
.72206 .45658 .72297 .45772 .72494 .45679 .72403 .45565 Mtetra
.888 .815 .771 r
.72403 .45565 .72494 .45679 .72681 .45418 .7259 .45303 Mtetra
.977 .757 .54 r
.7259 .45303 .72681 .45418 .72828 .44526 .72737 .44408 Mtetra
.977 .679 .365 r
.72737 .44408 .72828 .44526 .71724 .23734 .71638 .23613 Mtetra
.935 .785 .67 r
.71638 .23613 .71724 .23734 .71888 .23327 .71802 .23207 Mtetra
.72 .761 .885 r
.71802 .23207 .71888 .23327 .72071 .23233 .71986 .23112 Mtetra
.582 .704 .926 r
.71986 .23112 .72071 .23233 .72259 .23202 .72174 .23082 Mtetra
.543 .685 .932 r
.72174 .23082 .72259 .23202 .72449 .23185 .72363 .23065 Mtetra
.658 .737 .908 r
.72363 .23065 .72449 .23185 .72635 .23123 .7255 .23002 Mtetra
.663 .74 .907 r
.7255 .23002 .72635 .23123 .72821 .23058 .72736 .22937 Mtetra
.701 .754 .893 r
.72736 .22937 .72821 .23058 .73006 .22974 .72921 .22853 Mtetra
.756 .773 .867 r
.72921 .22853 .73006 .22974 .73189 .22857 .73104 .22736 Mtetra
.674 .745 .904 r
.73104 .22736 .73189 .22857 .73375 .22787 .7329 .22666 Mtetra
.242 .514 .909 r
.7329 .22666 .73375 .22787 .73571 .22853 .73486 .22732 Mtetra
.896 .51 .064 r
.73486 .22732 .73571 .22853 .73818 .23651 .73733 .2353 Mtetra
.975 .667 .334 r
.73733 .2353 .73818 .23651 .75463 .44304 .75373 .44189 Mtetra
.634 .179 0 r
.75373 .44189 .75463 .44304 .75692 .44637 .75602 .44522 Mtetra
.392 .636 .953 r
.75602 .44522 .75692 .44637 .75899 .4466 .7581 .44545 Mtetra
.695 .781 .917 r
.7581 .44545 .75899 .4466 .76099 .44575 .7601 .4446 Mtetra
.873 .82 .793 r
.7601 .4446 .76099 .44575 .76288 .4434 .76199 .44225 Mtetra
.978 .767 .552 r
.76199 .44225 .76288 .4434 .76436 .4355 .76347 .43435 Mtetra
.977 .675 .347 r
.76347 .43435 .76436 .4355 .7509 .22611 .75006 .22491 Mtetra
.951 .785 .641 r
.75006 .22491 .7509 .22611 .75248 .22146 .75164 .22025 Mtetra
.748 .773 .873 r
.75164 .22025 .75248 .22146 .75432 .22034 .75349 .21913 Mtetra
.622 .724 .92 r
.75349 .21913 .75432 .22034 .75622 .21987 .75538 .21866 Mtetra
.591 .71 .926 r
.75538 .21866 .75622 .21987 .75812 .21952 .75729 .21831 Mtetra
.75 .774 .872 r
.75729 .21831 .75812 .21952 .75997 .21839 .75913 .21718 Mtetra
.676 .747 .904 r
.75913 .21718 .75997 .21839 .76185 .21767 .76101 .21646 Mtetra
.377 .596 .932 r
.76101 .21646 .76185 .21767 .76381 .218 .76298 .21679 Mtetra
.807 .394 0 r
.76298 .21679 .76381 .218 .76618 .22345 .76535 .22225 Mtetra
.973 .663 .318 r
.76535 .22225 .76618 .22345 .78479 .4321 .78391 .43094 Mtetra
.717 .274 0 r
.78391 .43094 .78479 .4321 .7872 .43631 .78632 .43515 Mtetra
.503 .696 .955 r
.78632 .43515 .7872 .43631 .78928 .43621 .7884 .43505 Mtetra
.695 .782 .918 r
.7884 .43505 .78928 .43621 .7913 .43535 .79042 .43419 Mtetra
.735 .796 .901 r
.79042 .43419 .7913 .43535 .7933 .43426 .79242 .4331 Mtetra
.496 .692 .955 r
.79242 .4331 .7933 .43426 .79538 .43419 .7945 .43303 Mtetra
.625 .754 .939 r
.7945 .43303 .79538 .43419 .79743 .43365 .79655 .43249 Mtetra
.811 .816 .854 r
.79655 .43249 .79743 .43365 .79938 .43201 .79851 .43085 Mtetra
.98 .772 .552 r
.79851 .43085 .79938 .43201 .80083 .42441 .79996 .42325 Mtetra
.976 .671 .329 r
.79996 .42325 .80083 .42441 .78496 .21454 .78413 .21332 Mtetra
.959 .785 .623 r
.78413 .21332 .78496 .21454 .78648 .20954 .78566 .20832 Mtetra
.751 .775 .872 r
.78566 .20832 .78648 .20954 .78834 .20839 .78752 .20717 Mtetra
.622 .723 .919 r
.78752 .20717 .78834 .20839 .79026 .20791 .78944 .20669 Mtetra
.552 .69 .931 r
.78944 .20669 .79026 .20791 .79221 .2077 .79138 .20648 Mtetra
.746 .773 .875 r
.79138 .20648 .79221 .2077 .79407 .20659 .79325 .20536 Mtetra
.677 .747 .904 r
.79325 .20536 .79407 .20659 .79597 .20586 .79515 .20463 Mtetra
.456 .638 .935 r
.79515 .20463 .79597 .20586 .79795 .20597 .79713 .20474 Mtetra
.768 .353 0 r
.79713 .20474 .79795 .20597 .80039 .21117 .79957 .20994 Mtetra
.971 .657 .298 r
.79957 .20994 .80039 .21117 .82152 .42062 .82066 .41944 Mtetra
.726 .292 0 r
.82066 .41944 .82152 .42062 .82406 .42527 .8232 .42409 Mtetra
.306 .58 .938 r
.8232 .42409 .82406 .42527 .82623 .42575 .82537 .42457 Mtetra
.649 .764 .933 r
.82537 .42457 .82623 .42575 .82829 .4251 .82743 .42392 Mtetra
.829 .821 .841 r
.82743 .42392 .82829 .4251 .83024 .42329 .82938 .42211 Mtetra
.975 .789 .59 r
.82938 .42211 .83024 .42329 .83179 .41718 .83093 .416 Mtetra
.974 .667 .312 r
.83093 .416 .83179 .41718 .8138 .20637 .81299 .20514 Mtetra
.974 .774 .571 r
.81299 .20514 .8138 .20637 .81518 .20003 .81437 .1988 Mtetra
.76 .758 .85 r
.19715 .41268 .19821 .41367 .1998 .41259 .19873 .4116 Mtetra
.612 .727 .927 r
.19873 .4116 .1998 .41259 .20131 .41224 .20025 .41125 Mtetra
.454 .668 .955 r
.20025 .41125 .20131 .41224 .20279 .41228 .20173 .41129 Mtetra
.654 .739 .912 r
.20173 .41129 .20279 .41228 .20432 .41178 .20326 .41079 Mtetra
.663 .741 .908 r
.20326 .41079 .20432 .41178 .20586 .41125 .2048 .41026 Mtetra
.669 .743 .906 r
.2048 .41026 .20586 .41125 .2074 .41069 .20634 .4097 Mtetra
.763 .759 .849 r
.20634 .4097 .2074 .41069 .209 .40958 .20794 .40859 Mtetra
.709 .751 .885 r
.20794 .40859 .209 .40958 .21056 .40883 .2095 .40784 Mtetra
.494 .684 .952 r
.2095 .40784 .21056 .40883 .21205 .40879 .21099 .4078 Mtetra
.932 .563 .281 r
.21099 .4078 .21205 .40879 .21311 .41324 .21206 .41224 Mtetra
.939 .683 .523 r
.21206 .41224 .21311 .41324 .19548 .61275 .19434 .61181 Mtetra
.932 .569 .305 r
.19434 .61181 .19548 .61275 .19659 .61773 .19545 .61679 Mtetra
0 .387 .825 r
.19545 .61679 .19659 .61773 .19811 .61846 .19698 .61752 Mtetra
.627 .757 .94 r
.19698 .61752 .19811 .61846 .19975 .61802 .19861 .61708 Mtetra
.802 .78 .833 r
.19861 .61708 .19975 .61802 .20148 .61653 .20035 .61559 Mtetra
.906 .743 .669 r
.20035 .61559 .20148 .61653 .20355 .61146 .20242 .61051 Mtetra
.939 .687 .53 r
.20242 .61051 .20355 .61146 .22381 .41101 .22275 .40999 Mtetra
.913 .724 .633 r
.22275 .40999 .22381 .41101 .22594 .40421 .22489 .4032 Mtetra
.795 .759 .82 r
.22489 .4032 .22594 .40421 .22757 .40279 .22652 .40178 Mtetra
.644 .734 .914 r
.22652 .40178 .22757 .40279 .22912 .40233 .22807 .40132 Mtetra
.502 .684 .948 r
.22807 .40132 .22912 .40233 .23062 .40228 .22957 .40126 Mtetra
.737 .753 .866 r
.22957 .40126 .23062 .40228 .23221 .40137 .23116 .40034 Mtetra
.698 .744 .887 r
.23116 .40034 .23221 .40137 .23378 .40067 .23273 .39963 Mtetra
.473 .666 .947 r
.23273 .39963 .23378 .40067 .23528 .40069 .23424 .39965 Mtetra
.936 .571 .284 r
.23424 .39965 .23528 .40069 .23638 .40528 .23532 .40441 Mtetra
.941 .683 .518 r
.23532 .40441 .23638 .40528 .22006 .6059 .2189 .60525 Mtetra
.918 .545 .299 r
.2189 .60525 .22006 .6059 .22124 .61063 .2201 .60987 Mtetra
.289 .659 .971 r
.2201 .60987 .22124 .61063 .22283 .61088 .22169 .61005 Mtetra
.741 .803 .902 r
.22169 .61005 .22283 .61088 .22452 .61001 .22339 .6091 Mtetra
.801 .788 .84 r
.22339 .6091 .22452 .61001 .22625 .60867 .22513 .60765 Mtetra
.727 .765 .883 r
.22513 .60765 .22625 .60867 .22794 .60783 .22682 .60674 Mtetra
.68 .743 .899 r
.22682 .60674 .22794 .60783 .22961 .6072 .2285 .60608 Mtetra
.655 .731 .905 r
.2285 .60608 .22961 .6072 .23127 .60666 .23016 .60554 Mtetra
.614 .717 .919 r
.23016 .60554 .23127 .60666 .23292 .60627 .23181 .60515 Mtetra
.591 .712 .928 r
.23181 .60515 .23292 .60627 .23457 .60593 .23345 .60485 Mtetra
.586 .716 .933 r
.23345 .60485 .23457 .60593 .23621 .6056 .2351 .60456 Mtetra
.546 .71 .947 r
.2351 .60456 .23621 .6056 .23784 .60552 .23674 .60438 Mtetra
.598 .708 .921 r
.23674 .60438 .23784 .60552 .23949 .60524 .23839 .60405 Mtetra
.676 .725 .886 r
.23839 .60405 .23949 .60524 .24118 .60442 .24007 .6034 Mtetra
.801 .771 .825 r
.24007 .6034 .24118 .60442 .24305 .60148 .24182 .60186 Mtetra
.933 .947 .776 r
.24182 .60186 .24305 .60148 .24533 .59352 .24366 .59925 Mtetra
0 0 .086 r
.24366 .59925 .24533 .59352 .26307 .39538 .2457 .59424 Mtetra
0 0 .176 r
.2457 .59424 .26307 .39538 .2649 .39166 .26332 .39727 Mtetra
0 0 0 r
.26332 .39727 .2649 .39166 .26658 .38985 .26539 .39067 Mtetra
.944 .961 .711 r
.26539 .39067 .26658 .38985 .2682 .38867 .26716 .38775 Mtetra
.783 .778 .848 r
.26716 .38775 .2682 .38867 .2698 .38789 .26879 .38651 Mtetra
.657 .674 .854 r
.26879 .38651 .2698 .38789 .27137 .38736 .27037 .38595 Mtetra
.594 .646 .871 r
.27037 .38595 .27137 .38736 .27294 .38697 .27192 .38569 Mtetra
.607 .672 .887 r
.27192 .38569 .27294 .38697 .27451 .38655 .27348 .38536 Mtetra
.618 .694 .898 r
.27348 .38536 .27451 .38655 .27608 .38611 .27505 .38499 Mtetra
.626 .711 .907 r
.27505 .38499 .27608 .38611 .27765 .38563 .27662 .38459 Mtetra
.707 .748 .884 r
.27662 .38459 .27765 .38563 .27926 .38474 .27822 .38383 Mtetra
.721 .776 .896 r
.27822 .38383 .27926 .38474 .28086 .38388 .27982 .38302 Mtetra
.665 .775 .931 r
.27982 .38302 .28086 .38388 .28244 .38346 .2814 .38245 Mtetra
.349 .617 .951 r
.2814 .38245 .28244 .38346 .28388 .38481 .28293 .38269 Mtetra
.138 .289 .756 r
.28293 .38269 .28388 .38481 .28501 .39034 .28438 .38393 Mtetra
.211 .145 .561 r
.28438 .38393 .28501 .39034 .27184 .58873 .28568 .38724 Mtetra
0 0 .213 r
.28568 .38724 .27184 .58873 .27323 .59218 .27273 .58309 Mtetra
0 0 .442 r
.27273 .58309 .27323 .59218 .27481 .59318 .27387 .58991 Mtetra
.014 .118 .629 r
.27387 .58991 .27481 .59318 .27644 .59346 .27535 .59223 Mtetra
.157 .472 .894 r
.27535 .59223 .27644 .59346 .27808 .5936 .27696 .59289 Mtetra
.499 .771 .993 r
.27696 .59289 .27808 .5936 .27975 .59342 .27863 .59269 Mtetra
.7 .827 .943 r
.27863 .59269 .27975 .59342 .28146 .59263 .28034 .59194 Mtetra
.819 .834 .86 r
.28034 .59194 .28146 .59263 .2833 .59012 .2821 .59044 Mtetra
.925 .956 .785 r
.2821 .59044 .2833 .59012 .2854 .58383 .28394 .58796 Mtetra
0 0 0 r
.28394 .58796 .2854 .58383 .30106 .38331 .28591 .58352 Mtetra
0 0 .206 r
.28591 .58352 .30106 .38331 .30297 .37816 .30133 .38592 Mtetra
0 0 .035 r
.30133 .38592 .30297 .37816 .30468 .37601 .30348 .37748 Mtetra
.824 .936 .566 r
.30348 .37748 .30468 .37601 .30631 .37499 .30525 .37453 Mtetra
.697 .879 .966 r
.30525 .37453 .30631 .37499 .30782 .37578 .30686 .3738 Mtetra
.271 .392 .802 r
.30686 .3738 .30782 .37578 .3091 .37985 .30836 .37467 Mtetra
.173 .143 .581 r
.30836 .37467 .3091 .37985 .29734 .57917 .30973 .37759 Mtetra
0 0 .233 r
.30973 .37759 .29734 .57917 .29869 .58386 .29831 .57215 Mtetra
0 0 .409 r
.29831 .57215 .29869 .58386 .30028 .58504 .29936 .58141 Mtetra
.014 .097 .607 r
.29936 .58141 .30028 .58504 .30193 .58541 .30086 .58403 Mtetra
.131 .425 .867 r
.30086 .58403 .30193 .58541 .30359 .58557 .30248 .58483 Mtetra
.478 .758 .992 r
.30248 .58483 .30359 .58557 .30527 .58544 .30416 .58469 Mtetra
.69 .821 .945 r
.30416 .58469 .30527 .58544 .307 .58472 .30589 .58397 Mtetra
.831 .824 .842 r
.30589 .58397 .307 .58472 .30883 .58229 .30767 .58232 Mtetra
.937 .9 .764 r
.30767 .58232 .30883 .58229 .3109 .57595 .30953 .57947 Mtetra
0 0 0 r
.30953 .57947 .3109 .57595 .32512 .37524 .31149 .57502 Mtetra
.523 .3 .517 r
.31149 .57502 .32512 .37524 .32698 .37069 .31352 .56925 Mtetra
.528 .304 .518 r
.31352 .56925 .32698 .37069 .32863 .3695 .3154 .566 Mtetra
.539 .313 .52 r
.3154 .566 .32863 .3695 .3302 .36965 .31694 .56821 Mtetra
.543 .316 .521 r
.31694 .56821 .3302 .36965 .33156 .37335 .31835 .5727 Mtetra
.541 .314 .52 r
.31835 .5727 .33156 .37335 .32118 .57266 .31985 .57581 Mtetra
.651 .307 .378 r
.31985 .57581 .32118 .57266 .32256 .57781 .32143 .5775 Mtetra
0 .446 .721 r
.32143 .5775 .32256 .57781 .32418 .57901 .3231 .5779 Mtetra
.627 .73 .921 r
.3231 .5779 .32418 .57901 .32589 .57865 .32481 .57745 Mtetra
.683 .731 .887 r
.32481 .57745 .32589 .57865 .32763 .57785 .32655 .57674 Mtetra
.68 .747 .902 r
.32655 .57674 .32763 .57785 .32937 .57709 .32828 .57606 Mtetra
.653 .756 .925 r
.32828 .57606 .32937 .57709 .33109 .57652 .33001 .5755 Mtetra
.653 .757 .926 r
.33001 .5755 .33109 .57652 .33282 .57595 .33174 .57494 Mtetra
.651 .759 .929 r
.33174 .57494 .33282 .57595 .33455 .57538 .33346 .57439 Mtetra
.648 .762 .932 r
.33346 .57439 .33455 .57538 .33628 .57482 .33519 .57385 Mtetra
.647 .765 .935 r
.33519 .57385 .33628 .57482 .33801 .57426 .33692 .57331 Mtetra
.644 .769 .939 r
.33692 .57331 .33801 .57426 .33974 .5737 .33866 .57278 Mtetra
.642 .775 .944 r
.33866 .57278 .33974 .5737 .34147 .57314 .34039 .57225 Mtetra
.639 .783 .95 r
.34039 .57225 .34147 .57314 .34321 .57257 .34212 .57173 Mtetra
.635 .791 .957 r
.34212 .57173 .34321 .57257 .34494 .57202 .34385 .57121 Mtetra
.632 .798 .962 r
.34385 .57121 .34494 .57202 .34668 .57148 .34559 .5707 Mtetra
.631 .805 .966 r
.34559 .5707 .34668 .57148 .34841 .57095 .34732 .57018 Mtetra
.581 .793 .98 r
.34732 .57018 .34841 .57095 .35015 .57049 .34905 .56981 Mtetra
.536 .798 .994 r
.34905 .56981 .35015 .57049 .35188 .57007 .35078 .56951 Mtetra
.654 .861 .978 r
.35078 .56951 .35188 .57007 .35362 .56949 .35253 .56886 Mtetra
.85 .851 .843 r
.35253 .56886 .35362 .56949 .35539 .56841 .35433 .56709 Mtetra
.893 .738 .683 r
.35433 .56709 .35539 .56841 .35719 .56659 .35626 .56285 Mtetra
.906 .667 .565 r
.35626 .56285 .35719 .56659 .35902 .56437 .3588 .54605 Mtetra
.933 .666 .51 r
.3588 .54605 .35902 .56437 .36081 .56284 .36965 .3587 Mtetra
.537 .316 .526 r
.36965 .3587 .36081 .56284 .36253 .56276 .3713 .35802 Mtetra
.536 .315 .526 r
.3713 .35802 .36253 .56276 .36428 .56217 .37292 .35795 Mtetra
.541 .318 .527 r
.37292 .35795 .36428 .56217 .36618 .55835 .37464 .35562 Mtetra
.544 .321 .527 r
.37464 .35562 .36618 .55835 .37723 .3574 .37644 .35189 Mtetra
.687 .503 .632 r
.37644 .35189 .37723 .3574 .37913 .35125 .37817 .34933 Mtetra
.752 .656 .755 r
.37817 .34933 .37913 .35125 .38086 .34883 .37986 .34777 Mtetra
.694 .751 .895 r
.37986 .34777 .38086 .34883 .38251 .34805 .38151 .34706 Mtetra
.639 .749 .928 r
.38151 .34706 .38251 .34805 .38415 .34767 .38315 .34658 Mtetra
.657 .732 .905 r
.38315 .34658 .38415 .34767 .38578 .3473 .3848 .34603 Mtetra
.698 .713 .861 r
.3848 .34603 .38578 .3473 .38743 .34664 .38645 .34525 Mtetra
.643 .675 .866 r
.38645 .34525 .38743 .34664 .38908 .34612 .3881 .34475 Mtetra
.386 .56 .903 r
.3881 .34475 .38908 .34612 .39071 .34596 .38971 .34509 Mtetra
.776 .288 0 r
.38971 .34509 .39071 .34596 .39232 .34645 .39124 .34744 Mtetra
.899 .565 .405 r
.39124 .34744 .39232 .34645 .39391 .34727 .39254 .35534 Mtetra
.946 .672 .487 r
.39254 .35534 .39391 .34727 .39552 .3477 .38619 .54933 Mtetra
.534 .309 .519 r
.38619 .54933 .39552 .3477 .39719 .34677 .38794 .54917 Mtetra
.533 .308 .519 r
.38794 .54917 .39719 .34677 .39885 .3462 .38972 .54812 Mtetra
.537 .311 .52 r
.38972 .54812 .39885 .3462 .40042 .34784 .39141 .54936 Mtetra
.541 .314 .52 r
.39141 .54936 .40042 .34784 .39432 .5474 .39302 .55273 Mtetra
.624 .315 .426 r
.39302 .55273 .39432 .5474 .3958 .55439 .39469 .55459 Mtetra
.538 0 0 r
.39469 .55459 .3958 .55439 .39747 .55632 .39641 .55541 Mtetra
.491 .726 .976 r
.39641 .55541 .39747 .55632 .39922 .5562 .39816 .5553 Mtetra
.674 .794 .938 r
.39816 .5553 .39922 .5562 .401 .55546 .39994 .55463 Mtetra
.821 .825 .852 r
.39994 .55463 .401 .55546 .4028 .55423 .40175 .55305 Mtetra
.894 .759 .706 r
.40175 .55305 .4028 .55423 .40461 .55253 .40363 .54941 Mtetra
.88 .663 .605 r
.40363 .54941 .40461 .55253 .40644 .55047 .40568 .54106 Mtetra
.949 .679 .49 r
.40568 .54106 .40644 .55047 .40825 .5487 .41429 .34455 Mtetra
.538 .316 .526 r
.41429 .34455 .40825 .5487 .41002 .54856 .41598 .34358 Mtetra
.536 .314 .526 r
.41598 .34358 .41002 .54856 .41179 .54809 .41763 .34367 Mtetra
.54 .318 .527 r
.41763 .34367 .41179 .54809 .41363 .54564 .41934 .34175 Mtetra
.545 .322 .527 r
.41934 .34175 .41363 .54564 .42189 .34568 .42115 .3372 Mtetra
.654 .454 .601 r
.42115 .3372 .42189 .34568 .42383 .33661 .42289 .33433 Mtetra
.748 .63 .729 r
.42289 .33433 .42383 .33661 .42558 .33363 .4246 .33256 Mtetra
.671 .746 .907 r
.4246 .33256 .42558 .33363 .42726 .33285 .42628 .33195 Mtetra
.584 .755 .959 r
.42628 .33195 .42726 .33285 .42892 .33255 .42794 .33162 Mtetra
.563 .741 .96 r
.42794 .33162 .42892 .33255 .43058 .33239 .42961 .33136 Mtetra
.651 .747 .92 r
.42961 .33136 .43058 .33239 .43226 .33187 .43128 .33083 Mtetra
.665 .75 .914 r
.43128 .33083 .43226 .33187 .43393 .33131 .43296 .33024 Mtetra
.681 .749 .903 r
.43296 .33024 .43393 .33131 .43561 .33069 .43464 .32958 Mtetra
.701 .746 .887 r
.43464 .32958 .43561 .33069 .43729 .32999 .43632 .32881 Mtetra
.7 .733 .876 r
.43632 .32881 .43729 .32999 .43897 .32928 .43801 .32803 Mtetra
.692 .719 .87 r
.43801 .32803 .43897 .32928 .44066 .32858 .43969 .32728 Mtetra
.671 .704 .871 r
.43969 .32728 .44066 .32858 .44234 .32797 .44137 .32664 Mtetra
.664 .697 .87 r
.44137 .32664 .44234 .32797 .44402 .32737 .44306 .32602 Mtetra
.669 .696 .866 r
.44306 .32602 .44402 .32737 .44571 .32676 .44474 .32539 Mtetra
.705 .705 .847 r
.44474 .32539 .44571 .32676 .44739 .32603 .44643 .32453 Mtetra
.659 .669 .848 r
.44643 .32453 .44739 .32603 .44908 .32542 .44812 .32392 Mtetra
.523 .609 .88 r
.44812 .32392 .44908 .32542 .45076 .32509 .44979 .32391 Mtetra
.581 .113 0 r
.44979 .32391 .45076 .32509 .45242 .32554 .45142 .32599 Mtetra
.905 .543 .342 r
.45142 .32599 .45242 .32554 .45408 .32639 .45295 .33231 Mtetra
.955 .675 .467 r
.45295 .33231 .45408 .32639 .45573 .32741 .45023 .53018 Mtetra
.538 .312 .52 r
.45023 .53018 .45573 .32741 .45741 .32749 .45198 .53188 Mtetra
.533 .308 .519 r
.45198 .53188 .45741 .32749 .45911 .32682 .45379 .5311 Mtetra
.527 .303 .518 r
.45379 .5311 .45911 .32682 .46082 .32537 .45566 .52706 Mtetra
0 0 .299 r
.45566 .52706 .46082 .32537 .46255 .32311 .46148 .32698 Mtetra
0 0 0 r
.46148 .32698 .46255 .32311 .46427 .32117 .46329 .32113 Mtetra
.948 .913 .749 r
.46329 .32113 .46427 .32117 .46598 .31965 .46503 .31831 Mtetra
.716 .714 .847 r
.46503 .31831 .46598 .31965 .46768 .31892 .46673 .31739 Mtetra
.639 .657 .851 r
.46673 .31739 .46768 .31892 .46938 .31839 .46843 .31688 Mtetra
.598 .643 .866 r
.46843 .31688 .46938 .31839 .47108 .31796 .47012 .31658 Mtetra
.655 .687 .868 r
.47012 .31658 .47108 .31796 .47278 .31738 .47182 .316 Mtetra
.65 .685 .87 r
.47182 .316 .47278 .31738 .47448 .31682 .47352 .31546 Mtetra
.642 .685 .875 r
.47352 .31546 .47448 .31682 .47618 .31628 .47522 .31495 Mtetra
.621 .682 .886 r
.47522 .31495 .47618 .31628 .47788 .3158 .47692 .31453 Mtetra
.617 .691 .897 r
.47692 .31453 .47788 .3158 .47958 .31534 .47863 .31414 Mtetra
.622 .707 .907 r
.47863 .31414 .47958 .31534 .48129 .31484 .48033 .31372 Mtetra
.649 .732 .91 r
.48033 .31372 .48129 .31484 .48299 .31426 .48204 .31319 Mtetra
.664 .748 .912 r
.48204 .31319 .48299 .31426 .4847 .31362 .48374 .31259 Mtetra
.681 .76 .911 r
.48374 .31259 .4847 .31362 .48641 .31294 .48545 .31192 Mtetra
.745 .779 .881 r
.48545 .31192 .48641 .31294 .48813 .31181 .48717 .31091 Mtetra
.72 .798 .913 r
.48717 .31091 .48813 .31181 .48984 .31097 .48888 .31006 Mtetra
.642 .774 .943 r
.48888 .31006 .48984 .31097 .49155 .31068 .4906 .30953 Mtetra
.259 .537 .92 r
.4906 .30953 .49155 .31068 .49323 .31291 .4923 .31004 Mtetra
.245 .297 .718 r
.4923 .31004 .49323 .31291 .49484 .32328 .49399 .31157 Mtetra
.35 .215 .553 r
.49399 .31157 .49484 .32328 .49478 .52124 .49566 .31606 Mtetra
0 0 .331 r
.49566 .31606 .49478 .52124 .49659 .52333 .49562 .51652 Mtetra
.113 .088 .548 r
.49562 .51652 .49659 .52333 .49841 .52403 .49741 .52135 Mtetra
.145 .259 .724 r
.49741 .52135 .49841 .52403 .50024 .52407 .49923 .52313 Mtetra
.551 .751 .97 r
.49923 .52313 .50024 .52407 .50208 .52358 .50106 .52286 Mtetra
.699 .849 .954 r
.50106 .52286 .50208 .52358 .50392 .52285 .5029 .52204 Mtetra
.749 .84 .92 r
.5029 .52204 .50392 .52285 .50576 .52203 .50475 .52099 Mtetra
.552 .73 .958 r
.50475 .52099 .50576 .52203 .5076 .52196 .50659 .52075 Mtetra
.584 .708 .928 r
.50659 .52075 .5076 .52196 .50944 .52166 .50843 .52043 Mtetra
.662 .734 .903 r
.50843 .52043 .50944 .52166 .51129 .5208 .51028 .51979 Mtetra
.826 .808 .833 r
.51028 .51979 .51129 .5208 .51314 .51732 .51213 .51806 Mtetra
.875 .974 .664 r
.51213 .51806 .51314 .51732 .51502 .50743 .51398 .51525 Mtetra
.134 0 .314 r
.51398 .51525 .51502 .50743 .51734 .30636 .51584 .50991 Mtetra
0 0 .329 r
.51584 .50991 .51734 .30636 .51908 .30322 .51812 .30892 Mtetra
0 0 .124 r
.51812 .30892 .51908 .30322 .52081 .30154 .51986 .30238 Mtetra
.875 .958 .618 r
.51986 .30238 .52081 .30154 .52254 .30044 .5216 .29947 Mtetra
.76 .796 .882 r
.5216 .29947 .52254 .30044 .52427 .29969 .52333 .29837 Mtetra
.647 .699 .884 r
.52333 .29837 .52427 .29969 .52601 .29913 .52507 .29784 Mtetra
.59 .678 .902 r
.52507 .29784 .52601 .29913 .52774 .29868 .5268 .29754 Mtetra
.697 .748 .891 r
.5268 .29754 .52774 .29868 .52948 .29774 .52854 .29677 Mtetra
.691 .781 .92 r
.52854 .29677 .52948 .29774 .53121 .29696 .53028 .29605 Mtetra
.618 .769 .952 r
.53028 .29605 .53121 .29696 .53295 .29669 .53202 .2956 Mtetra
.322 .586 .939 r
.53202 .2956 .53295 .29669 .5347 .29869 .53376 .29596 Mtetra
.291 .338 .739 r
.53376 .29596 .5347 .29869 .53648 .30839 .53551 .29727 Mtetra
.387 .246 .565 r
.53551 .29727 .53648 .30839 .53908 .50712 .53727 .30092 Mtetra
0 0 .352 r
.53727 .30092 .53908 .50712 .54095 .50939 .53992 .50077 Mtetra
.151 .097 .537 r
.53992 .50077 .54095 .50939 .54282 .51005 .54181 .50663 Mtetra
.197 .245 .687 r
.54181 .50663 .54282 .51005 .54469 .51013 .54369 .50875 Mtetra
.239 .494 .897 r
.54369 .50875 .54469 .51013 .54656 .51035 .54557 .50945 Mtetra
.515 .747 .979 r
.54557 .50945 .54656 .51035 .54844 .51013 .54744 .50925 Mtetra
.756 .83 .909 r
.54744 .50925 .54844 .51013 .5503 .50913 .54931 .50814 Mtetra
.933 .789 .678 r
.54931 .50814 .5503 .50913 .55215 .50481 .55115 .50381 Mtetra
.971 .689 .436 r
.55115 .50381 .55215 .50481 .55223 .29994 .5513 .29889 Mtetra
.962 .739 .554 r
.5513 .29889 .55223 .29994 .5539 .29026 .55297 .2891 Mtetra
.838 .778 .794 r
.55297 .2891 .5539 .29026 .55564 .28831 .55471 .28715 Mtetra
.671 .74 .902 r
.55471 .28715 .55564 .28831 .55739 .28765 .55647 .28651 Mtetra
.552 .694 .934 r
.55647 .28651 .55739 .28765 .55915 .28745 .55823 .28632 Mtetra
.721 .76 .883 r
.55823 .28632 .55915 .28745 .5609 .28653 .55998 .28541 Mtetra
.714 .759 .888 r
.55998 .28541 .5609 .28653 .56266 .28567 .56173 .28455 Mtetra
.566 .705 .935 r
.56173 .28455 .56266 .28567 .56442 .28542 .5635 .2843 Mtetra
.713 .252 0 r
.5635 .2843 .56442 .28542 .56622 .2883 .5653 .28719 Mtetra
.972 .681 .415 r
.5653 .28719 .56622 .2883 .57083 .49278 .56985 .49174 Mtetra
.933 .555 .192 r
.56985 .49174 .57083 .49278 .57283 .50045 .57184 .49937 Mtetra
0 .251 .743 r
.57184 .49937 .57283 .50045 .57474 .50177 .57376 .50069 Mtetra
.569 .732 .952 r
.57376 .50069 .57474 .50177 .57663 .50148 .57565 .50039 Mtetra
.784 .798 .864 r
.57565 .50039 .57663 .50148 .57851 .50011 .57753 .49901 Mtetra
.93 .783 .676 r
.57753 .49901 .57851 .50011 .58034 .49579 .57936 .49467 Mtetra
.973 .688 .426 r
.57936 .49467 .58034 .49579 .5787 .29074 .57777 .28943 Mtetra
.958 .733 .557 r
.57777 .28943 .5787 .29074 .58031 .28118 .57939 .28001 Mtetra
.849 .779 .784 r
.57939 .28001 .58031 .28118 .58205 .27907 .58114 .27791 Mtetra
.668 .74 .904 r
.58114 .27791 .58205 .27907 .58382 .27842 .58291 .27728 Mtetra
.544 .692 .936 r
.58291 .27728 .58382 .27842 .5856 .27824 .58469 .27711 Mtetra
.654 .739 .912 r
.58469 .27711 .5856 .27824 .58737 .27755 .58646 .27653 Mtetra
.69 .776 .917 r
.58646 .27653 .58737 .27755 .58914 .27674 .58823 .27579 Mtetra
.629 .772 .949 r
.58823 .27579 .58914 .27674 .59092 .27637 .59001 .2753 Mtetra
.403 .638 .951 r
.59001 .2753 .59092 .27637 .59274 .27779 .5918 .27548 Mtetra
.305 .384 .779 r
.5918 .27548 .59274 .27779 .59467 .28401 .59362 .27656 Mtetra
.362 .255 .596 r
.59362 .27656 .59467 .28401 .60114 .48655 .59548 .27943 Mtetra
0 0 .379 r
.59548 .27943 .60114 .48655 .60313 .48974 .60192 .47834 Mtetra
.143 .076 .515 r
.60192 .47834 .60313 .48974 .60507 .49056 .60403 .48653 Mtetra
.218 .234 .663 r
.60403 .48653 .60507 .49056 .607 .49067 .60601 .489 Mtetra
.286 .471 .867 r
.60601 .489 .607 .49067 .60892 .49073 .60796 .48978 Mtetra
.523 .743 .975 r
.60796 .48978 .60892 .49073 .61084 .49048 .60988 .48957 Mtetra
.753 .831 .912 r
.60988 .48957 .61084 .49048 .61275 .48948 .61178 .48846 Mtetra
.927 .802 .703 r
.61178 .48846 .61275 .48948 .61458 .48581 .61361 .48472 Mtetra
.975 .687 .413 r
.61361 .48472 .61458 .48581 .61091 .2838 .61 .28266 Mtetra
.971 .728 .511 r
.61 .28266 .61091 .2838 .61235 .27046 .61145 .2693 Mtetra
.876 .786 .758 r
.61145 .2693 .61235 .27046 .61408 .26795 .61318 .26679 Mtetra
.689 .75 .898 r
.61318 .26679 .61408 .26795 .61587 .2672 .61497 .26605 Mtetra
.569 .703 .932 r
.61497 .26605 .61587 .2672 .61767 .26694 .61677 .26579 Mtetra
.685 .75 .901 r
.61677 .26579 .61767 .26694 .61946 .26621 .61856 .26507 Mtetra
.726 .764 .883 r
.61856 .26507 .61946 .26621 .62125 .26526 .62035 .26412 Mtetra
.609 .722 .925 r
.62035 .26412 .62125 .26526 .62305 .26486 .62215 .26371 Mtetra
0 .049 .584 r
.62215 .26371 .62305 .26486 .62493 .26676 .62403 .26563 Mtetra
.974 .678 .39 r
.62403 .26563 .62493 .26676 .63333 .46629 .63239 .46558 Mtetra
.953 .605 .278 r
.63239 .46558 .63333 .46629 .63572 .47996 .63477 .47889 Mtetra
0 .148 .658 r
.63477 .47889 .63572 .47996 .63773 .48163 .63678 .48055 Mtetra
.609 .752 .946 r
.63678 .48055 .63773 .48163 .63967 .48119 .63871 .4801 Mtetra
.732 .792 .901 r
.63871 .4801 .63967 .48119 .64158 .48017 .64063 .47907 Mtetra
.637 .76 .937 r
.64063 .47907 .64158 .48017 .64352 .47962 .64257 .47851 Mtetra
.543 .718 .954 r
.64257 .47851 .64352 .47962 .64547 .47941 .64452 .47829 Mtetra
.694 .777 .915 r
.64452 .47829 .64547 .47941 .6474 .47859 .64645 .47747 Mtetra
.909 .801 .728 r
.64645 .47747 .6474 .47859 .64924 .47536 .64829 .47422 Mtetra
.976 .685 .4 r
.64829 .47422 .64924 .47536 .64374 .28059 .64278 .27779 Mtetra
.956 .691 .492 r
.64278 .27779 .64374 .28059 .64476 .25941 .64387 .25822 Mtetra
.892 .785 .736 r
.64387 .25822 .64476 .25941 .64648 .25656 .6456 .25538 Mtetra
.702 .753 .891 r
.6456 .25538 .64648 .25656 .64829 .25574 .6474 .25456 Mtetra
.586 .707 .927 r
.6474 .25456 .64829 .25574 .65011 .25542 .64923 .25424 Mtetra
.665 .741 .906 r
.64923 .25424 .65011 .25542 .65193 .25477 .65104 .2536 Mtetra
.733 .764 .878 r
.65104 .2536 .65193 .25477 .65372 .25377 .65284 .2526 Mtetra
.636 .73 .916 r
.65284 .2526 .65372 .25377 .65555 .25326 .65466 .25208 Mtetra
0 .283 .78 r
.65466 .25208 .65555 .25326 .65745 .25458 .65656 .25341 Mtetra
.938 .574 .185 r
.65656 .25341 .65745 .25458 .65972 .26442 .65884 .26325 Mtetra
.975 .675 .374 r
.65884 .26325 .65972 .26442 .67059 .46786 .66965 .46674 Mtetra
0 0 .512 r
.66965 .46674 .67059 .46786 .67267 .47013 .67173 .46901 Mtetra
.63 .756 .938 r
.67173 .46901 .67267 .47013 .67463 .46959 .67369 .46848 Mtetra
.769 .8 .879 r
.67369 .46848 .67463 .46959 .67655 .46832 .67562 .4672 Mtetra
.782 .803 .87 r
.67562 .4672 .67655 .46832 .67847 .46695 .67754 .46583 Mtetra
.729 .79 .901 r
.67754 .46583 .67847 .46695 .68041 .46593 .67948 .46481 Mtetra
.714 .785 .907 r
.67948 .46481 .68041 .46593 .68236 .465 .68142 .46387 Mtetra
.655 .763 .929 r
.68142 .46387 .68236 .465 .68431 .46436 .68338 .46322 Mtetra
.565 .725 .949 r
.68338 .46322 .68431 .46436 .68629 .46406 .68536 .46293 Mtetra
.536 .713 .953 r
.68536 .46293 .68629 .46406 .68828 .46386 .68735 .46273 Mtetra
.445 .667 .957 r
.68735 .46273 .68828 .46386 .69027 .46393 .68935 .4628 Mtetra
.416 .652 .956 r
.68935 .4628 .69027 .46393 .69228 .46408 .69135 .46295 Mtetra
.628 .755 .938 r
.69135 .46295 .69228 .46408 .69425 .46355 .69333 .46242 Mtetra
.89 .812 .765 r
.69333 .46242 .69425 .46355 .69611 .46086 .69519 .45973 Mtetra
.981 .724 .467 r
.69519 .45973 .69611 .46086 .69719 .44339 .69627 .4422 Mtetra
.977 .681 .379 r
.69627 .4422 .69719 .44339 .68857 .24449 .6877 .2433 Mtetra
.912 .79 .713 r
.6877 .2433 .68857 .24449 .69027 .24124 .6894 .24006 Mtetra
.708 .758 .891 r
.6894 .24006 .69027 .24124 .6921 .24037 .69123 .23919 Mtetra
.587 .709 .927 r
.69123 .23919 .6921 .24037 .69396 .24005 .69309 .23886 Mtetra
.623 .724 .919 r
.69309 .23886 .69396 .24005 .69581 .23958 .69494 .2384 Mtetra
.731 .765 .88 r
.69494 .2384 .69581 .23958 .69763 .23858 .69677 .23739 Mtetra
.639 .731 .915 r
.69677 .23739 .69763 .23858 .69948 .23805 .69862 .23685 Mtetra
.063 .398 .855 r
.69862 .23685 .69948 .23805 .70143 .23908 .70056 .23789 Mtetra
.925 .553 .139 r
.70056 .23789 .70143 .23908 .70386 .24854 .70299 .24731 Mtetra
.975 .671 .352 r
.70299 .24731 .70386 .24854 .71782 .45348 .71691 .45233 Mtetra
.599 .137 0 r
.71691 .45233 .71782 .45348 .72002 .45643 .71911 .45529 Mtetra
.42 .653 .955 r
.71911 .45529 .72002 .45643 .72206 .45658 .72114 .45544 Mtetra
.711 .785 .91 r
.72114 .45544 .72206 .45658 .72403 .45565 .72311 .45451 Mtetra
.888 .815 .77 r
.72311 .45451 .72403 .45565 .7259 .45303 .72498 .45188 Mtetra
.977 .757 .539 r
.72498 .45188 .7259 .45303 .72737 .44408 .72646 .44288 Mtetra
.977 .679 .365 r
.72646 .44288 .72737 .44408 .71638 .23613 .71552 .23491 Mtetra
.935 .784 .67 r
.71552 .23491 .71638 .23613 .71802 .23207 .71716 .23086 Mtetra
.72 .76 .884 r
.71716 .23086 .71802 .23207 .71986 .23112 .719 .22991 Mtetra
.582 .703 .926 r
.719 .22991 .71986 .23112 .72174 .23082 .72089 .2296 Mtetra
.544 .685 .931 r
.72089 .2296 .72174 .23082 .72363 .23065 .72278 .22943 Mtetra
.657 .736 .908 r
.72278 .22943 .72363 .23065 .7255 .23002 .72464 .22881 Mtetra
.663 .739 .906 r
.72464 .22881 .7255 .23002 .72736 .22937 .72651 .22816 Mtetra
.7 .754 .893 r
.72651 .22816 .72736 .22937 .72921 .22853 .72836 .22732 Mtetra
.756 .773 .867 r
.72836 .22732 .72921 .22853 .73104 .22736 .73019 .22615 Mtetra
.673 .744 .904 r
.73019 .22615 .73104 .22736 .7329 .22666 .73205 .22545 Mtetra
.242 .514 .909 r
.73205 .22545 .7329 .22666 .73486 .22732 .73401 .22611 Mtetra
.895 .51 .064 r
.73401 .22611 .73486 .22732 .73733 .2353 .73648 .23408 Mtetra
.975 .667 .334 r
.73648 .23408 .73733 .2353 .75373 .44189 .75284 .44073 Mtetra
.634 .179 0 r
.75284 .44073 .75373 .44189 .75602 .44522 .75513 .44407 Mtetra
.392 .636 .953 r
.75513 .44407 .75602 .44522 .7581 .44545 .7572 .4443 Mtetra
.695 .781 .917 r
.7572 .4443 .7581 .44545 .7601 .4446 .7592 .44344 Mtetra
.873 .82 .793 r
.7592 .44344 .7601 .4446 .76199 .44225 .7611 .44109 Mtetra
.978 .767 .552 r
.7611 .44109 .76199 .44225 .76347 .43435 .76258 .4332 Mtetra
.977 .675 .347 r
.76258 .4332 .76347 .43435 .75006 .22491 .74922 .2237 Mtetra
.951 .785 .641 r
.74922 .2237 .75006 .22491 .75164 .22025 .7508 .21904 Mtetra
.748 .773 .873 r
.7508 .21904 .75164 .22025 .75349 .21913 .75265 .21792 Mtetra
.622 .724 .92 r
.75265 .21792 .75349 .21913 .75538 .21866 .75454 .21745 Mtetra
.591 .71 .926 r
.75454 .21745 .75538 .21866 .75729 .21831 .75645 .2171 Mtetra
.75 .774 .873 r
.75645 .2171 .75729 .21831 .75913 .21718 .7583 .21597 Mtetra
.676 .747 .905 r
.7583 .21597 .75913 .21718 .76101 .21646 .76018 .21525 Mtetra
.376 .596 .932 r
.76018 .21525 .76101 .21646 .76298 .21679 .76214 .21558 Mtetra
.808 .395 0 r
.76214 .21558 .76298 .21679 .76535 .22225 .76451 .22105 Mtetra
.973 .663 .318 r
.76451 .22105 .76535 .22225 .78391 .43094 .78303 .42979 Mtetra
.717 .274 0 r
.78303 .42979 .78391 .43094 .78632 .43515 .78544 .43399 Mtetra
.503 .696 .956 r
.78544 .43399 .78632 .43515 .7884 .43505 .78752 .43389 Mtetra
.695 .782 .918 r
.78752 .43389 .7884 .43505 .79042 .43419 .78954 .43303 Mtetra
.735 .796 .901 r
.78954 .43303 .79042 .43419 .79242 .4331 .79154 .43194 Mtetra
.496 .692 .956 r
.79154 .43194 .79242 .4331 .7945 .43303 .79363 .43187 Mtetra
.625 .754 .939 r
.79363 .43187 .7945 .43303 .79655 .43249 .79568 .43132 Mtetra
.812 .816 .854 r
.79568 .43132 .79655 .43249 .79851 .43085 .79763 .42968 Mtetra
.98 .772 .552 r
.79763 .42968 .79851 .43085 .79996 .42325 .79909 .42209 Mtetra
.976 .671 .329 r
.79909 .42209 .79996 .42325 .78413 .21332 .7833 .2121 Mtetra
.959 .785 .623 r
.7833 .2121 .78413 .21332 .78566 .20832 .78484 .20709 Mtetra
.751 .775 .872 r
.78484 .20709 .78566 .20832 .78752 .20717 .7867 .20594 Mtetra
.622 .724 .919 r
.7867 .20594 .78752 .20717 .78944 .20669 .78862 .20546 Mtetra
.552 .69 .931 r
.78862 .20546 .78944 .20669 .79138 .20648 .79056 .20525 Mtetra
.746 .773 .875 r
.79056 .20525 .79138 .20648 .79325 .20536 .79243 .20413 Mtetra
.677 .747 .904 r
.79243 .20413 .79325 .20536 .79515 .20463 .79433 .2034 Mtetra
.456 .638 .935 r
.79433 .2034 .79515 .20463 .79713 .20474 .79631 .20351 Mtetra
.768 .353 0 r
.79631 .20351 .79713 .20474 .79957 .20994 .79875 .20871 Mtetra
.971 .657 .298 r
.79875 .20871 .79957 .20994 .82066 .41944 .8198 .41826 Mtetra
.726 .292 0 r
.8198 .41826 .82066 .41944 .8232 .42409 .82234 .42291 Mtetra
.306 .58 .938 r
.82234 .42291 .8232 .42409 .82537 .42457 .8245 .42339 Mtetra
.649 .764 .933 r
.8245 .42339 .82537 .42457 .82743 .42392 .82657 .42274 Mtetra
.829 .821 .841 r
.82657 .42274 .82743 .42392 .82938 .42211 .82852 .42093 Mtetra
.975 .789 .59 r
.82852 .42093 .82938 .42211 .83093 .416 .83007 .41481 Mtetra
.974 .667 .312 r
.83007 .41481 .83093 .416 .81299 .20514 .81218 .2039 Mtetra
.974 .774 .572 r
.81218 .2039 .81299 .20514 .81437 .1988 .81356 .19756 Mtetra
.76 .758 .85 r
.19608 .41169 .19715 .41268 .19873 .4116 .19767 .41061 Mtetra
.612 .727 .927 r
.19767 .41061 .19873 .4116 .20025 .41125 .19919 .41026 Mtetra
.455 .668 .954 r
.19919 .41026 .20025 .41125 .20173 .41129 .20067 .4103 Mtetra
.654 .739 .912 r
.20067 .4103 .20173 .41129 .20326 .41079 .2022 .4098 Mtetra
.663 .741 .908 r
.2022 .4098 .20326 .41079 .2048 .41026 .20374 .40926 Mtetra
.669 .743 .905 r
.20374 .40926 .2048 .41026 .20634 .4097 .20528 .4087 Mtetra
.763 .758 .849 r
.20528 .4087 .20634 .4097 .20794 .40859 .20688 .4076 Mtetra
.709 .751 .885 r
.20688 .4076 .20794 .40859 .2095 .40784 .20844 .40685 Mtetra
.494 .684 .951 r
.20844 .40685 .2095 .40784 .21099 .4078 .20994 .4068 Mtetra
.932 .563 .28 r
.20994 .4068 .21099 .4078 .21206 .41224 .211 .41124 Mtetra
.939 .683 .523 r
.211 .41124 .21206 .41224 .19434 .61181 .19321 .61086 Mtetra
.932 .569 .305 r
.19321 .61086 .19434 .61181 .19545 .61679 .19432 .61585 Mtetra
0 .388 .825 r
.19432 .61585 .19545 .61679 .19698 .61752 .19584 .61658 Mtetra
.627 .757 .94 r
.19584 .61658 .19698 .61752 .19861 .61708 .19747 .61614 Mtetra
.802 .78 .832 r
.19747 .61614 .19861 .61708 .20035 .61559 .19921 .61465 Mtetra
.906 .743 .668 r
.19921 .61465 .20035 .61559 .20242 .61051 .20129 .60956 Mtetra
.939 .687 .53 r
.20129 .60956 .20242 .61051 .22275 .40999 .2217 .40897 Mtetra
.913 .724 .633 r
.2217 .40897 .22275 .40999 .22489 .4032 .22384 .40219 Mtetra
.795 .759 .82 r
.22384 .40219 .22489 .4032 .22652 .40178 .22547 .40078 Mtetra
.644 .735 .915 r
.22547 .40078 .22652 .40178 .22807 .40132 .22701 .40031 Mtetra
.502 .685 .949 r
.22701 .40031 .22807 .40132 .22957 .40126 .22852 .40025 Mtetra
.733 .754 .869 r
.22852 .40025 .22957 .40126 .23116 .40034 .23011 .39935 Mtetra
.698 .753 .894 r
.23011 .39935 .23116 .40034 .23273 .39963 .23168 .39865 Mtetra
.488 .686 .955 r
.23168 .39865 .23273 .39963 .23424 .39965 .23319 .39862 Mtetra
.924 .536 .222 r
.23319 .39862 .23424 .39965 .23532 .40441 .23434 .40257 Mtetra
.943 .685 .517 r
.23434 .40257 .23532 .40441 .2189 .60525 .21793 .60261 Mtetra
.916 .576 .113 r
.21793 .60261 .2189 .60525 .2201 .60987 .21905 .60802 Mtetra
.409 .504 .845 r
.21905 .60802 .2201 .60987 .22169 .61005 .22062 .60844 Mtetra
.673 .66 .83 r
.22062 .60844 .22169 .61005 .22339 .6091 .2223 .60773 Mtetra
.746 .713 .821 r
.2223 .60773 .22339 .6091 .22513 .60765 .22402 .60655 Mtetra
.707 .747 .883 r
.22402 .60655 .22513 .60765 .22682 .60674 .2257 .60574 Mtetra
.685 .761 .909 r
.2257 .60574 .22682 .60674 .2285 .60608 .22738 .60507 Mtetra
.675 .756 .912 r
.22738 .60507 .2285 .60608 .23016 .60554 .22905 .60444 Mtetra
.65 .733 .91 r
.22905 .60444 .23016 .60554 .23181 .60515 .23071 .60391 Mtetra
.634 .702 .895 r
.23071 .60391 .23181 .60515 .23345 .60485 .23237 .60345 Mtetra
.625 .673 .876 r
.23237 .60345 .23345 .60485 .2351 .60456 .23403 .60303 Mtetra
.61 .648 .863 r
.23403 .60303 .2351 .60456 .23674 .60438 .23568 .60268 Mtetra
.613 .626 .84 r
.23568 .60268 .23674 .60438 .23839 .60405 .23733 .60231 Mtetra
.627 .627 .831 r
.23733 .60231 .23839 .60405 .24007 .6034 .23899 .60186 Mtetra
.602 .643 .864 r
.23899 .60186 .24007 .6034 .24182 .60186 .24065 .60154 Mtetra
.619 .896 .987 r
.24065 .60154 .24182 .60186 .24366 .59925 .24232 .60093 Mtetra
0 0 0 r
.24232 .60093 .24366 .59925 .2457 .59424 .24406 .5996 Mtetra
0 0 .011 r
.24406 .5996 .2457 .59424 .26332 .39727 .24612 .59436 Mtetra
0 0 .156 r
.24612 .59436 .26332 .39727 .26539 .39067 .26404 .39351 Mtetra
.939 .888 .483 r
.26404 .39351 .26539 .39067 .26716 .38775 .26606 .38744 Mtetra
.866 .888 .849 r
.26606 .38744 .26716 .38775 .26879 .38651 .26773 .38575 Mtetra
.665 .798 .946 r
.26773 .38575 .26879 .38651 .27037 .38595 .26931 .38518 Mtetra
.515 .75 .981 r
.26931 .38518 .27037 .38595 .27192 .38569 .27086 .38502 Mtetra
.594 .803 .98 r
.27086 .38502 .27192 .38569 .27348 .38536 .27242 .38464 Mtetra
.645 .802 .958 r
.27242 .38464 .27348 .38536 .27505 .38499 .274 .38413 Mtetra
.654 .772 .936 r
.274 .38413 .27505 .38499 .27662 .38459 .27558 .38361 Mtetra
.676 .753 .909 r
.27558 .38361 .27662 .38459 .27822 .38383 .27717 .38301 Mtetra
.681 .789 .931 r
.27717 .38301 .27822 .38383 .27982 .38302 .27876 .38238 Mtetra
.658 .829 .966 r
.27876 .38238 .27982 .38302 .2814 .38245 .28034 .38182 Mtetra
.687 .834 .954 r
.28034 .38182 .2814 .38245 .28293 .38269 .28193 .38116 Mtetra
.634 .645 .844 r
.28193 .38116 .28293 .38269 .28438 .38393 .28351 .38071 Mtetra
.527 .45 .713 r
.28351 .38071 .28438 .38393 .28568 .38724 .28505 .38086 Mtetra
.219 .152 .564 r
.28505 .38086 .28568 .38724 .27273 .58309 .28635 .38409 Mtetra
0 0 .194 r
.28635 .38409 .27273 .58309 .27387 .58991 .27313 .58405 Mtetra
0 0 .311 r
.27313 .58405 .27387 .58991 .27535 .59223 .27432 .5903 Mtetra
.141 .336 .798 r
.27432 .5903 .27535 .59223 .27696 .59289 .27589 .59142 Mtetra
.604 .656 .875 r
.27589 .59142 .27696 .59289 .27863 .59269 .27757 .59108 Mtetra
.691 .67 .825 r
.27757 .59108 .27863 .59269 .28034 .59194 .27928 .59024 Mtetra
.651 .644 .83 r
.27928 .59024 .28034 .59194 .2821 .59044 .28098 .58965 Mtetra
.668 .805 .949 r
.28098 .58965 .2821 .59044 .28394 .58796 .28269 .58903 Mtetra
0 0 0 r
.28269 .58903 .28394 .58796 .28591 .58352 .28444 .58777 Mtetra
.28444 .58777 .28591 .58352 .30133 .38592 .28639 .58359 Mtetra
0 0 .186 r
.28639 .58359 .30133 .38592 .30348 .37748 .30202 .38264 Mtetra
.763 .759 .247 r
.30202 .38264 .30348 .37748 .30525 .37453 .30414 .37461 Mtetra
.92 .931 .799 r
.30414 .37461 .30525 .37453 .30686 .3738 .30586 .37236 Mtetra
.67 .673 .844 r
.30586 .37236 .30686 .3738 .30836 .37467 .30747 .37172 Mtetra
.494 .445 .73 r
.30747 .37172 .30836 .37467 .30973 .37759 .30901 .37206 Mtetra
.224 .172 .586 r
.30901 .37206 .30973 .37759 .29831 .57215 .31038 .37487 Mtetra
0 0 .208 r
.31038 .37487 .29831 .57215 .29936 .58141 .29868 .57414 Mtetra
0 0 .296 r
.29868 .57414 .29936 .58141 .30086 .58403 .29983 .58193 Mtetra
.059 .259 .753 r
.29983 .58193 .30086 .58403 .30248 .58483 .30141 .58335 Mtetra
.596 .652 .876 r
.30141 .58335 .30248 .58483 .30416 .58469 .30311 .58305 Mtetra
.69 .668 .823 r
.30311 .58305 .30416 .58469 .30589 .58397 .30484 .5822 Mtetra
.7 .657 .804 r
.30484 .5822 .30589 .58397 .30767 .58232 .30658 .58123 Mtetra
.729 .762 .878 r
.30658 .58123 .30767 .58232 .30953 .57947 .30832 .58028 Mtetra
0 0 0 r
.30832 .58028 .30953 .57947 .31149 .57502 .31006 .57929 Mtetra
.41 .097 .321 r
.31006 .57929 .31149 .57502 .31352 .56925 .3118 .57844 Mtetra
.492 .225 .437 r
.3118 .57844 .31352 .56925 .3154 .566 .31352 .57779 Mtetra
.508 .25 .458 r
.31352 .57779 .3154 .566 .31694 .56821 .31523 .57729 Mtetra
.509 .24 .442 r
.31523 .57729 .31694 .56821 .31835 .5727 .31694 .577 Mtetra
.489 .172 .355 r
.31694 .577 .31835 .5727 .31985 .57581 .31863 .57684 Mtetra
.304 0 0 r
.31863 .57684 .31985 .57581 .32143 .5775 .32033 .57666 Mtetra
.587 .778 .971 r
.32033 .57666 .32143 .5775 .3231 .5779 .32204 .5763 Mtetra
.645 .657 .847 r
.32204 .5763 .3231 .5779 .32481 .57745 .32377 .57575 Mtetra
.652 .647 .832 r
.32377 .57575 .32481 .57745 .32655 .57674 .3255 .57514 Mtetra
.652 .66 .845 r
.3255 .57514 .32655 .57674 .32828 .57606 .32722 .57455 Mtetra
.647 .671 .858 r
.32722 .57455 .32828 .57606 .33001 .5755 .32895 .574 Mtetra
.646 .671 .859 r
.32895 .574 .33001 .5755 .33174 .57494 .33068 .57345 Mtetra
.644 .672 .862 r
.33068 .57345 .33174 .57494 .33346 .57439 .33241 .57292 Mtetra
.642 .674 .865 r
.33241 .57292 .33346 .57439 .33519 .57385 .33414 .5724 Mtetra
.642 .678 .868 r
.33414 .5724 .33519 .57385 .33692 .57331 .33587 .57187 Mtetra
.646 .681 .869 r
.33587 .57187 .33692 .57331 .33866 .57278 .3376 .57133 Mtetra
.649 .682 .867 r
.3376 .57133 .33866 .57278 .34039 .57225 .33933 .57078 Mtetra
.648 .676 .864 r
.33933 .57078 .34039 .57225 .34212 .57173 .34107 .57022 Mtetra
.641 .67 .862 r
.34107 .57022 .34212 .57173 .34385 .57121 .3428 .5697 Mtetra
.635 .666 .863 r
.3428 .5697 .34385 .57121 .34559 .5707 .34453 .56921 Mtetra
.636 .67 .865 r
.34453 .56921 .34559 .5707 .34732 .57018 .34627 .56872 Mtetra
.591 .655 .882 r
.34627 .56872 .34732 .57018 .34905 .56981 .34799 .56843 Mtetra
.564 .659 .9 r
.34799 .56843 .34905 .56981 .35078 .56951 .34972 .56824 Mtetra
.681 .721 .88 r
.34972 .56824 .35078 .56951 .35253 .56886 .35147 .56753 Mtetra
.845 .742 .75 r
.35147 .56753 .35253 .56886 .35433 .56709 .35331 .565 Mtetra
.915 .696 .591 r
.35331 .565 .35433 .56709 .35626 .56285 .35554 .55461 Mtetra
.946 .681 .501 r
.35554 .55461 .35626 .56285 .3588 .54605 .36718 .35462 Mtetra
.543 .32 .527 r
.36718 .35462 .3588 .54605 .36965 .3587 .36896 .35124 Mtetra
.587 .412 .611 r
.36896 .35124 .36965 .3587 .3713 .35802 .37061 .35041 Mtetra
.561 .391 .608 r
.37061 .35041 .3713 .35802 .37292 .35795 .37224 .3501 Mtetra
.565 .392 .606 r
.37224 .3501 .37292 .35795 .37464 .35562 .37387 .34969 Mtetra
.602 .438 .631 r
.37387 .34969 .37464 .35562 .37644 .35189 .37553 .34879 Mtetra
.646 .532 .71 r
.37553 .34879 .37644 .35189 .37817 .34933 .37719 .34791 Mtetra
.689 .687 .843 r
.37719 .34791 .37817 .34933 .37986 .34777 .37884 .34715 Mtetra
.654 .84 .972 r
.37884 .34715 .37986 .34777 .38151 .34706 .38049 .34657 Mtetra
.617 .862 .989 r
.38049 .34657 .38151 .34706 .38315 .34658 .38213 .34604 Mtetra
.679 .865 .97 r
.38213 .34604 .38315 .34658 .3848 .34603 .38378 .34535 Mtetra
.736 .842 .93 r
.38378 .34535 .3848 .34603 .38645 .34525 .38545 .34447 Mtetra
.629 .794 .961 r
.38545 .34447 .38645 .34525 .3881 .34475 .38709 .344 Mtetra
0 .303 .739 r
.38709 .344 .3881 .34475 .38971 .34509 .38868 .34486 Mtetra
.923 .563 .325 r
.38868 .34486 .38971 .34509 .39124 .34744 .39005 .35099 Mtetra
.952 .679 .482 r
.39005 .35099 .39124 .34744 .39254 .35534 .38321 .55284 Mtetra
.541 .314 .52 r
.38321 .55284 .39254 .35534 .38619 .54933 .3848 .55619 Mtetra
.509 .224 .417 r
.3848 .55619 .38619 .54933 .38794 .54917 .38655 .55605 Mtetra
.467 .187 .404 r
.38655 .55605 .38794 .54917 .38972 .54812 .38833 .55526 Mtetra
.471 .193 .409 r
.38833 .55526 .38972 .54812 .39141 .54936 .3901 .55448 Mtetra
.499 .194 .381 r
.3901 .55448 .39141 .54936 .39302 .55273 .39185 .55434 Mtetra
.391 0 .091 r
.39185 .55434 .39302 .55273 .39469 .55459 .39361 .55417 Mtetra
.378 .787 .981 r
.39361 .55417 .39469 .55459 .39641 .55541 .39536 .554 Mtetra
.556 .653 .9 r
.39536 .554 .39641 .55541 .39816 .5553 .39712 .55384 Mtetra
.666 .689 .862 r
.39712 .55384 .39816 .5553 .39994 .55463 .39889 .55318 Mtetra
.811 .73 .776 r
.39889 .55318 .39994 .55463 .40175 .55305 .40072 .55118 Mtetra
.908 .707 .619 r
.40072 .55118 .40175 .55305 .40363 .54941 .40274 .54399 Mtetra
.954 .685 .487 r
.40274 .54399 .40363 .54941 .40568 .54106 .41176 .34057 Mtetra
.545 .322 .527 r
.41176 .34057 .40568 .54106 .41429 .34455 .41357 .33606 Mtetra
.586 .404 .601 r
.41357 .33606 .41429 .34455 .41598 .34358 .41525 .3351 Mtetra
.56 .384 .6 r
.41525 .3351 .41598 .34358 .41763 .34367 .41691 .33476 Mtetra
.556 .379 .597 r
.41691 .33476 .41763 .34367 .41934 .34175 .41857 .33449 Mtetra
.591 .417 .614 r
.41857 .33449 .41934 .34175 .42115 .3372 .42025 .33358 Mtetra
.635 .506 .689 r
.42025 .33358 .42115 .3372 .42289 .33433 .42193 .33268 Mtetra
.683 .658 .819 r
.42193 .33268 .42289 .33433 .4246 .33256 .42361 .3319 Mtetra
.646 .83 .971 r
.42361 .3319 .4246 .33256 .42628 .33195 .42528 .33133 Mtetra
.621 .836 .982 r
.42528 .33133 .42628 .33195 .42794 .33162 .42695 .33082 Mtetra
.638 .796 .959 r
.42695 .33082 .42794 .33162 .42961 .33136 .42863 .33031 Mtetra
.665 .748 .912 r
.42863 .33031 .42961 .33136 .43128 .33083 .4303 .32972 Mtetra
.669 .738 .902 r
.4303 .32972 .43128 .33083 .43296 .33024 .43198 .32911 Mtetra
.671 .735 .898 r
.43198 .32911 .43296 .33024 .43464 .32958 .43366 .32849 Mtetra
.672 .744 .904 r
.43366 .32849 .43464 .32958 .43632 .32881 .43534 .32786 Mtetra
.674 .774 .925 r
.43534 .32786 .43632 .32881 .43801 .32803 .43702 .32723 Mtetra
.673 .808 .947 r
.43702 .32723 .43801 .32803 .43969 .32728 .43871 .3266 Mtetra
.671 .834 .962 r
.43871 .3266 .43969 .32728 .44137 .32664 .44039 .32595 Mtetra
.669 .834 .963 r
.44039 .32595 .44137 .32664 .44306 .32602 .44207 .32531 Mtetra
.685 .831 .954 r
.44207 .32531 .44306 .32602 .44474 .32539 .44376 .32463 Mtetra
.751 .831 .913 r
.44376 .32463 .44474 .32539 .44643 .32453 .44546 .32364 Mtetra
.666 .786 .938 r
.44546 .32364 .44643 .32453 .44812 .32392 .44714 .32304 Mtetra
.274 .611 .956 r
.44714 .32304 .44812 .32392 .44979 .32391 .44881 .32335 Mtetra
.911 .509 .2 r
.44881 .32335 .44979 .32391 .45142 .32599 .45037 .32798 Mtetra
.96 .681 .462 r
.45037 .32798 .45142 .32599 .45295 .33231 .44735 .53143 Mtetra
.543 .316 .52 r
.44735 .53143 .45295 .33231 .45023 .53018 .44903 .53627 Mtetra
.546 .248 .414 r
.44903 .53627 .45023 .53018 .45198 .53188 .45081 .53678 Mtetra
.45 .146 .358 r
.45081 .53678 .45198 .53188 .45379 .5311 .45262 .53611 Mtetra
.301 .019 .308 r
.45262 .53611 .45379 .5311 .45566 .52706 .45446 .53403 Mtetra
0 0 .092 r
.45446 .53403 .45566 .52706 .46148 .32698 .45643 .52589 Mtetra
0 0 .284 r
.45643 .52589 .46148 .32698 .46329 .32113 .46228 .32212 Mtetra
.978 .912 .591 r
.46228 .32212 .46329 .32113 .46503 .31831 .46406 .31756 Mtetra
.772 .839 .903 r
.46406 .31756 .46503 .31831 .46673 .31739 .46576 .31646 Mtetra
.631 .768 .945 r
.46576 .31646 .46673 .31739 .46843 .31688 .46746 .31599 Mtetra
.525 .734 .97 r
.46746 .31599 .46843 .31688 .47012 .31658 .46915 .31581 Mtetra
.643 .809 .962 r
.46915 .31581 .47012 .31658 .47182 .316 .47085 .31526 Mtetra
.636 .813 .968 r
.47085 .31526 .47182 .316 .47352 .31546 .47255 .31473 Mtetra
.632 .817 .971 r
.47255 .31473 .47352 .31546 .47522 .31495 .47426 .31421 Mtetra
.637 .816 .969 r
.47426 .31421 .47522 .31495 .47692 .31453 .47596 .31368 Mtetra
.645 .789 .951 r
.47596 .31368 .47692 .31453 .47863 .31414 .47767 .31314 Mtetra
.651 .759 .928 r
.47767 .31314 .47863 .31414 .48033 .31372 .47937 .3126 Mtetra
.652 .733 .909 r
.47937 .3126 .48033 .31372 .48204 .31319 .48108 .31205 Mtetra
.657 .732 .905 r
.48108 .31205 .48204 .31319 .48374 .31259 .48279 .31148 Mtetra
.664 .741 .907 r
.48279 .31148 .48374 .31259 .48545 .31192 .4845 .31088 Mtetra
.692 .764 .907 r
.4845 .31088 .48545 .31192 .48717 .31091 .48621 .31016 Mtetra
.687 .827 .95 r
.48621 .31016 .48717 .31091 .48888 .31006 .48792 .30945 Mtetra
.657 .855 .975 r
.48792 .30945 .48888 .31006 .4906 .30953 .48964 .30882 Mtetra
.708 .839 .945 r
.48964 .30882 .4906 .30953 .4923 .31004 .49135 .30803 Mtetra
.614 .589 .802 r
.49135 .30803 .4923 .31004 .49399 .31157 .49307 .30762 Mtetra
.514 .419 .686 r
.49307 .30762 .49399 .31157 .49566 .31606 .49477 .30793 Mtetra
.153 .095 .533 r
.49477 .30793 .49566 .31606 .49562 .51652 .49644 .31328 Mtetra
0 0 .322 r
.49644 .31328 .49562 .51652 .49741 .52135 .49642 .51706 Mtetra
0 0 .506 r
.49642 .51706 .49741 .52135 .49923 .52313 .49821 .52151 Mtetra
.481 .586 .883 r
.49821 .52151 .49923 .52313 .50106 .52286 .50005 .52165 Mtetra
.67 .739 .902 r
.50005 .52165 .50106 .52286 .5029 .52204 .50189 .52098 Mtetra
.742 .786 .888 r
.50189 .52098 .5029 .52204 .50475 .52099 .50373 .51992 Mtetra
.633 .753 .934 r
.50373 .51992 .50475 .52099 .50659 .52075 .50558 .5194 Mtetra
.633 .701 .895 r
.50558 .5194 .50659 .52075 .50843 .52043 .50742 .5189 Mtetra
.645 .677 .866 r
.50742 .5189 .50843 .52043 .51028 .51979 .50927 .51833 Mtetra
.604 .67 .887 r
.50927 .51833 .51028 .51979 .51213 .51806 .51111 .51796 Mtetra
.544 .918 .939 r
.51111 .51796 .51213 .51806 .51398 .51525 .51296 .51723 Mtetra
.068 0 0 r
.51296 .51723 .51398 .51525 .51584 .50991 .51481 .51575 Mtetra
0 0 .156 r
.51481 .51575 .51584 .50991 .51812 .30892 .51668 .50967 Mtetra
0 0 .314 r
.51668 .50967 .51812 .30892 .51986 .30238 .51892 .30428 Mtetra
.925 .869 .439 r
.51892 .30428 .51986 .30238 .5216 .29947 .52066 .2985 Mtetra
.803 .802 .85 r
.52066 .2985 .5216 .29947 .52333 .29837 .52239 .29708 Mtetra
.645 .701 .887 r
.52239 .29708 .52333 .29837 .52507 .29784 .52413 .29655 Mtetra
.552 .663 .91 r
.52413 .29655 .52507 .29784 .5268 .29754 .52586 .29639 Mtetra
.662 .734 .903 r
.52586 .29639 .5268 .29754 .52854 .29677 .5276 .29579 Mtetra
.677 .774 .924 r
.5276 .29579 .52854 .29677 .53028 .29605 .52934 .29512 Mtetra
.665 .783 .937 r
.52934 .29512 .53028 .29605 .53202 .2956 .53108 .2945 Mtetra
.709 .761 .893 r
.53108 .2945 .53202 .2956 .53376 .29596 .53282 .29367 Mtetra
.627 .574 .775 r
.53282 .29367 .53376 .29596 .53551 .29727 .53456 .29313 Mtetra
.536 .429 .68 r
.53456 .29313 .53551 .29727 .53727 .30092 .53631 .29325 Mtetra
.257 .176 .57 r
.53631 .29325 .53727 .30092 .53992 .50077 .53807 .29735 Mtetra
0 0 .34 r
.53807 .29735 .53992 .50077 .54181 .50663 .5408 .50202 Mtetra
0 0 .461 r
.5408 .50202 .54181 .50663 .54369 .50875 .5427 .50738 Mtetra
.083 .396 .853 r
.5427 .50738 .54369 .50875 .54557 .50945 .54457 .5084 Mtetra
.573 .739 .955 r
.54457 .5084 .54557 .50945 .54744 .50925 .54645 .50808 Mtetra
.778 .78 .855 r
.54645 .50808 .54744 .50925 .54931 .50814 .54831 .50672 Mtetra
.913 .751 .667 r
.54831 .50672 .54931 .50814 .55115 .50381 .55016 .50212 Mtetra
.971 .688 .437 r
.55016 .50212 .55115 .50381 .5513 .29889 .55035 .29649 Mtetra
.917 .692 .583 r
.55035 .29649 .5513 .29889 .55297 .2891 .55204 .2879 Mtetra
.83 .77 .795 r
.55204 .2879 .55297 .2891 .55471 .28715 .55379 .28602 Mtetra
.669 .742 .905 r
.55379 .28602 .55471 .28715 .55647 .28651 .55554 .28538 Mtetra
.551 .697 .936 r
.55554 .28538 .55647 .28651 .55823 .28632 .5573 .28519 Mtetra
.72 .76 .884 r
.5573 .28519 .55823 .28632 .55998 .28541 .55905 .28428 Mtetra
.712 .758 .888 r
.55905 .28428 .55998 .28541 .56173 .28455 .56081 .28343 Mtetra
.564 .705 .936 r
.56081 .28343 .56173 .28455 .5635 .2843 .56257 .28319 Mtetra
.715 .255 0 r
.56257 .28319 .5635 .2843 .5653 .28719 .56438 .28609 Mtetra
.972 .681 .415 r
.56438 .28609 .5653 .28719 .56985 .49174 .56886 .4907 Mtetra
.932 .554 .19 r
.56886 .4907 .56985 .49174 .57184 .49937 .57086 .49829 Mtetra
0 .255 .746 r
.57086 .49829 .57184 .49937 .57376 .50069 .57277 .4996 Mtetra
.571 .732 .951 r
.57277 .4996 .57376 .50069 .57565 .50039 .57467 .4993 Mtetra
.785 .797 .862 r
.57467 .4993 .57565 .50039 .57753 .49901 .57655 .49791 Mtetra
.93 .783 .676 r
.57655 .49791 .57753 .49901 .57936 .49467 .57838 .49355 Mtetra
.973 .688 .426 r
.57838 .49355 .57936 .49467 .57777 .28943 .57685 .28817 Mtetra
.958 .735 .558 r
.57685 .28817 .57777 .28943 .57939 .28001 .57848 .27885 Mtetra
.849 .781 .785 r
.57848 .27885 .57939 .28001 .58114 .27791 .58022 .27676 Mtetra
.666 .741 .906 r
.58022 .27676 .58114 .27791 .58291 .27728 .58199 .27613 Mtetra
.542 .691 .936 r
.58199 .27613 .58291 .27728 .58469 .27711 .58377 .27597 Mtetra
.626 .728 .92 r
.58377 .27597 .58469 .27711 .58646 .27653 .58555 .2755 Mtetra
.673 .769 .922 r
.58555 .2755 .58646 .27653 .58823 .27579 .58732 .27484 Mtetra
.663 .782 .937 r
.58732 .27484 .58823 .27579 .59001 .2753 .5891 .27422 Mtetra
.702 .768 .903 r
.5891 .27422 .59001 .2753 .5918 .27548 .59087 .27342 Mtetra
.646 .606 .795 r
.59087 .27342 .5918 .27548 .59362 .27656 .59265 .27277 Mtetra
.554 .453 .695 r
.59265 .27277 .59362 .27656 .59548 .27943 .59444 .27272 Mtetra
.341 .249 .604 r
.59444 .27272 .59548 .27943 .60192 .47834 .5963 .27554 Mtetra
0 0 .365 r
.5963 .27554 .60192 .47834 .60403 .48653 .60293 .47995 Mtetra
0 0 .455 r
.60293 .47995 .60403 .48653 .60601 .489 .60503 .48731 Mtetra
.006 .286 .784 r
.60503 .48731 .60601 .489 .60796 .48978 .60699 .48883 Mtetra
.511 .737 .975 r
.60699 .48883 .60796 .48978 .60988 .48957 .60892 .48865 Mtetra
.769 .831 .9 r
.60892 .48865 .60988 .48957 .61178 .48846 .61082 .48743 Mtetra
.928 .8 .699 r
.61082 .48743 .61178 .48846 .61361 .48472 .61265 .48362 Mtetra
.975 .687 .413 r
.61265 .48362 .61361 .48472 .61 .28266 .6091 .28154 Mtetra
.972 .729 .51 r
.6091 .28154 .61 .28266 .61145 .2693 .61054 .26815 Mtetra
.877 .787 .758 r
.61054 .26815 .61145 .2693 .61318 .26679 .61228 .26564 Mtetra
.689 .751 .899 r
.61228 .26564 .61318 .26679 .61497 .26605 .61407 .2649 Mtetra
.567 .703 .933 r
.61407 .2649 .61497 .26605 .61677 .26579 .61587 .26464 Mtetra
.684 .751 .902 r
.61587 .26464 .61677 .26579 .61856 .26507 .61766 .26392 Mtetra
.726 .765 .884 r
.61766 .26392 .61856 .26507 .62035 .26412 .61945 .26297 Mtetra
.608 .723 .927 r
.61945 .26297 .62035 .26412 .62215 .26371 .62125 .26258 Mtetra
0 .042 .577 r
.62125 .26258 .62215 .26371 .62403 .26563 .62313 .26451 Mtetra
.974 .678 .39 r
.62313 .26451 .62403 .26563 .63239 .46558 .63145 .46483 Mtetra
.953 .603 .273 r
.63145 .46483 .63239 .46558 .63477 .47889 .63382 .47781 Mtetra
0 .154 .663 r
.63382 .47781 .63477 .47889 .63678 .48055 .63582 .47946 Mtetra
.609 .752 .946 r
.63582 .47946 .63678 .48055 .63871 .4801 .63776 .47901 Mtetra
.732 .793 .901 r
.63776 .47901 .63871 .4801 .64063 .47907 .63968 .47798 Mtetra
.639 .762 .937 r
.63968 .47798 .64063 .47907 .64257 .47851 .64162 .47741 Mtetra
.545 .721 .955 r
.64162 .47741 .64257 .47851 .64452 .47829 .64357 .47718 Mtetra
.696 .778 .915 r
.64357 .47718 .64452 .47829 .64645 .47747 .6455 .47635 Mtetra
.91 .801 .727 r
.6455 .47635 .64645 .47747 .64829 .47422 .64734 .47308 Mtetra
.976 .685 .4 r
.64734 .47308 .64829 .47422 .64278 .27779 .64184 .27558 Mtetra
.963 .7 .489 r
.64184 .27558 .64278 .27779 .64387 .25822 .64298 .25704 Mtetra
.892 .786 .737 r
.64298 .25704 .64387 .25822 .6456 .25538 .64471 .25421 Mtetra
.702 .754 .892 r
.64471 .25421 .6456 .25538 .6474 .25456 .64651 .25338 Mtetra
.586 .708 .927 r
.64651 .25338 .6474 .25456 .64923 .25424 .64834 .25307 Mtetra
.665 .741 .907 r
.64834 .25307 .64923 .25424 .65104 .2536 .65015 .25243 Mtetra
.733 .764 .878 r
.65015 .25243 .65104 .2536 .65284 .2526 .65195 .25142 Mtetra
.636 .73 .916 r
.65195 .25142 .65284 .2526 .65466 .25208 .65378 .25091 Mtetra
0 .283 .78 r
.65378 .25091 .65466 .25208 .65656 .25341 .65568 .25224 Mtetra
.938 .574 .185 r
.65568 .25224 .65656 .25341 .65884 .26325 .65795 .26207 Mtetra
.975 .675 .374 r
.65795 .26207 .65884 .26325 .66965 .46674 .66871 .46562 Mtetra
0 0 .513 r
.66871 .46562 .66965 .46674 .67173 .46901 .67079 .46789 Mtetra
.629 .756 .938 r
.67079 .46789 .67173 .46901 .67369 .46848 .67275 .46736 Mtetra
.769 .8 .879 r
.67275 .46736 .67369 .46848 .67562 .4672 .67468 .46608 Mtetra
.782 .803 .87 r
.67468 .46608 .67562 .4672 .67754 .46583 .6766 .4647 Mtetra
.729 .79 .901 r
.6766 .4647 .67754 .46583 .67948 .46481 .67854 .46368 Mtetra
.715 .785 .907 r
.67854 .46368 .67948 .46481 .68142 .46387 .68049 .46274 Mtetra
.655 .764 .93 r
.68049 .46274 .68142 .46387 .68338 .46322 .68245 .46209 Mtetra
.564 .726 .95 r
.68245 .46209 .68338 .46322 .68536 .46293 .68443 .4618 Mtetra
.535 .713 .954 r
.68443 .4618 .68536 .46293 .68735 .46273 .68641 .4616 Mtetra
.444 .667 .957 r
.68641 .4616 .68735 .46273 .68935 .4628 .68842 .46168 Mtetra
.415 .652 .956 r
.68842 .46168 .68935 .4628 .69135 .46295 .69042 .46182 Mtetra
.628 .755 .938 r
.69042 .46182 .69135 .46295 .69333 .46242 .6924 .46129 Mtetra
.89 .812 .765 r
.6924 .46129 .69333 .46242 .69519 .45973 .69426 .4586 Mtetra
.981 .723 .467 r
.69426 .4586 .69519 .45973 .69627 .4422 .69535 .44101 Mtetra
.977 .681 .379 r
.69535 .44101 .69627 .4422 .6877 .2433 .68683 .24212 Mtetra
.912 .79 .713 r
.68683 .24212 .6877 .2433 .6894 .24006 .68853 .23887 Mtetra
.708 .758 .891 r
.68853 .23887 .6894 .24006 .69123 .23919 .69036 .238 Mtetra
.587 .709 .927 r
.69036 .238 .69123 .23919 .69309 .23886 .69222 .23767 Mtetra
.623 .724 .919 r
.69222 .23767 .69309 .23886 .69494 .2384 .69408 .2372 Mtetra
.731 .765 .88 r
.69408 .2372 .69494 .2384 .69677 .23739 .6959 .2362 Mtetra
.64 .731 .915 r
.6959 .2362 .69677 .23739 .69862 .23685 .69775 .23566 Mtetra
.065 .399 .855 r
.69775 .23566 .69862 .23685 .70056 .23789 .6997 .23669 Mtetra
.924 .552 .138 r
.6997 .23669 .70056 .23789 .70299 .24731 .70212 .24606 Mtetra
.975 .671 .352 r
.70212 .24606 .70299 .24731 .71691 .45233 .71599 .45118 Mtetra
.598 .138 0 r
.71599 .45118 .71691 .45233 .71911 .45529 .71819 .45415 Mtetra
.42 .652 .955 r
.71819 .45415 .71911 .45529 .72114 .45544 .72023 .45429 Mtetra
.711 .784 .909 r
.72023 .45429 .72114 .45544 .72311 .45451 .7222 .45336 Mtetra
.888 .814 .77 r
.7222 .45336 .72311 .45451 .72498 .45188 .72407 .45072 Mtetra
.977 .756 .538 r
.72407 .45072 .72498 .45188 .72646 .44288 .72554 .44165 Mtetra
.977 .679 .365 r
.72554 .44165 .72646 .44288 .71552 .23491 .71466 .23368 Mtetra
.934 .783 .671 r
.71466 .23368 .71552 .23491 .71716 .23086 .71631 .22964 Mtetra
.719 .759 .883 r
.71631 .22964 .71716 .23086 .719 .22991 .71815 .22869 Mtetra
.582 .702 .925 r
.71815 .22869 .719 .22991 .72089 .2296 .72003 .22838 Mtetra
.544 .684 .93 r
.72003 .22838 .72089 .2296 .72278 .22943 .72192 .22821 Mtetra
.657 .735 .907 r
.72192 .22821 .72278 .22943 .72464 .22881 .72379 .22759 Mtetra
.662 .738 .906 r
.72379 .22759 .72464 .22881 .72651 .22816 .72565 .22694 Mtetra
.7 .753 .893 r
.72565 .22694 .72651 .22816 .72836 .22732 .72751 .22611 Mtetra
.755 .772 .867 r
.72751 .22611 .72836 .22732 .73019 .22615 .72934 .22494 Mtetra
.673 .744 .904 r
.72934 .22494 .73019 .22615 .73205 .22545 .7312 .22424 Mtetra
.243 .514 .909 r
.7312 .22424 .73205 .22545 .73401 .22611 .73316 .2249 Mtetra
.895 .509 .063 r
.73316 .2249 .73401 .22611 .73648 .23408 .73563 .23285 Mtetra
.975 .667 .334 r
.73563 .23285 .73648 .23408 .75284 .44073 .75194 .43958 Mtetra
.634 .18 0 r
.75194 .43958 .75284 .44073 .75513 .44407 .75423 .44292 Mtetra
.392 .636 .953 r
.75423 .44292 .75513 .44407 .7572 .4443 .7563 .44314 Mtetra
.694 .781 .917 r
.7563 .44314 .7572 .4443 .7592 .44344 .75831 .44229 Mtetra
.873 .82 .793 r
.75831 .44229 .7592 .44344 .7611 .44109 .7602 .43994 Mtetra
.978 .767 .553 r
.7602 .43994 .7611 .44109 .76258 .4332 .76169 .43204 Mtetra
.977 .675 .347 r
.76169 .43204 .76258 .4332 .74922 .2237 .74837 .22249 Mtetra
.951 .785 .641 r
.74837 .22249 .74922 .2237 .7508 .21904 .74996 .21783 Mtetra
.747 .773 .874 r
.74996 .21783 .7508 .21904 .75265 .21792 .75181 .21671 Mtetra
.621 .724 .92 r
.75181 .21671 .75265 .21792 .75454 .21745 .7537 .21624 Mtetra
.59 .71 .926 r
.7537 .21624 .75454 .21745 .75645 .2171 .75561 .21589 Mtetra
.75 .774 .873 r
.75561 .21589 .75645 .2171 .7583 .21597 .75746 .21475 Mtetra
.676 .747 .905 r
.75746 .21475 .7583 .21597 .76018 .21525 .75934 .21404 Mtetra
.376 .596 .932 r
.75934 .21404 .76018 .21525 .76214 .21558 .7613 .21437 Mtetra
.809 .396 0 r
.7613 .21437 .76214 .21558 .76451 .22105 .76368 .21986 Mtetra
.973 .663 .319 r
.76368 .21986 .76451 .22105 .78303 .42979 .78214 .42865 Mtetra
.717 .274 0 r
.78214 .42865 .78303 .42979 .78544 .43399 .78456 .43284 Mtetra
.503 .697 .956 r
.78456 .43284 .78544 .43399 .78752 .43389 .78664 .43273 Mtetra
.695 .783 .919 r
.78664 .43273 .78752 .43389 .78954 .43303 .78866 .43187 Mtetra
.735 .797 .901 r
.78866 .43187 .78954 .43303 .79154 .43194 .79066 .43078 Mtetra
.497 .693 .956 r
.79066 .43078 .79154 .43194 .79363 .43187 .79275 .4307 Mtetra
.625 .755 .94 r
.79275 .4307 .79363 .43187 .79568 .43132 .7948 .43016 Mtetra
.812 .816 .854 r
.7948 .43016 .79568 .43132 .79763 .42968 .79676 .42852 Mtetra
.98 .772 .552 r
.79676 .42852 .79763 .42968 .79909 .42209 .79822 .42093 Mtetra
.976 .671 .329 r
.79822 .42093 .79909 .42209 .7833 .2121 .78248 .21088 Mtetra
.959 .785 .623 r
.78248 .21088 .7833 .2121 .78484 .20709 .78401 .20587 Mtetra
.751 .775 .872 r
.78401 .20587 .78484 .20709 .7867 .20594 .78587 .20472 Mtetra
.622 .724 .919 r
.78587 .20472 .7867 .20594 .78862 .20546 .78779 .20423 Mtetra
.552 .69 .931 r
.78779 .20423 .78862 .20546 .79056 .20525 .78974 .20402 Mtetra
.746 .773 .875 r
.78974 .20402 .79056 .20525 .79243 .20413 .79161 .2029 Mtetra
.677 .747 .904 r
.79161 .2029 .79243 .20413 .79433 .2034 .79351 .20217 Mtetra
.456 .639 .935 r
.79351 .20217 .79433 .2034 .79631 .20351 .79549 .20228 Mtetra
.768 .353 0 r
.79549 .20228 .79631 .20351 .79875 .20871 .79793 .20748 Mtetra
.971 .657 .298 r
.79793 .20748 .79875 .20871 .8198 .41826 .81893 .41708 Mtetra
.726 .292 0 r
.81893 .41708 .8198 .41826 .82234 .42291 .82147 .42173 Mtetra
.306 .58 .938 r
.82147 .42173 .82234 .42291 .8245 .42339 .82364 .42221 Mtetra
.649 .764 .933 r
.82364 .42221 .8245 .42339 .82657 .42274 .8257 .42156 Mtetra
.829 .821 .84 r
.8257 .42156 .82657 .42274 .82852 .42093 .82766 .41974 Mtetra
.975 .789 .59 r
.82766 .41974 .82852 .42093 .83007 .41481 .82921 .41363 Mtetra
.974 .667 .312 r
.82921 .41363 .83007 .41481 .81218 .2039 .81136 .20265 Mtetra
.974 .774 .572 r
.81136 .20265 .81218 .2039 .81356 .19756 .81275 .19632 Mtetra
.76 .757 .85 r
.19502 .4107 .19608 .41169 .19767 .41061 .19661 .40962 Mtetra
.612 .727 .927 r
.19661 .40962 .19767 .41061 .19919 .41026 .19813 .40927 Mtetra
.455 .668 .954 r
.19813 .40927 .19919 .41026 .20067 .4103 .1996 .4093 Mtetra
.654 .738 .912 r
.1996 .4093 .20067 .4103 .2022 .4098 .20114 .4088 Mtetra
.663 .741 .908 r
.20114 .4088 .2022 .4098 .20374 .40926 .20268 .40827 Mtetra
.669 .742 .905 r
.20268 .40827 .20374 .40926 .20528 .4087 .20422 .4077 Mtetra
.763 .758 .848 r
.20422 .4077 .20528 .4087 .20688 .4076 .20582 .4066 Mtetra
.709 .751 .885 r
.20582 .4066 .20688 .4076 .20844 .40685 .20738 .40585 Mtetra
.494 .684 .951 r
.20738 .40585 .20844 .40685 .20994 .4068 .20888 .40581 Mtetra
.932 .563 .28 r
.20888 .40581 .20994 .4068 .211 .41124 .20994 .41024 Mtetra
.939 .683 .523 r
.20994 .41024 .211 .41124 .19321 .61086 .19207 .60991 Mtetra
.932 .569 .305 r
.19207 .60991 .19321 .61086 .19432 .61585 .19318 .61491 Mtetra
0 .388 .826 r
.19318 .61491 .19432 .61585 .19584 .61658 .1947 .61564 Mtetra
.627 .757 .94 r
.1947 .61564 .19584 .61658 .19747 .61614 .19633 .6152 Mtetra
.802 .78 .832 r
.19633 .6152 .19747 .61614 .19921 .61465 .19807 .6137 Mtetra
.906 .742 .668 r
.19807 .6137 .19921 .61465 .20129 .60956 .20015 .6086 Mtetra
.939 .687 .53 r
.20015 .6086 .20129 .60956 .2217 .40897 .22064 .40794 Mtetra
.913 .724 .633 r
.22064 .40794 .2217 .40897 .22384 .40219 .22278 .40118 Mtetra
.794 .759 .821 r
.22278 .40118 .22384 .40219 .22547 .40078 .22441 .39977 Mtetra
.644 .736 .916 r
.22441 .39977 .22547 .40078 .22701 .40031 .22596 .39931 Mtetra
.502 .687 .95 r
.22596 .39931 .22701 .40031 .22852 .40025 .22747 .39925 Mtetra
.717 .753 .881 r
.22747 .39925 .22852 .40025 .23011 .39935 .22905 .39845 Mtetra
.695 .769 .908 r
.22905 .39845 .23011 .39935 .23168 .39865 .23062 .39777 Mtetra
.541 .731 .962 r
.23062 .39777 .23168 .39865 .23319 .39862 .23214 .39759 Mtetra
.774 .292 0 r
.23214 .39759 .23319 .39862 .23434 .40257 .23346 .39967 Mtetra
.977 .678 .362 r
.23346 .39967 .23434 .40257 .21793 .60261 .23403 .41015 Mtetra
0 0 .157 r
.23403 .41015 .21793 .60261 .21905 .60802 .21831 .60276 Mtetra
.307 .241 .618 r
.21831 .60276 .21905 .60802 .22062 .60844 .21973 .60483 Mtetra
.474 .408 .702 r
.21973 .60483 .22062 .60844 .2223 .60773 .22129 .60537 Mtetra
.555 .529 .781 r
.22129 .60537 .2223 .60773 .22402 .60655 .22291 .6053 Mtetra
.631 .701 .896 r
.22291 .6053 .22402 .60655 .2257 .60574 .22457 .60486 Mtetra
.684 .785 .927 r
.22457 .60486 .2257 .60574 .22738 .60507 .22624 .60419 Mtetra
.708 .79 .916 r
.22624 .60419 .22738 .60507 .22905 .60444 .22793 .60341 Mtetra
.67 .754 .913 r
.22793 .60341 .22905 .60444 .23071 .60391 .2296 .6028 Mtetra
.647 .731 .91 r
.2296 .6028 .23071 .60391 .23237 .60345 .23126 .60229 Mtetra
.63 .715 .908 r
.23126 .60229 .23237 .60345 .23403 .60303 .23292 .60184 Mtetra
.595 .699 .916 r
.23292 .60184 .23403 .60303 .23568 .60268 .23457 .60153 Mtetra
.578 .701 .926 r
.23457 .60153 .23568 .60268 .23733 .60231 .23621 .60127 Mtetra
.575 .723 .943 r
.23621 .60127 .23733 .60231 .23899 .60186 .23786 .601 Mtetra
.451 .716 .981 r
.23786 .601 .23899 .60186 .24065 .60154 .23949 .60097 Mtetra
.497 .803 .999 r
.23949 .60097 .24065 .60154 .24232 .60093 .24114 .60072 Mtetra
.673 .929 .971 r
.24114 .60072 .24232 .60093 .24406 .5996 .24284 .59992 Mtetra
.95 .912 .745 r
.24284 .59992 .24406 .5996 .24612 .59436 .24472 .59681 Mtetra
.998 .845 .55 r
.24472 .59681 .24612 .59436 .26404 .39351 .2471 .58767 Mtetra
0 0 .158 r
.2471 .58767 .26404 .39351 .26606 .38744 .2647 .39044 Mtetra
0 0 .019 r
.2647 .39044 .26606 .38744 .26773 .38575 .26642 .38809 Mtetra
.383 .01 .202 r
.26642 .38809 .26773 .38575 .26931 .38518 .26799 .38763 Mtetra
.458 .091 .253 r
.26799 .38763 .26931 .38518 .27086 .38502 .26954 .38751 Mtetra
.078 0 .052 r
.26954 .38751 .27086 .38502 .27242 .38464 .2712 .38595 Mtetra
.563 .843 .504 r
.2712 .38595 .27242 .38464 .274 .38413 .27289 .38405 Mtetra
.858 .941 .874 r
.27289 .38405 .274 .38413 .27558 .38361 .27455 .3825 Mtetra
.717 .737 .866 r
.27455 .3825 .27558 .38361 .27717 .38301 .27616 .38166 Mtetra
.64 .674 .867 r
.27616 .38166 .27717 .38301 .27876 .38238 .27773 .38119 Mtetra
.615 .692 .899 r
.27773 .38119 .27876 .38238 .28034 .38182 .2793 .38083 Mtetra
.718 .761 .886 r
.2793 .38083 .28034 .38182 .28193 .38116 .28091 .38001 Mtetra
.716 .732 .863 r
.28091 .38001 .28193 .38116 .28351 .38071 .28252 .37917 Mtetra
.624 .64 .847 r
.28252 .37917 .28351 .38071 .28505 .38086 .28409 .37877 Mtetra
0 .201 .716 r
.28409 .37877 .28505 .38086 .28635 .38409 .28553 .38028 Mtetra
.843 .562 .021 r
.28553 .38028 .28635 .38409 .27313 .58405 .28659 .38682 Mtetra
0 0 .194 r
.28659 .38682 .27313 .58405 .27432 .5903 .27354 .58475 Mtetra
.34 .261 .619 r
.27354 .58475 .27432 .5903 .27589 .59142 .27505 .58676 Mtetra
.584 .451 .665 r
.27505 .58676 .27589 .59142 .27757 .59108 .27673 .58633 Mtetra
.61 .466 .661 r
.27673 .58633 .27757 .59108 .27928 .59024 .27845 .58553 Mtetra
.431 .345 .657 r
.27845 .58553 .27928 .59024 .28098 .58965 .28003 .5866 Mtetra
.305 .33 .722 r
.28003 .5866 .28098 .58965 .28269 .58903 .2816 .58784 Mtetra
.398 .616 .939 r
.2816 .58784 .28269 .58903 .28444 .58777 .28324 .58805 Mtetra
.938 .935 .77 r
.28324 .58805 .28444 .58777 .28639 .58359 .2851 .58532 Mtetra
.986 .783 .547 r
.2851 .58532 .28639 .58359 .30202 .38264 .28769 .57207 Mtetra
0 0 .168 r
.28769 .57207 .30202 .38264 .30414 .37461 .30307 .37427 Mtetra
.923 .836 .741 r
.30307 .37427 .30414 .37461 .30586 .37236 .30484 .37128 Mtetra
.747 .752 .856 r
.30484 .37128 .30586 .37236 .30747 .37172 .30647 .37026 Mtetra
.567 .628 .872 r
.30647 .37026 .30747 .37172 .30901 .37206 .30805 .37009 Mtetra
.019 .233 .739 r
.30805 .37009 .30901 .37206 .31038 .37487 .30952 .37149 Mtetra
.765 .48 0 r
.30952 .37149 .31038 .37487 .29868 .57414 .31073 .37684 Mtetra
0 0 .208 r
.31073 .37684 .29868 .57414 .29983 .58193 .29907 .57589 Mtetra
.278 .208 .596 r
.29907 .57589 .29983 .58193 .30141 .58335 .30056 .57858 Mtetra
.584 .449 .662 r
.30056 .57858 .30141 .58335 .30311 .58305 .30227 .57813 Mtetra
.617 .468 .657 r
.30227 .57813 .30311 .58305 .30484 .5822 .304 .5772 Mtetra
.527 .405 .656 r
.304 .5772 .30484 .5822 .30658 .58123 .30566 .57743 Mtetra
.414 .363 .692 r
.30566 .57743 .30658 .58123 .30832 .58028 .30728 .57841 Mtetra
.326 .458 .841 r
.30728 .57841 .30832 .58028 .31006 .57929 .30892 .57909 Mtetra
.059 .615 .813 r
.30892 .57909 .31006 .57929 .3118 .57844 .31059 .57917 Mtetra
.108 0 0 r
.31059 .57917 .3118 .57844 .31352 .57779 .3123 .57879 Mtetra
.109 0 0 r
.3123 .57879 .31352 .57779 .31523 .57729 .31402 .57824 Mtetra
.033 0 0 r
.31402 .57824 .31523 .57729 .31694 .577 .31575 .57759 Mtetra
0 0 0 r
.31575 .57759 .31694 .577 .31863 .57684 .31748 .5769 Mtetra
.531 .918 .915 r
.31748 .5769 .31863 .57684 .32033 .57666 .31921 .57618 Mtetra
.653 .876 .981 r
.31921 .57618 .32033 .57666 .32204 .5763 .32094 .57552 Mtetra
.652 .809 .959 r
.32094 .57552 .32204 .5763 .32377 .57575 .32267 .57494 Mtetra
.646 .8 .957 r
.32267 .57494 .32377 .57575 .3255 .57514 .32439 .57438 Mtetra
.64 .811 .965 r
.32439 .57438 .3255 .57514 .32722 .57455 .32612 .57384 Mtetra
.635 .82 .972 r
.32612 .57384 .32722 .57455 .32895 .574 .32785 .5733 Mtetra
.632 .823 .974 r
.32785 .5733 .32895 .574 .33068 .57345 .32957 .57276 Mtetra
.602 .817 .982 r
.32957 .57276 .33068 .57345 .33241 .57292 .3313 .57231 Mtetra
.579 .828 .992 r
.3313 .57231 .33241 .57292 .33414 .5724 .33302 .57188 Mtetra
.629 .865 .987 r
.33302 .57188 .33414 .5724 .33587 .57187 .33476 .57129 Mtetra
.774 .87 .919 r
.33476 .57129 .33587 .57187 .3376 .57133 .33652 .57017 Mtetra
.818 .761 .799 r
.33652 .57017 .3376 .57133 .33933 .57078 .33833 .56832 Mtetra
.766 .634 .715 r
.33833 .56832 .33933 .57078 .34107 .57022 .34015 .56609 Mtetra
.684 .529 .67 r
.34015 .56609 .34107 .57022 .3428 .5697 .34196 .56428 Mtetra
.592 .443 .648 r
.34196 .56428 .3428 .5697 .34453 .56921 .3437 .56364 Mtetra
.565 .421 .645 r
.3437 .56364 .34453 .56921 .34627 .56872 .34542 .56339 Mtetra
.54 .408 .65 r
.34542 .56339 .34627 .56872 .34799 .56843 .34712 .56347 Mtetra
.544 .418 .659 r
.34712 .56347 .34799 .56843 .34972 .56824 .34883 .56351 Mtetra
.61 .468 .663 r
.34883 .56351 .34972 .56824 .35147 .56753 .35058 .56271 Mtetra
.76 .566 .635 r
.35058 .56271 .35147 .56753 .35331 .565 .35251 .55844 Mtetra
.948 .683 .5 r
.35251 .55844 .35331 .565 .35554 .55461 .36438 .35737 Mtetra
.548 .324 .528 r
.36438 .35737 .35554 .55461 .36718 .35462 .36629 .35139 Mtetra
.74 .582 .678 r
.36629 .35139 .36718 .35462 .36896 .35124 .36801 .34904 Mtetra
.662 .592 .766 r
.36801 .34904 .36896 .35124 .37061 .35041 .36966 .34826 Mtetra
.609 .569 .784 r
.36966 .34826 .37061 .35041 .37224 .3501 .3713 .34788 Mtetra
.609 .563 .777 r
.3713 .34788 .37224 .3501 .37387 .34969 .37293 .34748 Mtetra
.644 .583 .771 r
.37293 .34748 .37387 .34969 .37553 .34879 .37457 .34685 Mtetra
.632 .6 .799 r
.37457 .34685 .37553 .34879 .37719 .34791 .37621 .34634 Mtetra
.56 .612 .861 r
.37621 .34634 .37719 .34791 .37884 .34715 .37784 .34621 Mtetra
.184 .541 .927 r
.37784 .34621 .37884 .34715 .38049 .34657 .37944 .34668 Mtetra
.536 0 0 r
.37944 .34668 .38049 .34657 .38213 .34604 .38102 .34746 Mtetra
.506 .071 .147 r
.38102 .34746 .38213 .34604 .38378 .34535 .38263 .34778 Mtetra
.29 0 .164 r
.38263 .34778 .38378 .34535 .38545 .34447 .3843 .34687 Mtetra
.377 .008 .205 r
.3843 .34687 .38545 .34447 .38709 .344 .38595 .34634 Mtetra
.679 .315 .349 r
.38595 .34634 .38709 .344 .38868 .34486 .3875 .34814 Mtetra
.952 .679 .482 r
.3875 .34814 .38868 .34486 .39005 .35099 .38057 .54787 Mtetra
.547 .319 .521 r
.38057 .54787 .39005 .35099 .38321 .55284 .38202 .55474 Mtetra
.694 .308 .311 r
.38202 .55474 .38321 .55284 .3848 .55619 .38368 .55662 Mtetra
.147 0 0 r
.38368 .55662 .3848 .55619 .38655 .55605 .38543 .5565 Mtetra
0 0 0 r
.38543 .5565 .38655 .55605 .38833 .55526 .3872 .55589 Mtetra
.3872 .55589 .38833 .55526 .3901 .55448 .38897 .55516 Mtetra
.38897 .55516 .3901 .55448 .39185 .55434 .39074 .55462 Mtetra
.367 .832 .772 r
.39074 .55462 .39185 .55434 .39361 .55417 .39251 .55391 Mtetra
.708 .939 .96 r
.39251 .55391 .39361 .55417 .39536 .554 .3943 .55296 Mtetra
.779 .786 .859 r
.3943 .55296 .39536 .554 .39712 .55384 .3961 .55166 Mtetra
.767 .653 .737 r
.3961 .55166 .39712 .55384 .39889 .55318 .39793 .54967 Mtetra
.798 .614 .652 r
.39793 .54967 .39889 .55318 .40072 .55118 .39983 .54552 Mtetra
.954 .684 .487 r
.39983 .54552 .40072 .55118 .40274 .54399 .40896 .34399 Mtetra
.551 .327 .528 r
.40896 .34399 .40274 .54399 .41176 .34057 .41088 .3365 Mtetra
.73 .555 .654 r
.41088 .3365 .41176 .34057 .41357 .33606 .41263 .33375 Mtetra
.668 .589 .757 r
.41263 .33375 .41357 .33606 .41525 .3351 .4143 .33288 Mtetra
.61 .565 .779 r
.4143 .33288 .41525 .3351 .41691 .33476 .41597 .33248 Mtetra
.582 .545 .779 r
.41597 .33248 .41691 .33476 .41857 .33449 .41762 .33225 Mtetra
.612 .565 .777 r
.41762 .33225 .41857 .33449 .42025 .33358 .41929 .33183 Mtetra
.621 .618 .826 r
.41929 .33183 .42025 .33358 .42193 .33268 .42096 .3314 Mtetra
.642 .696 .885 r
.42096 .3314 .42193 .33268 .42361 .3319 .42263 .33091 Mtetra
.683 .765 .914 r
.42263 .33091 .42361 .3319 .42528 .33133 .4243 .33024 Mtetra
.689 .746 .895 r
.4243 .33024 .42528 .33133 .42695 .33082 .42598 .32953 Mtetra
.686 .71 .866 r
.42598 .32953 .42695 .33082 .42863 .33031 .42766 .32881 Mtetra
.681 .676 .839 r
.42766 .32881 .42863 .33031 .4303 .32972 .42934 .32807 Mtetra
.655 .646 .829 r
.42934 .32807 .4303 .32972 .43198 .32911 .43102 .32747 Mtetra
.598 .621 .846 r
.43102 .32747 .43198 .32911 .43366 .32849 .43269 .32717 Mtetra
.341 .545 .906 r
.43269 .32717 .43366 .32849 .43534 .32786 .43434 .32759 Mtetra
.399 0 0 r
.43434 .32759 .43534 .32786 .43702 .32723 .43598 .32836 Mtetra
.59 .136 .142 r
.43598 .32836 .43702 .32723 .43871 .3266 .43763 .32916 Mtetra
.417 .054 .239 r
.43763 .32916 .43871 .3266 .44039 .32595 .43931 .32877 Mtetra
.36 .013 .235 r
.43931 .32877 .44039 .32595 .44207 .32531 .441 .32799 Mtetra
.303 0 .197 r
.441 .32799 .44207 .32531 .44376 .32463 .4427 .32699 Mtetra
.207 0 .122 r
.4427 .32699 .44376 .32463 .44546 .32364 .4444 .32576 Mtetra
.334 0 .153 r
.4444 .32576 .44546 .32364 .44714 .32304 .44609 .32514 Mtetra
.597 .21 .28 r
.44609 .32514 .44714 .32304 .44881 .32335 .44774 .32602 Mtetra
.959 .679 .463 r
.44774 .32602 .44881 .32335 .45037 .32798 .44468 .52373 Mtetra
.553 .324 .521 r
.44468 .52373 .45037 .32798 .44735 .53143 .44623 .53398 Mtetra
.715 .351 .358 r
.44623 .53398 .44735 .53143 .44903 .53627 .44796 .53655 Mtetra
.27 0 0 r
.44796 .53655 .44903 .53627 .45081 .53678 .44975 .53674 Mtetra
.492 .898 .922 r
.44975 .53674 .45081 .53678 .45262 .53611 .45156 .53609 Mtetra
.832 .982 .878 r
.45156 .53609 .45262 .53611 .45446 .53403 .4534 .53447 Mtetra
.982 .896 .652 r
.4534 .53447 .45446 .53403 .45643 .52589 .45529 .53003 Mtetra
.97 .697 .46 r
.45529 .53003 .45643 .52589 .46228 .32212 .46108 .3324 Mtetra
0 0 .116 r
.46108 .3324 .46228 .32212 .46406 .31756 .46302 .31984 Mtetra
.152 0 .087 r
.46302 .31984 .46406 .31756 .46576 .31646 .46474 .31846 Mtetra
.377 0 .158 r
.46474 .31846 .46576 .31646 .46746 .31599 .46644 .31806 Mtetra
.484 .092 .221 r
.46644 .31806 .46746 .31599 .46915 .31581 .46813 .31817 Mtetra
.433 .059 .227 r
.46813 .31817 .46915 .31581 .47085 .31526 .46982 .31793 Mtetra
.415 .057 .246 r
.46982 .31793 .47085 .31526 .47255 .31473 .47153 .3175 Mtetra
.334 0 .22 r
.47153 .3175 .47255 .31473 .47426 .31421 .47324 .31659 Mtetra
0 0 .007 r
.47324 .31659 .47426 .31421 .47596 .31368 .47497 .31448 Mtetra
.672 .927 .626 r
.47497 .31448 .47596 .31368 .47767 .31314 .4767 .3126 Mtetra
.836 .885 .878 r
.4767 .3126 .47767 .31314 .47937 .3126 .47842 .31112 Mtetra
.66 .675 .853 r
.47842 .31112 .47937 .3126 .48108 .31205 .48013 .3105 Mtetra
.619 .648 .856 r
.48013 .3105 .48108 .31205 .48279 .31148 .48183 .31009 Mtetra
.601 .664 .883 r
.48183 .31009 .48279 .31148 .4845 .31088 .48354 .30976 Mtetra
.658 .737 .908 r
.48354 .30976 .4845 .31088 .48621 .31016 .48525 .30919 Mtetra
.671 .772 .926 r
.48525 .30919 .48621 .31016 .48792 .30945 .48696 .30856 Mtetra
.683 .792 .932 r
.48696 .30856 .48792 .30945 .48964 .30882 .48868 .30787 Mtetra
.768 .8 .879 r
.48868 .30787 .48964 .30882 .49135 .30803 .4904 .30674 Mtetra
.707 .722 .861 r
.4904 .30674 .49135 .30803 .49307 .30762 .49212 .30588 Mtetra
.599 .613 .838 r
.49212 .30588 .49307 .30762 .49477 .30793 .49383 .30557 Mtetra
0 .124 .661 r
.49383 .30557 .49477 .30793 .49644 .31328 .49553 .30775 Mtetra
.713 .487 0 r
.49553 .30775 .49644 .31328 .49642 .51706 .49715 .31782 Mtetra
0 0 .324 r
.49715 .31782 .49642 .51706 .49821 .52151 .49723 .51634 Mtetra
.336 .275 .64 r
.49723 .51634 .49821 .52151 .50005 .52165 .49905 .51845 Mtetra
.448 .419 .734 r
.49905 .51845 .50005 .52165 .50189 .52098 .50088 .51913 Mtetra
.523 .577 .851 r
.50088 .51913 .50189 .52098 .50373 .51992 .50272 .51916 Mtetra
.601 .814 .981 r
.50272 .51916 .50373 .51992 .50558 .5194 .50456 .51868 Mtetra
.672 .844 .966 r
.50456 .51868 .50558 .5194 .50742 .5189 .50641 .51796 Mtetra
.698 .803 .931 r
.50641 .51796 .50742 .5189 .50927 .51833 .50825 .51716 Mtetra
.453 .658 .949 r
.50825 .51716 .50927 .51833 .51111 .51796 .5101 .51723 Mtetra
.499 .781 .995 r
.5101 .51723 .51111 .51796 .51296 .51723 .51195 .517 Mtetra
.695 .95 .956 r
.51195 .517 .51296 .51723 .51481 .51575 .5138 .51601 Mtetra
.989 .863 .621 r
.5138 .51601 .51481 .51575 .51668 .50967 .51566 .51072 Mtetra
.971 .692 .444 r
.51566 .51072 .51668 .50967 .51892 .30428 .51797 .30385 Mtetra
.972 .784 .593 r
.51797 .30385 .51892 .30428 .52066 .2985 .51972 .29702 Mtetra
.767 .715 .804 r
.51972 .29702 .52066 .2985 .52239 .29708 .52145 .2956 Mtetra
.619 .661 .869 r
.52145 .2956 .52239 .29708 .52413 .29655 .52319 .29519 Mtetra
.503 .628 .906 r
.52319 .29519 .52413 .29655 .52586 .29639 .52492 .29521 Mtetra
.635 .719 .908 r
.52492 .29521 .52586 .29639 .5276 .29579 .52666 .29472 Mtetra
.668 .755 .915 r
.52666 .29472 .5276 .29579 .52934 .29512 .5284 .29409 Mtetra
.681 .767 .916 r
.5284 .29409 .52934 .29512 .53108 .2945 .53014 .29341 Mtetra
.771 .777 .858 r
.53014 .29341 .53108 .2945 .53282 .29367 .53188 .29219 Mtetra
.715 .699 .833 r
.53188 .29219 .53282 .29367 .53456 .29313 .53362 .29122 Mtetra
.597 .594 .819 r
.53362 .29122 .53456 .29313 .53631 .29325 .53536 .2909 Mtetra
0 0 .512 r
.53536 .2909 .53631 .29325 .53807 .29735 .53712 .29399 Mtetra
.973 .685 .421 r
.53712 .29399 .53807 .29735 .5408 .50202 .53979 .49879 Mtetra
.796 .48 0 r
.53979 .49879 .5408 .50202 .5427 .50738 .5417 .50621 Mtetra
0 .328 .807 r
.5417 .50621 .5427 .50738 .54457 .5084 .54358 .50736 Mtetra
.584 .745 .953 r
.54358 .50736 .54457 .5084 .54645 .50808 .54545 .507 Mtetra
.793 .797 .855 r
.54545 .507 .54645 .50808 .54831 .50672 .54732 .50555 Mtetra
.928 .77 .664 r
.54732 .50555 .54831 .50672 .55016 .50212 .54916 .50085 Mtetra
.971 .689 .436 r
.54916 .50085 .55016 .50212 .55035 .29649 .54942 .29501 Mtetra
.945 .728 .579 r
.54942 .29501 .55035 .29649 .55204 .2879 .55111 .28674 Mtetra
.831 .776 .8 r
.55111 .28674 .55204 .2879 .55379 .28602 .55286 .28488 Mtetra
.667 .741 .905 r
.55286 .28488 .55379 .28602 .55554 .28538 .55461 .28424 Mtetra
.552 .696 .935 r
.55461 .28424 .55554 .28538 .5573 .28519 .55637 .28405 Mtetra
.72 .759 .884 r
.55637 .28405 .5573 .28519 .55905 .28428 .55813 .28315 Mtetra
.712 .757 .888 r
.55813 .28315 .55905 .28428 .56081 .28343 .55988 .28229 Mtetra
.564 .703 .934 r
.55988 .28229 .56081 .28343 .56257 .28319 .56165 .28206 Mtetra
.713 .253 0 r
.56165 .28206 .56257 .28319 .56438 .28609 .56345 .28496 Mtetra
.972 .681 .415 r
.56345 .28496 .56438 .28609 .56886 .4907 .56788 .48961 Mtetra
.932 .554 .186 r
.56788 .48961 .56886 .4907 .57086 .49829 .56987 .4972 Mtetra
0 .254 .746 r
.56987 .4972 .57086 .49829 .57277 .4996 .57179 .49852 Mtetra
.571 .732 .951 r
.57179 .49852 .57277 .4996 .57467 .4993 .57368 .49821 Mtetra
.788 .799 .861 r
.57368 .49821 .57467 .4993 .57655 .49791 .57556 .4968 Mtetra
.933 .78 .667 r
.57556 .4968 .57655 .49791 .57838 .49355 .57739 .49221 Mtetra
.973 .688 .426 r
.57739 .49221 .57838 .49355 .57685 .28817 .5759 .28552 Mtetra
.909 .684 .585 r
.5759 .28552 .57685 .28817 .57848 .27885 .57755 .27728 Mtetra
.809 .722 .769 r
.57755 .27728 .57848 .27885 .58022 .27676 .5793 .27533 Mtetra
.64 .68 .872 r
.5793 .27533 .58022 .27676 .58199 .27613 .58107 .27481 Mtetra
.519 .644 .912 r
.58107 .27481 .58199 .27613 .58377 .27597 .58285 .27476 Mtetra
.599 .705 .917 r
.58285 .27476 .58377 .27597 .58555 .2755 .58463 .27441 Mtetra
.662 .751 .916 r
.58463 .27441 .58555 .2755 .58732 .27484 .58641 .2738 Mtetra
.676 .766 .919 r
.58641 .2738 .58732 .27484 .5891 .27422 .58819 .27312 Mtetra
.758 .779 .871 r
.58819 .27312 .5891 .27422 .59087 .27342 .58995 .27199 Mtetra
.731 .716 .837 r
.58995 .27199 .59087 .27342 .59265 .27277 .59172 .27092 Mtetra
.625 .616 .822 r
.59172 .27092 .59265 .27277 .59444 .27272 .59351 .27043 Mtetra
0 .176 .695 r
.59351 .27043 .59444 .27272 .5963 .27554 .59535 .27254 Mtetra
.975 .682 .398 r
.59535 .27254 .5963 .27554 .60293 .47995 .60185 .47379 Mtetra
0 0 .141 r
.60185 .47379 .60293 .47995 .60503 .48731 .60406 .48601 Mtetra
0 .139 .67 r
.60406 .48601 .60503 .48731 .60699 .48883 .60603 .4878 Mtetra
.518 .724 .967 r
.60603 .4878 .60699 .48883 .60892 .48865 .60795 .48763 Mtetra
.772 .813 .886 r
.60795 .48763 .60892 .48865 .61082 .48743 .60985 .48637 Mtetra
.926 .797 .698 r
.60985 .48637 .61082 .48743 .61265 .48362 .61168 .48254 Mtetra
.975 .687 .413 r
.61168 .48254 .61265 .48362 .6091 .28154 .60819 .28052 Mtetra
.973 .73 .508 r
.60819 .28052 .6091 .28154 .61054 .26815 .60964 .267 Mtetra
.877 .788 .758 r
.60964 .267 .61054 .26815 .61228 .26564 .61138 .26449 Mtetra
.688 .752 .9 r
.61138 .26449 .61228 .26564 .61407 .2649 .61317 .26375 Mtetra
.566 .703 .934 r
.61317 .26375 .61407 .2649 .61587 .26464 .61497 .2635 Mtetra
.684 .752 .903 r
.61497 .2635 .61587 .26464 .61766 .26392 .61676 .26278 Mtetra
.726 .765 .884 r
.61676 .26278 .61766 .26392 .61945 .26297 .61855 .26183 Mtetra
.603 .72 .927 r
.61855 .26183 .61945 .26297 .62125 .26258 .62035 .26144 Mtetra
0 0 .526 r
.62035 .26144 .62125 .26258 .62313 .26451 .62224 .26353 Mtetra
.974 .678 .39 r
.62224 .26353 .62313 .26451 .63145 .46483 .63059 .46677 Mtetra
.903 .55 .363 r
.63059 .46677 .63145 .46483 .63382 .47781 .63288 .47722 Mtetra
.469 0 0 r
.63288 .47722 .63382 .47781 .63582 .47946 .63488 .47871 Mtetra
.62 .832 .981 r
.63488 .47871 .63582 .47946 .63776 .47901 .63681 .47813 Mtetra
.76 .843 .914 r
.63681 .47813 .63776 .47901 .63968 .47798 .63873 .47697 Mtetra
.658 .787 .943 r
.63873 .47697 .63968 .47798 .64162 .47741 .64066 .47631 Mtetra
.55 .725 .955 r
.64066 .47631 .64162 .47741 .64357 .47718 .64261 .47606 Mtetra
.696 .778 .915 r
.64261 .47606 .64357 .47718 .6455 .47635 .64454 .47523 Mtetra
.911 .802 .727 r
.64454 .47523 .6455 .47635 .64734 .47308 .64639 .47197 Mtetra
.976 .685 .399 r
.64639 .47197 .64734 .47308 .64184 .27558 .64094 .27415 Mtetra
.973 .713 .479 r
.64094 .27415 .64184 .27558 .64298 .25704 .64209 .25586 Mtetra
.893 .787 .738 r
.64209 .25586 .64298 .25704 .64471 .25421 .64382 .25303 Mtetra
.702 .754 .893 r
.64382 .25303 .64471 .25421 .64651 .25338 .64562 .25221 Mtetra
.585 .708 .928 r
.64562 .25221 .64651 .25338 .64834 .25307 .64745 .25189 Mtetra
.665 .741 .907 r
.64745 .25189 .64834 .25307 .65015 .25243 .64927 .25125 Mtetra
.732 .765 .879 r
.64927 .25125 .65015 .25243 .65195 .25142 .65107 .25025 Mtetra
.636 .73 .916 r
.65107 .25025 .65195 .25142 .65378 .25091 .65289 .24974 Mtetra
0 .282 .78 r
.65289 .24974 .65378 .25091 .65568 .25224 .65479 .25106 Mtetra
.938 .574 .185 r
.65479 .25106 .65568 .25224 .65795 .26207 .65706 .26089 Mtetra
.975 .675 .374 r
.65706 .26089 .65795 .26207 .66871 .46562 .66777 .4645 Mtetra
0 0 .512 r
.66777 .4645 .66871 .46562 .67079 .46789 .66985 .46677 Mtetra
.629 .756 .938 r
.66985 .46677 .67079 .46789 .67275 .46736 .67181 .46624 Mtetra
.769 .8 .878 r
.67181 .46624 .67275 .46736 .67468 .46608 .67374 .46496 Mtetra
.782 .803 .87 r
.67374 .46496 .67468 .46608 .6766 .4647 .67567 .46358 Mtetra
.729 .79 .901 r
.67567 .46358 .6766 .4647 .67854 .46368 .67761 .46256 Mtetra
.715 .785 .907 r
.67761 .46256 .67854 .46368 .68049 .46274 .67955 .46161 Mtetra
.655 .764 .93 r
.67955 .46161 .68049 .46274 .68245 .46209 .68152 .46096 Mtetra
.564 .726 .95 r
.68152 .46096 .68245 .46209 .68443 .4618 .6835 .46067 Mtetra
.535 .713 .954 r
.6835 .46067 .68443 .4618 .68641 .4616 .68548 .46047 Mtetra
.443 .667 .957 r
.68548 .46047 .68641 .4616 .68842 .46168 .68748 .46055 Mtetra
.415 .652 .956 r
.68748 .46055 .68842 .46168 .69042 .46182 .68949 .4607 Mtetra
.628 .755 .938 r
.68949 .4607 .69042 .46182 .6924 .46129 .69147 .46016 Mtetra
.89 .812 .765 r
.69147 .46016 .6924 .46129 .69426 .4586 .69333 .45747 Mtetra
.981 .723 .467 r
.69333 .45747 .69426 .4586 .69535 .44101 .69442 .43982 Mtetra
.977 .681 .379 r
.69442 .43982 .69535 .44101 .68683 .24212 .68596 .24093 Mtetra
.912 .79 .713 r
.68596 .24093 .68683 .24212 .68853 .23887 .68766 .23768 Mtetra
.709 .758 .891 r
.68766 .23768 .68853 .23887 .69036 .238 .68949 .23681 Mtetra
.587 .709 .927 r
.68949 .23681 .69036 .238 .69222 .23767 .69135 .23648 Mtetra
.623 .724 .919 r
.69135 .23648 .69222 .23767 .69408 .2372 .69321 .23601 Mtetra
.731 .765 .88 r
.69321 .23601 .69408 .2372 .6959 .2362 .69503 .235 Mtetra
.64 .731 .915 r
.69503 .235 .6959 .2362 .69775 .23566 .69689 .23446 Mtetra
.067 .4 .856 r
.69689 .23446 .69775 .23566 .6997 .23669 .69883 .23549 Mtetra
.923 .551 .136 r
.69883 .23549 .6997 .23669 .70212 .24606 .70125 .2448 Mtetra
.975 .671 .352 r
.70125 .2448 .70212 .24606 .71599 .45118 .71507 .45002 Mtetra
.599 .138 0 r
.71507 .45002 .71599 .45118 .71819 .45415 .71727 .453 Mtetra
.421 .652 .955 r
.71727 .453 .71819 .45415 .72023 .45429 .71931 .45314 Mtetra
.711 .784 .909 r
.71931 .45314 .72023 .45429 .7222 .45336 .72128 .4522 Mtetra
.888 .814 .769 r
.72128 .4522 .7222 .45336 .72407 .45072 .72315 .44956 Mtetra
.977 .755 .536 r
.72315 .44956 .72407 .45072 .72554 .44165 .72462 .44036 Mtetra
.977 .679 .365 r
.72462 .44036 .72554 .44165 .71466 .23368 .71379 .23242 Mtetra
.931 .781 .672 r
.71379 .23242 .71466 .23368 .71631 .22964 .71545 .2284 Mtetra
.718 .755 .882 r
.71545 .2284 .71631 .22964 .71815 .22869 .71729 .22746 Mtetra
.582 .7 .923 r
.71729 .22746 .71815 .22869 .72003 .22838 .71917 .22715 Mtetra
.544 .682 .929 r
.71917 .22715 .72003 .22838 .72192 .22821 .72106 .22698 Mtetra
.656 .733 .906 r
.72106 .22698 .72192 .22821 .72379 .22759 .72293 .22637 Mtetra
.661 .736 .905 r
.72293 .22637 .72379 .22759 .72565 .22694 .7248 .22572 Mtetra
.699 .752 .893 r
.7248 .22572 .72565 .22694 .72751 .22611 .72665 .22489 Mtetra
.754 .771 .867 r
.72665 .22489 .72751 .22611 .72934 .22494 .72849 .22372 Mtetra
.672 .743 .904 r
.72849 .22372 .72934 .22494 .7312 .22424 .73035 .22303 Mtetra
.243 .514 .909 r
.73035 .22303 .7312 .22424 .73316 .2249 .73231 .22369 Mtetra
.895 .509 .062 r
.73231 .22369 .73316 .2249 .73563 .23285 .73477 .23162 Mtetra
.975 .667 .334 r
.73477 .23162 .73563 .23285 .75194 .43958 .75104 .43842 Mtetra
.634 .18 0 r
.75104 .43842 .75194 .43958 .75423 .44292 .75333 .44176 Mtetra
.392 .636 .953 r
.75333 .44176 .75423 .44292 .7563 .44314 .75541 .44199 Mtetra
.694 .781 .917 r
.75541 .44199 .7563 .44314 .75831 .44229 .75741 .44114 Mtetra
.873 .82 .793 r
.75741 .44114 .75831 .44229 .7602 .43994 .7593 .43878 Mtetra
.978 .767 .553 r
.7593 .43878 .7602 .43994 .76169 .43204 .7608 .43089 Mtetra
.977 .675 .347 r
.7608 .43089 .76169 .43204 .74837 .22249 .74753 .22129 Mtetra
.951 .785 .64 r
.74753 .22129 .74837 .22249 .74996 .21783 .74912 .21662 Mtetra
.747 .773 .874 r
.74912 .21662 .74996 .21783 .75181 .21671 .75096 .2155 Mtetra
.621 .724 .92 r
.75096 .2155 .75181 .21671 .7537 .21624 .75286 .21503 Mtetra
.59 .71 .927 r
.75286 .21503 .7537 .21624 .75561 .21589 .75477 .21468 Mtetra
.75 .774 .873 r
.75477 .21468 .75561 .21589 .75746 .21475 .75662 .21354 Mtetra
.676 .747 .905 r
.75662 .21354 .75746 .21475 .75934 .21404 .7585 .21283 Mtetra
.375 .595 .932 r
.7585 .21283 .75934 .21404 .7613 .21437 .76047 .21316 Mtetra
.81 .397 0 r
.76047 .21316 .7613 .21437 .76368 .21986 .76284 .21867 Mtetra
.973 .663 .319 r
.76284 .21867 .76368 .21986 .78214 .42865 .78126 .4275 Mtetra
.717 .273 0 r
.78126 .4275 .78214 .42865 .78456 .43284 .78368 .43168 Mtetra
.503 .698 .956 r
.78368 .43168 .78456 .43284 .78664 .43273 .78576 .43158 Mtetra
.695 .783 .919 r
.78576 .43158 .78664 .43273 .78866 .43187 .78778 .43071 Mtetra
.735 .797 .901 r
.78778 .43071 .78866 .43187 .79066 .43078 .78978 .42962 Mtetra
.497 .694 .956 r
.78978 .42962 .79066 .43078 .79275 .4307 .79187 .42954 Mtetra
.626 .755 .94 r
.79187 .42954 .79275 .4307 .7948 .43016 .79392 .429 Mtetra
.812 .817 .854 r
.79392 .429 .7948 .43016 .79676 .42852 .79588 .42735 Mtetra
.98 .773 .552 r
.79588 .42735 .79676 .42852 .79822 .42093 .79734 .41977 Mtetra
.976 .671 .329 r
.79734 .41977 .79822 .42093 .78248 .21088 .78165 .20966 Mtetra
.959 .785 .623 r
.78165 .20966 .78248 .21088 .78401 .20587 .78318 .20464 Mtetra
.752 .775 .872 r
.78318 .20464 .78401 .20587 .78587 .20472 .78505 .20349 Mtetra
.622 .724 .919 r
.78505 .20349 .78587 .20472 .78779 .20423 .78697 .203 Mtetra
.553 .69 .931 r
.78697 .203 .78779 .20423 .78974 .20402 .78891 .20279 Mtetra
.746 .773 .875 r
.78891 .20279 .78974 .20402 .79161 .2029 .79078 .20167 Mtetra
.677 .747 .904 r
.79078 .20167 .79161 .2029 .79351 .20217 .79269 .20094 Mtetra
.456 .639 .935 r
.79269 .20094 .79351 .20217 .79549 .20228 .79467 .20105 Mtetra
.768 .353 0 r
.79467 .20105 .79549 .20228 .79793 .20748 .79711 .20624 Mtetra
.971 .657 .298 r
.79711 .20624 .79793 .20748 .81893 .41708 .81807 .4159 Mtetra
.726 .292 0 r
.81807 .4159 .81893 .41708 .82147 .42173 .82061 .42055 Mtetra
.306 .58 .938 r
.82061 .42055 .82147 .42173 .82364 .42221 .82277 .42103 Mtetra
.649 .764 .933 r
.82277 .42103 .82364 .42221 .8257 .42156 .82484 .42038 Mtetra
.829 .821 .84 r
.82484 .42038 .8257 .42156 .82766 .41974 .8268 .41856 Mtetra
.975 .789 .589 r
.8268 .41856 .82766 .41974 .82921 .41363 .82835 .41243 Mtetra
.974 .667 .312 r
.82835 .41243 .82921 .41363 .81136 .20265 .81054 .20141 Mtetra
.974 .774 .572 r
.81054 .20141 .81136 .20265 .81275 .19632 .81193 .19507 Mtetra
.76 .757 .85 r
.19395 .4097 .19502 .4107 .19661 .40962 .19554 .40862 Mtetra
.612 .726 .927 r
.19554 .40862 .19661 .40962 .19813 .40927 .19706 .40827 Mtetra
.456 .668 .954 r
.19706 .40827 .19813 .40927 .1996 .4093 .19854 .40831 Mtetra
.654 .738 .911 r
.19854 .40831 .1996 .4093 .20114 .4088 .20008 .4078 Mtetra
.663 .74 .907 r
.20008 .4078 .20114 .4088 .20268 .40827 .20162 .40727 Mtetra
.669 .742 .905 r
.20162 .40727 .20268 .40827 .20422 .4077 .20316 .4067 Mtetra
.762 .757 .848 r
.20316 .4067 .20422 .4077 .20582 .4066 .20476 .4056 Mtetra
.709 .75 .885 r
.20476 .4056 .20582 .4066 .20738 .40585 .20632 .40485 Mtetra
.495 .684 .951 r
.20632 .40485 .20738 .40585 .20888 .40581 .20782 .4048 Mtetra
.932 .563 .279 r
.20782 .4048 .20888 .40581 .20994 .41024 .20887 .40923 Mtetra
.939 .683 .523 r
.20887 .40923 .20994 .41024 .19207 .60991 .19093 .60896 Mtetra
.932 .57 .305 r
.19093 .60896 .19207 .60991 .19318 .61491 .19204 .61396 Mtetra
0 .388 .826 r
.19204 .61396 .19318 .61491 .1947 .61564 .19356 .61469 Mtetra
.627 .756 .94 r
.19356 .61469 .1947 .61564 .19633 .6152 .1952 .61425 Mtetra
.802 .779 .832 r
.1952 .61425 .19633 .6152 .19807 .6137 .19693 .61275 Mtetra
.906 .742 .668 r
.19693 .61275 .19807 .6137 .20015 .6086 .19902 .60764 Mtetra
.939 .687 .53 r
.19902 .60764 .20015 .6086 .22064 .40794 .21959 .40691 Mtetra
.913 .724 .633 r
.21959 .40691 .22064 .40794 .22278 .40118 .22173 .40017 Mtetra
.794 .759 .822 r
.22173 .40017 .22278 .40118 .22441 .39977 .22336 .39877 Mtetra
.642 .735 .916 r
.22336 .39877 .22441 .39977 .22596 .39931 .2249 .39831 Mtetra
.501 .688 .951 r
.2249 .39831 .22596 .39931 .22747 .39925 .22641 .39825 Mtetra
.691 .749 .896 r
.22641 .39825 .22747 .39925 .22905 .39845 .22798 .39758 Mtetra
.688 .776 .918 r
.22798 .39758 .22905 .39845 .23062 .39777 .22955 .39694 Mtetra
.611 .765 .953 r
.22955 .39694 .23062 .39777 .23214 .39759 .23109 .39656 Mtetra
.235 .549 .93 r
.23109 .39656 .23214 .39759 .23346 .39967 .23256 .39697 Mtetra
.219 .283 .716 r
.23256 .39697 .23346 .39967 .23403 .41015 .23395 .39828 Mtetra
.381 .228 .546 r
.23395 .39828 .23403 .41015 .21831 .60276 .23516 .40172 Mtetra
0 0 .18 r
.23516 .40172 .21831 .60276 .21973 .60483 .21931 .59593 Mtetra
.023 0 .462 r
.21931 .59593 .21973 .60483 .22129 .60537 .22039 .60193 Mtetra
.108 .17 .647 r
.22039 .60193 .22129 .60537 .22291 .6053 .22182 .60399 Mtetra
.486 .632 .918 r
.22182 .60399 .22291 .6053 .22457 .60486 .22343 .60404 Mtetra
.679 .798 .938 r
.22343 .60404 .22457 .60486 .22624 .60419 .2251 .60339 Mtetra
.741 .81 .907 r
.2251 .60339 .22624 .60419 .22793 .60341 .2268 .60245 Mtetra
.682 .767 .916 r
.2268 .60245 .22793 .60341 .2296 .6028 .22848 .60178 Mtetra
.65 .75 .923 r
.22848 .60178 .2296 .6028 .23126 .60229 .23014 .60126 Mtetra
.629 .742 .929 r
.23014 .60126 .23126 .60229 .23292 .60184 .2318 .60081 Mtetra
.576 .724 .944 r
.2318 .60081 .23292 .60184 .23457 .60153 .23345 .60054 Mtetra
.55 .723 .954 r
.23345 .60054 .23457 .60153 .23621 .60127 .23509 .60033 Mtetra
.551 .735 .961 r
.23509 .60033 .23621 .60127 .23786 .601 .23673 .6001 Mtetra
.517 .733 .972 r
.23673 .6001 .23786 .601 .23949 .60097 .23837 .59995 Mtetra
.588 .732 .943 r
.23837 .59995 .23949 .60097 .24114 .60072 .24003 .59963 Mtetra
.677 .745 .902 r
.24003 .59963 .24114 .60072 .24284 .59992 .24171 .59898 Mtetra
.829 .784 .809 r
.24171 .59898 .24284 .59992 .24472 .59681 .24349 .59716 Mtetra
.947 .92 .751 r
.24349 .59716 .24472 .59681 .2471 .58767 .24537 .59416 Mtetra
0 0 .192 r
.24537 .59416 .2471 .58767 .2647 .39044 .24738 .5895 Mtetra
.53 .305 .518 r
.24738 .5895 .2647 .39044 .26642 .38809 .24917 .58751 Mtetra
.535 .309 .519 r
.24917 .58751 .26642 .38809 .26799 .38763 .25079 .58774 Mtetra
.533 .307 .518 r
.25079 .58774 .26799 .38763 .26954 .38751 .25248 .58698 Mtetra
0 0 .194 r
.25248 .58698 .26954 .38751 .2712 .38595 .26948 .39355 Mtetra
0 0 0 r
.26948 .39355 .2712 .38595 .27289 .38405 .2717 .38498 Mtetra
.96 .946 .683 r
.2717 .38498 .27289 .38405 .27455 .3825 .2735 .38162 Mtetra
.789 .788 .851 r
.2735 .38162 .27455 .3825 .27616 .38166 .27514 .38035 Mtetra
.635 .68 .875 r
.27514 .38035 .27616 .38166 .27773 .38119 .27672 .37991 Mtetra
.566 .658 .898 r
.27672 .37991 .27773 .38119 .2793 .38083 .27827 .37973 Mtetra
.681 .731 .888 r
.27827 .37973 .2793 .38083 .28091 .38001 .27987 .37909 Mtetra
.716 .773 .897 r
.27987 .37909 .28091 .38001 .28252 .37917 .28147 .37829 Mtetra
.659 .772 .932 r
.28147 .37829 .28252 .37917 .28409 .37877 .28306 .37775 Mtetra
.185 .523 .919 r
.28306 .37775 .28409 .37877 .28553 .38028 .28457 .37824 Mtetra
0 .136 .678 r
.28457 .37824 .28553 .38028 .28659 .38682 .28599 .37991 Mtetra
.234 .155 .558 r
.28599 .37991 .28659 .38682 .27354 .58475 .28729 .38329 Mtetra
.531 .31 .524 r
.28729 .38329 .27354 .58475 .27505 .58676 .28871 .3852 Mtetra
.537 .315 .526 r
.28871 .3852 .27505 .58676 .27673 .58633 .29034 .38418 Mtetra
.535 .313 .525 r
.29034 .38418 .27673 .58633 .27845 .58553 .29189 .38432 Mtetra
0 0 .218 r
.29189 .38432 .27845 .58553 .28003 .5866 .27937 .57933 Mtetra
0 0 .444 r
.27937 .57933 .28003 .5866 .2816 .58784 .28061 .58517 Mtetra
.058 .196 .693 r
.28061 .58517 .2816 .58784 .28324 .58805 .28214 .58695 Mtetra
.833 .765 .787 r
.28214 .58695 .28324 .58805 .2851 .58532 .28395 .58491 Mtetra
.948 .744 .594 r
.28395 .58491 .2851 .58532 .28769 .57207 .28631 .57499 Mtetra
.952 .694 .508 r
.28631 .57499 .28769 .57207 .30307 .37427 .30202 .37358 Mtetra
.904 .791 .726 r
.30202 .37358 .30307 .37427 .30484 .37128 .3038 .37044 Mtetra
.756 .797 .886 r
.3038 .37044 .30484 .37128 .30647 .37026 .30543 .36943 Mtetra
.568 .759 .968 r
.30543 .36943 .30647 .37026 .30805 .37009 .30701 .36915 Mtetra
.124 .505 .908 r
.30701 .36915 .30805 .37009 .30952 .37149 .30854 .36968 Mtetra
0 .169 .705 r
.30854 .36968 .30952 .37149 .31073 .37684 .31001 .37119 Mtetra
.2 .152 .576 r
.31001 .37119 .31073 .37684 .29907 .57589 .31138 .37421 Mtetra
.531 .31 .524 r
.31138 .37421 .29907 .57589 .30056 .57858 .31282 .37618 Mtetra
.538 .316 .526 r
.31282 .37618 .30056 .57858 .30227 .57813 .31448 .3749 Mtetra
.536 .315 .525 r
.31448 .3749 .30227 .57813 .304 .5772 .31609 .3743 Mtetra
0 0 .255 r
.31609 .3743 .304 .5772 .30566 .57743 .30543 .56314 Mtetra
0 0 .392 r
.30543 .56314 .30566 .57743 .30728 .57841 .30637 .57453 Mtetra
0 .038 .567 r
.30637 .57453 .30728 .57841 .30892 .57909 .30785 .57758 Mtetra
.159 .418 .858 r
.30785 .57758 .30892 .57909 .31059 .57917 .30948 .57842 Mtetra
.529 .777 .988 r
.30948 .57842 .31059 .57917 .3123 .57879 .31118 .57817 Mtetra
.649 .843 .975 r
.31118 .57817 .3123 .57879 .31402 .57824 .31291 .57756 Mtetra
.682 .839 .958 r
.31291 .57756 .31402 .57824 .31575 .57759 .31464 .57686 Mtetra
.686 .827 .951 r
.31464 .57686 .31575 .57759 .31748 .5769 .31637 .57615 Mtetra
.695 .825 .945 r
.31637 .57615 .31748 .5769 .31921 .57618 .3181 .5754 Mtetra
.677 .816 .95 r
.3181 .5754 .31921 .57618 .32094 .57552 .31984 .57473 Mtetra
.65 .807 .959 r
.31984 .57473 .32094 .57552 .32267 .57494 .32156 .57416 Mtetra
.64 .806 .963 r
.32156 .57416 .32267 .57494 .32439 .57438 .32329 .57362 Mtetra
.635 .808 .966 r
.32329 .57362 .32439 .57438 .32612 .57384 .32501 .57309 Mtetra
.634 .811 .968 r
.32501 .57309 .32612 .57384 .32785 .5733 .32674 .57256 Mtetra
.633 .814 .97 r
.32674 .57256 .32785 .5733 .32957 .57276 .32847 .57203 Mtetra
.574 .798 .984 r
.32847 .57203 .32957 .57276 .3313 .57231 .33019 .57166 Mtetra
.539 .806 .995 r
.33019 .57166 .3313 .57231 .33302 .57188 .33191 .57134 Mtetra
.662 .866 .977 r
.33191 .57134 .33302 .57188 .33476 .57129 .33365 .57067 Mtetra
.858 .847 .831 r
.33365 .57067 .33476 .57129 .33652 .57017 .33546 .56878 Mtetra
.891 .732 .678 r
.33546 .56878 .33652 .57017 .33833 .56832 .33741 .56437 Mtetra
.949 .686 .502 r
.33741 .56437 .33833 .56832 .34015 .56609 .34936 .37742 Mtetra
.572 .344 .532 r
.34936 .37742 .34015 .56609 .34196 .56428 .35191 .36025 Mtetra
.537 .315 .526 r
.35191 .36025 .34196 .56428 .3437 .56364 .35357 .35916 Mtetra
.535 .313 .525 r
.35357 .35916 .3437 .56364 .34542 .56339 .35517 .35931 Mtetra
.534 .312 .525 r
.35517 .35931 .34542 .56339 .34712 .56347 .35674 .35997 Mtetra
.534 .313 .525 r
.35674 .35997 .34712 .56347 .34883 .56351 .35833 .36029 Mtetra
.537 .315 .525 r
.35833 .36029 .34883 .56351 .35058 .56271 .35999 .35939 Mtetra
.542 .32 .526 r
.35999 .35939 .35058 .56271 .35251 .55844 .36178 .35589 Mtetra
.543 .32 .527 r
.36178 .35589 .35251 .55844 .36438 .35737 .36358 .35212 Mtetra
.693 .51 .636 r
.36358 .35212 .36438 .35737 .36629 .35139 .36532 .34955 Mtetra
.754 .663 .761 r
.36532 .34955 .36629 .35139 .36801 .34904 .36701 .34802 Mtetra
.691 .757 .902 r
.36701 .34802 .36801 .34904 .36966 .34826 .36866 .34732 Mtetra
.634 .759 .938 r
.36866 .34732 .36966 .34826 .3713 .34788 .37029 .34686 Mtetra
.66 .749 .916 r
.37029 .34686 .3713 .34788 .37293 .34748 .37193 .3463 Mtetra
.701 .729 .872 r
.37193 .3463 .37293 .34748 .37457 .34685 .37359 .34552 Mtetra
.643 .687 .876 r
.37359 .34552 .37457 .34685 .37621 .34634 .37523 .34503 Mtetra
.356 .554 .909 r
.37523 .34503 .37621 .34634 .37784 .34621 .37683 .3454 Mtetra
.791 .305 0 r
.37683 .3454 .37784 .34621 .37944 .34668 .37834 .34776 Mtetra
.896 .563 .41 r
.37834 .34776 .37944 .34668 .38102 .34746 .3796 .35565 Mtetra
.945 .671 .489 r
.3796 .35565 .38102 .34746 .38263 .34778 .37248 .54921 Mtetra
.534 .308 .518 r
.37248 .54921 .38263 .34778 .3843 .34687 .37422 .549 Mtetra
.532 .307 .518 r
.37422 .549 .3843 .34687 .38595 .34634 .376 .54793 Mtetra
.537 .311 .519 r
.376 .54793 .38595 .34634 .3875 .34814 .37766 .5495 Mtetra
.541 .314 .52 r
.37766 .5495 .3875 .34814 .38057 .54787 .37925 .55295 Mtetra
.629 .317 .422 r
.37925 .55295 .38057 .54787 .38202 .55474 .3809 .55486 Mtetra
.515 0 0 r
.3809 .55486 .38202 .55474 .38368 .55662 .38261 .55565 Mtetra
.527 .728 .966 r
.38261 .55565 .38368 .55662 .38543 .5565 .38436 .55547 Mtetra
.627 .751 .936 r
.38436 .55547 .38543 .5565 .3872 .55589 .38612 .55499 Mtetra
.64 .783 .95 r
.38612 .55499 .3872 .55589 .38897 .55516 .38789 .55445 Mtetra
.59 .812 .984 r
.38789 .55445 .38897 .55516 .39074 .55462 .38966 .55402 Mtetra
.685 .863 .966 r
.38966 .55402 .39074 .55462 .39251 .55391 .39144 .55327 Mtetra
.823 .861 .875 r
.39144 .55327 .39251 .55391 .3943 .55296 .39324 .55176 Mtetra
.883 .759 .721 r
.39324 .55176 .3943 .55296 .3961 .55166 .39512 .54848 Mtetra
.866 .656 .617 r
.39512 .54848 .3961 .55166 .39793 .54967 .39715 .54127 Mtetra
.95 .681 .491 r
.39715 .54127 .39793 .54967 .39983 .54552 .40638 .34156 Mtetra
.545 .322 .527 r
.40638 .34156 .39983 .54552 .40896 .34399 .4082 .33673 Mtetra
.657 .465 .612 r
.4082 .33673 .40896 .34399 .41088 .3365 .40994 .33422 Mtetra
.73 .621 .737 r
.40994 .33422 .41088 .3365 .41263 .33375 .41164 .33269 Mtetra
.699 .755 .896 r
.41164 .33269 .41263 .33375 .4143 .33288 .41331 .33195 Mtetra
.628 .762 .943 r
.41331 .33195 .4143 .33288 .41597 .33248 .41498 .33149 Mtetra
.593 .737 .944 r
.41498 .33149 .41597 .33248 .41762 .33225 .41664 .33116 Mtetra
.619 .724 .921 r
.41664 .33116 .41762 .33225 .41929 .33183 .41831 .33075 Mtetra
.623 .728 .922 r
.41831 .33075 .41929 .33183 .42096 .3314 .41997 .33033 Mtetra
.649 .738 .914 r
.41997 .33033 .42096 .3314 .42263 .33091 .42164 .3298 Mtetra
.697 .747 .89 r
.42164 .3298 .42263 .33091 .4243 .33024 .42332 .32905 Mtetra
.701 .733 .876 r
.42332 .32905 .4243 .33024 .42598 .32953 .425 .32827 Mtetra
.703 .72 .863 r
.425 .32827 .42598 .32953 .42766 .32881 .42669 .32746 Mtetra
.71 .708 .847 r
.42669 .32746 .42766 .32881 .42934 .32807 .42837 .32658 Mtetra
.658 .669 .849 r
.42837 .32658 .42934 .32807 .43102 .32747 .43005 .32598 Mtetra
.499 .599 .884 r
.43005 .32598 .43102 .32747 .43269 .32717 .43171 .32604 Mtetra
.622 .143 0 r
.43171 .32604 .43269 .32717 .43434 .32759 .43331 .32814 Mtetra
.901 .542 .353 r
.43331 .32814 .43434 .32759 .43598 .32836 .4348 .33445 Mtetra
.953 .675 .471 r
.4348 .33445 .43598 .32836 .43763 .32916 .43095 .53147 Mtetra
.535 .309 .519 r
.43095 .53147 .43763 .32916 .43931 .32877 .43271 .53219 Mtetra
.532 .307 .518 r
.43271 .53219 .43931 .32877 .441 .32799 .43452 .53107 Mtetra
.53 .305 .518 r
.43452 .53107 .441 .32799 .4427 .32699 .43636 .52893 Mtetra
.43636 .52893 .4427 .32699 .4444 .32576 .43819 .52696 Mtetra
.533 .307 .518 r
.43819 .52696 .4444 .32576 .44609 .32514 .43999 .52619 Mtetra
.538 .311 .519 r
.43999 .52619 .44609 .32514 .44774 .32602 .44173 .52817 Mtetra
.542 .314 .52 r
.44173 .52817 .44774 .32602 .44468 .52373 .44341 .53226 Mtetra
.606 .321 .458 r
.44341 .53226 .44468 .52373 .44623 .53398 .44515 .53443 Mtetra
.611 .085 0 r
.44515 .53443 .44623 .53398 .44796 .53655 .44692 .53547 Mtetra
.513 .703 .956 r
.44692 .53547 .44796 .53655 .44975 .53674 .44872 .53536 Mtetra
.658 .702 .879 r
.44872 .53536 .44975 .53674 .45156 .53609 .45053 .53473 Mtetra
.747 .734 .84 r
.45053 .53473 .45156 .53609 .4534 .53447 .45235 .53354 Mtetra
.877 .806 .777 r
.45235 .53354 .4534 .53447 .45529 .53003 .45421 .53107 Mtetra
.93 .948 .611 r
.45421 .53107 .45529 .53003 .46108 .3324 .45608 .52736 Mtetra
.522 .299 .516 r
.45608 .52736 .46108 .3324 .46302 .31984 .458 .52138 Mtetra
.53 .305 .518 r
.458 .52138 .46302 .31984 .46474 .31846 .45985 .51896 Mtetra
.535 .309 .518 r
.45985 .51896 .46474 .31846 .46644 .31806 .46164 .51919 Mtetra
.536 .31 .519 r
.46164 .51919 .46644 .31806 .46813 .31817 .46342 .52038 Mtetra
.46342 .52038 .46813 .31817 .46982 .31793 .46521 .52147 Mtetra
.534 .308 .518 r
.46521 .52147 .46982 .31793 .47153 .3175 .46702 .52127 Mtetra
.529 .304 .518 r
.46702 .52127 .47153 .3175 .47324 .31659 .46887 .51862 Mtetra
0 0 .305 r
.46887 .51862 .47324 .31659 .47497 .31448 .47392 .31853 Mtetra
0 0 0 r
.47392 .31853 .47497 .31448 .4767 .3126 .47572 .31268 Mtetra
.952 .928 .741 r
.47572 .31268 .4767 .3126 .47842 .31112 .47746 .30981 Mtetra
.694 .715 .865 r
.47746 .30981 .47842 .31112 .48013 .3105 .47917 .30904 Mtetra
.602 .653 .873 r
.47917 .30904 .48013 .3105 .48183 .31009 .48088 .30871 Mtetra
.541 .64 .897 r
.48088 .30871 .48183 .31009 .48354 .30976 .48258 .30861 Mtetra
.645 .725 .907 r
.48258 .30861 .48354 .30976 .48525 .30919 .48429 .30809 Mtetra
.661 .742 .91 r
.48429 .30809 .48525 .30919 .48696 .30856 .48601 .3075 Mtetra
.677 .756 .91 r
.48601 .3075 .48696 .30856 .48868 .30787 .48772 .30684 Mtetra
.745 .778 .879 r
.48772 .30684 .48868 .30787 .4904 .30674 .48944 .30582 Mtetra
.723 .797 .91 r
.48944 .30582 .4904 .30674 .49212 .30588 .49116 .30495 Mtetra
.646 .774 .941 r
.49116 .30495 .49212 .30588 .49383 .30557 .49288 .30441 Mtetra
.267 .541 .921 r
.49288 .30441 .49383 .30557 .49553 .30775 .49459 .30491 Mtetra
.242 .297 .72 r
.49459 .30491 .49553 .30775 .49715 .31782 .49629 .30643 Mtetra
.343 .211 .553 r
.49629 .30643 .49715 .31782 .49723 .51634 .49797 .31089 Mtetra
0 0 .331 r
.49797 .31089 .49723 .51634 .49905 .51845 .49808 .5115 Mtetra
.116 .089 .547 r
.49808 .5115 .49905 .51845 .50088 .51913 .49987 .51639 Mtetra
.151 .259 .722 r
.49987 .51639 .50088 .51913 .50272 .51916 .5017 .51819 Mtetra
.541 .741 .968 r
.5017 .51819 .50272 .51916 .50456 .51868 .50354 .51795 Mtetra
.694 .847 .956 r
.50354 .51795 .50456 .51868 .50641 .51796 .50539 .51715 Mtetra
.746 .838 .921 r
.50539 .51715 .50641 .51796 .50825 .51716 .50724 .51611 Mtetra
.438 .675 .963 r
.50724 .51611 .50825 .51716 .5101 .51723 .50908 .51617 Mtetra
.544 .722 .956 r
.50908 .51617 .5101 .51723 .51195 .517 .51093 .51595 Mtetra
.73 .788 .898 r
.51093 .51595 .51195 .517 .5138 .51601 .51279 .51496 Mtetra
.94 .769 .643 r
.51279 .51496 .5138 .51601 .51566 .51072 .51465 .5095 Mtetra
.969 .689 .448 r
.51465 .5095 .51566 .51072 .51797 .30385 .51702 .3022 Mtetra
.923 .722 .612 r
.51702 .3022 .51797 .30385 .51972 .29702 .51877 .29566 Mtetra
.769 .733 .819 r
.51877 .29566 .51972 .29702 .52145 .2956 .52051 .29431 Mtetra
.605 .685 .899 r
.52051 .29431 .52145 .2956 .52319 .29519 .52224 .29395 Mtetra
.468 .633 .926 r
.52224 .29395 .52319 .29519 .52492 .29521 .52398 .29403 Mtetra
.624 .717 .913 r
.52398 .29403 .52492 .29521 .52666 .29472 .52572 .29359 Mtetra
.662 .74 .907 r
.52572 .29359 .52666 .29472 .5284 .29409 .52746 .29299 Mtetra
.678 .75 .905 r
.52746 .29299 .5284 .29409 .53014 .29341 .5292 .29231 Mtetra
.774 .776 .855 r
.5292 .29231 .53014 .29341 .53188 .29219 .53094 .29106 Mtetra
.737 .764 .874 r
.53094 .29106 .53188 .29219 .53362 .29122 .53268 .29006 Mtetra
.597 .711 .923 r
.53268 .29006 .53362 .29122 .53536 .2909 .53443 .28972 Mtetra
.744 .292 0 r
.53443 .28972 .53536 .2909 .53712 .29399 .53619 .29278 Mtetra
.97 .683 .426 r
.53619 .29278 .53712 .29399 .53979 .49879 .53879 .49764 Mtetra
.935 .56 .196 r
.53879 .49764 .53979 .49879 .5417 .50621 .5407 .50515 Mtetra
0 .308 .784 r
.5407 .50515 .5417 .50621 .54358 .50736 .54258 .5063 Mtetra
.587 .743 .951 r
.54258 .5063 .54358 .50736 .54545 .507 .54445 .50594 Mtetra
.796 .8 .856 r
.54445 .50594 .54545 .507 .54732 .50555 .54632 .50447 Mtetra
.934 .777 .664 r
.54632 .50447 .54732 .50555 .54916 .50085 .54817 .49976 Mtetra
.971 .689 .436 r
.54817 .49976 .54916 .50085 .54942 .29501 .54848 .29382 Mtetra
.954 .74 .576 r
.54848 .29382 .54942 .29501 .55111 .28674 .55018 .28559 Mtetra
.832 .779 .801 r
.55018 .28559 .55111 .28674 .55286 .28488 .55193 .28373 Mtetra
.667 .741 .905 r
.55193 .28373 .55286 .28488 .55461 .28424 .55368 .2831 Mtetra
.551 .695 .935 r
.55368 .2831 .55461 .28424 .55637 .28405 .55544 .28291 Mtetra
.719 .759 .884 r
.55544 .28291 .55637 .28405 .55813 .28315 .5572 .28201 Mtetra
.711 .757 .888 r
.5572 .28201 .55813 .28315 .55988 .28229 .55896 .28116 Mtetra
.565 .702 .933 r
.55896 .28116 .55988 .28229 .56165 .28206 .56072 .28092 Mtetra
.71 .251 0 r
.56072 .28092 .56165 .28206 .56345 .28496 .56252 .28382 Mtetra
.972 .681 .415 r
.56252 .28382 .56345 .28496 .56788 .48961 .56689 .48849 Mtetra
.932 .554 .183 r
.56689 .48849 .56788 .48961 .56987 .4972 .56889 .4961 Mtetra
0 .255 .747 r
.56889 .4961 .56987 .4972 .57179 .49852 .5708 .49743 Mtetra
.573 .731 .95 r
.5708 .49743 .57179 .49852 .57368 .49821 .5727 .49711 Mtetra
.789 .797 .858 r
.5727 .49711 .57368 .49821 .57556 .4968 .57458 .49569 Mtetra
.935 .778 .662 r
.57458 .49569 .57556 .4968 .57739 .49221 .57641 .49095 Mtetra
.973 .688 .426 r
.57641 .49095 .57739 .49221 .5759 .28552 .57497 .28368 Mtetra
.933 .716 .586 r
.57497 .28368 .5759 .28552 .57755 .27728 .57663 .27592 Mtetra
.819 .749 .786 r
.57663 .27592 .57755 .27728 .5793 .27533 .57838 .27403 Mtetra
.63 .699 .895 r
.57838 .27403 .5793 .27533 .58107 .27481 .58015 .27356 Mtetra
.494 .647 .925 r
.58015 .27356 .58107 .27481 .58285 .27476 .58194 .27357 Mtetra
.587 .702 .922 r
.58194 .27357 .58285 .27476 .58463 .27441 .58372 .27326 Mtetra
.657 .739 .91 r
.58372 .27326 .58463 .27441 .58641 .2738 .5855 .27267 Mtetra
.673 .749 .908 r
.5855 .27267 .58641 .2738 .58819 .27312 .58727 .272 Mtetra
.76 .776 .867 r
.58727 .272 .58819 .27312 .58995 .27199 .58904 .27085 Mtetra
.75 .77 .869 r
.58904 .27085 .58995 .27199 .59172 .27092 .59081 .26975 Mtetra
.637 .728 .914 r
.59081 .26975 .59172 .27092 .59351 .27043 .59259 .26924 Mtetra
0 0 .529 r
.59259 .26924 .59351 .27043 .59535 .27254 .59444 .27133 Mtetra
.974 .68 .402 r
.59444 .27133 .59535 .27254 .60185 .47379 .60087 .47256 Mtetra
.954 .607 .258 r
.60087 .47256 .60185 .47379 .60406 .48601 .60309 .48495 Mtetra
0 .085 .597 r
.60309 .48495 .60406 .48601 .60603 .4878 .60506 .48674 Mtetra
.525 .719 .961 r
.60506 .48674 .60603 .4878 .60795 .48763 .60698 .48656 Mtetra
.77 .803 .879 r
.60698 .48656 .60795 .48763 .60985 .48637 .60888 .48529 Mtetra
.925 .795 .698 r
.60888 .48529 .60985 .48637 .61168 .48254 .61072 .48146 Mtetra
.975 .687 .413 r
.61072 .48146 .61168 .48254 .60819 .28052 .60729 .27955 Mtetra
.975 .731 .505 r
.60729 .27955 .60819 .28052 .60964 .267 .60873 .26586 Mtetra
.878 .788 .758 r
.60873 .26586 .60964 .267 .61138 .26449 .61047 .26335 Mtetra
.688 .752 .901 r
.61047 .26335 .61138 .26449 .61317 .26375 .61226 .26261 Mtetra
.564 .703 .935 r
.61226 .26261 .61317 .26375 .61497 .2635 .61407 .26236 Mtetra
.684 .753 .904 r
.61407 .26236 .61497 .2635 .61676 .26278 .61586 .26164 Mtetra
.726 .767 .885 r
.61586 .26164 .61676 .26278 .61855 .26183 .61765 .26069 Mtetra
.599 .721 .93 r
.61765 .26069 .61855 .26183 .62035 .26144 .61945 .26032 Mtetra
0 0 .491 r
.61945 .26032 .62035 .26144 .62224 .26353 .62134 .26251 Mtetra
.974 .678 .39 r
.62134 .26251 .62224 .26353 .63059 .46677 .62968 .46693 Mtetra
.932 .563 .281 r
.62968 .46693 .63059 .46677 .63288 .47722 .63193 .47639 Mtetra
0 .188 .657 r
.63193 .47639 .63288 .47722 .63488 .47871 .63393 .47779 Mtetra
.649 .805 .958 r
.63393 .47779 .63488 .47871 .63681 .47813 .63586 .47716 Mtetra
.767 .825 .897 r
.63586 .47716 .63681 .47813 .63873 .47697 .63778 .47594 Mtetra
.669 .786 .936 r
.63778 .47594 .63873 .47697 .64066 .47631 .63971 .47523 Mtetra
.553 .73 .957 r
.63971 .47523 .64066 .47631 .64261 .47606 .64166 .47497 Mtetra
.697 .783 .917 r
.64166 .47497 .64261 .47606 .64454 .47523 .64359 .47413 Mtetra
.912 .804 .728 r
.64359 .47413 .64454 .47523 .64639 .47197 .64544 .47086 Mtetra
.976 .685 .399 r
.64544 .47086 .64639 .47197 .64094 .27415 .64005 .27316 Mtetra
.978 .72 .471 r
.64005 .27316 .64094 .27415 .64209 .25586 .6412 .25469 Mtetra
.893 .788 .738 r
.6412 .25469 .64209 .25586 .64382 .25303 .64293 .25186 Mtetra
.702 .755 .893 r
.64293 .25186 .64382 .25303 .64562 .25221 .64473 .25104 Mtetra
.585 .709 .928 r
.64473 .25104 .64562 .25221 .64745 .25189 .64656 .25072 Mtetra
.665 .742 .907 r
.64656 .25072 .64745 .25189 .64927 .25125 .64838 .25008 Mtetra
.732 .765 .879 r
.64838 .25008 .64927 .25125 .65107 .25025 .65018 .24908 Mtetra
.636 .73 .917 r
.65018 .24908 .65107 .25025 .65289 .24974 .652 .24856 Mtetra
0 .282 .78 r
.652 .24856 .65289 .24974 .65479 .25106 .65391 .24989 Mtetra
.938 .574 .185 r
.65391 .24989 .65479 .25106 .65706 .26089 .65617 .25972 Mtetra
.975 .675 .374 r
.65617 .25972 .65706 .26089 .66777 .4645 .66683 .46338 Mtetra
0 0 .512 r
.66683 .46338 .66777 .4645 .66985 .46677 .66891 .46565 Mtetra
.629 .756 .938 r
.66891 .46565 .66985 .46677 .67181 .46624 .67087 .46511 Mtetra
.769 .8 .878 r
.67087 .46511 .67181 .46624 .67374 .46496 .6728 .46383 Mtetra
.782 .803 .87 r
.6728 .46383 .67374 .46496 .67567 .46358 .67473 .46245 Mtetra
.73 .79 .9 r
.67473 .46245 .67567 .46358 .67761 .46256 .67667 .46143 Mtetra
.715 .786 .907 r
.67667 .46143 .67761 .46256 .67955 .46161 .67862 .46048 Mtetra
.655 .765 .93 r
.67862 .46048 .67955 .46161 .68152 .46096 .68058 .45983 Mtetra
.564 .726 .951 r
.68058 .45983 .68152 .46096 .6835 .46067 .68256 .45954 Mtetra
.535 .713 .954 r
.68256 .45954 .6835 .46067 .68548 .46047 .68455 .45934 Mtetra
.443 .667 .957 r
.68455 .45934 .68548 .46047 .68748 .46055 .68655 .45942 Mtetra
.415 .652 .956 r
.68655 .45942 .68748 .46055 .68949 .4607 .68856 .45956 Mtetra
.628 .755 .938 r
.68856 .45956 .68949 .4607 .69147 .46016 .69054 .45903 Mtetra
.89 .812 .765 r
.69054 .45903 .69147 .46016 .69333 .45747 .69241 .45634 Mtetra
.981 .723 .467 r
.69241 .45634 .69333 .45747 .69442 .43982 .6935 .43864 Mtetra
.977 .681 .379 r
.6935 .43864 .69442 .43982 .68596 .24093 .68509 .23974 Mtetra
.912 .79 .713 r
.68509 .23974 .68596 .24093 .68766 .23768 .68679 .23649 Mtetra
.709 .758 .891 r
.68679 .23649 .68766 .23768 .68949 .23681 .68862 .23561 Mtetra
.587 .709 .927 r
.68862 .23561 .68949 .23681 .69135 .23648 .69048 .23528 Mtetra
.623 .724 .919 r
.69048 .23528 .69135 .23648 .69321 .23601 .69234 .23481 Mtetra
.732 .765 .88 r
.69234 .23481 .69321 .23601 .69503 .235 .69417 .23381 Mtetra
.64 .731 .914 r
.69417 .23381 .69503 .235 .69689 .23446 .69602 .23326 Mtetra
.069 .401 .856 r
.69602 .23326 .69689 .23446 .69883 .23549 .69796 .23429 Mtetra
.923 .55 .134 r
.69796 .23429 .69883 .23549 .70125 .2448 .70038 .24353 Mtetra
.975 .671 .352 r
.70038 .24353 .70125 .2448 .71507 .45002 .71415 .44886 Mtetra
.599 .139 0 r
.71415 .44886 .71507 .45002 .71727 .453 .71635 .45184 Mtetra
.421 .652 .954 r
.71635 .45184 .71727 .453 .71931 .45314 .71839 .45199 Mtetra
.712 .783 .908 r
.71839 .45199 .71931 .45314 .72128 .4522 .72037 .45104 Mtetra
.889 .813 .768 r
.72037 .45104 .72128 .4522 .72315 .44956 .72224 .44839 Mtetra
.977 .754 .534 r
.72224 .44839 .72315 .44956 .72462 .44036 .7237 .43904 Mtetra
.977 .679 .365 r
.7237 .43904 .72462 .44036 .71379 .23242 .71293 .23115 Mtetra
.93 .78 .673 r
.71293 .23115 .71379 .23242 .71545 .2284 .71458 .22716 Mtetra
.717 .754 .881 r
.71458 .22716 .71545 .2284 .71729 .22746 .71643 .22622 Mtetra
.582 .699 .922 r
.71643 .22622 .71729 .22746 .71917 .22715 .71831 .22592 Mtetra
.544 .681 .928 r
.71831 .22592 .71917 .22715 .72106 .22698 .72021 .22575 Mtetra
.655 .732 .906 r
.72021 .22575 .72106 .22698 .72293 .22637 .72207 .22513 Mtetra
.66 .735 .905 r
.72207 .22513 .72293 .22637 .7248 .22572 .72394 .22449 Mtetra
.698 .75 .892 r
.72394 .22449 .7248 .22572 .72665 .22489 .7258 .22367 Mtetra
.753 .77 .867 r
.7258 .22367 .72665 .22489 .72849 .22372 .72763 .2225 Mtetra
.671 .742 .903 r
.72763 .2225 .72849 .22372 .73035 .22303 .7295 .22181 Mtetra
.243 .514 .908 r
.7295 .22181 .73035 .22303 .73231 .22369 .73146 .22247 Mtetra
.894 .508 .061 r
.73146 .22247 .73231 .22369 .73477 .23162 .73392 .23038 Mtetra
.975 .667 .334 r
.73392 .23038 .73477 .23162 .75104 .43842 .75014 .43726 Mtetra
.635 .181 0 r
.75014 .43726 .75104 .43842 .75333 .44176 .75243 .44061 Mtetra
.391 .635 .952 r
.75243 .44061 .75333 .44176 .75541 .44199 .75451 .44083 Mtetra
.694 .781 .917 r
.75451 .44083 .75541 .44199 .75741 .44114 .75651 .43998 Mtetra
.873 .82 .793 r
.75651 .43998 .75741 .44114 .7593 .43878 .75841 .43763 Mtetra
.978 .767 .553 r
.75841 .43763 .7593 .43878 .7608 .43089 .7599 .42973 Mtetra
.977 .675 .347 r
.7599 .42973 .7608 .43089 .74753 .22129 .74668 .22008 Mtetra
.951 .785 .64 r
.74668 .22008 .74753 .22129 .74912 .21662 .74827 .21541 Mtetra
.747 .773 .874 r
.74827 .21541 .74912 .21662 .75096 .2155 .75012 .21429 Mtetra
.621 .724 .92 r
.75012 .21429 .75096 .2155 .75286 .21503 .75202 .21381 Mtetra
.59 .71 .927 r
.75202 .21381 .75286 .21503 .75477 .21468 .75393 .21347 Mtetra
.75 .774 .873 r
.75393 .21347 .75477 .21468 .75662 .21354 .75578 .21233 Mtetra
.675 .748 .905 r
.75578 .21233 .75662 .21354 .7585 .21283 .75766 .21161 Mtetra
.373 .595 .932 r
.75766 .21161 .7585 .21283 .76047 .21316 .75963 .21195 Mtetra
.812 .399 0 r
.75963 .21195 .76047 .21316 .76284 .21867 .762 .21749 Mtetra
.973 .663 .319 r
.762 .21749 .76284 .21867 .78126 .4275 .78038 .42637 Mtetra
.717 .272 0 r
.78038 .42637 .78126 .4275 .78368 .43168 .78279 .43053 Mtetra
.503 .698 .957 r
.78279 .43053 .78368 .43168 .78576 .43158 .78487 .43042 Mtetra
.695 .784 .919 r
.78487 .43042 .78576 .43158 .78778 .43071 .7869 .42956 Mtetra
.736 .798 .902 r
.7869 .42956 .78778 .43071 .78978 .42962 .7889 .42847 Mtetra
.497 .695 .957 r
.7889 .42847 .78978 .42962 .79187 .42954 .79099 .42838 Mtetra
.626 .756 .94 r
.79099 .42838 .79187 .42954 .79392 .429 .79304 .42783 Mtetra
.812 .817 .854 r
.79304 .42783 .79392 .429 .79588 .42735 .795 .42619 Mtetra
.98 .773 .553 r
.795 .42619 .79588 .42735 .79734 .41977 .79647 .41862 Mtetra
.976 .671 .329 r
.79647 .41862 .79734 .41977 .78165 .20966 .78082 .20844 Mtetra
.96 .785 .622 r
.78082 .20844 .78165 .20966 .78318 .20464 .78236 .20342 Mtetra
.752 .775 .872 r
.78236 .20342 .78318 .20464 .78505 .20349 .78422 .20226 Mtetra
.623 .724 .919 r
.78422 .20226 .78505 .20349 .78697 .203 .78614 .20178 Mtetra
.553 .691 .931 r
.78614 .20178 .78697 .203 .78891 .20279 .78809 .20156 Mtetra
.747 .773 .875 r
.78809 .20156 .78891 .20279 .79078 .20167 .78996 .20044 Mtetra
.677 .747 .904 r
.78996 .20044 .79078 .20167 .79269 .20094 .79186 .1997 Mtetra
.456 .639 .935 r
.79186 .1997 .79269 .20094 .79467 .20105 .79384 .19981 Mtetra
.768 .353 0 r
.79384 .19981 .79467 .20105 .79711 .20624 .79628 .20501 Mtetra
.971 .657 .298 r
.79628 .20501 .79711 .20624 .81807 .4159 .8172 .41472 Mtetra
.726 .292 0 r
.8172 .41472 .81807 .4159 .82061 .42055 .81974 .41937 Mtetra
.306 .58 .938 r
.81974 .41937 .82061 .42055 .82277 .42103 .82191 .41985 Mtetra
.649 .763 .933 r
.82191 .41985 .82277 .42103 .82484 .42038 .82397 .41919 Mtetra
.83 .82 .84 r
.82397 .41919 .82484 .42038 .8268 .41856 .82593 .41737 Mtetra
.975 .789 .589 r
.82593 .41737 .8268 .41856 .82835 .41243 .82749 .41124 Mtetra
.974 .667 .312 r
.82749 .41124 .82835 .41243 .81054 .20141 .80973 .20016 Mtetra
.974 .774 .572 r
.80973 .20016 .81054 .20141 .81193 .19507 .81112 .19382 Mtetra
.76 .757 .85 r
.19288 .4087 .19395 .4097 .19554 .40862 .19448 .40762 Mtetra
.613 .726 .926 r
.19448 .40762 .19554 .40862 .19706 .40827 .196 .40727 Mtetra
.457 .668 .954 r
.196 .40727 .19706 .40827 .19854 .40831 .19748 .4073 Mtetra
.654 .737 .911 r
.19748 .4073 .19854 .40831 .20008 .4078 .19901 .4068 Mtetra
.663 .74 .907 r
.19901 .4068 .20008 .4078 .20162 .40727 .20055 .40626 Mtetra
.669 .741 .904 r
.20055 .40626 .20162 .40727 .20316 .4067 .2021 .4057 Mtetra
.762 .757 .848 r
.2021 .4057 .20316 .4067 .20476 .4056 .20369 .40459 Mtetra
.708 .75 .884 r
.20369 .40459 .20476 .4056 .20632 .40485 .20526 .40384 Mtetra
.495 .684 .95 r
.20526 .40384 .20632 .40485 .20782 .4048 .20675 .4038 Mtetra
.932 .562 .278 r
.20675 .4038 .20782 .4048 .20887 .40923 .20781 .40821 Mtetra
.939 .683 .523 r
.20781 .40821 .20887 .40923 .19093 .60896 .18979 .60799 Mtetra
.932 .57 .305 r
.18979 .60799 .19093 .60896 .19204 .61396 .19089 .61301 Mtetra
0 .388 .826 r
.19089 .61301 .19204 .61396 .19356 .61469 .19242 .61374 Mtetra
.627 .756 .939 r
.19242 .61374 .19356 .61469 .1952 .61425 .19405 .6133 Mtetra
.802 .779 .832 r
.19405 .6133 .1952 .61425 .19693 .61275 .19579 .6118 Mtetra
.906 .742 .668 r
.19579 .6118 .19693 .61275 .19902 .60764 .19788 .60666 Mtetra
.939 .687 .53 r
.19788 .60666 .19902 .60764 .21959 .40691 .21853 .40586 Mtetra
.912 .723 .634 r
.21853 .40586 .21959 .40691 .22173 .40017 .22067 .39915 Mtetra
.793 .758 .822 r
.22067 .39915 .22173 .40017 .22336 .39877 .2223 .39776 Mtetra
.641 .734 .917 r
.2223 .39776 .22336 .39877 .2249 .39831 .22385 .3973 Mtetra
.501 .687 .95 r
.22385 .3973 .2249 .39831 .22641 .39825 .22536 .39725 Mtetra
.661 .742 .91 r
.22536 .39725 .22641 .39825 .22798 .39758 .22691 .39671 Mtetra
.679 .774 .922 r
.22691 .39671 .22798 .39758 .22955 .39694 .22848 .3961 Mtetra
.668 .78 .933 r
.22848 .3961 .22955 .39694 .23109 .39656 .23004 .39554 Mtetra
.712 .75 .882 r
.23004 .39554 .23109 .39656 .23256 .39697 .23162 .39476 Mtetra
.629 .569 .769 r
.23162 .39476 .23256 .39697 .23395 .39828 .23317 .39425 Mtetra
.535 .425 .675 r
.23317 .39425 .23395 .39828 .23516 .40172 .23467 .39436 Mtetra
.21 .129 .541 r
.23467 .39436 .23516 .40172 .21931 .59593 .23586 .39804 Mtetra
0 0 .154 r
.23586 .39804 .21931 .59593 .22039 .60193 .21962 .59691 Mtetra
0 0 .231 r
.21962 .59691 .22039 .60193 .22182 .60399 .22071 .60271 Mtetra
.245 .512 .907 r
.22071 .60271 .22182 .60399 .22343 .60404 .22228 .60324 Mtetra
.674 .8 .942 r
.22228 .60324 .22343 .60404 .2251 .60339 .22396 .6026 Mtetra
.765 .814 .891 r
.22396 .6026 .2251 .60339 .2268 .60245 .22567 .60151 Mtetra
.687 .775 .919 r
.22567 .60151 .2268 .60245 .22848 .60178 .22735 .60083 Mtetra
.65 .763 .932 r
.22735 .60083 .22848 .60178 .23014 .60126 .22901 .6003 Mtetra
.641 .759 .935 r
.22901 .6003 .23014 .60126 .2318 .60081 .23068 .5998 Mtetra
.63 .747 .931 r
.23068 .5998 .2318 .60081 .23345 .60054 .23234 .59934 Mtetra
.624 .709 .906 r
.23234 .59934 .23345 .60054 .23509 .60033 .234 .59892 Mtetra
.618 .67 .878 r
.234 .59892 .23509 .60033 .23673 .6001 .23566 .59853 Mtetra
.598 .637 .861 r
.23566 .59853 .23673 .6001 .23837 .59995 .23731 .59823 Mtetra
.6 .619 .842 r
.23731 .59823 .23837 .59995 .24003 .59963 .23897 .59792 Mtetra
.617 .627 .838 r
.23897 .59792 .24003 .59963 .24171 .59898 .24063 .59753 Mtetra
.675 .683 .85 r
.24063 .59753 .24171 .59898 .24349 .59716 .24232 .59683 Mtetra
.707 .912 .966 r
.24232 .59683 .24349 .59716 .24537 .59416 .24402 .59598 Mtetra
.179 0 0 r
.24402 .59598 .24537 .59416 .24738 .5895 .24573 .59511 Mtetra
.497 .2 .393 r
.24573 .59511 .24738 .5895 .24917 .58751 .24738 .59491 Mtetra
.505 .225 .423 r
.24738 .59491 .24917 .58751 .25079 .58774 .24903 .59468 Mtetra
.457 .177 .4 r
.24903 .59468 .25079 .58774 .25248 .58698 .25074 .59378 Mtetra
.047 0 .227 r
.25074 .59378 .25248 .58698 .26948 .39355 .25274 .58926 Mtetra
0 0 .155 r
.25274 .58926 .26948 .39355 .2717 .38498 .2703 .3884 Mtetra
.931 .87 .444 r
.2703 .3884 .2717 .38498 .2735 .38162 .2724 .38137 Mtetra
.882 .893 .834 r
.2724 .38137 .2735 .38162 .27514 .38035 .27409 .37951 Mtetra
.676 .783 .931 r
.27409 .37951 .27514 .38035 .27672 .37991 .27568 .3789 Mtetra
.556 .711 .943 r
.27568 .3789 .27672 .37991 .27827 .37973 .27723 .3787 Mtetra
.638 .734 .918 r
.27723 .3787 .27827 .37973 .27987 .37909 .27881 .37825 Mtetra
.674 .785 .932 r
.27881 .37825 .27987 .37909 .28147 .37829 .28041 .37765 Mtetra
.649 .825 .968 r
.28041 .37765 .28147 .37829 .28306 .37775 .28199 .37711 Mtetra
.569 .804 .988 r
.28199 .37711 .28306 .37775 .28457 .37824 .28357 .37678 Mtetra
.576 .631 .869 r
.28357 .37678 .28457 .37824 .28599 .37991 .28513 .37658 Mtetra
.568 .472 .706 r
.28513 .37658 .28599 .37991 .28729 .38329 .28669 .37641 Mtetra
.585 .414 .617 r
.28669 .37641 .28729 .38329 .28871 .3852 .2883 .3757 Mtetra
.575 .389 .592 r
.2883 .3757 .28871 .3852 .29034 .38418 .28991 .37493 Mtetra
.55 .372 .592 r
.28991 .37493 .29034 .38418 .29189 .38432 .29148 .37476 Mtetra
.292 .174 .542 r
.29148 .37476 .29189 .38432 .27937 .57933 .29274 .37877 Mtetra
0 0 .197 r
.29274 .37877 .27937 .57933 .28061 .58517 .27978 .58038 Mtetra
0 0 .442 r
.27978 .58038 .28061 .58517 .28214 .58695 .28112 .5848 Mtetra
.737 .638 .75 r
.28112 .5848 .28214 .58695 .28395 .58491 .28289 .58326 Mtetra
.919 .704 .596 r
.28289 .58326 .28395 .58491 .28631 .57499 .2853 .57278 Mtetra
.947 .687 .512 r
.2853 .57278 .28631 .57499 .30202 .37358 .30098 .37263 Mtetra
.881 .767 .731 r
.30098 .37263 .30202 .37358 .3038 .37044 .30275 .36972 Mtetra
.727 .824 .925 r
.30275 .36972 .3038 .37044 .30543 .36943 .30437 .3689 Mtetra
.52 .815 .999 r
.30437 .3689 .30543 .36943 .30701 .36915 .30595 .36861 Mtetra
.48 .798 .999 r
.30595 .36861 .30701 .36915 .30854 .36968 .30753 .3684 Mtetra
.584 .667 .896 r
.30753 .3684 .30854 .36968 .31001 .37119 .30912 .36815 Mtetra
.576 .49 .721 r
.30912 .36815 .31001 .37119 .31138 .37421 .3107 .36794 Mtetra
.59 .424 .625 r
.3107 .36794 .31138 .37421 .31282 .37618 .31232 .36721 Mtetra
.582 .398 .597 r
.31232 .36721 .31282 .37618 .31448 .3749 .31395 .3663 Mtetra
.56 .383 .598 r
.31395 .3663 .31448 .3749 .31609 .3743 .31555 .36593 Mtetra
.411 .272 .581 r
.31555 .36593 .31609 .3743 .30543 .56314 .31698 .36809 Mtetra
0 0 .207 r
.31698 .36809 .30543 .56314 .30637 .57453 .30572 .56663 Mtetra
0 0 .253 r
.30572 .56663 .30637 .57453 .30785 .57758 .30682 .57555 Mtetra
0 .217 .733 r
.30682 .57555 .30785 .57758 .30948 .57842 .30841 .57708 Mtetra
.602 .68 .896 r
.30841 .57708 .30948 .57842 .31118 .57817 .31011 .57674 Mtetra
.7 .7 .847 r
.31011 .57674 .31118 .57817 .31291 .57756 .31185 .57588 Mtetra
.683 .662 .823 r
.31185 .57588 .31291 .57756 .31464 .57686 .31359 .57507 Mtetra
.65 .636 .823 r
.31359 .57507 .31464 .57686 .31637 .57615 .31532 .57447 Mtetra
.654 .65 .834 r
.31532 .57447 .31637 .57615 .3181 .5754 .31704 .57385 Mtetra
.653 .667 .851 r
.31704 .57385 .3181 .5754 .31984 .57473 .31877 .57327 Mtetra
.649 .678 .864 r
.31877 .57327 .31984 .57473 .32156 .57416 .3205 .57271 Mtetra
.646 .68 .867 r
.3205 .57271 .32156 .57416 .32329 .57362 .32222 .57217 Mtetra
.643 .678 .868 r
.32222 .57217 .32329 .57362 .32501 .57309 .32395 .57164 Mtetra
.641 .678 .869 r
.32395 .57164 .32501 .57309 .32674 .57256 .32568 .57112 Mtetra
.642 .68 .871 r
.32568 .57112 .32674 .57256 .32847 .57203 .32741 .5706 Mtetra
.59 .661 .887 r
.32741 .5706 .32847 .57203 .33019 .57166 .32912 .57031 Mtetra
.57 .667 .904 r
.32912 .57031 .33019 .57166 .33191 .57134 .33083 .57009 Mtetra
.689 .726 .879 r
.33083 .57009 .33191 .57134 .33365 .57067 .33258 .56934 Mtetra
.853 .742 .74 r
.33258 .56934 .33365 .57067 .33546 .56878 .33444 .56661 Mtetra
.918 .693 .583 r
.33444 .56661 .33546 .56878 .33741 .56437 .33681 .55467 Mtetra
.943 .678 .506 r
.33681 .55467 .33741 .56437 .34936 .37742 .34945 .35631 Mtetra
.594 .38 .559 r
.34945 .35631 .34936 .37742 .35191 .36025 .35123 .35316 Mtetra
.589 .416 .615 r
.35123 .35316 .35191 .36025 .35357 .35916 .35287 .35233 Mtetra
.561 .398 .617 r
.35287 .35233 .35357 .35916 .35517 .35931 .35449 .35205 Mtetra
.558 .391 .612 r
.35449 .35205 .35517 .35931 .35674 .35997 .35611 .35181 Mtetra
.568 .392 .603 r
.35611 .35181 .35674 .35997 .35833 .36029 .35774 .3513 Mtetra
.567 .386 .596 r
.35774 .3513 .35833 .36029 .35999 .35939 .35937 .35075 Mtetra
.576 .395 .599 r
.35937 .35075 .35999 .35939 .36178 .35589 .36102 .35001 Mtetra
.604 .439 .632 r
.36102 .35001 .36178 .35589 .36358 .35212 .36268 .3491 Mtetra
.65 .538 .713 r
.36268 .3491 .36358 .35212 .36532 .34955 .36433 .34819 Mtetra
.695 .699 .85 r
.36433 .34819 .36532 .34955 .36701 .34802 .36598 .34741 Mtetra
.661 .845 .971 r
.36598 .34741 .36701 .34802 .36866 .34732 .36763 .34681 Mtetra
.63 .859 .985 r
.36763 .34681 .36866 .34732 .37029 .34686 .36927 .34626 Mtetra
.689 .852 .961 r
.36927 .34626 .37029 .34686 .37193 .3463 .37092 .34555 Mtetra
.729 .824 .924 r
.37092 .34555 .37193 .3463 .37359 .34552 .37257 .3447 Mtetra
.618 .781 .959 r
.37257 .3447 .37359 .34552 .37523 .34503 .37421 .34427 Mtetra
0 .233 .677 r
.37421 .34427 .37523 .34503 .37683 .3454 .37578 .34524 Mtetra
.923 .569 .341 r
.37578 .34524 .37683 .3454 .37834 .34776 .3771 .35168 Mtetra
.951 .678 .485 r
.3771 .35168 .37834 .34776 .3796 .35565 .36945 .55324 Mtetra
.54 .313 .519 r
.36945 .55324 .3796 .35565 .37248 .54921 .37104 .55639 Mtetra
.507 .225 .42 r
.37104 .55639 .37248 .54921 .37422 .549 .37278 .55622 Mtetra
.469 .191 .408 r
.37278 .55622 .37422 .549 .376 .54793 .37455 .55541 Mtetra
.475 .199 .414 r
.37455 .55541 .376 .54793 .37766 .5495 .37632 .55466 Mtetra
.499 .195 .381 r
.37632 .55466 .37766 .5495 .37925 .55295 .37806 .55453 Mtetra
.394 0 .087 r
.37806 .55453 .37925 .55295 .3809 .55486 .37981 .55439 Mtetra
.459 .816 .996 r
.37981 .55439 .3809 .55486 .38261 .55565 .38156 .55412 Mtetra
.627 .665 .867 r
.38156 .55412 .38261 .55565 .38436 .55547 .38333 .55366 Mtetra
.636 .632 .829 r
.38333 .55366 .38436 .55547 .38612 .55499 .38509 .55312 Mtetra
.616 .616 .828 r
.38509 .55312 .38612 .55499 .38789 .55445 .38686 .5527 Mtetra
.574 .61 .851 r
.38686 .5527 .38789 .55445 .38966 .55402 .38861 .55249 Mtetra
.662 .679 .855 r
.38861 .55249 .38966 .55402 .39144 .55327 .39039 .55184 Mtetra
.811 .734 .779 r
.39039 .55184 .39144 .55327 .39324 .55176 .39221 .54988 Mtetra
.904 .706 .625 r
.39221 .54988 .39324 .55176 .39512 .54848 .39423 .54306 Mtetra
.954 .685 .488 r
.39423 .54306 .39512 .54848 .39715 .54127 .40378 .33946 Mtetra
.545 .321 .527 r
.40378 .33946 .39715 .54127 .40638 .34156 .40561 .33464 Mtetra
.615 .436 .617 r
.40561 .33464 .40638 .34156 .4082 .33673 .4073 .33328 Mtetra
.623 .504 .698 r
.4073 .33328 .4082 .33673 .40994 .33422 .40897 .33256 Mtetra
.633 .635 .835 r
.40897 .33256 .40994 .33422 .41164 .33269 .41064 .33208 Mtetra
.652 .845 .974 r
.41064 .33208 .41164 .33269 .41331 .33195 .41231 .33149 Mtetra
.603 .868 .992 r
.41231 .33149 .41331 .33195 .41498 .33149 .41397 .33096 Mtetra
.608 .854 .99 r
.41397 .33096 .41498 .33149 .41664 .33116 .41564 .33046 Mtetra
.645 .823 .968 r
.41564 .33046 .41664 .33116 .41831 .33075 .41731 .3299 Mtetra
.656 .791 .946 r
.41731 .3299 .41831 .33075 .41997 .33033 .41898 .32934 Mtetra
.666 .761 .921 r
.41898 .32934 .41997 .33033 .42164 .3298 .42066 .32874 Mtetra
.676 .75 .907 r
.42066 .32874 .42164 .3298 .42332 .32905 .42234 .3281 Mtetra
.679 .773 .922 r
.42234 .3281 .42332 .32905 .425 .32827 .42401 .32745 Mtetra
.699 .808 .933 r
.42401 .32745 .425 .32827 .42669 .32746 .4257 .32672 Mtetra
.754 .834 .913 r
.4257 .32672 .42669 .32746 .42837 .32658 .42739 .32572 Mtetra
.665 .792 .942 r
.42739 .32572 .42837 .32658 .43005 .32598 .42907 .32512 Mtetra
.192 .569 .938 r
.42907 .32512 .43005 .32598 .43171 .32604 .43072 .32553 Mtetra
.915 .521 .229 r
.43072 .32553 .43171 .32604 .43331 .32814 .43224 .33039 Mtetra
.958 .68 .467 r
.43224 .33039 .43331 .32814 .4348 .33445 .42804 .5336 Mtetra
.542 .315 .519 r
.42804 .5336 .4348 .33445 .43095 .53147 .42969 .53805 Mtetra
.516 .227 .413 r
.42969 .53805 .43095 .53147 .43271 .53219 .43147 .53806 Mtetra
.457 .167 .383 r
.43147 .53806 .43271 .53219 .43452 .53107 .43328 .5373 Mtetra
.438 .154 .383 r
.43328 .5373 .43452 .53107 .43636 .52893 .43509 .53622 Mtetra
.48 .201 .413 r
.43509 .53622 .43636 .52893 .43819 .52696 .4369 .53557 Mtetra
.491 .22 .431 r
.4369 .53557 .43819 .52696 .43999 .52619 .4387 .53495 Mtetra
.498 .227 .434 r
.4387 .53495 .43999 .52619 .44173 .52817 .4405 .53447 Mtetra
.504 .213 .405 r
.4405 .53447 .44173 .52817 .44341 .53226 .4423 .5343 Mtetra
.426 .025 .172 r
.4423 .5343 .44341 .53226 .44515 .53443 .44409 .53414 Mtetra
.353 .8 .953 r
.44409 .53414 .44515 .53443 .44692 .53547 .44589 .5339 Mtetra
.627 .662 .864 r
.44589 .5339 .44692 .53547 .44872 .53536 .4477 .53343 Mtetra
.641 .624 .817 r
.4477 .53343 .44872 .53536 .45053 .53473 .44951 .53284 Mtetra
.661 .636 .814 r
.44951 .53284 .45053 .53473 .45235 .53354 .45132 .53211 Mtetra
.713 .714 .85 r
.45132 .53211 .45235 .53354 .45421 .53107 .45314 .53115 Mtetra
.632 .961 .9 r
.45314 .53115 .45421 .53107 .45608 .52736 .45497 .53012 Mtetra
.317 0 .196 r
.45497 .53012 .45608 .52736 .458 .52138 .45679 .52916 Mtetra
.488 .212 .421 r
.45679 .52916 .458 .52138 .45985 .51896 .45861 .52857 Mtetra
.502 .235 .442 r
.45861 .52857 .45985 .51896 .46164 .51919 .46042 .52809 Mtetra
.503 .232 .436 r
.46042 .52809 .46164 .51919 .46342 .52038 .46224 .52768 Mtetra
.519 .235 .423 r
.46224 .52768 .46342 .52038 .46521 .52147 .46404 .52771 Mtetra
.485 .195 .398 r
.46404 .52771 .46521 .52147 .46702 .52127 .46586 .52726 Mtetra
.406 .124 .369 r
.46586 .52726 .46702 .52127 .46887 .51862 .4677 .52584 Mtetra
0 0 .154 r
.4677 .52584 .46887 .51862 .47392 .31853 .46964 .51826 Mtetra
0 0 .29 r
.46964 .51826 .47392 .31853 .47572 .31268 .47472 .31395 Mtetra
.965 .907 .547 r
.47472 .31395 .47572 .31268 .47746 .30981 .47649 .30911 Mtetra
.772 .85 .91 r
.47649 .30911 .47746 .30981 .47917 .30904 .47821 .30801 Mtetra
.625 .745 .933 r
.47821 .30801 .47917 .30904 .48088 .30871 .47992 .30756 Mtetra
.526 .679 .935 r
.47992 .30756 .48088 .30871 .48258 .30861 .48162 .30746 Mtetra
.648 .727 .907 r
.48162 .30746 .48258 .30861 .48429 .30809 .48334 .30692 Mtetra
.651 .726 .904 r
.48334 .30692 .48429 .30809 .48601 .3075 .48505 .30638 Mtetra
.659 .737 .908 r
.48505 .30638 .48601 .3075 .48772 .30684 .48676 .3058 Mtetra
.693 .765 .907 r
.48676 .3058 .48772 .30684 .48944 .30582 .48848 .30506 Mtetra
.69 .828 .949 r
.48848 .30506 .48944 .30582 .49116 .30495 .4902 .30434 Mtetra
.662 .856 .974 r
.4902 .30434 .49116 .30495 .49288 .30441 .49192 .30369 Mtetra
.706 .84 .946 r
.49192 .30369 .49288 .30441 .49459 .30491 .49364 .3029 Mtetra
.614 .591 .804 r
.49364 .3029 .49459 .30491 .49629 .30643 .49536 .30248 Mtetra
.515 .421 .686 r
.49536 .30248 .49629 .30643 .49797 .31089 .49707 .30279 Mtetra
.173 .109 .539 r
.49707 .30279 .49797 .31089 .49808 .5115 .49875 .30791 Mtetra
0 0 .322 r
.49875 .30791 .49808 .5115 .49987 .51639 .49888 .51194 Mtetra
0 0 .503 r
.49888 .51194 .49987 .51639 .5017 .51819 .50069 .51652 Mtetra
.466 .573 .878 r
.50069 .51652 .5017 .51819 .50354 .51795 .50253 .51672 Mtetra
.665 .736 .903 r
.50253 .51672 .50354 .51795 .50539 .51715 .50437 .51607 Mtetra
.74 .784 .888 r
.50437 .51607 .50539 .51715 .50724 .51611 .50622 .51502 Mtetra
.496 .695 .957 r
.50622 .51502 .50724 .51611 .50908 .51617 .50807 .51494 Mtetra
.598 .712 .924 r
.50807 .51494 .50908 .51617 .51093 .51595 .50992 .51458 Mtetra
.737 .735 .849 r
.50992 .51458 .51093 .51595 .51279 .51496 .51177 .51345 Mtetra
.918 .738 .643 r
.51177 .51345 .51279 .51496 .51465 .5095 .51364 .50797 Mtetra
.968 .689 .448 r
.51364 .50797 .51465 .5095 .51702 .3022 .51608 .30144 Mtetra
.959 .77 .605 r
.51608 .30144 .51702 .3022 .51877 .29566 .51783 .29492 Mtetra
.822 .851 .87 r
.51783 .29492 .51877 .29566 .52051 .29431 .51956 .29347 Mtetra
.625 .792 .962 r
.51956 .29347 .52051 .29431 .52224 .29395 .5213 .29298 Mtetra
.492 .706 .965 r
.5213 .29298 .52224 .29395 .52398 .29403 .52304 .2929 Mtetra
.636 .73 .916 r
.52304 .2929 .52398 .29403 .52572 .29359 .52478 .29241 Mtetra
.659 .728 .901 r
.52478 .29241 .52572 .29359 .52746 .29299 .52652 .29182 Mtetra
.665 .733 .901 r
.52652 .29182 .52746 .29299 .5292 .29231 .52826 .2912 Mtetra
.757 .771 .864 r
.52826 .2912 .5292 .29231 .53094 .29106 .53 .29007 Mtetra
.723 .786 .902 r
.53 .29007 .53094 .29106 .53268 .29006 .53174 .28918 Mtetra
.539 .749 .973 r
.53174 .28918 .53268 .29006 .53443 .28972 .53349 .28895 Mtetra
.834 .373 0 r
.53349 .28895 .53443 .28972 .53619 .29278 .53525 .29227 Mtetra
.97 .682 .427 r
.53525 .29227 .53619 .29278 .53879 .49764 .5378 .49742 Mtetra
.922 .538 .254 r
.5378 .49742 .53879 .49764 .5407 .50515 .5397 .50414 Mtetra
0 .328 .794 r
.5397 .50414 .5407 .50515 .54258 .5063 .54158 .50522 Mtetra
.592 .741 .947 r
.54158 .50522 .54258 .5063 .54445 .50594 .54345 .50484 Mtetra
.794 .796 .854 r
.54345 .50484 .54445 .50594 .54632 .50447 .54532 .50338 Mtetra
.933 .776 .663 r
.54532 .50338 .54632 .50447 .54817 .49976 .54717 .49865 Mtetra
.971 .689 .436 r
.54717 .49865 .54817 .49976 .54848 .29382 .54755 .29262 Mtetra
.953 .74 .577 r
.54755 .29262 .54848 .29382 .55018 .28559 .54925 .28445 Mtetra
.832 .779 .802 r
.54925 .28445 .55018 .28559 .55193 .28373 .551 .28259 Mtetra
.666 .741 .906 r
.551 .28259 .55193 .28373 .55368 .2831 .55275 .28196 Mtetra
.551 .695 .935 r
.55275 .28196 .55368 .2831 .55544 .28291 .55451 .28177 Mtetra
.719 .758 .884 r
.55451 .28177 .55544 .28291 .5572 .28201 .55627 .28087 Mtetra
.711 .756 .887 r
.55627 .28087 .5572 .28201 .55896 .28116 .55803 .28001 Mtetra
.565 .702 .933 r
.55803 .28001 .55896 .28116 .56072 .28092 .55979 .27977 Mtetra
.707 .248 0 r
.55979 .27977 .56072 .28092 .56252 .28382 .5616 .28266 Mtetra
.972 .681 .415 r
.5616 .28266 .56252 .28382 .56689 .48849 .56591 .48734 Mtetra
.932 .555 .182 r
.56591 .48734 .56689 .48849 .56889 .4961 .5679 .495 Mtetra
0 .262 .753 r
.5679 .495 .56889 .4961 .5708 .49743 .56981 .4963 Mtetra
.578 .728 .945 r
.56981 .4963 .5708 .49743 .5727 .49711 .57171 .49598 Mtetra
.787 .791 .856 r
.57171 .49598 .5727 .49711 .57458 .49569 .57359 .49456 Mtetra
.931 .779 .67 r
.57359 .49456 .57458 .49569 .57641 .49095 .57543 .49005 Mtetra
.973 .688 .426 r
.57543 .49005 .57641 .49095 .57497 .28368 .57407 .28388 Mtetra
.994 .796 .531 r
.57407 .28388 .57497 .28368 .57663 .27592 .57571 .27524 Mtetra
.882 .864 .817 r
.57571 .27524 .57663 .27592 .57838 .27403 .57746 .27321 Mtetra
.656 .809 .957 r
.57746 .27321 .57838 .27403 .58015 .27356 .57924 .2726 Mtetra
.513 .72 .966 r
.57924 .2726 .58015 .27356 .58194 .27357 .58102 .27245 Mtetra
.605 .726 .93 r
.58102 .27245 .58194 .27357 .58372 .27326 .5828 .27207 Mtetra
.656 .73 .904 r
.5828 .27207 .58372 .27326 .5855 .27267 .58458 .27148 Mtetra
.662 .732 .902 r
.58458 .27148 .5855 .27267 .58727 .272 .58636 .27086 Mtetra
.742 .767 .874 r
.58636 .27086 .58727 .272 .58904 .27085 .58813 .26982 Mtetra
.737 .788 .894 r
.58813 .26982 .58904 .27085 .59081 .26975 .5899 .26883 Mtetra
.595 .767 .962 r
.5899 .26883 .59081 .26975 .59259 .26924 .59169 .26844 Mtetra
.661 .156 0 r
.59169 .26844 .59259 .26924 .59444 .27133 .59353 .27072 Mtetra
.973 .679 .403 r
.59353 .27072 .59444 .27133 .60087 .47256 .59996 .47393 Mtetra
.912 .557 .352 r
.59996 .47393 .60087 .47256 .60309 .48495 .60212 .48397 Mtetra
0 .101 .599 r
.60212 .48397 .60309 .48495 .60506 .48674 .60408 .48565 Mtetra
.531 .718 .959 r
.60408 .48565 .60506 .48674 .60698 .48656 .60601 .48546 Mtetra
.768 .798 .877 r
.60601 .48546 .60698 .48656 .60888 .48529 .60791 .4842 Mtetra
.924 .794 .699 r
.60791 .4842 .60888 .48529 .61072 .48146 .60975 .48038 Mtetra
.975 .687 .413 r
.60975 .48038 .61072 .48146 .60729 .27955 .60638 .27862 Mtetra
.975 .731 .503 r
.60638 .27862 .60729 .27955 .60873 .26586 .60782 .26472 Mtetra
.878 .789 .758 r
.60782 .26472 .60873 .26586 .61047 .26335 .60957 .2622 Mtetra
.687 .753 .901 r
.60957 .2622 .61047 .26335 .61226 .26261 .61136 .26146 Mtetra
.561 .703 .936 r
.61136 .26146 .61226 .26261 .61407 .26236 .61316 .26123 Mtetra
.68 .752 .906 r
.61316 .26123 .61407 .26236 .61586 .26164 .61496 .26052 Mtetra
.724 .77 .889 r
.61496 .26052 .61586 .26164 .61765 .26069 .61675 .25959 Mtetra
.599 .728 .935 r
.61675 .25959 .61765 .26069 .61945 .26032 .61855 .25922 Mtetra
0 0 .529 r
.61855 .25922 .61945 .26032 .62134 .26251 .62044 .26126 Mtetra
.975 .678 .39 r
.62044 .26126 .62134 .26251 .62968 .46693 .62865 .46372 Mtetra
.884 .558 .056 r
.62865 .46372 .62968 .46693 .63193 .47639 .63095 .47475 Mtetra
0 .275 .779 r
.63095 .47475 .63193 .47639 .63393 .47779 .63296 .47631 Mtetra
.623 .685 .888 r
.63296 .47631 .63393 .47779 .63586 .47716 .6349 .47583 Mtetra
.726 .75 .871 r
.6349 .47583 .63586 .47716 .63778 .47594 .63682 .47478 Mtetra
.648 .753 .927 r
.63682 .47478 .63778 .47594 .63971 .47523 .63876 .47418 Mtetra
.551 .735 .961 r
.63876 .47418 .63971 .47523 .64166 .47497 .64071 .47391 Mtetra
.701 .792 .921 r
.64071 .47391 .64166 .47497 .64359 .47413 .64264 .47305 Mtetra
.914 .807 .728 r
.64264 .47305 .64359 .47413 .64544 .47086 .64448 .46977 Mtetra
.976 .685 .399 r
.64448 .46977 .64544 .47086 .64005 .27316 .63917 .27254 Mtetra
.982 .725 .462 r
.63917 .27254 .64005 .27316 .6412 .25469 .6403 .25353 Mtetra
.894 .789 .738 r
.6403 .25353 .6412 .25469 .64293 .25186 .64203 .25069 Mtetra
.702 .756 .894 r
.64203 .25069 .64293 .25186 .64473 .25104 .64384 .24987 Mtetra
.585 .709 .929 r
.64384 .24987 .64473 .25104 .64656 .25072 .64567 .24955 Mtetra
.665 .742 .908 r
.64567 .24955 .64656 .25072 .64838 .25008 .64749 .2489 Mtetra
.733 .765 .879 r
.64749 .2489 .64838 .25008 .65018 .24908 .64929 .2479 Mtetra
.636 .73 .917 r
.64929 .2479 .65018 .24908 .652 .24856 .65112 .24738 Mtetra
0 .282 .78 r
.65112 .24738 .652 .24856 .65391 .24989 .65302 .24871 Mtetra
.938 .574 .185 r
.65302 .24871 .65391 .24989 .65617 .25972 .65528 .25854 Mtetra
.975 .675 .374 r
.65528 .25854 .65617 .25972 .66683 .46338 .66589 .46225 Mtetra
0 0 .512 r
.66589 .46225 .66683 .46338 .66891 .46565 .66797 .46453 Mtetra
.629 .756 .938 r
.66797 .46453 .66891 .46565 .67087 .46511 .66993 .46399 Mtetra
.769 .8 .878 r
.66993 .46399 .67087 .46511 .6728 .46383 .67186 .46271 Mtetra
.782 .803 .87 r
.67186 .46271 .6728 .46383 .67473 .46245 .67379 .46133 Mtetra
.73 .79 .9 r
.67379 .46133 .67473 .46245 .67667 .46143 .67573 .4603 Mtetra
.716 .786 .907 r
.67573 .4603 .67667 .46143 .67862 .46048 .67768 .45935 Mtetra
.655 .765 .93 r
.67768 .45935 .67862 .46048 .68058 .45983 .67965 .4587 Mtetra
.563 .727 .951 r
.67965 .4587 .68058 .45983 .68256 .45954 .68163 .45841 Mtetra
.535 .713 .954 r
.68163 .45841 .68256 .45954 .68455 .45934 .68362 .45821 Mtetra
.443 .667 .958 r
.68362 .45821 .68455 .45934 .68655 .45942 .68562 .45828 Mtetra
.415 .652 .956 r
.68562 .45828 .68655 .45942 .68856 .45956 .68763 .45843 Mtetra
.628 .755 .938 r
.68763 .45843 .68856 .45956 .69054 .45903 .68961 .45789 Mtetra
.89 .812 .765 r
.68961 .45789 .69054 .45903 .69241 .45634 .69147 .4552 Mtetra
.981 .723 .466 r
.69147 .4552 .69241 .45634 .6935 .43864 .69257 .43745 Mtetra
.977 .681 .379 r
.69257 .43745 .6935 .43864 .68509 .23974 .68421 .23854 Mtetra
.912 .79 .713 r
.68421 .23854 .68509 .23974 .68679 .23649 .68592 .2353 Mtetra
.709 .758 .891 r
.68592 .2353 .68679 .23649 .68862 .23561 .68775 .23442 Mtetra
.588 .709 .927 r
.68775 .23442 .68862 .23561 .69048 .23528 .68961 .23409 Mtetra
.623 .724 .919 r
.68961 .23409 .69048 .23528 .69234 .23481 .69147 .23362 Mtetra
.732 .765 .88 r
.69147 .23362 .69234 .23481 .69417 .23381 .6933 .23261 Mtetra
.641 .731 .914 r
.6933 .23261 .69417 .23381 .69602 .23326 .69515 .23206 Mtetra
.071 .403 .857 r
.69515 .23206 .69602 .23326 .69796 .23429 .69709 .23308 Mtetra
.922 .548 .131 r
.69709 .23308 .69796 .23429 .70038 .24353 .6995 .24224 Mtetra
.975 .671 .352 r
.6995 .24224 .70038 .24353 .71415 .44886 .71323 .4477 Mtetra
.599 .14 0 r
.71323 .4477 .71415 .44886 .71635 .45184 .71543 .45068 Mtetra
.423 .652 .954 r
.71543 .45068 .71635 .45184 .71839 .45199 .71747 .45082 Mtetra
.713 .783 .907 r
.71747 .45082 .71839 .45199 .72037 .45104 .71945 .44988 Mtetra
.889 .812 .767 r
.71945 .44988 .72037 .45104 .72224 .44839 .72132 .4472 Mtetra
.977 .753 .532 r
.72132 .4472 .72224 .44839 .7237 .43904 .72278 .43772 Mtetra
.977 .679 .365 r
.72278 .43772 .7237 .43904 .71293 .23115 .71206 .22989 Mtetra
.93 .782 .675 r
.71206 .22989 .71293 .23115 .71458 .22716 .71372 .22593 Mtetra
.718 .756 .882 r
.71372 .22593 .71458 .22716 .71643 .22622 .71557 .22499 Mtetra
.583 .7 .923 r
.71557 .22499 .71643 .22622 .71831 .22592 .71745 .22467 Mtetra
.545 .681 .927 r
.71745 .22467 .71831 .22592 .72021 .22575 .71935 .2245 Mtetra
.654 .73 .905 r
.71935 .2245 .72021 .22575 .72207 .22513 .72121 .22389 Mtetra
.659 .733 .904 r
.72121 .22389 .72207 .22513 .72394 .22449 .72308 .22326 Mtetra
.696 .748 .892 r
.72308 .22326 .72394 .22449 .7258 .22367 .72494 .22244 Mtetra
.752 .769 .867 r
.72494 .22244 .7258 .22367 .72763 .2225 .72678 .22128 Mtetra
.671 .741 .903 r
.72678 .22128 .72763 .2225 .7295 .22181 .72864 .22059 Mtetra
.243 .513 .908 r
.72864 .22059 .7295 .22181 .73146 .22247 .7306 .22125 Mtetra
.894 .507 .059 r
.7306 .22125 .73146 .22247 .73392 .23038 .73306 .22913 Mtetra
.975 .667 .334 r
.73306 .22913 .73392 .23038 .75014 .43726 .74923 .43609 Mtetra
.635 .181 0 r
.74923 .43609 .75014 .43726 .75243 .44061 .75153 .43945 Mtetra
.391 .635 .952 r
.75153 .43945 .75243 .44061 .75451 .44083 .7536 .43968 Mtetra
.694 .78 .918 r
.7536 .43968 .75451 .44083 .75651 .43998 .75561 .43882 Mtetra
.873 .82 .793 r
.75561 .43882 .75651 .43998 .75841 .43763 .75751 .43647 Mtetra
.978 .768 .553 r
.75751 .43647 .75841 .43763 .7599 .42973 .75901 .42858 Mtetra
.977 .675 .347 r
.75901 .42858 .7599 .42973 .74668 .22008 .74584 .21887 Mtetra
.951 .785 .64 r
.74584 .21887 .74668 .22008 .74827 .21541 .74743 .21419 Mtetra
.747 .773 .874 r
.74743 .21419 .74827 .21541 .75012 .21429 .74928 .21307 Mtetra
.62 .724 .921 r
.74928 .21307 .75012 .21429 .75202 .21381 .75118 .2126 Mtetra
.589 .71 .927 r
.75118 .2126 .75202 .21381 .75393 .21347 .75309 .21226 Mtetra
.75 .775 .873 r
.75309 .21226 .75393 .21347 .75578 .21233 .75494 .21112 Mtetra
.675 .748 .906 r
.75494 .21112 .75578 .21233 .75766 .21161 .75682 .2104 Mtetra
.371 .594 .932 r
.75682 .2104 .75766 .21161 .75963 .21195 .75879 .21074 Mtetra
.815 .402 0 r
.75879 .21074 .75963 .21195 .762 .21749 .76117 .21633 Mtetra
.973 .663 .319 r
.76117 .21633 .762 .21749 .78038 .42637 .7795 .42524 Mtetra
.717 .271 0 r
.7795 .42524 .78038 .42637 .78279 .43053 .78191 .42938 Mtetra
.503 .7 .958 r
.78191 .42938 .78279 .43053 .78487 .43042 .78399 .42927 Mtetra
.695 .785 .92 r
.78399 .42927 .78487 .43042 .7869 .42956 .78601 .42841 Mtetra
.736 .799 .902 r
.78601 .42841 .7869 .42956 .7889 .42847 .78802 .42732 Mtetra
.498 .696 .957 r
.78802 .42732 .7889 .42847 .79099 .42838 .79011 .42723 Mtetra
.626 .757 .94 r
.79011 .42723 .79099 .42838 .79304 .42783 .79216 .42667 Mtetra
.812 .818 .855 r
.79216 .42667 .79304 .42783 .795 .42619 .79412 .42503 Mtetra
.98 .773 .553 r
.79412 .42503 .795 .42619 .79647 .41862 .79559 .41747 Mtetra
.976 .671 .329 r
.79559 .41747 .79647 .41862 .78082 .20844 .77999 .20723 Mtetra
.96 .785 .622 r
.77999 .20723 .78082 .20844 .78236 .20342 .78153 .20219 Mtetra
.752 .776 .872 r
.78153 .20219 .78236 .20342 .78422 .20226 .78339 .20103 Mtetra
.623 .724 .919 r
.78339 .20103 .78422 .20226 .78614 .20178 .78531 .20055 Mtetra
.553 .691 .931 r
.78531 .20055 .78614 .20178 .78809 .20156 .78726 .20033 Mtetra
.747 .774 .875 r
.78726 .20033 .78809 .20156 .78996 .20044 .78913 .19921 Mtetra
.677 .748 .904 r
.78913 .19921 .78996 .20044 .79186 .1997 .79104 .19847 Mtetra
.456 .639 .935 r
.79104 .19847 .79186 .1997 .79384 .19981 .79302 .19858 Mtetra
.768 .353 0 r
.79302 .19858 .79384 .19981 .79628 .20501 .79546 .20378 Mtetra
.971 .657 .298 r
.79546 .20378 .79628 .20501 .8172 .41472 .81633 .41353 Mtetra
.726 .292 0 r
.81633 .41353 .8172 .41472 .81974 .41937 .81887 .41818 Mtetra
.307 .58 .938 r
.81887 .41818 .81974 .41937 .82191 .41985 .82104 .41866 Mtetra
.649 .763 .932 r
.82104 .41866 .82191 .41985 .82397 .41919 .82311 .418 Mtetra
.83 .82 .84 r
.82311 .418 .82397 .41919 .82593 .41737 .82507 .41618 Mtetra
.975 .789 .589 r
.82507 .41618 .82593 .41737 .82749 .41124 .82663 .41004 Mtetra
.974 .667 .312 r
.82663 .41004 .82749 .41124 .80973 .20016 .80891 .1989 Mtetra
.974 .773 .573 r
.80891 .1989 .80973 .20016 .81112 .19382 .8103 .19257 Mtetra
.76 .756 .85 r
.19182 .4077 .19288 .4087 .19448 .40762 .19341 .40662 Mtetra
.613 .726 .926 r
.19341 .40662 .19448 .40762 .196 .40727 .19493 .40626 Mtetra
.458 .667 .953 r
.19493 .40626 .196 .40727 .19748 .4073 .19641 .4063 Mtetra
.654 .737 .91 r
.19641 .4063 .19748 .4073 .19901 .4068 .19795 .40579 Mtetra
.663 .739 .907 r
.19795 .40579 .19901 .4068 .20055 .40626 .19949 .40526 Mtetra
.669 .741 .904 r
.19949 .40526 .20055 .40626 .2021 .4057 .20103 .40469 Mtetra
.762 .757 .848 r
.20103 .40469 .2021 .4057 .20369 .40459 .20263 .40359 Mtetra
.708 .749 .884 r
.20263 .40359 .20369 .40459 .20526 .40384 .2042 .40283 Mtetra
.496 .683 .95 r
.2042 .40283 .20526 .40384 .20675 .4038 .20569 .40279 Mtetra
.932 .562 .277 r
.20569 .40279 .20675 .4038 .20781 .40821 .20675 .40719 Mtetra
.939 .683 .523 r
.20675 .40719 .20781 .40821 .18979 .60799 .18865 .60702 Mtetra
.933 .571 .306 r
.18865 .60702 .18979 .60799 .19089 .61301 .18975 .61206 Mtetra
0 .387 .826 r
.18975 .61206 .19089 .61301 .19242 .61374 .19127 .61279 Mtetra
.628 .756 .939 r
.19127 .61279 .19242 .61374 .19405 .6133 .19291 .61235 Mtetra
.802 .779 .831 r
.19291 .61235 .19405 .6133 .19579 .6118 .19465 .61084 Mtetra
.906 .741 .667 r
.19465 .61084 .19579 .6118 .19788 .60666 .19675 .60567 Mtetra
.939 .687 .53 r
.19675 .60567 .19788 .60666 .21853 .40586 .21748 .40477 Mtetra
.91 .722 .635 r
.21748 .40477 .21853 .40586 .22067 .39915 .21961 .39812 Mtetra
.79 .756 .821 r
.21961 .39812 .22067 .39915 .2223 .39776 .22125 .39673 Mtetra
.638 .731 .915 r
.22125 .39673 .2223 .39776 .22385 .3973 .22279 .39629 Mtetra
.499 .683 .949 r
.22279 .39629 .22385 .3973 .22536 .39725 .2243 .39624 Mtetra
.646 .736 .915 r
.2243 .39624 .22536 .39725 .22691 .39671 .22585 .39576 Mtetra
.673 .756 .913 r
.22585 .39576 .22691 .39671 .22848 .3961 .22741 .39518 Mtetra
.685 .763 .911 r
.22741 .39518 .22848 .3961 .23004 .39554 .22898 .39454 Mtetra
.771 .762 .845 r
.22898 .39454 .23004 .39554 .23162 .39476 .2306 .39336 Mtetra
.718 .691 .824 r
.2306 .39336 .23162 .39476 .23317 .39425 .23219 .39243 Mtetra
.604 .594 .815 r
.23219 .39243 .23317 .39425 .23467 .39436 .23373 .39212 Mtetra
0 0 .323 r
.23373 .39212 .23467 .39436 .23586 .39804 .23499 .39493 Mtetra
.945 .687 .515 r
.23499 .39493 .23586 .39804 .21962 .59691 .21874 .59309 Mtetra
.954 .657 .222 r
.21874 .59309 .21962 .59691 .22071 .60271 .21959 .60165 Mtetra
.011 .419 .86 r
.21959 .60165 .22071 .60271 .22228 .60324 .22114 .60237 Mtetra
.673 .786 .934 r
.22114 .60237 .22228 .60324 .22396 .6026 .22282 .60174 Mtetra
.77 .799 .877 r
.22282 .60174 .22396 .6026 .22567 .60151 .22454 .60059 Mtetra
.666 .774 .93 r
.22454 .60059 .22567 .60151 .22735 .60083 .22621 .6 Mtetra
.637 .787 .953 r
.22621 .6 .22735 .60083 .22901 .6003 .22787 .5995 Mtetra
.684 .804 .939 r
.22787 .5995 .22901 .6003 .23068 .5998 .22955 .59882 Mtetra
.807 .778 .826 r
.22955 .59882 .23068 .5998 .23234 .59934 .23131 .59725 Mtetra
.772 .654 .732 r
.23131 .59725 .23234 .59934 .234 .59892 .23311 .5952 Mtetra
.7 .549 .678 r
.23311 .5952 .234 .59892 .23566 .59853 .2349 .5933 Mtetra
.476 .362 .645 r
.2349 .5933 .23566 .59853 .23731 .59823 .23646 .59406 Mtetra
.351 .304 .665 r
.23646 .59406 .23731 .59823 .23897 .59792 .23797 .59547 Mtetra
.282 .362 .768 r
.23797 .59547 .23897 .59792 .24063 .59753 .23951 .5965 Mtetra
.404 .654 .96 r
.23951 .5965 .24063 .59753 .24232 .59683 .24113 .59662 Mtetra
.377 .818 .952 r
.24113 .59662 .24232 .59683 .24402 .59598 .24279 .59634 Mtetra
0 0 0 r
.24279 .59634 .24402 .59598 .24573 .59511 .24446 .59588 Mtetra
.187 0 0 r
.24446 .59588 .24573 .59511 .24738 .59491 .24612 .59562 Mtetra
.053 0 0 r
.24612 .59562 .24738 .59491 .24903 .59468 .24779 .5952 Mtetra
.44 .863 .731 r
.24779 .5952 .24903 .59468 .25074 .59378 .2495 .59426 Mtetra
.943 .946 .754 r
.2495 .59426 .25074 .59378 .25274 .58926 .25137 .59141 Mtetra
.995 .87 .563 r
.25137 .59141 .25274 .58926 .2703 .3884 .2536 .58406 Mtetra
0 0 .16 r
.2536 .58406 .2703 .3884 .2724 .38137 .27102 .38468 Mtetra
0 0 0 r
.27102 .38468 .2724 .38137 .27409 .37951 .27288 .38065 Mtetra
.627 .894 .577 r
.27288 .38065 .27409 .37951 .27568 .3789 .27457 .3788 Mtetra
.793 .954 .921 r
.27457 .3788 .27568 .3789 .27723 .3787 .2762 .37762 Mtetra
.697 .739 .883 r
.2762 .37762 .27723 .3787 .27881 .37825 .2778 .3769 Mtetra
.636 .674 .87 r
.2778 .3769 .27881 .37825 .28041 .37765 .27938 .37645 Mtetra
.609 .691 .901 r
.27938 .37645 .28041 .37765 .28199 .37711 .28095 .37611 Mtetra
.662 .747 .913 r
.28095 .37611 .28199 .37711 .28357 .37678 .28254 .37556 Mtetra
.686 .713 .869 r
.28254 .37556 .28357 .37678 .28513 .37658 .28415 .37487 Mtetra
.668 .638 .811 r
.28415 .37487 .28513 .37658 .28669 .37641 .28575 .37419 Mtetra
.669 .591 .759 r
.28575 .37419 .28669 .37641 .2883 .3757 .28736 .37335 Mtetra
.65 .573 .754 r
.28736 .37335 .2883 .3757 .28991 .37493 .28897 .37264 Mtetra
.589 .544 .772 r
.28897 .37264 .28991 .37493 .29148 .37476 .29054 .37237 Mtetra
0 .097 .642 r
.29054 .37237 .29148 .37476 .29274 .37877 .29195 .37431 Mtetra
.971 .686 .277 r
.29195 .37431 .29274 .37877 .27978 .58038 .29265 .38624 Mtetra
0 0 .202 r
.29265 .38624 .27978 .58038 .28112 .5848 .28031 .57966 Mtetra
.652 .488 .649 r
.28031 .57966 .28112 .5848 .28289 .58326 .28209 .57806 Mtetra
.943 .683 .515 r
.28209 .57806 .28289 .58326 .2853 .57278 .2978 .37982 Mtetra
.554 .329 .528 r
.2978 .37982 .2853 .57278 .30098 .37263 .29998 .37117 Mtetra
.821 .712 .745 r
.29998 .37117 .30098 .37263 .30275 .36972 .3017 .36893 Mtetra
.7 .803 .929 r
.3017 .36893 .30275 .36972 .30437 .3689 .30331 .36822 Mtetra
.581 .801 .983 r
.30331 .36822 .30437 .3689 .30595 .36861 .3049 .36787 Mtetra
.656 .805 .955 r
.3049 .36787 .30595 .36861 .30753 .3684 .30651 .36732 Mtetra
.703 .743 .883 r
.30651 .36732 .30753 .3684 .30912 .36815 .30813 .36656 Mtetra
.68 .658 .821 r
.30813 .36656 .30912 .36815 .3107 .36794 .30975 .36582 Mtetra
.686 .609 .763 r
.30975 .36582 .3107 .36794 .31232 .36721 .31138 .36486 Mtetra
.67 .584 .75 r
.31138 .36486 .31232 .36721 .31395 .3663 .31301 .36397 Mtetra
.602 .549 .768 r
.31301 .36397 .31395 .3663 .31555 .36593 .31461 .36361 Mtetra
0 .118 .658 r
.31461 .36361 .31555 .36593 .31698 .36809 .31606 .36549 Mtetra
.953 .687 .495 r
.31606 .36549 .31698 .36809 .30572 .56663 .30506 .55887 Mtetra
.906 .668 .162 r
.30506 .55887 .30572 .56663 .30682 .57555 .30574 .5743 Mtetra
0 .205 .715 r
.30574 .5743 .30682 .57555 .30841 .57708 .30734 .57555 Mtetra
.755 .703 .803 r
.30734 .57555 .30841 .57708 .31011 .57674 .30911 .57419 Mtetra
.77 .631 .707 r
.30911 .57419 .31011 .57674 .31185 .57588 .31095 .5718 Mtetra
.697 .538 .669 r
.31095 .5718 .31185 .57588 .31359 .57507 .31276 .56977 Mtetra
.599 .449 .649 r
.31276 .56977 .31359 .57507 .31532 .57447 .3145 .56904 Mtetra
.577 .432 .647 r
.3145 .56904 .31532 .57447 .31704 .57385 .31621 .56862 Mtetra
.58 .437 .651 r
.31621 .56862 .31704 .57385 .31877 .57327 .31793 .56817 Mtetra
.589 .446 .654 r
.31793 .56817 .31877 .57327 .3205 .57271 .31965 .56761 Mtetra
.588 .445 .655 r
.31965 .56761 .3205 .57271 .32222 .57217 .32138 .56708 Mtetra
.586 .444 .655 r
.32138 .56708 .32222 .57217 .32395 .57164 .3231 .56656 Mtetra
.585 .443 .655 r
.3231 .56656 .32395 .57164 .32568 .57112 .32482 .56607 Mtetra
.586 .444 .656 r
.32482 .56607 .32568 .57112 .32741 .5706 .32655 .56556 Mtetra
.555 .424 .657 r
.32655 .56556 .32741 .5706 .32912 .57031 .32825 .56546 Mtetra
.548 .422 .661 r
.32825 .56546 .32912 .57031 .33083 .57009 .32995 .56545 Mtetra
.616 .473 .665 r
.32995 .56545 .33083 .57009 .33258 .56934 .33171 .56458 Mtetra
.773 .576 .632 r
.33171 .56458 .33258 .56934 .33444 .56661 .33368 .55984 Mtetra
.946 .682 .504 r
.33368 .55984 .33444 .56661 .33681 .55467 .34664 .35885 Mtetra
.547 .323 .527 r
.34664 .35885 .33681 .55467 .34945 .35631 .34855 .35318 Mtetra
.737 .583 .684 r
.34855 .35318 .34945 .35631 .35123 .35316 .35028 .35097 Mtetra
.658 .591 .768 r
.35028 .35097 .35123 .35316 .35287 .35233 .35192 .35022 Mtetra
.608 .573 .789 r
.35192 .35022 .35287 .35233 .35449 .35205 .35354 .34985 Mtetra
.614 .567 .778 r
.35354 .34985 .35449 .35205 .35611 .35181 .35517 .34942 Mtetra
.643 .569 .756 r
.35517 .34942 .35611 .35181 .35774 .3513 .35681 .34876 Mtetra
.636 .554 .746 r
.35681 .34876 .35774 .3513 .35937 .35075 .35845 .34811 Mtetra
.624 .542 .742 r
.35845 .34811 .35937 .35075 .36102 .35001 .36009 .34755 Mtetra
.614 .548 .756 r
.36009 .34755 .36102 .35001 .36268 .3491 .36172 .34709 Mtetra
.62 .588 .796 r
.36172 .34709 .36268 .3491 .36433 .34819 .36335 .34665 Mtetra
.647 .654 .843 r
.36335 .34665 .36433 .34819 .36598 .34741 .36499 .34611 Mtetra
.676 .701 .866 r
.36499 .34611 .36598 .34741 .36763 .34681 .36663 .34545 Mtetra
.653 .686 .868 r
.36663 .34545 .36763 .34681 .36927 .34626 .36828 .34491 Mtetra
.598 .665 .886 r
.36828 .34491 .36927 .34626 .37092 .34555 .36991 .3446 Mtetra
.408 .664 .965 r
.36991 .3446 .37092 .34555 .37257 .3447 .37152 .34471 Mtetra
.513 0 0 r
.37152 .34471 .37257 .3447 .37421 .34427 .3731 .34548 Mtetra
.804 .423 .334 r
.3731 .34548 .37421 .34427 .37578 .34524 .37457 .34867 Mtetra
.951 .679 .485 r
.37457 .34867 .37578 .34524 .3771 .35168 .36679 .54921 Mtetra
.545 .317 .52 r
.36679 .54921 .3771 .35168 .36945 .55324 .36824 .55523 Mtetra
.674 .288 .308 r
.36824 .55523 .36945 .55324 .37104 .55639 .36989 .55689 Mtetra
.159 0 0 r
.36989 .55689 .37104 .55639 .37278 .55622 .37164 .55675 Mtetra
0 0 0 r
.37164 .55675 .37278 .55622 .37455 .55541 .3734 .55612 Mtetra
.3734 .55612 .37455 .55541 .37632 .55466 .37517 .55539 Mtetra
.37517 .55539 .37632 .55466 .37806 .55453 .37694 .55483 Mtetra
.372 .834 .771 r
.37694 .55483 .37806 .55453 .37981 .55439 .37871 .55411 Mtetra
.75 .938 .947 r
.37871 .55411 .37981 .55439 .38156 .55412 .3805 .55303 Mtetra
.813 .778 .821 r
.3805 .55303 .38156 .55412 .38333 .55366 .38231 .55134 Mtetra
.76 .641 .73 r
.38231 .55134 .38333 .55366 .38509 .55312 .38414 .54936 Mtetra
.678 .536 .685 r
.38414 .54936 .38509 .55312 .38686 .5527 .38595 .54781 Mtetra
.558 .43 .662 r
.38595 .54781 .38686 .5527 .38861 .55249 .3877 .54767 Mtetra
.589 .452 .663 r
.3877 .54767 .38861 .55249 .39039 .55184 .38947 .54715 Mtetra
.712 .536 .65 r
.38947 .54715 .39039 .55184 .39221 .54988 .39132 .54445 Mtetra
.954 .685 .489 r
.39132 .54445 .39221 .54988 .39423 .54306 .40092 .34393 Mtetra
.553 .328 .528 r
.40092 .34393 .39423 .54306 .40378 .33946 .40291 .33526 Mtetra
.731 .553 .65 r
.40291 .33526 .40378 .33946 .40561 .33464 .40466 .33241 Mtetra
.658 .59 .767 r
.40466 .33241 .40561 .33464 .4073 .33328 .40633 .33164 Mtetra
.595 .621 .848 r
.40633 .33164 .4073 .33328 .40897 .33256 .40799 .33136 Mtetra
.555 .676 .919 r
.40799 .33136 .40897 .33256 .41064 .33208 .40964 .33118 Mtetra
.649 .776 .941 r
.40964 .33118 .41064 .33208 .41231 .33149 .41131 .33065 Mtetra
.659 .792 .946 r
.41131 .33065 .41231 .33149 .41397 .33096 .41298 .33007 Mtetra
.683 .787 .929 r
.41298 .33007 .41397 .33096 .41564 .33046 .41465 .32941 Mtetra
.714 .761 .89 r
.41465 .32941 .41564 .33046 .41731 .3299 .41633 .32858 Mtetra
.683 .704 .863 r
.41633 .32858 .41731 .3299 .41898 .32934 .41801 .32787 Mtetra
.615 .655 .866 r
.41801 .32787 .41898 .32934 .42066 .32874 .41968 .32748 Mtetra
.349 .564 .918 r
.41968 .32748 .42066 .32874 .42234 .3281 .42132 .32785 Mtetra
.378 0 0 r
.42132 .32785 .42234 .3281 .42401 .32745 .42296 .32856 Mtetra
.539 .075 .102 r
.42296 .32856 .42401 .32745 .4257 .32672 .4246 .3291 Mtetra
.259 0 .146 r
.4246 .3291 .4257 .32672 .42739 .32572 .4263 .32807 Mtetra
.333 0 .178 r
.4263 .32807 .42739 .32572 .42907 .32512 .42798 .32736 Mtetra
.596 .216 .293 r
.42798 .32736 .42907 .32512 .43072 .32553 .42962 .32825 Mtetra
.957 .679 .468 r
.42962 .32825 .43072 .32553 .43224 .33039 .42539 .52671 Mtetra
.551 .322 .521 r
.42539 .52671 .43224 .33039 .42804 .5336 .42689 .53607 Mtetra
.706 .339 .351 r
.42689 .53607 .42804 .5336 .42969 .53805 .4286 .53843 Mtetra
.089 0 0 r
.4286 .53843 .42969 .53805 .43147 .53806 .43039 .53826 Mtetra
.4 .855 .817 r
.43039 .53826 .43147 .53806 .43328 .5373 .4322 .53756 Mtetra
.472 .892 .813 r
.4322 .53756 .43328 .5373 .43509 .53622 .43401 .53669 Mtetra
0 0 0 r
.43401 .53669 .43509 .53622 .4369 .53557 .43581 .53623 Mtetra
.034 0 0 r
.43581 .53623 .4369 .53557 .4387 .53495 .43761 .53575 Mtetra
.06 0 0 r
.43761 .53575 .4387 .53495 .4405 .53447 .43941 .53521 Mtetra
0 0 0 r
.43941 .53521 .4405 .53447 .4423 .5343 .44122 .53451 Mtetra
.406 .857 .808 r
.44122 .53451 .4423 .5343 .44409 .53414 .44303 .53378 Mtetra
.637 .908 .982 r
.44303 .53378 .44409 .53414 .44589 .5339 .44484 .53306 Mtetra
.655 .806 .956 r
.44484 .53306 .44589 .5339 .4477 .53343 .44666 .53244 Mtetra
.651 .773 .938 r
.44666 .53244 .4477 .53343 .44951 .53284 .44847 .53185 Mtetra
.646 .773 .941 r
.44847 .53185 .44951 .53284 .45132 .53211 .45028 .53128 Mtetra
.638 .806 .964 r
.45028 .53128 .45132 .53211 .45314 .53115 .45209 .53072 Mtetra
.578 .878 .993 r
.45209 .53072 .45314 .53115 .45497 .53012 .45391 .53017 Mtetra
.375 .841 .863 r
.45391 .53017 .45497 .53012 .45679 .52916 .45572 .52963 Mtetra
0 0 0 r
.45572 .52963 .45679 .52916 .45861 .52857 .45754 .52909 Mtetra
.45754 .52909 .45861 .52857 .46042 .52809 .45935 .52856 Mtetra
.45935 .52856 .46042 .52809 .46224 .52768 .46117 .52805 Mtetra
.101 0 0 r
.46117 .52805 .46224 .52768 .46404 .52771 .46299 .5279 Mtetra
.228 .745 .744 r
.46299 .5279 .46404 .52771 .46586 .52726 .46481 .52743 Mtetra
.64 .966 .868 r
.46481 .52743 .46586 .52726 .4677 .52584 .46664 .52629 Mtetra
.976 .917 .667 r
.46664 .52629 .4677 .52584 .46964 .51826 .46852 .52229 Mtetra
.991 .797 .413 r
.46852 .52229 .46964 .51826 .47472 .31395 .4706 .50595 Mtetra
0 0 .294 r
.4706 .50595 .47472 .31395 .47649 .30911 .47548 .31138 Mtetra
0 0 0 r
.47548 .31138 .47649 .30911 .47821 .30801 .47722 .30865 Mtetra
.644 .935 .678 r
.47722 .30865 .47821 .30801 .47992 .30756 .47895 .30704 Mtetra
.763 .893 .935 r
.47895 .30704 .47992 .30756 .48162 .30746 .48067 .30599 Mtetra
.657 .677 .858 r
.48067 .30599 .48162 .30746 .48334 .30692 .48238 .30539 Mtetra
.615 .649 .861 r
.48238 .30539 .48334 .30692 .48505 .30638 .48409 .305 Mtetra
.595 .666 .888 r
.48409 .305 .48505 .30638 .48676 .3058 .48581 .3047 Mtetra
.659 .742 .911 r
.48581 .3047 .48676 .3058 .48848 .30506 .48752 .30412 Mtetra
.675 .779 .928 r
.48752 .30412 .48848 .30506 .4902 .30434 .48924 .30347 Mtetra
.688 .799 .934 r
.48924 .30347 .4902 .30434 .49192 .30369 .49096 .30276 Mtetra
.772 .804 .879 r
.49096 .30276 .49192 .30369 .49364 .3029 .49269 .3016 Mtetra
.711 .723 .859 r
.49269 .3016 .49364 .3029 .49536 .30248 .49441 .30072 Mtetra
.604 .613 .834 r
.49441 .30072 .49536 .30248 .49707 .30279 .49613 .30038 Mtetra
0 .147 .674 r
.49613 .30038 .49707 .30279 .49875 .30791 .49783 .30249 Mtetra
0 0 .152 r
.49783 .30249 .49875 .30791 .49888 .51194 .49948 .31172 Mtetra
0 0 .324 r
.49948 .31172 .49888 .51194 .50069 .51652 .4997 .51124 Mtetra
.349 .282 .639 r
.4997 .51124 .50069 .51652 .50253 .51672 .50152 .51328 Mtetra
.47 .421 .721 r
.50152 .51328 .50253 .51672 .50437 .51607 .50336 .51386 Mtetra
.545 .549 .81 r
.50336 .51386 .50437 .51607 .50622 .51502 .50521 .51382 Mtetra
.477 .664 .945 r
.50521 .51382 .50622 .51502 .50807 .51494 .50705 .51384 Mtetra
.615 .742 .936 r
.50705 .51384 .50807 .51494 .50992 .51458 .5089 .51339 Mtetra
.746 .767 .87 r
.5089 .51339 .50992 .51458 .51177 .51345 .51076 .51226 Mtetra
.904 .773 .705 r
.51076 .51226 .51177 .51345 .51364 .50797 .51262 .50859 Mtetra
.992 .778 .513 r
.51262 .50859 .51364 .50797 .51608 .30144 .51451 .49655 Mtetra
0 0 .313 r
.51451 .49655 .51608 .30144 .51783 .29492 .51687 .29755 Mtetra
0 0 0 r
.51687 .29755 .51783 .29492 .51956 .29347 .51862 .29459 Mtetra
.51862 .29459 .51956 .29347 .5213 .29298 .52036 .29298 Mtetra
.685 .975 .909 r
.52036 .29298 .5213 .29298 .52304 .2929 .52209 .29192 Mtetra
.701 .781 .914 r
.52209 .29192 .52304 .2929 .52478 .29241 .52384 .29114 Mtetra
.658 .713 .889 r
.52384 .29114 .52478 .29241 .52652 .29182 .52558 .29055 Mtetra
.638 .705 .895 r
.52558 .29055 .52652 .29182 .52826 .2912 .52732 .29005 Mtetra
.747 .763 .866 r
.52732 .29005 .52826 .2912 .53 .29007 .52906 .28898 Mtetra
.712 .764 .893 r
.52906 .28898 .53 .29007 .53174 .28918 .5308 .28813 Mtetra
.544 .711 .949 r
.5308 .28813 .53174 .28918 .53349 .28895 .53255 .28794 Mtetra
.816 .364 0 r
.53255 .28794 .53349 .28895 .53525 .29227 .53431 .29135 Mtetra
.97 .682 .426 r
.53431 .29135 .53525 .29227 .5378 .49742 .5368 .4966 Mtetra
.925 .535 .19 r
.5368 .4966 .5378 .49742 .5397 .50414 .53869 .50308 Mtetra
0 .343 .809 r
.53869 .50308 .5397 .50414 .54158 .50522 .54057 .50415 Mtetra
.593 .743 .948 r
.54057 .50415 .54158 .50522 .54345 .50484 .54245 .50376 Mtetra
.795 .798 .855 r
.54245 .50376 .54345 .50484 .54532 .50338 .54432 .5023 Mtetra
.934 .777 .663 r
.54432 .5023 .54532 .50338 .54717 .49865 .54617 .49755 Mtetra
.971 .689 .436 r
.54617 .49755 .54717 .49865 .54755 .29262 .54661 .29144 Mtetra
.954 .742 .577 r
.54661 .29144 .54755 .29262 .54925 .28445 .54832 .2833 Mtetra
.832 .78 .802 r
.54832 .2833 .54925 .28445 .551 .28259 .55006 .28145 Mtetra
.666 .741 .906 r
.55006 .28145 .551 .28259 .55275 .28196 .55182 .28082 Mtetra
.551 .695 .935 r
.55182 .28082 .55275 .28196 .55451 .28177 .55358 .28063 Mtetra
.719 .758 .884 r
.55358 .28063 .55451 .28177 .55627 .28087 .55534 .27973 Mtetra
.711 .756 .887 r
.55534 .27973 .55627 .28087 .55803 .28001 .5571 .27887 Mtetra
.566 .702 .933 r
.5571 .27887 .55803 .28001 .55979 .27977 .55886 .27863 Mtetra
.704 .245 0 r
.55886 .27863 .55979 .27977 .5616 .28266 .56067 .2815 Mtetra
.972 .681 .415 r
.56067 .2815 .5616 .28266 .56591 .48734 .56492 .48616 Mtetra
.932 .556 .181 r
.56492 .48616 .56591 .48734 .5679 .495 .56691 .49389 Mtetra
0 .297 .78 r
.56691 .49389 .5679 .495 .56981 .4963 .56882 .49511 Mtetra
.595 .721 .932 r
.56882 .49511 .56981 .4963 .57171 .49598 .57072 .49473 Mtetra
.769 .769 .853 r
.57072 .49473 .57171 .49598 .57359 .49456 .5726 .49341 Mtetra
.9 .789 .73 r
.5726 .49341 .57359 .49456 .57543 .49005 .57446 .49021 Mtetra
.993 .804 .545 r
.57446 .49021 .57543 .49005 .57407 .28388 .57624 .48183 Mtetra
0 0 .337 r
.57624 .48183 .57407 .28388 .57571 .27524 .57486 .27831 Mtetra
0 0 .011 r
.57486 .27831 .57571 .27524 .57746 .27321 .57658 .27452 Mtetra
0 0 0 r
.57658 .27452 .57746 .27321 .57924 .2726 .57834 .27277 Mtetra
.628 .961 .839 r
.57834 .27277 .57924 .2726 .58102 .27245 .58011 .27162 Mtetra
.709 .823 .936 r
.58011 .27162 .58102 .27245 .5828 .27207 .58188 .2708 Mtetra
.662 .719 .891 r
.58188 .2708 .5828 .27207 .58458 .27148 .58366 .27018 Mtetra
.638 .704 .894 r
.58366 .27018 .58458 .27148 .58636 .27086 .58544 .26967 Mtetra
.727 .755 .875 r
.58544 .26967 .58636 .27086 .58813 .26982 .58721 .2687 Mtetra
.726 .769 .887 r
.58721 .2687 .58813 .26982 .5899 .26883 .58899 .26776 Mtetra
.593 .73 .94 r
.58899 .26776 .5899 .26883 .59169 .26844 .59077 .26741 Mtetra
.609 .13 0 r
.59077 .26741 .59169 .26844 .59353 .27072 .59262 .26977 Mtetra
.973 .679 .402 r
.59262 .26977 .59353 .27072 .59996 .47393 .59901 .47352 Mtetra
.94 .573 .262 r
.59901 .47352 .59996 .47393 .60212 .48397 .60114 .48293 Mtetra
0 .132 .637 r
.60114 .48293 .60212 .48397 .60408 .48565 .60311 .48457 Mtetra
.533 .719 .959 r
.60311 .48457 .60408 .48565 .60601 .48546 .60504 .48437 Mtetra
.768 .8 .878 r
.60504 .48437 .60601 .48546 .60791 .4842 .60694 .48311 Mtetra
.924 .795 .699 r
.60694 .48311 .60791 .4842 .60975 .48038 .60878 .4793 Mtetra
.975 .687 .413 r
.60878 .4793 .60975 .48038 .60638 .27862 .60547 .27771 Mtetra
.976 .731 .501 r
.60547 .27771 .60638 .27862 .60782 .26472 .60692 .26358 Mtetra
.878 .789 .758 r
.60692 .26358 .60782 .26472 .60957 .2622 .60866 .26106 Mtetra
.686 .753 .903 r
.60866 .26106 .60957 .2622 .61136 .26146 .61045 .26033 Mtetra
.559 .704 .937 r
.61045 .26033 .61136 .26146 .61316 .26123 .61226 .2601 Mtetra
.664 .748 .913 r
.61226 .2601 .61316 .26123 .61496 .26052 .61406 .25947 Mtetra
.715 .78 .903 r
.61406 .25947 .61496 .26052 .61675 .25959 .61585 .25859 Mtetra
.614 .758 .948 r
.61585 .25859 .61675 .25959 .61855 .25922 .61765 .25815 Mtetra
0 .319 .8 r
.61765 .25815 .61855 .25922 .62044 .26126 .61951 .2593 Mtetra
.783 .411 0 r
.61951 .2593 .62044 .26126 .62865 .46372 .6215 .26469 Mtetra
0 0 .369 r
.6215 .26469 .62865 .46372 .63095 .47475 .62983 .46857 Mtetra
.232 .189 .602 r
.62983 .46857 .63095 .47475 .63296 .47631 .6319 .47227 Mtetra
.459 .393 .697 r
.6319 .47227 .63296 .47631 .6349 .47583 .63388 .47309 Mtetra
.53 .503 .77 r
.63388 .47309 .6349 .47583 .63682 .47478 .63584 .47318 Mtetra
.516 .615 .89 r
.63584 .47318 .63682 .47478 .63876 .47418 .6378 .47318 Mtetra
.527 .738 .972 r
.6378 .47318 .63876 .47418 .64071 .47391 .63976 .47297 Mtetra
.718 .821 .929 r
.63976 .47297 .64071 .47391 .64264 .47305 .64169 .47203 Mtetra
.919 .813 .725 r
.64169 .47203 .64264 .47305 .64448 .46977 .64353 .46869 Mtetra
.976 .685 .399 r
.64353 .46869 .64448 .46977 .63917 .27254 .63831 .27253 Mtetra
.987 .731 .447 r
.63831 .27253 .63917 .27254 .6403 .25353 .63941 .25237 Mtetra
.895 .79 .737 r
.63941 .25237 .6403 .25353 .64203 .25069 .64114 .24952 Mtetra
.703 .756 .894 r
.64114 .24952 .64203 .25069 .64384 .24987 .64295 .24869 Mtetra
.586 .71 .929 r
.64295 .24869 .64384 .24987 .64567 .24955 .64478 .24837 Mtetra
.665 .742 .908 r
.64478 .24837 .64567 .24955 .64749 .2489 .6466 .24773 Mtetra
.733 .765 .879 r
.6466 .24773 .64749 .2489 .64929 .2479 .6484 .24672 Mtetra
.636 .731 .917 r
.6484 .24672 .64929 .2479 .65112 .24738 .65023 .24621 Mtetra
0 .282 .78 r
.65023 .24621 .65112 .24738 .65302 .24871 .65213 .24753 Mtetra
.938 .574 .185 r
.65213 .24753 .65302 .24871 .65528 .25854 .65439 .25737 Mtetra
.975 .675 .374 r
.65439 .25737 .65528 .25854 .66589 .46225 .66494 .46113 Mtetra
0 0 .512 r
.66494 .46113 .66589 .46225 .66797 .46453 .66703 .46341 Mtetra
.629 .756 .938 r
.66703 .46341 .66797 .46453 .66993 .46399 .66899 .46287 Mtetra
.769 .8 .878 r
.66899 .46287 .66993 .46399 .67186 .46271 .67092 .46158 Mtetra
.782 .803 .87 r
.67092 .46158 .67186 .46271 .67379 .46133 .67285 .4602 Mtetra
.73 .79 .9 r
.67285 .4602 .67379 .46133 .67573 .4603 .6748 .45917 Mtetra
.716 .786 .907 r
.6748 .45917 .67573 .4603 .67768 .45935 .67674 .45822 Mtetra
.655 .765 .93 r
.67674 .45822 .67768 .45935 .67965 .4587 .67871 .45757 Mtetra
.563 .727 .951 r
.67871 .45757 .67965 .4587 .68163 .45841 .68069 .45728 Mtetra
.534 .713 .954 r
.68069 .45728 .68163 .45841 .68362 .45821 .68268 .45708 Mtetra
.443 .667 .958 r
.68268 .45708 .68362 .45821 .68562 .45828 .68468 .45715 Mtetra
.415 .652 .956 r
.68468 .45715 .68562 .45828 .68763 .45843 .68669 .4573 Mtetra
.628 .755 .938 r
.68669 .4573 .68763 .45843 .68961 .45789 .68867 .45676 Mtetra
.89 .812 .765 r
.68867 .45676 .68961 .45789 .69147 .4552 .69054 .45406 Mtetra
.981 .723 .466 r
.69054 .45406 .69147 .4552 .69257 .43745 .69164 .43625 Mtetra
.977 .681 .379 r
.69164 .43625 .69257 .43745 .68421 .23854 .68334 .23735 Mtetra
.912 .79 .713 r
.68334 .23735 .68421 .23854 .68592 .2353 .68505 .2341 Mtetra
.709 .758 .891 r
.68505 .2341 .68592 .2353 .68775 .23442 .68688 .23323 Mtetra
.588 .709 .927 r
.68688 .23323 .68775 .23442 .68961 .23409 .68874 .23289 Mtetra
.624 .725 .919 r
.68874 .23289 .68961 .23409 .69147 .23362 .6906 .23242 Mtetra
.732 .765 .879 r
.6906 .23242 .69147 .23362 .6933 .23261 .69243 .23141 Mtetra
.641 .731 .914 r
.69243 .23141 .6933 .23261 .69515 .23206 .69428 .23086 Mtetra
.074 .405 .858 r
.69428 .23086 .69515 .23206 .69709 .23308 .69622 .23187 Mtetra
.921 .547 .128 r
.69622 .23187 .69709 .23308 .6995 .24224 .69863 .24093 Mtetra
.975 .671 .352 r
.69863 .24093 .6995 .24224 .71323 .4477 .71231 .44652 Mtetra
.6 .141 0 r
.71231 .44652 .71323 .4477 .71543 .45068 .71451 .44952 Mtetra
.42 .65 .954 r
.71451 .44952 .71543 .45068 .71747 .45082 .71655 .44967 Mtetra
.715 .785 .907 r
.71655 .44967 .71747 .45082 .71945 .44988 .71853 .44871 Mtetra
.894 .812 .76 r
.71853 .44871 .71945 .44988 .72132 .4472 .7204 .44595 Mtetra
.978 .744 .515 r
.7204 .44595 .72132 .4472 .72278 .43772 .72178 .43512 Mtetra
.977 .678 .368 r
.72178 .43512 .72278 .43772 .71206 .22989 .71117 .22811 Mtetra
.89 .731 .679 r
.71117 .22811 .71206 .22989 .71372 .22593 .71284 .22437 Mtetra
.688 .691 .848 r
.71284 .22437 .71372 .22593 .71557 .22499 .71469 .22353 Mtetra
.565 .65 .893 r
.71469 .22353 .71557 .22499 .71745 .22467 .71658 .22332 Mtetra
.526 .65 .913 r
.71658 .22332 .71745 .22467 .71935 .2245 .71848 .22324 Mtetra
.649 .726 .905 r
.71848 .22324 .71935 .2245 .72121 .22389 .72035 .22266 Mtetra
.659 .734 .906 r
.72035 .22266 .72121 .22389 .72308 .22326 .72222 .22202 Mtetra
.697 .75 .892 r
.72222 .22202 .72308 .22326 .72494 .22244 .72408 .2212 Mtetra
.751 .768 .867 r
.72408 .2212 .72494 .22244 .72678 .22128 .72592 .22005 Mtetra
.669 .74 .903 r
.72592 .22005 .72678 .22128 .72864 .22059 .72779 .21937 Mtetra
.243 .513 .908 r
.72779 .21937 .72864 .22059 .7306 .22125 .72975 .22003 Mtetra
.893 .506 .058 r
.72975 .22003 .7306 .22125 .73306 .22913 .7322 .22787 Mtetra
.975 .667 .334 r
.7322 .22787 .73306 .22913 .74923 .43609 .74833 .43492 Mtetra
.636 .182 0 r
.74833 .43492 .74923 .43609 .75153 .43945 .75062 .43829 Mtetra
.39 .635 .952 r
.75062 .43829 .75153 .43945 .7536 .43968 .7527 .43852 Mtetra
.694 .78 .918 r
.7527 .43852 .7536 .43968 .75561 .43882 .75471 .43766 Mtetra
.873 .82 .793 r
.75471 .43766 .75561 .43882 .75751 .43647 .75661 .43531 Mtetra
.978 .768 .553 r
.75661 .43531 .75751 .43647 .75901 .42858 .75811 .42742 Mtetra
.977 .675 .347 r
.75811 .42742 .75901 .42858 .74584 .21887 .74499 .21766 Mtetra
.951 .785 .64 r
.74499 .21766 .74584 .21887 .74743 .21419 .74658 .21298 Mtetra
.747 .773 .874 r
.74658 .21298 .74743 .21419 .74928 .21307 .74843 .21186 Mtetra
.62 .724 .921 r
.74843 .21186 .74928 .21307 .75118 .2126 .75033 .21139 Mtetra
.588 .71 .928 r
.75033 .21139 .75118 .2126 .75309 .21226 .75225 .21105 Mtetra
.75 .775 .874 r
.75225 .21105 .75309 .21226 .75494 .21112 .7541 .20991 Mtetra
.675 .748 .906 r
.7541 .20991 .75494 .21112 .75682 .2104 .75598 .2092 Mtetra
.368 .593 .932 r
.75598 .2092 .75682 .2104 .75879 .21074 .75795 .20954 Mtetra
.819 .407 0 r
.75795 .20954 .75879 .21074 .76117 .21633 .76033 .2152 Mtetra
.973 .663 .319 r
.76033 .2152 .76117 .21633 .7795 .42524 .77861 .42415 Mtetra
.72 .271 0 r
.77861 .42415 .7795 .42524 .78191 .42938 .78102 .42825 Mtetra
.503 .703 .96 r
.78102 .42825 .78191 .42938 .78399 .42927 .78311 .42813 Mtetra
.696 .788 .921 r
.78311 .42813 .78399 .42927 .78601 .42841 .78513 .42726 Mtetra
.737 .801 .903 r
.78513 .42726 .78601 .42841 .78802 .42732 .78714 .42617 Mtetra
.499 .698 .958 r
.78714 .42617 .78802 .42732 .79011 .42723 .78922 .42607 Mtetra
.627 .758 .941 r
.78922 .42607 .79011 .42723 .79216 .42667 .79128 .42551 Mtetra
.812 .818 .855 r
.79128 .42551 .79216 .42667 .79412 .42503 .79324 .42387 Mtetra
.98 .773 .554 r
.79324 .42387 .79412 .42503 .79559 .41747 .79472 .41633 Mtetra
.976 .671 .329 r
.79472 .41633 .79559 .41747 .77999 .20723 .77916 .20601 Mtetra
.96 .785 .621 r
.77916 .20601 .77999 .20723 .78153 .20219 .7807 .20096 Mtetra
.752 .776 .872 r
.7807 .20096 .78153 .20219 .78339 .20103 .78256 .1998 Mtetra
.623 .725 .92 r
.78256 .1998 .78339 .20103 .78531 .20055 .78449 .19931 Mtetra
.553 .691 .931 r
.78449 .19931 .78531 .20055 .78726 .20033 .78644 .1991 Mtetra
.747 .774 .875 r
.78644 .1991 .78726 .20033 .78913 .19921 .78831 .19797 Mtetra
.678 .748 .904 r
.78831 .19797 .78913 .19921 .79104 .19847 .79021 .19723 Mtetra
.456 .639 .935 r
.79021 .19723 .79104 .19847 .79302 .19858 .7922 .19734 Mtetra
.768 .353 0 r
.7922 .19734 .79302 .19858 .79546 .20378 .79463 .20254 Mtetra
.971 .657 .298 r
.79463 .20254 .79546 .20378 .81633 .41353 .81546 .41235 Mtetra
.726 .292 0 r
.81546 .41235 .81633 .41353 .81887 .41818 .818 .417 Mtetra
.307 .58 .938 r
.818 .417 .81887 .41818 .82104 .41866 .82017 .41747 Mtetra
.65 .763 .932 r
.82017 .41747 .82104 .41866 .82311 .418 .82224 .41681 Mtetra
.83 .82 .84 r
.82224 .41681 .82311 .418 .82507 .41618 .8242 .41499 Mtetra
.975 .788 .589 r
.8242 .41499 .82507 .41618 .82663 .41004 .82576 .40883 Mtetra
.974 .667 .312 r
.82576 .40883 .82663 .41004 .80891 .1989 .80809 .19763 Mtetra
.973 .773 .573 r
.80809 .19763 .80891 .1989 .8103 .19257 .80948 .19132 Mtetra
.759 .756 .849 r
.19075 .40669 .19182 .4077 .19341 .40662 .19234 .40561 Mtetra
.613 .725 .925 r
.19234 .40561 .19341 .40662 .19493 .40626 .19386 .40525 Mtetra
.459 .667 .953 r
.19386 .40525 .19493 .40626 .19641 .4063 .19534 .40529 Mtetra
.654 .736 .91 r
.19534 .40529 .19641 .4063 .19795 .40579 .19688 .40478 Mtetra
.663 .738 .906 r
.19688 .40478 .19795 .40579 .19949 .40526 .19842 .40425 Mtetra
.669 .74 .904 r
.19842 .40425 .19949 .40526 .20103 .40469 .19997 .40368 Mtetra
.761 .756 .848 r
.19997 .40368 .20103 .40469 .20263 .40359 .20157 .40258 Mtetra
.708 .749 .884 r
.20157 .40258 .20263 .40359 .2042 .40283 .20313 .40182 Mtetra
.497 .683 .95 r
.20313 .40182 .2042 .40283 .20569 .40279 .20463 .40178 Mtetra
.932 .561 .275 r
.20463 .40178 .20569 .40279 .20675 .40719 .20569 .40616 Mtetra
.939 .683 .523 r
.20569 .40616 .20675 .40719 .18865 .60702 .18751 .60605 Mtetra
.933 .572 .306 r
.18751 .60605 .18865 .60702 .18975 .61206 .18861 .6111 Mtetra
0 .387 .826 r
.18861 .6111 .18975 .61206 .19127 .61279 .19013 .61184 Mtetra
.628 .755 .938 r
.19013 .61184 .19127 .61279 .19291 .61235 .19177 .61139 Mtetra
.803 .778 .83 r
.19177 .61139 .19291 .61235 .19465 .61084 .19351 .60988 Mtetra
.906 .741 .666 r
.19351 .60988 .19465 .61084 .19675 .60567 .19561 .60467 Mtetra
.939 .687 .53 r
.19561 .60467 .19675 .60567 .21748 .40477 .21643 .40366 Mtetra
.91 .721 .636 r
.21643 .40366 .21748 .40477 .21961 .39812 .21856 .39708 Mtetra
.789 .755 .822 r
.21856 .39708 .21961 .39812 .22125 .39673 .22019 .3957 Mtetra
.637 .729 .915 r
.22019 .3957 .22125 .39673 .22279 .39629 .22173 .39526 Mtetra
.496 .681 .948 r
.22173 .39526 .22279 .39629 .2243 .39624 .22324 .39522 Mtetra
.642 .734 .915 r
.22324 .39522 .2243 .39624 .22585 .39576 .22479 .39476 Mtetra
.67 .744 .906 r
.22479 .39476 .22585 .39576 .22741 .39518 .22635 .39419 Mtetra
.683 .75 .902 r
.22635 .39419 .22741 .39518 .22898 .39454 .22792 .39356 Mtetra
.775 .764 .843 r
.22792 .39356 .22898 .39454 .2306 .39336 .22954 .39235 Mtetra
.742 .756 .864 r
.22954 .39235 .2306 .39336 .23219 .39243 .23114 .39139 Mtetra
.607 .718 .923 r
.23114 .39139 .23219 .39243 .23373 .39212 .23268 .39105 Mtetra
.869 .43 .044 r
.23268 .39105 .23373 .39212 .23499 .39493 .23394 .39384 Mtetra
.942 .684 .516 r
.23394 .39384 .23499 .39493 .21874 .59309 .21762 .59207 Mtetra
.946 .626 .396 r
.21762 .59207 .21874 .59309 .21959 .60165 .21845 .60074 Mtetra
0 .389 .822 r
.21845 .60074 .21959 .60165 .22114 .60237 .22001 .60146 Mtetra
.673 .779 .93 r
.22001 .60146 .22114 .60237 .22282 .60174 .22168 .60084 Mtetra
.769 .792 .872 r
.22168 .60084 .22282 .60174 .22454 .60059 .2234 .59968 Mtetra
.627 .767 .947 r
.2234 .59968 .22454 .60059 .22621 .6 .22506 .59922 Mtetra
.618 .796 .967 r
.22506 .59922 .22621 .6 .22787 .5995 .22672 .59877 Mtetra
.734 .827 .922 r
.22672 .59877 .22787 .5995 .22955 .59882 .22842 .59787 Mtetra
.889 .761 .715 r
.22842 .59787 .22955 .59882 .23131 .59725 .23035 .59437 Mtetra
.885 .668 .604 r
.23035 .59437 .23131 .59725 .23311 .5952 .23285 .58413 Mtetra
.93 .674 .529 r
.23285 .58413 .23311 .5952 .2349 .5933 .25084 .39204 Mtetra
.509 .291 .519 r
.25084 .39204 .2349 .5933 .23646 .59406 .25146 .4029 Mtetra
0 0 .178 r
.25146 .4029 .23646 .59406 .23797 .59547 .23707 .59172 Mtetra
0 0 .441 r
.23707 .59172 .23797 .59547 .23951 .5965 .2384 .59534 Mtetra
.104 .457 .887 r
.2384 .59534 .23951 .5965 .24113 .59662 .23998 .59601 Mtetra
.498 .795 .998 r
.23998 .59601 .24113 .59662 .24279 .59634 .24163 .59577 Mtetra
.637 .848 .981 r
.24163 .59577 .24279 .59634 .24446 .59588 .24331 .59521 Mtetra
.606 .816 .981 r
.24331 .59521 .24446 .59588 .24612 .59562 .24498 .59476 Mtetra
.652 .785 .945 r
.24498 .59476 .24612 .59562 .24779 .5952 .24667 .59421 Mtetra
.72 .773 .894 r
.24667 .59421 .24779 .5952 .2495 .59426 .24838 .59334 Mtetra
.814 .79 .829 r
.24838 .59334 .2495 .59426 .25137 .59141 .25015 .59173 Mtetra
.932 .943 .778 r
.25015 .59173 .25137 .59141 .2536 .58406 .252 .58912 Mtetra
0 0 .024 r
.252 .58912 .2536 .58406 .27102 .38468 .25402 .58434 Mtetra
0 0 .181 r
.25402 .58434 .27102 .38468 .27288 .38065 .27125 .38705 Mtetra
0 0 0 r
.27125 .38705 .27288 .38065 .27457 .3788 .27337 .37979 Mtetra
.933 .966 .684 r
.27337 .37979 .27457 .3788 .2762 .37762 .27515 .37679 Mtetra
.785 .8 .864 r
.27515 .37679 .2762 .37762 .2778 .3769 .27678 .37558 Mtetra
.632 .678 .875 r
.27678 .37558 .2778 .3769 .27938 .37645 .27836 .37515 Mtetra
.563 .654 .897 r
.27836 .37515 .27938 .37645 .28095 .37611 .27992 .37498 Mtetra
.644 .716 .9 r
.27992 .37498 .28095 .37611 .28254 .37556 .28151 .3745 Mtetra
.694 .743 .89 r
.28151 .3745 .28254 .37556 .28415 .37487 .28311 .3738 Mtetra
.695 .741 .887 r
.28311 .3738 .28415 .37487 .28575 .37419 .28472 .37309 Mtetra
.703 .739 .879 r
.28472 .37309 .28575 .37419 .28736 .37335 .28632 .37234 Mtetra
.685 .751 .901 r
.28632 .37234 .28736 .37335 .28897 .37264 .28793 .37169 Mtetra
.612 .744 .939 r
.28793 .37169 .28897 .37264 .29054 .37237 .28951 .37131 Mtetra
.005 .398 .851 r
.28951 .37131 .29054 .37237 .29195 .37431 .29101 .37207 Mtetra
0 0 .565 r
.29101 .37207 .29195 .37431 .29265 .38624 .29241 .37425 Mtetra
.347 .203 .539 r
.29241 .37425 .29265 .38624 .28031 .57966 .29367 .3784 Mtetra
.537 .315 .525 r
.29367 .3784 .28031 .57966 .28209 .57806 .29533 .37707 Mtetra
.544 .321 .526 r
.29533 .37707 .28209 .57806 .2978 .37982 .29721 .37254 Mtetra
.675 .478 .612 r
.29721 .37254 .2978 .37982 .29998 .37117 .29899 .36951 Mtetra
.755 .677 .775 r
.29899 .36951 .29998 .37117 .3017 .36893 .30066 .36809 Mtetra
.68 .786 .93 r
.30066 .36809 .3017 .36893 .30331 .36822 .30226 .36746 Mtetra
.625 .792 .962 r
.30226 .36746 .30331 .36822 .3049 .36787 .30386 .36701 Mtetra
.681 .784 .929 r
.30386 .36701 .3049 .36787 .30651 .36732 .30547 .36638 Mtetra
.715 .774 .899 r
.30547 .36638 .30651 .36732 .30813 .36656 .30709 .36558 Mtetra
.711 .766 .895 r
.30709 .36558 .30813 .36656 .30975 .36582 .30872 .3648 Mtetra
.744 .764 .869 r
.30872 .3648 .30975 .36582 .31138 .36486 .31035 .36382 Mtetra
.729 .757 .875 r
.31035 .36382 .31138 .36486 .31301 .36397 .31199 .36292 Mtetra
.608 .723 .927 r
.31199 .36292 .31301 .36397 .31461 .36361 .31358 .36257 Mtetra
.708 .218 0 r
.31358 .36257 .31461 .36361 .31606 .36549 .31502 .36459 Mtetra
.951 .685 .496 r
.31502 .36459 .31606 .36549 .30506 .55887 .3037 .56196 Mtetra
.87 .566 .471 r
.3037 .56196 .30506 .55887 .30574 .5743 .30463 .57353 Mtetra
.165 .586 .936 r
.30463 .57353 .30574 .5743 .30734 .57555 .30629 .57388 Mtetra
.858 .71 .697 r
.30629 .57388 .30734 .57555 .30911 .57419 .3082 .57028 Mtetra
.896 .66 .575 r
.3082 .57028 .30911 .57419 .31095 .5718 .31086 .55491 Mtetra
.931 .668 .517 r
.31086 .55491 .31095 .5718 .31276 .56977 .32442 .36601 Mtetra
.537 .315 .525 r
.32442 .36601 .31276 .56977 .3145 .56904 .32607 .36487 Mtetra
.534 .313 .524 r
.32607 .36487 .3145 .56904 .31621 .56862 .32766 .36486 Mtetra
.535 .313 .524 r
.32766 .36486 .31621 .56862 .31793 .56817 .32925 .36479 Mtetra
.536 .314 .525 r
.32925 .36479 .31793 .56817 .31965 .56761 .33088 .3642 Mtetra
.33088 .3642 .31965 .56761 .32138 .56708 .3325 .36366 Mtetra
.535 .313 .525 r
.3325 .36366 .32138 .56708 .3231 .56656 .33413 .36315 Mtetra
.33413 .36315 .3231 .56656 .32482 .56607 .33575 .36265 Mtetra
.33575 .36265 .32482 .56607 .32655 .56556 .33738 .36214 Mtetra
.534 .313 .524 r
.33738 .36214 .32655 .56556 .32825 .56546 .33897 .36215 Mtetra
.534 .312 .524 r
.33897 .36215 .32825 .56546 .32995 .56545 .34055 .36245 Mtetra
.537 .314 .525 r
.34055 .36245 .32995 .56545 .33171 .56458 .34221 .36142 Mtetra
.542 .319 .526 r
.34221 .36142 .33171 .56458 .33368 .55984 .34403 .3577 Mtetra
.34403 .3577 .33368 .55984 .34664 .35885 .34584 .35396 Mtetra
.7 .52 .642 r
.34584 .35396 .34664 .35885 .34855 .35318 .34758 .35143 Mtetra
.753 .669 .769 r
.34758 .35143 .34855 .35318 .35028 .35097 .34926 .34997 Mtetra
.685 .758 .907 r
.34926 .34997 .35028 .35097 .35192 .35022 .3509 .3493 Mtetra
.632 .762 .94 r
.3509 .3493 .35192 .35022 .35354 .34985 .35253 .34884 Mtetra
.655 .75 .92 r
.35253 .34884 .35354 .34985 .35517 .34942 .35416 .3483 Mtetra
.695 .738 .884 r
.35416 .3483 .35517 .34942 .35681 .34876 .3558 .34757 Mtetra
.689 .725 .878 r
.3558 .34757 .35681 .34876 .35845 .34811 .35745 .34687 Mtetra
.665 .707 .879 r
.35745 .34687 .35845 .34811 .36009 .34755 .35909 .34627 Mtetra
.635 .691 .885 r
.35909 .34627 .36009 .34755 .36172 .34709 .36072 .34581 Mtetra
.628 .688 .888 r
.36072 .34581 .36172 .34709 .36335 .34665 .36235 .34539 Mtetra
.663 .703 .877 r
.36235 .34539 .36335 .34665 .36499 .34611 .36399 .3448 Mtetra
.693 .706 .857 r
.36399 .3448 .36499 .34611 .36663 .34545 .36565 .34404 Mtetra
.643 .672 .863 r
.36565 .34404 .36663 .34545 .36828 .34491 .36729 .34354 Mtetra
.402 .569 .903 r
.36729 .34354 .36828 .34491 .36991 .3446 .36889 .34383 Mtetra
.73 .22 0 r
.36889 .34383 .36991 .3446 .37152 .34471 .37041 .34581 Mtetra
.881 .539 .397 r
.37041 .34581 .37152 .34471 .3731 .34548 .37172 .35227 Mtetra
.946 .674 .489 r
.37172 .35227 .3731 .34548 .37457 .34867 .3639 .55013 Mtetra
.54 .313 .519 r
.3639 .55013 .37457 .34867 .36679 .54921 .36545 .55386 Mtetra
.615 .297 .408 r
.36545 .55386 .36679 .54921 .36824 .55523 .36711 .55541 Mtetra
.418 0 0 r
.36711 .55541 .36824 .55523 .36989 .55689 .36882 .55593 Mtetra
.53 .732 .967 r
.36882 .55593 .36989 .55689 .37164 .55675 .37056 .55574 Mtetra
.632 .758 .938 r
.37056 .55574 .37164 .55675 .3734 .55612 .37232 .55524 Mtetra
.641 .79 .953 r
.37232 .55524 .3734 .55612 .37517 .55539 .37408 .5547 Mtetra
.594 .819 .986 r
.37408 .5547 .37517 .55539 .37694 .55483 .37584 .55425 Mtetra
.691 .868 .966 r
.37584 .55425 .37694 .55483 .37871 .55411 .37762 .55347 Mtetra
.838 .859 .86 r
.37762 .55347 .37871 .55411 .3805 .55303 .37943 .55183 Mtetra
.893 .756 .703 r
.37943 .55183 .3805 .55303 .38231 .55134 .38134 .54813 Mtetra
.877 .66 .606 r
.38134 .54813 .38231 .55134 .38414 .54936 .38343 .53973 Mtetra
.948 .679 .495 r
.38343 .53973 .38414 .54936 .38595 .54781 .39331 .34395 Mtetra
.536 .314 .525 r
.39331 .34395 .38595 .54781 .3877 .54767 .39499 .34305 Mtetra
.534 .312 .524 r
.39499 .34305 .3877 .54767 .38947 .54715 .39662 .34321 Mtetra
.54 .317 .525 r
.39662 .34321 .38947 .54715 .39132 .54445 .39837 .34067 Mtetra
.544 .321 .526 r
.39837 .34067 .39132 .54445 .40092 .34393 .4002 .33595 Mtetra
.661 .462 .605 r
.4002 .33595 .40092 .34393 .40291 .33526 .40196 .33305 Mtetra
.749 .635 .734 r
.40196 .33305 .40291 .33526 .40466 .33241 .40367 .33133 Mtetra
.667 .743 .907 r
.40367 .33133 .40466 .33241 .40633 .33164 .40533 .33073 Mtetra
.581 .75 .957 r
.40533 .33073 .40633 .33164 .40799 .33136 .40699 .33041 Mtetra
.57 .739 .956 r
.40699 .33041 .40799 .33136 .40964 .33118 .40865 .33014 Mtetra
.655 .746 .917 r
.40865 .33014 .40964 .33118 .41131 .33065 .41032 .32958 Mtetra
.669 .747 .909 r
.41032 .32958 .41131 .33065 .41298 .33007 .41199 .32898 Mtetra
.699 .749 .89 r
.41199 .32898 .41298 .33007 .41465 .32941 .41367 .32822 Mtetra
.739 .743 .855 r
.41367 .32822 .41465 .32941 .41633 .32858 .41536 .3272 Mtetra
.687 .697 .853 r
.41536 .3272 .41633 .32858 .41801 .32787 .41704 .32645 Mtetra
.519 .621 .892 r
.41704 .32645 .41801 .32787 .41968 .32748 .41869 .32643 Mtetra
.648 .161 0 r
.41869 .32643 .41968 .32748 .42132 .32785 .42028 .32851 Mtetra
.897 .541 .361 r
.42028 .32851 .42132 .32785 .42296 .32856 .42173 .33482 Mtetra
.952 .674 .475 r
.42173 .33482 .42296 .32856 .4246 .3291 .41709 .53118 Mtetra
.533 .307 .518 r
.41709 .53118 .4246 .3291 .4263 .32807 .41886 .531 Mtetra
.531 .305 .517 r
.41886 .531 .4263 .32807 .42798 .32736 .42068 .52967 Mtetra
.535 .308 .518 r
.42068 .52967 .42798 .32736 .42962 .32825 .42243 .5303 Mtetra
.541 .313 .519 r
.42243 .5303 .42962 .32825 .42539 .52671 .42408 .53432 Mtetra
.612 .32 .451 r
.42408 .53432 .42539 .52671 .42689 .53607 .4258 .53645 Mtetra
.586 .047 0 r
.4258 .53645 .42689 .53607 .4286 .53843 .42755 .5374 Mtetra
.586 .743 .951 r
.42755 .5374 .4286 .53843 .43039 .53826 .42935 .53705 Mtetra
.666 .735 .902 r
.42935 .53705 .43039 .53826 .4322 .53756 .43115 .53641 Mtetra
.68 .749 .904 r
.43115 .53641 .4322 .53756 .43401 .53669 .43296 .5357 Mtetra
.596 .755 .954 r
.43296 .5357 .43401 .53669 .43581 .53623 .43475 .53531 Mtetra
.597 .771 .963 r
.43475 .53531 .43581 .53623 .43761 .53575 .43655 .5349 Mtetra
.618 .794 .966 r
.43655 .5349 .43761 .53575 .43941 .53521 .43836 .53441 Mtetra
.677 .822 .953 r
.43836 .53441 .43941 .53521 .44122 .53451 .44017 .53371 Mtetra
.691 .824 .947 r
.44017 .53371 .44122 .53451 .44303 .53378 .44198 .53295 Mtetra
.69 .818 .944 r
.44198 .53295 .44303 .53378 .44484 .53306 .4438 .53219 Mtetra
.659 .803 .952 r
.4438 .53219 .44484 .53306 .44666 .53244 .44561 .53156 Mtetra
.651 .798 .953 r
.44561 .53156 .44666 .53244 .44847 .53185 .44742 .53096 Mtetra
.647 .794 .953 r
.44742 .53096 .44847 .53185 .45028 .53128 .44923 .53037 Mtetra
.651 .792 .95 r
.44923 .53037 .45028 .53128 .45209 .53072 .45105 .52978 Mtetra
.65 .784 .945 r
.45105 .52978 .45209 .53072 .45391 .53017 .45286 .52918 Mtetra
.649 .775 .94 r
.45286 .52918 .45391 .53017 .45572 .52963 .45468 .5286 Mtetra
.648 .767 .936 r
.45468 .5286 .45572 .52963 .45754 .52909 .4565 .52803 Mtetra
.646 .758 .931 r
.4565 .52803 .45754 .52909 .45935 .52856 .45832 .52747 Mtetra
.639 .75 .929 r
.45832 .52747 .45935 .52856 .46117 .52805 .46014 .52693 Mtetra
.573 .721 .943 r
.46014 .52693 .46117 .52805 .46299 .5279 .46195 .52664 Mtetra
.627 .714 .909 r
.46195 .52664 .46299 .5279 .46481 .52743 .46377 .52617 Mtetra
.703 .739 .879 r
.46377 .52617 .46481 .52743 .46664 .52629 .4656 .52531 Mtetra
.844 .807 .814 r
.4656 .52531 .46664 .52629 .46852 .52229 .46745 .52335 Mtetra
.867 .954 .605 r
.46745 .52335 .46852 .52229 .4706 .50595 .46932 .52018 Mtetra
.265 .059 .402 r
.46932 .52018 .4706 .50595 .47548 .31138 .47125 .51322 Mtetra
0 0 .303 r
.47125 .51322 .47548 .31138 .47722 .30865 .47618 .31225 Mtetra
0 0 0 r
.47618 .31225 .47722 .30865 .47895 .30704 .47797 .30725 Mtetra
.933 .963 .758 r
.47797 .30725 .47895 .30704 .48067 .30599 .47971 .30471 Mtetra
.691 .719 .871 r
.47971 .30471 .48067 .30599 .48238 .30539 .48142 .30396 Mtetra
.596 .656 .879 r
.48142 .30396 .48238 .30539 .48409 .305 .48314 .30365 Mtetra
.532 .641 .903 r
.48314 .30365 .48409 .305 .48581 .3047 .48485 .30357 Mtetra
.646 .732 .911 r
.48485 .30357 .48581 .3047 .48752 .30412 .48656 .30304 Mtetra
.666 .75 .912 r
.48656 .30304 .48752 .30412 .48924 .30347 .48828 .30242 Mtetra
.684 .763 .911 r
.48828 .30242 .48924 .30347 .49096 .30276 .49 .30173 Mtetra
.751 .781 .878 r
.49 .30173 .49096 .30276 .49269 .3016 .49173 .30068 Mtetra
.729 .799 .907 r
.49173 .30068 .49269 .3016 .49441 .30072 .49345 .29977 Mtetra
.656 .775 .937 r
.49345 .29977 .49441 .30072 .49613 .30038 .49518 .2992 Mtetra
.285 .547 .922 r
.49518 .2992 .49613 .30038 .49783 .30249 .49689 .29967 Mtetra
.252 .306 .724 r
.49689 .29967 .49783 .30249 .49948 .31172 .4986 .30114 Mtetra
.348 .218 .559 r
.4986 .30114 .49948 .31172 .4997 .51124 .50029 .3052 Mtetra
0 0 .333 r
.50029 .3052 .4997 .51124 .50152 .51328 .50056 .50517 Mtetra
.139 .091 .536 r
.50056 .50517 .50152 .51328 .50336 .51386 .50236 .51064 Mtetra
.193 .254 .698 r
.50236 .51064 .50336 .51386 .50521 .51382 .50419 .51259 Mtetra
.412 .622 .939 r
.50419 .51259 .50521 .51382 .50705 .51384 .50604 .51279 Mtetra
.627 .758 .941 r
.50604 .51279 .50705 .51384 .5089 .51339 .50789 .51229 Mtetra
.742 .782 .885 r
.50789 .51229 .5089 .51339 .51076 .51226 .50974 .51122 Mtetra
.826 .804 .829 r
.50974 .51122 .51076 .51226 .51262 .50859 .5116 .50945 Mtetra
.837 .963 .632 r
.5116 .50945 .51262 .50859 .51451 .49655 .51347 .50668 Mtetra
.25 .033 .376 r
.51347 .50668 .51451 .49655 .51687 .29755 .51533 .50142 Mtetra
0 0 .327 r
.51533 .50142 .51687 .29755 .51862 .29459 .51765 .30043 Mtetra
0 0 .137 r
.51765 .30043 .51862 .29459 .52036 .29298 .51941 .29394 Mtetra
.849 .946 .587 r
.51941 .29394 .52036 .29298 .52209 .29192 .52115 .291 Mtetra
.772 .812 .884 r
.52115 .291 .52209 .29192 .52384 .29114 .52289 .28984 Mtetra
.658 .707 .884 r
.52289 .28984 .52384 .29114 .52558 .29055 .52463 .28925 Mtetra
.605 .685 .899 r
.52463 .28925 .52558 .29055 .52732 .29005 .52638 .28889 Mtetra
.742 .758 .866 r
.52638 .28889 .52732 .29005 .52906 .28898 .52812 .28784 Mtetra
.71 .755 .887 r
.52812 .28784 .52906 .28898 .5308 .28813 .52986 .287 Mtetra
.548 .695 .936 r
.52986 .287 .5308 .28813 .53255 .28794 .53161 .28682 Mtetra
.801 .354 0 r
.53161 .28682 .53255 .28794 .53431 .29135 .53337 .29024 Mtetra
.97 .683 .426 r
.53337 .29024 .53431 .29135 .5368 .4966 .5358 .49554 Mtetra
.923 .534 .163 r
.5358 .49554 .5368 .4966 .53869 .50308 .53769 .50201 Mtetra
0 .348 .814 r
.53769 .50201 .53869 .50308 .54057 .50415 .53957 .50307 Mtetra
.594 .743 .948 r
.53957 .50307 .54057 .50415 .54245 .50376 .54145 .50269 Mtetra
.796 .799 .855 r
.54145 .50269 .54245 .50376 .54432 .5023 .54332 .50121 Mtetra
.934 .777 .663 r
.54332 .50121 .54432 .5023 .54617 .49755 .54517 .49646 Mtetra
.971 .689 .436 r
.54517 .49646 .54617 .49755 .54661 .29144 .54568 .29027 Mtetra
.954 .742 .578 r
.54568 .29027 .54661 .29144 .54832 .2833 .54738 .28216 Mtetra
.832 .78 .803 r
.54738 .28216 .54832 .2833 .55006 .28145 .54913 .28031 Mtetra
.666 .741 .906 r
.54913 .28031 .55006 .28145 .55182 .28082 .55089 .27968 Mtetra
.551 .695 .935 r
.55089 .27968 .55182 .28082 .55358 .28063 .55265 .27948 Mtetra
.719 .758 .884 r
.55265 .27948 .55358 .28063 .55534 .27973 .55441 .27858 Mtetra
.711 .756 .887 r
.55441 .27858 .55534 .27973 .5571 .27887 .55617 .27772 Mtetra
.567 .702 .932 r
.55617 .27772 .5571 .27887 .55886 .27863 .55794 .27748 Mtetra
.7 .241 0 r
.55794 .27748 .55886 .27863 .56067 .2815 .55974 .28033 Mtetra
.972 .681 .415 r
.55974 .28033 .56067 .2815 .56492 .48616 .56393 .48496 Mtetra
.933 .558 .183 r
.56393 .48496 .56492 .48616 .56691 .49389 .56592 .49277 Mtetra
0 .342 .814 r
.56592 .49277 .56691 .49389 .56882 .49511 .56783 .49388 Mtetra
.613 .721 .923 r
.56783 .49388 .56882 .49511 .57072 .49473 .56973 .49344 Mtetra
.749 .756 .858 r
.56973 .49344 .57072 .49473 .5726 .49341 .57162 .49225 Mtetra
.818 .792 .827 r
.57162 .49225 .5726 .49341 .57446 .49021 .5735 .4905 Mtetra
.909 .983 .742 r
.5735 .4905 .57446 .49021 .57624 .48183 .57536 .48789 Mtetra
.087 0 .27 r
.57536 .48789 .57624 .48183 .57486 .27831 .5772 .48323 Mtetra
0 0 .355 r
.5772 .48323 .57486 .27831 .57658 .27452 .57581 .28259 Mtetra
0 0 .234 r
.57581 .28259 .57658 .27452 .57834 .27277 .57746 .2742 Mtetra
.709 .841 .406 r
.57746 .2742 .57834 .27277 .58011 .27162 .57919 .27094 Mtetra
.822 .874 .883 r
.57919 .27094 .58011 .27162 .58188 .2708 .58096 .2695 Mtetra
.67 .717 .884 r
.58096 .2695 .58188 .2708 .58366 .27018 .58273 .26884 Mtetra
.61 .685 .896 r
.58273 .26884 .58366 .27018 .58544 .26967 .58452 .26845 Mtetra
.716 .748 .877 r
.58452 .26845 .58544 .26967 .58721 .2687 .58629 .26755 Mtetra
.724 .761 .883 r
.58629 .26755 .58721 .2687 .58899 .26776 .58807 .26661 Mtetra
.593 .715 .929 r
.58807 .26661 .58899 .26776 .59077 .26741 .58986 .26627 Mtetra
.576 .113 0 r
.58986 .26627 .59077 .26741 .59262 .26977 .59171 .26866 Mtetra
.973 .68 .402 r
.59171 .26866 .59262 .26977 .59901 .47352 .59804 .47257 Mtetra
.941 .574 .223 r
.59804 .47257 .59901 .47352 .60114 .48293 .60017 .48185 Mtetra
0 .143 .651 r
.60017 .48185 .60114 .48293 .60311 .48457 .60214 .48349 Mtetra
.535 .72 .958 r
.60214 .48349 .60311 .48457 .60504 .48437 .60406 .48328 Mtetra
.769 .8 .878 r
.60406 .48328 .60504 .48437 .60694 .48311 .60597 .48202 Mtetra
.924 .795 .699 r
.60597 .48202 .60694 .48311 .60878 .4793 .60781 .47821 Mtetra
.975 .687 .413 r
.60781 .47821 .60878 .4793 .60547 .27771 .60457 .27681 Mtetra
.976 .731 .5 r
.60457 .27681 .60547 .27771 .60692 .26358 .60601 .26244 Mtetra
.878 .789 .758 r
.60601 .26244 .60692 .26358 .60866 .26106 .60775 .25992 Mtetra
.685 .753 .903 r
.60775 .25992 .60866 .26106 .61045 .26033 .60954 .25919 Mtetra
.557 .703 .938 r
.60954 .25919 .61045 .26033 .61226 .2601 .61135 .25897 Mtetra
.641 .74 .921 r
.61135 .25897 .61226 .2601 .61406 .25947 .61315 .25844 Mtetra
.699 .781 .915 r
.61315 .25844 .61406 .25947 .61585 .25859 .61495 .25765 Mtetra
.642 .781 .948 r
.61495 .25765 .61585 .25859 .61765 .25815 .61675 .25709 Mtetra
.434 .662 .957 r
.61675 .25709 .61765 .25815 .61951 .2593 .61858 .25718 Mtetra
.292 .399 .8 r
.61858 .25718 .61951 .2593 .6215 .26469 .62043 .25821 Mtetra
.344 .255 .609 r
.62043 .25821 .6215 .26469 .62983 .46857 .62234 .26092 Mtetra
0 0 .388 r
.62234 .26092 .62983 .46857 .6319 .47227 .63055 .45897 Mtetra
.14 .067 .506 r
.63055 .45897 .6319 .47227 .63388 .47309 .63281 .46869 Mtetra
.232 .231 .652 r
.63281 .46869 .63388 .47309 .63584 .47318 .63486 .47132 Mtetra
.288 .446 .845 r
.63486 .47132 .63584 .47318 .6378 .47318 .63685 .47221 Mtetra
.498 .731 .976 r
.63685 .47221 .6378 .47318 .63976 .47297 .63881 .47206 Mtetra
.738 .835 .924 r
.63881 .47206 .63976 .47297 .64169 .47203 .64073 .47102 Mtetra
.923 .815 .721 r
.64073 .47102 .64169 .47203 .64353 .46869 .64258 .46761 Mtetra
.976 .685 .4 r
.64258 .46761 .64353 .46869 .63831 .27253 .63748 .2734 Mtetra
.991 .735 .424 r
.63748 .2734 .63831 .27253 .63941 .25237 .63851 .25121 Mtetra
.895 .79 .737 r
.63851 .25121 .63941 .25237 .64114 .24952 .64025 .24835 Mtetra
.703 .757 .894 r
.64025 .24835 .64114 .24952 .64295 .24869 .64206 .24752 Mtetra
.586 .71 .929 r
.64206 .24752 .64295 .24869 .64478 .24837 .64389 .2472 Mtetra
.666 .743 .908 r
.64389 .2472 .64478 .24837 .6466 .24773 .6457 .24655 Mtetra
.733 .766 .879 r
.6457 .24655 .6466 .24773 .6484 .24672 .64751 .24555 Mtetra
.636 .731 .917 r
.64751 .24555 .6484 .24672 .65023 .24621 .64934 .24503 Mtetra
0 .282 .78 r
.64934 .24503 .65023 .24621 .65213 .24753 .65124 .24635 Mtetra
.938 .574 .185 r
.65124 .24635 .65213 .24753 .65439 .25737 .6535 .25619 Mtetra
.975 .675 .374 r
.6535 .25619 .65439 .25737 .66494 .46113 .664 .46 Mtetra
0 0 .512 r
.664 .46 .66494 .46113 .66703 .46341 .66608 .46228 Mtetra
.629 .756 .938 r
.66608 .46228 .66703 .46341 .66899 .46287 .66805 .46174 Mtetra
.769 .8 .878 r
.66805 .46174 .66899 .46287 .67092 .46158 .66998 .46046 Mtetra
.782 .803 .87 r
.66998 .46046 .67092 .46158 .67285 .4602 .67191 .45907 Mtetra
.73 .79 .9 r
.67191 .45907 .67285 .4602 .6748 .45917 .67385 .45804 Mtetra
.716 .786 .907 r
.67385 .45804 .6748 .45917 .67674 .45822 .67581 .45709 Mtetra
.655 .765 .93 r
.67581 .45709 .67674 .45822 .67871 .45757 .67777 .45644 Mtetra
.563 .727 .951 r
.67777 .45644 .67871 .45757 .68069 .45728 .67975 .45614 Mtetra
.534 .713 .954 r
.67975 .45614 .68069 .45728 .68268 .45708 .68174 .45594 Mtetra
.443 .667 .958 r
.68174 .45594 .68268 .45708 .68468 .45715 .68375 .45602 Mtetra
.415 .652 .956 r
.68375 .45602 .68468 .45715 .68669 .4573 .68576 .45616 Mtetra
.628 .755 .938 r
.68576 .45616 .68669 .4573 .68867 .45676 .68774 .45562 Mtetra
.89 .812 .765 r
.68774 .45562 .68867 .45676 .69054 .45406 .68961 .45293 Mtetra
.981 .723 .466 r
.68961 .45293 .69054 .45406 .69164 .43625 .69071 .43506 Mtetra
.977 .681 .379 r
.69071 .43506 .69164 .43625 .68334 .23735 .68246 .23616 Mtetra
.912 .79 .713 r
.68246 .23616 .68334 .23735 .68505 .2341 .68417 .23291 Mtetra
.709 .758 .89 r
.68417 .23291 .68505 .2341 .68688 .23323 .686 .23203 Mtetra
.588 .709 .927 r
.686 .23203 .68688 .23323 .68874 .23289 .68787 .23169 Mtetra
.624 .725 .919 r
.68787 .23169 .68874 .23289 .6906 .23242 .68972 .23122 Mtetra
.732 .765 .879 r
.68972 .23122 .6906 .23242 .69243 .23141 .69155 .2302 Mtetra
.642 .731 .914 r
.69155 .2302 .69243 .23141 .69428 .23086 .69341 .22965 Mtetra
.078 .407 .86 r
.69341 .22965 .69428 .23086 .69622 .23187 .69535 .23066 Mtetra
.919 .545 .125 r
.69535 .23066 .69622 .23187 .69863 .24093 .69775 .23961 Mtetra
.975 .671 .352 r
.69775 .23961 .69863 .24093 .71231 .44652 .71139 .44534 Mtetra
.6 .143 0 r
.71139 .44534 .71231 .44652 .71451 .44952 .71359 .44836 Mtetra
.421 .649 .953 r
.71359 .44836 .71451 .44952 .71655 .44967 .71563 .4485 Mtetra
.717 .783 .905 r
.71563 .4485 .71655 .44967 .71853 .44871 .7176 .44753 Mtetra
.896 .81 .756 r
.7176 .44753 .71853 .44871 .7204 .44595 .71947 .44471 Mtetra
.979 .739 .502 r
.71947 .44471 .7204 .44595 .72178 .43512 .72079 .43278 Mtetra
.977 .678 .368 r
.72079 .43278 .72178 .43512 .71117 .22811 .71028 .22658 Mtetra
.903 .756 .688 r
.71028 .22658 .71117 .22811 .71284 .22437 .71196 .22296 Mtetra
.685 .714 .87 r
.71196 .22296 .71284 .22437 .71469 .22353 .71382 .22217 Mtetra
.548 .66 .91 r
.71382 .22217 .71469 .22353 .71658 .22332 .71571 .22201 Mtetra
.51 .649 .92 r
.71571 .22201 .71658 .22332 .71848 .22324 .71762 .22198 Mtetra
.645 .723 .905 r
.71762 .22198 .71848 .22324 .72035 .22266 .71949 .2214 Mtetra
.657 .731 .904 r
.71949 .2214 .72035 .22266 .72222 .22202 .72136 .22078 Mtetra
.695 .747 .891 r
.72136 .22078 .72222 .22202 .72408 .2212 .72322 .21996 Mtetra
.749 .767 .867 r
.72322 .21996 .72408 .2212 .72592 .22005 .72506 .21882 Mtetra
.668 .739 .903 r
.72506 .21882 .72592 .22005 .72779 .21937 .72693 .21814 Mtetra
.243 .512 .908 r
.72693 .21814 .72779 .21937 .72975 .22003 .72889 .2188 Mtetra
.892 .505 .056 r
.72889 .2188 .72975 .22003 .7322 .22787 .73134 .22661 Mtetra
.975 .667 .334 r
.73134 .22661 .7322 .22787 .74833 .43492 .74743 .43375 Mtetra
.637 .183 0 r
.74743 .43375 .74833 .43492 .75062 .43829 .74972 .43713 Mtetra
.39 .634 .952 r
.74972 .43713 .75062 .43829 .7527 .43852 .7518 .43736 Mtetra
.694 .78 .918 r
.7518 .43736 .7527 .43852 .75471 .43766 .75381 .4365 Mtetra
.873 .82 .793 r
.75381 .4365 .75471 .43766 .75661 .43531 .75571 .43415 Mtetra
.978 .768 .553 r
.75571 .43415 .75661 .43531 .75811 .42742 .75721 .42627 Mtetra
.977 .675 .347 r
.75721 .42627 .75811 .42742 .74499 .21766 .74414 .21645 Mtetra
.951 .785 .64 r
.74414 .21645 .74499 .21766 .74658 .21298 .74574 .21177 Mtetra
.747 .773 .874 r
.74574 .21177 .74658 .21298 .74843 .21186 .74759 .21065 Mtetra
.619 .724 .921 r
.74759 .21065 .74843 .21186 .75033 .21139 .74949 .21018 Mtetra
.587 .71 .928 r
.74949 .21018 .75033 .21139 .75225 .21105 .7514 .20984 Mtetra
.75 .776 .874 r
.7514 .20984 .75225 .21105 .7541 .20991 .75326 .20871 Mtetra
.674 .749 .907 r
.75326 .20871 .7541 .20991 .75598 .2092 .75514 .20799 Mtetra
.364 .592 .932 r
.75514 .20799 .75598 .2092 .75795 .20954 .75711 .20834 Mtetra
.823 .412 0 r
.75711 .20834 .75795 .20954 .76033 .2152 .7595 .21408 Mtetra
.973 .663 .319 r
.7595 .21408 .76033 .2152 .77861 .42415 .77773 .42306 Mtetra
.718 .267 0 r
.77773 .42306 .77861 .42415 .78102 .42825 .78014 .42712 Mtetra
.504 .705 .96 r
.78014 .42712 .78102 .42825 .78311 .42813 .78222 .427 Mtetra
.697 .789 .922 r
.78222 .427 .78311 .42813 .78513 .42726 .78424 .42612 Mtetra
.737 .802 .903 r
.78424 .42612 .78513 .42726 .78714 .42617 .78625 .42502 Mtetra
.5 .7 .959 r
.78625 .42502 .78714 .42617 .78922 .42607 .78834 .42492 Mtetra
.628 .759 .941 r
.78834 .42492 .78922 .42607 .79128 .42551 .7904 .42436 Mtetra
.813 .819 .855 r
.7904 .42436 .79128 .42551 .79324 .42387 .79236 .42271 Mtetra
.98 .774 .554 r
.79236 .42271 .79324 .42387 .79472 .41633 .79384 .41519 Mtetra
.976 .671 .329 r
.79384 .41519 .79472 .41633 .77916 .20601 .77833 .2048 Mtetra
.961 .786 .621 r
.77833 .2048 .77916 .20601 .7807 .20096 .77987 .19974 Mtetra
.753 .776 .872 r
.77987 .19974 .7807 .20096 .78256 .1998 .78173 .19857 Mtetra
.623 .725 .92 r
.78173 .19857 .78256 .1998 .78449 .19931 .78366 .19808 Mtetra
.553 .691 .931 r
.78366 .19808 .78449 .19931 .78644 .1991 .78561 .19787 Mtetra
.747 .774 .875 r
.78561 .19787 .78644 .1991 .78831 .19797 .78748 .19674 Mtetra
.678 .748 .904 r
.78748 .19674 .78831 .19797 .79021 .19723 .78939 .196 Mtetra
.456 .639 .935 r
.78939 .196 .79021 .19723 .7922 .19734 .79137 .1961 Mtetra
.769 .353 0 r
.79137 .1961 .7922 .19734 .79463 .20254 .79381 .2013 Mtetra
.971 .657 .298 r
.79381 .2013 .79463 .20254 .81546 .41235 .81459 .41116 Mtetra
.726 .292 0 r
.81459 .41116 .81546 .41235 .818 .417 .81713 .41581 Mtetra
.307 .58 .938 r
.81713 .41581 .818 .417 .82017 .41747 .8193 .41628 Mtetra
.65 .764 .932 r
.8193 .41628 .82017 .41747 .82224 .41681 .82137 .41562 Mtetra
.83 .82 .84 r
.82137 .41562 .82224 .41681 .8242 .41499 .82333 .41379 Mtetra
.975 .788 .588 r
.82333 .41379 .8242 .41499 .82576 .40883 .82489 .40762 Mtetra
.974 .667 .312 r
.82489 .40762 .82576 .40883 .80809 .19763 .80726 .19635 Mtetra
.973 .773 .574 r
.80726 .19635 .80809 .19763 .80948 .19132 .80866 .19006 Mtetra
.759 .755 .849 r
.18968 .40568 .19075 .40669 .19234 .40561 .19127 .4046 Mtetra
.614 .724 .924 r
.19127 .4046 .19234 .40561 .19386 .40525 .19279 .40424 Mtetra
.461 .667 .952 r
.19279 .40424 .19386 .40525 .19534 .40529 .19428 .40427 Mtetra
.654 .735 .909 r
.19428 .40427 .19534 .40529 .19688 .40478 .19581 .40377 Mtetra
.662 .738 .906 r
.19581 .40377 .19688 .40478 .19842 .40425 .19736 .40323 Mtetra
.668 .739 .903 r
.19736 .40323 .19842 .40425 .19997 .40368 .1989 .40267 Mtetra
.761 .756 .848 r
.1989 .40267 .19997 .40368 .20157 .40258 .2005 .40156 Mtetra
.708 .748 .884 r
.2005 .40156 .20157 .40258 .20313 .40182 .20207 .40081 Mtetra
.498 .683 .949 r
.20207 .40081 .20313 .40182 .20463 .40178 .20356 .40076 Mtetra
.932 .56 .273 r
.20356 .40076 .20463 .40178 .20569 .40616 .20462 .40512 Mtetra
.939 .683 .523 r
.20462 .40512 .20569 .40616 .18751 .60605 .18637 .60506 Mtetra
.933 .572 .307 r
.18637 .60506 .18751 .60605 .18861 .6111 .18746 .61014 Mtetra
0 .388 .827 r
.18746 .61014 .18861 .6111 .19013 .61184 .18899 .61088 Mtetra
.629 .755 .937 r
.18899 .61088 .19013 .61184 .19177 .61139 .19063 .61042 Mtetra
.803 .777 .829 r
.19063 .61042 .19177 .61139 .19351 .60988 .19237 .60891 Mtetra
.906 .74 .665 r
.19237 .60891 .19351 .60988 .19561 .60467 .19447 .60366 Mtetra
.939 .687 .53 r
.19447 .60366 .19561 .60467 .21643 .40366 .21537 .40256 Mtetra
.91 .722 .637 r
.21537 .40256 .21643 .40366 .21856 .39708 .2175 .39605 Mtetra
.789 .756 .823 r
.2175 .39605 .21856 .39708 .22019 .3957 .21913 .39467 Mtetra
.636 .73 .916 r
.21913 .39467 .22019 .3957 .22173 .39526 .22068 .39423 Mtetra
.495 .679 .948 r
.22068 .39423 .22173 .39526 .22324 .39522 .22219 .3942 Mtetra
.643 .733 .914 r
.22219 .3942 .22324 .39522 .22479 .39476 .22374 .39373 Mtetra
.667 .739 .903 r
.22374 .39373 .22479 .39476 .22635 .39419 .2253 .39317 Mtetra
.675 .743 .901 r
.2253 .39317 .22635 .39419 .22792 .39356 .22686 .39257 Mtetra
.762 .764 .854 r
.22686 .39257 .22792 .39356 .22954 .39235 .22847 .39147 Mtetra
.731 .782 .893 r
.22847 .39147 .22954 .39235 .23114 .39139 .23006 .39062 Mtetra
.546 .762 .977 r
.23006 .39062 .23114 .39139 .23268 .39105 .23159 .39038 Mtetra
.888 .466 .175 r
.23159 .39038 .23268 .39105 .23394 .39384 .23283 .3934 Mtetra
.941 .683 .517 r
.23283 .3934 .23394 .39384 .21762 .59207 .21638 .59236 Mtetra
.907 .583 .421 r
.21638 .59236 .21762 .59207 .21845 .60074 .21731 .59988 Mtetra
0 .412 .831 r
.21731 .59988 .21845 .60074 .22001 .60146 .21887 .60055 Mtetra
.672 .777 .928 r
.21887 .60055 .22001 .60146 .22168 .60084 .22054 .59993 Mtetra
.766 .789 .872 r
.22054 .59993 .22168 .60084 .2234 .59968 .22226 .59878 Mtetra
.582 .756 .961 r
.22226 .59878 .2234 .59968 .22506 .59922 .22391 .59846 Mtetra
.601 .793 .972 r
.22391 .59846 .22506 .59922 .22672 .59877 .22557 .59805 Mtetra
.768 .829 .899 r
.22557 .59805 .22672 .59877 .22842 .59787 .22729 .59696 Mtetra
.918 .741 .648 r
.22729 .59696 .22842 .59787 .23035 .59437 .22944 .59088 Mtetra
.94 .685 .524 r
.22944 .59088 .23035 .59437 .23285 .58413 .24837 .38973 Mtetra
.545 .322 .527 r
.24837 .38973 .23285 .58413 .25084 .39204 .25032 .38488 Mtetra
.438 .302 .597 r
.25032 .38488 .25084 .39204 .25146 .4029 .25172 .38635 Mtetra
.964 .707 .497 r
.25172 .38635 .25146 .4029 .23707 .59172 .23661 .58295 Mtetra
0 0 .138 r
.23661 .58295 .23707 .59172 .2384 .59534 .23735 .59345 Mtetra
.099 .315 .791 r
.23735 .59345 .2384 .59534 .23998 .59601 .23889 .59459 Mtetra
.603 .664 .882 r
.23889 .59459 .23998 .59601 .24163 .59577 .24055 .59426 Mtetra
.686 .68 .839 r
.24055 .59426 .24163 .59577 .24331 .59521 .24225 .59348 Mtetra
.643 .637 .829 r
.24225 .59348 .24331 .59521 .24498 .59476 .24393 .59294 Mtetra
.63 .621 .822 r
.24393 .59294 .24498 .59476 .24667 .59421 .24561 .59245 Mtetra
.648 .636 .825 r
.24561 .59245 .24667 .59421 .24838 .59334 .24729 .59187 Mtetra
.631 .667 .867 r
.24729 .59187 .24838 .59334 .25015 .59173 .24897 .59141 Mtetra
.647 .905 .982 r
.24897 .59141 .25015 .59173 .252 .58912 .25067 .59072 Mtetra
0 0 0 r
.25067 .59072 .252 .58912 .25402 .58434 .25242 .58937 Mtetra
0 0 .02 r
.25242 .58937 .25402 .58434 .27125 .38705 .25444 .58459 Mtetra
0 0 .16 r
.25444 .58459 .27125 .38705 .27337 .37979 .27196 .38337 Mtetra
.897 .859 .411 r
.27196 .38337 .27337 .37979 .27515 .37679 .27404 .37659 Mtetra
.885 .903 .836 r
.27404 .37659 .27515 .37679 .27678 .37558 .27573 .37473 Mtetra
.675 .781 .93 r
.27573 .37473 .27678 .37558 .27836 .37515 .27732 .37412 Mtetra
.555 .706 .941 r
.27732 .37412 .27836 .37515 .27992 .37498 .27889 .37393 Mtetra
.624 .725 .919 r
.27889 .37393 .27992 .37498 .28151 .3745 .28047 .37352 Mtetra
.667 .753 .915 r
.28047 .37352 .28151 .3745 .28311 .3738 .28206 .37295 Mtetra
.666 .781 .935 r
.28206 .37295 .28311 .3738 .28472 .37309 .28365 .37238 Mtetra
.67 .814 .952 r
.28365 .37238 .28472 .37309 .28632 .37234 .28525 .37178 Mtetra
.655 .849 .975 r
.28525 .37178 .28632 .37234 .28793 .37169 .28685 .3712 Mtetra
.617 .858 .989 r
.28685 .3712 .28793 .37169 .28951 .37131 .28844 .3707 Mtetra
.513 .793 .996 r
.28844 .3707 .28951 .37131 .29101 .37207 .29002 .37046 Mtetra
.543 .596 .857 r
.29002 .37046 .29101 .37207 .29241 .37425 .29158 .3704 Mtetra
.557 .446 .683 r
.29158 .3704 .29241 .37425 .29367 .3784 .29314 .37031 Mtetra
.571 .394 .603 r
.29314 .37031 .29367 .3784 .29533 .37707 .29474 .36975 Mtetra
.591 .415 .612 r
.29474 .36975 .29533 .37707 .29721 .37254 .29637 .36885 Mtetra
.637 .504 .684 r
.29637 .36885 .29721 .37254 .29899 .36951 .298 .36791 Mtetra
.676 .655 .821 r
.298 .36791 .29899 .36951 .30066 .36809 .29961 .36719 Mtetra
.659 .772 .933 r
.29961 .36719 .30066 .36809 .30226 .36746 .30122 .36665 Mtetra
.65 .788 .948 r
.30122 .36665 .30226 .36746 .30386 .36701 .30282 .36612 Mtetra
.673 .777 .928 r
.30282 .36612 .30386 .36701 .30547 .36638 .30443 .36552 Mtetra
.69 .787 .925 r
.30443 .36552 .30547 .36638 .30709 .36558 .30604 .36485 Mtetra
.69 .816 .942 r
.30604 .36485 .30709 .36558 .30872 .3648 .30766 .36418 Mtetra
.753 .848 .922 r
.30766 .36418 .30872 .3648 .31035 .36382 .3093 .36323 Mtetra
.745 .856 .931 r
.3093 .36323 .31035 .36382 .31199 .36292 .31093 .36232 Mtetra
.568 .817 .992 r
.31093 .36232 .31199 .36292 .31358 .36257 .31253 .36196 Mtetra
.825 .347 .011 r
.31253 .36196 .31358 .36257 .31502 .36459 .31395 .36429 Mtetra
.95 .684 .497 r
.31395 .36429 .31502 .36459 .3037 .56196 .30235 .56479 Mtetra
.845 .53 .454 r
.30235 .56479 .3037 .56196 .30463 .57353 .30351 .57283 Mtetra
.676 .832 .959 r
.30351 .57283 .30463 .57353 .30629 .57388 .30523 .57215 Mtetra
.913 .705 .609 r
.30523 .57215 .30629 .57388 .3082 .57028 .30748 .56347 Mtetra
.944 .682 .51 r
.30748 .56347 .3082 .57028 .31086 .55491 .322 .36187 Mtetra
.542 .319 .526 r
.322 .36187 .31086 .55491 .32442 .36601 .32379 .35857 Mtetra
.586 .41 .61 r
.32379 .35857 .32442 .36601 .32607 .36487 .32543 .35776 Mtetra
.56 .394 .613 r
.32543 .35776 .32607 .36487 .32766 .36486 .32703 .35747 Mtetra
.562 .393 .61 r
.32703 .35747 .32766 .36486 .32925 .36479 .32864 .35712 Mtetra
.573 .399 .608 r
.32864 .35712 .32925 .36479 .33088 .3642 .33026 .35655 Mtetra
.572 .399 .608 r
.33026 .35655 .33088 .3642 .3325 .36366 .33188 .356 Mtetra
.572 .398 .608 r
.33188 .356 .3325 .36366 .33413 .36315 .33351 .35544 Mtetra
.572 .398 .607 r
.33351 .35544 .33413 .36315 .33575 .36265 .33513 .35488 Mtetra
.572 .397 .607 r
.33513 .35488 .33575 .36265 .33738 .36214 .33676 .35433 Mtetra
.57 .395 .606 r
.33676 .35433 .33738 .36214 .33897 .36215 .33838 .35381 Mtetra
.567 .39 .601 r
.33838 .35381 .33897 .36215 .34055 .36245 .34001 .3533 Mtetra
.567 .385 .594 r
.34001 .3533 .34055 .36245 .34221 .36142 .34164 .35274 Mtetra
.577 .395 .599 r
.34164 .35274 .34221 .36142 .34403 .3577 .34328 .35198 Mtetra
.606 .443 .634 r
.34328 .35198 .34403 .3577 .34584 .35396 .34493 .35105 Mtetra
.654 .544 .718 r
.34493 .35105 .34584 .35396 .34758 .35143 .34658 .35014 Mtetra
.695 .709 .859 r
.34658 .35014 .34758 .35143 .34926 .34997 .34822 .34938 Mtetra
.654 .845 .974 r
.34822 .34938 .34926 .34997 .3509 .3493 .34986 .34879 Mtetra
.628 .858 .986 r
.34986 .34879 .3509 .3493 .35253 .34884 .35149 .34825 Mtetra
.644 .842 .976 r
.35149 .34825 .35253 .34884 .35416 .3483 .35313 .34769 Mtetra
.661 .841 .969 r
.35313 .34769 .35416 .3483 .3558 .34757 .35476 .34708 Mtetra
.647 .869 .982 r
.35476 .34708 .3558 .34757 .35745 .34687 .3564 .34648 Mtetra
.622 .887 .989 r
.3564 .34648 .35745 .34687 .35909 .34627 .35804 .3459 Mtetra
.608 .886 .99 r
.35804 .3459 .35909 .34627 .36072 .34581 .35968 .34534 Mtetra
.622 .868 .989 r
.35968 .34534 .36072 .34581 .36235 .34539 .36132 .34479 Mtetra
.696 .855 .958 r
.36132 .34479 .36235 .34539 .36399 .3448 .36297 .34407 Mtetra
.732 .827 .924 r
.36297 .34407 .36399 .3448 .36565 .34404 .36463 .3432 Mtetra
.625 .778 .955 r
.36463 .3432 .36565 .34404 .36729 .34354 .36626 .34275 Mtetra
0 .255 .703 r
.36626 .34275 .36729 .34354 .36889 .34383 .36783 .34369 Mtetra
.919 .56 .334 r
.36783 .34369 .36889 .34383 .37041 .34581 .36916 .34971 Mtetra
.95 .678 .486 r
.36916 .34971 .37041 .34581 .37172 .35227 .36097 .5516 Mtetra
.54 .312 .519 r
.36097 .5516 .37172 .35227 .3639 .55013 .36253 .55506 Mtetra
.529 .218 .385 r
.36253 .55506 .3639 .55013 .36545 .55386 .36425 .55534 Mtetra
.309 0 .014 r
.36425 .55534 .36545 .55386 .36711 .55541 .366 .55496 Mtetra
.601 .875 .992 r
.366 .55496 .36711 .55541 .36882 .55593 .36776 .5544 Mtetra
.626 .663 .866 r
.36776 .5544 .36882 .55593 .37056 .55574 .36952 .55394 Mtetra
.638 .634 .83 r
.36952 .55394 .37056 .55574 .37232 .55524 .37128 .5534 Mtetra
.616 .618 .83 r
.37128 .5534 .37232 .55524 .37408 .5547 .37304 .55297 Mtetra
.578 .616 .854 r
.37304 .55297 .37408 .5547 .37584 .55425 .37479 .55275 Mtetra
.668 .685 .856 r
.37479 .55275 .37584 .55425 .37762 .55347 .37656 .55206 Mtetra
.82 .737 .772 r
.37656 .55206 .37762 .55347 .37943 .55183 .3784 .54996 Mtetra
.908 .706 .617 r
.3784 .54996 .37943 .55183 .38134 .54813 .38046 .54254 Mtetra
.953 .684 .491 r
.38046 .54254 .38134 .54813 .38343 .53973 .39082 .33924 Mtetra
.543 .32 .526 r
.39082 .33924 .38343 .53973 .39331 .34395 .39264 .33495 Mtetra
.582 .397 .597 r
.39264 .33495 .39331 .34395 .39499 .34305 .39432 .33401 Mtetra
.557 .378 .595 r
.39432 .33401 .39499 .34305 .39662 .34321 .39597 .33369 Mtetra
.556 .375 .591 r
.39597 .33369 .39662 .34321 .39837 .34067 .39762 .33336 Mtetra
.593 .417 .613 r
.39762 .33336 .39837 .34067 .4002 .33595 .3993 .3324 Mtetra
.639 .511 .691 r
.3993 .3324 .4002 .33595 .40196 .33305 .40098 .33146 Mtetra
.687 .666 .824 r
.40098 .33146 .40196 .33305 .40367 .33133 .40266 .33065 Mtetra
.646 .828 .97 r
.40266 .33065 .40367 .33133 .40533 .33073 .40433 .33009 Mtetra
.621 .831 .981 r
.40433 .33009 .40533 .33073 .40699 .33041 .40599 .32959 Mtetra
.641 .792 .955 r
.40599 .32959 .40699 .33041 .40865 .33014 .40766 .32907 Mtetra
.67 .747 .909 r
.40766 .32907 .40865 .33014 .41032 .32958 .40933 .32846 Mtetra
.672 .736 .898 r
.40933 .32846 .41032 .32958 .41199 .32898 .411 .32783 Mtetra
.695 .74 .886 r
.411 .32783 .41199 .32898 .41367 .32822 .41268 .32709 Mtetra
.738 .753 .865 r
.41268 .32709 .41367 .32822 .41536 .3272 .41437 .32609 Mtetra
.665 .739 .905 r
.41437 .32609 .41536 .3272 .41704 .32645 .41604 .3255 Mtetra
.174 .535 .924 r
.41604 .3255 .41704 .32645 .41869 .32643 .41768 .32599 Mtetra
.918 .533 .256 r
.41768 .32599 .41869 .32643 .42028 .32851 .41917 .33114 Mtetra
.957 .68 .471 r
.41917 .33114 .42028 .32851 .42173 .33482 .41413 .53414 Mtetra
.541 .313 .519 r
.41413 .53414 .42173 .33482 .41709 .53118 .41577 .53827 Mtetra
.51 .226 .418 r
.41577 .53827 .41709 .53118 .41886 .531 .41755 .53817 Mtetra
.468 .189 .406 r
.41755 .53817 .41886 .531 .42068 .52967 .41935 .53735 Mtetra
.466 .191 .412 r
.41935 .53735 .42068 .52967 .42243 .5303 .42116 .53642 Mtetra
.503 .21 .401 r
.42116 .53642 .42243 .5303 .42408 .53432 .42294 .53628 Mtetra
.422 .014 .158 r
.42294 .53628 .42408 .53432 .4258 .53645 .42472 .53614 Mtetra
.378 .808 .966 r
.42472 .53614 .4258 .53645 .42755 .5374 .42651 .53588 Mtetra
.636 .673 .868 r
.42651 .53588 .42755 .5374 .42935 .53705 .42831 .53537 Mtetra
.646 .654 .844 r
.42831 .53537 .42935 .53705 .43115 .53641 .43011 .53478 Mtetra
.65 .663 .849 r
.43011 .53478 .43115 .53641 .43296 .5357 .43192 .53417 Mtetra
.64 .674 .866 r
.43192 .53417 .43296 .5357 .43475 .53531 .43372 .53363 Mtetra
.639 .653 .847 r
.43372 .53363 .43475 .53531 .43655 .5349 .43553 .53309 Mtetra
.64 .636 .83 r
.43553 .53309 .43655 .5349 .43836 .53441 .43733 .53252 Mtetra
.646 .63 .82 r
.43733 .53252 .43836 .53441 .44017 .53371 .43914 .5319 Mtetra
.65 .642 .828 r
.43914 .5319 .44017 .53371 .44198 .53295 .44095 .53127 Mtetra
.654 .659 .842 r
.44095 .53127 .44198 .53295 .4438 .53219 .44276 .53063 Mtetra
.656 .676 .857 r
.44276 .53063 .4438 .53219 .44561 .53156 .44458 .53 Mtetra
.654 .676 .858 r
.44458 .53 .44561 .53156 .44742 .53096 .44639 .52938 Mtetra
.652 .672 .856 r
.44639 .52938 .44742 .53096 .44923 .53037 .4482 .52877 Mtetra
.646 .666 .855 r
.4482 .52877 .44923 .53037 .45105 .52978 .45002 .52819 Mtetra
.645 .668 .857 r
.45002 .52819 .45105 .52978 .45286 .52918 .45183 .52761 Mtetra
.645 .67 .859 r
.45183 .52761 .45286 .52918 .45468 .5286 .45365 .52704 Mtetra
.65 .673 .859 r
.45365 .52704 .45468 .5286 .4565 .52803 .45547 .52644 Mtetra
.648 .669 .857 r
.45547 .52644 .4565 .52803 .45832 .52747 .45729 .52585 Mtetra
.642 .663 .855 r
.45729 .52585 .45832 .52747 .46014 .52693 .45911 .52529 Mtetra
.621 .65 .858 r
.45911 .52529 .46014 .52693 .46195 .52664 .46093 .52484 Mtetra
.625 .632 .837 r
.46093 .52484 .46195 .52664 .46377 .52617 .46275 .52436 Mtetra
.637 .637 .834 r
.46275 .52436 .46377 .52617 .4656 .52531 .46457 .52381 Mtetra
.61 .668 .881 r
.46457 .52381 .4656 .52531 .46745 .52335 .4664 .52342 Mtetra
.537 .924 .891 r
.4664 .52342 .46745 .52335 .46932 .52018 .46823 .52258 Mtetra
.068 0 .043 r
.46823 .52258 .46932 .52018 .47125 .51322 .47008 .52084 Mtetra
0 0 .168 r
.47008 .52084 .47125 .51322 .47618 .31225 .47202 .51295 Mtetra
0 0 .293 r
.47202 .51295 .47618 .31225 .47797 .30725 .47696 .30881 Mtetra
.93 .902 .504 r
.47696 .30881 .47797 .30725 .47971 .30471 .47874 .30404 Mtetra
.77 .86 .917 r
.47874 .30404 .47971 .30471 .48142 .30396 .48046 .30296 Mtetra
.618 .751 .941 r
.48046 .30296 .48142 .30396 .48314 .30365 .48217 .30253 Mtetra
.515 .681 .941 r
.48217 .30253 .48314 .30365 .48485 .30357 .48389 .30244 Mtetra
.649 .734 .911 r
.48389 .30244 .48485 .30357 .48656 .30304 .4856 .3019 Mtetra
.657 .734 .906 r
.4856 .3019 .48656 .30304 .48828 .30242 .48732 .30132 Mtetra
.667 .745 .909 r
.48732 .30132 .48828 .30242 .49 .30173 .48904 .3007 Mtetra
.703 .771 .905 r
.48904 .3007 .49 .30173 .49173 .30068 .49077 .29992 Mtetra
.702 .831 .944 r
.49077 .29992 .49173 .30068 .49345 .29977 .49249 .29915 Mtetra
.676 .857 .968 r
.49249 .29915 .49345 .29977 .49518 .2992 .49422 .29845 Mtetra
.711 .836 .941 r
.49422 .29845 .49518 .2992 .49689 .29967 .49594 .29764 Mtetra
.618 .592 .801 r
.49594 .29764 .49689 .29967 .4986 .30114 .49767 .29719 Mtetra
.521 .424 .687 r
.49767 .29719 .4986 .30114 .50029 .3052 .49939 .29744 Mtetra
.204 .135 .552 r
.49939 .29744 .50029 .3052 .50056 .50517 .50108 .30202 Mtetra
0 0 .32 r
.50108 .30202 .50056 .50517 .50236 .51064 .50136 .50634 Mtetra
0 0 .449 r
.50136 .50634 .50236 .51064 .50419 .51259 .50317 .51136 Mtetra
.332 .581 .933 r
.50317 .51136 .50419 .51259 .50604 .51279 .50502 .51174 Mtetra
.639 .764 .938 r
.50502 .51174 .50604 .51279 .50789 .51229 .50687 .51119 Mtetra
.733 .781 .891 r
.50687 .51119 .50789 .51229 .50974 .51122 .50873 .51018 Mtetra
.596 .749 .95 r
.50873 .51018 .50974 .51122 .5116 .50945 .51058 .50978 Mtetra
.286 .775 .705 r
.51058 .50978 .5116 .50945 .51347 .50668 .51244 .50908 Mtetra
.164 0 .092 r
.51244 .50908 .51347 .50668 .51533 .50142 .5143 .50763 Mtetra
0 0 .198 r
.5143 .50763 .51533 .50142 .51765 .30043 .51617 .50178 Mtetra
0 0 .312 r
.51617 .50178 .51765 .30043 .51941 .29394 .51845 .2961 Mtetra
.901 .853 .403 r
.51845 .2961 .51941 .29394 .52115 .291 .5202 .29008 Mtetra
.819 .816 .847 r
.5202 .29008 .52115 .291 .52289 .28984 .52195 .28855 Mtetra
.66 .71 .885 r
.52195 .28855 .52289 .28984 .52463 .28925 .52369 .28795 Mtetra
.571 .672 .907 r
.52369 .28795 .52463 .28925 .52638 .28889 .52543 .28772 Mtetra
.737 .756 .868 r
.52543 .28772 .52638 .28889 .52812 .28784 .52718 .2867 Mtetra
.708 .753 .888 r
.52718 .2867 .52812 .28784 .52986 .287 .52892 .28587 Mtetra
.545 .693 .937 r
.52892 .28587 .52986 .287 .53161 .28682 .53067 .28569 Mtetra
.802 .355 0 r
.53067 .28569 .53161 .28682 .53337 .29024 .53243 .28912 Mtetra
.97 .683 .426 r
.53243 .28912 .53337 .29024 .5358 .49554 .53479 .49448 Mtetra
.923 .533 .161 r
.53479 .49448 .5358 .49554 .53769 .50201 .53669 .50094 Mtetra
0 .349 .816 r
.53669 .50094 .53769 .50201 .53957 .50307 .53857 .50199 Mtetra
.594 .742 .947 r
.53857 .50199 .53957 .50307 .54145 .50269 .54044 .5016 Mtetra
.795 .799 .855 r
.54044 .5016 .54145 .50269 .54332 .50121 .54232 .50013 Mtetra
.934 .777 .663 r
.54232 .50013 .54332 .50121 .54517 .49646 .54417 .49537 Mtetra
.971 .689 .436 r
.54417 .49537 .54517 .49646 .54568 .29027 .54474 .28911 Mtetra
.955 .743 .578 r
.54474 .28911 .54568 .29027 .54738 .28216 .54645 .28101 Mtetra
.832 .78 .803 r
.54645 .28101 .54738 .28216 .54913 .28031 .5482 .27916 Mtetra
.666 .741 .906 r
.5482 .27916 .54913 .28031 .55089 .27968 .54995 .27853 Mtetra
.551 .695 .935 r
.54995 .27853 .55089 .27968 .55265 .27948 .55172 .27834 Mtetra
.719 .758 .884 r
.55172 .27834 .55265 .27948 .55441 .27858 .55348 .27744 Mtetra
.712 .756 .887 r
.55348 .27744 .55441 .27858 .55617 .27772 .55524 .27658 Mtetra
.567 .702 .932 r
.55524 .27658 .55617 .27772 .55794 .27748 .557 .27633 Mtetra
.697 .237 0 r
.557 .27633 .55794 .27748 .55974 .28033 .55881 .27916 Mtetra
.972 .681 .415 r
.55881 .27916 .55974 .28033 .56393 .48496 .56294 .48376 Mtetra
.934 .56 .186 r
.56294 .48376 .56393 .48496 .56592 .49277 .56493 .49165 Mtetra
0 .386 .843 r
.56493 .49165 .56592 .49277 .56783 .49388 .56684 .49265 Mtetra
.628 .728 .919 r
.56684 .49265 .56783 .49388 .56973 .49344 .56873 .49215 Mtetra
.73 .752 .87 r
.56873 .49215 .56973 .49344 .57162 .49225 .57063 .49109 Mtetra
.65 .75 .923 r
.57063 .49109 .57162 .49225 .5735 .4905 .57252 .49049 Mtetra
.44 .876 .889 r
.57252 .49049 .5735 .4905 .57536 .48789 .57442 .48983 Mtetra
.127 0 .017 r
.57442 .48983 .57536 .48789 .5772 .48323 .57631 .48852 Mtetra
.008 0 .218 r
.57631 .48852 .5772 .48323 .57581 .28259 .57815 .4839 Mtetra
0 0 .34 r
.57815 .4839 .57581 .28259 .57746 .2742 .57662 .27802 Mtetra
.709 .698 .162 r
.57662 .27802 .57746 .2742 .57919 .27094 .57828 .27028 Mtetra
.885 .868 .816 r
.57828 .27028 .57919 .27094 .58096 .2695 .58003 .26822 Mtetra
.677 .721 .882 r
.58003 .26822 .58096 .2695 .58273 .26884 .58181 .26751 Mtetra
.581 .674 .903 r
.58181 .26751 .58273 .26884 .58452 .26845 .5836 .26724 Mtetra
.705 .744 .882 r
.5836 .26724 .58452 .26845 .58629 .26755 .58538 .26639 Mtetra
.722 .76 .883 r
.58538 .26639 .58629 .26755 .58807 .26661 .58715 .26547 Mtetra
.59 .714 .93 r
.58715 .26547 .58807 .26661 .58986 .26627 .58894 .26514 Mtetra
.583 .119 0 r
.58894 .26514 .58986 .26627 .59171 .26866 .59079 .26754 Mtetra
.973 .68 .402 r
.59079 .26754 .59171 .26866 .59804 .47257 .59707 .47162 Mtetra
.941 .572 .22 r
.59707 .47162 .59804 .47257 .60017 .48185 .59919 .48077 Mtetra
0 .147 .656 r
.59919 .48077 .60017 .48185 .60214 .48349 .60116 .4824 Mtetra
.536 .719 .958 r
.60116 .4824 .60214 .48349 .60406 .48328 .60309 .48219 Mtetra
.768 .799 .878 r
.60309 .48219 .60406 .48328 .60597 .48202 .60499 .48093 Mtetra
.924 .795 .7 r
.60499 .48093 .60597 .48202 .60781 .47821 .60684 .47712 Mtetra
.975 .687 .413 r
.60684 .47712 .60781 .47821 .60457 .27681 .60366 .27591 Mtetra
.976 .73 .498 r
.60366 .27591 .60457 .27681 .60601 .26244 .6051 .2613 Mtetra
.878 .789 .758 r
.6051 .2613 .60601 .26244 .60775 .25992 .60684 .25878 Mtetra
.683 .752 .904 r
.60684 .25878 .60775 .25992 .60954 .25919 .60864 .25806 Mtetra
.555 .702 .938 r
.60864 .25806 .60954 .25919 .61135 .25897 .61045 .25784 Mtetra
.615 .73 .928 r
.61045 .25784 .61135 .25897 .61315 .25844 .61225 .25741 Mtetra
.68 .775 .922 r
.61225 .25741 .61315 .25844 .61495 .25765 .61405 .2567 Mtetra
.67 .79 .939 r
.61405 .2567 .61495 .25765 .61675 .25709 .61585 .25604 Mtetra
.698 .776 .912 r
.61585 .25604 .61675 .25709 .61858 .25718 .61765 .25525 Mtetra
.653 .624 .808 r
.61765 .25525 .61858 .25718 .62043 .25821 .61945 .25457 Mtetra
.56 .463 .702 r
.61945 .25457 .62043 .25821 .62234 .26092 .62127 .25444 Mtetra
.38 .279 .614 r
.62127 .25444 .62234 .26092 .63055 .45897 .62317 .25674 Mtetra
0 0 .374 r
.62317 .25674 .63055 .45897 .63281 .46869 .63162 .46029 Mtetra
0 0 .45 r
.63162 .46029 .63281 .46869 .63486 .47132 .63387 .4694 Mtetra
0 .233 .747 r
.63387 .4694 .63486 .47132 .63685 .47221 .63589 .47123 Mtetra
.476 .718 .976 r
.63589 .47123 .63685 .47221 .63881 .47206 .63785 .47115 Mtetra
.755 .835 .913 r
.63785 .47115 .63881 .47206 .64073 .47102 .63978 .47001 Mtetra
.924 .813 .718 r
.63978 .47001 .64073 .47102 .64258 .46761 .64162 .46653 Mtetra
.976 .685 .4 r
.64162 .46653 .64258 .46761 .63748 .2734 .63673 .27645 Mtetra
.99 .74 .372 r
.63673 .27645 .63748 .2734 .63851 .25121 .63762 .25006 Mtetra
.896 .79 .736 r
.63762 .25006 .63851 .25121 .64025 .24835 .63935 .24718 Mtetra
.703 .757 .894 r
.63935 .24718 .64025 .24835 .64206 .24752 .64116 .24635 Mtetra
.586 .71 .929 r
.64116 .24635 .64206 .24752 .64389 .2472 .64299 .24602 Mtetra
.666 .743 .908 r
.64299 .24602 .64389 .2472 .6457 .24655 .64481 .24537 Mtetra
.733 .766 .879 r
.64481 .24537 .6457 .24655 .64751 .24555 .64662 .24437 Mtetra
.636 .731 .917 r
.64662 .24437 .64751 .24555 .64934 .24503 .64845 .24385 Mtetra
0 .282 .78 r
.64845 .24385 .64934 .24503 .65124 .24635 .65035 .24517 Mtetra
.938 .574 .185 r
.65035 .24517 .65124 .24635 .6535 .25619 .65261 .25502 Mtetra
.975 .675 .374 r
.65261 .25502 .6535 .25619 .664 .46 .66305 .45888 Mtetra
0 0 .512 r
.66305 .45888 .664 .46 .66608 .46228 .66514 .46115 Mtetra
.629 .756 .938 r
.66514 .46115 .66608 .46228 .66805 .46174 .6671 .46061 Mtetra
.769 .8 .878 r
.6671 .46061 .66805 .46174 .66998 .46046 .66904 .45933 Mtetra
.782 .803 .87 r
.66904 .45933 .66998 .46046 .67191 .45907 .67097 .45794 Mtetra
.73 .79 .9 r
.67097 .45794 .67191 .45907 .67385 .45804 .67291 .45691 Mtetra
.716 .786 .907 r
.67291 .45691 .67385 .45804 .67581 .45709 .67486 .45596 Mtetra
.655 .765 .93 r
.67486 .45596 .67581 .45709 .67777 .45644 .67683 .4553 Mtetra
.563 .727 .951 r
.67683 .4553 .67777 .45644 .67975 .45614 .67882 .45501 Mtetra
.534 .713 .954 r
.67882 .45501 .67975 .45614 .68174 .45594 .68081 .45481 Mtetra
.443 .667 .958 r
.68081 .45481 .68174 .45594 .68375 .45602 .68281 .45488 Mtetra
.415 .652 .956 r
.68281 .45488 .68375 .45602 .68576 .45616 .68482 .45503 Mtetra
.628 .755 .938 r
.68482 .45503 .68576 .45616 .68774 .45562 .6868 .45449 Mtetra
.89 .812 .765 r
.6868 .45449 .68774 .45562 .68961 .45293 .68868 .45179 Mtetra
.981 .723 .466 r
.68868 .45179 .68961 .45293 .69071 .43506 .68978 .43387 Mtetra
.977 .681 .379 r
.68978 .43387 .69071 .43506 .68246 .23616 .68158 .23496 Mtetra
.912 .79 .713 r
.68158 .23496 .68246 .23616 .68417 .23291 .6833 .23171 Mtetra
.709 .758 .89 r
.6833 .23171 .68417 .23291 .686 .23203 .68513 .23083 Mtetra
.589 .709 .927 r
.68513 .23083 .686 .23203 .68787 .23169 .68699 .23049 Mtetra
.625 .725 .919 r
.68699 .23049 .68787 .23169 .68972 .23122 .68885 .23001 Mtetra
.732 .765 .879 r
.68885 .23001 .68972 .23122 .69155 .2302 .69068 .229 Mtetra
.642 .732 .914 r
.69068 .229 .69155 .2302 .69341 .22965 .69254 .22844 Mtetra
.081 .409 .861 r
.69254 .22844 .69341 .22965 .69535 .23066 .69448 .22944 Mtetra
.918 .542 .121 r
.69448 .22944 .69535 .23066 .69775 .23961 .69687 .23827 Mtetra
.975 .671 .352 r
.69687 .23827 .69775 .23961 .71139 .44534 .71046 .44415 Mtetra
.599 .143 0 r
.71046 .44415 .71139 .44534 .71359 .44836 .71266 .44717 Mtetra
.43 .651 .952 r
.71266 .44717 .71359 .44836 .71563 .4485 .7147 .4473 Mtetra
.717 .777 .9 r
.7147 .4473 .71563 .4485 .7176 .44753 .71668 .44633 Mtetra
.89 .807 .76 r
.71668 .44633 .7176 .44753 .71947 .44471 .71855 .44357 Mtetra
.98 .749 .517 r
.71855 .44357 .71947 .44471 .72079 .43278 .71996 .43311 Mtetra
.978 .68 .361 r
.71996 .43311 .72079 .43278 .71028 .22658 .70945 .22593 Mtetra
.964 .848 .679 r
.70945 .22593 .71028 .22658 .71196 .22296 .71112 .2221 Mtetra
.724 .838 .935 r
.71112 .2221 .71196 .22296 .71382 .22217 .71297 .22118 Mtetra
.565 .746 .962 r
.71297 .22118 .71382 .22217 .71571 .22201 .71486 .22087 Mtetra
.534 .698 .944 r
.71486 .22087 .71571 .22201 .71762 .22198 .71675 .2207 Mtetra
.649 .723 .903 r
.71675 .2207 .71762 .22198 .71949 .2214 .71863 .22011 Mtetra
.653 .722 .899 r
.71863 .22011 .71949 .2214 .72136 .22078 .7205 .2195 Mtetra
.69 .74 .89 r
.7205 .2195 .72136 .22078 .72322 .21996 .72236 .21871 Mtetra
.747 .765 .868 r
.72236 .21871 .72322 .21996 .72506 .21882 .7242 .21758 Mtetra
.667 .738 .903 r
.7242 .21758 .72506 .21882 .72693 .21814 .72607 .21691 Mtetra
.243 .512 .907 r
.72607 .21691 .72693 .21814 .72889 .2188 .72804 .21757 Mtetra
.891 .504 .054 r
.72804 .21757 .72889 .2188 .73134 .22661 .73048 .22534 Mtetra
.975 .667 .334 r
.73048 .22534 .73134 .22661 .74743 .43375 .74652 .43258 Mtetra
.637 .184 0 r
.74652 .43258 .74743 .43375 .74972 .43713 .74881 .43596 Mtetra
.389 .634 .952 r
.74881 .43596 .74972 .43713 .7518 .43736 .75089 .43619 Mtetra
.693 .78 .918 r
.75089 .43619 .7518 .43736 .75381 .4365 .7529 .43534 Mtetra
.873 .82 .793 r
.7529 .43534 .75381 .4365 .75571 .43415 .75481 .43299 Mtetra
.978 .768 .553 r
.75481 .43299 .75571 .43415 .75721 .42627 .75631 .42511 Mtetra
.977 .675 .347 r
.75631 .42511 .75721 .42627 .74414 .21645 .74329 .21524 Mtetra
.951 .785 .64 r
.74329 .21524 .74414 .21645 .74574 .21177 .74489 .21055 Mtetra
.747 .773 .875 r
.74489 .21055 .74574 .21177 .74759 .21065 .74674 .20944 Mtetra
.618 .724 .922 r
.74674 .20944 .74759 .21065 .74949 .21018 .74864 .20897 Mtetra
.586 .71 .929 r
.74864 .20897 .74949 .21018 .7514 .20984 .75056 .20863 Mtetra
.749 .776 .875 r
.75056 .20863 .7514 .20984 .75326 .20871 .75241 .2075 Mtetra
.673 .75 .908 r
.75241 .2075 .75326 .20871 .75514 .20799 .7543 .20679 Mtetra
.359 .59 .933 r
.7543 .20679 .75514 .20799 .75711 .20834 .75627 .20715 Mtetra
.827 .417 0 r
.75627 .20715 .75711 .20834 .7595 .21408 .75867 .21297 Mtetra
.973 .663 .319 r
.75867 .21297 .7595 .21408 .77773 .42306 .77685 .42196 Mtetra
.712 .262 0 r
.77685 .42196 .77773 .42306 .78014 .42712 .77925 .42598 Mtetra
.506 .704 .959 r
.77925 .42598 .78014 .42712 .78222 .427 .78133 .42586 Mtetra
.696 .788 .921 r
.78133 .42586 .78222 .427 .78424 .42612 .78336 .42498 Mtetra
.737 .802 .904 r
.78336 .42498 .78424 .42612 .78625 .42502 .78537 .42388 Mtetra
.501 .702 .96 r
.78537 .42388 .78625 .42502 .78834 .42492 .78746 .42377 Mtetra
.629 .761 .942 r
.78746 .42377 .78834 .42492 .7904 .42436 .78951 .4232 Mtetra
.813 .82 .855 r
.78951 .4232 .7904 .42436 .79236 .42271 .79148 .42155 Mtetra
.98 .774 .555 r
.79148 .42155 .79236 .42271 .79384 .41519 .79296 .41406 Mtetra
.976 .671 .329 r
.79296 .41406 .79384 .41519 .77833 .2048 .7775 .20359 Mtetra
.961 .786 .62 r
.7775 .20359 .77833 .2048 .77987 .19974 .77904 .19851 Mtetra
.753 .777 .872 r
.77904 .19851 .77987 .19974 .78173 .19857 .7809 .19734 Mtetra
.623 .725 .92 r
.7809 .19734 .78173 .19857 .78366 .19808 .78283 .19685 Mtetra
.553 .691 .931 r
.78283 .19685 .78366 .19808 .78561 .19787 .78478 .19663 Mtetra
.747 .774 .875 r
.78478 .19663 .78561 .19787 .78748 .19674 .78665 .1955 Mtetra
.678 .748 .904 r
.78665 .1955 .78748 .19674 .78939 .196 .78856 .19476 Mtetra
.456 .639 .935 r
.78856 .19476 .78939 .196 .79137 .1961 .79054 .19486 Mtetra
.769 .353 0 r
.79054 .19486 .79137 .1961 .79381 .2013 .79298 .20007 Mtetra
.971 .657 .298 r
.79298 .20007 .79381 .2013 .81459 .41116 .81372 .40997 Mtetra
.726 .292 0 r
.81372 .40997 .81459 .41116 .81713 .41581 .81626 .41462 Mtetra
.308 .581 .938 r
.81626 .41462 .81713 .41581 .8193 .41628 .81843 .41509 Mtetra
.65 .764 .932 r
.81843 .41509 .8193 .41628 .82137 .41562 .8205 .41443 Mtetra
.83 .82 .839 r
.8205 .41443 .82137 .41562 .82333 .41379 .82247 .4126 Mtetra
.975 .788 .588 r
.82247 .4126 .82333 .41379 .82489 .40762 .82402 .4064 Mtetra
.974 .667 .312 r
.82402 .4064 .82489 .40762 .80726 .19635 .80644 .19507 Mtetra
.972 .772 .575 r
.80644 .19507 .80726 .19635 .80866 .19006 .80784 .18879 Mtetra
.757 .752 .848 r
.18861 .40465 .18968 .40568 .19127 .4046 .19021 .40357 Mtetra
.613 .722 .923 r
.19021 .40357 .19127 .4046 .19279 .40424 .19173 .40322 Mtetra
.462 .665 .95 r
.19173 .40322 .19279 .40424 .19428 .40427 .19321 .40325 Mtetra
.653 .734 .909 r
.19321 .40325 .19428 .40427 .19581 .40377 .19475 .40274 Mtetra
.662 .737 .905 r
.19475 .40274 .19581 .40377 .19736 .40323 .19629 .40221 Mtetra
.668 .738 .903 r
.19629 .40221 .19736 .40323 .1989 .40267 .19783 .40165 Mtetra
.76 .755 .848 r
.19783 .40165 .1989 .40267 .2005 .40156 .19943 .40055 Mtetra
.708 .748 .883 r
.19943 .40055 .2005 .40156 .20207 .40081 .201 .39979 Mtetra
.499 .683 .949 r
.201 .39979 .20207 .40081 .20356 .40076 .2025 .39974 Mtetra
.931 .559 .271 r
.2025 .39974 .20356 .40076 .20462 .40512 .20356 .40408 Mtetra
.939 .683 .523 r
.20356 .40408 .20462 .40512 .18637 .60506 .18523 .60406 Mtetra
.934 .573 .307 r
.18523 .60406 .18637 .60506 .18746 .61014 .18632 .60918 Mtetra
0 .381 .823 r
.18632 .60918 .18746 .61014 .18899 .61088 .18784 .60992 Mtetra
.63 .756 .938 r
.18784 .60992 .18899 .61088 .19063 .61042 .18948 .60947 Mtetra
.806 .778 .827 r
.18948 .60947 .19063 .61042 .19237 .60891 .19123 .60792 Mtetra
.908 .737 .658 r
.19123 .60792 .19237 .60891 .19447 .60366 .19337 .60233 Mtetra
.938 .686 .53 r
.19337 .60233 .19447 .60366 .21537 .40256 .21439 .40067 Mtetra
.878 .687 .641 r
.21439 .40067 .21537 .40256 .2175 .39605 .21647 .39466 Mtetra
.756 .702 .801 r
.21647 .39466 .2175 .39605 .21913 .39467 .2181 .3934 Mtetra
.611 .675 .886 r
.2181 .3934 .21913 .39467 .22068 .39423 .21963 .39306 Mtetra
.465 .635 .929 r
.21963 .39306 .22068 .39423 .22219 .3942 .22113 .39314 Mtetra
.632 .722 .913 r
.22113 .39314 .22219 .3942 .22374 .39373 .22268 .39271 Mtetra
.664 .74 .906 r
.22268 .39271 .22374 .39373 .2253 .39317 .22424 .39216 Mtetra
.674 .745 .904 r
.22424 .39216 .2253 .39317 .22686 .39257 .2258 .39157 Mtetra
.756 .761 .857 r
.2258 .39157 .22686 .39257 .22847 .39147 .22741 .39051 Mtetra
.721 .764 .887 r
.22741 .39051 .22847 .39147 .23006 .39062 .22899 .3897 Mtetra
.548 .726 .957 r
.22899 .3897 .23006 .39062 .23159 .39038 .23052 .3895 Mtetra
.895 .474 .148 r
.23052 .3895 .23159 .39038 .23283 .3934 .23175 .39263 Mtetra
.942 .683 .517 r
.23175 .39263 .23283 .3934 .21638 .59236 .2152 .59186 Mtetra
.929 .597 .388 r
.2152 .59186 .21638 .59236 .21731 .59988 .21617 .59899 Mtetra
0 .433 .852 r
.21617 .59899 .21731 .59988 .21887 .60055 .21773 .59963 Mtetra
.671 .777 .929 r
.21773 .59963 .21887 .60055 .22054 .59993 .2194 .59901 Mtetra
.764 .79 .874 r
.2194 .59901 .22054 .59993 .22226 .59878 .22112 .59788 Mtetra
.557 .748 .966 r
.22112 .59788 .22226 .59878 .22391 .59846 .22277 .59763 Mtetra
.596 .776 .966 r
.22277 .59763 .22391 .59846 .22557 .59805 .22442 .59725 Mtetra
.773 .812 .884 r
.22442 .59725 .22557 .59805 .22729 .59696 .22615 .5961 Mtetra
.924 .738 .633 r
.22615 .5961 .22729 .59696 .22944 .59088 .22838 .5891 Mtetra
.942 .687 .523 r
.22838 .5891 .22944 .59088 .24837 .38973 .24746 .38717 Mtetra
.833 .65 .655 r
.24746 .38717 .24837 .38973 .25032 .38488 .24937 .38266 Mtetra
.444 .468 .79 r
.24937 .38266 .25032 .38488 .25172 .38635 .25086 .38307 Mtetra
.687 .415 0 r
.25086 .38307 .25172 .38635 .23661 .58295 .25202 .3875 Mtetra
0 0 .154 r
.25202 .3875 .23661 .58295 .23735 .59345 .23665 .58738 Mtetra
.314 .231 .6 r
.23665 .58738 .23735 .59345 .23889 .59459 .23809 .58972 Mtetra
.578 .441 .659 r
.23809 .58972 .23889 .59459 .24055 .59426 .23975 .58934 Mtetra
.606 .46 .657 r
.23975 .58934 .24055 .59426 .24225 .59348 .24145 .58857 Mtetra
.476 .37 .654 r
.24145 .58857 .24225 .59348 .24393 .59294 .24303 .58927 Mtetra
.405 .361 .696 r
.24303 .58927 .24393 .59294 .24561 .59245 .24458 .59023 Mtetra
.391 .452 .803 r
.24458 .59023 .24561 .59245 .24729 .59187 .24617 .59082 Mtetra
.381 .64 .958 r
.24617 .59082 .24729 .59187 .24897 .59141 .2478 .591 Mtetra
.477 .83 .996 r
.2478 .591 .24897 .59141 .25067 .59072 .24947 .59069 Mtetra
.675 .956 .947 r
.24947 .59069 .25067 .59072 .25242 .58937 .25119 .58978 Mtetra
.942 .941 .76 r
.25119 .58978 .25242 .58937 .25444 .58459 .25306 .58696 Mtetra
.992 .875 .55 r
.25306 .58696 .25444 .58459 .27196 .38337 .25529 .57957 Mtetra
0 0 .161 r
.25529 .57957 .27196 .38337 .27404 .37659 .27266 .37985 Mtetra
0 0 0 r
.27266 .37985 .27404 .37659 .27573 .37473 .27452 .37584 Mtetra
.632 .901 .589 r
.27452 .37584 .27573 .37473 .27732 .37412 .27621 .37401 Mtetra
.793 .953 .922 r
.27621 .37401 .27732 .37412 .27889 .37393 .27785 .37283 Mtetra
.711 .74 .874 r
.27785 .37283 .27889 .37393 .28047 .37352 .27946 .37203 Mtetra
.655 .66 .843 r
.27946 .37203 .28047 .37352 .28206 .37295 .28106 .37146 Mtetra
.631 .651 .852 r
.28106 .37146 .28206 .37295 .28365 .37238 .28264 .37102 Mtetra
.644 .676 .866 r
.28264 .37102 .28365 .37238 .28525 .37178 .28423 .37053 Mtetra
.656 .698 .877 r
.28423 .37053 .28525 .37178 .28685 .3712 .28583 .36999 Mtetra
.66 .706 .881 r
.28583 .36999 .28685 .3712 .28844 .3707 .28742 .36943 Mtetra
.672 .701 .869 r
.28742 .36943 .28844 .3707 .29002 .37046 .28902 .3688 Mtetra
.664 .643 .82 r
.28902 .3688 .29002 .37046 .29158 .3704 .29063 .36816 Mtetra
.639 .575 .767 r
.29063 .36816 .29158 .3704 .29314 .37031 .29223 .36756 Mtetra
.605 .523 .736 r
.29223 .36756 .29314 .37031 .29474 .36975 .29382 .36714 Mtetra
.589 .522 .747 r
.29382 .36714 .29474 .36975 .29637 .36885 .29541 .36685 Mtetra
.591 .572 .801 r
.29541 .36685 .29637 .36885 .298 .36791 .29699 .36658 Mtetra
.619 .673 .88 r
.29699 .36658 .298 .36791 .29961 .36719 .29858 .3662 Mtetra
.647 .746 .922 r
.29858 .3662 .29961 .36719 .30122 .36665 .30018 .3657 Mtetra
.662 .761 .923 r
.30018 .3657 .30122 .36665 .30282 .36612 .30178 .36514 Mtetra
.67 .756 .915 r
.30178 .36514 .30282 .36612 .30443 .36552 .30339 .36455 Mtetra
.676 .759 .914 r
.30339 .36455 .30443 .36552 .30604 .36485 .305 .36394 Mtetra
.679 .772 .921 r
.305 .36394 .30604 .36485 .30766 .36418 .30662 .36331 Mtetra
.742 .794 .894 r
.30662 .36331 .30766 .36418 .3093 .36323 .30825 .36238 Mtetra
.739 .797 .899 r
.30825 .36238 .3093 .36323 .31093 .36232 .30989 .36147 Mtetra
.597 .764 .959 r
.30989 .36147 .31093 .36232 .31253 .36196 .31148 .36111 Mtetra
.83 .361 0 r
.31148 .36111 .31253 .36196 .31395 .36429 .31289 .36362 Mtetra
.95 .684 .497 r
.31289 .36362 .31395 .36429 .30235 .56479 .30117 .56502 Mtetra
.91 .568 .384 r
.30117 .56502 .30235 .56479 .30351 .57283 .30239 .57201 Mtetra
.778 .818 .884 r
.30239 .57201 .30351 .57283 .30523 .57215 .30415 .5708 Mtetra
.942 .702 .547 r
.30415 .5708 .30523 .57215 .30748 .56347 .30727 .54866 Mtetra
.933 .671 .516 r
.30727 .54866 .30748 .56347 .322 .36187 .32111 .35879 Mtetra
.766 .601 .674 r
.32111 .35879 .322 .36187 .32379 .35857 .32287 .35597 Mtetra
.65 .558 .738 r
.32287 .35597 .32379 .35857 .32543 .35776 .3245 .35519 Mtetra
.594 .529 .751 r
.3245 .35519 .32543 .35776 .32703 .35747 .32611 .35486 Mtetra
.6 .53 .747 r
.32611 .35486 .32703 .35747 .32864 .35712 .32771 .35449 Mtetra
.625 .542 .741 r
.32771 .35449 .32864 .35712 .33026 .35655 .32934 .35392 Mtetra
.623 .541 .741 r
.32934 .35392 .33026 .35655 .33188 .356 .33096 .35336 Mtetra
.33096 .35336 .33188 .356 .33351 .35544 .33258 .3528 Mtetra
.624 .541 .741 r
.33258 .3528 .33351 .35544 .33513 .35488 .33421 .35223 Mtetra
.623 .541 .74 r
.33421 .35223 .33513 .35488 .33676 .35433 .33583 .35167 Mtetra
.623 .54 .74 r
.33583 .35167 .33676 .35433 .33838 .35381 .33746 .35111 Mtetra
.622 .537 .737 r
.33746 .35111 .33838 .35381 .34001 .3533 .33909 .35055 Mtetra
.619 .532 .734 r
.33909 .35055 .34001 .3533 .34164 .35274 .34071 .35 Mtetra
.613 .53 .737 r
.34071 .35 .34164 .35274 .34328 .35198 .34234 .34951 Mtetra
.611 .546 .756 r
.34234 .34951 .34328 .35198 .34493 .35105 .34396 .34907 Mtetra
.62 .591 .799 r
.34396 .34907 .34493 .35105 .34658 .35014 .34559 .34863 Mtetra
.649 .66 .847 r
.34559 .34863 .34658 .35014 .34822 .34938 .34722 .34809 Mtetra
.672 .703 .87 r
.34722 .34809 .34822 .34938 .34986 .34879 .34886 .34746 Mtetra
.65 .687 .872 r
.34886 .34746 .34986 .34879 .35149 .34825 .35049 .34693 Mtetra
.548 .649 .901 r
.35049 .34693 .35149 .34825 .35313 .34769 .3521 .3468 Mtetra
.169 .548 .929 r
.3521 .3468 .35313 .34769 .35476 .34708 .35369 .34724 Mtetra
.52 0 0 r
.35369 .34724 .35476 .34708 .3564 .34648 .35526 .34795 Mtetra
.526 .096 .167 r
.35526 .34795 .3564 .34648 .35804 .3459 .35684 .34836 Mtetra
.396 .028 .217 r
.35684 .34836 .35804 .3459 .35968 .34534 .35848 .34792 Mtetra
.343 0 .202 r
.35848 .34792 .35968 .34534 .36132 .34479 .36013 .34719 Mtetra
.254 0 .139 r
.36013 .34719 .36132 .34479 .36297 .34407 .3618 .34618 Mtetra
.2 0 .077 r
.3618 .34618 .36297 .34407 .36463 .3432 .36347 .34514 Mtetra
.368 0 .143 r
.36347 .34514 .36463 .3432 .36626 .34275 .3651 .34475 Mtetra
.714 .342 .343 r
.3651 .34475 .36626 .34275 .36783 .34369 .36661 .34688 Mtetra
.951 .679 .486 r
.36661 .34688 .36783 .34369 .36916 .34971 .35835 .54694 Mtetra
.546 .317 .519 r
.35835 .54694 .36916 .34971 .36097 .5516 .35974 .55369 Mtetra
.679 .299 .319 r
.35974 .55369 .36097 .5516 .36253 .55506 .36139 .55545 Mtetra
.083 0 0 r
.36139 .55545 .36253 .55506 .36425 .55534 .36313 .55527 Mtetra
.596 .936 .947 r
.36313 .55527 .36425 .55534 .366 .55496 .3649 .55449 Mtetra
.793 .899 .917 r
.3649 .55449 .366 .55496 .36776 .5544 .36669 .55324 Mtetra
.805 .768 .818 r
.36669 .55324 .36776 .5544 .36952 .55394 .36851 .55159 Mtetra
.757 .638 .73 r
.36851 .55159 .36952 .55394 .37128 .5534 .37033 .54963 Mtetra
.673 .533 .686 r
.37033 .54963 .37128 .5534 .37304 .55297 .37214 .54815 Mtetra
.558 .431 .663 r
.37214 .54815 .37304 .55297 .37479 .55275 .37388 .54801 Mtetra
.592 .456 .665 r
.37388 .54801 .37479 .55275 .37656 .55206 .37565 .54745 Mtetra
.722 .545 .649 r
.37565 .54745 .37656 .55206 .3784 .54996 .37752 .54453 Mtetra
.953 .685 .491 r
.37752 .54453 .3784 .54996 .38046 .54254 .38796 .3435 Mtetra
.551 .326 .527 r
.38796 .3435 .38046 .54254 .39082 .33924 .38994 .33534 Mtetra
.738 .563 .657 r
.38994 .33534 .39082 .33924 .39264 .33495 .3917 .33254 Mtetra
.664 .58 .751 r
.3917 .33254 .39264 .33495 .39432 .33401 .39337 .33167 Mtetra
.607 .554 .77 r
.39337 .33167 .39432 .33401 .39597 .33369 .39503 .33128 Mtetra
.583 .536 .768 r
.39503 .33128 .39597 .33369 .39762 .33336 .39668 .33103 Mtetra
.611 .558 .77 r
.39668 .33103 .39762 .33336 .3993 .3324 .39834 .3306 Mtetra
.62 .614 .822 r
.39834 .3306 .3993 .3324 .40098 .33146 .4 .33018 Mtetra
.643 .697 .885 r
.4 .33018 .40098 .33146 .40266 .33065 .40166 .32967 Mtetra
.682 .768 .916 r
.40166 .32967 .40266 .33065 .40433 .33009 .40333 .32901 Mtetra
.689 .748 .897 r
.40333 .32901 .40433 .33009 .40599 .32959 .40501 .32831 Mtetra
.687 .712 .867 r
.40501 .32831 .40599 .32959 .40766 .32907 .40668 .32758 Mtetra
.683 .678 .839 r
.40668 .32758 .40766 .32907 .40933 .32846 .40836 .32683 Mtetra
.656 .65 .832 r
.40836 .32683 .40933 .32846 .411 .32783 .41003 .32622 Mtetra
.614 .634 .847 r
.41003 .32622 .411 .32783 .41268 .32709 .4117 .32584 Mtetra
.503 .644 .919 r
.4117 .32584 .41268 .32709 .41437 .32609 .41335 .32583 Mtetra
.307 0 0 r
.41335 .32583 .41437 .32609 .41604 .3255 .41499 .32643 Mtetra
.777 .36 .26 r
.41499 .32643 .41604 .3255 .41768 .32599 .41656 .32886 Mtetra
.956 .679 .471 r
.41656 .32886 .41768 .32599 .41917 .33114 .41144 .5292 Mtetra
.547 .318 .519 r
.41144 .5292 .41917 .33114 .41413 .53414 .41296 .5367 Mtetra
.683 .317 .346 r
.41296 .5367 .41413 .53414 .41577 .53827 .41466 .53873 Mtetra
.106 0 0 r
.41466 .53873 .41577 .53827 .41755 .53817 .41645 .53853 Mtetra
.327 .801 .721 r
.41645 .53853 .41755 .53817 .41935 .53735 .41825 .53779 Mtetra
.405 .843 .72 r
.41825 .53779 .41935 .53735 .42116 .53642 .42005 .53686 Mtetra
0 0 0 r
.42005 .53686 .42116 .53642 .42294 .53628 .42185 .53626 Mtetra
.458 .883 .91 r
.42185 .53626 .42294 .53628 .42472 .53614 .42365 .53566 Mtetra
.602 .874 .992 r
.42365 .53566 .42472 .53614 .42651 .53588 .42545 .53508 Mtetra
.599 .8 .976 r
.42545 .53508 .42651 .53588 .42831 .53537 .42725 .53464 Mtetra
.632 .826 .975 r
.42725 .53464 .42831 .53537 .43011 .53478 .42905 .53407 Mtetra
.714 .85 .947 r
.42905 .53407 .43011 .53478 .43192 .53417 .43087 .53321 Mtetra
.821 .807 .837 r
.43087 .53321 .43192 .53417 .43372 .53363 .4327 .53153 Mtetra
.777 .666 .741 r
.4327 .53153 .43372 .53363 .43553 .53309 .43455 .52948 Mtetra
.717 .565 .682 r
.43455 .52948 .43553 .53309 .43733 .53252 .43639 .52734 Mtetra
.613 .462 .653 r
.43639 .52734 .43733 .53252 .43914 .5319 .43821 .52638 Mtetra
.582 .436 .647 r
.43821 .52638 .43914 .5319 .44095 .53127 .44001 .52585 Mtetra
.575 .432 .65 r
.44001 .52585 .44095 .53127 .44276 .53063 .44182 .52545 Mtetra
.613 .462 .653 r
.44182 .52545 .44276 .53063 .44458 .53 .44364 .52449 Mtetra
.594 .444 .647 r
.44364 .52449 .44458 .53 .44639 .52938 .44545 .52379 Mtetra
.552 .414 .646 r
.44545 .52379 .44639 .52938 .4482 .52877 .44725 .5237 Mtetra
.438 .346 .654 r
.44725 .5237 .4482 .52877 .45002 .52819 .44903 .52485 Mtetra
.419 .393 .723 r
.44903 .52485 .45002 .52819 .45183 .52761 .45081 .52571 Mtetra
.43 .519 .849 r
.45081 .52571 .45183 .52761 .45365 .52704 .45261 .52611 Mtetra
.635 .783 .952 r
.45261 .52611 .45365 .52704 .45547 .52644 .45442 .52557 Mtetra
.69 .812 .94 r
.45442 .52557 .45547 .52644 .45729 .52585 .45625 .52481 Mtetra
.704 .78 .911 r
.45625 .52481 .45729 .52585 .45911 .52529 .45808 .52398 Mtetra
.646 .713 .896 r
.45808 .52398 .45911 .52529 .46093 .52484 .4599 .52342 Mtetra
.632 .688 .885 r
.4599 .52342 .46093 .52484 .46275 .52436 .46172 .52292 Mtetra
.614 .679 .888 r
.46172 .52292 .46275 .52436 .46457 .52381 .46354 .52251 Mtetra
.465 .636 .929 r
.46354 .52251 .46457 .52381 .4664 .52342 .46536 .5226 Mtetra
.531 .772 .986 r
.46536 .5226 .4664 .52342 .46823 .52258 .46718 .52233 Mtetra
.687 .943 .961 r
.46718 .52233 .46823 .52258 .47008 .52084 .46901 .52139 Mtetra
.972 .929 .663 r
.46901 .52139 .47008 .52084 .47202 .51295 .4709 .51749 Mtetra
.965 .802 .37 r
.4709 .51749 .47202 .51295 .47696 .30881 .47294 .50315 Mtetra
0 0 .295 r
.47294 .50315 .47696 .30881 .47874 .30404 .47772 .30646 Mtetra
0 0 0 r
.47772 .30646 .47874 .30404 .48046 .30296 .47947 .30387 Mtetra
.47947 .30387 .48046 .30296 .48217 .30253 .4812 .30236 Mtetra
.711 .959 .947 r
.4812 .30236 .48217 .30253 .48389 .30244 .48292 .30137 Mtetra
.688 .758 .905 r
.48292 .30137 .48389 .30244 .4856 .3019 .48464 .30066 Mtetra
.649 .712 .894 r
.48464 .30066 .4856 .3019 .48732 .30132 .48636 .30011 Mtetra
.634 .713 .904 r
.48636 .30011 .48732 .30132 .48904 .3007 .48808 .29963 Mtetra
.678 .756 .91 r
.48808 .29963 .48904 .3007 .49077 .29992 .48981 .29896 Mtetra
.689 .783 .922 r
.48981 .29896 .49077 .29992 .49249 .29915 .49153 .29825 Mtetra
.698 .797 .927 r
.49153 .29825 .49249 .29915 .49422 .29845 .49326 .2975 Mtetra
.788 .803 .864 r
.49326 .2975 .49422 .29845 .49594 .29764 .49499 .29621 Mtetra
.712 .704 .84 r
.49499 .29621 .49594 .29764 .49767 .29719 .49672 .29527 Mtetra
.586 .587 .82 r
.49672 .29527 .49767 .29719 .49939 .29744 .49844 .29501 Mtetra
0 0 .431 r
.49844 .29501 .49939 .29744 .50108 .30202 .50014 .29844 Mtetra
.971 .687 .433 r
.50014 .29844 .50108 .30202 .50136 .50634 .50036 .5033 Mtetra
.816 .491 0 r
.50036 .5033 .50136 .50634 .50317 .51136 .50215 .51025 Mtetra
.273 .574 .939 r
.50215 .51025 .50317 .51136 .50502 .51174 .504 .51068 Mtetra
.647 .764 .934 r
.504 .51068 .50502 .51174 .50687 .51119 .50585 .5101 Mtetra
.727 .781 .895 r
.50585 .5101 .50687 .51119 .50873 .51018 .50771 .50912 Mtetra
.38 .647 .961 r
.50771 .50912 .50873 .51018 .51058 .50978 .50956 .50931 Mtetra
.338 .76 .976 r
.50956 .50931 .51058 .50978 .51244 .50908 .51142 .50921 Mtetra
.491 .904 .855 r
.51142 .50921 .51244 .50908 .5143 .50763 .51328 .50837 Mtetra
.979 .915 .61 r
.51328 .50837 .5143 .50763 .51617 .50178 .51515 .5038 Mtetra
.972 .693 .441 r
.51515 .5038 .51617 .50178 .51845 .2961 .51749 .29805 Mtetra
.99 .833 .458 r
.51749 .29805 .51845 .2961 .5202 .29008 .51926 .28905 Mtetra
.828 .796 .821 r
.51926 .28905 .5202 .29008 .52195 .28855 .521 .28734 Mtetra
.662 .724 .895 r
.521 .28734 .52195 .28855 .52369 .28795 .52274 .28673 Mtetra
.55 .678 .923 r
.52274 .28673 .52369 .28795 .52543 .28772 .52449 .28656 Mtetra
.736 .758 .87 r
.52449 .28656 .52543 .28772 .52718 .2867 .52623 .28555 Mtetra
.708 .752 .887 r
.52623 .28555 .52718 .2867 .52892 .28587 .52798 .28472 Mtetra
.546 .691 .934 r
.52798 .28472 .52892 .28587 .53067 .28569 .52973 .28454 Mtetra
.797 .351 0 r
.52973 .28454 .53067 .28569 .53243 .28912 .53148 .28796 Mtetra
.97 .683 .426 r
.53148 .28796 .53243 .28912 .53479 .49448 .53379 .49335 Mtetra
.922 .534 .156 r
.53379 .49335 .53479 .49448 .53669 .50094 .53568 .49985 Mtetra
0 .349 .816 r
.53568 .49985 .53669 .50094 .53857 .50199 .53756 .50091 Mtetra
.594 .742 .947 r
.53756 .50091 .53857 .50199 .54044 .5016 .53944 .50052 Mtetra
.795 .798 .854 r
.53944 .50052 .54044 .5016 .54232 .50013 .54131 .49904 Mtetra
.934 .777 .662 r
.54131 .49904 .54232 .50013 .54417 .49537 .54317 .49428 Mtetra
.971 .689 .436 r
.54317 .49428 .54417 .49537 .54474 .28911 .5438 .28795 Mtetra
.954 .743 .578 r
.5438 .28795 .54474 .28911 .54645 .28101 .54551 .27987 Mtetra
.832 .78 .803 r
.54551 .27987 .54645 .28101 .5482 .27916 .54726 .27802 Mtetra
.666 .741 .906 r
.54726 .27802 .5482 .27916 .54995 .27853 .54902 .27739 Mtetra
.551 .695 .935 r
.54902 .27739 .54995 .27853 .55172 .27834 .55078 .27719 Mtetra
.719 .759 .884 r
.55078 .27719 .55172 .27834 .55348 .27744 .55254 .27629 Mtetra
.712 .756 .887 r
.55254 .27629 .55348 .27744 .55524 .27658 .5543 .27543 Mtetra
.568 .702 .932 r
.5543 .27543 .55524 .27658 .557 .27633 .55607 .27518 Mtetra
.695 .235 0 r
.55607 .27518 .557 .27633 .55881 .27916 .55787 .278 Mtetra
.972 .681 .415 r
.55787 .278 .55881 .27916 .56294 .48376 .56194 .48259 Mtetra
.935 .561 .191 r
.56194 .48259 .56294 .48376 .56493 .49165 .56393 .49054 Mtetra
.011 .403 .854 r
.56393 .49054 .56493 .49165 .56684 .49265 .56585 .49149 Mtetra
.634 .744 .928 r
.56585 .49149 .56684 .49265 .56873 .49215 .56774 .49096 Mtetra
.726 .769 .887 r
.56774 .49096 .56873 .49215 .57063 .49109 .56963 .48995 Mtetra
.537 .708 .95 r
.56963 .48995 .57063 .49109 .57252 .49049 .57154 .48976 Mtetra
.447 .762 .996 r
.57154 .48976 .57252 .49049 .57442 .48983 .57344 .48962 Mtetra
.601 .931 .96 r
.57344 .48962 .57442 .48983 .57631 .48852 .57534 .48882 Mtetra
.971 .93 .667 r
.57534 .48882 .57631 .48852 .57815 .4839 .57719 .48503 Mtetra
.975 .69 .42 r
.57719 .48503 .57815 .4839 .57662 .27802 .57579 .28248 Mtetra
.907 .764 .273 r
.57579 .28248 .57662 .27802 .57828 .27028 .57736 .26931 Mtetra
.879 .813 .78 r
.57736 .26931 .57828 .27028 .58003 .26822 .57911 .267 Mtetra
.681 .735 .891 r
.57911 .267 .58003 .26822 .58181 .26751 .58089 .26628 Mtetra
.564 .685 .921 r
.58089 .26628 .58181 .26751 .5836 .26724 .58268 .26605 Mtetra
.701 .749 .889 r
.58268 .26605 .5836 .26724 .58538 .26639 .58446 .26524 Mtetra
.721 .76 .884 r
.58446 .26524 .58538 .26639 .58715 .26547 .58623 .26432 Mtetra
.588 .713 .93 r
.58623 .26432 .58715 .26547 .58894 .26514 .58802 .26399 Mtetra
.584 .121 0 r
.58802 .26399 .58894 .26514 .59079 .26754 .58987 .26641 Mtetra
.973 .68 .402 r
.58987 .26641 .59079 .26754 .59707 .47162 .59609 .47062 Mtetra
.94 .571 .213 r
.59609 .47062 .59707 .47162 .59919 .48077 .59822 .47968 Mtetra
0 .151 .66 r
.59822 .47968 .59919 .48077 .60116 .4824 .60018 .4813 Mtetra
.536 .719 .957 r
.60018 .4813 .60116 .4824 .60309 .48219 .60211 .48109 Mtetra
.768 .799 .878 r
.60211 .48109 .60309 .48219 .60499 .48093 .60402 .47983 Mtetra
.923 .795 .7 r
.60402 .47983 .60499 .48093 .60684 .47712 .60586 .47603 Mtetra
.975 .687 .413 r
.60586 .47603 .60684 .47712 .60366 .27591 .60275 .27498 Mtetra
.976 .729 .498 r
.60275 .27498 .60366 .27591 .6051 .2613 .60419 .26015 Mtetra
.878 .789 .758 r
.60419 .26015 .6051 .2613 .60684 .25878 .60593 .25763 Mtetra
.682 .751 .904 r
.60593 .25763 .60684 .25878 .60864 .25806 .60773 .25692 Mtetra
.553 .7 .938 r
.60773 .25692 .60864 .25806 .61045 .25784 .60954 .2567 Mtetra
.603 .724 .93 r
.60954 .2567 .61045 .25784 .61225 .25741 .61134 .25631 Mtetra
.671 .759 .917 r
.61134 .25631 .61225 .25741 .61405 .2567 .61314 .25565 Mtetra
.68 .771 .92 r
.61314 .25565 .61405 .2567 .61585 .25604 .61495 .25495 Mtetra
.754 .785 .878 r
.61495 .25495 .61585 .25604 .61765 .25525 .61673 .25383 Mtetra
.741 .726 .837 r
.61673 .25383 .61765 .25525 .61945 .25457 .61852 .25268 Mtetra
.64 .623 .818 r
.61852 .25268 .61945 .25457 .62127 .25444 .62033 .2521 Mtetra
.159 .289 .749 r
.62033 .2521 .62127 .25444 .62317 .25674 .62221 .25372 Mtetra
.958 .638 .23 r
.62221 .25372 .62317 .25674 .63162 .46029 .62464 .27234 Mtetra
0 0 .365 r
.62464 .27234 .63162 .46029 .63387 .4694 .6329 .46797 Mtetra
0 .048 .599 r
.6329 .46797 .63387 .4694 .63589 .47123 .63494 .47019 Mtetra
.48 .706 .969 r
.63494 .47019 .63589 .47123 .63785 .47115 .6369 .47012 Mtetra
.758 .815 .898 r
.6369 .47012 .63785 .47115 .63978 .47001 .63882 .46895 Mtetra
.922 .807 .715 r
.63882 .46895 .63978 .47001 .64162 .46653 .64067 .46544 Mtetra
.978 .705 .441 r
.64067 .46544 .64162 .46653 .63673 .27645 .64145 .43247 Mtetra
0 0 .314 r
.64145 .43247 .63673 .27645 .63762 .25006 .63672 .24889 Mtetra
.896 .79 .736 r
.63672 .24889 .63762 .25006 .63935 .24718 .63846 .24601 Mtetra
.704 .757 .893 r
.63846 .24601 .63935 .24718 .64116 .24635 .64027 .24517 Mtetra
.587 .711 .929 r
.64027 .24517 .64116 .24635 .64299 .24602 .6421 .24485 Mtetra
.666 .743 .908 r
.6421 .24485 .64299 .24602 .64481 .24537 .64392 .2442 Mtetra
.733 .766 .879 r
.64392 .2442 .64481 .24537 .64662 .24437 .64573 .24319 Mtetra
.636 .731 .917 r
.64573 .24319 .64662 .24437 .64845 .24385 .64755 .24267 Mtetra
0 .282 .78 r
.64755 .24267 .64845 .24385 .65035 .24517 .64946 .24399 Mtetra
.938 .574 .185 r
.64946 .24399 .65035 .24517 .65261 .25502 .65172 .25384 Mtetra
.975 .675 .374 r
.65172 .25384 .65261 .25502 .66305 .45888 .66211 .45775 Mtetra
0 0 .512 r
.66211 .45775 .66305 .45888 .66514 .46115 .66419 .46002 Mtetra
.629 .756 .938 r
.66419 .46002 .66514 .46115 .6671 .46061 .66616 .45948 Mtetra
.769 .8 .878 r
.66616 .45948 .6671 .46061 .66904 .45933 .66809 .4582 Mtetra
.782 .803 .87 r
.66809 .4582 .66904 .45933 .67097 .45794 .67002 .45681 Mtetra
.73 .79 .9 r
.67002 .45681 .67097 .45794 .67291 .45691 .67197 .45578 Mtetra
.716 .786 .907 r
.67197 .45578 .67291 .45691 .67486 .45596 .67392 .45482 Mtetra
.655 .765 .93 r
.67392 .45482 .67486 .45596 .67683 .4553 .67589 .45417 Mtetra
.563 .727 .951 r
.67589 .45417 .67683 .4553 .67882 .45501 .67788 .45387 Mtetra
.534 .713 .954 r
.67788 .45387 .67882 .45501 .68081 .45481 .67987 .45367 Mtetra
.443 .667 .958 r
.67987 .45367 .68081 .45481 .68281 .45488 .68187 .45374 Mtetra
.415 .652 .956 r
.68187 .45374 .68281 .45488 .68482 .45503 .68389 .45389 Mtetra
.629 .755 .938 r
.68389 .45389 .68482 .45503 .6868 .45449 .68587 .45335 Mtetra
.89 .812 .765 r
.68587 .45335 .6868 .45449 .68868 .45179 .68774 .45065 Mtetra
.981 .723 .466 r
.68774 .45065 .68868 .45179 .68978 .43387 .68885 .43267 Mtetra
.977 .681 .379 r
.68885 .43267 .68978 .43387 .68158 .23496 .68071 .23376 Mtetra
.912 .79 .713 r
.68071 .23376 .68158 .23496 .6833 .23171 .68242 .23051 Mtetra
.709 .758 .89 r
.68242 .23051 .6833 .23171 .68513 .23083 .68425 .22963 Mtetra
.589 .709 .927 r
.68425 .22963 .68513 .23083 .68699 .23049 .68612 .22929 Mtetra
.625 .725 .919 r
.68612 .22929 .68699 .23049 .68885 .23001 .68798 .22881 Mtetra
.733 .765 .879 r
.68798 .22881 .68885 .23001 .69068 .229 .68981 .22779 Mtetra
.643 .732 .913 r
.68981 .22779 .69068 .229 .69254 .22844 .69166 .22723 Mtetra
.086 .412 .862 r
.69166 .22723 .69254 .22844 .69448 .22944 .69361 .22822 Mtetra
.916 .539 .116 r
.69361 .22822 .69448 .22944 .69687 .23827 .69598 .23689 Mtetra
.975 .671 .351 r
.69598 .23689 .69687 .23827 .71046 .44415 .70953 .44295 Mtetra
.592 .136 0 r
.70953 .44295 .71046 .44415 .71266 .44717 .71173 .44595 Mtetra
.464 .662 .947 r
.71173 .44595 .71266 .44717 .7147 .4473 .71377 .446 Mtetra
.71 .757 .888 r
.71377 .446 .7147 .4473 .71668 .44633 .71575 .44504 Mtetra
.855 .795 .791 r
.71575 .44504 .71668 .44633 .71855 .44357 .71765 .44278 Mtetra
.975 .815 .621 r
.71765 .44278 .71855 .44357 .71996 .43311 .71937 .43741 Mtetra
.979 .683 .351 r
.71937 .43741 .71996 .43311 .70945 .22593 .70897 .23108 Mtetra
0 0 .148 r
.70897 .23108 .70945 .22593 .71112 .2221 .71044 .22388 Mtetra
0 0 0 r
.71044 .22388 .71112 .2221 .71297 .22118 .71221 .22171 Mtetra
.442 .825 .589 r
.71221 .22171 .71297 .22118 .71486 .22087 .71404 .22035 Mtetra
.71 .915 .965 r
.71404 .22035 .71486 .22087 .71675 .2207 .71589 .21942 Mtetra
.673 .731 .894 r
.71589 .21942 .71675 .2207 .71863 .22011 .71775 .21871 Mtetra
.641 .697 .886 r
.71775 .21871 .71863 .22011 .7205 .2195 .71963 .21815 Mtetra
.669 .718 .886 r
.71963 .21815 .7205 .2195 .72236 .21871 .7215 .21746 Mtetra
.746 .764 .868 r
.7215 .21746 .72236 .21871 .7242 .21758 .72334 .21634 Mtetra
.665 .736 .903 r
.72334 .21634 .7242 .21758 .72607 .21691 .72522 .21567 Mtetra
.242 .51 .907 r
.72522 .21567 .72607 .21691 .72804 .21757 .72718 .21634 Mtetra
.89 .503 .052 r
.72718 .21634 .72804 .21757 .73048 .22534 .72962 .22406 Mtetra
.975 .667 .334 r
.72962 .22406 .73048 .22534 .74652 .43258 .74561 .43141 Mtetra
.638 .185 0 r
.74561 .43141 .74652 .43258 .74881 .43596 .74791 .4348 Mtetra
.389 .633 .952 r
.74791 .4348 .74881 .43596 .75089 .43619 .74999 .43503 Mtetra
.693 .78 .918 r
.74999 .43503 .75089 .43619 .7529 .43534 .752 .43417 Mtetra
.873 .82 .793 r
.752 .43417 .7529 .43534 .75481 .43299 .7539 .43182 Mtetra
.978 .768 .554 r
.7539 .43182 .75481 .43299 .75631 .42511 .75542 .42396 Mtetra
.977 .675 .347 r
.75542 .42396 .75631 .42511 .74329 .21524 .74244 .21403 Mtetra
.952 .785 .64 r
.74244 .21403 .74329 .21524 .74489 .21055 .74404 .20934 Mtetra
.746 .774 .875 r
.74404 .20934 .74489 .21055 .74674 .20944 .7459 .20822 Mtetra
.617 .724 .922 r
.7459 .20822 .74674 .20944 .74864 .20897 .7478 .20776 Mtetra
.585 .71 .929 r
.7478 .20776 .74864 .20897 .75056 .20863 .74971 .20743 Mtetra
.75 .777 .875 r
.74971 .20743 .75056 .20863 .75241 .2075 .75157 .20629 Mtetra
.672 .747 .908 r
.75157 .20629 .75241 .2075 .7543 .20679 .75346 .20559 Mtetra
.339 .578 .93 r
.75346 .20559 .7543 .20679 .75627 .20715 .75543 .206 Mtetra
.857 .454 0 r
.75543 .206 .75627 .20715 .75867 .21297 .75788 .21257 Mtetra
.973 .662 .321 r
.75788 .21257 .75867 .21297 .77685 .42196 .77601 .4215 Mtetra
.785 .299 0 r
.77601 .4215 .77685 .42196 .77925 .42598 .77839 .42522 Mtetra
.484 .782 .997 r
.77839 .42522 .77925 .42598 .78133 .42586 .78047 .42497 Mtetra
.721 .85 .943 r
.78047 .42497 .78133 .42586 .78336 .42498 .78248 .42397 Mtetra
.761 .836 .909 r
.78248 .42397 .78336 .42498 .78537 .42388 .78448 .42275 Mtetra
.509 .709 .961 r
.78448 .42275 .78537 .42388 .78746 .42377 .78657 .42261 Mtetra
.63 .759 .94 r
.78657 .42261 .78746 .42377 .78951 .4232 .78863 .42204 Mtetra
.811 .818 .856 r
.78863 .42204 .78951 .4232 .79148 .42155 .7906 .4204 Mtetra
.98 .775 .556 r
.7906 .4204 .79148 .42155 .79296 .41406 .79209 .41294 Mtetra
.976 .671 .329 r
.79209 .41294 .79296 .41406 .7775 .20359 .77666 .20239 Mtetra
.962 .786 .619 r
.77666 .20239 .7775 .20359 .77904 .19851 .7782 .19728 Mtetra
.754 .777 .872 r
.7782 .19728 .77904 .19851 .7809 .19734 .78007 .19611 Mtetra
.623 .725 .92 r
.78007 .19611 .7809 .19734 .78283 .19685 .782 .19562 Mtetra
.553 .692 .932 r
.782 .19562 .78283 .19685 .78478 .19663 .78395 .1954 Mtetra
.748 .775 .875 r
.78395 .1954 .78478 .19663 .78665 .1955 .78582 .19427 Mtetra
.678 .748 .904 r
.78582 .19427 .78665 .1955 .78856 .19476 .78773 .19352 Mtetra
.456 .64 .935 r
.78773 .19352 .78856 .19476 .79054 .19486 .78972 .19363 Mtetra
.769 .354 0 r
.78972 .19363 .79054 .19486 .79298 .20007 .79215 .19883 Mtetra
.971 .657 .298 r
.79215 .19883 .79298 .20007 .81372 .40997 .81285 .40878 Mtetra
.726 .292 0 r
.81285 .40878 .81372 .40997 .81626 .41462 .81539 .41343 Mtetra
.308 .581 .938 r
.81539 .41343 .81626 .41462 .81843 .41509 .81756 .4139 Mtetra
.651 .764 .932 r
.81756 .4139 .81843 .41509 .8205 .41443 .81963 .41323 Mtetra
.831 .82 .839 r
.81963 .41323 .8205 .41443 .82247 .4126 .82159 .41139 Mtetra
.975 .787 .586 r
.82159 .41139 .82247 .4126 .82402 .4064 .82315 .40515 Mtetra
.974 .667 .312 r
.82315 .40515 .82402 .4064 .80644 .19507 .80561 .19374 Mtetra
.97 .77 .578 r
.80561 .19374 .80644 .19507 .80784 .18879 .80702 .18751 Mtetra
.757 .752 .848 r
.18754 .40362 .18861 .40465 .19021 .40357 .18914 .40254 Mtetra
.613 .721 .922 r
.18914 .40254 .19021 .40357 .19173 .40322 .19066 .40219 Mtetra
.463 .665 .95 r
.19066 .40219 .19173 .40322 .19321 .40325 .19214 .40222 Mtetra
.653 .732 .908 r
.19214 .40222 .19321 .40325 .19475 .40274 .19368 .40172 Mtetra
.661 .735 .905 r
.19368 .40172 .19475 .40274 .19629 .40221 .19522 .40118 Mtetra
.667 .737 .902 r
.19522 .40118 .19629 .40221 .19783 .40165 .19677 .40062 Mtetra
.76 .754 .848 r
.19677 .40062 .19783 .40165 .19943 .40055 .19837 .39952 Mtetra
.707 .747 .883 r
.19837 .39952 .19943 .40055 .201 .39979 .19993 .39877 Mtetra
.5 .683 .948 r
.19993 .39877 .201 .39979 .2025 .39974 .20143 .39872 Mtetra
.931 .558 .268 r
.20143 .39872 .2025 .39974 .20356 .40408 .20249 .40302 Mtetra
.939 .683 .523 r
.20249 .40302 .20356 .40408 .18523 .60406 .18409 .60306 Mtetra
.934 .575 .308 r
.18409 .60306 .18523 .60406 .18632 .60918 .18517 .6082 Mtetra
0 .379 .822 r
.18517 .6082 .18632 .60918 .18784 .60992 .18669 .60895 Mtetra
.631 .754 .936 r
.18669 .60895 .18784 .60992 .18948 .60947 .18833 .60849 Mtetra
.807 .776 .824 r
.18833 .60849 .18948 .60947 .19123 .60792 .19009 .60692 Mtetra
.909 .735 .654 r
.19009 .60692 .19123 .60792 .19337 .60233 .19225 .6011 Mtetra
.938 .687 .53 r
.19225 .6011 .19337 .60233 .21439 .40067 .21337 .39917 Mtetra
.889 .705 .647 r
.21337 .39917 .21439 .40067 .21647 .39466 .21543 .39343 Mtetra
.759 .723 .819 r
.21543 .39343 .21647 .39466 .2181 .3934 .21705 .39223 Mtetra
.595 .688 .907 r
.21705 .39223 .2181 .3934 .21963 .39306 .21858 .39194 Mtetra
.428 .63 .938 r
.21858 .39194 .21963 .39306 .22113 .39314 .22007 .39207 Mtetra
.624 .72 .915 r
.22007 .39207 .22113 .39314 .22268 .39271 .22162 .39168 Mtetra
.66 .736 .906 r
.22162 .39168 .22268 .39271 .22424 .39216 .22318 .39114 Mtetra
.672 .742 .903 r
.22318 .39114 .22424 .39216 .2258 .39157 .22474 .39056 Mtetra
.754 .759 .856 r
.22474 .39056 .2258 .39157 .22741 .39051 .22635 .38951 Mtetra
.718 .755 .882 r
.22635 .38951 .22741 .39051 .22899 .3897 .22793 .3887 Mtetra
.553 .71 .945 r
.22793 .3887 .22899 .3897 .23052 .3895 .22946 .38851 Mtetra
.896 .476 .131 r
.22946 .38851 .23052 .3895 .23175 .39263 .23069 .39167 Mtetra
.942 .683 .517 r
.23069 .39167 .23175 .39263 .2152 .59186 .21405 .59106 Mtetra
.937 .603 .373 r
.21405 .59106 .2152 .59186 .21617 .59899 .21503 .59807 Mtetra
0 .439 .858 r
.21503 .59807 .21617 .59899 .21773 .59963 .21659 .59872 Mtetra
.67 .777 .93 r
.21659 .59872 .21773 .59963 .2194 .59901 .21826 .5981 Mtetra
.763 .791 .876 r
.21826 .5981 .2194 .59901 .22112 .59788 .21998 .59699 Mtetra
.548 .745 .968 r
.21998 .59699 .22112 .59788 .22277 .59763 .22162 .59675 Mtetra
.591 .765 .962 r
.22162 .59675 .22277 .59763 .22442 .59725 .22328 .5964 Mtetra
.767 .802 .881 r
.22328 .5964 .22442 .59725 .22615 .5961 .225 .59527 Mtetra
.922 .744 .642 r
.225 .59527 .22615 .5961 .22838 .5891 .22718 .58886 Mtetra
.943 .689 .522 r
.22718 .58886 .22838 .5891 .24746 .38717 .24636 .38659 Mtetra
.926 .766 .665 r
.24636 .38659 .24746 .38717 .24937 .38266 .24832 .38164 Mtetra
.654 .74 .913 r
.24832 .38164 .24937 .38266 .25086 .38307 .24989 .38113 Mtetra
.031 .244 .746 r
.24989 .38113 .25086 .38307 .25202 .3875 .25131 .38243 Mtetra
.036 .044 .536 r
.25131 .38243 .25202 .3875 .23665 .58738 .25255 .38581 Mtetra
.531 .309 .523 r
.25255 .38581 .23665 .58738 .23809 .58972 .25397 .38716 Mtetra
.535 .313 .524 r
.25397 .38716 .23809 .58972 .23975 .58934 .25557 .38644 Mtetra
.533 .311 .524 r
.25557 .38644 .23975 .58934 .24145 .58857 .2571 .38657 Mtetra
0 0 .199 r
.2571 .38657 .24145 .58857 .24303 .58927 .24261 .57977 Mtetra
0 0 .411 r
.24261 .57977 .24303 .58927 .24458 .59023 .24363 .58714 Mtetra
0 .02 .576 r
.24363 .58714 .24458 .59023 .24617 .59082 .24506 .58969 Mtetra
.187 .516 .915 r
.24506 .58969 .24617 .59082 .2478 .591 .24666 .59022 Mtetra
.583 .788 .977 r
.24666 .59022 .2478 .591 .24947 .59069 .24833 .58986 Mtetra
.736 .807 .908 r
.24833 .58986 .24947 .59069 .25119 .58978 .25005 .58893 Mtetra
.821 .802 .833 r
.25005 .58893 .25119 .58978 .25306 .58696 .25183 .58729 Mtetra
.933 .943 .776 r
.25183 .58729 .25306 .58696 .25529 .57957 .25368 .58465 Mtetra
0 0 .007 r
.25368 .58465 .25529 .57957 .27266 .37985 .25572 .57971 Mtetra
0 0 .181 r
.25572 .57971 .27266 .37985 .27452 .37584 .27291 .3821 Mtetra
0 0 0 r
.27291 .3821 .27452 .37584 .27621 .37401 .27501 .37499 Mtetra
.934 .966 .685 r
.27501 .37499 .27621 .37401 .27785 .37283 .2768 .37197 Mtetra
.8 .796 .848 r
.2768 .37197 .27785 .37283 .27946 .37203 .27845 .37063 Mtetra
.666 .678 .852 r
.27845 .37063 .27946 .37203 .28106 .37146 .28005 .37002 Mtetra
.609 .65 .865 r
.28005 .37002 .28106 .37146 .28264 .37102 .28162 .36968 Mtetra
.632 .675 .873 r
.28162 .36968 .28264 .37102 .28423 .37053 .28321 .36924 Mtetra
.654 .692 .873 r
.28321 .36924 .28423 .37053 .28583 .36999 .28481 .3687 Mtetra
.657 .694 .873 r
.28481 .3687 .28583 .36999 .28742 .36943 .2864 .36815 Mtetra
.677 .701 .865 r
.2864 .36815 .28742 .36943 .28902 .3688 .28801 .3675 Mtetra
.682 .699 .859 r
.28801 .3675 .28902 .3688 .29063 .36816 .28962 .36682 Mtetra
.67 .689 .86 r
.28962 .36682 .29063 .36816 .29223 .36756 .29122 .3662 Mtetra
.62 .668 .875 r
.29122 .3662 .29223 .36756 .29382 .36714 .29281 .36581 Mtetra
.573 .656 .893 r
.29281 .36581 .29382 .36714 .29541 .36685 .29438 .36561 Mtetra
.557 .665 .909 r
.29438 .36561 .29541 .36685 .29699 .36658 .29596 .36545 Mtetra
.6 .702 .915 r
.29596 .36545 .29699 .36658 .29858 .3662 .29755 .36512 Mtetra
.643 .729 .911 r
.29755 .36512 .29858 .3662 .30018 .3657 .29915 .36464 Mtetra
.661 .738 .907 r
.29915 .36464 .30018 .3657 .30178 .36514 .30075 .36409 Mtetra
.667 .74 .905 r
.30075 .36409 .30178 .36514 .30339 .36455 .30236 .36351 Mtetra
.67 .743 .905 r
.30236 .36351 .30339 .36455 .305 .36394 .30397 .36291 Mtetra
.674 .748 .907 r
.30397 .36291 .305 .36394 .30662 .36331 .30558 .3623 Mtetra
.734 .765 .877 r
.30558 .3623 .30662 .36331 .30825 .36238 .30722 .36138 Mtetra
.732 .766 .88 r
.30722 .36138 .30825 .36238 .30989 .36147 .30885 .36048 Mtetra
.603 .734 .937 r
.30885 .36048 .30989 .36147 .31148 .36111 .31045 .36013 Mtetra
.825 .361 0 r
.31045 .36013 .31148 .36111 .31289 .36362 .31185 .3627 Mtetra
.951 .685 .497 r
.31185 .3627 .31289 .36362 .30117 .56502 .30004 .56441 Mtetra
.933 .583 .338 r
.30004 .56441 .30117 .56502 .30239 .57201 .30128 .57111 Mtetra
.785 .802 .867 r
.30128 .57111 .30239 .57201 .30415 .5708 .30305 .56982 Mtetra
.95 .69 .506 r
.30305 .56982 .30415 .5708 .30727 .54866 .31717 .37829 Mtetra
.583 .353 .533 r
.31717 .37829 .30727 .54866 .32111 .35879 .3201 .35751 Mtetra
.857 .735 .728 r
.3201 .35751 .32111 .35879 .32287 .35597 .32186 .35473 Mtetra
.701 .716 .86 r
.32186 .35473 .32287 .35597 .3245 .35519 .32349 .35394 Mtetra
.606 .683 .897 r
.32349 .35394 .3245 .35519 .32611 .35486 .3251 .3536 Mtetra
.617 .686 .892 r
.3251 .3536 .32611 .35486 .32771 .35449 .32671 .35322 Mtetra
.661 .701 .876 r
.32671 .35322 .32771 .35449 .32934 .35392 .32833 .35265 Mtetra
.658 .699 .877 r
.32833 .35265 .32934 .35392 .33096 .35336 .32995 .35209 Mtetra
.658 .699 .876 r
.32995 .35209 .33096 .35336 .33258 .3528 .33158 .35152 Mtetra
.659 .699 .876 r
.33158 .35152 .33258 .3528 .33421 .35223 .3332 .35096 Mtetra
.3332 .35096 .33421 .35223 .33583 .35167 .33483 .35039 Mtetra
.66 .698 .875 r
.33483 .35039 .33583 .35167 .33746 .35111 .33645 .34982 Mtetra
.659 .697 .874 r
.33645 .34982 .33746 .35111 .33909 .35055 .33808 .34925 Mtetra
.655 .694 .875 r
.33808 .34925 .33909 .35055 .34071 .35 .33971 .3487 Mtetra
.642 .689 .878 r
.33971 .3487 .34071 .35 .34234 .34951 .34134 .34821 Mtetra
.628 .684 .884 r
.34134 .34821 .34234 .34951 .34396 .34907 .34296 .34778 Mtetra
.626 .686 .886 r
.34296 .34778 .34396 .34907 .34559 .34863 .34458 .34736 Mtetra
.665 .703 .875 r
.34458 .34736 .34559 .34863 .34722 .34809 .34622 .34677 Mtetra
.688 .702 .857 r
.34622 .34677 .34722 .34809 .34886 .34746 .34786 .34603 Mtetra
.637 .668 .864 r
.34786 .34603 .34886 .34746 .35049 .34693 .34949 .34556 Mtetra
.317 .524 .898 r
.34949 .34556 .35049 .34693 .3521 .3468 .35107 .34603 Mtetra
.811 .33 0 r
.35107 .34603 .3521 .3468 .35369 .34724 .35255 .34844 Mtetra
.893 .565 .42 r
.35255 .34844 .35369 .34724 .35526 .34795 .35372 .35654 Mtetra
.942 .671 .495 r
.35372 .35654 .35526 .34795 .35684 .34836 .34504 .54961 Mtetra
.534 .307 .517 r
.34504 .54961 .35684 .34836 .35848 .34792 .34673 .55006 Mtetra
.53 .304 .516 r
.34673 .55006 .35848 .34792 .36013 .34719 .34852 .54869 Mtetra
.528 .303 .516 r
.34852 .54869 .36013 .34719 .3618 .34618 .35036 .54642 Mtetra
.529 .303 .516 r
.35036 .54642 .3618 .34618 .36347 .34514 .35218 .54445 Mtetra
.533 .306 .517 r
.35218 .54445 .36347 .34514 .3651 .34475 .3539 .54442 Mtetra
.54 .312 .518 r
.3539 .54442 .3651 .34475 .36661 .34688 .35543 .54812 Mtetra
.35543 .54812 .36661 .34688 .35835 .54694 .35697 .55183 Mtetra
.633 .318 .419 r
.35697 .55183 .35835 .54694 .35974 .55369 .35861 .55378 Mtetra
.513 0 0 r
.35861 .55378 .35974 .55369 .36139 .55545 .3603 .55457 Mtetra
.502 .74 .98 r
.3603 .55457 .36139 .55545 .36313 .55527 .36204 .55441 Mtetra
.686 .806 .939 r
.36204 .55441 .36313 .55527 .3649 .55449 .36381 .55369 Mtetra
.834 .827 .841 r
.36381 .55369 .3649 .55449 .36669 .55324 .36562 .55199 Mtetra
.889 .75 .702 r
.36562 .55199 .36669 .55324 .36851 .55159 .36753 .54828 Mtetra
.875 .657 .605 r
.36753 .54828 .36851 .55159 .37033 .54963 .36967 .53972 Mtetra
.946 .678 .497 r
.36967 .53972 .37033 .54963 .37214 .54815 .38032 .34439 Mtetra
.535 .313 .524 r
.38032 .34439 .37214 .54815 .37388 .54801 .38199 .34359 Mtetra
.533 .311 .524 r
.38199 .34359 .37388 .54801 .37565 .54745 .38362 .34376 Mtetra
.54 .317 .525 r
.38362 .34376 .37565 .54745 .37752 .54453 .38538 .34087 Mtetra
.544 .32 .525 r
.38538 .34087 .37752 .54453 .38796 .3435 .38723 .33614 Mtetra
.669 .472 .61 r
.38723 .33614 .38796 .3435 .38994 .33534 .38899 .33323 Mtetra
.757 .645 .738 r
.38899 .33323 .38994 .33534 .3917 .33254 .3907 .33147 Mtetra
.699 .754 .894 r
.3907 .33147 .3917 .33254 .39337 .33167 .39237 .33072 Mtetra
.632 .758 .938 r
.39237 .33072 .39337 .33167 .39503 .33128 .39403 .33025 Mtetra
.6 .732 .937 r
.39403 .33025 .39503 .33128 .39668 .33103 .39568 .3299 Mtetra
.618 .717 .916 r
.39568 .3299 .39668 .33103 .39834 .3306 .39734 .3295 Mtetra
.621 .723 .919 r
.39734 .3295 .39834 .3306 .4 .33018 .399 .32909 Mtetra
.65 .735 .912 r
.399 .32909 .4 .33018 .40166 .32967 .40067 .32856 Mtetra
.696 .745 .889 r
.40067 .32856 .40166 .32967 .40333 .32901 .40234 .32781 Mtetra
.7 .731 .874 r
.40234 .32781 .40333 .32901 .40501 .32831 .40402 .32703 Mtetra
.704 .719 .861 r
.40402 .32703 .40501 .32831 .40668 .32758 .4057 .32621 Mtetra
.708 .705 .845 r
.4057 .32621 .40668 .32758 .40836 .32683 .40738 .32533 Mtetra
.656 .668 .85 r
.40738 .32533 .40836 .32683 .41003 .32622 .40905 .32474 Mtetra
.496 .599 .886 r
.40905 .32474 .41003 .32622 .4117 .32584 .4107 .32481 Mtetra
.541 .046 0 r
.4107 .32481 .4117 .32584 .41335 .32583 .4123 .32654 Mtetra
.879 .511 .344 r
.4123 .32654 .41335 .32583 .41499 .32643 .41377 .3317 Mtetra
.953 .676 .475 r
.41377 .3317 .41499 .32643 .41656 .32886 .40851 .53108 Mtetra
.541 .313 .518 r
.40851 .53108 .41656 .32886 .41144 .5292 .41013 .53544 Mtetra
.605 .304 .432 r
.41013 .53544 .41144 .5292 .41296 .5367 .41185 .53715 Mtetra
.486 0 0 r
.41185 .53715 .41296 .5367 .41466 .53873 .4136 .53773 Mtetra
.589 .749 .954 r
.4136 .53773 .41466 .53873 .41645 .53853 .41539 .53737 Mtetra
.673 .746 .905 r
.41539 .53737 .41645 .53853 .41825 .53779 .41719 .53669 Mtetra
.693 .763 .905 r
.41719 .53669 .41825 .53779 .42005 .53686 .41899 .53591 Mtetra
.643 .779 .946 r
.41899 .53591 .42005 .53686 .42185 .53626 .42079 .53536 Mtetra
.641 .788 .952 r
.42079 .53536 .42185 .53626 .42365 .53566 .42259 .5348 Mtetra
.624 .793 .963 r
.42259 .5348 .42365 .53566 .42545 .53508 .42439 .53429 Mtetra
.538 .779 .987 r
.42439 .53429 .42545 .53508 .42725 .53464 .42618 .53401 Mtetra
.621 .845 .985 r
.42618 .53401 .42725 .53464 .42905 .53407 .42799 .53344 Mtetra
.787 .873 .911 r
.42799 .53344 .42905 .53407 .43087 .53321 .42981 .5322 Mtetra
.905 .783 .716 r
.42981 .5322 .43087 .53321 .4327 .53153 .4317 .52869 Mtetra
.885 .673 .609 r
.4317 .52869 .4327 .53153 .43455 .52948 .4337 .52099 Mtetra
.954 .681 .479 r
.4337 .52099 .43455 .52948 .43639 .52734 .44081 .32199 Mtetra
.538 .315 .524 r
.44081 .32199 .43639 .52734 .43821 .52638 .44254 .31992 Mtetra
.534 .312 .524 r
.44254 .31992 .43821 .52638 .44001 .52585 .44424 .31953 Mtetra
.533 .311 .524 r
.44424 .31953 .44001 .52585 .44182 .52545 .44592 .31969 Mtetra
.537 .314 .524 r
.44592 .31969 .44182 .52545 .44364 .52449 .44765 .31795 Mtetra
.535 .313 .524 r
.44765 .31795 .44364 .52449 .44545 .52379 .44935 .31717 Mtetra
.531 .309 .523 r
.44935 .31717 .44545 .52379 .44725 .5237 .45101 .31855 Mtetra
0 0 .309 r
.45101 .31855 .44725 .5237 .44903 .52485 .44813 .51743 Mtetra
.031 .018 .507 r
.44813 .51743 .44903 .52485 .45081 .52571 .4498 .52316 Mtetra
.023 .189 .698 r
.4498 .52316 .45081 .52571 .45261 .52611 .45156 .52515 Mtetra
.581 .759 .963 r
.45156 .52515 .45261 .52611 .45442 .52557 .45338 .5248 Mtetra
.712 .838 .942 r
.45338 .5248 .45442 .52557 .45625 .52481 .4552 .52394 Mtetra
.753 .823 .907 r
.4552 .52394 .45625 .52481 .45808 .52398 .45704 .52286 Mtetra
.655 .751 .92 r
.45704 .52286 .45808 .52398 .4599 .52342 .45886 .52226 Mtetra
.636 .736 .92 r
.45886 .52226 .4599 .52342 .46172 .52292 .46068 .52173 Mtetra
.611 .722 .924 r
.46068 .52173 .46172 .52292 .46354 .52251 .46251 .52132 Mtetra
.486 .668 .944 r
.46251 .52132 .46354 .52251 .46536 .5226 .46432 .52131 Mtetra
.56 .682 .921 r
.46432 .52131 .46536 .5226 .46718 .52233 .46614 .52109 Mtetra
.659 .73 .902 r
.46614 .52109 .46718 .52233 .46901 .52139 .46798 .52047 Mtetra
.842 .819 .826 r
.46798 .52047 .46901 .52139 .4709 .51749 .46983 .5186 Mtetra
.828 .944 .586 r
.46983 .5186 .4709 .51749 .47294 .50315 .4717 .51558 Mtetra
.26 .049 .391 r
.4717 .51558 .47294 .50315 .47772 .30646 .47362 .50945 Mtetra
0 0 .305 r
.47362 .50945 .47772 .30646 .47947 .30387 .47842 .3087 Mtetra
0 0 .058 r
.47842 .3087 .47947 .30387 .4812 .30236 .48021 .30304 Mtetra
.896 .975 .675 r
.48021 .30304 .4812 .30236 .48292 .30137 .48196 .30033 Mtetra
.734 .776 .886 r
.48196 .30033 .48292 .30137 .48464 .30066 .48368 .29937 Mtetra
.643 .702 .889 r
.48368 .29937 .48464 .30066 .48636 .30011 .4854 .29885 Mtetra
.594 .687 .907 r
.4854 .29885 .48636 .30011 .48808 .29963 .48712 .29854 Mtetra
.674 .749 .907 r
.48712 .29854 .48808 .29963 .48981 .29896 .48885 .29788 Mtetra
.685 .756 .905 r
.48885 .29788 .48981 .29896 .49153 .29825 .49057 .29718 Mtetra
.695 .761 .903 r
.49057 .29718 .49153 .29825 .49326 .2975 .4923 .29643 Mtetra
.786 .782 .849 r
.4923 .29643 .49326 .2975 .49499 .29621 .49403 .29509 Mtetra
.734 .764 .876 r
.49403 .29509 .49499 .29621 .49672 .29527 .49576 .29412 Mtetra
.583 .705 .926 r
.49576 .29412 .49672 .29527 .49844 .29501 .49749 .29383 Mtetra
.806 .363 0 r
.49749 .29383 .49844 .29501 .50014 .29844 .49918 .29722 Mtetra
.968 .684 .437 r
.49918 .29722 .50014 .29844 .50036 .5033 .49934 .50216 Mtetra
.935 .558 .202 r
.49934 .50216 .50036 .5033 .50215 .51025 .50113 .50921 Mtetra
.257 .581 .944 r
.50113 .50921 .50215 .51025 .504 .51068 .50298 .50963 Mtetra
.65 .766 .934 r
.50298 .50963 .504 .51068 .50585 .5101 .50483 .50903 Mtetra
.727 .786 .899 r
.50483 .50903 .50585 .5101 .50771 .50912 .50669 .50806 Mtetra
.338 .622 .956 r
.50669 .50806 .50771 .50912 .50956 .50931 .50854 .50834 Mtetra
.448 .701 .975 r
.50854 .50834 .50956 .50931 .51142 .50921 .5104 .50833 Mtetra
.686 .814 .943 r
.5104 .50833 .51142 .50921 .51328 .50837 .51226 .50757 Mtetra
.942 .801 .676 r
.51226 .50757 .51328 .50837 .51515 .5038 .51413 .50312 Mtetra
.97 .69 .445 r
.51413 .50312 .51515 .5038 .51749 .29805 .51654 .29766 Mtetra
.976 .761 .549 r
.51654 .29766 .51749 .29805 .51926 .28905 .51831 .28793 Mtetra
.824 .779 .811 r
.51831 .28793 .51926 .28905 .521 .28734 .52005 .28618 Mtetra
.663 .736 .904 r
.52005 .28618 .521 .28734 .52274 .28673 .5218 .28557 Mtetra
.543 .687 .933 r
.5218 .28557 .52274 .28673 .52449 .28656 .52354 .2854 Mtetra
.736 .759 .871 r
.52354 .2854 .52449 .28656 .52623 .28555 .52529 .2844 Mtetra
.708 .752 .886 r
.52529 .2844 .52623 .28555 .52798 .28472 .52703 .28356 Mtetra
.547 .69 .933 r
.52703 .28356 .52798 .28472 .52973 .28454 .52878 .28338 Mtetra
.792 .347 0 r
.52878 .28338 .52973 .28454 .53148 .28796 .53054 .28677 Mtetra
.97 .683 .426 r
.53054 .28677 .53148 .28796 .53379 .49335 .53278 .49219 Mtetra
.923 .536 .155 r
.53278 .49219 .53379 .49335 .53568 .49985 .53467 .49875 Mtetra
0 .348 .815 r
.53467 .49875 .53568 .49985 .53756 .50091 .53656 .49982 Mtetra
.594 .741 .946 r
.53656 .49982 .53756 .50091 .53944 .50052 .53843 .49943 Mtetra
.795 .798 .854 r
.53843 .49943 .53944 .50052 .54131 .49904 .54031 .49796 Mtetra
.934 .777 .662 r
.54031 .49796 .54131 .49904 .54317 .49428 .54217 .49318 Mtetra
.971 .689 .436 r
.54217 .49318 .54317 .49428 .5438 .28795 .54286 .28678 Mtetra
.954 .743 .579 r
.54286 .28678 .5438 .28795 .54551 .27987 .54457 .27872 Mtetra
.832 .78 .803 r
.54457 .27872 .54551 .27987 .54726 .27802 .54632 .27687 Mtetra
.666 .741 .907 r
.54632 .27687 .54726 .27802 .54902 .27739 .54808 .27624 Mtetra
.551 .695 .935 r
.54808 .27624 .54902 .27739 .55078 .27719 .54985 .27605 Mtetra
.719 .759 .884 r
.54985 .27605 .55078 .27719 .55254 .27629 .55161 .27514 Mtetra
.712 .757 .887 r
.55161 .27514 .55254 .27629 .5543 .27543 .55337 .27428 Mtetra
.568 .703 .932 r
.55337 .27428 .5543 .27543 .55607 .27518 .55514 .27403 Mtetra
.694 .234 0 r
.55514 .27403 .55607 .27518 .55787 .278 .55694 .27684 Mtetra
.972 .681 .415 r
.55694 .27684 .55787 .278 .56194 .48259 .56095 .48145 Mtetra
.935 .562 .194 r
.56095 .48145 .56194 .48259 .56393 .49054 .56294 .48943 Mtetra
.011 .404 .854 r
.56294 .48943 .56393 .49054 .56585 .49149 .56485 .49038 Mtetra
.635 .754 .934 r
.56485 .49038 .56585 .49149 .56774 .49096 .56675 .48984 Mtetra
.729 .783 .895 r
.56675 .48984 .56774 .49096 .56963 .48995 .56864 .48883 Mtetra
.524 .706 .954 r
.56864 .48883 .56963 .48995 .57154 .48976 .57055 .48867 Mtetra
.5 .703 .961 r
.57055 .48867 .57154 .48976 .57344 .48962 .57245 .48857 Mtetra
.685 .785 .926 r
.57245 .48857 .57344 .48962 .57534 .48882 .57435 .48781 Mtetra
.925 .8 .704 r
.57435 .48781 .57534 .48882 .57719 .48503 .57621 .48406 Mtetra
.973 .688 .424 r
.57621 .48406 .57719 .48503 .57579 .28248 .57487 .28188 Mtetra
.978 .739 .506 r
.57487 .28188 .57579 .28248 .57736 .26931 .57643 .26814 Mtetra
.864 .783 .769 r
.57643 .26814 .57736 .26931 .57911 .267 .57819 .26582 Mtetra
.681 .743 .898 r
.57819 .26582 .57911 .267 .58089 .26628 .57997 .26511 Mtetra
.557 .694 .932 r
.57997 .26511 .58089 .26628 .58268 .26605 .58176 .26489 Mtetra
.701 .753 .892 r
.58176 .26489 .58268 .26605 .58446 .26524 .58353 .26408 Mtetra
.72 .76 .884 r
.58353 .26408 .58446 .26524 .58623 .26432 .58531 .26316 Mtetra
.587 .712 .929 r
.58531 .26316 .58623 .26432 .58802 .26399 .58711 .26284 Mtetra
.583 .121 0 r
.58711 .26284 .58802 .26399 .58987 .26641 .58896 .26527 Mtetra
.973 .68 .402 r
.58896 .26527 .58987 .26641 .59609 .47062 .59512 .46957 Mtetra
.939 .571 .209 r
.59512 .46957 .59609 .47062 .59822 .47968 .59724 .47859 Mtetra
0 .154 .662 r
.59724 .47859 .59822 .47968 .60018 .4813 .59921 .4802 Mtetra
.537 .719 .957 r
.59921 .4802 .60018 .4813 .60211 .48109 .60114 .48 Mtetra
.768 .799 .878 r
.60114 .48 .60211 .48109 .60402 .47983 .60304 .47873 Mtetra
.923 .794 .7 r
.60304 .47873 .60402 .47983 .60586 .47603 .60489 .47493 Mtetra
.975 .687 .413 r
.60489 .47493 .60586 .47603 .60275 .27498 .60183 .27401 Mtetra
.975 .728 .497 r
.60183 .27401 .60275 .27498 .60419 .26015 .60327 .259 Mtetra
.878 .788 .758 r
.60327 .259 .60419 .26015 .60593 .25763 .60502 .25648 Mtetra
.681 .75 .904 r
.60502 .25648 .60593 .25763 .60773 .25692 .60682 .25577 Mtetra
.551 .698 .937 r
.60682 .25577 .60773 .25692 .60954 .2567 .60863 .25556 Mtetra
.6 .721 .929 r
.60863 .25556 .60954 .2567 .61134 .25631 .61044 .25518 Mtetra
.668 .75 .912 r
.61044 .25518 .61134 .25631 .61314 .25565 .61224 .25453 Mtetra
.679 .756 .909 r
.61224 .25453 .61314 .25565 .61495 .25495 .61404 .25382 Mtetra
.757 .78 .872 r
.61404 .25382 .61495 .25495 .61673 .25383 .61583 .25268 Mtetra
.762 .776 .865 r
.61583 .25268 .61673 .25383 .61852 .25268 .61762 .25149 Mtetra
.66 .736 .906 r
.61762 .25149 .61852 .25268 .62033 .2521 .61942 .25087 Mtetra
0 .179 .704 r
.61942 .25087 .62033 .2521 .62221 .25372 .6213 .25247 Mtetra
.963 .631 .29 r
.6213 .25247 .62221 .25372 .62464 .27234 .62368 .26975 Mtetra
.976 .679 .383 r
.62368 .26975 .62464 .27234 .6329 .46797 .63194 .46688 Mtetra
0 0 .491 r
.63194 .46688 .6329 .46797 .63494 .47019 .63398 .46911 Mtetra
.488 .701 .964 r
.63398 .46911 .63494 .47019 .6369 .47012 .63594 .46903 Mtetra
.756 .802 .89 r
.63594 .46903 .6369 .47012 .63882 .46895 .63786 .46785 Mtetra
.92 .803 .715 r
.63786 .46785 .63882 .46895 .64067 .46544 .63971 .46435 Mtetra
.978 .709 .449 r
.63971 .46435 .64067 .46544 .64145 .43247 .64069 .4364 Mtetra
.98 .69 .387 r
.64069 .4364 .64145 .43247 .63672 .24889 .63582 .24773 Mtetra
.896 .789 .735 r
.63582 .24773 .63672 .24889 .63846 .24601 .63756 .24484 Mtetra
.704 .757 .893 r
.63756 .24484 .63846 .24601 .64027 .24517 .63937 .244 Mtetra
.587 .711 .929 r
.63937 .244 .64027 .24517 .6421 .24485 .6412 .24367 Mtetra
.666 .743 .908 r
.6412 .24367 .6421 .24485 .64392 .2442 .64302 .24301 Mtetra
.733 .766 .879 r
.64302 .24301 .64392 .2442 .64573 .24319 .64483 .24201 Mtetra
.636 .731 .917 r
.64483 .24201 .64573 .24319 .64755 .24267 .64666 .24149 Mtetra
0 .282 .78 r
.64666 .24149 .64755 .24267 .64946 .24399 .64856 .24281 Mtetra
.938 .574 .185 r
.64856 .24281 .64946 .24399 .65172 .25384 .65082 .25266 Mtetra
.975 .675 .374 r
.65082 .25266 .65172 .25384 .66211 .45775 .66116 .45662 Mtetra
0 0 .512 r
.66116 .45662 .66211 .45775 .66419 .46002 .66324 .45889 Mtetra
.629 .756 .938 r
.66324 .45889 .66419 .46002 .66616 .45948 .66521 .45835 Mtetra
.769 .8 .878 r
.66521 .45835 .66616 .45948 .66809 .4582 .66715 .45707 Mtetra
.782 .803 .87 r
.66715 .45707 .66809 .4582 .67002 .45681 .66908 .45568 Mtetra
.73 .79 .9 r
.66908 .45568 .67002 .45681 .67197 .45578 .67103 .45464 Mtetra
.716 .786 .907 r
.67103 .45464 .67197 .45578 .67392 .45482 .67298 .45369 Mtetra
.655 .765 .93 r
.67298 .45369 .67392 .45482 .67589 .45417 .67495 .45303 Mtetra
.563 .727 .951 r
.67495 .45303 .67589 .45417 .67788 .45387 .67693 .45273 Mtetra
.534 .713 .954 r
.67693 .45273 .67788 .45387 .67987 .45367 .67893 .45253 Mtetra
.442 .667 .958 r
.67893 .45253 .67987 .45367 .68187 .45374 .68093 .4526 Mtetra
.415 .652 .956 r
.68093 .4526 .68187 .45374 .68389 .45389 .68295 .45275 Mtetra
.629 .755 .938 r
.68295 .45275 .68389 .45389 .68587 .45335 .68493 .45221 Mtetra
.89 .812 .765 r
.68493 .45221 .68587 .45335 .68774 .45065 .68681 .4495 Mtetra
.981 .723 .465 r
.68681 .4495 .68774 .45065 .68885 .43267 .68791 .43148 Mtetra
.977 .681 .379 r
.68791 .43148 .68885 .43267 .68071 .23376 .67983 .23256 Mtetra
.912 .79 .713 r
.67983 .23256 .68071 .23376 .68242 .23051 .68154 .22931 Mtetra
.709 .758 .89 r
.68154 .22931 .68242 .23051 .68425 .22963 .68338 .22843 Mtetra
.589 .71 .927 r
.68338 .22843 .68425 .22963 .68612 .22929 .68524 .22809 Mtetra
.625 .725 .919 r
.68524 .22809 .68612 .22929 .68798 .22881 .6871 .2276 Mtetra
.733 .765 .879 r
.6871 .2276 .68798 .22881 .68981 .22779 .68893 .22658 Mtetra
.643 .732 .913 r
.68893 .22658 .68981 .22779 .69166 .22723 .69079 .22602 Mtetra
.09 .416 .864 r
.69079 .22602 .69166 .22723 .69361 .22822 .69273 .227 Mtetra
.914 .536 .111 r
.69273 .227 .69361 .22822 .69598 .23689 .6951 .23551 Mtetra
.975 .671 .351 r
.6951 .23551 .69598 .23689 .70953 .44295 .70861 .44175 Mtetra
.583 .128 0 r
.70861 .44175 .70953 .44295 .71173 .44595 .7108 .44471 Mtetra
.504 .678 .944 r
.7108 .44471 .71173 .44595 .71377 .446 .71283 .44464 Mtetra
.703 .745 .884 r
.71283 .44464 .71377 .446 .71575 .44504 .71482 .44371 Mtetra
.794 .778 .838 r
.71482 .44371 .71575 .44504 .71765 .44278 .71676 .44211 Mtetra
.897 .9 .82 r
.71676 .44211 .71765 .44278 .71937 .43741 .71866 .43985 Mtetra
0 0 0 r
.71866 .43985 .71937 .43741 .70897 .23108 .72048 .43616 Mtetra
.514 .292 .515 r
.72048 .43616 .70897 .23108 .71044 .22388 .72186 .42524 Mtetra
0 0 .399 r
.72186 .42524 .71044 .22388 .71221 .22171 .7116 .22461 Mtetra
0 0 .02 r
.7116 .22461 .71221 .22171 .71404 .22035 .71325 .22031 Mtetra
.894 .986 .79 r
.71325 .22031 .71404 .22035 .71589 .21942 .71502 .21813 Mtetra
.702 .742 .883 r
.71502 .21813 .71589 .21942 .71775 .21871 .71688 .21727 Mtetra
.628 .684 .884 r
.71688 .21727 .71775 .21871 .71963 .21815 .71876 .21677 Mtetra
.643 .702 .889 r
.71876 .21677 .71963 .21815 .7215 .21746 .72064 .2162 Mtetra
.745 .763 .868 r
.72064 .2162 .7215 .21746 .72334 .21634 .72248 .21509 Mtetra
.663 .735 .903 r
.72248 .21509 .72334 .21634 .72522 .21567 .72436 .21443 Mtetra
.24 .509 .906 r
.72436 .21443 .72522 .21567 .72718 .21634 .72632 .2151 Mtetra
.89 .502 .05 r
.72632 .2151 .72718 .21634 .72962 .22406 .72876 .22278 Mtetra
.975 .667 .334 r
.72876 .22278 .72962 .22406 .74561 .43141 .7447 .43023 Mtetra
.64 .187 0 r
.7447 .43023 .74561 .43141 .74791 .4348 .747 .43363 Mtetra
.388 .633 .952 r
.747 .43363 .74791 .4348 .74999 .43503 .74908 .43386 Mtetra
.693 .78 .918 r
.74908 .43386 .74999 .43503 .752 .43417 .75109 .43301 Mtetra
.872 .82 .794 r
.75109 .43301 .752 .43417 .7539 .43182 .753 .43066 Mtetra
.978 .768 .554 r
.753 .43066 .7539 .43182 .75542 .42396 .75451 .4228 Mtetra
.977 .675 .347 r
.75451 .4228 .75542 .42396 .74244 .21403 .74159 .21282 Mtetra
.952 .785 .64 r
.74159 .21282 .74244 .21403 .74404 .20934 .74319 .20812 Mtetra
.746 .774 .876 r
.74319 .20812 .74404 .20934 .7459 .20822 .74505 .20701 Mtetra
.616 .724 .923 r
.74505 .20701 .7459 .20822 .7478 .20776 .74695 .20656 Mtetra
.583 .709 .93 r
.74695 .20656 .7478 .20776 .74971 .20743 .74887 .20623 Mtetra
.751 .778 .876 r
.74887 .20623 .74971 .20743 .75157 .20629 .75072 .20509 Mtetra
.67 .749 .91 r
.75072 .20509 .75157 .20629 .75346 .20559 .75262 .20439 Mtetra
.32 .569 .929 r
.75262 .20439 .75346 .20559 .75543 .206 .7546 .20485 Mtetra
.872 .475 .013 r
.7546 .20485 .75543 .206 .75788 .21257 .75709 .21201 Mtetra
.973 .663 .321 r
.75709 .21201 .75788 .21257 .77601 .4215 .77515 .42074 Mtetra
.731 .249 0 r
.77515 .42074 .77601 .4215 .77839 .42522 .77752 .42428 Mtetra
.538 .768 .982 r
.77752 .42428 .77839 .42522 .78047 .42497 .77959 .42397 Mtetra
.733 .831 .925 r
.77959 .42397 .78047 .42497 .78248 .42397 .7816 .42291 Mtetra
.77 .828 .898 r
.7816 .42291 .78248 .42397 .78448 .42275 .7836 .42163 Mtetra
.516 .713 .961 r
.7836 .42163 .78448 .42275 .78657 .42261 .78569 .42146 Mtetra
.631 .763 .942 r
.78569 .42146 .78657 .42261 .78863 .42204 .78774 .42088 Mtetra
.812 .82 .857 r
.78774 .42088 .78863 .42204 .7906 .4204 .78971 .41924 Mtetra
.98 .775 .556 r
.78971 .41924 .7906 .4204 .79209 .41294 .79121 .41183 Mtetra
.976 .671 .329 r
.79121 .41183 .79209 .41294 .77666 .20239 .77583 .20118 Mtetra
.962 .786 .618 r
.77583 .20118 .77666 .20239 .7782 .19728 .77737 .19605 Mtetra
.754 .778 .872 r
.77737 .19605 .7782 .19728 .78007 .19611 .77924 .19488 Mtetra
.624 .726 .92 r
.77924 .19488 .78007 .19611 .782 .19562 .78117 .19439 Mtetra
.553 .692 .932 r
.78117 .19439 .782 .19562 .78395 .1954 .78312 .19417 Mtetra
.748 .775 .875 r
.78312 .19417 .78395 .1954 .78582 .19427 .78499 .19303 Mtetra
.678 .749 .904 r
.78499 .19303 .78582 .19427 .78773 .19352 .7869 .19228 Mtetra
.456 .64 .935 r
.7869 .19228 .78773 .19352 .78972 .19363 .78889 .19239 Mtetra
.77 .354 0 r
.78889 .19239 .78972 .19363 .79215 .19883 .79133 .1976 Mtetra
.971 .657 .298 r
.79133 .1976 .79215 .19883 .81285 .40878 .81197 .40759 Mtetra
.726 .292 0 r
.81197 .40759 .81285 .40878 .81539 .41343 .81451 .41223 Mtetra
.309 .581 .938 r
.81451 .41223 .81539 .41343 .81756 .4139 .81669 .4127 Mtetra
.652 .764 .932 r
.81669 .4127 .81756 .4139 .81963 .41323 .81876 .41203 Mtetra
.831 .82 .838 r
.81876 .41203 .81963 .41323 .82159 .41139 .82072 .41019 Mtetra
.976 .787 .585 r
.82072 .41019 .82159 .41139 .82315 .40515 .82228 .4039 Mtetra
.974 .667 .312 r
.82228 .4039 .82315 .40515 .80561 .19374 .80478 .19241 Mtetra
.97 .77 .579 r
.80478 .19241 .80561 .19374 .80702 .18751 .8062 .18622 Mtetra
.758 .753 .849 r
.18647 .40259 .18754 .40362 .18914 .40254 .18807 .40151 Mtetra
.614 .722 .923 r
.18807 .40151 .18914 .40254 .19066 .40219 .18959 .40115 Mtetra
.466 .666 .95 r
.18959 .40115 .19066 .40219 .19214 .40222 .19107 .40118 Mtetra
.652 .731 .907 r
.19107 .40118 .19214 .40222 .19368 .40172 .19261 .40068 Mtetra
.66 .734 .904 r
.19261 .40068 .19368 .40172 .19522 .40118 .19415 .40015 Mtetra
.666 .736 .902 r
.19415 .40015 .19522 .40118 .19677 .40062 .1957 .39959 Mtetra
.759 .753 .848 r
.1957 .39959 .19677 .40062 .19837 .39952 .1973 .3985 Mtetra
.707 .747 .883 r
.1973 .3985 .19837 .39952 .19993 .39877 .19887 .39775 Mtetra
.501 .683 .948 r
.19887 .39775 .19993 .39877 .20143 .39872 .20036 .39769 Mtetra
.931 .556 .265 r
.20036 .39769 .20143 .39872 .20249 .40302 .20143 .40196 Mtetra
.939 .683 .523 r
.20143 .40196 .20249 .40302 .18409 .60306 .18295 .60204 Mtetra
.935 .576 .309 r
.18295 .60204 .18409 .60306 .18517 .6082 .18402 .60723 Mtetra
0 .39 .83 r
.18402 .60723 .18517 .6082 .18669 .60895 .18555 .60796 Mtetra
.635 .75 .931 r
.18555 .60796 .18669 .60895 .18833 .60849 .18719 .60749 Mtetra
.804 .771 .823 r
.18719 .60749 .18833 .60849 .19009 .60692 .18894 .60593 Mtetra
.907 .737 .66 r
.18894 .60593 .19009 .60692 .19225 .6011 .19108 .60042 Mtetra
.939 .687 .53 r
.19108 .60042 .19225 .6011 .21337 .39917 .21223 .39893 Mtetra
.94 .769 .642 r
.21223 .39893 .21337 .39917 .21543 .39343 .21433 .39281 Mtetra
.812 .832 .865 r
.21433 .39281 .21543 .39343 .21705 .39223 .21596 .39148 Mtetra
.618 .788 .963 r
.21596 .39148 .21705 .39223 .21858 .39194 .2175 .39106 Mtetra
.457 .699 .971 r
.2175 .39106 .21858 .39194 .22007 .39207 .21901 .39105 Mtetra
.633 .73 .917 r
.21901 .39105 .22007 .39207 .22162 .39168 .22056 .39061 Mtetra
.657 .729 .902 r
.22056 .39061 .22162 .39168 .22318 .39114 .22212 .39009 Mtetra
.664 .733 .902 r
.22212 .39009 .22318 .39114 .22474 .39056 .22368 .38954 Mtetra
.751 .757 .857 r
.22368 .38954 .22474 .39056 .22635 .38951 .22529 .3885 Mtetra
.716 .754 .883 r
.22529 .3885 .22635 .38951 .22793 .3887 .22687 .3877 Mtetra
.548 .709 .946 r
.22687 .3877 .22793 .3887 .22946 .38851 .2284 .38753 Mtetra
.898 .48 .139 r
.2284 .38753 .22946 .38851 .23069 .39167 .22962 .39073 Mtetra
.942 .683 .517 r
.22962 .39073 .23069 .39167 .21405 .59106 .2129 .59028 Mtetra
.936 .601 .371 r
.2129 .59028 .21405 .59106 .21503 .59807 .21388 .59717 Mtetra
0 .442 .86 r
.21388 .59717 .21503 .59807 .21659 .59872 .21544 .5978 Mtetra
.669 .776 .93 r
.21544 .5978 .21659 .59872 .21826 .5981 .21712 .59719 Mtetra
.761 .79 .877 r
.21712 .59719 .21826 .5981 .21998 .59699 .21884 .59609 Mtetra
.546 .745 .969 r
.21884 .59609 .21998 .59699 .22162 .59675 .22048 .59586 Mtetra
.587 .76 .961 r
.22048 .59586 .22162 .59675 .22328 .5964 .22213 .59552 Mtetra
.76 .797 .883 r
.22213 .59552 .22328 .5964 .225 .59527 .22385 .59443 Mtetra
.917 .751 .659 r
.22385 .59443 .225 .59527 .22718 .58886 .22596 .58894 Mtetra
.944 .689 .522 r
.22596 .58894 .22718 .58886 .24636 .38659 .2452 .38683 Mtetra
.962 .807 .642 r
.2452 .38683 .24636 .38659 .24832 .38164 .24723 .38105 Mtetra
.819 .842 .866 r
.24723 .38105 .24832 .38164 .24989 .38113 .24888 .37967 Mtetra
.58 .633 .869 r
.24888 .37967 .24989 .38113 .25131 .38243 .25042 .37945 Mtetra
.504 .448 .728 r
.25042 .37945 .25131 .38243 .25255 .38581 .25193 .37972 Mtetra
.583 .421 .627 r
.25193 .37972 .25255 .38581 .25397 .38716 .25351 .37912 Mtetra
.577 .399 .603 r
.25351 .37912 .25397 .38716 .25557 .38644 .25511 .37842 Mtetra
.549 .377 .601 r
.25511 .37842 .25557 .38644 .2571 .38657 .25665 .3783 Mtetra
.304 .191 .556 r
.25665 .3783 .2571 .38657 .24261 .57977 .25792 .38156 Mtetra
0 0 .166 r
.25792 .38156 .24261 .57977 .24363 .58714 .24288 .58167 Mtetra
0 0 .249 r
.24288 .58167 .24363 .58714 .24506 .58969 .244 .58788 Mtetra
.167 .372 .821 r
.244 .58788 .24506 .58969 .24666 .59022 .24556 .58884 Mtetra
.614 .675 .885 r
.24556 .58884 .24666 .59022 .24833 .58986 .24724 .58846 Mtetra
.708 .704 .844 r
.24724 .58846 .24833 .58986 .25005 .58893 .24896 .58757 Mtetra
.662 .696 .871 r
.24896 .58757 .25005 .58893 .25183 .58729 .25065 .58696 Mtetra
.662 .906 .979 r
.25065 .58696 .25183 .58729 .25368 .58465 .25236 .58623 Mtetra
0 0 0 r
.25236 .58623 .25368 .58465 .25572 .57971 .25412 .58483 Mtetra
0 0 .026 r
.25412 .58483 .25572 .57971 .27291 .3821 .25615 .58 Mtetra
0 0 .16 r
.25615 .58 .27291 .3821 .27501 .37499 .27362 .37841 Mtetra
.908 .865 .426 r
.27362 .37841 .27501 .37499 .2768 .37197 .27569 .37174 Mtetra
.887 .894 .83 r
.27569 .37174 .2768 .37197 .27845 .37063 .27739 .36982 Mtetra
.686 .795 .932 r
.27739 .36982 .27845 .37063 .28005 .37002 .27899 .36917 Mtetra
.554 .749 .968 r
.27899 .36917 .28005 .37002 .28162 .36968 .28056 .36893 Mtetra
.605 .789 .969 r
.28056 .36893 .28162 .36968 .28321 .36924 .28215 .36853 Mtetra
.65 .812 .961 r
.28215 .36853 .28321 .36924 .28481 .3687 .28374 .368 Mtetra
.649 .812 .962 r
.28374 .368 .28481 .3687 .2864 .36815 .28534 .36746 Mtetra
.655 .818 .962 r
.28534 .36746 .2864 .36815 .28801 .3675 .28694 .36691 Mtetra
.651 .84 .973 r
.28694 .36691 .28801 .3675 .28962 .36682 .28854 .36635 Mtetra
.631 .864 .986 r
.28854 .36635 .28962 .36682 .29122 .3662 .29014 .3658 Mtetra
.588 .87 .994 r
.29014 .3658 .29122 .3662 .29281 .36581 .29173 .36532 Mtetra
.586 .847 .994 r
.29173 .36532 .29281 .36581 .29438 .36561 .29333 .36488 Mtetra
.613 .798 .97 r
.29333 .36488 .29438 .36561 .29596 .36545 .29492 .36445 Mtetra
.636 .743 .926 r
.29492 .36445 .29596 .36545 .29755 .36512 .29652 .36399 Mtetra
.645 .719 .902 r
.29652 .36399 .29755 .36512 .29915 .36464 .29812 .3635 Mtetra
.651 .719 .898 r
.29812 .3635 .29915 .36464 .30075 .36409 .29972 .36299 Mtetra
.659 .729 .901 r
.29972 .36299 .30075 .36409 .30236 .36351 .30133 .36244 Mtetra
.666 .737 .903 r
.30133 .36244 .30236 .36351 .30397 .36291 .30294 .36186 Mtetra
.669 .742 .905 r
.30294 .36186 .30397 .36291 .30558 .3623 .30455 .36127 Mtetra
.731 .76 .876 r
.30455 .36127 .30558 .3623 .30722 .36138 .30619 .36037 Mtetra
.73 .763 .88 r
.30619 .36037 .30722 .36138 .30885 .36048 .30782 .35947 Mtetra
.6 .731 .936 r
.30782 .35947 .30885 .36048 .31045 .36013 .30942 .35914 Mtetra
.825 .362 0 r
.30942 .35914 .31045 .36013 .31185 .3627 .31082 .36172 Mtetra
.951 .685 .496 r
.31082 .36172 .31185 .3627 .30004 .56441 .29894 .56345 Mtetra
.942 .59 .318 r
.29894 .56345 .30004 .56441 .30128 .57111 .30017 .57015 Mtetra
.749 .789 .886 r
.30017 .57015 .30128 .57111 .30305 .56982 .30193 .5691 Mtetra
.946 .728 .576 r
.30193 .5691 .30305 .56982 .31717 .37829 .30442 .5567 Mtetra
0 0 .13 r
.30442 .5567 .31717 .37829 .3201 .35751 .31901 .35739 Mtetra
.938 .868 .743 r
.31901 .35739 .3201 .35751 .32186 .35473 .32078 .35439 Mtetra
.704 .913 .967 r
.32078 .35439 .32186 .35473 .32349 .35394 .32242 .35359 Mtetra
.48 .843 .992 r
.32242 .35359 .32349 .35394 .3251 .3536 .32403 .35326 Mtetra
.505 .855 .993 r
.32403 .35326 .3251 .3536 .32671 .35322 .32564 .35289 Mtetra
.613 .894 .988 r
.32564 .35289 .32671 .35322 .32833 .35265 .32726 .35231 Mtetra
.608 .891 .989 r
.32726 .35231 .32833 .35265 .32995 .35209 .32888 .35174 Mtetra
.609 .891 .989 r
.32888 .35174 .32995 .35209 .33158 .35152 .33051 .35118 Mtetra
.611 .891 .989 r
.33051 .35118 .33158 .35152 .3332 .35096 .33214 .35061 Mtetra
.33214 .35061 .3332 .35096 .33483 .35039 .33376 .35004 Mtetra
.612 .89 .989 r
.33376 .35004 .33483 .35039 .33645 .34982 .33539 .34947 Mtetra
.61 .89 .989 r
.33539 .34947 .33645 .34982 .33808 .34925 .33702 .3489 Mtetra
.606 .89 .99 r
.33702 .3489 .33808 .34925 .33971 .3487 .33865 .34834 Mtetra
.602 .886 .991 r
.33865 .34834 .33971 .3487 .34134 .34821 .34028 .34779 Mtetra
.607 .875 .992 r
.34028 .34779 .34134 .34821 .34296 .34778 .34191 .34726 Mtetra
.622 .855 .987 r
.34191 .34726 .34296 .34778 .34458 .34736 .34354 .34673 Mtetra
.698 .846 .953 r
.34354 .34673 .34458 .34736 .34622 .34677 .34519 .34601 Mtetra
.725 .819 .924 r
.34519 .34601 .34622 .34677 .34786 .34603 .34684 .34517 Mtetra
.613 .77 .955 r
.34684 .34517 .34786 .34603 .34949 .34556 .34846 .34476 Mtetra
0 .138 .594 r
.34846 .34476 .34949 .34556 .35107 .34603 .35001 .34589 Mtetra
.925 .579 .36 r
.35001 .34589 .35107 .34603 .35255 .34844 .35123 .35283 Mtetra
.948 .677 .491 r
.35123 .35283 .35255 .34844 .35372 .35654 .34195 .55397 Mtetra
.538 .31 .518 r
.34195 .55397 .35372 .35654 .34504 .54961 .34351 .55684 Mtetra
.506 .223 .418 r
.34351 .55684 .34504 .54961 .34673 .55006 .34524 .55667 Mtetra
.457 .173 .393 r
.34524 .55667 .34673 .55006 .34852 .54869 .34701 .55582 Mtetra
.457 .178 .401 r
.34701 .55582 .34852 .54869 .35036 .54642 .34878 .55489 Mtetra
.487 .215 .427 r
.34878 .55489 .35036 .54642 .35218 .54445 .35054 .55427 Mtetra
.497 .231 .441 r
.35054 .55427 .35218 .54445 .3539 .54442 .35229 .55372 Mtetra
.506 .236 .439 r
.35229 .55372 .3539 .54442 .35543 .54812 .35403 .55341 Mtetra
.504 .2 .384 r
.35403 .55341 .35543 .54812 .35697 .55183 .35576 .55335 Mtetra
.402 0 .078 r
.35576 .55335 .35697 .55183 .35861 .55378 .3575 .55327 Mtetra
.366 .762 .986 r
.3575 .55327 .35861 .55378 .3603 .55457 .35923 .55317 Mtetra
.56 .658 .902 r
.35923 .55317 .3603 .55457 .36204 .55441 .36098 .55299 Mtetra
.676 .698 .864 r
.36098 .55299 .36204 .55441 .36381 .55369 .36275 .55228 Mtetra
.827 .736 .764 r
.36275 .55228 .36381 .55369 .36562 .55199 .36459 .55004 Mtetra
.908 .702 .613 r
.36459 .55004 .36562 .55199 .36753 .54828 .36669 .54225 Mtetra
.951 .684 .494 r
.36669 .54225 .36753 .54828 .36967 .53972 .37786 .33929 Mtetra
.542 .318 .525 r
.37786 .33929 .36967 .53972 .38032 .34439 .37968 .33522 Mtetra
.579 .394 .595 r
.37968 .33522 .38032 .34439 .38199 .34359 .38135 .33432 Mtetra
.555 .375 .593 r
.38135 .33432 .38199 .34359 .38362 .34376 .383 .33402 Mtetra
.556 .374 .589 r
.383 .33402 .38362 .34376 .38538 .34087 .38465 .33365 Mtetra
.595 .419 .613 r
.38465 .33365 .38538 .34087 .38723 .33614 .38633 .33266 Mtetra
.643 .516 .693 r
.38633 .33266 .38723 .33614 .38899 .33323 .38801 .33169 Mtetra
.694 .676 .828 r
.38801 .33169 .38899 .33323 .3907 .33147 .38968 .33086 Mtetra
.658 .847 .972 r
.38968 .33086 .3907 .33147 .39237 .33072 .39134 .33025 Mtetra
.615 .869 .99 r
.39134 .33025 .39237 .33072 .39403 .33025 .39301 .3297 Mtetra
.618 .851 .987 r
.39301 .3297 .39403 .33025 .39568 .3299 .39467 .32918 Mtetra
.644 .817 .966 r
.39467 .32918 .39568 .3299 .39734 .3295 .39633 .32864 Mtetra
.653 .786 .945 r
.39633 .32864 .39734 .3295 .399 .32909 .398 .32808 Mtetra
.664 .758 .92 r
.398 .32808 .399 .32909 .40067 .32856 .39967 .32749 Mtetra
.676 .749 .906 r
.39967 .32749 .40067 .32856 .40234 .32781 .40134 .32685 Mtetra
.679 .771 .92 r
.40134 .32685 .40234 .32781 .40402 .32703 .40301 .3262 Mtetra
.705 .806 .928 r
.40301 .3262 .40402 .32703 .4057 .32621 .40469 .32544 Mtetra
.751 .828 .911 r
.40469 .32544 .4057 .32621 .40738 .32533 .40638 .32446 Mtetra
.66 .787 .942 r
.40638 .32446 .40738 .32533 .40905 .32474 .40805 .32388 Mtetra
.119 .524 .914 r
.40805 .32388 .40905 .32474 .4107 .32481 .40969 .32439 Mtetra
.913 .522 .245 r
.40969 .32439 .4107 .32481 .4123 .32654 .41117 .3292 Mtetra
.956 .68 .472 r
.41117 .3292 .4123 .32654 .41377 .3317 .40561 .53233 Mtetra
.541 .313 .518 r
.40561 .53233 .41377 .3317 .40851 .53108 .40722 .53682 Mtetra
.536 .235 .403 r
.40722 .53682 .40851 .53108 .41013 .53544 .40897 .5372 Mtetra
.358 0 .093 r
.40897 .5372 .41013 .53544 .41185 .53715 .41076 .53687 Mtetra
.585 .906 .981 r
.41076 .53687 .41185 .53715 .4136 .53773 .41256 .53622 Mtetra
.638 .676 .87 r
.41256 .53622 .4136 .53773 .41539 .53737 .41435 .5357 Mtetra
.65 .658 .845 r
.41435 .5357 .41539 .53737 .41719 .53669 .41615 .53509 Mtetra
.656 .67 .851 r
.41615 .53509 .41719 .53669 .41899 .53591 .41795 .53445 Mtetra
.647 .686 .873 r
.41795 .53445 .41899 .53591 .42079 .53536 .41975 .53388 Mtetra
.647 .684 .871 r
.41975 .53388 .42079 .53536 .42259 .5348 .42155 .53331 Mtetra
.63 .676 .875 r
.42155 .53331 .42259 .5348 .42439 .53429 .42335 .53283 Mtetra
.548 .644 .897 r
.42335 .53283 .42439 .53429 .42618 .53401 .42514 .53269 Mtetra
.646 .71 .894 r
.42514 .53269 .42618 .53401 .42799 .53344 .42694 .53213 Mtetra
.793 .751 .814 r
.42694 .53213 .42799 .53344 .42981 .5322 .42878 .53051 Mtetra
.913 .72 .628 r
.42878 .53051 .42981 .5322 .4317 .52869 .43075 .52405 Mtetra
.959 .686 .475 r
.43075 .52405 .4317 .52869 .4337 .52099 .43819 .31918 Mtetra
.545 .32 .525 r
.43819 .31918 .4337 .52099 .44081 .32199 .44001 .31387 Mtetra
.596 .413 .604 r
.44001 .31387 .44081 .32199 .44254 .31992 .44172 .31269 Mtetra
.57 .401 .613 r
.44172 .31269 .44254 .31992 .44424 .31953 .44342 .31219 Mtetra
.558 .391 .612 r
.44342 .31219 .44424 .31953 .44592 .31969 .44511 .31192 Mtetra
.593 .414 .608 r
.44511 .31192 .44592 .31969 .44765 .31795 .44682 .31086 Mtetra
.579 .409 .615 r
.44682 .31086 .44765 .31795 .44935 .31717 .44852 .31021 Mtetra
.529 .374 .615 r
.44852 .31021 .44935 .31717 .45101 .31855 .4502 .31045 Mtetra
.164 .1 .533 r
.4502 .31045 .45101 .31855 .44813 .51743 .45177 .31547 Mtetra
0 0 .293 r
.45177 .31547 .44813 .51743 .4498 .52316 .44883 .519 Mtetra
0 0 .467 r
.44883 .519 .4498 .52316 .45156 .52515 .45053 .5235 Mtetra
.511 .598 .877 r
.45053 .5235 .45156 .52515 .45338 .5248 .45234 .52353 Mtetra
.678 .732 .89 r
.45234 .52353 .45338 .5248 .4552 .52394 .45416 .52281 Mtetra
.741 .773 .879 r
.45416 .52281 .4552 .52394 .45704 .52286 .456 .52174 Mtetra
.648 .749 .923 r
.456 .52174 .45704 .52286 .45886 .52226 .45782 .52117 Mtetra
.641 .753 .93 r
.45782 .52117 .45886 .52226 .46068 .52173 .45964 .52062 Mtetra
.629 .743 .93 r
.45964 .52062 .46068 .52173 .46251 .52132 .46147 .52012 Mtetra
.581 .71 .931 r
.46147 .52012 .46251 .52132 .46432 .52131 .46329 .51982 Mtetra
.597 .664 .886 r
.46329 .51982 .46432 .52131 .46614 .52109 .46512 .51948 Mtetra
.617 .655 .865 r
.46512 .51948 .46614 .52109 .46798 .52047 .46694 .51905 Mtetra
.595 .676 .897 r
.46694 .51905 .46798 .52047 .46983 .5186 .46877 .51872 Mtetra
.475 .896 .86 r
.46877 .51872 .46983 .5186 .4717 .51558 .47061 .51794 Mtetra
.099 0 .051 r
.47061 .51794 .4717 .51558 .47362 .50945 .47246 .51633 Mtetra
0 0 .172 r
.47246 .51633 .47362 .50945 .47842 .3087 .47439 .50951 Mtetra
0 0 .291 r
.47439 .50951 .47842 .3087 .48021 .30304 .47921 .30459 Mtetra
.956 .894 .508 r
.47921 .30459 .48021 .30304 .48196 .30033 .48099 .29928 Mtetra
.769 .782 .864 r
.48099 .29928 .48196 .30033 .48368 .29937 .48272 .29809 Mtetra
.639 .702 .892 r
.48272 .29809 .48368 .29937 .4854 .29885 .48444 .29759 Mtetra
.552 .669 .915 r
.48444 .29759 .4854 .29885 .48712 .29854 .48616 .29742 Mtetra
.674 .746 .905 r
.48616 .29742 .48712 .29854 .48885 .29788 .48788 .29677 Mtetra
.682 .748 .901 r
.48788 .29677 .48885 .29788 .49057 .29718 .48961 .29607 Mtetra
.687 .752 .901 r
.48961 .29607 .49057 .29718 .4923 .29643 .49134 .29536 Mtetra
.773 .78 .858 r
.49134 .29536 .4923 .29643 .49403 .29509 .49307 .29413 Mtetra
.722 .791 .906 r
.49307 .29413 .49403 .29509 .49576 .29412 .4948 .29326 Mtetra
.521 .745 .977 r
.4948 .29326 .49576 .29412 .49749 .29383 .49653 .29306 Mtetra
.866 .423 .041 r
.49653 .29306 .49749 .29383 .49918 .29722 .49822 .29672 Mtetra
.967 .683 .439 r
.49822 .29672 .49918 .29722 .49934 .50216 .49831 .50184 Mtetra
.921 .536 .252 r
.49831 .50184 .49934 .50216 .50113 .50921 .50011 .50819 Mtetra
.256 .586 .946 r
.50011 .50819 .50113 .50921 .50298 .50963 .50195 .5086 Mtetra
.649 .771 .938 r
.50195 .5086 .50298 .50963 .50483 .50903 .50381 .508 Mtetra
.735 .795 .9 r
.50381 .508 .50483 .50903 .50669 .50806 .50567 .50699 Mtetra
.461 .685 .963 r
.50567 .50699 .50669 .50806 .50854 .50834 .50752 .50699 Mtetra
.575 .681 .913 r
.50752 .50699 .50854 .50834 .5104 .50833 .50938 .50672 Mtetra
.709 .695 .835 r
.50938 .50672 .5104 .50833 .51226 .50757 .51124 .50572 Mtetra
.894 .719 .657 r
.51124 .50572 .51226 .50757 .51413 .50312 .51312 .50083 Mtetra
.968 .688 .447 r
.51312 .50083 .51413 .50312 .51654 .29766 .51559 .29451 Mtetra
.884 .661 .596 r
.51559 .29451 .51654 .29766 .51831 .28793 .51736 .28672 Mtetra
.811 .766 .812 r
.51736 .28672 .51831 .28793 .52005 .28618 .5191 .28506 Mtetra
.664 .745 .91 r
.5191 .28506 .52005 .28618 .5218 .28557 .52085 .28445 Mtetra
.55 .7 .939 r
.52085 .28445 .5218 .28557 .52354 .2854 .52259 .28425 Mtetra
.737 .76 .872 r
.52259 .28425 .52354 .2854 .52529 .2844 .52434 .28324 Mtetra
.707 .751 .886 r
.52434 .28324 .52529 .2844 .52703 .28356 .52609 .2824 Mtetra
.547 .691 .934 r
.52609 .2824 .52703 .28356 .52878 .28338 .52784 .28222 Mtetra
.791 .344 0 r
.52784 .28222 .52878 .28338 .53054 .28677 .52959 .28559 Mtetra
.97 .683 .426 r
.52959 .28559 .53054 .28677 .53278 .49219 .53178 .49102 Mtetra
.924 .537 .158 r
.53178 .49102 .53278 .49219 .53467 .49875 .53367 .49765 Mtetra
0 .345 .814 r
.53367 .49765 .53467 .49875 .53656 .49982 .53555 .49872 Mtetra
.593 .739 .946 r
.53555 .49872 .53656 .49982 .53843 .49943 .53743 .49834 Mtetra
.795 .797 .854 r
.53743 .49834 .53843 .49943 .54031 .49796 .5393 .49686 Mtetra
.934 .777 .662 r
.5393 .49686 .54031 .49796 .54217 .49318 .54116 .49208 Mtetra
.971 .689 .436 r
.54116 .49208 .54217 .49318 .54286 .28678 .54192 .28561 Mtetra
.954 .743 .579 r
.54192 .28561 .54286 .28678 .54457 .27872 .54363 .27757 Mtetra
.832 .78 .803 r
.54363 .27757 .54457 .27872 .54632 .27687 .54539 .27573 Mtetra
.666 .742 .907 r
.54539 .27573 .54632 .27687 .54808 .27624 .54715 .2751 Mtetra
.551 .695 .935 r
.54715 .2751 .54808 .27624 .54985 .27605 .54891 .2749 Mtetra
.719 .759 .884 r
.54891 .2749 .54985 .27605 .55161 .27514 .55067 .27399 Mtetra
.712 .757 .887 r
.55067 .27399 .55161 .27514 .55337 .27428 .55244 .27313 Mtetra
.568 .703 .933 r
.55244 .27313 .55337 .27428 .55514 .27403 .55421 .27288 Mtetra
.694 .233 0 r
.55421 .27288 .55514 .27403 .55694 .27684 .55601 .27569 Mtetra
.972 .681 .415 r
.55601 .27569 .55694 .27684 .56095 .48145 .55996 .48032 Mtetra
.936 .562 .197 r
.55996 .48032 .56095 .48145 .56294 .48943 .56194 .48833 Mtetra
.001 .399 .85 r
.56194 .48833 .56294 .48943 .56485 .49038 .56386 .48929 Mtetra
.633 .758 .938 r
.56386 .48929 .56485 .49038 .56675 .48984 .56575 .48875 Mtetra
.733 .79 .898 r
.56575 .48875 .56675 .48984 .56864 .48883 .56765 .48773 Mtetra
.558 .725 .952 r
.56765 .48773 .56864 .48883 .57055 .48867 .56955 .48746 Mtetra
.553 .7 .937 r
.56955 .48746 .57055 .48867 .57245 .48857 .57146 .48723 Mtetra
.701 .736 .878 r
.57146 .48723 .57245 .48857 .57435 .48781 .57336 .48634 Mtetra
.901 .755 .69 r
.57336 .48634 .57435 .48781 .57621 .48406 .57521 .4824 Mtetra
.973 .687 .425 r
.57521 .4824 .57621 .48406 .57487 .28188 .57389 .278 Mtetra
.899 .656 .562 r
.57389 .278 .57487 .28188 .57643 .26814 .57551 .26691 Mtetra
.854 .773 .771 r
.57551 .26691 .57643 .26814 .57819 .26582 .57726 .26466 Mtetra
.679 .747 .902 r
.57726 .26466 .57819 .26582 .57997 .26511 .57904 .26396 Mtetra
.558 .7 .936 r
.57904 .26396 .57997 .26511 .58176 .26489 .58083 .26374 Mtetra
.701 .755 .894 r
.58083 .26374 .58176 .26489 .58353 .26408 .58261 .26292 Mtetra
.72 .76 .885 r
.58261 .26292 .58353 .26408 .58531 .26316 .58439 .26201 Mtetra
.587 .712 .93 r
.58439 .26201 .58531 .26316 .58711 .26284 .58618 .26169 Mtetra
.584 .122 0 r
.58618 .26169 .58711 .26284 .58896 .26527 .58803 .26412 Mtetra
.973 .68 .402 r
.58803 .26412 .58896 .26527 .59512 .46957 .59414 .4685 Mtetra
.939 .57 .207 r
.59414 .4685 .59512 .46957 .59724 .47859 .59626 .47749 Mtetra
0 .155 .664 r
.59626 .47749 .59724 .47859 .59921 .4802 .59823 .4791 Mtetra
.537 .718 .956 r
.59823 .4791 .59921 .4802 .60114 .48 .60016 .47889 Mtetra
.768 .798 .878 r
.60016 .47889 .60114 .48 .60304 .47873 .60206 .47763 Mtetra
.923 .794 .7 r
.60206 .47763 .60304 .47873 .60489 .47493 .60391 .47383 Mtetra
.975 .687 .413 r
.60391 .47383 .60489 .47493 .60183 .27401 .60092 .273 Mtetra
.974 .726 .497 r
.60092 .273 .60183 .27401 .60327 .259 .60236 .25784 Mtetra
.878 .788 .758 r
.60236 .25784 .60327 .259 .60502 .25648 .60411 .25532 Mtetra
.68 .749 .903 r
.60411 .25532 .60502 .25648 .60682 .25577 .60591 .25461 Mtetra
.55 .697 .937 r
.60591 .25461 .60682 .25577 .60863 .25556 .60772 .25441 Mtetra
.601 .72 .928 r
.60772 .25441 .60863 .25556 .61044 .25518 .60953 .25403 Mtetra
.668 .746 .909 r
.60953 .25403 .61044 .25518 .61224 .25453 .61133 .25337 Mtetra
.675 .748 .906 r
.61133 .25337 .61224 .25453 .61404 .25382 .61313 .25268 Mtetra
.743 .773 .877 r
.61313 .25268 .61404 .25382 .61583 .25268 .61492 .25163 Mtetra
.751 .791 .886 r
.61492 .25163 .61583 .25268 .61762 .25149 .61672 .25055 Mtetra
.63 .777 .951 r
.61672 .25055 .61762 .25149 .61942 .25087 .61853 .25003 Mtetra
0 .03 .521 r
.61853 .25003 .61942 .25087 .6213 .25247 .62041 .25179 Mtetra
.974 .677 .388 r
.62041 .25179 .6213 .25247 .62368 .26975 .6285 .44962 Mtetra
.563 .329 .519 r
.6285 .44962 .62368 .26975 .63194 .46688 .63098 .46591 Mtetra
.515 .017 0 r
.63098 .46591 .63194 .46688 .63398 .46911 .63301 .46801 Mtetra
.496 .701 .961 r
.63301 .46801 .63398 .46911 .63594 .46903 .63498 .46792 Mtetra
.754 .797 .887 r
.63498 .46792 .63594 .46903 .63786 .46785 .6369 .46674 Mtetra
.918 .801 .715 r
.6369 .46674 .63786 .46785 .63971 .46435 .63875 .46324 Mtetra
.978 .711 .453 r
.63875 .46324 .63971 .46435 .64069 .4364 .6398 .43702 Mtetra
.978 .687 .395 r
.6398 .43702 .64069 .4364 .63582 .24773 .63492 .24655 Mtetra
.896 .789 .735 r
.63492 .24655 .63582 .24773 .63756 .24484 .63666 .24366 Mtetra
.704 .757 .893 r
.63666 .24366 .63756 .24484 .63937 .244 .63847 .24282 Mtetra
.587 .711 .928 r
.63847 .24282 .63937 .244 .6412 .24367 .64031 .24249 Mtetra
.666 .743 .907 r
.64031 .24249 .6412 .24367 .64302 .24301 .64213 .24183 Mtetra
.733 .766 .879 r
.64213 .24183 .64302 .24301 .64483 .24201 .64394 .24082 Mtetra
.636 .731 .917 r
.64394 .24082 .64483 .24201 .64666 .24149 .64577 .2403 Mtetra
0 .282 .78 r
.64577 .2403 .64666 .24149 .64856 .24281 .64767 .24162 Mtetra
.938 .574 .185 r
.64767 .24162 .64856 .24281 .65082 .25266 .64993 .25148 Mtetra
.975 .675 .374 r
.64993 .25148 .65082 .25266 .66116 .45662 .66021 .45549 Mtetra
0 0 .512 r
.66021 .45549 .66116 .45662 .66324 .45889 .66229 .45776 Mtetra
.629 .756 .938 r
.66229 .45776 .66324 .45889 .66521 .45835 .66426 .45722 Mtetra
.769 .8 .878 r
.66426 .45722 .66521 .45835 .66715 .45707 .6662 .45593 Mtetra
.782 .803 .87 r
.6662 .45593 .66715 .45707 .66908 .45568 .66813 .45454 Mtetra
.73 .79 .9 r
.66813 .45454 .66908 .45568 .67103 .45464 .67008 .45351 Mtetra
.716 .786 .907 r
.67008 .45351 .67103 .45464 .67298 .45369 .67204 .45255 Mtetra
.656 .765 .93 r
.67204 .45255 .67298 .45369 .67495 .45303 .67401 .45189 Mtetra
.563 .727 .951 r
.67401 .45189 .67495 .45303 .67693 .45273 .67599 .4516 Mtetra
.534 .713 .954 r
.67599 .4516 .67693 .45273 .67893 .45253 .67799 .45139 Mtetra
.442 .667 .958 r
.67799 .45139 .67893 .45253 .68093 .4526 .67999 .45146 Mtetra
.415 .652 .956 r
.67999 .45146 .68093 .4526 .68295 .45275 .68201 .45161 Mtetra
.629 .755 .938 r
.68201 .45161 .68295 .45275 .68493 .45221 .68399 .45107 Mtetra
.89 .812 .765 r
.68399 .45107 .68493 .45221 .68681 .4495 .68587 .44836 Mtetra
.981 .723 .465 r
.68587 .44836 .68681 .4495 .68791 .43148 .68698 .43029 Mtetra
.977 .682 .379 r
.68698 .43029 .68791 .43148 .67983 .23256 .67895 .23136 Mtetra
.912 .79 .713 r
.67895 .23136 .67983 .23256 .68154 .22931 .68066 .22811 Mtetra
.709 .758 .89 r
.68066 .22811 .68154 .22931 .68338 .22843 .6825 .22723 Mtetra
.59 .71 .927 r
.6825 .22723 .68338 .22843 .68524 .22809 .68436 .22688 Mtetra
.626 .725 .918 r
.68436 .22688 .68524 .22809 .6871 .2276 .68622 .2264 Mtetra
.733 .765 .879 r
.68622 .2264 .6871 .2276 .68893 .22658 .68806 .22537 Mtetra
.644 .732 .913 r
.68806 .22537 .68893 .22658 .69079 .22602 .68991 .22481 Mtetra
.094 .419 .866 r
.68991 .22481 .69079 .22602 .69273 .227 .69186 .22578 Mtetra
.912 .533 .106 r
.69186 .22578 .69273 .227 .6951 .23551 .69421 .23413 Mtetra
.975 .671 .352 r
.69421 .23413 .6951 .23551 .70861 .44175 .70768 .44054 Mtetra
.577 .122 0 r
.70768 .44054 .70861 .44175 .7108 .44471 .70987 .44347 Mtetra
.538 .696 .941 r
.70987 .44347 .7108 .44471 .71283 .44464 .7119 .44328 Mtetra
.698 .743 .886 r
.7119 .44328 .71283 .44464 .71482 .44371 .71388 .44238 Mtetra
.714 .754 .884 r
.71388 .44238 .71482 .44371 .71676 .44211 .71586 .44139 Mtetra
.588 .836 .992 r
.71586 .44139 .71676 .44211 .71866 .43985 .71787 .44086 Mtetra
0 0 0 r
.71787 .44086 .71866 .43985 .72048 .43616 .71985 .43981 Mtetra
.149 0 .217 r
.71985 .43981 .72048 .43616 .72186 .42524 .72173 .43713 Mtetra
0 0 .313 r
.72173 .43713 .72186 .42524 .7116 .22461 .723 .42448 Mtetra
0 0 .393 r
.723 .42448 .7116 .22461 .71325 .22031 .71247 .2205 Mtetra
.968 .932 .633 r
.71247 .2205 .71325 .22031 .71502 .21813 .71415 .21684 Mtetra
.725 .751 .873 r
.71415 .21684 .71502 .21813 .71688 .21727 .716 .21584 Mtetra
.616 .682 .889 r
.716 .21584 .71688 .21727 .71876 .21677 .71789 .2154 Mtetra
.618 .693 .897 r
.71789 .2154 .71876 .21677 .72064 .2162 .71977 .21495 Mtetra
.744 .763 .869 r
.71977 .21495 .72064 .2162 .72248 .21509 .72162 .21384 Mtetra
.661 .734 .904 r
.72162 .21384 .72248 .21509 .72436 .21443 .72349 .21319 Mtetra
.238 .508 .905 r
.72349 .21319 .72436 .21443 .72632 .2151 .72546 .21387 Mtetra
.889 .5 .048 r
.72546 .21387 .72632 .2151 .72876 .22278 .72789 .2215 Mtetra
.975 .667 .334 r
.72789 .2215 .72876 .22278 .7447 .43023 .74379 .42905 Mtetra
.641 .188 0 r
.74379 .42905 .7447 .43023 .747 .43363 .74609 .43246 Mtetra
.387 .632 .952 r
.74609 .43246 .747 .43363 .74908 .43386 .74817 .43269 Mtetra
.693 .78 .918 r
.74817 .43269 .74908 .43386 .75109 .43301 .75018 .43184 Mtetra
.872 .819 .794 r
.75018 .43184 .75109 .43301 .753 .43066 .75209 .42949 Mtetra
.977 .768 .554 r
.75209 .42949 .753 .43066 .75451 .4228 .75361 .42164 Mtetra
.977 .675 .347 r
.75361 .42164 .75451 .4228 .74159 .21282 .74074 .21161 Mtetra
.952 .785 .639 r
.74074 .21161 .74159 .21282 .74319 .20812 .74234 .20691 Mtetra
.745 .774 .876 r
.74234 .20691 .74319 .20812 .74505 .20701 .7442 .2058 Mtetra
.614 .723 .923 r
.7442 .2058 .74505 .20701 .74695 .20656 .7461 .20535 Mtetra
.579 .708 .931 r
.7461 .20535 .74695 .20656 .74887 .20623 .74802 .20503 Mtetra
.748 .779 .878 r
.74802 .20503 .74887 .20623 .75072 .20509 .74988 .20392 Mtetra
.669 .755 .915 r
.74988 .20392 .75072 .20509 .75262 .20439 .75177 .20323 Mtetra
.327 .58 .934 r
.75177 .20323 .75262 .20439 .7546 .20485 .75375 .20364 Mtetra
.849 .446 0 r
.75375 .20364 .7546 .20485 .75709 .21201 .75619 .21009 Mtetra
.974 .663 .316 r
.75619 .21009 .75709 .21201 .77515 .42074 .77421 .41893 Mtetra
0 0 .461 r
.77421 .41893 .77515 .42074 .77752 .42428 .77659 .4227 Mtetra
.55 .644 .896 r
.77659 .4227 .77752 .42428 .77959 .42397 .77868 .42253 Mtetra
.695 .735 .881 r
.77868 .42253 .77959 .42397 .7816 .42291 .7807 .42163 Mtetra
.736 .777 .885 r
.7807 .42163 .7816 .42291 .7836 .42163 .78271 .4205 Mtetra
.511 .711 .961 r
.78271 .4205 .7836 .42163 .78569 .42146 .7848 .42035 Mtetra
.633 .771 .946 r
.7848 .42035 .78569 .42146 .78774 .42088 .78686 .41976 Mtetra
.816 .826 .857 r
.78686 .41976 .78774 .42088 .78971 .41924 .78883 .41809 Mtetra
.98 .776 .558 r
.78883 .41809 .78971 .41924 .79121 .41183 .79033 .41073 Mtetra
.976 .671 .329 r
.79033 .41073 .79121 .41183 .77583 .20118 .775 .19998 Mtetra
.963 .786 .617 r
.775 .19998 .77583 .20118 .77737 .19605 .77654 .19483 Mtetra
.755 .778 .872 r
.77654 .19483 .77737 .19605 .77924 .19488 .77841 .19365 Mtetra
.624 .726 .92 r
.77841 .19365 .77924 .19488 .78117 .19439 .78033 .19315 Mtetra
.553 .692 .932 r
.78033 .19315 .78117 .19439 .78312 .19417 .78229 .19293 Mtetra
.748 .775 .875 r
.78229 .19293 .78312 .19417 .78499 .19303 .78416 .19179 Mtetra
.678 .749 .904 r
.78416 .19179 .78499 .19303 .7869 .19228 .78607 .19105 Mtetra
.456 .64 .936 r
.78607 .19105 .7869 .19228 .78889 .19239 .78806 .19115 Mtetra
.771 .355 0 r
.78806 .19115 .78889 .19239 .79133 .1976 .7905 .19637 Mtetra
.971 .657 .298 r
.7905 .19637 .79133 .1976 .81197 .40759 .8111 .40641 Mtetra
.727 .291 0 r
.8111 .40641 .81197 .40759 .81451 .41223 .81364 .41104 Mtetra
.31 .583 .939 r
.81364 .41104 .81451 .41223 .81669 .4127 .81581 .41151 Mtetra
.653 .764 .931 r
.81581 .41151 .81669 .4127 .81876 .41203 .81788 .41083 Mtetra
.832 .82 .837 r
.81788 .41083 .81876 .41203 .82072 .41019 .81985 .40897 Mtetra
.976 .786 .584 r
.81985 .40897 .82072 .41019 .82228 .4039 .82141 .40265 Mtetra
.974 .667 .312 r
.82141 .40265 .82228 .4039 .80478 .19241 .80395 .19109 Mtetra
.97 .772 .58 r
.80395 .19109 .80478 .19241 .8062 .18622 .80537 .18494 Mtetra
.726 .697 .822 r
.18543 .40124 .18647 .40259 .18807 .40151 .18702 .40026 Mtetra
.592 .67 .894 r
.18702 .40026 .18807 .40151 .18959 .40115 .18853 .39999 Mtetra
.437 .624 .931 r
.18853 .39999 .18959 .40115 .19107 .40118 .19 .40012 Mtetra
.645 .725 .907 r
.19 .40012 .19107 .40118 .19261 .40068 .19154 .39965 Mtetra
.659 .735 .905 r
.19154 .39965 .19261 .40068 .19415 .40015 .19308 .39912 Mtetra
.668 .738 .902 r
.19308 .39912 .19415 .40015 .1957 .39959 .19463 .39856 Mtetra
.758 .753 .848 r
.19463 .39856 .1957 .39959 .1973 .3985 .19623 .39747 Mtetra
.706 .746 .883 r
.19623 .39747 .1973 .3985 .19887 .39775 .1978 .39672 Mtetra
.502 .682 .947 r
.1978 .39672 .19887 .39775 .20036 .39769 .1993 .39666 Mtetra
.93 .554 .261 r
.1993 .39666 .20036 .39769 .20143 .40196 .20036 .40088 Mtetra
.939 .683 .523 r
.20036 .40088 .20143 .40196 .18295 .60204 .18181 .601 Mtetra
.936 .578 .311 r
.18181 .601 .18295 .60204 .18402 .60723 .18288 .60624 Mtetra
.019 .444 .869 r
.18288 .60624 .18402 .60723 .18555 .60796 .18441 .60688 Mtetra
.643 .736 .916 r
.18441 .60688 .18555 .60796 .18719 .60749 .18605 .60639 Mtetra
.786 .756 .825 r
.18605 .60639 .18719 .60749 .18894 .60593 .18779 .60495 Mtetra
.888 .754 .708 r
.18779 .60495 .18894 .60593 .19108 .60042 .18975 .60127 Mtetra
.962 .754 .577 r
.18975 .60127 .19108 .60042 .21223 .39893 .19266 .58785 Mtetra
0 0 .11 r
.19266 .58785 .21223 .39893 .21433 .39281 .21293 .39521 Mtetra
0 0 0 r
.21293 .39521 .21433 .39281 .21596 .39148 .2147 .39252 Mtetra
.506 .846 .571 r
.2147 .39252 .21596 .39148 .2175 .39106 .21634 .39108 Mtetra
.707 .965 .939 r
.21634 .39108 .2175 .39106 .21901 .39105 .21794 .39015 Mtetra
.696 .772 .91 r
.21794 .39015 .21901 .39105 .22056 .39061 .21951 .38946 Mtetra
.655 .712 .889 r
.21951 .38946 .22056 .39061 .22212 .39009 .22107 .38894 Mtetra
.636 .707 .897 r
.22107 .38894 .22212 .39009 .22368 .38954 .22262 .3885 Mtetra
.747 .753 .857 r
.22262 .3885 .22368 .38954 .22529 .3885 .22422 .38749 Mtetra
.714 .752 .883 r
.22422 .38749 .22529 .3885 .22687 .3877 .22581 .3867 Mtetra
.543 .705 .945 r
.22581 .3867 .22687 .3877 .2284 .38753 .22734 .38653 Mtetra
.9 .484 .144 r
.22734 .38653 .2284 .38753 .22962 .39073 .22855 .38978 Mtetra
.942 .683 .517 r
.22855 .38978 .22962 .39073 .2129 .59028 .21174 .5895 Mtetra
.936 .598 .368 r
.21174 .5895 .2129 .59028 .21388 .59717 .21274 .59626 Mtetra
0 .446 .861 r
.21274 .59626 .21388 .59717 .21544 .5978 .2143 .59689 Mtetra
.669 .778 .931 r
.2143 .59689 .21544 .5978 .21712 .59719 .21597 .59628 Mtetra
.76 .791 .878 r
.21597 .59628 .21712 .59719 .21884 .59609 .21769 .59518 Mtetra
.545 .743 .968 r
.21769 .59518 .21884 .59609 .22048 .59586 .21934 .59496 Mtetra
.584 .758 .961 r
.21934 .59496 .22048 .59586 .22213 .59552 .22099 .59463 Mtetra
.756 .795 .885 r
.22099 .59463 .22213 .59552 .22385 .59443 .22271 .59357 Mtetra
.913 .752 .667 r
.22271 .59357 .22385 .59443 .22596 .58894 .22479 .58843 Mtetra
.943 .688 .522 r
.22479 .58843 .22596 .58894 .2452 .38683 .24408 .38648 Mtetra
.941 .765 .637 r
.24408 .38648 .2452 .38683 .24723 .38105 .24616 .38022 Mtetra
.834 .792 .812 r
.24616 .38022 .24723 .38105 .24888 .37967 .24784 .37849 Mtetra
.683 .717 .875 r
.24784 .37849 .24888 .37967 .25042 .37945 .24942 .37783 Mtetra
.595 .616 .843 r
.24942 .37783 .25042 .37945 .25193 .37972 .25098 .37755 Mtetra
.656 .589 .768 r
.25098 .37755 .25193 .37972 .25351 .37912 .25257 .37684 Mtetra
.647 .575 .76 r
.25257 .37684 .25351 .37912 .25511 .37842 .25416 .37617 Mtetra
.581 .543 .777 r
.25416 .37617 .25511 .37842 .25665 .3783 .25571 .37595 Mtetra
.019 .185 .695 r
.25571 .37595 .25665 .3783 .25792 .38156 .25711 .37755 Mtetra
.807 .542 0 r
.25711 .37755 .25792 .38156 .24288 .58167 .25813 .38381 Mtetra
0 0 .17 r
.25813 .38381 .24288 .58167 .244 .58788 .24324 .58248 Mtetra
.153 .129 .576 r
.24324 .58248 .244 .58788 .24556 .58884 .24463 .58551 Mtetra
.408 .38 .715 r
.24463 .58551 .24556 .58884 .24724 .58846 .2462 .58636 Mtetra
.503 .528 .815 r
.2462 .58636 .24724 .58846 .24896 .58757 .24784 .5865 Mtetra
.457 .674 .957 r
.24784 .5865 .24896 .58757 .25065 .58696 .24948 .58653 Mtetra
.49 .834 .997 r
.24948 .58653 .25065 .58696 .25236 .58623 .25115 .58621 Mtetra
.679 .959 .945 r
.25115 .58621 .25236 .58623 .25412 .58483 .25288 .58528 Mtetra
.948 .937 .748 r
.25288 .58528 .25412 .58483 .25615 .58 .25476 .58229 Mtetra
.997 .856 .553 r
.25476 .58229 .25615 .58 .27362 .37841 .25707 .57395 Mtetra
0 0 .16 r
.25707 .57395 .27362 .37841 .27569 .37174 .27433 .3747 Mtetra
0 0 0 r
.27433 .3747 .27569 .37174 .27739 .36982 .27611 .37176 Mtetra
.268 0 .084 r
.27611 .37176 .27739 .36982 .27899 .36917 .27772 .37106 Mtetra
.444 .042 .181 r
.27772 .37106 .27899 .36917 .28056 .36893 .27928 .37101 Mtetra
.399 .009 .178 r
.27928 .37101 .28056 .36893 .28215 .36853 .28086 .37071 Mtetra
.351 0 .162 r
.28086 .37071 .28215 .36853 .28374 .368 .28245 .3702 Mtetra
.356 0 .167 r
.28245 .3702 .28374 .368 .28534 .36746 .28405 .36969 Mtetra
.397 .015 .193 r
.28405 .36969 .28534 .36746 .28694 .36691 .28563 .36935 Mtetra
.407 .036 .219 r
.28563 .36935 .28694 .36691 .28854 .36635 .28722 .36898 Mtetra
.354 0 .21 r
.28722 .36898 .28854 .36635 .29014 .3658 .28883 .36832 Mtetra
.083 0 .055 r
.28883 .36832 .29014 .3658 .29173 .36532 .29051 .36675 Mtetra
0 0 0 r
.29051 .36675 .29173 .36532 .29333 .36488 .29221 .36492 Mtetra
.851 .967 .875 r
.29221 .36492 .29333 .36488 .29492 .36445 .29389 .36337 Mtetra
.736 .75 .864 r
.29389 .36337 .29492 .36445 .29652 .36399 .29552 .36241 Mtetra
.65 .647 .834 r
.29552 .36241 .29652 .36399 .29812 .3635 .29713 .36186 Mtetra
.621 .627 .835 r
.29713 .36186 .29812 .3635 .29972 .36299 .29872 .36145 Mtetra
.623 .643 .849 r
.29872 .36145 .29972 .36299 .30133 .36244 .30032 .36104 Mtetra
.632 .667 .866 r
.30032 .36104 .30133 .36244 .30294 .36186 .30192 .36059 Mtetra
.634 .69 .885 r
.30192 .36059 .30294 .36186 .30455 .36127 .30352 .36015 Mtetra
.714 .739 .871 r
.30352 .36015 .30455 .36127 .30619 .36037 .30515 .35931 Mtetra
.725 .755 .876 r
.30515 .35931 .30619 .36037 .30782 .35947 .30679 .35844 Mtetra
.595 .722 .932 r
.30679 .35844 .30782 .35947 .30942 .35914 .30838 .35812 Mtetra
.826 .365 0 r
.30838 .35812 .30942 .35914 .31082 .36172 .30978 .36073 Mtetra
.951 .685 .496 r
.30978 .36073 .31082 .36172 .29894 .56345 .29781 .56281 Mtetra
.934 .584 .336 r
.29781 .56281 .29894 .56345 .30017 .57015 .29904 .5695 Mtetra
.502 .792 .997 r
.29904 .5695 .30017 .57015 .30193 .5691 .30074 .56926 Mtetra
.966 .841 .669 r
.30074 .56926 .30193 .5691 .30442 .5567 .30275 .56446 Mtetra
.961 .701 .497 r
.30275 .56446 .30442 .5567 .31901 .35739 .31755 .36301 Mtetra
0 0 .025 r
.31755 .36301 .31901 .35739 .32078 .35439 .31951 .35713 Mtetra
.257 0 .17 r
.31951 .35713 .32078 .35439 .32242 .35359 .32117 .356 Mtetra
.395 .023 .21 r
.32117 .356 .32242 .35359 .32403 .35326 .32279 .35558 Mtetra
.391 .014 .199 r
.32279 .35558 .32403 .35326 .32564 .35289 .3244 .35517 Mtetra
.34 0 .169 r
.3244 .35517 .32564 .35289 .32726 .35231 .32603 .35456 Mtetra
.35 0 .17 r
.32603 .35456 .32726 .35231 .32888 .35174 .32765 .354 Mtetra
.35 0 .171 r
.32765 .354 .32888 .35174 .33051 .35118 .32928 .35344 Mtetra
.346 0 .169 r
.32928 .35344 .33051 .35118 .33214 .35061 .33091 .35286 Mtetra
.347 0 .169 r
.33091 .35286 .33214 .35061 .33376 .35004 .33254 .35228 Mtetra
.347 0 .168 r
.33254 .35228 .33376 .35004 .33539 .34947 .33417 .35171 Mtetra
.348 0 .169 r
.33417 .35171 .33539 .34947 .33702 .3489 .3358 .35115 Mtetra
.349 0 .169 r
.3358 .35115 .33702 .3489 .33865 .34834 .33744 .35058 Mtetra
.347 0 .168 r
.33744 .35058 .33865 .34834 .34028 .34779 .33907 .35001 Mtetra
.344 0 .164 r
.33907 .35001 .34028 .34779 .34191 .34726 .3407 .34944 Mtetra
.342 0 .158 r
.3407 .34944 .34191 .34726 .34354 .34673 .34234 .34887 Mtetra
.254 0 .106 r
.34234 .34887 .34354 .34673 .34519 .34601 .34399 .348 Mtetra
.189 0 .052 r
.34399 .348 .34519 .34601 .34684 .34517 .34565 .34701 Mtetra
.373 0 .131 r
.34565 .34701 .34684 .34517 .34846 .34476 .34728 .34669 Mtetra
.735 .365 .352 r
.34728 .34669 .34846 .34476 .35001 .34589 .34875 .34911 Mtetra
.949 .679 .49 r
.34875 .34911 .35001 .34589 .35123 .35283 .33934 .54941 Mtetra
.545 .316 .519 r
.33934 .54941 .35123 .35283 .34195 .55397 .34071 .55579 Mtetra
.676 .284 .294 r
.34071 .55579 .34195 .55397 .34351 .55684 .34234 .55741 Mtetra
.159 0 0 r
.34234 .55741 .34351 .55684 .34524 .55667 .34407 .55722 Mtetra
0 0 0 r
.34407 .55722 .34524 .55667 .34701 .55582 .34583 .55658 Mtetra
.34583 .55658 .34701 .55582 .34878 .55489 .34759 .55589 Mtetra
.126 0 0 r
.34759 .55589 .34878 .55489 .35054 .55427 .34934 .55536 Mtetra
.134 0 0 r
.34934 .55536 .35054 .55427 .35229 .55372 .3511 .55479 Mtetra
.129 0 0 r
.3511 .55479 .35229 .55372 .35403 .55341 .35285 .55422 Mtetra
.032 0 0 r
.35285 .55422 .35403 .55341 .35576 .55335 .35461 .55366 Mtetra
.363 .829 .768 r
.35461 .55366 .35576 .55335 .3575 .55327 .35638 .55295 Mtetra
.709 .926 .964 r
.35638 .55295 .3575 .55327 .35923 .55317 .35816 .55203 Mtetra
.767 .765 .851 r
.35816 .55203 .35923 .55317 .36098 .55299 .35995 .55076 Mtetra
.762 .648 .736 r
.35995 .55076 .36098 .55299 .36275 .55228 .36178 .54881 Mtetra
.805 .619 .65 r
.36178 .54881 .36275 .55228 .36459 .55004 .36373 .54442 Mtetra
.951 .684 .494 r
.36373 .54442 .36459 .55004 .36669 .54225 .37503 .34237 Mtetra
.548 .323 .526 r
.37503 .34237 .36669 .54225 .37786 .33929 .37699 .33534 Mtetra
.726 .555 .659 r
.37699 .33534 .37786 .33929 .37968 .33522 .37874 .33277 Mtetra
.659 .574 .749 r
.37874 .33277 .37968 .33522 .38135 .33432 .38041 .33194 Mtetra
.602 .548 .767 r
.38041 .33194 .38135 .33432 .383 .33402 .38206 .33156 Mtetra
.582 .533 .764 r
.38206 .33156 .383 .33402 .38465 .33365 .3837 .33132 Mtetra
.612 .558 .77 r
.3837 .33132 .38465 .33365 .38633 .33266 .38536 .33089 Mtetra
.623 .617 .824 r
.38536 .33089 .38633 .33266 .38801 .33169 .38701 .33045 Mtetra
.648 .705 .889 r
.38701 .33045 .38801 .33169 .38968 .33086 .38867 .32993 Mtetra
.685 .778 .922 r
.38867 .32993 .38968 .33086 .39134 .33025 .39034 .32925 Mtetra
.691 .767 .909 r
.39034 .32925 .39134 .33025 .39301 .3297 .39201 .32855 Mtetra
.69 .735 .885 r
.39201 .32855 .39301 .3297 .39467 .32918 .39368 .32783 Mtetra
.682 .699 .859 r
.39368 .32783 .39467 .32918 .39633 .32864 .39535 .32711 Mtetra
.654 .663 .847 r
.39535 .32711 .39633 .32864 .398 .32808 .39702 .32653 Mtetra
.587 .631 .862 r
.39702 .32653 .398 .32808 .39967 .32749 .39868 .32627 Mtetra
.337 .567 .923 r
.39868 .32627 .39967 .32749 .40134 .32685 .40031 .32664 Mtetra
.369 0 0 r
.40031 .32664 .40134 .32685 .40301 .3262 .40193 .3273 Mtetra
.496 .025 .068 r
.40193 .3273 .40301 .3262 .40469 .32544 .40357 .32766 Mtetra
.234 0 .11 r
.40357 .32766 .40469 .32544 .40638 .32446 .40526 .32665 Mtetra
.324 0 .151 r
.40526 .32665 .40638 .32446 .40805 .32388 .40694 .32599 Mtetra
.623 .239 .294 r
.40694 .32599 .40805 .32388 .40969 .32439 .40855 .32711 Mtetra
.956 .68 .473 r
.40855 .32711 .40969 .32439 .41117 .3292 .40296 .52623 Mtetra
.549 .319 .519 r
.40296 .52623 .41117 .3292 .40561 .53233 .40441 .53505 Mtetra
.689 .329 .358 r
.40441 .53505 .40561 .53233 .40722 .53682 .4061 .53726 Mtetra
.09 0 0 r
.4061 .53726 .40722 .53682 .40897 .5372 .40788 .53705 Mtetra
.596 .928 .962 r
.40788 .53705 .40897 .5372 .41076 .53687 .40968 .5363 Mtetra
.715 .881 .958 r
.40968 .5363 .41076 .53687 .41256 .53622 .41149 .53542 Mtetra
.606 .799 .974 r
.41149 .53542 .41256 .53622 .41435 .5357 .41328 .53495 Mtetra
.64 .824 .971 r
.41328 .53495 .41435 .5357 .41615 .53509 .41508 .53437 Mtetra
.721 .848 .942 r
.41508 .53437 .41615 .53509 .41795 .53445 .41689 .53348 Mtetra
.817 .804 .839 r
.41689 .53348 .41795 .53445 .41975 .53388 .41872 .53184 Mtetra
.775 .669 .747 r
.41872 .53184 .41975 .53388 .42155 .53331 .42056 .52987 Mtetra
.705 .563 .692 r
.42056 .52987 .42155 .53331 .42335 .53283 .4224 .52804 Mtetra
.556 .432 .666 r
.4224 .52804 .42335 .53283 .42514 .53269 .42419 .52791 Mtetra
.583 .45 .665 r
.42419 .52791 .42514 .53269 .42694 .53213 .42599 .52745 Mtetra
.685 .519 .656 r
.42599 .52745 .42694 .53213 .42878 .53051 .42784 .52536 Mtetra
.958 .685 .477 r
.42784 .52536 .42878 .53051 .43075 .52405 .43533 .32509 Mtetra
.555 .328 .527 r
.43533 .32509 .43075 .52405 .43819 .31918 .4373 .31474 Mtetra
.742 .555 .642 r
.4373 .31474 .43819 .31918 .44001 .31387 .43907 .31144 Mtetra
.677 .587 .747 r
.43907 .31144 .44001 .31387 .44172 .31269 .44077 .31043 Mtetra
.626 .574 .775 r
.44077 .31043 .44172 .31269 .44342 .31219 .44247 .3099 Mtetra
.603 .559 .777 r
.44247 .3099 .44342 .31219 .44511 .31192 .44416 .30952 Mtetra
.669 .586 .753 r
.44416 .30952 .44511 .31192 .44682 .31086 .44587 .3086 Mtetra
.642 .582 .772 r
.44587 .3086 .44682 .31086 .44852 .31021 .44757 .30795 Mtetra
.553 .534 .788 r
.44757 .30795 .44852 .31021 .4502 .31045 .44925 .30788 Mtetra
.01 .163 .676 r
.44925 .30788 .4502 .31045 .45177 .31547 .45089 .30991 Mtetra
0 0 .331 r
.45089 .30991 .45177 .31547 .44883 .519 .45243 .31676 Mtetra
0 0 .3 r
.45243 .31676 .44883 .519 .45053 .5235 .4496 .5172 Mtetra
.337 .252 .611 r
.4496 .5172 .45053 .5235 .45234 .52353 .45135 .51966 Mtetra
.446 .387 .698 r
.45135 .51966 .45234 .52353 .45416 .52281 .45315 .52048 Mtetra
.52 .524 .799 r
.45315 .52048 .45416 .52281 .456 .52174 .45495 .52058 Mtetra
.592 .72 .933 r
.45495 .52058 .456 .52174 .45782 .52117 .45677 .52022 Mtetra
.644 .785 .949 r
.45677 .52022 .45782 .52117 .45964 .52062 .4586 .51965 Mtetra
.664 .785 .939 r
.4586 .51965 .45964 .52062 .46147 .52012 .46043 .519 Mtetra
.613 .737 .934 r
.46043 .519 .46147 .52012 .46329 .51982 .46225 .51857 Mtetra
.603 .708 .918 r
.46225 .51857 .46329 .51982 .46512 .51948 .46408 .51819 Mtetra
.585 .692 .916 r
.46408 .51819 .46512 .51948 .46694 .51905 .46591 .51788 Mtetra
.328 .591 .941 r
.46591 .51788 .46694 .51905 .46877 .51872 .46772 .51823 Mtetra
.361 .769 .982 r
.46772 .51823 .46877 .51872 .47061 .51794 .46955 .51811 Mtetra
.535 .924 .854 r
.46955 .51811 .47061 .51794 .47246 .51633 .47139 .51718 Mtetra
.988 .895 .597 r
.47139 .51718 .47246 .51633 .47439 .50951 .4733 .51197 Mtetra
.97 .694 .453 r
.4733 .51197 .47439 .50951 .47921 .30459 .47821 .30566 Mtetra
.999 .84 .537 r
.47821 .30566 .47921 .30459 .48099 .29928 .48003 .2982 Mtetra
.782 .777 .849 r
.48003 .2982 .48099 .29928 .48272 .29809 .48176 .29689 Mtetra
.638 .716 .904 r
.48176 .29689 .48272 .29809 .48444 .29759 .48348 .2964 Mtetra
.524 .67 .929 r
.48348 .2964 .48444 .29759 .48616 .29742 .4852 .2963 Mtetra
.671 .744 .905 r
.4852 .2963 .48616 .29742 .48788 .29677 .48692 .29566 Mtetra
.681 .749 .903 r
.48692 .29566 .48788 .29677 .48961 .29607 .48865 .29497 Mtetra
.689 .753 .9 r
.48865 .29497 .48961 .29607 .49134 .29536 .49038 .29424 Mtetra
.778 .773 .848 r
.49038 .29424 .49134 .29536 .49307 .29413 .49211 .29295 Mtetra
.725 .749 .871 r
.49211 .29295 .49307 .29413 .4948 .29326 .49384 .29201 Mtetra
.575 .684 .914 r
.49384 .29201 .4948 .29326 .49653 .29306 .49557 .29176 Mtetra
.803 .37 0 r
.49557 .29176 .49653 .29306 .49822 .29672 .49726 .2953 Mtetra
.968 .684 .437 r
.49726 .2953 .49822 .29672 .49831 .50184 .49729 .50049 Mtetra
.927 .546 .16 r
.49729 .50049 .49831 .50184 .50011 .50819 .49908 .50712 Mtetra
.204 .543 .928 r
.49908 .50712 .50011 .50819 .50195 .5086 .50093 .50766 Mtetra
.639 .788 .953 r
.50093 .50766 .50195 .5086 .50381 .508 .50278 .50709 Mtetra
.767 .824 .897 r
.50278 .50709 .50381 .508 .50567 .50699 .50465 .5059 Mtetra
.73 .784 .895 r
.50465 .5059 .50567 .50699 .50752 .50699 .50651 .50491 Mtetra
.733 .654 .772 r
.50651 .50491 .50752 .50699 .50938 .50672 .50837 .50347 Mtetra
.745 .594 .689 r
.50837 .50347 .50938 .50672 .51124 .50572 .51024 .50106 Mtetra
.864 .631 .585 r
.51024 .50106 .51124 .50572 .51312 .50083 .51213 .49138 Mtetra
.96 .679 .457 r
.51213 .49138 .51312 .50083 .51559 .29451 .51465 .28974 Mtetra
.767 .566 .626 r
.51465 .28974 .51559 .29451 .51736 .28672 .51641 .28539 Mtetra
.772 .74 .824 r
.51641 .28539 .51736 .28672 .5191 .28506 .51815 .28404 Mtetra
.663 .763 .924 r
.51815 .28404 .5191 .28506 .52085 .28445 .5199 .28342 Mtetra
.582 .734 .947 r
.5199 .28342 .52085 .28445 .52259 .28425 .52165 .2831 Mtetra
.754 .766 .862 r
.52165 .2831 .52259 .28425 .52434 .28324 .52339 .28198 Mtetra
.72 .737 .864 r
.52339 .28198 .52434 .28324 .52609 .2824 .52514 .28104 Mtetra
.587 .668 .895 r
.52514 .28104 .52609 .2824 .52784 .28222 .52689 .28075 Mtetra
.681 .257 0 r
.52689 .28075 .52784 .28222 .52959 .28559 .52865 .28387 Mtetra
.971 .683 .425 r
.52865 .28387 .52959 .28559 .53178 .49102 .53077 .48913 Mtetra
.915 .547 .109 r
.53077 .48913 .53178 .49102 .53367 .49765 .53266 .49649 Mtetra
0 .328 .805 r
.53266 .49649 .53367 .49765 .53555 .49872 .53454 .49763 Mtetra
.59 .739 .947 r
.53454 .49763 .53555 .49872 .53743 .49834 .53642 .49725 Mtetra
.796 .799 .854 r
.53642 .49725 .53743 .49834 .5393 .49686 .5383 .49577 Mtetra
.934 .776 .662 r
.5383 .49577 .5393 .49686 .54116 .49208 .54016 .49097 Mtetra
.971 .689 .436 r
.54016 .49097 .54116 .49208 .54192 .28561 .54097 .28444 Mtetra
.954 .743 .579 r
.54097 .28444 .54192 .28561 .54363 .27757 .54269 .27643 Mtetra
.831 .78 .803 r
.54269 .27643 .54363 .27757 .54539 .27573 .54445 .27458 Mtetra
.666 .742 .907 r
.54445 .27458 .54539 .27573 .54715 .2751 .54621 .27395 Mtetra
.55 .696 .936 r
.54621 .27395 .54715 .2751 .54891 .2749 .54798 .27375 Mtetra
.719 .759 .884 r
.54798 .27375 .54891 .2749 .55067 .27399 .54974 .27285 Mtetra
.712 .757 .888 r
.54974 .27285 .55067 .27399 .55244 .27313 .5515 .27198 Mtetra
.568 .703 .933 r
.5515 .27198 .55244 .27313 .55421 .27288 .55327 .27173 Mtetra
.694 .233 0 r
.55327 .27173 .55421 .27288 .55601 .27569 .55507 .27454 Mtetra
.972 .681 .415 r
.55507 .27454 .55601 .27569 .55996 .48032 .55896 .47923 Mtetra
.936 .562 .2 r
.55896 .47923 .55996 .48032 .56194 .48833 .56095 .48724 Mtetra
0 .4 .85 r
.56095 .48724 .56194 .48833 .56386 .48929 .56286 .48819 Mtetra
.634 .757 .936 r
.56286 .48819 .56386 .48929 .56575 .48875 .56476 .48765 Mtetra
.731 .787 .897 r
.56476 .48765 .56575 .48875 .56765 .48773 .56665 .48663 Mtetra
.537 .719 .957 r
.56665 .48663 .56765 .48773 .56955 .48746 .56856 .48643 Mtetra
.512 .721 .967 r
.56856 .48643 .56955 .48746 .57146 .48723 .57047 .48627 Mtetra
.696 .806 .933 r
.57047 .48627 .57146 .48723 .57336 .48634 .57237 .48545 Mtetra
.934 .811 .701 r
.57237 .48545 .57336 .48634 .57521 .4824 .57423 .48161 Mtetra
.973 .688 .423 r
.57423 .48161 .57521 .4824 .57389 .278 .57298 .27813 Mtetra
.99 .763 .498 r
.57298 .27813 .57389 .278 .57551 .26691 .57458 .26579 Mtetra
.866 .791 .775 r
.57458 .26579 .57551 .26691 .57726 .26466 .57634 .26351 Mtetra
.68 .748 .902 r
.57634 .26351 .57726 .26466 .57904 .26396 .57812 .2628 Mtetra
.557 .697 .934 r
.57812 .2628 .57904 .26396 .58083 .26374 .57991 .26258 Mtetra
.701 .755 .894 r
.57991 .26258 .58083 .26374 .58261 .26292 .58169 .26177 Mtetra
.72 .761 .885 r
.58169 .26177 .58261 .26292 .58439 .26201 .58347 .26085 Mtetra
.587 .712 .93 r
.58347 .26085 .58439 .26201 .58618 .26169 .58526 .26053 Mtetra
.585 .123 0 r
.58526 .26053 .58618 .26169 .58803 .26412 .58711 .26297 Mtetra
.973 .68 .402 r
.58711 .26297 .58803 .26412 .59414 .4685 .59316 .46742 Mtetra
.939 .57 .206 r
.59316 .46742 .59414 .4685 .59626 .47749 .59528 .47639 Mtetra
0 .156 .666 r
.59528 .47639 .59626 .47749 .59823 .4791 .59725 .478 Mtetra
.537 .718 .956 r
.59725 .478 .59823 .4791 .60016 .47889 .59918 .47779 Mtetra
.768 .798 .878 r
.59918 .47779 .60016 .47889 .60206 .47763 .60109 .47652 Mtetra
.923 .794 .7 r
.60109 .47652 .60206 .47763 .60391 .47383 .60294 .47273 Mtetra
.975 .687 .413 r
.60294 .47273 .60391 .47383 .60092 .273 .6 .27192 Mtetra
.974 .725 .498 r
.6 .27192 .60092 .273 .60236 .25784 .60144 .25668 Mtetra
.877 .787 .758 r
.60144 .25668 .60236 .25784 .60411 .25532 .6032 .25416 Mtetra
.68 .748 .903 r
.6032 .25416 .60411 .25532 .60591 .25461 .60499 .25345 Mtetra
.55 .695 .936 r
.60499 .25345 .60591 .25461 .60772 .25441 .60681 .25325 Mtetra
.602 .719 .927 r
.60681 .25325 .60772 .25441 .60953 .25403 .60861 .25287 Mtetra
.668 .745 .908 r
.60861 .25287 .60953 .25403 .61133 .25337 .61042 .25221 Mtetra
.673 .747 .906 r
.61042 .25221 .61133 .25337 .61313 .25268 .61222 .25153 Mtetra
.738 .77 .878 r
.61222 .25153 .61313 .25268 .61492 .25163 .61402 .2505 Mtetra
.742 .776 .88 r
.61402 .2505 .61492 .25163 .61672 .25055 .61581 .24945 Mtetra
.626 .744 .932 r
.61581 .24945 .61672 .25055 .61853 .25003 .61762 .24897 Mtetra
0 .061 .584 r
.61762 .24897 .61853 .25003 .62041 .25179 .61951 .25079 Mtetra
.974 .677 .388 r
.61951 .25079 .62041 .25179 .6285 .44962 .62761 .4506 Mtetra
.938 .593 .343 r
.62761 .4506 .6285 .44962 .63098 .46591 .63002 .46485 Mtetra
0 .018 .533 r
.63002 .46485 .63098 .46591 .63301 .46801 .63205 .4669 Mtetra
.499 .701 .96 r
.63205 .4669 .63301 .46801 .63498 .46792 .63401 .4668 Mtetra
.754 .797 .887 r
.63401 .4668 .63498 .46792 .6369 .46674 .63594 .46562 Mtetra
.918 .801 .716 r
.63594 .46562 .6369 .46674 .63875 .46324 .63779 .46213 Mtetra
.978 .712 .455 r
.63779 .46213 .63875 .46324 .6398 .43702 .63887 .43664 Mtetra
.977 .686 .397 r
.63887 .43664 .6398 .43702 .63492 .24655 .63402 .24538 Mtetra
.896 .789 .735 r
.63402 .24538 .63492 .24655 .63666 .24366 .63576 .24248 Mtetra
.704 .756 .893 r
.63576 .24248 .63666 .24366 .63847 .24282 .63757 .24164 Mtetra
.587 .71 .928 r
.63757 .24164 .63847 .24282 .64031 .24249 .63941 .2413 Mtetra
.666 .743 .907 r
.63941 .2413 .64031 .24249 .64213 .24183 .64123 .24065 Mtetra
.733 .766 .879 r
.64123 .24065 .64213 .24183 .64394 .24082 .64304 .23964 Mtetra
.636 .731 .917 r
.64304 .23964 .64394 .24082 .64577 .2403 .64487 .23912 Mtetra
0 .282 .78 r
.64487 .23912 .64577 .2403 .64767 .24162 .64678 .24044 Mtetra
.938 .574 .185 r
.64678 .24044 .64767 .24162 .64993 .25148 .64903 .2503 Mtetra
.975 .675 .374 r
.64903 .2503 .64993 .25148 .66021 .45549 .65926 .45436 Mtetra
0 0 .513 r
.65926 .45436 .66021 .45549 .66229 .45776 .66134 .45663 Mtetra
.629 .756 .938 r
.66134 .45663 .66229 .45776 .66426 .45722 .66331 .45609 Mtetra
.769 .8 .878 r
.66331 .45609 .66426 .45722 .6662 .45593 .66525 .4548 Mtetra
.782 .803 .87 r
.66525 .4548 .6662 .45593 .66813 .45454 .66718 .45341 Mtetra
.73 .79 .9 r
.66718 .45341 .66813 .45454 .67008 .45351 .66914 .45237 Mtetra
.716 .786 .907 r
.66914 .45237 .67008 .45351 .67204 .45255 .67109 .45141 Mtetra
.656 .765 .93 r
.67109 .45141 .67204 .45255 .67401 .45189 .67306 .45075 Mtetra
.563 .727 .951 r
.67306 .45075 .67401 .45189 .67599 .4516 .67505 .45046 Mtetra
.534 .713 .955 r
.67505 .45046 .67599 .4516 .67799 .45139 .67704 .45025 Mtetra
.442 .667 .958 r
.67704 .45025 .67799 .45139 .67999 .45146 .67905 .45032 Mtetra
.415 .652 .956 r
.67905 .45032 .67999 .45146 .68201 .45161 .68107 .45047 Mtetra
.629 .755 .938 r
.68107 .45047 .68201 .45161 .68399 .45107 .68305 .44992 Mtetra
.89 .812 .765 r
.68305 .44992 .68399 .45107 .68587 .44836 .68493 .44722 Mtetra
.981 .722 .465 r
.68493 .44722 .68587 .44836 .68698 .43029 .68604 .42911 Mtetra
.977 .682 .379 r
.68604 .42911 .68698 .43029 .67895 .23136 .67806 .23016 Mtetra
.912 .79 .713 r
.67806 .23016 .67895 .23136 .68066 .22811 .67978 .22691 Mtetra
.709 .758 .89 r
.67978 .22691 .68066 .22811 .6825 .22723 .68162 .22602 Mtetra
.59 .71 .927 r
.68162 .22602 .6825 .22723 .68436 .22688 .68349 .22568 Mtetra
.626 .726 .919 r
.68349 .22568 .68436 .22688 .68622 .2264 .68535 .22519 Mtetra
.733 .766 .879 r
.68535 .22519 .68622 .2264 .68806 .22537 .68718 .22417 Mtetra
.644 .733 .913 r
.68718 .22417 .68806 .22537 .68991 .22481 .68904 .2236 Mtetra
.097 .421 .867 r
.68904 .2236 .68991 .22481 .69186 .22578 .69098 .22456 Mtetra
.911 .53 .102 r
.69098 .22456 .69186 .22578 .69421 .23413 .69333 .2328 Mtetra
.975 .671 .352 r
.69333 .2328 .69421 .23413 .70768 .44054 .70675 .43934 Mtetra
.578 .121 0 r
.70675 .43934 .70768 .44054 .70987 .44347 .70894 .44226 Mtetra
.551 .709 .945 r
.70894 .44226 .70987 .44347 .7119 .44328 .71096 .44201 Mtetra
.7 .761 .9 r
.71096 .44201 .7119 .44328 .71388 .44238 .71295 .44112 Mtetra
.673 .753 .911 r
.71295 .44112 .71388 .44238 .71586 .44139 .71494 .44037 Mtetra
.441 .696 .973 r
.71494 .44037 .71586 .44139 .71787 .44086 .71699 .44038 Mtetra
.527 .865 .993 r
.71699 .44038 .71787 .44086 .71985 .43981 .719 .43987 Mtetra
.844 .999 .799 r
.719 .43987 .71985 .43981 .72173 .43713 .72092 .4378 Mtetra
.995 .826 .467 r
.72092 .4378 .72173 .43713 .723 .42448 .72246 .42955 Mtetra
.979 .683 .346 r
.72246 .42955 .723 .42448 .71247 .2205 .71164 .21993 Mtetra
.977 .845 .645 r
.71164 .21993 .71247 .2205 .71415 .21684 .71328 .21556 Mtetra
.734 .756 .87 r
.71328 .21556 .71415 .21684 .716 .21584 .71513 .21451 Mtetra
.609 .696 .906 r
.71513 .21451 .716 .21584 .71789 .2154 .71702 .2141 Mtetra
.605 .7 .911 r
.71702 .2141 .71789 .2154 .71977 .21495 .71891 .2137 Mtetra
.743 .764 .87 r
.71891 .2137 .71977 .21495 .72162 .21384 .72076 .21259 Mtetra
.66 .735 .905 r
.72076 .21259 .72162 .21384 .72349 .21319 .72263 .21195 Mtetra
.236 .507 .905 r
.72263 .21195 .72349 .21319 .72546 .21387 .7246 .21263 Mtetra
.888 .499 .046 r
.7246 .21263 .72546 .21387 .72789 .2215 .72703 .22022 Mtetra
.975 .667 .334 r
.72703 .22022 .72789 .2215 .74379 .42905 .74288 .42787 Mtetra
.642 .189 0 r
.74288 .42787 .74379 .42905 .74609 .43246 .74518 .43129 Mtetra
.386 .632 .952 r
.74518 .43129 .74609 .43246 .74817 .43269 .74726 .43152 Mtetra
.692 .78 .918 r
.74726 .43152 .74817 .43269 .75018 .43184 .74928 .43067 Mtetra
.872 .819 .794 r
.74928 .43067 .75018 .43184 .75209 .42949 .75119 .42832 Mtetra
.977 .768 .554 r
.75119 .42832 .75209 .42949 .75361 .42164 .75271 .42048 Mtetra
.977 .675 .347 r
.75271 .42048 .75361 .42164 .74074 .21161 .73989 .2104 Mtetra
.952 .785 .639 r
.73989 .2104 .74074 .21161 .74234 .20691 .74149 .20569 Mtetra
.744 .773 .877 r
.74149 .20569 .74234 .20691 .7442 .2058 .74335 .20459 Mtetra
.612 .723 .925 r
.74335 .20459 .7442 .2058 .7461 .20535 .74526 .20415 Mtetra
.571 .706 .933 r
.74526 .20415 .7461 .20535 .74802 .20503 .74718 .20386 Mtetra
.733 .778 .889 r
.74718 .20386 .74802 .20503 .74988 .20392 .74904 .20284 Mtetra
.67 .775 .929 r
.74904 .20284 .74988 .20392 .75177 .20323 .75094 .20214 Mtetra
.424 .656 .956 r
.75094 .20214 .75177 .20323 .75375 .20364 .75289 .20226 Mtetra
0 0 .445 r
.75289 .20226 .75375 .20364 .75619 .21009 .75508 .20543 Mtetra
.973 .665 .306 r
.75508 .20543 .75619 .21009 .77421 .41893 .7727 .40974 Mtetra
.074 .053 .527 r
.7727 .40974 .77421 .41893 .77659 .4227 .77543 .41805 Mtetra
.434 .363 .678 r
.77543 .41805 .77659 .4227 .77868 .42253 .77762 .41928 Mtetra
.514 .467 .742 r
.77762 .41928 .77868 .42253 .7807 .42163 .77974 .41953 Mtetra
.563 .583 .832 r
.77974 .41953 .7807 .42163 .78271 .4205 .78182 .41936 Mtetra
.468 .684 .96 r
.78182 .41936 .78271 .4205 .7848 .42035 .78393 .41935 Mtetra
.638 .796 .959 r
.78393 .41935 .7848 .42035 .78686 .41976 .78598 .41871 Mtetra
.833 .844 .855 r
.78598 .41871 .78686 .41976 .78883 .41809 .78794 .41695 Mtetra
.98 .777 .559 r
.78794 .41695 .78883 .41809 .79033 .41073 .78945 .40964 Mtetra
.976 .671 .329 r
.78945 .40964 .79033 .41073 .775 .19998 .77416 .19879 Mtetra
.963 .787 .616 r
.77416 .19879 .775 .19998 .77654 .19483 .7757 .1936 Mtetra
.755 .778 .872 r
.7757 .1936 .77654 .19483 .77841 .19365 .77757 .19242 Mtetra
.624 .726 .92 r
.77757 .19242 .77841 .19365 .78033 .19315 .7795 .19192 Mtetra
.553 .692 .932 r
.7795 .19192 .78033 .19315 .78229 .19293 .78145 .1917 Mtetra
.748 .776 .875 r
.78145 .1917 .78229 .19293 .78416 .19179 .78333 .19056 Mtetra
.678 .749 .905 r
.78333 .19056 .78416 .19179 .78607 .19105 .78524 .18981 Mtetra
.455 .64 .936 r
.78524 .18981 .78607 .19105 .78806 .19115 .78723 .18991 Mtetra
.773 .357 0 r
.78723 .18991 .78806 .19115 .7905 .19637 .78967 .19516 Mtetra
.971 .657 .298 r
.78967 .19516 .7905 .19637 .8111 .40641 .81023 .40524 Mtetra
.729 .292 0 r
.81023 .40524 .8111 .40641 .81364 .41104 .81276 .40986 Mtetra
.306 .582 .939 r
.81276 .40986 .81364 .41104 .81581 .41151 .81494 .41032 Mtetra
.654 .768 .933 r
.81494 .41032 .81581 .41151 .81788 .41083 .81701 .40964 Mtetra
.836 .823 .835 r
.81701 .40964 .81788 .41083 .81985 .40897 .81897 .40774 Mtetra
.978 .781 .571 r
.81897 .40774 .81985 .40897 .82141 .40265 .82049 .401 Mtetra
.974 .666 .314 r
.82049 .401 .82141 .40265 .80395 .19109 .80305 .18907 Mtetra
.933 .728 .604 r
.80305 .18907 .80395 .19109 .80537 .18494 .80452 .18332 Mtetra
.727 .718 .842 r
.18438 .40002 .18543 .40124 .18702 .40026 .18596 .39909 Mtetra
.575 .681 .913 r
.18596 .39909 .18702 .40026 .18853 .39999 .18747 .39888 Mtetra
.401 .617 .939 r
.18747 .39888 .18853 .39999 .19 .40012 .18893 .39905 Mtetra
.64 .723 .908 r
.18893 .39905 .19 .40012 .19154 .39965 .19047 .3986 Mtetra
.658 .732 .904 r
.19047 .3986 .19154 .39965 .19308 .39912 .19201 .39808 Mtetra
.668 .736 .9 r
.19201 .39808 .19308 .39912 .19463 .39856 .19356 .39751 Mtetra
.757 .752 .848 r
.19356 .39751 .19463 .39856 .19623 .39747 .19516 .39643 Mtetra
.705 .745 .883 r
.19516 .39643 .19623 .39747 .1978 .39672 .19673 .39569 Mtetra
.502 .682 .947 r
.19673 .39569 .1978 .39672 .1993 .39666 .19823 .39563 Mtetra
.929 .552 .257 r
.19823 .39563 .1993 .39666 .20036 .40088 .1993 .3998 Mtetra
.939 .683 .523 r
.1993 .3998 .20036 .40088 .18181 .601 .18067 .59994 Mtetra
.937 .58 .313 r
.18067 .59994 .18181 .601 .18288 .60624 .18173 .60526 Mtetra
.127 .514 .912 r
.18173 .60526 .18288 .60624 .18441 .60688 .18327 .60577 Mtetra
.652 .73 .907 r
.18327 .60577 .18441 .60688 .18605 .60639 .18492 .60523 Mtetra
.764 .746 .837 r
.18492 .60523 .18605 .60639 .18779 .60495 .18664 .60399 Mtetra
.824 .776 .807 r
.18664 .60399 .18779 .60495 .18975 .60127 .18842 .60219 Mtetra
.927 .973 .728 r
.18842 .60219 .18975 .60127 .19266 .58785 .1903 .59935 Mtetra
.194 0 .338 r
.1903 .59935 .19266 .58785 .21293 .39521 .19245 .59365 Mtetra
0 0 .135 r
.19245 .59365 .21293 .39521 .2147 .39252 .21303 .39767 Mtetra
0 0 0 r
.21303 .39767 .2147 .39252 .21634 .39108 .21509 .39201 Mtetra
.922 .975 .716 r
.21509 .39201 .21634 .39108 .21794 .39015 .21685 .38931 Mtetra
.763 .793 .877 r
.21685 .38931 .21794 .39015 .21951 .38946 .21846 .38827 Mtetra
.655 .705 .884 r
.21846 .38827 .21951 .38946 .22107 .38894 .22002 .38774 Mtetra
.598 .686 .903 r
.22002 .38774 .22107 .38894 .22262 .3885 .22156 .38745 Mtetra
.742 .751 .859 r
.22156 .38745 .22262 .3885 .22422 .38749 .22316 .38647 Mtetra
.711 .751 .883 r
.22316 .38647 .22422 .38749 .22581 .3867 .22475 .38569 Mtetra
.538 .702 .946 r
.22475 .38569 .22581 .3867 .22734 .38653 .22628 .38554 Mtetra
.902 .488 .15 r
.22628 .38554 .22734 .38653 .22855 .38978 .22749 .38883 Mtetra
.942 .683 .517 r
.22749 .38883 .22855 .38978 .21174 .5895 .21059 .58872 Mtetra
.936 .597 .364 r
.21059 .58872 .21174 .5895 .21274 .59626 .21159 .59536 Mtetra
.001 .451 .865 r
.21159 .59536 .21274 .59626 .2143 .59689 .21315 .59598 Mtetra
.668 .778 .931 r
.21315 .59598 .2143 .59689 .21597 .59628 .21483 .59537 Mtetra
.759 .791 .879 r
.21483 .59537 .21597 .59628 .21769 .59518 .21655 .59428 Mtetra
.544 .743 .968 r
.21655 .59428 .21769 .59518 .21934 .59496 .21819 .59405 Mtetra
.584 .756 .96 r
.21819 .59405 .21934 .59496 .22099 .59463 .21985 .59372 Mtetra
.754 .792 .884 r
.21985 .59372 .22099 .59463 .22271 .59357 .22156 .59267 Mtetra
.912 .751 .669 r
.22156 .59267 .22271 .59357 .22479 .58843 .22364 .58762 Mtetra
.943 .688 .522 r
.22364 .58762 .22479 .58843 .24408 .38648 .24301 .38565 Mtetra
.923 .739 .636 r
.24301 .38565 .24408 .38648 .24616 .38022 .2451 .37924 Mtetra
.825 .77 .8 r
.2451 .37924 .24616 .38022 .24784 .37849 .24678 .37749 Mtetra
.692 .754 .899 r
.24678 .37749 .24784 .37849 .24942 .37783 .24837 .37681 Mtetra
.59 .72 .934 r
.24837 .37681 .24942 .37783 .25098 .37755 .24992 .37651 Mtetra
.679 .742 .898 r
.24992 .37651 .25098 .37755 .25257 .37684 .25151 .37588 Mtetra
.68 .76 .912 r
.25151 .37588 .25257 .37684 .25416 .37617 .2531 .37526 Mtetra
.599 .749 .949 r
.2531 .37526 .25416 .37617 .25571 .37595 .25466 .37492 Mtetra
.222 .544 .928 r
.25466 .37492 .25571 .37595 .25711 .37755 .25616 .37535 Mtetra
.049 .223 .722 r
.25616 .37535 .25711 .37755 .25813 .38381 .25758 .37679 Mtetra
.168 .103 .535 r
.25758 .37679 .25813 .38381 .24324 .58248 .2588 .38061 Mtetra
0 0 .188 r
.2588 .38061 .24324 .58248 .24463 .58551 .24409 .5774 Mtetra
0 0 .457 r
.24409 .5774 .24463 .58551 .2462 .58636 .24525 .58324 Mtetra
.037 .145 .648 r
.24525 .58324 .2462 .58636 .24784 .5865 .24672 .58532 Mtetra
.263 .549 .927 r
.24672 .58532 .24784 .5865 .24948 .58653 .24833 .58576 Mtetra
.589 .792 .977 r
.24833 .58576 .24948 .58653 .25115 .58621 .25001 .58538 Mtetra
.739 .809 .907 r
.25001 .58538 .25115 .58621 .25288 .58528 .25174 .58443 Mtetra
.842 .8 .81 r
.25174 .58443 .25288 .58528 .25476 .58229 .25354 .58251 Mtetra
.946 .904 .749 r
.25354 .58251 .25476 .58229 .25707 .57395 .25544 .57942 Mtetra
0 0 .06 r
.25544 .57942 .25707 .57395 .27433 .3747 .25748 .57448 Mtetra
.523 .297 .514 r
.25748 .57448 .27433 .3747 .27611 .37176 .25949 .56985 Mtetra
.53 .304 .516 r
.25949 .56985 .27611 .37176 .27772 .37106 .26122 .56889 Mtetra
.534 .307 .517 r
.26122 .56889 .27772 .37106 .27928 .37101 .26279 .5699 Mtetra
.532 .305 .516 r
.26279 .5699 .27928 .37101 .28086 .37071 .26443 .57002 Mtetra
.531 .305 .516 r
.26443 .57002 .28086 .37071 .28245 .3702 .26612 .5696 Mtetra
.26612 .5696 .28245 .3702 .28405 .36969 .26781 .56918 Mtetra
.533 .306 .516 r
.26781 .56918 .28405 .36969 .28563 .36935 .26942 .56982 Mtetra
.26942 .56982 .28563 .36935 .28722 .36898 .27106 .5701 Mtetra
.529 .303 .516 r
.27106 .5701 .28722 .36898 .28883 .36832 .27282 .5687 Mtetra
0 0 .208 r
.27282 .5687 .28883 .36832 .29051 .36675 .28872 .37588 Mtetra
0 0 .044 r
.28872 .37588 .29051 .36675 .29221 .36492 .29101 .36606 Mtetra
.952 .949 .649 r
.29101 .36606 .29221 .36492 .29389 .36337 .29283 .3625 Mtetra
.819 .796 .83 r
.29283 .3625 .29389 .36337 .29552 .36241 .29451 .36096 Mtetra
.665 .671 .847 r
.29451 .36096 .29552 .36241 .29713 .36186 .29612 .36034 Mtetra
.6 .636 .859 r
.29612 .36034 .29713 .36186 .29872 .36145 .29771 .36004 Mtetra
.6 .653 .874 r
.29771 .36004 .29872 .36145 .30032 .36104 .2993 .35973 Mtetra
.615 .677 .886 r
.2993 .35973 .30032 .36104 .30192 .36059 .3009 .35937 Mtetra
.613 .69 .898 r
.3009 .35937 .30192 .36059 .30352 .36015 .3025 .359 Mtetra
.704 .734 .875 r
.3025 .359 .30352 .36015 .30515 .35931 .30412 .35823 Mtetra
.72 .748 .874 r
.30412 .35823 .30515 .35931 .30679 .35844 .30575 .35737 Mtetra
.589 .714 .93 r
.30575 .35737 .30679 .35844 .30838 .35812 .30735 .35708 Mtetra
.815 .35 0 r
.30735 .35708 .30838 .35812 .30978 .36073 .30875 .35962 Mtetra
.951 .685 .496 r
.30875 .35962 .30978 .36073 .29781 .56281 .29672 .56158 Mtetra
.949 .602 .312 r
.29672 .56158 .29781 .56281 .29904 .5695 .29792 .56866 Mtetra
.023 .479 .877 r
.29792 .56866 .29904 .5695 .30074 .56926 .29957 .56924 Mtetra
.895 .941 .834 r
.29957 .56924 .30074 .56926 .30275 .56446 .3014 .56718 Mtetra
0 0 0 r
.3014 .56718 .30275 .56446 .31755 .36301 .30333 .56341 Mtetra
.523 .298 .514 r
.30333 .56341 .31755 .36301 .31951 .35713 .3053 .55914 Mtetra
.528 .302 .515 r
.3053 .55914 .31951 .35713 .32117 .356 .30712 .55702 Mtetra
.53 .304 .516 r
.30712 .55702 .32117 .356 .32279 .35558 .30888 .55598 Mtetra
.531 .304 .516 r
.30888 .55598 .32279 .35558 .3244 .35517 .31061 .55526 Mtetra
.53 .304 .516 r
.31061 .55526 .3244 .35517 .32603 .35456 .31235 .55447 Mtetra
.531 .304 .516 r
.31235 .55447 .32603 .35456 .32765 .354 .31408 .55393 Mtetra
.31408 .55393 .32765 .354 .32928 .35344 .31581 .55339 Mtetra
.31581 .55339 .32928 .35344 .33091 .35286 .31754 .55279 Mtetra
.31754 .55279 .33091 .35286 .33254 .35228 .31927 .5522 Mtetra
.31927 .5522 .33254 .35228 .33417 .35171 .321 .55164 Mtetra
.321 .55164 .33417 .35171 .3358 .35115 .32274 .55109 Mtetra
.32274 .55109 .3358 .35115 .33744 .35058 .32447 .55055 Mtetra
.32447 .55055 .33744 .35058 .33907 .35001 .3262 .55001 Mtetra
.3262 .55001 .33907 .35001 .3407 .34944 .32794 .54946 Mtetra
.32794 .54946 .3407 .34944 .34234 .34887 .32967 .54893 Mtetra
.529 .303 .516 r
.32967 .54893 .34234 .34887 .34399 .348 .33146 .54758 Mtetra
.528 .302 .515 r
.33146 .54758 .34399 .348 .34565 .34701 .33328 .54549 Mtetra
.533 .306 .516 r
.33328 .54549 .34565 .34701 .34728 .34669 .33497 .54583 Mtetra
.54 .312 .518 r
.33497 .54583 .34728 .34669 .34875 .34911 .33644 .55008 Mtetra
.539 .311 .517 r
.33644 .55008 .34875 .34911 .33934 .54941 .33795 .55379 Mtetra
.642 .319 .41 r
.33795 .55379 .33934 .54941 .34071 .55579 .33956 .55575 Mtetra
.449 0 0 r
.33956 .55575 .34071 .55579 .34234 .55741 .34124 .55645 Mtetra
.542 .738 .966 r
.34124 .55645 .34234 .55741 .34407 .55722 .34298 .55622 Mtetra
.631 .76 .94 r
.34298 .55622 .34407 .55722 .34583 .55658 .34473 .55573 Mtetra
.642 .795 .956 r
.34473 .55573 .34583 .55658 .34759 .55589 .34648 .55518 Mtetra
.616 .82 .979 r
.34648 .55518 .34759 .55589 .34934 .55536 .34823 .55467 Mtetra
.633 .831 .976 r
.34823 .55467 .34934 .55536 .3511 .55479 .34999 .55412 Mtetra
.617 .829 .982 r
.34999 .55412 .3511 .55479 .35285 .55422 .35175 .5536 Mtetra
.597 .835 .989 r
.35175 .5536 .35285 .55422 .35461 .55366 .3535 .55312 Mtetra
.69 .877 .968 r
.3535 .55312 .35461 .55366 .35638 .55295 .35527 .55234 Mtetra
.833 .863 .867 r
.35527 .55234 .35638 .55295 .35816 .55203 .35708 .55075 Mtetra
.877 .749 .718 r
.35708 .55075 .35816 .55203 .35995 .55076 .35898 .54743 Mtetra
.861 .651 .616 r
.35898 .54743 .35995 .55076 .36178 .54881 .36107 .54011 Mtetra
.947 .68 .497 r
.36107 .54011 .36178 .54881 .36373 .54442 .37242 .34061 Mtetra
.543 .319 .525 r
.37242 .34061 .36373 .54442 .37503 .34237 .37428 .33574 Mtetra
.667 .476 .618 r
.37428 .33574 .37503 .34237 .37699 .33534 .37603 .33319 Mtetra
.734 .633 .746 r
.37603 .33319 .37699 .33534 .37874 .33277 .37773 .3317 Mtetra
.694 .753 .897 r
.37773 .3317 .37874 .33277 .38041 .33194 .3794 .33098 Mtetra
.623 .755 .941 r
.3794 .33098 .38041 .33194 .38206 .33156 .38105 .33054 Mtetra
.595 .731 .939 r
.38105 .33054 .38206 .33156 .3837 .33132 .3827 .33021 Mtetra
.618 .72 .919 r
.3827 .33021 .3837 .33132 .38536 .33089 .38435 .3298 Mtetra
.623 .727 .922 r
.38435 .3298 .38536 .33089 .38701 .33045 .38601 .32938 Mtetra
.654 .741 .913 r
.38601 .32938 .38701 .33045 .38867 .32993 .38767 .32883 Mtetra
.699 .749 .89 r
.38767 .32883 .38867 .32993 .39034 .32925 .38934 .32807 Mtetra
.702 .734 .876 r
.38934 .32807 .39034 .32925 .39201 .32855 .39102 .32728 Mtetra
.704 .721 .862 r
.39102 .32728 .39201 .32855 .39368 .32783 .39269 .32646 Mtetra
.704 .704 .848 r
.39269 .32646 .39368 .32783 .39535 .32711 .39437 .32561 Mtetra
.65 .665 .852 r
.39437 .32561 .39535 .32711 .39702 .32653 .39604 .32506 Mtetra
.453 .578 .89 r
.39604 .32506 .39702 .32653 .39868 .32627 .39768 .32525 Mtetra
.69 .2 0 r
.39768 .32525 .39868 .32627 .40031 .32664 .39924 .3274 Mtetra
.894 .543 .372 r
.39924 .3274 .40031 .32664 .40193 .3273 .40063 .33385 Mtetra
.95 .674 .479 r
.40063 .33385 .40193 .3273 .40357 .32766 .39469 .52957 Mtetra
.532 .305 .516 r
.39469 .52957 .40357 .32766 .40526 .32665 .39646 .52935 Mtetra
.53 .303 .516 r
.39646 .52935 .40526 .32665 .40694 .32599 .39827 .52806 Mtetra
.534 .307 .517 r
.39827 .52806 .40694 .32599 .40855 .32711 .39998 .52924 Mtetra
.54 .311 .517 r
.39998 .52924 .40855 .32711 .40296 .52623 .4016 .5333 Mtetra
.615 .319 .445 r
.4016 .5333 .40296 .52623 .40441 .53505 .40329 .53542 Mtetra
.572 .029 0 r
.40329 .53542 .40441 .53505 .4061 .53726 .40503 .53631 Mtetra
.576 .758 .964 r
.40503 .53631 .4061 .53726 .40788 .53705 .40682 .53597 Mtetra
.668 .761 .92 r
.40682 .53597 .40788 .53705 .40968 .5363 .40861 .53532 Mtetra
.676 .783 .93 r
.40861 .53532 .40968 .5363 .41149 .53542 .41041 .53464 Mtetra
.544 .784 .987 r
.41041 .53464 .41149 .53542 .41328 .53495 .4122 .53433 Mtetra
.628 .849 .984 r
.4122 .53433 .41328 .53495 .41508 .53437 .414 .53375 Mtetra
.796 .874 .905 r
.414 .53375 .41508 .53437 .41689 .53348 .41583 .53245 Mtetra
.902 .78 .717 r
.41583 .53245 .41689 .53348 .41872 .53184 .41772 .52896 Mtetra
.881 .67 .613 r
.41772 .52896 .41872 .53184 .42056 .52987 .41974 .52153 Mtetra
.953 .681 .482 r
.41974 .52153 .42056 .52987 .4224 .52804 .42765 .32317 Mtetra
.535 .313 .523 r
.42765 .32317 .4224 .52804 .42419 .52791 .42936 .32204 Mtetra
.533 .311 .523 r
.42936 .32204 .42419 .52791 .42599 .52745 .43103 .32207 Mtetra
.536 .313 .524 r
.43103 .32207 .42599 .52745 .42784 .52536 .43276 .32039 Mtetra
.543 .319 .525 r
.43276 .32039 .42784 .52536 .43533 .32509 .43459 .3154 Mtetra
.647 .442 .592 r
.43459 .3154 .43533 .32509 .4373 .31474 .43635 .31232 Mtetra
.758 .629 .717 r
.43635 .31232 .4373 .31474 .43907 .31144 .43809 .31031 Mtetra
.713 .752 .882 r
.43809 .31031 .43907 .31144 .44077 .31043 .43979 .30946 Mtetra
.657 .768 .931 r
.43979 .30946 .44077 .31043 .44247 .3099 .44148 .30889 Mtetra
.635 .752 .933 r
.44148 .30889 .44247 .3099 .44416 .30952 .44318 .30841 Mtetra
.706 .753 .888 r
.44318 .30841 .44416 .30952 .44587 .3086 .44488 .3076 Mtetra
.679 .767 .918 r
.44488 .3076 .44587 .3086 .44757 .30795 .44659 .30694 Mtetra
.599 .739 .942 r
.44659 .30694 .44757 .30795 .44925 .30788 .44828 .30657 Mtetra
.364 .565 .914 r
.44828 .30657 .44925 .30788 .45089 .30991 .44996 .30693 Mtetra
.352 .359 .727 r
.44996 .30693 .45089 .30991 .45243 .31676 .45162 .30801 Mtetra
.385 .255 .578 r
.45162 .30801 .45243 .31676 .4496 .5172 .45325 .31074 Mtetra
0 0 .314 r
.45325 .31074 .4496 .5172 .45135 .51966 .45054 .50836 Mtetra
.028 0 .464 r
.45054 .50836 .45135 .51966 .45315 .52048 .45215 .51711 Mtetra
.109 .186 .664 r
.45215 .51711 .45315 .52048 .45495 .52058 .45391 .51941 Mtetra
.5 .681 .947 r
.45391 .51941 .45495 .52058 .45677 .52022 .45573 .51935 Mtetra
.646 .801 .957 r
.45573 .51935 .45677 .52022 .4586 .51965 .45755 .51876 Mtetra
.702 .811 .933 r
.45755 .51876 .4586 .51965 .46043 .519 .45939 .51794 Mtetra
.612 .749 .943 r
.45939 .51794 .46043 .519 .46225 .51857 .46121 .5175 Mtetra
.596 .742 .946 r
.46121 .5175 .46225 .51857 .46408 .51819 .46304 .51712 Mtetra
.566 .73 .952 r
.46304 .51712 .46408 .51819 .46591 .51788 .46487 .51683 Mtetra
.233 .565 .937 r
.46487 .51683 .46591 .51788 .46772 .51823 .46668 .51729 Mtetra
.451 .709 .978 r
.46668 .51729 .46772 .51823 .46955 .51811 .46851 .51726 Mtetra
.708 .823 .936 r
.46851 .51726 .46955 .51811 .47139 .51718 .47035 .51641 Mtetra
.946 .79 .657 r
.47035 .51641 .47139 .51718 .4733 .51197 .47226 .51137 Mtetra
.967 .691 .457 r
.47226 .51137 .4733 .51197 .47821 .30566 .47723 .30505 Mtetra
.964 .762 .582 r
.47723 .30505 .47821 .30566 .48003 .2982 .47906 .29708 Mtetra
.782 .772 .844 r
.47906 .29708 .48003 .2982 .48176 .29689 .48079 .29575 Mtetra
.638 .728 .914 r
.48079 .29575 .48176 .29689 .48348 .2964 .48251 .29525 Mtetra
.515 .678 .939 r
.48251 .29525 .48348 .2964 .4852 .2963 .48423 .29517 Mtetra
.67 .742 .904 r
.48423 .29517 .4852 .2963 .48692 .29566 .48596 .29453 Mtetra
.681 .746 .9 r
.48596 .29453 .48692 .29566 .48865 .29497 .48769 .29384 Mtetra
.691 .749 .896 r
.48769 .29384 .48865 .29497 .49038 .29424 .48941 .2931 Mtetra
.783 .769 .84 r
.48941 .2931 .49038 .29424 .49211 .29295 .49115 .29175 Mtetra
.732 .748 .865 r
.49115 .29175 .49211 .29295 .49384 .29201 .49288 .29076 Mtetra
.589 .688 .91 r
.49288 .29076 .49384 .29201 .49557 .29176 .49461 .29045 Mtetra
.789 .354 0 r
.49461 .29045 .49557 .29176 .49726 .2953 .49631 .29387 Mtetra
.968 .684 .437 r
.49631 .29387 .49726 .2953 .49729 .50049 .49627 .49908 Mtetra
.931 .555 .171 r
.49627 .49908 .49729 .50049 .49908 .50712 .49806 .50604 Mtetra
.115 .483 .899 r
.49806 .50604 .49908 .50712 .50093 .50766 .4999 .50674 Mtetra
.627 .789 .96 r
.4999 .50674 .50093 .50766 .50278 .50709 .50176 .50621 Mtetra
.799 .834 .879 r
.50176 .50621 .50278 .50709 .50465 .5059 .50362 .50481 Mtetra
.878 .793 .762 r
.50362 .50481 .50465 .5059 .50651 .50491 .50549 .50216 Mtetra
.855 .666 .646 r
.50549 .50216 .50651 .50491 .50837 .50347 .50738 .49717 Mtetra
.963 .683 .454 r
.50738 .49717 .50837 .50347 .51024 .50106 .51018 .29709 Mtetra
.549 .323 .525 r
.51018 .29709 .51024 .50106 .51213 .49138 .51195 .2891 Mtetra
.539 .316 .524 r
.51195 .2891 .51213 .49138 .51465 .28974 .51371 .28597 Mtetra
.701 .545 .673 r
.51371 .28597 .51465 .28974 .51641 .28539 .51546 .28402 Mtetra
.72 .718 .847 r
.51546 .28402 .51641 .28539 .51815 .28404 .5172 .28304 Mtetra
.662 .77 .93 r
.5172 .28304 .51815 .28404 .5199 .28342 .51895 .28243 Mtetra
.626 .758 .942 r
.51895 .28243 .5199 .28342 .52165 .2831 .5207 .28196 Mtetra
.765 .769 .855 r
.5207 .28196 .52165 .2831 .52339 .28198 .52245 .28075 Mtetra
.731 .746 .864 r
.52245 .28075 .52339 .28198 .52514 .28104 .52419 .27975 Mtetra
.601 .689 .904 r
.52419 .27975 .52514 .28104 .52689 .28075 .52594 .2794 Mtetra
.689 .25 0 r
.52594 .2794 .52689 .28075 .52865 .28387 .5277 .28237 Mtetra
.971 .683 .425 r
.5277 .28237 .52865 .28387 .53077 .48913 .52976 .48738 Mtetra
.931 .566 .155 r
.52976 .48738 .53077 .48913 .53266 .49649 .53165 .49534 Mtetra
0 .309 .791 r
.53165 .49534 .53266 .49649 .53454 .49763 .53353 .49652 Mtetra
.588 .736 .946 r
.53353 .49652 .53454 .49763 .53642 .49725 .53541 .49615 Mtetra
.796 .797 .853 r
.53541 .49615 .53642 .49725 .5383 .49577 .53729 .49467 Mtetra
.934 .776 .662 r
.53729 .49467 .5383 .49577 .54016 .49097 .53915 .48987 Mtetra
.971 .689 .436 r
.53915 .48987 .54016 .49097 .54097 .28444 .54003 .28327 Mtetra
.954 .743 .58 r
.54003 .28327 .54097 .28444 .54269 .27643 .54175 .27528 Mtetra
.831 .78 .804 r
.54175 .27528 .54269 .27643 .54445 .27458 .54351 .27343 Mtetra
.665 .742 .907 r
.54351 .27343 .54445 .27458 .54621 .27395 .54527 .2728 Mtetra
.55 .696 .936 r
.54527 .2728 .54621 .27395 .54798 .27375 .54704 .2726 Mtetra
.719 .759 .884 r
.54704 .2726 .54798 .27375 .54974 .27285 .5488 .2717 Mtetra
.712 .757 .888 r
.5488 .2717 .54974 .27285 .5515 .27198 .55056 .27083 Mtetra
.568 .703 .933 r
.55056 .27083 .5515 .27198 .55327 .27173 .55234 .27058 Mtetra
.695 .234 0 r
.55234 .27058 .55327 .27173 .55507 .27454 .55414 .27339 Mtetra
.972 .681 .415 r
.55414 .27339 .55507 .27454 .55896 .47923 .55797 .47815 Mtetra
.936 .562 .201 r
.55797 .47815 .55896 .47923 .56095 .48724 .55995 .48615 Mtetra
0 .401 .85 r
.55995 .48615 .56095 .48724 .56286 .48819 .56186 .4871 Mtetra
.634 .758 .938 r
.56186 .4871 .56286 .48819 .56476 .48765 .56376 .48656 Mtetra
.729 .788 .9 r
.56376 .48656 .56476 .48765 .56665 .48663 .56566 .48555 Mtetra
.515 .712 .961 r
.56566 .48555 .56665 .48663 .56856 .48643 .56757 .4854 Mtetra
.486 .712 .97 r
.56757 .4854 .56856 .48643 .57047 .48627 .56948 .48531 Mtetra
.682 .804 .94 r
.56948 .48531 .57047 .48627 .57237 .48545 .57138 .48455 Mtetra
.932 .813 .706 r
.57138 .48455 .57237 .48545 .57423 .48161 .57324 .48082 Mtetra
.974 .688 .423 r
.57324 .48082 .57423 .48161 .57298 .27813 .57208 .27904 Mtetra
.996 .767 .467 r
.57208 .27904 .57298 .27813 .57458 .26579 .57366 .2647 Mtetra
.871 .794 .772 r
.57366 .2647 .57458 .26579 .57634 .26351 .57541 .26236 Mtetra
.682 .751 .903 r
.57541 .26236 .57634 .26351 .57812 .2628 .57719 .26165 Mtetra
.555 .699 .936 r
.57719 .26165 .57812 .2628 .57991 .26258 .57898 .26143 Mtetra
.701 .756 .895 r
.57898 .26143 .57991 .26258 .58169 .26177 .58077 .26062 Mtetra
.72 .762 .885 r
.58077 .26062 .58169 .26177 .58347 .26085 .58255 .2597 Mtetra
.587 .712 .93 r
.58255 .2597 .58347 .26085 .58526 .26053 .58434 .25937 Mtetra
.585 .124 0 r
.58434 .25937 .58526 .26053 .58711 .26297 .58619 .26181 Mtetra
.973 .68 .402 r
.58619 .26181 .58711 .26297 .59316 .46742 .59218 .46633 Mtetra
.939 .569 .204 r
.59218 .46633 .59316 .46742 .59528 .47639 .5943 .47528 Mtetra
0 .157 .667 r
.5943 .47528 .59528 .47639 .59725 .478 .59626 .47689 Mtetra
.538 .718 .956 r
.59626 .47689 .59725 .478 .59918 .47779 .5982 .47668 Mtetra
.768 .798 .877 r
.5982 .47668 .59918 .47779 .60109 .47652 .60011 .47541 Mtetra
.923 .794 .7 r
.60011 .47541 .60109 .47652 .60294 .47273 .60196 .47162 Mtetra
.975 .687 .413 r
.60196 .47162 .60294 .47273 .6 .27192 .59908 .27078 Mtetra
.973 .724 .499 r
.59908 .27078 .6 .27192 .60144 .25668 .60053 .25552 Mtetra
.877 .787 .757 r
.60053 .25552 .60144 .25668 .6032 .25416 .60228 .25299 Mtetra
.68 .748 .902 r
.60228 .25299 .6032 .25416 .60499 .25345 .60408 .25228 Mtetra
.55 .694 .935 r
.60408 .25228 .60499 .25345 .60681 .25325 .60589 .25208 Mtetra
.602 .717 .926 r
.60589 .25208 .60681 .25325 .60861 .25287 .6077 .2517 Mtetra
.668 .744 .907 r
.6077 .2517 .60861 .25287 .61042 .25221 .60951 .25104 Mtetra
.673 .746 .905 r
.60951 .25104 .61042 .25221 .61222 .25153 .61131 .25036 Mtetra
.738 .767 .876 r
.61131 .25036 .61222 .25153 .61402 .2505 .61311 .24933 Mtetra
.74 .767 .875 r
.61311 .24933 .61402 .2505 .61581 .24945 .6149 .24828 Mtetra
.628 .728 .919 r
.6149 .24828 .61581 .24945 .61762 .24897 .61671 .24779 Mtetra
0 .09 .623 r
.61671 .24779 .61762 .24897 .61951 .25079 .6186 .24961 Mtetra
.975 .677 .387 r
.6186 .24961 .61951 .25079 .62761 .4506 .62665 .44947 Mtetra
.956 .612 .265 r
.62665 .44947 .62761 .4506 .63002 .46485 .62905 .46373 Mtetra
0 .03 .553 r
.62905 .46373 .63002 .46485 .63205 .4669 .63108 .46578 Mtetra
.5 .7 .959 r
.63108 .46578 .63205 .4669 .63401 .4668 .63305 .46568 Mtetra
.754 .797 .887 r
.63305 .46568 .63401 .4668 .63594 .46562 .63498 .4645 Mtetra
.918 .801 .715 r
.63498 .4645 .63594 .46562 .63779 .46213 .63683 .461 Mtetra
.978 .712 .455 r
.63683 .461 .63779 .46213 .63887 .43664 .63792 .43567 Mtetra
.976 .685 .399 r
.63792 .43567 .63887 .43664 .63402 .24538 .63312 .2442 Mtetra
.896 .788 .734 r
.63312 .2442 .63402 .24538 .63576 .24248 .63486 .2413 Mtetra
.704 .756 .892 r
.63486 .2413 .63576 .24248 .63757 .24164 .63667 .24045 Mtetra
.587 .71 .928 r
.63667 .24045 .63757 .24164 .63941 .2413 .63851 .24012 Mtetra
.666 .743 .907 r
.63851 .24012 .63941 .2413 .64123 .24065 .64033 .23946 Mtetra
.733 .765 .879 r
.64033 .23946 .64123 .24065 .64304 .23964 .64214 .23845 Mtetra
.636 .731 .917 r
.64214 .23845 .64304 .23964 .64487 .23912 .64397 .23793 Mtetra
0 .282 .78 r
.64397 .23793 .64487 .23912 .64678 .24044 .64588 .23925 Mtetra
.938 .574 .185 r
.64588 .23925 .64678 .24044 .64903 .2503 .64813 .24912 Mtetra
.975 .675 .374 r
.64813 .24912 .64903 .2503 .65926 .45436 .65831 .45322 Mtetra
0 0 .513 r
.65831 .45322 .65926 .45436 .66134 .45663 .66039 .4555 Mtetra
.629 .756 .938 r
.66039 .4555 .66134 .45663 .66331 .45609 .66236 .45495 Mtetra
.769 .8 .878 r
.66236 .45495 .66331 .45609 .66525 .4548 .6643 .45366 Mtetra
.782 .803 .87 r
.6643 .45366 .66525 .4548 .66718 .45341 .66624 .45227 Mtetra
.73 .79 .9 r
.66624 .45227 .66718 .45341 .66914 .45237 .66819 .45123 Mtetra
.716 .786 .907 r
.66819 .45123 .66914 .45237 .67109 .45141 .67014 .45027 Mtetra
.656 .765 .93 r
.67014 .45027 .67109 .45141 .67306 .45075 .67212 .44961 Mtetra
.563 .727 .951 r
.67212 .44961 .67306 .45075 .67505 .45046 .6741 .44931 Mtetra
.534 .713 .955 r
.6741 .44931 .67505 .45046 .67704 .45025 .6761 .44911 Mtetra
.442 .667 .958 r
.6761 .44911 .67704 .45025 .67905 .45032 .67811 .44918 Mtetra
.414 .652 .957 r
.67811 .44918 .67905 .45032 .68107 .45047 .68012 .44932 Mtetra
.629 .755 .938 r
.68012 .44932 .68107 .45047 .68305 .44992 .68211 .44878 Mtetra
.89 .812 .765 r
.68211 .44878 .68305 .44992 .68493 .44722 .68399 .44607 Mtetra
.981 .722 .465 r
.68399 .44607 .68493 .44722 .68604 .42911 .68511 .42793 Mtetra
.977 .682 .379 r
.68511 .42793 .68604 .42911 .67806 .23016 .67718 .22896 Mtetra
.912 .79 .713 r
.67718 .22896 .67806 .23016 .67978 .22691 .6789 .2257 Mtetra
.709 .758 .89 r
.6789 .2257 .67978 .22691 .68162 .22602 .68074 .22482 Mtetra
.59 .71 .927 r
.68074 .22482 .68162 .22602 .68349 .22568 .68261 .22447 Mtetra
.626 .726 .919 r
.68261 .22447 .68349 .22568 .68535 .22519 .68447 .22398 Mtetra
.733 .766 .879 r
.68447 .22398 .68535 .22519 .68718 .22417 .6863 .22296 Mtetra
.645 .733 .913 r
.6863 .22296 .68718 .22417 .68904 .2236 .68816 .22239 Mtetra
.099 .422 .868 r
.68816 .22239 .68904 .2236 .69098 .22456 .6901 .22334 Mtetra
.91 .529 .1 r
.6901 .22334 .69098 .22456 .69333 .2328 .69245 .2315 Mtetra
.975 .671 .352 r
.69245 .2315 .69333 .2328 .70675 .43934 .70581 .43815 Mtetra
.582 .125 0 r
.70581 .43815 .70675 .43934 .70894 .44226 .70801 .44107 Mtetra
.552 .715 .948 r
.70801 .44107 .70894 .44226 .71096 .44201 .71003 .44082 Mtetra
.703 .775 .908 r
.71003 .44082 .71096 .44201 .71295 .44112 .71202 .43992 Mtetra
.67 .762 .919 r
.71202 .43992 .71295 .44112 .71494 .44037 .71402 .43918 Mtetra
.454 .664 .952 r
.71402 .43918 .71494 .44037 .71699 .44038 .71606 .43924 Mtetra
.61 .749 .944 r
.71606 .43924 .71699 .44038 .719 .43987 .71808 .43876 Mtetra
.852 .825 .82 r
.71808 .43876 .719 .43987 .72092 .4378 .72 .43672 Mtetra
.978 .767 .55 r
.72 .43672 .72092 .4378 .72246 .42955 .72155 .42849 Mtetra
.977 .678 .362 r
.72155 .42849 .72246 .42955 .71164 .21993 .71077 .21867 Mtetra
.94 .781 .656 r
.71077 .21867 .71164 .21993 .71328 .21556 .71241 .21429 Mtetra
.733 .757 .872 r
.71241 .21429 .71328 .21556 .71513 .21451 .71426 .21325 Mtetra
.605 .707 .916 r
.71426 .21325 .71513 .21451 .71702 .2141 .71615 .21284 Mtetra
.602 .707 .918 r
.71615 .21284 .71702 .2141 .71891 .2137 .71804 .21245 Mtetra
.742 .765 .872 r
.71804 .21245 .71891 .2137 .72076 .21259 .71989 .21135 Mtetra
.659 .736 .906 r
.71989 .21135 .72076 .21259 .72263 .21195 .72177 .21071 Mtetra
.235 .507 .906 r
.72177 .21071 .72263 .21195 .7246 .21263 .72374 .21139 Mtetra
.887 .498 .045 r
.72374 .21139 .7246 .21263 .72703 .22022 .72616 .21895 Mtetra
.975 .667 .334 r
.72616 .21895 .72703 .22022 .74288 .42787 .74197 .42669 Mtetra
.644 .191 0 r
.74197 .42669 .74288 .42787 .74518 .43129 .74427 .43011 Mtetra
.386 .632 .952 r
.74427 .43011 .74518 .43129 .74726 .43152 .74635 .43035 Mtetra
.692 .779 .918 r
.74635 .43035 .74726 .43152 .74928 .43067 .74837 .4295 Mtetra
.872 .819 .794 r
.74837 .4295 .74928 .43067 .75119 .42832 .75028 .42715 Mtetra
.977 .768 .555 r
.75028 .42715 .75119 .42832 .75271 .42048 .7518 .41932 Mtetra
.977 .675 .347 r
.7518 .41932 .75271 .42048 .73989 .2104 .73903 .20919 Mtetra
.952 .785 .639 r
.73903 .20919 .73989 .2104 .74149 .20569 .74064 .20448 Mtetra
.743 .773 .878 r
.74064 .20448 .74149 .20569 .74335 .20459 .7425 .20338 Mtetra
.609 .722 .925 r
.7425 .20338 .74335 .20459 .74526 .20415 .74441 .20295 Mtetra
.561 .701 .935 r
.74441 .20295 .74526 .20415 .74718 .20386 .74633 .2027 Mtetra
.708 .772 .902 r
.74633 .2027 .74718 .20386 .74904 .20284 .74821 .20181 Mtetra
.672 .787 .936 r
.74821 .20181 .74904 .20284 .75094 .20214 .7501 .2011 Mtetra
.562 .738 .958 r
.7501 .2011 .75094 .20214 .75289 .20226 .75203 .2008 Mtetra
.294 .5 .887 r
.75203 .2008 .75289 .20226 .75508 .20543 .75403 .20149 Mtetra
.321 .302 .682 r
.75403 .20149 .75508 .20543 .7727 .40974 .75613 .20341 Mtetra
.519 .301 .522 r
.75613 .20341 .7727 .40974 .77543 .41805 .75864 .21068 Mtetra
.028 0 .425 r
.75864 .21068 .77543 .41805 .77762 .41928 .77633 .41297 Mtetra
.259 .212 .613 r
.77633 .41297 .77762 .41928 .77974 .41953 .77872 .41675 Mtetra
.297 .361 .76 r
.77872 .41675 .77974 .41953 .78182 .41936 .78093 .4182 Mtetra
.402 .646 .956 r
.78093 .4182 .78182 .41936 .78393 .41935 .78305 .41838 Mtetra
.647 .81 .961 r
.78305 .41838 .78393 .41935 .78598 .41871 .7851 .41771 Mtetra
.849 .852 .845 r
.7851 .41771 .78598 .41871 .78794 .41695 .78706 .4158 Mtetra
.98 .777 .561 r
.78706 .4158 .78794 .41695 .78945 .40964 .78857 .40855 Mtetra
.976 .671 .328 r
.78857 .40855 .78945 .40964 .77416 .19879 .77333 .1976 Mtetra
.964 .787 .614 r
.77333 .1976 .77416 .19879 .7757 .1936 .77487 .19237 Mtetra
.756 .779 .872 r
.77487 .19237 .7757 .1936 .77757 .19242 .77674 .19118 Mtetra
.624 .727 .92 r
.77674 .19118 .77757 .19242 .7795 .19192 .77867 .19068 Mtetra
.553 .692 .932 r
.77867 .19068 .7795 .19192 .78145 .1917 .78062 .19046 Mtetra
.748 .776 .875 r
.78062 .19046 .78145 .1917 .78333 .19056 .7825 .18932 Mtetra
.678 .75 .905 r
.7825 .18932 .78333 .19056 .78524 .18981 .78441 .18857 Mtetra
.454 .64 .936 r
.78441 .18857 .78524 .18981 .78723 .18991 .7864 .18868 Mtetra
.775 .36 0 r
.7864 .18868 .78723 .18991 .78967 .19516 .78884 .19396 Mtetra
.971 .657 .298 r
.78884 .19396 .78967 .19516 .81023 .40524 .80935 .40408 Mtetra
.728 .29 0 r
.80935 .40408 .81023 .40524 .81276 .40986 .81189 .40867 Mtetra
.308 .583 .939 r
.81189 .40867 .81276 .40986 .81494 .41032 .81406 .40913 Mtetra
.656 .768 .932 r
.81406 .40913 .81494 .41032 .81701 .40964 .81613 .40844 Mtetra
.839 .822 .832 r
.81613 .40844 .81701 .40964 .81897 .40774 .8181 .40651 Mtetra
.979 .778 .562 r
.8181 .40651 .81897 .40774 .82049 .401 .81959 .39947 Mtetra
.974 .666 .313 r
.81959 .39947 .82049 .401 .80305 .18907 .80219 .18738 Mtetra
.946 .751 .607 r
.80219 .18738 .80305 .18907 .80452 .18332 .80367 .18184 Mtetra
.776 .833 .896 r
.18326 .3994 .18438 .40002 .18596 .39909 .18486 .39833 Mtetra
.597 .779 .967 r
.18486 .39833 .18596 .39909 .18747 .39888 .18638 .39798 Mtetra
.436 .687 .97 r
.18638 .39798 .18747 .39888 .18893 .39905 .18786 .39801 Mtetra
.648 .729 .908 r
.18786 .39801 .18893 .39905 .19047 .3986 .1894 .39753 Mtetra
.655 .725 .9 r
.1894 .39753 .19047 .3986 .19201 .39808 .19094 .39701 Mtetra
.662 .728 .899 r
.19094 .39701 .19201 .39808 .19356 .39751 .19249 .39647 Mtetra
.755 .751 .849 r
.19249 .39647 .19356 .39751 .19516 .39643 .19409 .3954 Mtetra
.704 .745 .883 r
.19409 .3954 .19516 .39643 .19673 .39569 .19566 .39466 Mtetra
.503 .682 .947 r
.19566 .39466 .19673 .39569 .19823 .39563 .19716 .3946 Mtetra
.929 .55 .253 r
.19716 .3946 .19823 .39563 .1993 .3998 .19823 .39872 Mtetra
.939 .683 .523 r
.19823 .39872 .1993 .3998 .18067 .59994 .17953 .59889 Mtetra
.937 .582 .316 r
.17953 .59889 .18067 .59994 .18173 .60526 .18058 .60427 Mtetra
.227 .572 .941 r
.18058 .60427 .18173 .60526 .18327 .60577 .18214 .60465 Mtetra
.66 .733 .903 r
.18214 .60465 .18327 .60577 .18492 .60523 .18379 .60407 Mtetra
.742 .743 .853 r
.18379 .60407 .18492 .60523 .18664 .60399 .18549 .60302 Mtetra
.621 .752 .94 r
.18549 .60302 .18664 .60399 .18842 .60219 .18714 .60259 Mtetra
.378 .836 .759 r
.18714 .60259 .18842 .60219 .1903 .59935 .18881 .60187 Mtetra
.093 0 .034 r
.18881 .60187 .1903 .59935 .19245 .59365 .19055 .60041 Mtetra
0 0 .064 r
.19055 .60041 .19245 .59365 .21303 .39767 .19274 .59442 Mtetra
0 0 .111 r
.19274 .59442 .21303 .39767 .21509 .39201 .21373 .39398 Mtetra
.983 .902 .585 r
.21373 .39398 .21509 .39201 .21685 .38931 .21577 .38847 Mtetra
.804 .792 .841 r
.21577 .38847 .21685 .38931 .21846 .38827 .21741 .38708 Mtetra
.655 .707 .886 r
.21741 .38708 .21846 .38827 .22002 .38774 .21897 .38656 Mtetra
.556 .673 .916 r
.21897 .38656 .22002 .38774 .22156 .38745 .2205 .3864 Mtetra
.738 .751 .863 r
.2205 .3864 .22156 .38745 .22316 .38647 .2221 .38545 Mtetra
.709 .752 .885 r
.2221 .38545 .22316 .38647 .22475 .38569 .22368 .38468 Mtetra
.532 .701 .947 r
.22368 .38468 .22475 .38569 .22628 .38554 .22521 .38454 Mtetra
.904 .492 .157 r
.22521 .38454 .22628 .38554 .22749 .38883 .22642 .38787 Mtetra
.942 .683 .517 r
.22642 .38787 .22749 .38883 .21059 .58872 .20943 .58791 Mtetra
.936 .596 .36 r
.20943 .58791 .21059 .58872 .21159 .59536 .21044 .59445 Mtetra
.012 .455 .869 r
.21044 .59445 .21159 .59536 .21315 .59598 .21201 .59506 Mtetra
.667 .776 .931 r
.21201 .59506 .21315 .59598 .21483 .59537 .21368 .59445 Mtetra
.758 .79 .879 r
.21368 .59445 .21483 .59537 .21655 .59428 .2154 .59337 Mtetra
.546 .743 .968 r
.2154 .59337 .21655 .59428 .21819 .59405 .21705 .59314 Mtetra
.585 .756 .959 r
.21705 .59314 .21819 .59405 .21985 .59372 .2187 .59281 Mtetra
.753 .79 .884 r
.2187 .59281 .21985 .59372 .22156 .59267 .22042 .59176 Mtetra
.911 .75 .67 r
.22042 .59176 .22156 .59267 .22364 .58762 .22249 .58674 Mtetra
.943 .688 .522 r
.22249 .58674 .22364 .58762 .24301 .38565 .24194 .38473 Mtetra
.92 .734 .635 r
.24194 .38473 .24301 .38565 .2451 .37924 .24404 .37827 Mtetra
.82 .771 .806 r
.24404 .37827 .2451 .37924 .24678 .37749 .24571 .37659 Mtetra
.668 .77 .926 r
.24571 .37659 .24678 .37749 .24837 .37681 .24729 .37602 Mtetra
.517 .749 .98 r
.24729 .37602 .24837 .37681 .24992 .37651 .24884 .37584 Mtetra
.626 .814 .973 r
.24884 .37584 .24992 .37651 .25151 .37588 .25041 .37537 Mtetra
.644 .857 .981 r
.25041 .37537 .25151 .37588 .2531 .37526 .25199 .37481 Mtetra
.603 .862 .992 r
.25199 .37481 .2531 .37526 .25466 .37492 .25357 .37433 Mtetra
.657 .841 .971 r
.25357 .37433 .25466 .37492 .25616 .37535 .25516 .37375 Mtetra
.611 .628 .844 r
.25516 .37375 .25616 .37535 .25758 .37679 .25672 .3734 Mtetra
.508 .432 .705 r
.25672 .3734 .25758 .37679 .2588 .38061 .25824 .37367 Mtetra
.189 .12 .543 r
.25824 .37367 .2588 .38061 .24409 .5774 .25948 .3773 Mtetra
0 0 .171 r
.25948 .3773 .24409 .5774 .24525 .58324 .24449 .57777 Mtetra
0 0 .316 r
.24449 .57777 .24525 .58324 .24672 .58532 .24567 .58347 Mtetra
.198 .384 .823 r
.24567 .58347 .24672 .58532 .24833 .58576 .24724 .58439 Mtetra
.619 .68 .886 r
.24724 .58439 .24833 .58576 .25001 .58538 .24892 .58399 Mtetra
.71 .707 .845 r
.24892 .58399 .25001 .58538 .25174 .58443 .25064 .58307 Mtetra
.722 .715 .844 r
.25064 .58307 .25174 .58443 .25354 .58251 .25237 .58209 Mtetra
.753 .9 .943 r
.25237 .58209 .25354 .58251 .25544 .57942 .2541 .58108 Mtetra
.063 0 0 r
.2541 .58108 .25544 .57942 .25748 .57448 .25584 .58004 Mtetra
.445 .149 .368 r
.25584 .58004 .25748 .57448 .25949 .56985 .25755 .57928 Mtetra
.495 .226 .437 r
.25755 .57928 .25949 .56985 .26122 .56889 .25925 .57874 Mtetra
.5 .233 .441 r
.25925 .57874 .26122 .56889 .26279 .5699 .26094 .57829 Mtetra
.492 .219 .427 r
.26094 .57829 .26279 .5699 .26443 .57002 .26264 .5778 Mtetra
.487 .21 .419 r
.26264 .5778 .26443 .57002 .26612 .5696 .26434 .57729 Mtetra
.486 .208 .417 r
.26434 .57729 .26612 .5696 .26781 .56918 .26604 .57677 Mtetra
.508 .227 .423 r
.26604 .57677 .26781 .56918 .26942 .56982 .26771 .57662 Mtetra
.499 .213 .41 r
.26771 .57662 .26942 .56982 .27106 .5701 .26939 .57639 Mtetra
.444 .158 .382 r
.26939 .57639 .27106 .5701 .27282 .5687 .27112 .57548 Mtetra
.12 0 .259 r
.27112 .57548 .27282 .5687 .28872 .37588 .27309 .57145 Mtetra
0 0 .164 r
.27309 .57145 .28872 .37588 .29101 .36606 .28958 .3703 Mtetra
.893 .838 .375 r
.28958 .3703 .29101 .36606 .29283 .3625 .29174 .36227 Mtetra
.902 .887 .808 r
.29174 .36227 .29283 .3625 .29451 .36096 .29346 .36012 Mtetra
.686 .791 .93 r
.29346 .36012 .29451 .36096 .29612 .36034 .29507 .35946 Mtetra
.543 .74 .967 r
.29507 .35946 .29612 .36034 .29771 .36004 .29666 .35925 Mtetra
.577 .774 .972 r
.29666 .35925 .29771 .36004 .2993 .35973 .29825 .35893 Mtetra
.641 .789 .953 r
.29825 .35893 .2993 .35973 .3009 .35937 .29985 .35843 Mtetra
.644 .76 .933 r
.29985 .35843 .3009 .35937 .3025 .359 .30146 .35794 Mtetra
.714 .751 .881 r
.30146 .35794 .3025 .359 .30412 .35823 .30309 .35712 Mtetra
.715 .743 .874 r
.30309 .35712 .30412 .35823 .30575 .35737 .30472 .35629 Mtetra
.582 .708 .929 r
.30472 .35629 .30575 .35737 .30735 .35708 .30632 .35601 Mtetra
.764 .286 0 r
.30632 .35601 .30735 .35708 .30875 .35962 .30774 .35828 Mtetra
.951 .685 .496 r
.30774 .35828 .30875 .35962 .29672 .56158 .29575 .55846 Mtetra
.957 .64 .229 r
.29575 .55846 .29672 .56158 .29792 .56866 .29685 .56713 Mtetra
0 .23 .749 r
.29685 .56713 .29792 .56866 .29957 .56924 .29845 .56843 Mtetra
.688 .812 .942 r
.29845 .56843 .29957 .56924 .3014 .56718 .30019 .56772 Mtetra
.633 .955 .778 r
.30019 .56772 .3014 .56718 .30333 .56341 .30196 .56639 Mtetra
.28 0 .185 r
.30196 .56639 .30333 .56341 .3053 .55914 .30373 .56526 Mtetra
.463 .172 .386 r
.30373 .56526 .3053 .55914 .30712 .55702 .30546 .56459 Mtetra
.481 .203 .414 r
.30546 .56459 .30712 .55702 .30888 .55598 .30719 .564 Mtetra
.485 .21 .42 r
.30719 .564 .30888 .55598 .31061 .55526 .30893 .56341 Mtetra
.486 .211 .422 r
.30893 .56341 .31061 .55526 .31235 .55447 .31066 .56283 Mtetra
.488 .214 .425 r
.31066 .56283 .31235 .55447 .31408 .55393 .31239 .56225 Mtetra
.488 .214 .424 r
.31239 .56225 .31408 .55393 .31581 .55339 .31413 .56169 Mtetra
.31413 .56169 .31581 .55339 .31754 .55279 .31586 .56112 Mtetra
.489 .215 .425 r
.31586 .56112 .31754 .55279 .31927 .5522 .3176 .56057 Mtetra
.3176 .56057 .31927 .5522 .321 .55164 .31934 .56001 Mtetra
.489 .216 .425 r
.31934 .56001 .321 .55164 .32274 .55109 .32107 .55947 Mtetra
.32107 .55947 .32274 .55109 .32447 .55055 .32281 .55892 Mtetra
.32281 .55892 .32447 .55055 .3262 .55001 .32455 .55837 Mtetra
.32455 .55837 .3262 .55001 .32794 .54946 .32629 .55782 Mtetra
.32629 .55782 .32794 .54946 .32967 .54893 .32803 .55727 Mtetra
.487 .213 .424 r
.32803 .55727 .32967 .54893 .33146 .54758 .32978 .55668 Mtetra
.49 .22 .432 r
.32978 .55668 .33146 .54758 .33328 .54549 .33153 .55607 Mtetra
.5 .236 .446 r
.33153 .55607 .33328 .54549 .33497 .54583 .33327 .55554 Mtetra
.508 .239 .442 r
.33327 .55554 .33497 .54583 .33644 .55008 .335 .55526 Mtetra
.504 .197 .38 r
.335 .55526 .33644 .55008 .33795 .55379 .33672 .55522 Mtetra
.397 0 .056 r
.33672 .55522 .33795 .55379 .33956 .55575 .33844 .55515 Mtetra
.485 .799 .999 r
.33844 .55515 .33956 .55575 .34124 .55645 .34018 .55491 Mtetra
.628 .663 .865 r
.34018 .55491 .34124 .55645 .34298 .55622 .34193 .55444 Mtetra
.636 .635 .832 r
.34193 .55444 .34298 .55622 .34473 .55573 .34368 .55391 Mtetra
.636 .63 .828 r
.34368 .55391 .34473 .55573 .34648 .55518 .34543 .55337 Mtetra
.631 .63 .831 r
.34543 .55337 .34648 .55518 .34823 .55467 .34718 .55287 Mtetra
.634 .631 .83 r
.34718 .55287 .34823 .55467 .34999 .55412 .34894 .55234 Mtetra
.608 .623 .841 r
.34894 .55234 .34999 .55412 .35175 .5536 .35069 .55196 Mtetra
.584 .631 .864 r
.35069 .55196 .35175 .5536 .3535 .55312 .35243 .5517 Mtetra
.677 .701 .865 r
.35243 .5517 .3535 .55312 .35527 .55234 .3542 .55099 Mtetra
.829 .743 .77 r
.3542 .55099 .35527 .55234 .35708 .55075 .35604 .54879 Mtetra
.903 .702 .621 r
.35604 .54879 .35708 .55075 .35898 .54743 .35814 .54155 Mtetra
.951 .684 .495 r
.35814 .54155 .35898 .54743 .36107 .54011 .36984 .33821 Mtetra
.542 .318 .524 r
.36984 .33821 .36107 .54011 .37242 .34061 .37169 .33375 Mtetra
.615 .437 .617 r
.37169 .33375 .37242 .34061 .37428 .33574 .37338 .33239 Mtetra
.627 .511 .702 r
.37338 .33239 .37428 .33574 .37603 .33319 .37505 .33164 Mtetra
.645 .655 .845 r
.37505 .33164 .37603 .33319 .37773 .3317 .3767 .3311 Mtetra
.652 .847 .975 r
.3767 .3311 .37773 .3317 .3794 .33098 .37836 .33051 Mtetra
.603 .865 .992 r
.37836 .33051 .3794 .33098 .38105 .33054 .38002 .32999 Mtetra
.61 .849 .989 r
.38002 .32999 .38105 .33054 .3827 .33021 .38168 .32949 Mtetra
.643 .818 .967 r
.38168 .32949 .3827 .33021 .38435 .3298 .38334 .32895 Mtetra
.655 .788 .946 r
.38334 .32895 .38435 .3298 .38601 .32938 .385 .32839 Mtetra
.666 .761 .921 r
.385 .32839 .38601 .32938 .38767 .32883 .38666 .32779 Mtetra
.679 .755 .908 r
.38666 .32779 .38767 .32883 .38934 .32807 .38833 .32714 Mtetra
.682 .777 .923 r
.38833 .32714 .38934 .32807 .39102 .32728 .39 .32647 Mtetra
.709 .811 .929 r
.39 .32647 .39102 .32728 .39269 .32646 .39168 .3257 Mtetra
.747 .828 .914 r
.39168 .3257 .39269 .32646 .39437 .32561 .39336 .32474 Mtetra
.651 .783 .945 r
.39336 .32474 .39437 .32561 .39604 .32506 .39503 .32419 Mtetra
.018 .456 .872 r
.39503 .32419 .39604 .32506 .39768 .32525 .39665 .32483 Mtetra
.921 .544 .277 r
.39665 .32483 .39768 .32525 .39924 .3274 .39808 .33024 Mtetra
.955 .68 .475 r
.39808 .33024 .39924 .3274 .40063 .33385 .39167 .53323 Mtetra
.539 .311 .517 r
.39167 .53323 .40063 .33385 .39469 .52957 .39328 .53707 Mtetra
.509 .226 .421 r
.39328 .53707 .39469 .52957 .39646 .52935 .39505 .53695 Mtetra
.47 .193 .41 r
.39505 .53695 .39646 .52935 .39827 .52806 .39685 .53614 Mtetra
.472 .198 .417 r
.39685 .53614 .39827 .52806 .39998 .52924 .39865 .53529 Mtetra
.505 .209 .398 r
.39865 .53529 .39998 .52924 .4016 .5333 .40042 .5352 Mtetra
.425 .011 .148 r
.40042 .5352 .4016 .5333 .40329 .53542 .4022 .5351 Mtetra
.374 .805 .966 r
.4022 .5351 .40329 .53542 .40503 .53631 .40398 .53486 Mtetra
.638 .684 .877 r
.40398 .53486 .40503 .53631 .40682 .53597 .40577 .53433 Mtetra
.65 .662 .848 r
.40577 .53433 .40682 .53597 .40861 .53532 .40757 .53372 Mtetra
.638 .662 .858 r
.40757 .53372 .40861 .53532 .41041 .53464 .40936 .53319 Mtetra
.554 .651 .899 r
.40936 .53319 .41041 .53464 .4122 .53433 .41115 .53303 Mtetra
.651 .714 .894 r
.41115 .53303 .4122 .53433 .414 .53375 .41295 .53245 Mtetra
.801 .753 .809 r
.41295 .53245 .414 .53375 .41583 .53245 .41478 .53074 Mtetra
.912 .718 .628 r
.41478 .53074 .41583 .53245 .41772 .52896 .41678 .52424 Mtetra
.958 .686 .478 r
.41678 .52424 .41772 .52896 .41974 .52153 .42506 .3195 Mtetra
.544 .319 .524 r
.42506 .3195 .41974 .52153 .42765 .32317 .4269 .31431 Mtetra
.586 .401 .597 r
.4269 .31431 .42765 .32317 .42936 .32204 .4286 .31326 Mtetra
.56 .382 .597 r
.4286 .31326 .42936 .32204 .43103 .32207 .43029 .31285 Mtetra
.553 .374 .593 r
.43029 .31285 .43103 .32207 .43276 .32039 .43197 .31258 Mtetra
.591 .411 .607 r
.43197 .31258 .43276 .32039 .43459 .3154 .43368 .31156 Mtetra
.638 .503 .681 r
.43368 .31156 .43459 .3154 .43635 .31232 .43539 .31054 Mtetra
.695 .651 .803 r
.43539 .31054 .43635 .31232 .43809 .31031 .43709 .30962 Mtetra
.677 .837 .96 r
.43709 .30962 .43809 .31031 .43979 .30946 .43879 .30895 Mtetra
.641 .87 .984 r
.43879 .30895 .43979 .30946 .44148 .30889 .44049 .30833 Mtetra
.644 .861 .982 r
.44049 .30833 .44148 .30889 .44318 .30841 .44219 .30773 Mtetra
.687 .843 .958 r
.44219 .30773 .44318 .30841 .44488 .3076 .44389 .30701 Mtetra
.671 .862 .972 r
.44389 .30701 .44488 .3076 .44659 .30694 .44559 .30634 Mtetra
.657 .855 .976 r
.44559 .30634 .44659 .30694 .44828 .30657 .44729 .3057 Mtetra
.696 .801 .93 r
.44729 .3057 .44828 .30657 .44996 .30693 .449 .30497 Mtetra
.608 .592 .809 r
.449 .30497 .44996 .30693 .45162 .30801 .4507 .30458 Mtetra
.493 .425 .709 r
.4507 .30458 .45162 .30801 .45325 .31074 .45238 .30498 Mtetra
.021 .032 .528 r
.45238 .30498 .45325 .31074 .45054 .50836 .45397 .30948 Mtetra
0 0 .286 r
.45397 .30948 .45054 .50836 .45215 .51711 .45117 .51323 Mtetra
0 0 .367 r
.45117 .51323 .45215 .51711 .45391 .51941 .45287 .5183 Mtetra
.399 .642 .955 r
.45287 .5183 .45391 .51941 .45573 .51935 .45468 .51846 Mtetra
.649 .799 .955 r
.45468 .51846 .45573 .51935 .45755 .51876 .45651 .51786 Mtetra
.727 .816 .92 r
.45651 .51786 .45755 .51876 .45939 .51794 .45834 .51692 Mtetra
.6 .754 .951 r
.45834 .51692 .45939 .51794 .46121 .5175 .46017 .51651 Mtetra
.594 .759 .957 r
.46017 .51651 .46121 .5175 .46304 .51712 .462 .51612 Mtetra
.587 .754 .958 r
.462 .51612 .46304 .51712 .46487 .51683 .46383 .51575 Mtetra
.385 .643 .958 r
.46383 .51575 .46487 .51683 .46668 .51729 .46565 .51593 Mtetra
.576 .678 .909 r
.46565 .51593 .46668 .51729 .46851 .51726 .46748 .51566 Mtetra
.719 .697 .829 r
.46748 .51566 .46851 .51726 .47035 .51641 .46932 .51459 Mtetra
.902 .717 .643 r
.46932 .51459 .47035 .51641 .47226 .51137 .47124 .50906 Mtetra
.965 .689 .46 r
.47124 .50906 .47226 .51137 .47723 .30505 .47628 .3027 Mtetra
.896 .687 .612 r
.47628 .3027 .47723 .30505 .47906 .29708 .47809 .29594 Mtetra
.775 .767 .846 r
.47809 .29594 .47906 .29708 .48079 .29575 .47983 .29466 Mtetra
.639 .739 .921 r
.47983 .29466 .48079 .29575 .48251 .29525 .48155 .29415 Mtetra
.524 .691 .944 r
.48155 .29415 .48251 .29525 .48423 .29517 .48327 .29403 Mtetra
.675 .742 .901 r
.48327 .29403 .48423 .29517 .48596 .29453 .48499 .29336 Mtetra
.682 .739 .894 r
.48499 .29336 .48596 .29453 .48769 .29384 .48672 .29266 Mtetra
.685 .739 .892 r
.48672 .29266 .48769 .29384 .48941 .2931 .48845 .29195 Mtetra
.765 .765 .852 r
.48845 .29195 .48941 .2931 .49115 .29175 .49019 .29074 Mtetra
.717 .781 .903 r
.49019 .29074 .49115 .29175 .49288 .29076 .49192 .28989 Mtetra
.514 .741 .977 r
.49192 .28989 .49288 .29076 .49461 .29045 .49365 .28971 Mtetra
.869 .428 .051 r
.49365 .28971 .49461 .29045 .49631 .29387 .49534 .29342 Mtetra
.967 .683 .439 r
.49534 .29342 .49631 .29387 .49627 .49908 .49524 .49873 Mtetra
.92 .534 .247 r
.49524 .49873 .49627 .49908 .49806 .50604 .49703 .50499 Mtetra
.044 .442 .874 r
.49703 .50499 .49806 .50604 .4999 .50674 .49887 .50579 Mtetra
.618 .778 .957 r
.49887 .50579 .4999 .50674 .50176 .50621 .50073 .5053 Mtetra
.816 .827 .858 r
.50073 .5053 .50176 .50621 .50362 .50481 .5026 .50372 Mtetra
.931 .772 .662 r
.5026 .50372 .50362 .50481 .50549 .50216 .50448 .49889 Mtetra
.967 .687 .451 r
.50448 .49889 .50549 .50216 .50738 .49717 .50748 .29422 Mtetra
.55 .324 .525 r
.50748 .29422 .50738 .49717 .51018 .29709 .50927 .28593 Mtetra
.601 .401 .583 r
.50927 .28593 .51018 .29709 .51195 .2891 .51102 .28405 Mtetra
.609 .456 .65 r
.51102 .28405 .51195 .2891 .51371 .28597 .51276 .28315 Mtetra
.609 .529 .739 r
.51276 .28315 .51371 .28597 .51546 .28402 .51451 .28266 Mtetra
.664 .701 .874 r
.51451 .28266 .51546 .28402 .5172 .28304 .51625 .28202 Mtetra
.664 .765 .925 r
.51625 .28202 .5172 .28304 .51895 .28243 .518 .2814 Mtetra
.658 .761 .926 r
.518 .2814 .51895 .28243 .5207 .28196 .51975 .28081 Mtetra
.751 .765 .864 r
.51975 .28081 .5207 .28196 .52245 .28075 .5215 .27971 Mtetra
.717 .776 .899 r
.5215 .27971 .52245 .28075 .52419 .27975 .52325 .27884 Mtetra
.54 .743 .97 r
.52325 .27884 .52419 .27975 .52594 .2794 .525 .27861 Mtetra
.82 .354 0 r
.525 .27861 .52594 .2794 .5277 .28237 .52675 .28178 Mtetra
.97 .682 .427 r
.52675 .28178 .5277 .28237 .52976 .48738 .52875 .48706 Mtetra
.927 .549 .257 r
.52875 .48706 .52976 .48738 .53165 .49534 .53063 .49425 Mtetra
0 .316 .791 r
.53063 .49425 .53165 .49534 .53353 .49652 .53252 .49539 Mtetra
.587 .731 .942 r
.53252 .49539 .53353 .49652 .53541 .49615 .5344 .49503 Mtetra
.792 .792 .852 r
.5344 .49503 .53541 .49615 .53729 .49467 .53628 .49357 Mtetra
.934 .776 .662 r
.53628 .49357 .53729 .49467 .53915 .48987 .53814 .48876 Mtetra
.971 .689 .436 r
.53814 .48876 .53915 .48987 .54003 .28327 .53908 .2821 Mtetra
.954 .743 .58 r
.53908 .2821 .54003 .28327 .54175 .27528 .54081 .27413 Mtetra
.831 .781 .804 r
.54081 .27413 .54175 .27528 .54351 .27343 .54257 .27228 Mtetra
.665 .742 .907 r
.54257 .27228 .54351 .27343 .54527 .2728 .54433 .27165 Mtetra
.55 .696 .936 r
.54433 .27165 .54527 .2728 .54704 .2726 .5461 .27145 Mtetra
.719 .759 .884 r
.5461 .27145 .54704 .2726 .5488 .2717 .54786 .27055 Mtetra
.712 .757 .888 r
.54786 .27055 .5488 .2717 .55056 .27083 .54963 .26969 Mtetra
.567 .703 .933 r
.54963 .26969 .55056 .27083 .55234 .27058 .5514 .26943 Mtetra
.696 .236 0 r
.5514 .26943 .55234 .27058 .55414 .27339 .5532 .27225 Mtetra
.972 .681 .415 r
.5532 .27225 .55414 .27339 .55797 .47815 .55697 .47709 Mtetra
.936 .562 .202 r
.55697 .47709 .55797 .47815 .55995 .48615 .55895 .48507 Mtetra
0 .393 .845 r
.55895 .48507 .55995 .48615 .56186 .4871 .56086 .48604 Mtetra
.629 .763 .943 r
.56086 .48604 .56186 .4871 .56376 .48656 .56276 .48551 Mtetra
.733 .797 .904 r
.56276 .48551 .56376 .48656 .56566 .48555 .56466 .48449 Mtetra
.557 .734 .958 r
.56466 .48449 .56566 .48555 .56757 .4854 .56657 .48421 Mtetra
.557 .707 .94 r
.56657 .48421 .56757 .4854 .56948 .48531 .56848 .48396 Mtetra
.703 .736 .877 r
.56848 .48396 .56948 .48531 .57138 .48455 .57038 .48306 Mtetra
.899 .753 .69 r
.57038 .48306 .57138 .48455 .57324 .48082 .57224 .47914 Mtetra
.973 .687 .425 r
.57224 .47914 .57324 .48082 .57208 .27904 .57111 .275 Mtetra
.899 .654 .559 r
.57111 .275 .57208 .27904 .57366 .2647 .57273 .26351 Mtetra
.859 .78 .773 r
.57273 .26351 .57366 .2647 .57541 .26236 .57448 .26125 Mtetra
.683 .757 .908 r
.57448 .26125 .57541 .26236 .57719 .26165 .57627 .26053 Mtetra
.559 .708 .94 r
.57627 .26053 .57719 .26165 .57898 .26143 .57806 .26029 Mtetra
.704 .76 .896 r
.57806 .26029 .57898 .26143 .58077 .26062 .57984 .25947 Mtetra
.721 .763 .885 r
.57984 .25947 .58077 .26062 .58255 .2597 .58162 .25854 Mtetra
.588 .713 .93 r
.58162 .25854 .58255 .2597 .58434 .25937 .58342 .25821 Mtetra
.585 .123 0 r
.58342 .25821 .58434 .25937 .58619 .26181 .58527 .26065 Mtetra
.973 .68 .402 r
.58527 .26065 .58619 .26181 .59218 .46633 .5912 .46522 Mtetra
.939 .569 .203 r
.5912 .46522 .59218 .46633 .5943 .47528 .59331 .47417 Mtetra
0 .158 .668 r
.59331 .47417 .5943 .47528 .59626 .47689 .59528 .47578 Mtetra
.538 .718 .956 r
.59528 .47578 .59626 .47689 .5982 .47668 .59721 .47557 Mtetra
.768 .798 .877 r
.59721 .47557 .5982 .47668 .60011 .47541 .59912 .4743 Mtetra
.923 .794 .7 r
.59912 .4743 .60011 .47541 .60196 .47162 .60098 .4705 Mtetra
.975 .687 .413 r
.60098 .4705 .60196 .47162 .59908 .27078 .59816 .26957 Mtetra
.972 .723 .5 r
.59816 .26957 .59908 .27078 .60053 .25552 .59961 .25434 Mtetra
.877 .786 .757 r
.59961 .25434 .60053 .25552 .60228 .25299 .60137 .25181 Mtetra
.68 .747 .902 r
.60137 .25181 .60228 .25299 .60408 .25228 .60316 .2511 Mtetra
.551 .694 .934 r
.60316 .2511 .60408 .25228 .60589 .25208 .60498 .2509 Mtetra
.602 .716 .925 r
.60498 .2509 .60589 .25208 .6077 .2517 .60679 .25052 Mtetra
.668 .742 .905 r
.60679 .25052 .6077 .2517 .60951 .25104 .60859 .24986 Mtetra
.673 .743 .903 r
.60859 .24986 .60951 .25104 .61131 .25036 .6104 .24917 Mtetra
.737 .764 .875 r
.6104 .24917 .61131 .25036 .61311 .24933 .61219 .24814 Mtetra
.739 .765 .874 r
.61219 .24814 .61311 .24933 .6149 .24828 .61399 .2471 Mtetra
.627 .727 .919 r
.61399 .2471 .6149 .24828 .61671 .24779 .6158 .24662 Mtetra
0 .087 .62 r
.6158 .24662 .61671 .24779 .6186 .24961 .61769 .24844 Mtetra
.975 .677 .387 r
.61769 .24844 .6186 .24961 .62665 .44947 .62568 .44835 Mtetra
.956 .611 .265 r
.62568 .44835 .62665 .44947 .62905 .46373 .62808 .4626 Mtetra
0 .033 .556 r
.62808 .4626 .62905 .46373 .63108 .46578 .63012 .46465 Mtetra
.501 .698 .957 r
.63012 .46465 .63108 .46578 .63305 .46568 .63208 .46455 Mtetra
.754 .795 .886 r
.63208 .46455 .63305 .46568 .63498 .4645 .63401 .46337 Mtetra
.917 .8 .715 r
.63401 .46337 .63498 .4645 .63683 .461 .63586 .45987 Mtetra
.978 .711 .455 r
.63586 .45987 .63683 .461 .63792 .43567 .63695 .43417 Mtetra
.976 .684 .4 r
.63695 .43417 .63792 .43567 .63312 .2442 .63222 .24301 Mtetra
.895 .788 .734 r
.63222 .24301 .63312 .2442 .63486 .2413 .63396 .24011 Mtetra
.704 .756 .892 r
.63396 .24011 .63486 .2413 .63667 .24045 .63577 .23926 Mtetra
.587 .71 .928 r
.63577 .23926 .63667 .24045 .63851 .24012 .63761 .23893 Mtetra
.666 .742 .907 r
.63761 .23893 .63851 .24012 .64033 .23946 .63943 .23828 Mtetra
.733 .765 .879 r
.63943 .23828 .64033 .23946 .64214 .23845 .64124 .23726 Mtetra
.636 .731 .917 r
.64124 .23726 .64214 .23845 .64397 .23793 .64308 .23674 Mtetra
0 .282 .78 r
.64308 .23674 .64397 .23793 .64588 .23925 .64498 .23806 Mtetra
.938 .574 .185 r
.64498 .23806 .64588 .23925 .64813 .24912 .64723 .24793 Mtetra
.975 .675 .374 r
.64723 .24793 .64813 .24912 .65831 .45322 .65735 .45209 Mtetra
0 0 .513 r
.65735 .45209 .65831 .45322 .66039 .4555 .65944 .45436 Mtetra
.629 .756 .938 r
.65944 .45436 .66039 .4555 .66236 .45495 .66141 .45381 Mtetra
.769 .8 .878 r
.66141 .45381 .66236 .45495 .6643 .45366 .66335 .45252 Mtetra
.782 .803 .87 r
.66335 .45252 .6643 .45366 .66624 .45227 .66529 .45113 Mtetra
.73 .79 .9 r
.66529 .45113 .66624 .45227 .66819 .45123 .66724 .45009 Mtetra
.716 .786 .907 r
.66724 .45009 .66819 .45123 .67014 .45027 .6692 .44913 Mtetra
.656 .766 .93 r
.6692 .44913 .67014 .45027 .67212 .44961 .67117 .44847 Mtetra
.563 .727 .951 r
.67117 .44847 .67212 .44961 .6741 .44931 .67316 .44817 Mtetra
.534 .714 .955 r
.67316 .44817 .6741 .44931 .6761 .44911 .67515 .44797 Mtetra
.442 .667 .958 r
.67515 .44797 .6761 .44911 .67811 .44918 .67716 .44804 Mtetra
.414 .652 .957 r
.67716 .44804 .67811 .44918 .68012 .44932 .67918 .44818 Mtetra
.629 .755 .938 r
.67918 .44818 .68012 .44932 .68211 .44878 .68117 .44763 Mtetra
.89 .812 .765 r
.68117 .44763 .68211 .44878 .68399 .44607 .68305 .44492 Mtetra
.981 .722 .465 r
.68305 .44492 .68399 .44607 .68511 .42793 .68417 .42676 Mtetra
.977 .682 .379 r
.68417 .42676 .68511 .42793 .67718 .22896 .6763 .22776 Mtetra
.912 .79 .713 r
.6763 .22776 .67718 .22896 .6789 .2257 .67802 .2245 Mtetra
.709 .758 .89 r
.67802 .2245 .6789 .2257 .68074 .22482 .67986 .22361 Mtetra
.59 .71 .927 r
.67986 .22361 .68074 .22482 .68261 .22447 .68173 .22327 Mtetra
.626 .726 .919 r
.68173 .22327 .68261 .22447 .68447 .22398 .68359 .22277 Mtetra
.734 .766 .879 r
.68359 .22277 .68447 .22398 .6863 .22296 .68542 .22175 Mtetra
.645 .734 .913 r
.68542 .22175 .6863 .22296 .68816 .22239 .68728 .22117 Mtetra
.1 .424 .869 r
.68728 .22117 .68816 .22239 .6901 .22334 .68923 .22212 Mtetra
.909 .527 .098 r
.68923 .22212 .6901 .22334 .69245 .2315 .69156 .23023 Mtetra
.975 .671 .352 r
.69156 .23023 .69245 .2315 .70581 .43815 .70488 .43697 Mtetra
.588 .129 0 r
.70488 .43697 .70581 .43815 .70801 .44107 .70708 .4399 Mtetra
.549 .717 .95 r
.70708 .4399 .70801 .44107 .71003 .44082 .7091 .43965 Mtetra
.706 .782 .911 r
.7091 .43965 .71003 .44082 .71202 .43992 .71109 .43873 Mtetra
.685 .772 .917 r
.71109 .43873 .71202 .43992 .71402 .43918 .71308 .43793 Mtetra
.504 .678 .943 r
.71308 .43793 .71402 .43918 .71606 .43924 .71512 .43785 Mtetra
.642 .718 .903 r
.71512 .43785 .71606 .43924 .71808 .43876 .71713 .43725 Mtetra
.834 .764 .784 r
.71713 .43725 .71808 .43876 .72 .43672 .71905 .43506 Mtetra
.964 .738 .547 r
.71905 .43506 .72 .43672 .72155 .42849 .72055 .42595 Mtetra
.977 .677 .365 r
.72055 .42595 .72155 .42849 .71077 .21867 .70988 .21716 Mtetra
.919 .759 .667 r
.70988 .21716 .71077 .21867 .71241 .21429 .71154 .21303 Mtetra
.73 .758 .875 r
.71154 .21303 .71241 .21429 .71426 .21325 .71339 .21201 Mtetra
.604 .712 .921 r
.71339 .21201 .71426 .21325 .71615 .21284 .71528 .2116 Mtetra
.602 .711 .921 r
.71528 .2116 .71615 .21284 .71804 .21245 .71718 .21121 Mtetra
.741 .765 .873 r
.71718 .21121 .71804 .21245 .71989 .21135 .71903 .21012 Mtetra
.658 .736 .907 r
.71903 .21012 .71989 .21135 .72177 .21071 .72091 .20948 Mtetra
.234 .507 .906 r
.72091 .20948 .72177 .21071 .72374 .21139 .72287 .21016 Mtetra
.887 .497 .043 r
.72287 .21016 .72374 .21139 .72616 .21895 .72529 .21767 Mtetra
.975 .667 .334 r
.72529 .21767 .72616 .21895 .74197 .42669 .74106 .4255 Mtetra
.645 .192 0 r
.74106 .4255 .74197 .42669 .74427 .43011 .74335 .42894 Mtetra
.385 .631 .951 r
.74335 .42894 .74427 .43011 .74635 .43035 .74544 .42918 Mtetra
.692 .779 .918 r
.74544 .42918 .74635 .43035 .74837 .4295 .74746 .42833 Mtetra
.872 .819 .794 r
.74746 .42833 .74837 .4295 .75028 .42715 .74937 .42597 Mtetra
.977 .768 .555 r
.74937 .42597 .75028 .42715 .7518 .41932 .7509 .41815 Mtetra
.977 .675 .347 r
.7509 .41815 .7518 .41932 .73903 .20919 .73818 .20797 Mtetra
.951 .785 .639 r
.73818 .20797 .73903 .20919 .74064 .20448 .73978 .20326 Mtetra
.741 .772 .878 r
.73978 .20326 .74064 .20448 .7425 .20338 .74165 .20217 Mtetra
.607 .721 .925 r
.74165 .20217 .7425 .20338 .74441 .20295 .74356 .20175 Mtetra
.551 .696 .936 r
.74356 .20175 .74441 .20295 .74633 .2027 .74548 .20153 Mtetra
.681 .761 .912 r
.74548 .20153 .74633 .2027 .74821 .20181 .74737 .20078 Mtetra
.675 .788 .935 r
.74737 .20078 .74821 .20181 .7501 .2011 .74927 .20006 Mtetra
.67 .784 .934 r
.74927 .20006 .7501 .2011 .75203 .2008 .75116 .19936 Mtetra
.688 .715 .869 r
.75116 .19936 .75203 .2008 .75403 .20149 .75305 .19854 Mtetra
.592 .518 .741 r
.75305 .19854 .75403 .20149 .75613 .20341 .75497 .19814 Mtetra
.492 .379 .653 r
.75497 .19814 .75613 .20341 .75864 .21068 .75698 .19884 Mtetra
.221 .135 .541 r
.75698 .19884 .75864 .21068 .77633 .41297 .75954 .20667 Mtetra
.012 0 .42 r
.75954 .20667 .77633 .41297 .77872 .41675 .77766 .41352 Mtetra
0 .103 .633 r
.77766 .41352 .77872 .41675 .78093 .4182 .78004 .41704 Mtetra
.336 .607 .948 r
.78004 .41704 .78093 .4182 .78305 .41838 .78217 .41741 Mtetra
.658 .811 .956 r
.78217 .41741 .78305 .41838 .7851 .41771 .78422 .41669 Mtetra
.861 .851 .832 r
.78422 .41669 .7851 .41771 .78706 .4158 .78617 .41464 Mtetra
.979 .778 .562 r
.78617 .41464 .78706 .4158 .78857 .40855 .78769 .40745 Mtetra
.976 .671 .329 r
.78769 .40745 .78857 .40855 .77333 .1976 .77249 .19641 Mtetra
.964 .786 .613 r
.77249 .19641 .77333 .1976 .77487 .19237 .77403 .19114 Mtetra
.756 .779 .871 r
.77403 .19114 .77487 .19237 .77674 .19118 .7759 .18995 Mtetra
.624 .727 .92 r
.7759 .18995 .77674 .19118 .77867 .19068 .77783 .18945 Mtetra
.552 .692 .932 r
.77783 .18945 .77867 .19068 .78062 .19046 .77979 .18923 Mtetra
.748 .776 .876 r
.77979 .18923 .78062 .19046 .7825 .18932 .78167 .18809 Mtetra
.678 .75 .906 r
.78167 .18809 .7825 .18932 .78441 .18857 .78358 .18734 Mtetra
.452 .64 .937 r
.78358 .18734 .78441 .18857 .7864 .18868 .78557 .18745 Mtetra
.777 .362 0 r
.78557 .18745 .7864 .18868 .78884 .19396 .78801 .19275 Mtetra
.971 .657 .298 r
.78801 .19275 .78884 .19396 .80935 .40408 .80848 .40289 Mtetra
.724 .287 0 r
.80848 .40289 .80935 .40408 .81189 .40867 .81101 .40747 Mtetra
.319 .588 .94 r
.81101 .40747 .81189 .40867 .81406 .40913 .81318 .40791 Mtetra
.659 .763 .927 r
.81318 .40791 .81406 .40913 .81613 .40844 .81526 .40721 Mtetra
.835 .816 .832 r
.81526 .40721 .81613 .40844 .8181 .40651 .81722 .4053 Mtetra
.978 .783 .575 r
.81722 .4053 .8181 .40651 .81959 .39947 .81876 .39871 Mtetra
.974 .667 .311 r
.81876 .39871 .81959 .39947 .80219 .18738 .80143 .18687 Mtetra
.996 .826 .557 r
.80143 .18687 .80219 .18738 .80367 .18184 .80288 .18097 Mtetra
0 0 0 r
.18184 .40164 .18326 .3994 .18486 .39833 .18357 .39927 Mtetra
.543 .882 .631 r
.18357 .39927 .18486 .39833 .18638 .39798 .1852 .39791 Mtetra
.713 .951 .953 r
.1852 .39791 .18638 .39798 .18786 .39801 .18678 .39702 Mtetra
.691 .752 .898 r
.18678 .39702 .18786 .39801 .1894 .39753 .18834 .39636 Mtetra
.652 .707 .888 r
.18834 .39636 .1894 .39753 .19094 .39701 .18988 .39585 Mtetra
.635 .704 .896 r
.18988 .39585 .19094 .39701 .19249 .39647 .19142 .39542 Mtetra
.754 .75 .849 r
.19142 .39542 .19249 .39647 .19409 .3954 .19302 .39436 Mtetra
.703 .744 .883 r
.19302 .39436 .19409 .3954 .19566 .39466 .19459 .39362 Mtetra
.502 .681 .946 r
.19459 .39362 .19566 .39466 .19716 .3946 .19608 .39356 Mtetra
.928 .548 .25 r
.19608 .39356 .19716 .3946 .19823 .39872 .19716 .39765 Mtetra
.939 .683 .523 r
.19716 .39765 .19823 .39872 .17953 .59889 .17838 .59784 Mtetra
.937 .583 .32 r
.17838 .59784 .17953 .59889 .18058 .60427 .17942 .60328 Mtetra
.267 .595 .95 r
.17942 .60328 .18058 .60427 .18214 .60465 .18099 .6036 Mtetra
.665 .748 .912 r
.18099 .6036 .18214 .60465 .18379 .60407 .18265 .60301 Mtetra
.736 .758 .87 r
.18265 .60301 .18379 .60407 .18549 .60302 .18434 .60203 Mtetra
.419 .671 .966 r
.18434 .60203 .18549 .60302 .18714 .60259 .18594 .6021 Mtetra
.436 .796 .996 r
.18594 .6021 .18714 .60259 .18881 .60187 .18756 .60191 Mtetra
.666 .959 .94 r
.18756 .60191 .18881 .60187 .19055 .60041 .18925 .601 Mtetra
.97 .859 .674 r
.18925 .601 .19055 .60041 .19274 .59442 .19132 .59625 Mtetra
.943 .691 .527 r
.19132 .59625 .19274 .59442 .21373 .39398 .21246 .39499 Mtetra
.979 .812 .608 r
.21246 .39499 .21373 .39398 .21577 .38847 .2147 .38751 Mtetra
.807 .769 .817 r
.2147 .38751 .21577 .38847 .21741 .38708 .21635 .38598 Mtetra
.654 .722 .899 r
.21635 .38598 .21741 .38708 .21897 .38656 .21791 .38547 Mtetra
.526 .679 .935 r
.21791 .38547 .21897 .38656 .2205 .3864 .21943 .38537 Mtetra
.737 .754 .866 r
.21943 .38537 .2205 .3864 .2221 .38545 .22103 .38443 Mtetra
.708 .751 .886 r
.22103 .38443 .2221 .38545 .22368 .38468 .22262 .38367 Mtetra
.519 .695 .949 r
.22262 .38367 .22368 .38468 .22521 .38454 .22414 .38356 Mtetra
.914 .513 .194 r
.22414 .38356 .22521 .38454 .22642 .38787 .22532 .38718 Mtetra
.942 .683 .517 r
.22532 .38718 .22642 .38787 .20943 .58791 .20819 .588 Mtetra
.903 .56 .386 r
.20819 .588 .20943 .58791 .21044 .59445 .20926 .59392 Mtetra
0 .44 .777 r
.20926 .59392 .21044 .59445 .21201 .59506 .21083 .59441 Mtetra
.69 .839 .954 r
.21083 .59441 .21201 .59506 .21368 .59445 .21252 .59369 Mtetra
.781 .821 .883 r
.21252 .59369 .21368 .59445 .2154 .59337 .21425 .59249 Mtetra
.559 .756 .97 r
.21425 .59249 .2154 .59337 .21705 .59314 .2159 .59222 Mtetra
.588 .756 .958 r
.2159 .59222 .21705 .59314 .2187 .59281 .21756 .59188 Mtetra
.754 .789 .881 r
.21756 .59188 .2187 .59281 .22042 .59176 .21928 .59082 Mtetra
.911 .746 .664 r
.21928 .59082 .22042 .59176 .22249 .58674 .22137 .58556 Mtetra
.942 .688 .523 r
.22137 .58556 .22249 .58674 .24194 .38473 .24094 .38306 Mtetra
.89 .699 .639 r
.24094 .38306 .24194 .38473 .24404 .37827 .243 .37695 Mtetra
.786 .719 .789 r
.243 .37695 .24404 .37827 .24571 .37659 .24467 .37539 Mtetra
.634 .7 .893 r
.24467 .37539 .24571 .37659 .24729 .37602 .24624 .37495 Mtetra
.489 .672 .945 r
.24624 .37495 .24729 .37602 .24884 .37584 .24777 .37493 Mtetra
.6 .748 .948 r
.24777 .37493 .24884 .37584 .25041 .37537 .24934 .37458 Mtetra
.65 .791 .95 r
.24934 .37458 .25041 .37537 .25199 .37481 .25091 .37407 Mtetra
.66 .803 .952 r
.25091 .37407 .25199 .37481 .25357 .37433 .2525 .37351 Mtetra
.744 .8 .897 r
.2525 .37351 .25357 .37433 .25516 .37375 .25411 .37259 Mtetra
.714 .729 .862 r
.25411 .37259 .25516 .37375 .25672 .3734 .25572 .37175 Mtetra
.614 .622 .836 r
.25572 .37175 .25672 .3734 .25824 .37367 .25729 .37138 Mtetra
.02 .193 .703 r
.25729 .37138 .25824 .37367 .25948 .3773 .2587 .37294 Mtetra
.789 .538 0 r
.2587 .37294 .25948 .3773 .24449 .57777 .2597 .37955 Mtetra
0 0 .171 r
.2597 .37955 .24449 .57777 .24567 .58347 .24489 .57821 Mtetra
.163 .14 .583 r
.24489 .57821 .24567 .58347 .24724 .58439 .24629 .5811 Mtetra
.419 .389 .719 r
.24629 .5811 .24724 .58439 .24892 .58399 .24788 .58187 Mtetra
.507 .53 .815 r
.24788 .58187 .24892 .58399 .25064 .58307 .24952 .582 Mtetra
.543 .709 .948 r
.24952 .582 .25064 .58307 .25237 .58209 .25118 .58182 Mtetra
.471 .856 .98 r
.25118 .58182 .25237 .58209 .2541 .58108 .25287 .58144 Mtetra
.222 .733 .693 r
.25287 .58144 .2541 .58108 .25584 .58004 .25456 .58092 Mtetra
.067 0 0 r
.25456 .58092 .25584 .58004 .25755 .57928 .25626 .5804 Mtetra
.153 0 0 r
.25626 .5804 .25755 .57928 .25925 .57874 .25796 .57988 Mtetra
.139 0 0 r
.25796 .57988 .25925 .57874 .26094 .57829 .25966 .57932 Mtetra
.076 0 0 r
.25966 .57932 .26094 .57829 .26264 .5778 .26137 .57871 Mtetra
.006 0 0 r
.26137 .57871 .26264 .5778 .26434 .57729 .26308 .57808 Mtetra
0 0 0 r
.26308 .57808 .26434 .57729 .26604 .57677 .26479 .57744 Mtetra
.102 0 0 r
.26479 .57744 .26604 .57677 .26771 .57662 .26647 .57711 Mtetra
.01 0 0 r
.26647 .57711 .26771 .57662 .26939 .57639 .26816 .57678 Mtetra
.404 .851 .764 r
.26816 .57678 .26939 .57639 .27112 .57548 .26989 .57599 Mtetra
.933 .962 .76 r
.26989 .57599 .27112 .57548 .27309 .57145 .27176 .57328 Mtetra
.996 .86 .571 r
.27176 .57328 .27309 .57145 .28958 .3703 .27398 .56582 Mtetra
0 0 .167 r
.27398 .56582 .28958 .3703 .29174 .36227 .29039 .36541 Mtetra
0 0 0 r
.29039 .36541 .29174 .36227 .29346 .36012 .29219 .36217 Mtetra
.315 0 .125 r
.29219 .36217 .29346 .36012 .29507 .35946 .2938 .36157 Mtetra
.444 .054 .205 r
.2938 .36157 .29507 .35946 .29666 .35925 .29538 .36148 Mtetra
.186 0 .076 r
.29538 .36148 .29666 .35925 .29825 .35893 .29703 .36038 Mtetra
0 0 0 r
.29703 .36038 .29825 .35893 .29985 .35843 .29872 .35867 Mtetra
.814 .995 .863 r
.29872 .35867 .29985 .35843 .30146 .35794 .3004 .35718 Mtetra
.787 .82 .878 r
.3004 .35718 .30146 .35794 .30309 .35712 .30206 .35599 Mtetra
.709 .738 .874 r
.30206 .35599 .30309 .35712 .30472 .35629 .30369 .35519 Mtetra
.579 .703 .927 r
.30369 .35519 .30472 .35629 .30632 .35601 .30528 .35493 Mtetra
0 .02 .53 r
.30528 .35493 .30632 .35601 .30774 .35828 .30676 .35639 Mtetra
.961 .624 .282 r
.30676 .35639 .30774 .35828 .29575 .55846 .30784 .36372 Mtetra
0 0 .196 r
.30784 .36372 .29575 .55846 .29685 .56713 .29601 .56213 Mtetra
.253 .213 .618 r
.29601 .56213 .29685 .56713 .29845 .56843 .29754 .56447 Mtetra
.57 .461 .69 r
.29754 .56447 .29845 .56843 .30019 .56772 .29924 .56423 Mtetra
.617 .507 .705 r
.29924 .56423 .30019 .56772 .30196 .56639 .30097 .56356 Mtetra
.537 .49 .752 r
.30097 .56356 .30196 .56639 .30373 .56526 .30266 .5636 Mtetra
.305 .482 .869 r
.30266 .5636 .30373 .56526 .30546 .56459 .30431 .56421 Mtetra
0 .472 .762 r
.30431 .56421 .30546 .56459 .30719 .564 .30598 .56461 Mtetra
.227 0 0 r
.30598 .56461 .30719 .564 .30893 .56341 .30769 .56451 Mtetra
.16 0 0 r
.30769 .56451 .30893 .56341 .31066 .56283 .30942 .564 Mtetra
.116 0 0 r
.30942 .564 .31066 .56283 .31239 .56225 .31116 .56336 Mtetra
.102 0 0 r
.31116 .56336 .31239 .56225 .31413 .56169 .3129 .56273 Mtetra
.117 0 0 r
.3129 .56273 .31413 .56169 .31586 .56112 .31463 .56217 Mtetra
.119 0 0 r
.31463 .56217 .31586 .56112 .3176 .56057 .31637 .56161 Mtetra
.121 0 0 r
.31637 .56161 .3176 .56057 .31934 .56001 .31811 .56106 Mtetra
.123 0 0 r
.31811 .56106 .31934 .56001 .32107 .55947 .31985 .56051 Mtetra
.124 0 0 r
.31985 .56051 .32107 .55947 .32281 .55892 .32159 .55996 Mtetra
.32159 .55996 .32281 .55892 .32455 .55837 .32333 .55941 Mtetra
.32333 .55941 .32455 .55837 .32629 .55782 .32507 .55887 Mtetra
.123 0 0 r
.32507 .55887 .32629 .55782 .32803 .55727 .32681 .55832 Mtetra
.126 0 0 r
.32681 .55832 .32803 .55727 .32978 .55668 .32856 .55777 Mtetra
.143 0 0 r
.32856 .55777 .32978 .55668 .33153 .55607 .33031 .55723 Mtetra
.155 0 0 r
.33031 .55723 .33153 .55607 .33327 .55554 .33205 .55666 Mtetra
.146 0 0 r
.33205 .55666 .33327 .55554 .335 .55526 .3338 .5561 Mtetra
.027 0 0 r
.3338 .5561 .335 .55526 .33672 .55522 .33555 .55552 Mtetra
.383 .842 .781 r
.33555 .55552 .33672 .55522 .33844 .55515 .33731 .55479 Mtetra
.764 .921 .94 r
.33731 .55479 .33844 .55515 .34018 .55491 .3391 .55368 Mtetra
.801 .756 .812 r
.3391 .55368 .34018 .55491 .34193 .55444 .34091 .55203 Mtetra
.749 .631 .728 r
.34091 .55203 .34193 .55444 .34368 .55391 .34273 .55013 Mtetra
.678 .536 .684 r
.34273 .55013 .34368 .55391 .34543 .55337 .34454 .54857 Mtetra
.598 .458 .662 r
.34454 .54857 .34543 .55337 .34718 .55287 .3463 .54791 Mtetra
.574 .439 .659 r
.3463 .54791 .34718 .55287 .34894 .55234 .34805 .54755 Mtetra
.551 .427 .664 r
.34805 .54755 .34894 .55234 .35069 .55196 .34978 .54749 Mtetra
.547 .432 .674 r
.34978 .54749 .35069 .55196 .35243 .5517 .35151 .54747 Mtetra
.609 .479 .679 r
.35151 .54747 .35243 .5517 .3542 .55099 .35328 .54676 Mtetra
.745 .567 .653 r
.35328 .54676 .3542 .55099 .35604 .54879 .35517 .54351 Mtetra
.951 .685 .495 r
.35517 .54351 .35604 .54879 .35814 .54155 .36695 .34227 Mtetra
.55 .324 .526 r
.36695 .34227 .35814 .54155 .36984 .33821 .36898 .33411 Mtetra
.726 .551 .655 r
.36898 .33411 .36984 .33821 .37169 .33375 .37074 .33145 Mtetra
.651 .581 .763 r
.37074 .33145 .37169 .33375 .37338 .33239 .3724 .33072 Mtetra
.589 .614 .845 r
.3724 .33072 .37338 .33239 .37505 .33164 .37404 .33046 Mtetra
.564 .685 .921 r
.37404 .33046 .37505 .33164 .3767 .3311 .37568 .33025 Mtetra
.649 .786 .947 r
.37568 .33025 .3767 .3311 .37836 .33051 .37734 .32971 Mtetra
.658 .801 .952 r
.37734 .32971 .37836 .33051 .38002 .32999 .379 .32913 Mtetra
.686 .794 .932 r
.379 .32913 .38002 .32999 .38168 .32949 .38067 .32845 Mtetra
.71 .763 .893 r
.38067 .32845 .38168 .32949 .38334 .32895 .38234 .32765 Mtetra
.68 .707 .868 r
.38234 .32765 .38334 .32895 .385 .32839 .38401 .32695 Mtetra
.602 .656 .875 r
.38401 .32695 .385 .32839 .38666 .32779 .38566 .32663 Mtetra
.336 .579 .932 r
.38566 .32663 .38666 .32779 .38833 .32714 .38729 .32696 Mtetra
.372 0 0 r
.38729 .32696 .38833 .32714 .39 .32647 .3889 .32759 Mtetra
.475 .005 .057 r
.3889 .32759 .39 .32647 .39168 .3257 .39054 .32787 Mtetra
.224 0 .097 r
.39054 .32787 .39168 .3257 .39336 .32474 .39222 .32687 Mtetra
.325 0 .142 r
.39222 .32687 .39336 .32474 .39503 .32419 .3939 .32625 Mtetra
.646 .262 .302 r
.3939 .32625 .39503 .32419 .39665 .32483 .39549 .32759 Mtetra
.955 .68 .476 r
.39549 .32759 .39665 .32483 .39808 .33024 .38904 .52746 Mtetra
.547 .317 .518 r
.38904 .52746 .39808 .33024 .39167 .53323 .39047 .53556 Mtetra
.696 .323 .338 r
.39047 .53556 .39167 .53323 .39328 .53707 .39215 .53769 Mtetra
.222 0 0 r
.39215 .53769 .39328 .53707 .39505 .53695 .39392 .53758 Mtetra
0 0 0 r
.39392 .53758 .39505 .53695 .39685 .53614 .39571 .53696 Mtetra
.39571 .53696 .39685 .53614 .39865 .53529 .39751 .53615 Mtetra
.054 0 0 r
.39751 .53615 .39865 .53529 .40042 .5352 .3993 .53558 Mtetra
.317 .794 .714 r
.3993 .53558 .40042 .5352 .4022 .5351 .4011 .53485 Mtetra
.725 .944 .954 r
.4011 .53485 .4022 .5351 .40398 .53486 .40291 .53382 Mtetra
.813 .793 .833 r
.40291 .53382 .40398 .53486 .40577 .53433 .40474 .53218 Mtetra
.766 .657 .742 r
.40474 .53218 .40577 .53433 .40757 .53372 .40659 .53024 Mtetra
.696 .557 .693 r
.40659 .53024 .40757 .53372 .40936 .53319 .40842 .52854 Mtetra
.558 .436 .669 r
.40842 .52854 .40936 .53319 .41115 .53303 .41021 .52839 Mtetra
.587 .455 .669 r
.41021 .52839 .41115 .53303 .41295 .53245 .412 .52789 Mtetra
.695 .528 .658 r
.412 .52789 .41295 .53245 .41478 .53074 .41386 .52566 Mtetra
.957 .685 .48 r
.41386 .52566 .41478 .53074 .41678 .52424 .42218 .32527 Mtetra
.554 .327 .526 r
.42218 .32527 .41678 .52424 .42506 .3195 .42418 .315 Mtetra
.737 .551 .642 r
.42418 .315 .42506 .3195 .4269 .31431 .42595 .31178 Mtetra
.668 .576 .743 r
.42595 .31178 .4269 .31431 .4286 .31326 .42766 .31082 Mtetra
.613 .553 .763 r
.42766 .31082 .4286 .31326 .43029 .31285 .42934 .31036 Mtetra
.581 .531 .764 r
.42934 .31036 .43029 .31285 .43197 .31258 .43103 .31012 Mtetra
.612 .551 .762 r
.43103 .31012 .43197 .31258 .43368 .31156 .43272 .30966 Mtetra
.623 .606 .812 r
.43272 .30966 .43368 .31156 .43539 .31054 .43441 .3092 Mtetra
.644 .691 .879 r
.43441 .3092 .43539 .31054 .43709 .30962 .4361 .30867 Mtetra
.688 .782 .922 r
.4361 .30867 .43709 .30962 .43879 .30895 .4378 .30797 Mtetra
.698 .778 .914 r
.4378 .30797 .43879 .30895 .44049 .30833 .4395 .30722 Mtetra
.697 .751 .893 r
.4395 .30722 .44049 .30833 .44219 .30773 .44121 .30646 Mtetra
.695 .723 .871 r
.44121 .30646 .44219 .30773 .44389 .30701 .44291 .30569 Mtetra
.675 .706 .87 r
.44291 .30569 .44389 .30701 .44559 .30634 .44462 .30501 Mtetra
.645 .694 .882 r
.44462 .30501 .44559 .30634 .44729 .3057 .44632 .30448 Mtetra
.6 .697 .911 r
.44632 .30448 .44729 .3057 .449 .30497 .44801 .30414 Mtetra
.385 .69 .98 r
.44801 .30414 .449 .30497 .4507 .30458 .4497 .30421 Mtetra
.444 0 0 r
.4497 .30421 .4507 .30458 .45238 .30498 .45137 .30517 Mtetra
.913 .546 .32 r
.45137 .30517 .45238 .30498 .45397 .30948 .45292 .31151 Mtetra
.961 .68 .457 r
.45292 .31151 .45397 .30948 .45117 .51323 .45009 .51347 Mtetra
.861 .443 .228 r
.45009 .51347 .45117 .51323 .45287 .5183 .45182 .51732 Mtetra
.405 .679 .973 r
.45182 .51732 .45287 .5183 .45468 .51846 .45363 .51741 Mtetra
.65 .763 .932 r
.45363 .51741 .45468 .51846 .45651 .51786 .45546 .51682 Mtetra
.707 .783 .911 r
.45546 .51682 .45651 .51786 .45834 .51692 .45729 .51597 Mtetra
.506 .732 .975 r
.45729 .51597 .45834 .51692 .46017 .51651 .45912 .51581 Mtetra
.514 .794 .996 r
.45912 .51581 .46017 .51651 .462 .51612 .46094 .51553 Mtetra
.593 .851 .993 r
.46094 .51553 .462 .51612 .46383 .51575 .46278 .51501 Mtetra
.73 .851 .938 r
.46278 .51501 .46383 .51575 .46565 .51593 .46462 .51406 Mtetra
.751 .678 .781 r
.46462 .51406 .46565 .51593 .46748 .51566 .46647 .51254 Mtetra
.758 .606 .689 r
.46647 .51254 .46748 .51566 .46932 .51459 .46834 .50995 Mtetra
.878 .641 .576 r
.46834 .50995 .46932 .51459 .47124 .50906 .47036 .49843 Mtetra
.956 .678 .47 r
.47036 .49843 .47124 .50906 .47628 .3027 .47535 .29883 Mtetra
.786 .594 .64 r
.47535 .29883 .47628 .3027 .47809 .29594 .47713 .29475 Mtetra
.75 .755 .857 r
.47713 .29475 .47809 .29594 .47983 .29466 .47886 .29365 Mtetra
.642 .757 .932 r
.47886 .29365 .47983 .29466 .48155 .29415 .48058 .29312 Mtetra
.557 .722 .95 r
.48058 .29312 .48155 .29415 .48327 .29403 .4823 .29289 Mtetra
.699 .749 .89 r
.4823 .29289 .48327 .29403 .48499 .29336 .48403 .2921 Mtetra
.684 .723 .879 r
.48403 .2921 .48499 .29336 .48672 .29266 .48576 .29138 Mtetra
.651 .706 .888 r
.48576 .29138 .48672 .29266 .48845 .29195 .48749 .29082 Mtetra
.591 .713 .928 r
.48749 .29082 .48845 .29195 .49019 .29074 .48921 .29049 Mtetra
.062 .61 .834 r
.48921 .29049 .49019 .29074 .49192 .28989 .49094 .29062 Mtetra
.622 .127 .057 r
.49094 .29062 .49192 .28989 .49365 .28971 .49265 .29166 Mtetra
.891 .554 .402 r
.49265 .29166 .49365 .28971 .49534 .29342 .49429 .30103 Mtetra
.958 .672 .451 r
.49429 .30103 .49534 .29342 .49524 .49873 .49418 .50066 Mtetra
.774 .391 .33 r
.49418 .50066 .49524 .49873 .49703 .50499 .496 .50405 Mtetra
.098 .504 .904 r
.496 .50405 .49703 .50499 .49887 .50579 .49785 .50467 Mtetra
.617 .743 .936 r
.49785 .50467 .49887 .50579 .50073 .5053 .4997 .50421 Mtetra
.803 .795 .845 r
.4997 .50421 .50073 .5053 .5026 .50372 .50157 .50266 Mtetra
.944 .764 .629 r
.50157 .50266 .5026 .50372 .50448 .49889 .50347 .49662 Mtetra
.968 .688 .449 r
.50347 .49662 .50448 .49889 .50748 .29422 .50655 .28914 Mtetra
.798 .582 .609 r
.50655 .28914 .50748 .29422 .50927 .28593 .50832 .28321 Mtetra
.697 .584 .724 r
.50832 .28321 .50927 .28593 .51102 .28405 .51007 .28186 Mtetra
.61 .574 .789 r
.51007 .28186 .51102 .28405 .51276 .28315 .51181 .28144 Mtetra
.529 .585 .856 r
.51181 .28144 .51276 .28315 .51451 .28266 .51355 .28143 Mtetra
.658 .722 .896 r
.51355 .28143 .51451 .28266 .51625 .28202 .5153 .28083 Mtetra
.672 .734 .897 r
.5153 .28083 .51625 .28202 .518 .2814 .51705 .28017 Mtetra
.643 .716 .901 r
.51705 .28017 .518 .2814 .51975 .28081 .51879 .27964 Mtetra
.588 .707 .925 r
.51879 .27964 .51975 .28081 .5215 .27971 .52054 .27932 Mtetra
.16 .662 .909 r
.52054 .27932 .5215 .27971 .52325 .27884 .52229 .27943 Mtetra
.596 .079 0 r
.52229 .27943 .52325 .27884 .525 .27861 .52405 .28039 Mtetra
.875 .521 .376 r
.52405 .28039 .525 .27861 .52675 .28178 .5258 .28763 Mtetra
.962 .673 .438 r
.5258 .28763 .52675 .28178 .52875 .48706 .52774 .48963 Mtetra
.764 .396 .358 r
.52774 .48963 .52875 .48706 .53063 .49425 .52962 .49336 Mtetra
0 .422 .847 r
.52962 .49336 .53063 .49425 .53252 .49539 .5315 .49417 Mtetra
.59 .716 .93 r
.5315 .49417 .53252 .49539 .5344 .49503 .53339 .49382 Mtetra
.776 .775 .852 r
.53339 .49382 .5344 .49503 .53628 .49357 .53527 .49245 Mtetra
.933 .775 .662 r
.53527 .49245 .53628 .49357 .53814 .48876 .53713 .48767 Mtetra
.971 .689 .436 r
.53713 .48767 .53814 .48876 .53908 .2821 .53814 .28095 Mtetra
.955 .744 .58 r
.53814 .28095 .53908 .2821 .54081 .27413 .53987 .27298 Mtetra
.832 .781 .804 r
.53987 .27298 .54081 .27413 .54257 .27228 .54163 .27113 Mtetra
.665 .742 .907 r
.54163 .27113 .54257 .27228 .54433 .27165 .54339 .2705 Mtetra
.55 .696 .936 r
.54339 .2705 .54433 .27165 .5461 .27145 .54516 .27031 Mtetra
.719 .76 .885 r
.54516 .27031 .5461 .27145 .54786 .27055 .54692 .2694 Mtetra
.712 .757 .888 r
.54692 .2694 .54786 .27055 .54963 .26969 .54869 .26854 Mtetra
.567 .703 .933 r
.54869 .26854 .54963 .26969 .5514 .26943 .55046 .26828 Mtetra
.699 .238 0 r
.55046 .26828 .5514 .26943 .5532 .27225 .55226 .27111 Mtetra
.972 .681 .415 r
.55226 .27111 .5532 .27225 .55697 .47709 .55597 .47607 Mtetra
.936 .561 .204 r
.55597 .47607 .55697 .47709 .55895 .48507 .55795 .484 Mtetra
0 .358 .821 r
.55795 .484 .55895 .48507 .56086 .48604 .55986 .48505 Mtetra
.612 .772 .957 r
.55986 .48505 .56086 .48604 .56276 .48551 .56177 .48457 Mtetra
.753 .824 .907 r
.56177 .48457 .56276 .48551 .56466 .48449 .56366 .48345 Mtetra
.742 .801 .9 r
.56366 .48345 .56466 .48449 .56657 .48421 .56556 .48238 Mtetra
.736 .683 .8 r
.56556 .48238 .56657 .48421 .56848 .48396 .56746 .48104 Mtetra
.746 .61 .708 r
.56746 .48104 .56848 .48396 .57038 .48306 .56934 .47888 Mtetra
.841 .624 .61 r
.56934 .47888 .57038 .48306 .57224 .47914 .57116 .47223 Mtetra
.968 .681 .433 r
.57116 .47223 .57224 .47914 .57111 .275 .57008 .26726 Mtetra
.728 .509 .595 r
.57008 .26726 .57111 .275 .57273 .26351 .57179 .26199 Mtetra
.801 .728 .783 r
.57179 .26199 .57273 .26351 .57448 .26125 .57356 .2602 Mtetra
.677 .769 .92 r
.57356 .2602 .57448 .26125 .57627 .26053 .57534 .25951 Mtetra
.577 .738 .952 r
.57534 .25951 .57627 .26053 .57806 .26029 .57713 .25919 Mtetra
.713 .77 .897 r
.57713 .25919 .57806 .26029 .57984 .25947 .57892 .25832 Mtetra
.723 .764 .886 r
.57892 .25832 .57984 .25947 .58162 .25854 .5807 .25739 Mtetra
.589 .715 .93 r
.5807 .25739 .58162 .25854 .58342 .25821 .58249 .25705 Mtetra
.584 .122 0 r
.58249 .25705 .58342 .25821 .58527 .26065 .58434 .25949 Mtetra
.973 .68 .402 r
.58434 .25949 .58527 .26065 .5912 .46522 .59022 .4641 Mtetra
.939 .569 .202 r
.59022 .4641 .5912 .46522 .59331 .47417 .59233 .47306 Mtetra
0 .159 .668 r
.59233 .47306 .59331 .47417 .59528 .47578 .5943 .47467 Mtetra
.538 .718 .956 r
.5943 .47467 .59528 .47578 .59721 .47557 .59623 .47445 Mtetra
.768 .797 .877 r
.59623 .47445 .59721 .47557 .59912 .4743 .59814 .47319 Mtetra
.923 .794 .7 r
.59814 .47319 .59912 .4743 .60098 .4705 .6 .46938 Mtetra
.975 .687 .413 r
.6 .46938 .60098 .4705 .59816 .26957 .59723 .2683 Mtetra
.971 .721 .502 r
.59723 .2683 .59816 .26957 .59961 .25434 .59869 .25316 Mtetra
.876 .786 .757 r
.59869 .25316 .59961 .25434 .60137 .25181 .60045 .25064 Mtetra
.68 .746 .901 r
.60045 .25064 .60137 .25181 .60316 .2511 .60225 .24992 Mtetra
.552 .693 .933 r
.60225 .24992 .60316 .2511 .60498 .2509 .60406 .24971 Mtetra
.602 .714 .924 r
.60406 .24971 .60498 .2509 .60679 .25052 .60587 .24933 Mtetra
.668 .741 .905 r
.60587 .24933 .60679 .25052 .60859 .24986 .60768 .24867 Mtetra
.676 .745 .903 r
.60768 .24867 .60859 .24986 .6104 .24917 .60948 .24798 Mtetra
.748 .765 .867 r
.60948 .24798 .6104 .24917 .61219 .24814 .61128 .24687 Mtetra
.748 .752 .855 r
.61128 .24687 .61219 .24814 .61399 .2471 .61307 .24573 Mtetra
.648 .699 .884 r
.61307 .24573 .61399 .2471 .6158 .24662 .61489 .24515 Mtetra
0 .196 .725 r
.61489 .24515 .6158 .24662 .61769 .24844 .61677 .24682 Mtetra
.975 .678 .386 r
.61677 .24682 .61769 .24844 .62568 .44835 .62445 .43835 Mtetra
.756 .539 0 r
.62445 .43835 .62568 .44835 .62808 .4626 .62711 .46135 Mtetra
0 .024 .561 r
.62711 .46135 .62808 .4626 .63012 .46465 .62915 .46351 Mtetra
.497 .695 .957 r
.62915 .46351 .63012 .46465 .63208 .46455 .63111 .46342 Mtetra
.755 .796 .886 r
.63111 .46342 .63208 .46455 .63401 .46337 .63304 .46224 Mtetra
.918 .8 .715 r
.63304 .46224 .63401 .46337 .63586 .45987 .6349 .45873 Mtetra
.978 .71 .452 r
.6349 .45873 .63586 .45987 .63695 .43417 .63596 .43197 Mtetra
.975 .684 .401 r
.63596 .43197 .63695 .43417 .63222 .24301 .63131 .24182 Mtetra
.895 .787 .734 r
.63131 .24182 .63222 .24301 .63396 .24011 .63306 .23892 Mtetra
.704 .755 .892 r
.63306 .23892 .63396 .24011 .63577 .23926 .63487 .23808 Mtetra
.587 .71 .928 r
.63487 .23808 .63577 .23926 .63761 .23893 .63671 .23774 Mtetra
.666 .742 .907 r
.63671 .23774 .63761 .23893 .63943 .23828 .63853 .23709 Mtetra
.733 .765 .879 r
.63853 .23709 .63943 .23828 .64124 .23726 .64035 .23607 Mtetra
.636 .731 .916 r
.64035 .23607 .64124 .23726 .64308 .23674 .64218 .23555 Mtetra
0 .282 .78 r
.64218 .23555 .64308 .23674 .64498 .23806 .64408 .23687 Mtetra
.938 .574 .185 r
.64408 .23687 .64498 .23806 .64723 .24793 .64633 .24674 Mtetra
.975 .675 .374 r
.64633 .24674 .64723 .24793 .65735 .45209 .6564 .45095 Mtetra
0 0 .513 r
.6564 .45095 .65735 .45209 .65944 .45436 .65848 .45322 Mtetra
.629 .756 .938 r
.65848 .45322 .65944 .45436 .66141 .45381 .66046 .45268 Mtetra
.769 .8 .878 r
.66046 .45268 .66141 .45381 .66335 .45252 .6624 .45138 Mtetra
.782 .803 .87 r
.6624 .45138 .66335 .45252 .66529 .45113 .66434 .44999 Mtetra
.73 .79 .9 r
.66434 .44999 .66529 .45113 .66724 .45009 .66629 .44895 Mtetra
.716 .786 .907 r
.66629 .44895 .66724 .45009 .6692 .44913 .66825 .44799 Mtetra
.656 .766 .93 r
.66825 .44799 .6692 .44913 .67117 .44847 .67022 .44733 Mtetra
.563 .727 .951 r
.67022 .44733 .67117 .44847 .67316 .44817 .67221 .44703 Mtetra
.534 .714 .955 r
.67221 .44703 .67316 .44817 .67515 .44797 .67421 .44682 Mtetra
.442 .667 .958 r
.67421 .44682 .67515 .44797 .67716 .44804 .67622 .44689 Mtetra
.414 .652 .957 r
.67622 .44689 .67716 .44804 .67918 .44818 .67824 .44703 Mtetra
.629 .755 .938 r
.67824 .44703 .67918 .44818 .68117 .44763 .68022 .44649 Mtetra
.89 .812 .765 r
.68022 .44649 .68117 .44763 .68305 .44492 .68211 .44378 Mtetra
.981 .722 .465 r
.68211 .44378 .68305 .44492 .68417 .42676 .68324 .42561 Mtetra
.977 .682 .379 r
.68324 .42561 .68417 .42676 .6763 .22776 .67541 .22655 Mtetra
.912 .79 .713 r
.67541 .22655 .6763 .22776 .67802 .2245 .67714 .22329 Mtetra
.709 .758 .89 r
.67714 .22329 .67802 .2245 .67986 .22361 .67898 .22241 Mtetra
.59 .71 .927 r
.67898 .22241 .67986 .22361 .68173 .22327 .68084 .22206 Mtetra
.626 .726 .919 r
.68084 .22206 .68173 .22327 .68359 .22277 .68271 .22157 Mtetra
.734 .767 .879 r
.68271 .22157 .68359 .22277 .68542 .22175 .68454 .22054 Mtetra
.645 .734 .914 r
.68454 .22054 .68542 .22175 .68728 .22117 .6864 .21996 Mtetra
.1 .424 .869 r
.6864 .21996 .68728 .22117 .68923 .22212 .68835 .22091 Mtetra
.909 .527 .098 r
.68835 .22091 .68923 .22212 .69156 .23023 .69068 .22899 Mtetra
.975 .671 .352 r
.69068 .22899 .69156 .23023 .70488 .43697 .70395 .4358 Mtetra
.592 .131 0 r
.70395 .4358 .70488 .43697 .70708 .4399 .70615 .43874 Mtetra
.549 .718 .951 r
.70615 .43874 .70708 .4399 .7091 .43965 .70817 .43848 Mtetra
.708 .782 .91 r
.70817 .43848 .7091 .43965 .71109 .43873 .71016 .43755 Mtetra
.691 .775 .915 r
.71016 .43755 .71109 .43873 .71308 .43793 .71215 .43671 Mtetra
.515 .692 .948 r
.71215 .43671 .71308 .43793 .71512 .43785 .71419 .43659 Mtetra
.652 .744 .917 r
.71419 .43659 .71512 .43785 .71713 .43725 .7162 .43594 Mtetra
.853 .793 .791 r
.7162 .43594 .71713 .43725 .71905 .43506 .71811 .43368 Mtetra
.973 .746 .533 r
.71811 .43368 .71905 .43506 .72055 .42595 .71958 .42404 Mtetra
.977 .678 .364 r
.71958 .42404 .72055 .42595 .70988 .21716 .709 .2158 Mtetra
.926 .774 .672 r
.709 .2158 .70988 .21716 .71154 .21303 .71067 .21178 Mtetra
.728 .759 .877 r
.71067 .21178 .71154 .21303 .71339 .21201 .71253 .21077 Mtetra
.604 .712 .921 r
.71253 .21077 .71339 .21201 .71528 .2116 .71442 .21036 Mtetra
.602 .712 .921 r
.71442 .21036 .71528 .2116 .71718 .21121 .71631 .20996 Mtetra
.74 .766 .874 r
.71631 .20996 .71718 .21121 .71903 .21012 .71816 .20888 Mtetra
.658 .736 .908 r
.71816 .20888 .71903 .21012 .72091 .20948 .72004 .20824 Mtetra
.234 .507 .906 r
.72004 .20824 .72091 .20948 .72287 .21016 .72201 .20892 Mtetra
.886 .496 .042 r
.72201 .20892 .72287 .21016 .72529 .21767 .72443 .2164 Mtetra
.975 .667 .334 r
.72443 .2164 .72529 .21767 .74106 .4255 .74014 .42432 Mtetra
.646 .193 0 r
.74014 .42432 .74106 .4255 .74335 .42894 .74244 .42776 Mtetra
.385 .631 .951 r
.74244 .42776 .74335 .42894 .74544 .42918 .74453 .428 Mtetra
.692 .779 .918 r
.74453 .428 .74544 .42918 .74746 .42833 .74654 .42715 Mtetra
.872 .819 .794 r
.74654 .42715 .74746 .42833 .74937 .42597 .74846 .4248 Mtetra
.977 .768 .555 r
.74846 .4248 .74937 .42597 .7509 .41815 .74999 .41696 Mtetra
.977 .675 .347 r
.74999 .41696 .7509 .41815 .73818 .20797 .73732 .20674 Mtetra
.951 .784 .64 r
.73732 .20674 .73818 .20797 .73978 .20326 .73893 .20203 Mtetra
.74 .771 .878 r
.73893 .20203 .73978 .20326 .74165 .20217 .74079 .20095 Mtetra
.605 .719 .925 r
.74079 .20095 .74165 .20217 .74356 .20175 .7427 .20053 Mtetra
.545 .692 .935 r
.7427 .20053 .74356 .20175 .74548 .20153 .74463 .20034 Mtetra
.666 .751 .914 r
.74463 .20034 .74548 .20153 .74737 .20078 .74653 .19966 Mtetra
.675 .768 .921 r
.74653 .19966 .74737 .20078 .74927 .20006 .74842 .19894 Mtetra
.705 .78 .91 r
.74842 .19894 .74927 .20006 .75116 .19936 .75031 .19807 Mtetra
.773 .771 .851 r
.75031 .19807 .75116 .19936 .75305 .19854 .75216 .19674 Mtetra
.685 .664 .823 r
.75216 .19674 .75305 .19854 .75497 .19814 .75404 .19585 Mtetra
.513 .52 .801 r
.75404 .19585 .75497 .19814 .75698 .19884 .75601 .19599 Mtetra
0 0 .443 r
.75601 .19599 .75698 .19884 .75954 .20667 .75836 .20105 Mtetra
.973 .664 .3 r
.75836 .20105 .75954 .20667 .77766 .41352 .77669 .41127 Mtetra
0 0 .423 r
.77669 .41127 .77766 .41352 .78004 .41704 .77915 .4159 Mtetra
.308 .592 .945 r
.77915 .4159 .78004 .41704 .78217 .41741 .78129 .41632 Mtetra
.666 .792 .942 r
.78129 .41632 .78217 .41741 .78422 .41669 .78334 .41558 Mtetra
.86 .836 .822 r
.78334 .41558 .78422 .41669 .78617 .41464 .78528 .41348 Mtetra
.979 .778 .564 r
.78528 .41348 .78617 .41464 .78769 .40745 .78681 .40633 Mtetra
.976 .671 .329 r
.78681 .40633 .78769 .40745 .77249 .19641 .77165 .1952 Mtetra
.964 .785 .612 r
.77165 .1952 .77249 .19641 .77403 .19114 .77319 .18991 Mtetra
.756 .778 .871 r
.77319 .18991 .77403 .19114 .7759 .18995 .77506 .18871 Mtetra
.624 .726 .92 r
.77506 .18871 .7759 .18995 .77783 .18945 .77699 .18821 Mtetra
.551 .692 .933 r
.77699 .18821 .77783 .18945 .77979 .18923 .77895 .18799 Mtetra
.75 .777 .875 r
.77895 .18799 .77979 .18923 .78167 .18809 .78083 .18684 Mtetra
.677 .748 .905 r
.78083 .18684 .78167 .18809 .78358 .18734 .78274 .1861 Mtetra
.442 .633 .936 r
.78274 .1861 .78358 .18734 .78557 .18745 .78474 .18624 Mtetra
.807 .395 0 r
.78474 .18624 .78557 .18745 .78801 .19275 .78723 .19205 Mtetra
.971 .657 .3 r
.78723 .19205 .78801 .19275 .80848 .40289 .80765 .40234 Mtetra
.795 .323 0 r
.80765 .40234 .80848 .40289 .81101 .40747 .81016 .40663 Mtetra
.311 .667 .974 r
.81016 .40663 .81101 .40747 .81318 .40791 .81231 .40684 Mtetra
.685 .803 .938 r
.81231 .40684 .81318 .40791 .81526 .40721 .81438 .406 Mtetra
.831 .821 .839 r
.81438 .406 .81526 .40721 .81722 .4053 .81635 .40416 Mtetra
.956 .816 .665 r
.81635 .40416 .81722 .4053 .81876 .39871 .8181 .39982 Mtetra
.982 .716 .328 r
.8181 .39982 .81876 .39871 .80143 .18687 .8179 .37432 Mtetra
.021 0 .42 r
.8179 .37432 .80143 .18687 .80288 .18097 .80237 .18311 Mtetra
0 0 .108 r
.15953 .59943 .18184 .40164 .18357 .39927 .1819 .40385 Mtetra
0 0 0 r
.1819 .40385 .18357 .39927 .1852 .39791 .18394 .39863 Mtetra
.93 .968 .751 r
.18394 .39863 .1852 .39791 .18678 .39702 .1857 .39607 Mtetra
.739 .766 .875 r
.1857 .39607 .18678 .39702 .18834 .39636 .18728 .39515 Mtetra
.649 .699 .883 r
.18728 .39515 .18834 .39636 .18988 .39585 .18882 .39466 Mtetra
.596 .684 .903 r
.18882 .39466 .18988 .39585 .19142 .39542 .19034 .39437 Mtetra
.753 .75 .85 r
.19034 .39437 .19142 .39542 .19302 .39436 .19195 .39331 Mtetra
.702 .743 .884 r
.19195 .39331 .19302 .39436 .19459 .39362 .19351 .39258 Mtetra
.5 .68 .947 r
.19351 .39258 .19459 .39362 .19608 .39356 .19501 .39253 Mtetra
.927 .546 .247 r
.19501 .39253 .19608 .39356 .19716 .39765 .19609 .39658 Mtetra
.939 .683 .523 r
.19609 .39658 .19716 .39765 .17838 .59784 .17723 .59681 Mtetra
.937 .584 .323 r
.17723 .59681 .17838 .59784 .17942 .60328 .17827 .60229 Mtetra
.271 .598 .951 r
.17827 .60229 .17942 .60328 .18099 .6036 .17984 .60261 Mtetra
.668 .759 .919 r
.17984 .60261 .18099 .6036 .18265 .60301 .1815 .602 Mtetra
.739 .77 .878 r
.1815 .602 .18265 .60301 .18434 .60203 .18319 .60102 Mtetra
.396 .658 .964 r
.18319 .60102 .18434 .60203 .18594 .6021 .18478 .60114 Mtetra
.519 .721 .965 r
.18478 .60114 .18594 .6021 .18756 .60191 .1864 .601 Mtetra
.724 .785 .901 r
.1864 .601 .18756 .60191 .18925 .601 .18809 .60013 Mtetra
.907 .752 .678 r
.18809 .60013 .18925 .601 .19132 .59625 .19016 .59541 Mtetra
.939 .687 .529 r
.19016 .59541 .19132 .59625 .21246 .39499 .21139 .39402 Mtetra
.919 .724 .623 r
.21139 .39402 .21246 .39499 .2147 .38751 .21363 .38645 Mtetra
.801 .755 .811 r
.21363 .38645 .2147 .38751 .21635 .38598 .21529 .38493 Mtetra
.651 .732 .908 r
.21529 .38493 .21635 .38598 .21791 .38547 .21685 .38443 Mtetra
.512 .687 .946 r
.21685 .38443 .21791 .38547 .21943 .38537 .21836 .38435 Mtetra
.736 .757 .869 r
.21836 .38435 .21943 .38537 .22103 .38443 .21997 .38342 Mtetra
.706 .753 .889 r
.21997 .38342 .22103 .38443 .22262 .38367 .22155 .38267 Mtetra
.506 .694 .953 r
.22155 .38267 .22262 .38367 .22414 .38356 .22307 .38259 Mtetra
.92 .527 .219 r
.22307 .38259 .22414 .38356 .22532 .38718 .22423 .38643 Mtetra
.942 .683 .517 r
.22423 .38643 .22532 .38718 .20819 .588 .20699 .58769 Mtetra
.914 .563 .358 r
.20699 .58769 .20819 .588 .20926 .59392 .20809 .59324 Mtetra
.043 .53 .884 r
.20809 .59324 .20926 .59392 .21083 .59441 .20967 .59366 Mtetra
.707 .819 .935 r
.20967 .59366 .21083 .59441 .21252 .59369 .21136 .59288 Mtetra
.787 .81 .87 r
.21136 .59288 .21252 .59369 .21425 .59249 .2131 .59161 Mtetra
.572 .758 .966 r
.2131 .59161 .21425 .59249 .2159 .59222 .21475 .5913 Mtetra
.593 .757 .957 r
.21475 .5913 .2159 .59222 .21756 .59188 .21641 .59095 Mtetra
.756 .788 .879 r
.21641 .59095 .21756 .59188 .21928 .59082 .21813 .58987 Mtetra
.912 .744 .661 r
.21813 .58987 .21928 .59082 .22137 .58556 .22025 .58444 Mtetra
.942 .688 .523 r
.22025 .58444 .22137 .58556 .24094 .38306 .23991 .38164 Mtetra
.898 .712 .643 r
.23991 .38164 .24094 .38306 .243 .37695 .24196 .37573 Mtetra
.789 .733 .801 r
.24196 .37573 .243 .37695 .24467 .37539 .24363 .37422 Mtetra
.62 .701 .903 r
.24363 .37422 .24467 .37539 .24624 .37495 .24519 .37384 Mtetra
.467 .652 .94 r
.24519 .37384 .24624 .37495 .24777 .37493 .24672 .37388 Mtetra
.592 .716 .93 r
.24672 .37388 .24777 .37493 .24934 .37458 .24828 .37358 Mtetra
.648 .743 .919 r
.24828 .37358 .24934 .37458 .25091 .37407 .24985 .37308 Mtetra
.663 .751 .915 r
.24985 .37308 .25091 .37407 .2525 .37351 .25144 .37252 Mtetra
.724 .764 .885 r
.25144 .37252 .2525 .37351 .25411 .37259 .25305 .37168 Mtetra
.722 .779 .898 r
.25305 .37168 .25411 .37259 .25572 .37175 .25466 .37086 Mtetra
.656 .769 .932 r
.25466 .37086 .25572 .37175 .25729 .37138 .25624 .37032 Mtetra
.281 .571 .937 r
.25624 .37032 .25729 .37138 .2587 .37294 .25775 .37068 Mtetra
.051 .218 .717 r
.25775 .37068 .2587 .37294 .2597 .37955 .25917 .37215 Mtetra
.16 .093 .526 r
.25917 .37215 .2597 .37955 .24489 .57821 .26038 .37623 Mtetra
0 0 .187 r
.26038 .37623 .24489 .57821 .24629 .5811 .24573 .57319 Mtetra
0 0 .467 r
.24573 .57319 .24629 .5811 .24788 .58187 .24692 .57876 Mtetra
.038 .146 .65 r
.24692 .57876 .24788 .58187 .24952 .582 .2484 .58084 Mtetra
.276 .56 .932 r
.2484 .58084 .24952 .582 .25118 .58182 .25002 .58125 Mtetra
.527 .817 .999 r
.25002 .58125 .25118 .58182 .25287 .58144 .2517 .58093 Mtetra
.64 .866 .984 r
.2517 .58093 .25287 .58144 .25456 .58092 .2534 .58032 Mtetra
.632 .844 .981 r
.2534 .58032 .25456 .58092 .25626 .5804 .2551 .57976 Mtetra
.627 .834 .98 r
.2551 .57976 .25626 .5804 .25796 .57988 .2568 .57923 Mtetra
.647 .836 .973 r
.2568 .57923 .25796 .57988 .25966 .57932 .25851 .57865 Mtetra
.673 .835 .961 r
.25851 .57865 .25966 .57932 .26137 .57871 .26022 .57798 Mtetra
.688 .825 .949 r
.26022 .57798 .26137 .57871 .26308 .57808 .26194 .57726 Mtetra
.69 .808 .939 r
.26194 .57726 .26308 .57808 .26479 .57744 .26365 .57655 Mtetra
.624 .777 .954 r
.26365 .57655 .26479 .57744 .26647 .57711 .26535 .57608 Mtetra
.616 .744 .937 r
.26535 .57608 .26647 .57711 .26816 .57678 .26705 .57566 Mtetra
.679 .745 .901 r
.26705 .57566 .26816 .57678 .26989 .57599 .26877 .57498 Mtetra
.819 .782 .818 r
.26877 .57498 .26989 .57599 .27176 .57328 .27056 .57326 Mtetra
.937 .885 .755 r
.27056 .57326 .27176 .57328 .27398 .56582 .27246 .57024 Mtetra
0 0 0 r
.27246 .57024 .27398 .56582 .29039 .36541 .27448 .56548 Mtetra
.524 .298 .514 r
.27448 .56548 .29039 .36541 .29219 .36217 .2764 .56208 Mtetra
.532 .305 .516 r
.2764 .56208 .29219 .36217 .2938 .36157 .27805 .56234 Mtetra
.531 .304 .515 r
.27805 .56234 .2938 .36157 .29538 .36148 .27974 .56205 Mtetra
0 0 .225 r
.27974 .56205 .29538 .36148 .29703 .36038 .29499 .37323 Mtetra
0 0 .12 r
.29499 .37323 .29703 .36038 .29872 .35867 .29749 .36037 Mtetra
.894 .933 .556 r
.29749 .36037 .29872 .35867 .3004 .35718 .29933 .35662 Mtetra
.858 .847 .832 r
.29933 .35662 .3004 .35718 .30206 .35599 .30103 .35485 Mtetra
.703 .736 .876 r
.30103 .35485 .30206 .35599 .30369 .35519 .30266 .35408 Mtetra
.576 .701 .927 r
.30266 .35408 .30369 .35519 .30528 .35493 .30425 .35383 Mtetra
.162 .493 .905 r
.30425 .35383 .30528 .35493 .30676 .35639 .30579 .35439 Mtetra
0 .116 .666 r
.30579 .35439 .30676 .35639 .30784 .36372 .30725 .35612 Mtetra
.222 .139 .546 r
.30725 .35612 .30784 .36372 .29601 .56213 .30857 .35992 Mtetra
.521 .3 .52 r
.30857 .35992 .29601 .56213 .29754 .56447 .30981 .36509 Mtetra
.531 .309 .522 r
.30981 .36509 .29754 .56447 .29924 .56423 .31136 .36565 Mtetra
.517 .297 .519 r
.31136 .36565 .29924 .56423 .30097 .56356 .31251 .37236 Mtetra
0 0 .232 r
.31251 .37236 .30097 .56356 .30266 .5636 .30198 .55608 Mtetra
.056 .025 .501 r
.30198 .55608 .30266 .5636 .30431 .56421 .30334 .56115 Mtetra
0 .125 .642 r
.30334 .56115 .30431 .56421 .30598 .56461 .30489 .56338 Mtetra
.211 .511 .911 r
.30489 .56338 .30598 .56461 .30769 .56451 .30655 .56395 Mtetra
.573 .838 .995 r
.30655 .56395 .30769 .56451 .30942 .564 .30828 .56351 Mtetra
.674 .881 .975 r
.30828 .56351 .30942 .564 .31116 .56336 .31002 .56278 Mtetra
.672 .862 .971 r
.31002 .56278 .31116 .56336 .3129 .56273 .31177 .56208 Mtetra
.633 .836 .978 r
.31177 .56208 .3129 .56273 .31463 .56217 .3135 .56152 Mtetra
.3135 .56152 .31463 .56217 .31637 .56161 .31524 .56096 Mtetra
.632 .835 .978 r
.31524 .56096 .31637 .56161 .31811 .56106 .31698 .5604 Mtetra
.63 .834 .979 r
.31698 .5604 .31811 .56106 .31985 .56051 .31872 .55985 Mtetra
.629 .833 .979 r
.31872 .55985 .31985 .56051 .32159 .55996 .32046 .5593 Mtetra
.32046 .5593 .32159 .55996 .32333 .55941 .32221 .55875 Mtetra
.32221 .55875 .32333 .55941 .32507 .55887 .32395 .5582 Mtetra
.628 .833 .979 r
.32395 .5582 .32507 .55887 .32681 .55832 .32569 .55765 Mtetra
.624 .832 .98 r
.32569 .55765 .32681 .55832 .32856 .55777 .32744 .55711 Mtetra
.622 .833 .981 r
.32744 .55711 .32856 .55777 .33031 .55723 .32918 .55658 Mtetra
.63 .838 .98 r
.32918 .55658 .33031 .55723 .33205 .55666 .33093 .55602 Mtetra
.611 .834 .985 r
.33093 .55602 .33205 .55666 .3338 .5561 .33268 .55551 Mtetra
.605 .845 .99 r
.33268 .55551 .3338 .5561 .33555 .55552 .33443 .555 Mtetra
.699 .883 .966 r
.33443 .555 .33555 .55552 .33731 .55479 .33619 .55419 Mtetra
.852 .857 .845 r
.33619 .55419 .33731 .55479 .3391 .55368 .33802 .55239 Mtetra
.887 .745 .698 r
.33802 .55239 .3391 .55368 .34091 .55203 .33995 .54857 Mtetra
.873 .654 .604 r
.33995 .54857 .34091 .55203 .34273 .55013 .34215 .5397 Mtetra
.944 .677 .503 r
.34215 .5397 .34273 .55013 .34454 .54857 .35436 .34491 Mtetra
.536 .312 .523 r
.35436 .34491 .34454 .54857 .3463 .54791 .35606 .34336 Mtetra
.531 .309 .522 r
.35606 .34336 .3463 .54791 .34805 .54755 .35766 .34378 Mtetra
.529 .307 .522 r
.35766 .34378 .34805 .54755 .34978 .54749 .3592 .3455 Mtetra
.528 .306 .522 r
.3592 .3455 .34978 .54749 .35151 .54747 .36072 .34743 Mtetra
.535 .312 .523 r
.36072 .34743 .35151 .54747 .35328 .54676 .36241 .34632 Mtetra
.546 .321 .525 r
.36241 .34632 .35328 .54676 .35517 .54351 .36436 .34011 Mtetra
.543 .319 .524 r
.36436 .34011 .35517 .54351 .36695 .34227 .36624 .33501 Mtetra
.672 .475 .61 r
.36624 .33501 .36695 .34227 .36898 .33411 .36802 .33203 Mtetra
.751 .645 .743 r
.36802 .33203 .36898 .33411 .37074 .33145 .36973 .33037 Mtetra
.662 .741 .909 r
.36973 .33037 .37074 .33145 .3724 .33072 .37138 .32979 Mtetra
.574 .745 .958 r
.37138 .32979 .3724 .33072 .37404 .33046 .37303 .3295 Mtetra
.577 .739 .953 r
.37303 .3295 .37404 .33046 .37568 .33025 .37467 .3292 Mtetra
.656 .747 .917 r
.37467 .3292 .37568 .33025 .37734 .32971 .37633 .32865 Mtetra
.669 .748 .91 r
.37633 .32865 .37734 .32971 .379 .32913 .37799 .32804 Mtetra
.705 .751 .888 r
.37799 .32804 .379 .32913 .38067 .32845 .37967 .32725 Mtetra
.735 .739 .855 r
.37967 .32725 .38067 .32845 .38234 .32765 .38135 .32625 Mtetra
.681 .693 .854 r
.38135 .32625 .38234 .32765 .38401 .32695 .38302 .32554 Mtetra
.47 .598 .898 r
.38302 .32554 .38401 .32695 .38566 .32663 .38465 .32566 Mtetra
.717 .223 0 r
.38465 .32566 .38566 .32663 .38729 .32696 .3862 .32782 Mtetra
.893 .547 .383 r
.3862 .32782 .38729 .32696 .3889 .32759 .38755 .33456 Mtetra
.948 .673 .482 r
.38755 .33456 .3889 .32759 .39054 .32787 .38081 .52976 Mtetra
.531 .304 .515 r
.38081 .52976 .39054 .32787 .39222 .32687 .38257 .52945 Mtetra
.529 .302 .515 r
.38257 .52945 .39222 .32687 .3939 .32625 .38438 .52818 Mtetra
.534 .307 .516 r
.38438 .52818 .3939 .32625 .39549 .32759 .38607 .52969 Mtetra
.539 .31 .517 r
.38607 .52969 .39549 .32759 .38904 .52746 .38767 .5337 Mtetra
.623 .32 .435 r
.38767 .5337 .38904 .52746 .39047 .53556 .38934 .53582 Mtetra
.57 .016 0 r
.38934 .53582 .39047 .53556 .39215 .53769 .39107 .53673 Mtetra
.517 .733 .972 r
.39107 .53673 .39215 .53769 .39392 .53758 .39284 .53656 Mtetra
.628 .759 .941 r
.39284 .53656 .39392 .53758 .39571 .53696 .39463 .53607 Mtetra
.653 .795 .951 r
.39463 .53607 .39571 .53696 .39751 .53615 .39642 .53547 Mtetra
.593 .823 .987 r
.39642 .53547 .39751 .53615 .3993 .53558 .39821 .535 Mtetra
.683 .873 .97 r
.39821 .535 .3993 .53558 .4011 .53485 .40001 .53423 Mtetra
.822 .872 .882 r
.40001 .53423 .4011 .53485 .40291 .53382 .40184 .53274 Mtetra
.899 .773 .714 r
.40184 .53274 .40291 .53382 .40474 .53218 .40374 .52922 Mtetra
.877 .666 .614 r
.40374 .52922 .40474 .53218 .40659 .53024 .40578 .52186 Mtetra
.952 .681 .485 r
.40578 .52186 .40659 .53024 .40842 .52854 .4145 .32399 Mtetra
.535 .312 .523 r
.4145 .32399 .40842 .52854 .41021 .52839 .41621 .32285 Mtetra
.532 .309 .522 r
.41621 .32285 .41021 .52839 .412 .52789 .41787 .32292 Mtetra
.537 .313 .523 r
.41787 .32292 .412 .52789 .41386 .52566 .41962 .32084 Mtetra
.543 .318 .524 r
.41962 .32084 .41386 .52566 .42218 .32527 .42146 .31569 Mtetra
.648 .443 .593 r
.42146 .31569 .42218 .32527 .42418 .315 .42323 .3126 Mtetra
.756 .628 .719 r
.42323 .3126 .42418 .315 .42595 .31178 .42497 .31063 Mtetra
.706 .745 .882 r
.42497 .31063 .42595 .31178 .42766 .31082 .42666 .30982 Mtetra
.64 .754 .931 r
.42666 .30982 .42766 .31082 .42934 .31036 .42835 .30931 Mtetra
.599 .73 .936 r
.42835 .30931 .42934 .31036 .43103 .31012 .43004 .30896 Mtetra
.621 .715 .913 r
.43004 .30896 .43103 .31012 .43272 .30966 .43173 .30853 Mtetra
.623 .723 .918 r
.43173 .30853 .43272 .30966 .43441 .3092 .43342 .3081 Mtetra
.646 .737 .915 r
.43342 .3081 .43441 .3092 .4361 .30867 .43512 .30757 Mtetra
.7 .753 .893 r
.43512 .30757 .4361 .30867 .4378 .30797 .43682 .3068 Mtetra
.707 .742 .879 r
.43682 .3068 .4378 .30797 .4395 .30722 .43852 .30598 Mtetra
.706 .729 .868 r
.43852 .30598 .4395 .30722 .44121 .30646 .44023 .30514 Mtetra
.713 .719 .854 r
.44023 .30514 .44121 .30646 .44291 .30569 .44194 .30424 Mtetra
.671 .685 .855 r
.44194 .30424 .44291 .30569 .44462 .30501 .44364 .30356 Mtetra
.579 .647 .882 r
.44364 .30356 .44462 .30501 .44632 .30448 .44534 .30332 Mtetra
0 .342 .819 r
.44534 .30332 .44632 .30448 .44801 .30414 .447 .30431 Mtetra
.806 .342 .128 r
.447 .30431 .44801 .30414 .4497 .30421 .44863 .30674 Mtetra
.88 .554 .429 r
.44863 .30674 .4497 .30421 .45137 .30517 .45009 .31675 Mtetra
.948 .666 .47 r
.45009 .31675 .45137 .30517 .45292 .31151 .44725 .51191 Mtetra
.537 .309 .516 r
.44725 .51191 .45292 .31151 .45009 .51347 .44898 .51519 Mtetra
.635 .22 .238 r
.44898 .51519 .45009 .51347 .45182 .51732 .45077 .51644 Mtetra
.502 .746 .982 r
.45077 .51644 .45182 .51732 .45363 .51741 .45258 .51627 Mtetra
.643 .745 .923 r
.45258 .51627 .45363 .51741 .45546 .51682 .45441 .51571 Mtetra
.669 .759 .918 r
.45441 .51571 .45546 .51682 .45729 .51597 .45625 .51504 Mtetra
.403 .689 .977 r
.45625 .51504 .45729 .51597 .45912 .51581 .45806 .51511 Mtetra
.486 .781 .997 r
.45806 .51511 .45912 .51581 .46094 .51553 .45989 .51489 Mtetra
.678 .862 .969 r
.45989 .51489 .46094 .51553 .46278 .51501 .46173 .51413 Mtetra
.891 .816 .767 r
.46173 .51413 .46278 .51501 .46462 .51406 .4636 .51146 Mtetra
.86 .672 .648 r
.4636 .51146 .46462 .51406 .46647 .51254 .46552 .50641 Mtetra
.96 .684 .466 r
.46552 .50641 .46647 .51254 .46834 .50995 .4708 .30618 Mtetra
.548 .322 .524 r
.4708 .30618 .46834 .50995 .47036 .49843 .47265 .29852 Mtetra
.539 .315 .523 r
.47265 .29852 .47036 .49843 .47535 .29883 .47441 .29544 Mtetra
.71 .562 .685 r
.47441 .29544 .47535 .29883 .47713 .29475 .47616 .29355 Mtetra
.713 .742 .875 r
.47616 .29355 .47713 .29475 .47886 .29365 .47789 .29268 Mtetra
.648 .769 .937 r
.47789 .29268 .47886 .29365 .48058 .29312 .47961 .29213 Mtetra
.605 .749 .946 r
.47961 .29213 .48058 .29312 .4823 .29289 .48133 .29173 Mtetra
.727 .756 .875 r
.48133 .29173 .4823 .29289 .48403 .2921 .48307 .29079 Mtetra
.688 .716 .87 r
.48307 .29079 .48403 .2921 .48576 .29138 .4848 .29004 Mtetra
.602 .678 .895 r
.4848 .29004 .48576 .29138 .48749 .29082 .48652 .28969 Mtetra
0 .243 .744 r
.48652 .28969 .48749 .29082 .48921 .29049 .48823 .29092 Mtetra
.847 .424 .228 r
.48823 .29092 .48921 .29049 .49094 .29062 .48992 .2944 Mtetra
.962 .677 .447 r
.48992 .2944 .49094 .29062 .49265 .29166 .48953 .49317 Mtetra
.544 .314 .517 r
.48953 .49317 .49265 .29166 .49429 .30103 .4913 .50002 Mtetra
.535 .307 .516 r
.4913 .50002 .49429 .30103 .49418 .50066 .49313 .50223 Mtetra
.591 .158 .187 r
.49313 .50223 .49418 .50066 .496 .50405 .49497 .50315 Mtetra
.268 .624 .96 r
.49497 .50315 .496 .50405 .49785 .50467 .49682 .50345 Mtetra
.615 .722 .922 r
.49682 .50345 .49785 .50467 .4997 .50421 .49868 .50301 Mtetra
.78 .775 .848 r
.49868 .50301 .4997 .50421 .50157 .50266 .50054 .5016 Mtetra
.945 .764 .627 r
.50054 .5016 .50157 .50266 .50347 .49662 .50244 .49551 Mtetra
.969 .69 .447 r
.50244 .49551 .50347 .49662 .50655 .28914 .50559 .28783 Mtetra
.932 .744 .625 r
.50559 .28783 .50655 .28914 .50832 .28321 .50736 .28197 Mtetra
.775 .755 .835 r
.50736 .28197 .50832 .28321 .51007 .28186 .50911 .28065 Mtetra
.61 .707 .913 r
.50911 .28065 .51007 .28186 .51181 .28144 .51085 .28025 Mtetra
.479 .654 .936 r
.51085 .28025 .51181 .28144 .51355 .28143 .5126 .28027 Mtetra
.688 .747 .897 r
.5126 .28027 .51355 .28143 .5153 .28083 .51434 .27954 Mtetra
.681 .72 .879 r
.51434 .27954 .5153 .28083 .51705 .28017 .51609 .27883 Mtetra
.604 .68 .895 r
.51609 .27883 .51705 .28017 .51879 .27964 .51784 .27846 Mtetra
0 .343 .82 r
.51784 .27846 .51879 .27964 .52054 .27932 .51959 .27951 Mtetra
.837 .388 .154 r
.51959 .27951 .52054 .27932 .52229 .27943 .52134 .28262 Mtetra
.965 .677 .435 r
.52134 .28262 .52229 .27943 .52405 .28039 .52298 .48031 Mtetra
.547 .317 .517 r
.52298 .48031 .52405 .28039 .5258 .28763 .52485 .48912 Mtetra
.536 .308 .516 r
.52485 .48912 .5258 .28763 .52774 .48963 .52673 .49155 Mtetra
.6 .187 .231 r
.52673 .49155 .52774 .48963 .52962 .49336 .52861 .49257 Mtetra
.203 .608 .948 r
.52861 .49257 .52962 .49336 .5315 .49417 .53049 .49291 Mtetra
.592 .708 .924 r
.53049 .49291 .5315 .49417 .53339 .49382 .53237 .49256 Mtetra
.756 .763 .858 r
.53237 .49256 .53339 .49382 .53527 .49245 .53425 .49132 Mtetra
.932 .775 .664 r
.53425 .49132 .53527 .49245 .53713 .48767 .53612 .48657 Mtetra
.971 .689 .436 r
.53612 .48657 .53713 .48767 .53814 .28095 .53719 .2798 Mtetra
.955 .745 .58 r
.53719 .2798 .53814 .28095 .53987 .27298 .53892 .27184 Mtetra
.832 .782 .804 r
.53892 .27184 .53987 .27298 .54163 .27113 .54068 .26999 Mtetra
.665 .743 .908 r
.54068 .26999 .54163 .27113 .54339 .2705 .54245 .26936 Mtetra
.55 .696 .936 r
.54245 .26936 .54339 .2705 .54516 .27031 .54422 .26916 Mtetra
.719 .76 .885 r
.54422 .26916 .54516 .27031 .54692 .2694 .54598 .26825 Mtetra
.712 .757 .888 r
.54598 .26825 .54692 .2694 .54869 .26854 .54775 .26738 Mtetra
.566 .703 .933 r
.54775 .26738 .54869 .26854 .55046 .26828 .54952 .26713 Mtetra
.701 .241 0 r
.54952 .26713 .55046 .26828 .55226 .27111 .55132 .26998 Mtetra
.972 .681 .415 r
.55132 .26998 .55226 .27111 .55597 .47607 .55497 .47505 Mtetra
.935 .56 .203 r
.55497 .47505 .55597 .47607 .55795 .484 .55695 .48292 Mtetra
0 .309 .786 r
.55695 .48292 .55795 .484 .55986 .48505 .55886 .48409 Mtetra
.589 .771 .966 r
.55886 .48409 .55986 .48505 .56177 .48457 .56077 .48367 Mtetra
.777 .838 .898 r
.56077 .48367 .56177 .48457 .56366 .48345 .56266 .48241 Mtetra
.873 .813 .788 r
.56266 .48241 .56366 .48345 .56556 .48238 .56455 .48004 Mtetra
.862 .689 .666 r
.56455 .48004 .56556 .48238 .56746 .48104 .56641 .47577 Mtetra
.933 .665 .506 r
.56641 .47577 .56746 .48104 .56934 .47888 .56797 .44903 Mtetra
.938 .65 .467 r
.56797 .44903 .56934 .47888 .57116 .47223 .56735 .26613 Mtetra
.539 .315 .523 r
.56735 .26613 .57116 .47223 .57008 .26726 .56909 .2625 Mtetra
.685 .513 .647 r
.56909 .2625 .57008 .26726 .57179 .26199 .57085 .26034 Mtetra
.729 .689 .812 r
.57085 .26034 .57179 .26199 .57356 .2602 .57263 .25919 Mtetra
.666 .774 .93 r
.57263 .25919 .57356 .2602 .57534 .25951 .57442 .25854 Mtetra
.61 .764 .953 r
.57442 .25854 .57534 .25951 .57713 .25919 .57621 .25811 Mtetra
.725 .777 .894 r
.57621 .25811 .57713 .25919 .57892 .25832 .57799 .25717 Mtetra
.724 .765 .885 r
.57799 .25717 .57892 .25832 .5807 .25739 .57977 .25624 Mtetra
.592 .716 .93 r
.57977 .25624 .5807 .25739 .58249 .25705 .58157 .25589 Mtetra
.582 .12 0 r
.58157 .25589 .58249 .25705 .58434 .25949 .58342 .25832 Mtetra
.973 .68 .402 r
.58342 .25832 .58434 .25949 .59022 .4641 .58923 .46297 Mtetra
.939 .57 .201 r
.58923 .46297 .59022 .4641 .59233 .47306 .59134 .47194 Mtetra
0 .159 .669 r
.59134 .47194 .59233 .47306 .5943 .47467 .59331 .47355 Mtetra
.538 .717 .955 r
.59331 .47355 .5943 .47467 .59623 .47445 .59524 .47334 Mtetra
.768 .797 .877 r
.59524 .47334 .59623 .47445 .59814 .47319 .59716 .47207 Mtetra
.923 .793 .7 r
.59716 .47207 .59814 .47319 .6 .46938 .59901 .46826 Mtetra
.975 .687 .413 r
.59901 .46826 .6 .46938 .59723 .2683 .5963 .26697 Mtetra
.97 .72 .504 r
.5963 .26697 .59723 .2683 .59869 .25316 .59777 .25198 Mtetra
.876 .785 .757 r
.59777 .25198 .59869 .25316 .60045 .25064 .59953 .24945 Mtetra
.681 .746 .9 r
.59953 .24945 .60045 .25064 .60225 .24992 .60133 .24873 Mtetra
.554 .693 .932 r
.60133 .24873 .60225 .24992 .60406 .24971 .60315 .24852 Mtetra
.603 .713 .922 r
.60315 .24852 .60406 .24971 .60587 .24933 .60496 .24813 Mtetra
.668 .739 .903 r
.60496 .24813 .60587 .24933 .60768 .24867 .60676 .24747 Mtetra
.679 .742 .899 r
.60676 .24747 .60768 .24867 .60948 .24798 .60857 .24676 Mtetra
.753 .764 .861 r
.60857 .24676 .60948 .24798 .61128 .24687 .61036 .24561 Mtetra
.757 .757 .852 r
.61036 .24561 .61128 .24687 .61307 .24573 .61216 .24441 Mtetra
.66 .714 .888 r
.61216 .24441 .61307 .24573 .61489 .24515 .61397 .24378 Mtetra
0 .211 .735 r
.61397 .24378 .61489 .24515 .61677 .24682 .61585 .24535 Mtetra
.961 .626 .271 r
.61585 .24535 .61677 .24682 .62445 .43835 .61816 .26121 Mtetra
0 0 .336 r
.61816 .26121 .62445 .43835 .62711 .46135 .62614 .46011 Mtetra
0 0 .533 r
.62614 .46011 .62711 .46135 .62915 .46351 .62818 .46236 Mtetra
.495 .691 .955 r
.62818 .46236 .62915 .46351 .63111 .46342 .63014 .46228 Mtetra
.754 .794 .885 r
.63014 .46228 .63111 .46342 .63304 .46224 .63208 .4611 Mtetra
.917 .799 .714 r
.63208 .4611 .63304 .46224 .6349 .45873 .63393 .45758 Mtetra
.978 .708 .448 r
.63393 .45758 .6349 .45873 .63596 .43197 .63492 .4284 Mtetra
.974 .682 .404 r
.63492 .4284 .63596 .43197 .63131 .24182 .63041 .24062 Mtetra
.894 .787 .735 r
.63041 .24062 .63131 .24182 .63306 .23892 .63215 .23773 Mtetra
.704 .755 .892 r
.63215 .23773 .63306 .23892 .63487 .23808 .63397 .23688 Mtetra
.587 .709 .928 r
.63397 .23688 .63487 .23808 .63671 .23774 .63581 .23655 Mtetra
.666 .742 .907 r
.63581 .23655 .63671 .23774 .63853 .23709 .63763 .2359 Mtetra
.733 .765 .879 r
.63763 .2359 .63853 .23709 .64035 .23607 .63945 .23488 Mtetra
.636 .73 .916 r
.63945 .23488 .64035 .23607 .64218 .23555 .64128 .23436 Mtetra
0 .282 .78 r
.64128 .23436 .64218 .23555 .64408 .23687 .64318 .23568 Mtetra
.938 .574 .185 r
.64318 .23568 .64408 .23687 .64633 .24674 .64543 .24555 Mtetra
.975 .675 .374 r
.64543 .24555 .64633 .24674 .6564 .45095 .65544 .44981 Mtetra
0 0 .513 r
.65544 .44981 .6564 .45095 .65848 .45322 .65753 .45208 Mtetra
.629 .756 .938 r
.65753 .45208 .65848 .45322 .66046 .45268 .6595 .45154 Mtetra
.769 .8 .879 r
.6595 .45154 .66046 .45268 .6624 .45138 .66144 .45024 Mtetra
.782 .803 .87 r
.66144 .45024 .6624 .45138 .66434 .44999 .66338 .44885 Mtetra
.73 .791 .9 r
.66338 .44885 .66434 .44999 .66629 .44895 .66534 .44781 Mtetra
.716 .786 .907 r
.66534 .44781 .66629 .44895 .66825 .44799 .6673 .44685 Mtetra
.656 .766 .931 r
.6673 .44685 .66825 .44799 .67022 .44733 .66927 .44619 Mtetra
.563 .727 .951 r
.66927 .44619 .67022 .44733 .67221 .44703 .67126 .44588 Mtetra
.534 .714 .955 r
.67126 .44588 .67221 .44703 .67421 .44682 .67326 .44568 Mtetra
.442 .667 .958 r
.67326 .44568 .67421 .44682 .67622 .44689 .67527 .44575 Mtetra
.414 .652 .957 r
.67527 .44575 .67622 .44689 .67824 .44703 .67729 .44589 Mtetra
.629 .755 .938 r
.67729 .44589 .67824 .44703 .68022 .44649 .67928 .44534 Mtetra
.89 .812 .765 r
.67928 .44534 .68022 .44649 .68211 .44378 .68116 .44263 Mtetra
.981 .722 .465 r
.68116 .44263 .68211 .44378 .68324 .42561 .6823 .42447 Mtetra
.977 .682 .379 r
.6823 .42447 .68324 .42561 .67541 .22655 .67453 .22535 Mtetra
.912 .79 .713 r
.67453 .22535 .67541 .22655 .67714 .22329 .67625 .22209 Mtetra
.709 .759 .891 r
.67625 .22209 .67714 .22329 .67898 .22241 .67809 .2212 Mtetra
.59 .71 .927 r
.67809 .2212 .67898 .22241 .68084 .22206 .67996 .22085 Mtetra
.626 .727 .919 r
.67996 .22085 .68084 .22206 .68271 .22157 .68183 .22036 Mtetra
.734 .767 .879 r
.68183 .22036 .68271 .22157 .68454 .22054 .68366 .21933 Mtetra
.645 .734 .914 r
.68366 .21933 .68454 .22054 .6864 .21996 .68552 .21875 Mtetra
.099 .424 .869 r
.68552 .21875 .6864 .21996 .68835 .22091 .68747 .2197 Mtetra
.909 .527 .098 r
.68747 .2197 .68835 .22091 .69068 .22899 .6898 .22777 Mtetra
.975 .671 .352 r
.6898 .22777 .69068 .22899 .70395 .4358 .70302 .43463 Mtetra
.595 .133 0 r
.70302 .43463 .70395 .4358 .70615 .43874 .70521 .43757 Mtetra
.55 .719 .952 r
.70521 .43757 .70615 .43874 .70817 .43848 .70724 .43731 Mtetra
.709 .783 .91 r
.70724 .43731 .70817 .43848 .71016 .43755 .70923 .43638 Mtetra
.692 .776 .916 r
.70923 .43638 .71016 .43755 .71215 .43671 .71122 .43553 Mtetra
.513 .697 .953 r
.71122 .43553 .71215 .43671 .71419 .43659 .71326 .4354 Mtetra
.652 .76 .928 r
.71326 .4354 .71419 .43659 .7162 .43594 .71527 .43475 Mtetra
.864 .813 .798 r
.71527 .43475 .7162 .43594 .71811 .43368 .71718 .43248 Mtetra
.978 .752 .527 r
.71718 .43248 .71811 .43368 .71958 .42404 .71865 .4227 Mtetra
.977 .678 .362 r
.71865 .4227 .71958 .42404 .709 .2158 .70813 .21453 Mtetra
.932 .783 .674 r
.70813 .21453 .709 .2158 .71067 .21178 .7098 .21053 Mtetra
.728 .761 .879 r
.7098 .21053 .71067 .21178 .71253 .21077 .71166 .20952 Mtetra
.603 .712 .921 r
.71166 .20952 .71253 .21077 .71442 .21036 .71355 .20912 Mtetra
.602 .712 .921 r
.71355 .20912 .71442 .21036 .71631 .20996 .71544 .20872 Mtetra
.74 .767 .874 r
.71544 .20872 .71631 .20996 .71816 .20888 .71729 .20764 Mtetra
.657 .737 .908 r
.71729 .20764 .71816 .20888 .72004 .20824 .71918 .20701 Mtetra
.234 .508 .906 r
.71918 .20701 .72004 .20824 .72201 .20892 .72114 .20768 Mtetra
.885 .495 .04 r
.72114 .20768 .72201 .20892 .72443 .2164 .72356 .21512 Mtetra
.975 .667 .334 r
.72356 .21512 .72443 .2164 .74014 .42432 .73923 .42313 Mtetra
.647 .194 0 r
.73923 .42313 .74014 .42432 .74244 .42776 .74153 .42658 Mtetra
.385 .63 .951 r
.74153 .42658 .74244 .42776 .74453 .428 .74361 .42682 Mtetra
.692 .779 .918 r
.74361 .42682 .74453 .428 .74654 .42715 .74563 .42597 Mtetra
.872 .819 .794 r
.74563 .42597 .74654 .42715 .74846 .4248 .74755 .42361 Mtetra
.977 .768 .555 r
.74755 .42361 .74846 .4248 .74999 .41696 .74908 .41576 Mtetra
.977 .675 .347 r
.74908 .41576 .74999 .41696 .73732 .20674 .73646 .2055 Mtetra
.95 .784 .64 r
.73646 .2055 .73732 .20674 .73893 .20203 .73807 .2008 Mtetra
.739 .769 .878 r
.73807 .2008 .73893 .20203 .74079 .20095 .73994 .19972 Mtetra
.604 .717 .924 r
.73994 .19972 .74079 .20095 .7427 .20053 .74185 .19931 Mtetra
.542 .689 .934 r
.74185 .19931 .7427 .20053 .74463 .20034 .74378 .19912 Mtetra
.662 .746 .912 r
.74378 .19912 .74463 .20034 .74653 .19966 .74568 .19846 Mtetra
.672 .753 .912 r
.74568 .19846 .74653 .19966 .74842 .19894 .74758 .19775 Mtetra
.706 .768 .901 r
.74758 .19775 .74842 .19894 .75031 .19807 .74946 .19687 Mtetra
.785 .791 .858 r
.74946 .19687 .75031 .19807 .75216 .19674 .75131 .19549 Mtetra
.714 .76 .888 r
.75131 .19549 .75216 .19674 .75404 .19585 .75319 .19456 Mtetra
.459 .632 .929 r
.75319 .19456 .75404 .19585 .75601 .19599 .75515 .19467 Mtetra
.763 .35 0 r
.75515 .19467 .75601 .19599 .75836 .20105 .7575 .19967 Mtetra
.973 .662 .315 r
.7575 .19967 .75836 .20105 .77669 .41127 .77579 .41008 Mtetra
.75 .314 0 r
.77579 .41008 .77669 .41127 .77915 .4159 .77826 .41475 Mtetra
.309 .594 .945 r
.77826 .41475 .77915 .4159 .78129 .41632 .7804 .41517 Mtetra
.669 .779 .932 r
.7804 .41517 .78129 .41632 .78334 .41558 .78245 .41442 Mtetra
.857 .827 .818 r
.78245 .41442 .78334 .41558 .78528 .41348 .78439 .41231 Mtetra
.979 .778 .564 r
.78439 .41231 .78528 .41348 .78681 .40633 .78592 .40519 Mtetra
.976 .671 .329 r
.78592 .40519 .78681 .40633 .77165 .1952 .77081 .19398 Mtetra
.964 .784 .612 r
.77081 .19398 .77165 .1952 .77319 .18991 .77235 .18867 Mtetra
.756 .778 .871 r
.77235 .18867 .77319 .18991 .77506 .18871 .77422 .18747 Mtetra
.623 .726 .92 r
.77422 .18747 .77506 .18871 .77699 .18821 .77616 .18697 Mtetra
.55 .691 .933 r
.77616 .18697 .77699 .18821 .77895 .18799 .77811 .18676 Mtetra
.75 .777 .875 r
.77811 .18676 .77895 .18799 .78083 .18684 .77999 .1856 Mtetra
.676 .749 .906 r
.77999 .1856 .78083 .18684 .78274 .1861 .78191 .18487 Mtetra
.432 .629 .937 r
.78191 .18487 .78274 .1861 .78474 .18624 .78391 .18503 Mtetra
.823 .416 0 r
.78391 .18503 .78474 .18624 .78723 .19205 .78643 .19124 Mtetra
.971 .657 .3 r
.78643 .19124 .78723 .19205 .80765 .40234 .80681 .40155 Mtetra
.752 .285 0 r
.80681 .40155 .80765 .40234 .81016 .40663 .8093 .40566 Mtetra
.436 .708 .98 r
.8093 .40566 .81016 .40663 .81231 .40684 .81144 .40564 Mtetra
.703 .786 .916 r
.81144 .40564 .81231 .40684 .81438 .406 .81349 .40471 Mtetra
.807 .801 .847 r
.81349 .40471 .81438 .406 .81635 .40416 .81548 .40304 Mtetra
.863 .84 .821 r
.81548 .40304 .81635 .40416 .8181 .39982 .81743 .40091 Mtetra
.649 .811 .376 r
.81743 .40091 .8181 .39982 .8179 .37432 .81927 .39764 Mtetra
.414 .199 .475 r
.81927 .39764 .8179 .37432 .80237 .18311 .8208 .39101 Mtetra
0 0 .025 r
.15748 .60678 .15953 .59943 .1819 .40385 .15979 .59998 Mtetra
0 0 .084 r
.15979 .59998 .1819 .40385 .18394 .39863 .18259 .40015 Mtetra
.986 .898 .629 r
.18259 .40015 .18394 .39863 .1857 .39607 .18461 .39512 Mtetra
.771 .768 .85 r
.18461 .39512 .1857 .39607 .18728 .39515 .18622 .39396 Mtetra
.647 .701 .886 r
.18622 .39396 .18728 .39515 .18882 .39466 .18776 .39347 Mtetra
.553 .671 .915 r
.18776 .39347 .18882 .39466 .19034 .39437 .18927 .39332 Mtetra
.751 .75 .851 r
.18927 .39332 .19034 .39437 .19195 .39331 .19087 .39227 Mtetra
.701 .744 .885 r
.19087 .39227 .19195 .39331 .19351 .39258 .19244 .39155 Mtetra
.497 .68 .947 r
.19244 .39155 .19351 .39258 .19501 .39253 .19394 .3915 Mtetra
.927 .545 .245 r
.19394 .3915 .19501 .39253 .19609 .39658 .19502 .39552 Mtetra
.939 .683 .523 r
.19502 .39552 .19609 .39658 .17723 .59681 .17608 .59578 Mtetra
.937 .585 .325 r
.17608 .59578 .17723 .59681 .17827 .60229 .17712 .60131 Mtetra
.261 .594 .949 r
.17712 .60131 .17827 .60229 .17984 .60261 .17868 .60164 Mtetra
.668 .764 .922 r
.17868 .60164 .17984 .60261 .1815 .602 .18034 .60103 Mtetra
.745 .776 .878 r
.18034 .60103 .1815 .602 .18319 .60102 .18204 .60002 Mtetra
.458 .686 .964 r
.18204 .60002 .18319 .60102 .18478 .60114 .18364 .60002 Mtetra
.576 .707 .931 r
.18364 .60002 .18478 .60114 .1864 .601 .18527 .59976 Mtetra
.728 .729 .851 r
.18527 .59976 .1864 .601 .18809 .60013 .18697 .59877 Mtetra
.888 .72 .668 r
.18697 .59877 .18809 .60013 .19016 .59541 .18907 .59377 Mtetra
.939 .686 .529 r
.18907 .59377 .19016 .59541 .21139 .39402 .21039 .39223 Mtetra
.889 .692 .631 r
.21039 .39223 .21139 .39402 .21363 .38645 .21257 .38538 Mtetra
.795 .751 .813 r
.21257 .38538 .21363 .38645 .21529 .38493 .21422 .38391 Mtetra
.647 .736 .914 r
.21422 .38391 .21529 .38493 .21685 .38443 .21578 .38342 Mtetra
.507 .691 .951 r
.21578 .38342 .21685 .38443 .21836 .38435 .2173 .38334 Mtetra
.732 .758 .873 r
.2173 .38334 .21836 .38435 .21997 .38342 .21889 .38244 Mtetra
.704 .758 .895 r
.21889 .38244 .21997 .38342 .22155 .38267 .22048 .38171 Mtetra
.504 .701 .958 r
.22048 .38171 .22155 .38267 .22307 .38259 .222 .38162 Mtetra
.914 .513 .196 r
.222 .38162 .22307 .38259 .22423 .38643 .22318 .38523 Mtetra
.942 .684 .516 r
.22318 .38523 .22423 .38643 .20699 .58769 .20591 .58595 Mtetra
.953 .602 .271 r
.20591 .58595 .20699 .58769 .20809 .59324 .20698 .59188 Mtetra
.25 .504 .901 r
.20698 .59188 .20809 .59324 .20967 .59366 .20855 .59243 Mtetra
.672 .719 .885 r
.20855 .59243 .20967 .59366 .21136 .59288 .21023 .59178 Mtetra
.753 .759 .857 r
.21023 .59178 .21136 .59288 .2131 .59161 .21195 .59066 Mtetra
.568 .745 .96 r
.21195 .59066 .2131 .59161 .21475 .5913 .2136 .59038 Mtetra
.6 .76 .955 r
.2136 .59038 .21475 .5913 .21641 .59095 .21526 .59001 Mtetra
.757 .787 .877 r
.21526 .59001 .21641 .59095 .21813 .58987 .21699 .58892 Mtetra
.91 .747 .667 r
.21699 .58892 .21813 .58987 .22025 .58444 .21907 .5838 Mtetra
.943 .688 .522 r
.21907 .5838 .22025 .58444 .23991 .38164 .23877 .38141 Mtetra
.945 .771 .636 r
.23877 .38141 .23991 .38164 .24196 .37573 .24087 .37507 Mtetra
.838 .826 .836 r
.24087 .37507 .24196 .37573 .24363 .37422 .24254 .37346 Mtetra
.641 .794 .956 r
.24254 .37346 .24363 .37422 .24519 .37384 .24412 .37296 Mtetra
.484 .715 .972 r
.24412 .37296 .24519 .37384 .24672 .37388 .24566 .37288 Mtetra
.606 .732 .934 r
.24566 .37288 .24672 .37388 .24828 .37358 .24722 .37253 Mtetra
.647 .734 .913 r
.24722 .37253 .24828 .37358 .24985 .37308 .2488 .37204 Mtetra
.653 .737 .911 r
.2488 .37204 .24985 .37308 .25144 .37252 .25038 .37152 Mtetra
.681 .753 .906 r
.25038 .37152 .25144 .37252 .25305 .37168 .25197 .37089 Mtetra
.686 .8 .936 r
.25197 .37089 .25305 .37168 .25466 .37086 .25356 .37024 Mtetra
.657 .835 .968 r
.25356 .37024 .25466 .37086 .25624 .37032 .25515 .36967 Mtetra
.67 .828 .96 r
.25515 .36967 .25624 .37032 .25775 .37068 .25674 .36906 Mtetra
.61 .626 .842 r
.25674 .36906 .25775 .37068 .25917 .37215 .25832 .36872 Mtetra
.505 .428 .703 r
.25832 .36872 .25917 .37215 .26038 .37623 .25983 .36901 Mtetra
.199 .124 .541 r
.25983 .36901 .26038 .37623 .24573 .57319 .26108 .3727 Mtetra
0 0 .171 r
.26108 .3727 .24573 .57319 .24692 .57876 .24615 .57344 Mtetra
0 0 .317 r
.24615 .57344 .24692 .57876 .2484 .58084 .24734 .57902 Mtetra
.186 .384 .825 r
.24734 .57902 .2484 .58084 .25002 .58125 .24892 .57994 Mtetra
.615 .691 .898 r
.24892 .57994 .25002 .58125 .2517 .58093 .2506 .57955 Mtetra
.699 .707 .854 r
.2506 .57955 .2517 .58093 .2534 .58032 .25232 .57872 Mtetra
.667 .665 .839 r
.25232 .57872 .2534 .58032 .2551 .57976 .25403 .57804 Mtetra
.644 .641 .832 r
.25403 .57804 .2551 .57976 .2568 .57923 .25573 .57748 Mtetra
.647 .639 .828 r
.25573 .57748 .2568 .57923 .25851 .57865 .25744 .57689 Mtetra
.649 .64 .827 r
.25744 .57689 .25851 .57865 .26022 .57798 .25915 .5763 Mtetra
.652 .649 .835 r
.25915 .5763 .26022 .57798 .26194 .57726 .26085 .57569 Mtetra
.654 .665 .848 r
.26085 .57569 .26194 .57726 .26365 .57655 .26256 .5751 Mtetra
.643 .678 .868 r
.26256 .5751 .26365 .57655 .26535 .57608 .26427 .57457 Mtetra
.639 .668 .862 r
.26427 .57457 .26535 .57608 .26705 .57566 .26597 .57406 Mtetra
.648 .659 .847 r
.26597 .57406 .26705 .57566 .26877 .57498 .26768 .57349 Mtetra
.692 .689 .842 r
.26768 .57349 .26877 .57498 .27056 .57326 .26941 .57267 Mtetra
.751 .863 .931 r
.26941 .57267 .27056 .57326 .27246 .57024 .27116 .57167 Mtetra
0 0 0 r
.27116 .57167 .27246 .57024 .27448 .56548 .2729 .57065 Mtetra
.473 .169 .368 r
.2729 .57065 .27448 .56548 .2764 .56208 .2746 .57026 Mtetra
.507 .23 .429 r
.2746 .57026 .2764 .56208 .27805 .56234 .27629 .57008 Mtetra
.47 .194 .411 r
.27629 .57008 .27805 .56234 .27974 .56205 .27802 .56931 Mtetra
.202 0 .302 r
.27802 .56931 .27974 .56205 .29499 .37323 .27996 .56565 Mtetra
0 0 .16 r
.27996 .56565 .29499 .37323 .29749 .36037 .29601 .36539 Mtetra
.883 .818 .341 r
.29601 .36539 .29749 .36037 .29933 .35662 .29825 .35608 Mtetra
.893 .833 .781 r
.29825 .35608 .29933 .35662 .30103 .35485 .3 .35372 Mtetra
.699 .736 .88 r
.3 .35372 .30103 .35485 .30266 .35408 .30162 .35297 Mtetra
.573 .701 .928 r
.30162 .35297 .30266 .35408 .30425 .35383 .30322 .35273 Mtetra
.538 .689 .936 r
.30322 .35273 .30425 .35383 .30579 .35439 .3048 .35258 Mtetra
.57 .585 .829 r
.3048 .35258 .30579 .35439 .30725 .35612 .3064 .35242 Mtetra
.558 .453 .691 r
.3064 .35242 .30725 .35612 .30857 .35992 .30798 .3523 Mtetra
.573 .399 .607 r
.30798 .3523 .30857 .35992 .30981 .36509 .30961 .3517 Mtetra
.563 .365 .571 r
.30961 .3517 .30981 .36509 .31136 .36565 .31125 .35088 Mtetra
.545 .348 .565 r
.31125 .35088 .31136 .36565 .31251 .37236 .31285 .35062 Mtetra
.481 .287 .54 r
.31285 .35062 .31251 .37236 .30198 .55608 .31426 .35318 Mtetra
0 0 .215 r
.31426 .35318 .30198 .55608 .30334 .56115 .30262 .55416 Mtetra
0 0 .363 r
.30262 .55416 .30334 .56115 .30489 .56338 .30387 .56094 Mtetra
.149 .282 .745 r
.30387 .56094 .30489 .56338 .30655 .56395 .30548 .56234 Mtetra
.605 .644 .862 r
.30548 .56234 .30655 .56395 .30828 .56351 .3072 .56199 Mtetra
.692 .688 .842 r
.3072 .56199 .30828 .56351 .31002 .56278 .30895 .56116 Mtetra
.682 .672 .834 r
.30895 .56116 .31002 .56278 .31177 .56208 .3107 .56037 Mtetra
.643 .646 .838 r
.3107 .56037 .31177 .56208 .3135 .56152 .31244 .55981 Mtetra
.644 .646 .837 r
.31244 .55981 .3135 .56152 .31524 .56096 .31418 .55924 Mtetra
.643 .645 .837 r
.31418 .55924 .31524 .56096 .31698 .5604 .31592 .55867 Mtetra
.641 .643 .837 r
.31592 .55867 .31698 .5604 .31872 .55985 .31766 .55812 Mtetra
.31766 .55812 .31872 .55985 .32046 .5593 .3194 .55757 Mtetra
.64 .643 .837 r
.3194 .55757 .32046 .5593 .32221 .55875 .32115 .55702 Mtetra
.64 .642 .837 r
.32115 .55702 .32221 .55875 .32395 .5582 .32289 .55647 Mtetra
.32289 .55647 .32395 .5582 .32569 .55765 .32463 .55592 Mtetra
.638 .642 .838 r
.32463 .55592 .32569 .55765 .32744 .55711 .32638 .55539 Mtetra
.637 .642 .838 r
.32638 .55539 .32744 .55711 .32918 .55658 .32813 .55485 Mtetra
.64 .643 .837 r
.32813 .55485 .32918 .55658 .33093 .55602 .32987 .5543 Mtetra
.609 .631 .848 r
.32987 .5543 .33093 .55602 .33268 .55551 .33161 .55393 Mtetra
.592 .642 .869 r
.33161 .55393 .33268 .55551 .33443 .555 .33335 .55363 Mtetra
.687 .709 .865 r
.33335 .55363 .33443 .555 .33619 .55419 .33511 .55286 Mtetra
.841 .745 .758 r
.33511 .55286 .33619 .55419 .33802 .55239 .33697 .55044 Mtetra
.909 .701 .61 r
.33697 .55044 .33802 .55239 .33995 .54857 .33915 .54219 Mtetra
.949 .683 .499 r
.33915 .54219 .33995 .54857 .34215 .5397 .35195 .3396 Mtetra
.54 .316 .524 r
.35195 .3396 .34215 .5397 .35436 .34491 .35377 .33579 Mtetra
.579 .394 .595 r
.35377 .33579 .35436 .34491 .35606 .34336 .35544 .33488 Mtetra
.555 .379 .598 r
.35544 .33488 .35606 .34336 .35766 .34378 .35707 .33459 Mtetra
.548 .37 .592 r
.35707 .33459 .35766 .34378 .3592 .3455 .3587 .33441 Mtetra
.556 .368 .581 r
.3587 .33441 .3592 .3455 .36072 .34743 .36035 .33393 Mtetra
.554 .359 .57 r
.36035 .33393 .36072 .34743 .36241 .34632 .362 .33339 Mtetra
.562 .366 .573 r
.362 .33339 .36241 .34632 .36436 .34011 .36367 .33262 Mtetra
.595 .417 .61 r
.36367 .33262 .36436 .34011 .36624 .33501 .36535 .33156 Mtetra
.649 .521 .694 r
.36535 .33156 .36624 .33501 .36802 .33203 .36702 .33053 Mtetra
.696 .683 .833 r
.36702 .33053 .36802 .33203 .36973 .33037 .36869 .3297 Mtetra
.645 .829 .971 r
.36869 .3297 .36973 .33037 .37138 .32979 .37035 .32914 Mtetra
.618 .827 .98 r
.37035 .32914 .37138 .32979 .37303 .3295 .372 .32865 Mtetra
.641 .786 .952 r
.372 .32865 .37303 .3295 .37467 .3292 .37366 .32814 Mtetra
.669 .747 .909 r
.37366 .32814 .37467 .3292 .37633 .32865 .37532 .32753 Mtetra
.672 .737 .899 r
.37532 .32753 .37633 .32865 .37799 .32804 .37699 .3269 Mtetra
.702 .743 .883 r
.37699 .3269 .37799 .32804 .37967 .32725 .37866 .32612 Mtetra
.735 .752 .866 r
.37866 .32612 .37967 .32725 .38135 .32625 .38034 .32514 Mtetra
.656 .735 .908 r
.38034 .32514 .38135 .32625 .38302 .32554 .382 .32459 Mtetra
0 .422 .858 r
.382 .32459 .38302 .32554 .38465 .32566 .38361 .32531 Mtetra
.924 .555 .302 r
.38361 .32531 .38465 .32566 .3862 .32782 .385 .33113 Mtetra
.953 .679 .479 r
.385 .33113 .3862 .32782 .38755 .33456 .37776 .53381 Mtetra
.538 .309 .516 r
.37776 .53381 .38755 .33456 .38081 .52976 .37936 .53735 Mtetra
.506 .224 .42 r
.37936 .53735 .38081 .52976 .38257 .52945 .38112 .53719 Mtetra
.469 .192 .411 r
.38112 .53719 .38257 .52945 .38438 .52818 .38292 .53636 Mtetra
.474 .2 .417 r
.38292 .53636 .38438 .52818 .38607 .52969 .38471 .53556 Mtetra
.505 .207 .394 r
.38471 .53556 .38607 .52969 .38767 .5337 .38647 .5355 Mtetra
.424 .003 .133 r
.38647 .5355 .38767 .5337 .38934 .53582 .38824 .53543 Mtetra
.38 .797 .976 r
.38824 .53543 .38934 .53582 .39107 .53673 .39001 .53522 Mtetra
.623 .669 .873 r
.39001 .53522 .39107 .53673 .39284 .53656 .3918 .53477 Mtetra
.636 .637 .834 r
.3918 .53477 .39284 .53656 .39463 .53607 .39359 .53422 Mtetra
.626 .626 .831 r
.39359 .53422 .39463 .53607 .39642 .53547 .39538 .53373 Mtetra
.578 .618 .856 r
.39538 .53373 .39642 .53547 .39821 .535 .39716 .5335 Mtetra
.663 .686 .861 r
.39716 .5335 .39821 .535 .40001 .53423 .39896 .53283 Mtetra
.805 .74 .792 r
.39896 .53283 .40001 .53423 .40184 .53274 .4008 .531 Mtetra
.91 .715 .627 r
.4008 .531 .40184 .53274 .40374 .52922 .40281 .52438 Mtetra
.957 .686 .482 r
.40281 .52438 .40374 .52922 .40578 .52186 .41195 .31969 Mtetra
.543 .318 .524 r
.41195 .31969 .40578 .52186 .4145 .32399 .41379 .31465 Mtetra
.583 .395 .593 r
.41379 .31465 .4145 .32399 .41621 .32285 .41549 .31361 Mtetra
.557 .377 .593 r
.41549 .31361 .41621 .32285 .41787 .32292 .41717 .31322 Mtetra
.553 .371 .589 r
.41717 .31322 .41787 .32292 .41962 .32084 .41885 .31291 Mtetra
.591 .41 .606 r
.41885 .31291 .41962 .32084 .42146 .31569 .42056 .31187 Mtetra
.639 .504 .681 r
.42056 .31187 .42146 .31569 .42323 .3126 .42226 .31084 Mtetra
.694 .653 .805 r
.42226 .31084 .42323 .3126 .42497 .31063 .42396 .30993 Mtetra
.667 .833 .963 r
.42396 .30993 .42497 .31063 .42666 .30982 .42566 .30929 Mtetra
.622 .863 .988 r
.42566 .30929 .42666 .30982 .42835 .30931 .42735 .30874 Mtetra
.616 .849 .987 r
.42735 .30874 .42835 .30931 .43004 .30896 .42904 .30821 Mtetra
.642 .816 .966 r
.42904 .30821 .43004 .30896 .43173 .30853 .43073 .30766 Mtetra
.652 .789 .947 r
.43073 .30766 .43173 .30853 .43342 .3081 .43243 .3071 Mtetra
.663 .763 .924 r
.43243 .3071 .43342 .3081 .43512 .30757 .43413 .3065 Mtetra
.681 .753 .906 r
.43413 .3065 .43512 .30757 .43682 .3068 .43583 .30582 Mtetra
.687 .774 .918 r
.43583 .30582 .43682 .3068 .43852 .30598 .43753 .30512 Mtetra
.697 .805 .932 r
.43753 .30512 .43852 .30598 .44023 .30514 .43924 .30438 Mtetra
.756 .835 .912 r
.43924 .30438 .44023 .30514 .44194 .30424 .44095 .30336 Mtetra
.683 .796 .934 r
.44095 .30336 .44194 .30424 .44364 .30356 .44265 .30267 Mtetra
.413 .688 .975 r
.44265 .30267 .44364 .30356 .44534 .30332 .44434 .30273 Mtetra
.856 .401 .052 r
.44434 .30273 .44534 .30332 .447 .30431 .44595 .30589 Mtetra
.961 .681 .458 r
.44595 .30589 .447 .30431 .44863 .30674 .44268 .50706 Mtetra
.547 .316 .517 r
.44268 .50706 .44863 .30674 .45009 .31675 .44428 .51553 Mtetra
.533 .305 .515 r
.44428 .51553 .45009 .31675 .44725 .51191 .44607 .5163 Mtetra
.486 .165 .348 r
.44607 .5163 .44725 .51191 .44898 .51519 .44788 .51615 Mtetra
.106 0 0 r
.44788 .51615 .44898 .51519 .45077 .51644 .44971 .51558 Mtetra
.594 .788 .973 r
.44971 .51558 .45077 .51644 .45258 .51627 .45154 .51515 Mtetra
.635 .747 .929 r
.45154 .51515 .45258 .51627 .45441 .51571 .45337 .51463 Mtetra
.637 .754 .933 r
.45337 .51463 .45441 .51571 .45625 .51504 .4552 .51409 Mtetra
.425 .694 .976 r
.4552 .51409 .45625 .51504 .45806 .51511 .45702 .51412 Mtetra
.586 .757 .96 r
.45702 .51412 .45806 .51511 .45989 .51489 .45885 .51375 Mtetra
.752 .776 .873 r
.45885 .51375 .45989 .51489 .46173 .51413 .46069 .5126 Mtetra
.91 .735 .653 r
.46069 .5126 .46173 .51413 .4636 .51146 .46261 .50743 Mtetra
.963 .687 .464 r
.46261 .50743 .4636 .51146 .46552 .50641 .46815 .30281 Mtetra
.547 .322 .524 r
.46815 .30281 .46552 .50641 .4708 .30618 .47 .2953 Mtetra
.594 .397 .584 r
.47 .2953 .4708 .30618 .47265 .29852 .47174 .29368 Mtetra
.609 .46 .655 r
.47174 .29368 .47265 .29852 .47441 .29544 .47347 .29283 Mtetra
.61 .541 .752 r
.47347 .29283 .47441 .29544 .47616 .29355 .47519 .29236 Mtetra
.671 .73 .894 r
.47519 .29236 .47616 .29355 .47789 .29268 .47691 .29171 Mtetra
.656 .771 .934 r
.47691 .29171 .47789 .29268 .47961 .29213 .47864 .29113 Mtetra
.65 .762 .932 r
.47864 .29113 .47961 .29213 .48133 .29173 .48036 .29057 Mtetra
.748 .759 .861 r
.48036 .29057 .48133 .29173 .48307 .29079 .4821 .28948 Mtetra
.692 .718 .869 r
.4821 .28948 .48307 .29079 .4848 .29004 .48383 .28871 Mtetra
.547 .656 .907 r
.48383 .28871 .4848 .29004 .48652 .28969 .48555 .28856 Mtetra
.814 .368 0 r
.48555 .28856 .48652 .28969 .48823 .29092 .48724 .29192 Mtetra
.965 .681 .443 r
.48724 .29192 .48823 .29092 .48992 .2944 .48662 .49522 Mtetra
.544 .314 .517 r
.48662 .49522 .48992 .2944 .48953 .49317 .48838 .50243 Mtetra
.548 .27 .445 r
.48838 .50243 .48953 .49317 .4913 .50002 .49022 .50317 Mtetra
.453 .1 .275 r
.49022 .50317 .4913 .50002 .49313 .50223 .49208 .50293 Mtetra
0 0 0 r
.49208 .50293 .49313 .50223 .49497 .50315 .49394 .50224 Mtetra
.441 .715 .982 r
.49394 .50224 .49497 .50315 .49682 .50345 .49579 .50221 Mtetra
.612 .718 .921 r
.49579 .50221 .49682 .50345 .49868 .50301 .49765 .50178 Mtetra
.759 .766 .859 r
.49765 .50178 .49868 .50301 .50054 .5016 .49952 .50054 Mtetra
.942 .767 .637 r
.49952 .50054 .50054 .5016 .50244 .49551 .50141 .49484 Mtetra
.969 .69 .447 r
.50141 .49484 .50244 .49551 .50559 .28783 .50462 .28749 Mtetra
.974 .798 .603 r
.50462 .28749 .50559 .28783 .50736 .28197 .5064 .28121 Mtetra
.819 .847 .87 r
.5064 .28121 .50736 .28197 .50911 .28065 .50815 .27976 Mtetra
.631 .785 .956 r
.50815 .27976 .50911 .28065 .51085 .28025 .5099 .27925 Mtetra
.502 .706 .962 r
.5099 .27925 .51085 .28025 .5126 .28027 .51164 .27915 Mtetra
.721 .762 .885 r
.51164 .27915 .5126 .28027 .51434 .27954 .51339 .27824 Mtetra
.689 .721 .874 r
.51339 .27824 .51434 .27954 .51609 .27883 .51514 .27748 Mtetra
.559 .66 .904 r
.51514 .27748 .51609 .27883 .51784 .27846 .51689 .27729 Mtetra
.706 .246 0 r
.51689 .27729 .51784 .27846 .51959 .27951 .51863 .28007 Mtetra
.968 .681 .431 r
.51863 .28007 .51959 .27951 .52134 .28262 .52009 .48213 Mtetra
.548 .317 .517 r
.52009 .48213 .52134 .28262 .52298 .48031 .52195 .49144 Mtetra
.557 .285 .459 r
.52195 .49144 .52298 .48031 .52485 .48912 .52383 .49255 Mtetra
.469 .124 .298 r
.52383 .49255 .52485 .48912 .52673 .49155 .52571 .49239 Mtetra
.038 0 0 r
.52571 .49239 .52673 .49155 .52861 .49257 .52759 .49175 Mtetra
.447 .74 .99 r
.52759 .49175 .52861 .49257 .53049 .49291 .52947 .49166 Mtetra
.593 .709 .924 r
.52947 .49166 .53049 .49291 .53237 .49256 .53136 .49129 Mtetra
.739 .759 .868 r
.53136 .49129 .53237 .49256 .53425 .49132 .53324 .49018 Mtetra
.931 .775 .665 r
.53324 .49018 .53425 .49132 .53612 .48657 .53511 .48547 Mtetra
.971 .689 .436 r
.53511 .48547 .53612 .48657 .53719 .2798 .53624 .27866 Mtetra
.955 .745 .58 r
.53624 .27866 .53719 .2798 .53892 .27184 .53798 .27069 Mtetra
.832 .783 .805 r
.53798 .27069 .53892 .27184 .54068 .26999 .53974 .26885 Mtetra
.666 .744 .908 r
.53974 .26885 .54068 .26999 .54245 .26936 .5415 .26821 Mtetra
.551 .697 .937 r
.5415 .26821 .54245 .26936 .54422 .26916 .54327 .26801 Mtetra
.719 .76 .885 r
.54327 .26801 .54422 .26916 .54598 .26825 .54504 .2671 Mtetra
.712 .757 .888 r
.54504 .2671 .54598 .26825 .54775 .26738 .54681 .26623 Mtetra
.566 .703 .933 r
.54681 .26623 .54775 .26738 .54952 .26713 .54858 .26598 Mtetra
.703 .243 0 r
.54858 .26598 .54952 .26713 .55132 .26998 .55038 .26883 Mtetra
.972 .681 .415 r
.55038 .26883 .55132 .26998 .55497 .47505 .55397 .47402 Mtetra
.935 .559 .2 r
.55397 .47402 .55497 .47505 .55695 .48292 .55594 .48184 Mtetra
0 .264 .751 r
.55594 .48184 .55695 .48292 .55886 .48409 .55786 .48312 Mtetra
.57 .762 .969 r
.55786 .48312 .55886 .48409 .56077 .48367 .55977 .48277 Mtetra
.795 .837 .884 r
.55977 .48277 .56077 .48367 .56266 .48241 .56166 .48138 Mtetra
.926 .796 .697 r
.56166 .48138 .56266 .48241 .56455 .48004 .56353 .47747 Mtetra
.972 .686 .429 r
.56353 .47747 .56455 .48004 .56641 .47577 .56302 .28042 Mtetra
.567 .337 .526 r
.56302 .28042 .56641 .47577 .56797 .44903 .5646 .26289 Mtetra
.538 .314 .523 r
.5646 .26289 .56797 .44903 .56735 .26613 .56635 .26033 Mtetra
.607 .444 .635 r
.56635 .26033 .56735 .26613 .56909 .2625 .56813 .2593 Mtetra
.608 .51 .718 r
.56813 .2593 .56909 .2625 .57085 .26034 .56992 .25875 Mtetra
.645 .662 .852 r
.56992 .25875 .57085 .26034 .57263 .25919 .5717 .25817 Mtetra
.655 .77 .934 r
.5717 .25817 .57263 .25919 .57442 .25854 .57349 .25758 Mtetra
.644 .776 .944 r
.57349 .25758 .57442 .25854 .57621 .25811 .57528 .25702 Mtetra
.735 .779 .888 r
.57528 .25702 .57621 .25811 .57799 .25717 .57706 .25602 Mtetra
.725 .764 .884 r
.57706 .25602 .57799 .25717 .57977 .25624 .57884 .25508 Mtetra
.594 .716 .929 r
.57884 .25508 .57977 .25624 .58157 .25589 .58064 .25472 Mtetra
.578 .117 0 r
.58064 .25472 .58157 .25589 .58342 .25832 .58249 .25714 Mtetra
.973 .68 .402 r
.58249 .25714 .58342 .25832 .58923 .46297 .58824 .4618 Mtetra
.939 .57 .2 r
.58824 .4618 .58923 .46297 .59134 .47194 .59035 .47082 Mtetra
0 .159 .669 r
.59035 .47082 .59134 .47194 .59331 .47355 .59232 .47243 Mtetra
.538 .717 .955 r
.59232 .47243 .59331 .47355 .59524 .47334 .59426 .47222 Mtetra
.768 .797 .877 r
.59426 .47222 .59524 .47334 .59716 .47207 .59617 .47094 Mtetra
.923 .793 .7 r
.59617 .47094 .59716 .47207 .59901 .46826 .59803 .46713 Mtetra
.975 .687 .413 r
.59803 .46713 .59901 .46826 .5963 .26697 .59537 .2656 Mtetra
.969 .72 .505 r
.59537 .2656 .5963 .26697 .59777 .25198 .59685 .25079 Mtetra
.876 .785 .757 r
.59685 .25079 .59777 .25198 .59953 .24945 .59861 .24826 Mtetra
.682 .745 .899 r
.59861 .24826 .59953 .24945 .60133 .24873 .60041 .24754 Mtetra
.557 .693 .931 r
.60041 .24754 .60133 .24873 .60315 .24852 .60223 .24732 Mtetra
.608 .715 .92 r
.60223 .24732 .60315 .24852 .60496 .24813 .60404 .24691 Mtetra
.672 .736 .898 r
.60404 .24691 .60496 .24813 .60676 .24747 .60585 .24623 Mtetra
.676 .734 .894 r
.60585 .24623 .60676 .24747 .60857 .24676 .60765 .24552 Mtetra
.737 .756 .867 r
.60765 .24552 .60857 .24676 .61036 .24561 .60945 .24447 Mtetra
.744 .776 .879 r
.60945 .24447 .61036 .24561 .61216 .24441 .61125 .24341 Mtetra
.629 .767 .946 r
.61125 .24341 .61216 .24441 .61397 .24378 .61306 .2429 Mtetra
0 .048 .542 r
.61306 .2429 .61397 .24378 .61585 .24535 .61495 .24462 Mtetra
.974 .677 .388 r
.61495 .24462 .61585 .24535 .61816 .26121 .62263 .43979 Mtetra
.567 .332 .518 r
.62263 .43979 .61816 .26121 .62614 .46011 .62517 .45904 Mtetra
0 0 .506 r
.62517 .45904 .62614 .46011 .62818 .46236 .6272 .46118 Mtetra
.497 .687 .952 r
.6272 .46118 .62818 .46236 .63014 .46228 .62917 .46111 Mtetra
.75 .786 .882 r
.62917 .46111 .63014 .46228 .63208 .4611 .63111 .45994 Mtetra
.916 .797 .715 r
.63111 .45994 .63208 .4611 .63393 .45758 .63296 .45642 Mtetra
.976 .685 .401 r
.63296 .45642 .63393 .45758 .63492 .4284 .62898 .27884 Mtetra
.624 .381 .529 r
.62898 .27884 .63492 .4284 .63041 .24062 .6295 .23942 Mtetra
.894 .787 .735 r
.6295 .23942 .63041 .24062 .63215 .23773 .63125 .23653 Mtetra
.703 .755 .892 r
.63125 .23653 .63215 .23773 .63397 .23688 .63307 .23569 Mtetra
.587 .709 .928 r
.63307 .23569 .63397 .23688 .63581 .23655 .6349 .23536 Mtetra
.666 .742 .907 r
.6349 .23536 .63581 .23655 .63763 .2359 .63673 .2347 Mtetra
.733 .765 .879 r
.63673 .2347 .63763 .2359 .63945 .23488 .63854 .23369 Mtetra
.636 .73 .916 r
.63854 .23369 .63945 .23488 .64128 .23436 .64038 .23316 Mtetra
0 .282 .78 r
.64038 .23316 .64128 .23436 .64318 .23568 .64228 .23448 Mtetra
.938 .574 .185 r
.64228 .23448 .64318 .23568 .64543 .24555 .64453 .24436 Mtetra
.975 .675 .374 r
.64453 .24436 .64543 .24555 .65544 .44981 .65449 .44867 Mtetra
0 0 .513 r
.65449 .44867 .65544 .44981 .65753 .45208 .65657 .45094 Mtetra
.629 .756 .938 r
.65657 .45094 .65753 .45208 .6595 .45154 .65855 .4504 Mtetra
.769 .8 .879 r
.65855 .4504 .6595 .45154 .66144 .45024 .66049 .4491 Mtetra
.782 .803 .87 r
.66049 .4491 .66144 .45024 .66338 .44885 .66243 .44771 Mtetra
.73 .791 .9 r
.66243 .44771 .66338 .44885 .66534 .44781 .66439 .44667 Mtetra
.716 .787 .907 r
.66439 .44667 .66534 .44781 .6673 .44685 .66635 .44571 Mtetra
.656 .766 .931 r
.66635 .44571 .6673 .44685 .66927 .44619 .66832 .44504 Mtetra
.564 .728 .951 r
.66832 .44504 .66927 .44619 .67126 .44588 .67031 .44474 Mtetra
.535 .714 .955 r
.67031 .44474 .67126 .44588 .67326 .44568 .67231 .44453 Mtetra
.443 .668 .958 r
.67231 .44453 .67326 .44568 .67527 .44575 .67432 .4446 Mtetra
.414 .652 .957 r
.67432 .4446 .67527 .44575 .67729 .44589 .67634 .44474 Mtetra
.629 .755 .938 r
.67634 .44474 .67729 .44589 .67928 .44534 .67833 .44419 Mtetra
.89 .812 .765 r
.67833 .44419 .67928 .44534 .68116 .44263 .68022 .44148 Mtetra
.981 .722 .465 r
.68022 .44148 .68116 .44263 .6823 .42447 .68136 .42333 Mtetra
.977 .682 .379 r
.68136 .42333 .6823 .42447 .67453 .22535 .67364 .22414 Mtetra
.912 .79 .713 r
.67364 .22414 .67453 .22535 .67625 .22209 .67537 .22088 Mtetra
.709 .759 .891 r
.67537 .22088 .67625 .22209 .67809 .2212 .67721 .21999 Mtetra
.59 .711 .927 r
.67721 .21999 .67809 .2212 .67996 .22085 .67908 .21964 Mtetra
.626 .727 .919 r
.67908 .21964 .67996 .22085 .68183 .22036 .68094 .21915 Mtetra
.734 .767 .88 r
.68094 .21915 .68183 .22036 .68366 .21933 .68278 .21812 Mtetra
.645 .735 .914 r
.68278 .21812 .68366 .21933 .68552 .21875 .68464 .21755 Mtetra
.097 .423 .868 r
.68464 .21755 .68552 .21875 .68747 .2197 .68659 .21849 Mtetra
.91 .528 .1 r
.68659 .21849 .68747 .2197 .6898 .22777 .68892 .2266 Mtetra
.975 .671 .352 r
.68892 .2266 .6898 .22777 .70302 .43463 .70208 .43348 Mtetra
.598 .134 0 r
.70208 .43348 .70302 .43463 .70521 .43757 .70428 .43641 Mtetra
.55 .721 .953 r
.70428 .43641 .70521 .43757 .70724 .43731 .70631 .43615 Mtetra
.71 .785 .91 r
.70631 .43615 .70724 .43731 .70923 .43638 .70829 .43521 Mtetra
.694 .779 .917 r
.70829 .43521 .70923 .43638 .71122 .43553 .71029 .43436 Mtetra
.514 .7 .954 r
.71029 .43436 .71122 .43553 .71326 .4354 .71233 .43422 Mtetra
.654 .761 .928 r
.71233 .43422 .71326 .4354 .71527 .43475 .71434 .43356 Mtetra
.865 .813 .797 r
.71434 .43356 .71527 .43475 .71718 .43248 .71625 .43127 Mtetra
.978 .751 .525 r
.71625 .43127 .71718 .43248 .71865 .4227 .71771 .42137 Mtetra
.977 .678 .362 r
.71771 .42137 .71865 .4227 .70813 .21453 .70726 .21327 Mtetra
.932 .784 .675 r
.70726 .21327 .70813 .21453 .7098 .21053 .70893 .20929 Mtetra
.728 .762 .88 r
.70893 .20929 .7098 .21053 .71166 .20952 .71079 .20829 Mtetra
.603 .713 .922 r
.71079 .20829 .71166 .20952 .71355 .20912 .71268 .20789 Mtetra
.602 .712 .922 r
.71268 .20789 .71355 .20912 .71544 .20872 .71457 .20749 Mtetra
.74 .767 .875 r
.71457 .20749 .71544 .20872 .71729 .20764 .71643 .20641 Mtetra
.657 .737 .909 r
.71643 .20641 .71729 .20764 .71918 .20701 .71831 .20577 Mtetra
.234 .508 .906 r
.71831 .20577 .71918 .20701 .72114 .20768 .72028 .20644 Mtetra
.884 .494 .039 r
.72028 .20644 .72114 .20768 .72356 .21512 .72269 .21385 Mtetra
.975 .667 .334 r
.72269 .21385 .72356 .21512 .73923 .42313 .73831 .42194 Mtetra
.648 .195 0 r
.73831 .42194 .73923 .42313 .74153 .42658 .74061 .4254 Mtetra
.385 .63 .951 r
.74061 .4254 .74153 .42658 .74361 .42682 .7427 .42564 Mtetra
.692 .779 .917 r
.7427 .42564 .74361 .42682 .74563 .42597 .74472 .42479 Mtetra
.872 .818 .793 r
.74472 .42479 .74563 .42597 .74755 .42361 .74663 .42243 Mtetra
.977 .767 .554 r
.74663 .42243 .74755 .42361 .74908 .41576 .74817 .41455 Mtetra
.977 .675 .347 r
.74817 .41455 .74908 .41576 .73646 .2055 .7356 .20425 Mtetra
.95 .783 .641 r
.7356 .20425 .73646 .2055 .73807 .2008 .73722 .19956 Mtetra
.737 .768 .877 r
.73722 .19956 .73807 .2008 .73994 .19972 .73908 .19848 Mtetra
.602 .714 .923 r
.73908 .19848 .73994 .19972 .74185 .19931 .741 .19808 Mtetra
.541 .686 .933 r
.741 .19808 .74185 .19931 .74378 .19912 .74293 .1979 Mtetra
.663 .743 .91 r
.74293 .1979 .74378 .19912 .74568 .19846 .74483 .19723 Mtetra
.669 .746 .908 r
.74483 .19723 .74568 .19846 .74758 .19775 .74673 .19654 Mtetra
.695 .759 .9 r
.74673 .19654 .74758 .19775 .74946 .19687 .74862 .19571 Mtetra
.771 .793 .871 r
.74862 .19571 .74946 .19687 .75131 .19549 .75047 .19444 Mtetra
.699 .793 .923 r
.75047 .19444 .75131 .19549 .75319 .19456 .75236 .19361 Mtetra
.349 .646 .966 r
.75236 .19361 .75319 .19456 .75515 .19467 .75434 .19383 Mtetra
.848 .421 0 r
.75434 .19383 .75515 .19467 .7575 .19967 .75672 .19936 Mtetra
.973 .662 .318 r
.75672 .19936 .7575 .19967 .77579 .41008 .77492 .4093 Mtetra
.784 .321 0 r
.77492 .4093 .77579 .41008 .77826 .41475 .77736 .41361 Mtetra
.323 .602 .947 r
.77736 .41361 .77826 .41475 .7804 .41517 .7795 .41399 Mtetra
.67 .774 .928 r
.7795 .41399 .7804 .41517 .78245 .41442 .78155 .41324 Mtetra
.854 .823 .817 r
.78155 .41324 .78245 .41442 .78439 .41231 .78349 .41114 Mtetra
.978 .778 .565 r
.78349 .41114 .78439 .41231 .78592 .40519 .78503 .40402 Mtetra
.976 .671 .329 r
.78503 .40402 .78592 .40519 .77081 .19398 .76997 .19274 Mtetra
.963 .783 .612 r
.76997 .19274 .77081 .19398 .77235 .18867 .77151 .18742 Mtetra
.756 .777 .87 r
.77151 .18742 .77235 .18867 .77422 .18747 .77338 .18623 Mtetra
.623 .725 .92 r
.77338 .18623 .77422 .18747 .77616 .18697 .77532 .18573 Mtetra
.548 .69 .933 r
.77532 .18573 .77616 .18697 .77811 .18676 .77728 .18552 Mtetra
.747 .776 .877 r
.77728 .18552 .77811 .18676 .77999 .1856 .77916 .18439 Mtetra
.675 .754 .91 r
.77916 .18439 .77999 .1856 .78191 .18487 .78108 .18366 Mtetra
.436 .637 .941 r
.78108 .18366 .78191 .18487 .78391 .18503 .78307 .1838 Mtetra
.796 .384 0 r
.78307 .1838 .78391 .18503 .78643 .19124 .78554 .18945 Mtetra
.971 .658 .296 r
.78554 .18945 .78643 .19124 .80681 .40155 .80587 .39967 Mtetra
0 0 .412 r
.80587 .39967 .80681 .40155 .8093 .40566 .80838 .40404 Mtetra
.513 .622 .897 r
.80838 .40404 .8093 .40566 .81144 .40564 .81052 .40402 Mtetra
.674 .702 .868 r
.81052 .40402 .81144 .40564 .81349 .40471 .81258 .4032 Mtetra
.747 .748 .853 r
.81258 .4032 .81349 .40471 .81548 .40304 .81461 .40192 Mtetra
.621 .768 .95 r
.81461 .40192 .81548 .40304 .81743 .40091 .8167 .40136 Mtetra
0 0 0 r
.8167 .40136 .81743 .40091 .81927 .39764 .81876 .40039 Mtetra
.207 0 .174 r
.81876 .40039 .81927 .39764 .8208 .39101 .82074 .3986 Mtetra
.97 .845 .662 r
.15614 .60748 .15748 .60678 .15979 .59998 .15829 .60218 Mtetra
.94 .69 .533 r
.15829 .60218 .15979 .59998 .18259 .40015 .18134 .40075 Mtetra
.966 .804 .63 r
.18134 .40075 .18259 .40015 .18461 .39512 .18353 .3941 Mtetra
.778 .759 .835 r
.18353 .3941 .18461 .39512 .18622 .39396 .18515 .39285 Mtetra
.646 .717 .9 r
.18515 .39285 .18622 .39396 .18776 .39347 .18669 .39237 Mtetra
.525 .677 .934 r
.18669 .39237 .18776 .39347 .18927 .39332 .18819 .39227 Mtetra
.751 .752 .853 r
.18819 .39227 .18927 .39332 .19087 .39227 .1898 .39123 Mtetra
.7 .745 .886 r
.1898 .39123 .19087 .39227 .19244 .39155 .19136 .39051 Mtetra
.495 .68 .948 r
.19136 .39051 .19244 .39155 .19394 .3915 .19286 .39047 Mtetra
.926 .544 .244 r
.19286 .39047 .19394 .3915 .19502 .39552 .19395 .39447 Mtetra
.939 .683 .523 r
.19395 .39447 .19502 .39552 .17608 .59578 .17493 .59477 Mtetra
.937 .585 .328 r
.17493 .59477 .17608 .59578 .17712 .60131 .17596 .60033 Mtetra
.255 .592 .949 r
.17596 .60033 .17712 .60131 .17868 .60164 .17752 .60066 Mtetra
.669 .764 .921 r
.17752 .60066 .17868 .60164 .18034 .60103 .17918 .60005 Mtetra
.747 .776 .876 r
.17918 .60005 .18034 .60103 .18204 .60002 .18089 .59902 Mtetra
.479 .697 .964 r
.18089 .59902 .18204 .60002 .18364 .60002 .18249 .59898 Mtetra
.587 .727 .94 r
.18249 .59898 .18364 .60002 .18527 .59976 .18413 .59866 Mtetra
.742 .755 .863 r
.18413 .59866 .18527 .59976 .18697 .59877 .18583 .59763 Mtetra
.899 .732 .666 r
.18583 .59763 .18697 .59877 .18907 .59377 .18795 .59247 Mtetra
.939 .687 .529 r
.18795 .59247 .18907 .59377 .21039 .39223 .20935 .39089 Mtetra
.902 .712 .635 r
.20935 .39089 .21039 .39223 .21257 .38538 .2115 .38432 Mtetra
.794 .756 .818 r
.2115 .38432 .21257 .38538 .21422 .38391 .21315 .38289 Mtetra
.643 .736 .916 r
.21315 .38289 .21422 .38391 .21578 .38342 .21471 .38241 Mtetra
.503 .69 .952 r
.21471 .38241 .21578 .38342 .2173 .38334 .21622 .38234 Mtetra
.716 .757 .884 r
.21622 .38234 .2173 .38334 .21889 .38244 .21781 .38154 Mtetra
.698 .774 .91 r
.21781 .38154 .21889 .38244 .22048 .38171 .21939 .38084 Mtetra
.54 .737 .967 r
.21939 .38084 .22048 .38171 .222 .38162 .22093 .38064 Mtetra
.793 .312 0 r
.22093 .38064 .222 .38162 .22318 .38523 .22224 .38277 Mtetra
.971 .676 .408 r
.22224 .38277 .22318 .38523 .20591 .58595 .22259 .39523 Mtetra
0 0 .139 r
.22259 .39523 .20591 .58595 .20698 .59188 .20617 .58726 Mtetra
.273 .234 .632 r
.20617 .58726 .20698 .59188 .20855 .59243 .20761 .58921 Mtetra
.474 .427 .725 r
.20761 .58921 .20855 .59243 .21023 .59178 .20919 .58966 Mtetra
.561 .557 .807 r
.20919 .58966 .21023 .59178 .21195 .59066 .21082 .58954 Mtetra
.5 .68 .946 r
.21082 .58954 .21195 .59066 .2136 .59038 .21245 .58949 Mtetra
.612 .768 .955 r
.21245 .58949 .2136 .59038 .21526 .59001 .21411 .58907 Mtetra
.755 .787 .879 r
.21411 .58907 .21526 .59001 .21699 .58892 .21584 .58799 Mtetra
.891 .765 .716 r
.21584 .58799 .21699 .58892 .21907 .5838 .21778 .58448 Mtetra
.961 .747 .568 r
.21778 .58448 .21907 .5838 .23877 .38141 .22073 .56977 Mtetra
0 0 .128 r
.22073 .56977 .23877 .38141 .24087 .37507 .23953 .37722 Mtetra
.629 .813 .392 r
.23953 .37722 .24087 .37507 .24254 .37346 .24132 .37428 Mtetra
.647 .94 .691 r
.24132 .37428 .24254 .37346 .24412 .37296 .24298 .37276 Mtetra
.757 .937 .943 r
.24298 .37276 .24412 .37296 .24566 .37288 .24461 .37176 Mtetra
.693 .731 .879 r
.24461 .37176 .24566 .37288 .24722 .37253 .2462 .37105 Mtetra
.646 .658 .848 r
.2462 .37105 .24722 .37253 .2488 .37204 .24778 .37053 Mtetra
.622 .645 .852 r
.24778 .37053 .2488 .37204 .25038 .37152 .24935 .37013 Mtetra
.629 .666 .866 r
.24935 .37013 .25038 .37152 .25197 .37089 .25093 .3697 Mtetra
.637 .704 .895 r
.25093 .3697 .25197 .37089 .25356 .37024 .2525 .36925 Mtetra
.643 .744 .923 r
.2525 .36925 .25356 .37024 .25515 .36967 .25409 .36877 Mtetra
.735 .783 .891 r
.25409 .36877 .25515 .36967 .25674 .36906 .2557 .36787 Mtetra
.714 .726 .859 r
.2557 .36787 .25674 .36906 .25832 .36872 .25732 .36703 Mtetra
.616 .619 .831 r
.25732 .36703 .25832 .36872 .25983 .36901 .25889 .36665 Mtetra
0 .159 .681 r
.25889 .36665 .25983 .36901 .26108 .3727 .2603 .36833 Mtetra
.888 .615 .1 r
.2603 .36833 .26108 .3727 .24615 .57344 .26119 .37622 Mtetra
0 0 .17 r
.26119 .37622 .24615 .57344 .24734 .57902 .24653 .57403 Mtetra
.328 .264 .632 r
.24653 .57403 .24734 .57902 .24892 .57994 .24804 .57584 Mtetra
.585 .465 .683 r
.24804 .57584 .24892 .57994 .2506 .57955 .24972 .57543 Mtetra
.639 .5 .677 r
.24972 .57543 .2506 .57955 .25232 .57872 .25146 .57435 Mtetra
.627 .486 .671 r
.25146 .57435 .25232 .57872 .25403 .57804 .2532 .57338 Mtetra
.604 .464 .664 r
.2532 .57338 .25403 .57804 .25573 .57748 .25491 .57266 Mtetra
.58 .445 .661 r
.25491 .57266 .25573 .57748 .25744 .57689 .2566 .57223 Mtetra
.495 .389 .664 r
.2566 .57223 .25744 .57689 .25915 .5763 .25822 .57272 Mtetra
.436 .387 .705 r
.25822 .57272 .25915 .5763 .26085 .57569 .25982 .57347 Mtetra
.418 .47 .807 r
.25982 .57347 .26085 .57569 .26256 .5751 .26145 .57396 Mtetra
.525 .69 .943 r
.26145 .57396 .26256 .5751 .26427 .57457 .26312 .57384 Mtetra
.627 .813 .972 r
.26312 .57384 .26427 .57457 .26597 .57406 .26483 .57333 Mtetra
.665 .822 .959 r
.26483 .57333 .26597 .57406 .26768 .57349 .26654 .57269 Mtetra
.646 .804 .959 r
.26654 .57269 .26768 .57349 .26941 .57267 .26825 .57213 Mtetra
.596 .85 .992 r
.26825 .57213 .26941 .57267 .27116 .57167 .26996 .57164 Mtetra
.426 .863 .916 r
.26996 .57164 .27116 .57167 .2729 .57065 .27167 .57115 Mtetra
.137 0 0 r
.27167 .57115 .2729 .57065 .2746 .57026 .27335 .57098 Mtetra
.187 0 0 r
.27335 .57098 .2746 .57026 .27629 .57008 .27504 .57076 Mtetra
0 0 0 r
.27504 .57076 .27629 .57008 .27802 .56931 .27678 .56994 Mtetra
.959 .936 .715 r
.27678 .56994 .27802 .56931 .27996 .56565 .2787 .56656 Mtetra
.951 .692 .508 r
.2787 .56656 .27996 .56565 .29601 .36539 .29452 .3705 Mtetra
.996 .817 .459 r
.29452 .3705 .29601 .36539 .29825 .35608 .29723 .35481 Mtetra
.848 .736 .74 r
.29723 .35481 .29825 .35608 .3 .35372 .29898 .35227 Mtetra
.683 .68 .84 r
.29898 .35227 .3 .35372 .30162 .35297 .30061 .35154 Mtetra
.582 .643 .876 r
.30061 .35154 .30162 .35297 .30322 .35273 .3022 .3513 Mtetra
.611 .657 .87 r
.3022 .3513 .30322 .35273 .3048 .35258 .30381 .35095 Mtetra
.653 .644 .829 r
.30381 .35095 .3048 .35258 .3064 .35242 .30543 .35036 Mtetra
.639 .593 .786 r
.30543 .35036 .3064 .35242 .30798 .3523 .30705 .34979 Mtetra
.651 .564 .744 r
.30705 .34979 .30798 .3523 .30961 .3517 .30868 .34901 Mtetra
.647 .552 .733 r
.30868 .34901 .30961 .3517 .31125 .35088 .31032 .34822 Mtetra
.598 .526 .745 r
.31032 .34822 .31125 .35088 .31285 .35062 .31193 .34785 Mtetra
.268 .315 .726 r
.31193 .34785 .31285 .35062 .31426 .35318 .31343 .34908 Mtetra
.707 .461 0 r
.31343 .34908 .31426 .35318 .30262 .55416 .31462 .35506 Mtetra
0 0 .207 r
.31462 .35506 .30262 .55416 .30387 .56094 .30306 .55532 Mtetra
.224 .178 .594 r
.30306 .55532 .30387 .56094 .30548 .56234 .30458 .55813 Mtetra
.57 .454 .681 r
.30458 .55813 .30548 .56234 .3072 .56199 .30629 .55787 Mtetra
.632 .496 .679 r
.30629 .55787 .3072 .56199 .30895 .56116 .30805 .55688 Mtetra
.625 .488 .675 r
.30805 .55688 .30895 .56116 .3107 .56037 .30981 .55594 Mtetra
.596 .465 .673 r
.30981 .55594 .3107 .56037 .31244 .55981 .31155 .55536 Mtetra
.596 .465 .672 r
.31155 .55536 .31244 .55981 .31418 .55924 .31329 .55477 Mtetra
.595 .464 .672 r
.31329 .55477 .31418 .55924 .31592 .55867 .31503 .5542 Mtetra
.594 .462 .671 r
.31503 .5542 .31592 .55867 .31766 .55812 .31677 .55363 Mtetra
.593 .462 .671 r
.31677 .55363 .31766 .55812 .3194 .55757 .31851 .55308 Mtetra
.593 .461 .671 r
.31851 .55308 .3194 .55757 .32115 .55702 .32025 .55252 Mtetra
.32025 .55252 .32115 .55702 .32289 .55647 .32199 .55197 Mtetra
.592 .461 .671 r
.32199 .55197 .32289 .55647 .32463 .55592 .32374 .55143 Mtetra
.591 .46 .671 r
.32374 .55143 .32463 .55592 .32638 .55539 .32548 .55089 Mtetra
.32548 .55089 .32638 .55539 .32813 .55485 .32723 .55037 Mtetra
.591 .461 .671 r
.32723 .55037 .32813 .55485 .32987 .5543 .32897 .54983 Mtetra
.566 .444 .673 r
.32897 .54983 .32987 .5543 .33161 .55393 .3307 .5496 Mtetra
.553 .439 .678 r
.3307 .5496 .33161 .55393 .33335 .55363 .33243 .54952 Mtetra
.617 .488 .682 r
.33243 .54952 .33335 .55363 .33511 .55286 .33419 .54872 Mtetra
.76 .577 .65 r
.33419 .54872 .33511 .55286 .33697 .55044 .33611 .54512 Mtetra
.95 .684 .499 r
.33611 .54512 .33697 .55044 .33915 .54219 .34904 .34334 Mtetra
.548 .322 .525 r
.34904 .34334 .33915 .54219 .35195 .3396 .35107 .33584 Mtetra
.732 .563 .663 r
.35107 .33584 .35195 .3396 .35377 .33579 .35283 .33329 Mtetra
.655 .569 .746 r
.35283 .33329 .35377 .33579 .35544 .33488 .35449 .33247 Mtetra
.603 .547 .765 r
.35449 .33247 .35544 .33488 .35707 .33459 .35613 .33209 Mtetra
.595 .536 .759 r
.35613 .33209 .35707 .33459 .3587 .33441 .35777 .33175 Mtetra
.621 .541 .743 r
.35777 .33175 .3587 .33441 .36035 .33393 .35942 .33119 Mtetra
.617 .533 .738 r
.35942 .33119 .36035 .33393 .362 .33339 .36107 .33066 Mtetra
.611 .531 .739 r
.36107 .33066 .362 .33339 .36367 .33262 .36272 .33017 Mtetra
.61 .548 .761 r
.36272 .33017 .36367 .33262 .36535 .33156 .36437 .32973 Mtetra
.623 .611 .817 r
.36437 .32973 .36535 .33156 .36702 .33053 .36602 .32928 Mtetra
.65 .705 .887 r
.36602 .32928 .36702 .33053 .36869 .3297 .36767 .32874 Mtetra
.683 .773 .919 r
.36767 .32874 .36869 .3297 .37035 .32914 .36934 .32808 Mtetra
.688 .752 .9 r
.36934 .32808 .37035 .32914 .372 .32865 .371 .32738 Mtetra
.687 .714 .869 r
.371 .32738 .372 .32865 .37366 .32814 .37267 .32665 Mtetra
.68 .679 .842 r
.37267 .32665 .37366 .32814 .37532 .32753 .37434 .32592 Mtetra
.654 .652 .836 r
.37434 .32592 .37532 .32753 .37699 .3269 .376 .32533 Mtetra
.612 .639 .853 r
.376 .32533 .37699 .3269 .37866 .32612 .37765 .32495 Mtetra
.499 .661 .933 r
.37765 .32495 .37866 .32612 .38034 .32514 .37929 .32492 Mtetra
.334 0 0 r
.37929 .32492 .38034 .32514 .382 .32459 .3809 .32552 Mtetra
.794 .388 .282 r
.3809 .32552 .382 .32459 .38361 .32531 .38242 .32824 Mtetra
.954 .679 .479 r
.38242 .32824 .38361 .32531 .385 .33113 .37508 .52939 Mtetra
.544 .314 .517 r
.37508 .52939 .385 .33113 .37776 .53381 .37653 .53616 Mtetra
.677 .303 .33 r
.37653 .53616 .37776 .53381 .37936 .53735 .3782 .53801 Mtetra
.22 0 0 r
.3782 .53801 .37936 .53735 .38112 .53719 .37997 .53788 Mtetra
0 0 0 r
.37997 .53788 .38112 .53719 .38292 .53636 .38176 .53723 Mtetra
.38176 .53723 .38292 .53636 .38471 .53556 .38355 .53644 Mtetra
.055 0 0 r
.38355 .53644 .38471 .53556 .38647 .5355 .38534 .53586 Mtetra
.33 .804 .728 r
.38534 .53586 .38647 .5355 .38824 .53543 .38713 .53513 Mtetra
.731 .937 .954 r
.38713 .53513 .38824 .53543 .39001 .53522 .38894 .53411 Mtetra
.804 .779 .83 r
.38894 .53411 .39001 .53522 .3918 .53477 .39077 .53251 Mtetra
.755 .646 .74 r
.39077 .53251 .3918 .53477 .39359 .53422 .39261 .53065 Mtetra
.684 .547 .692 r
.39261 .53065 .39359 .53422 .39538 .53373 .39444 .52909 Mtetra
.56 .437 .669 r
.39444 .52909 .39538 .53373 .39716 .5335 .39622 .52891 Mtetra
.591 .459 .67 r
.39622 .52891 .39716 .5335 .39896 .53283 .39801 .52837 Mtetra
.704 .536 .658 r
.39801 .52837 .39896 .53283 .4008 .531 .39987 .52597 Mtetra
.956 .685 .482 r
.39987 .52597 .4008 .531 .40281 .52438 .40903 .3253 Mtetra
.553 .326 .525 r
.40903 .3253 .40281 .52438 .41195 .31969 .41107 .3152 Mtetra
.735 .55 .643 r
.41107 .3152 .41195 .31969 .41379 .31465 .41285 .31205 Mtetra
.664 .57 .739 r
.41285 .31205 .41379 .31465 .41549 .31361 .41455 .31111 Mtetra
.611 .547 .758 r
.41455 .31111 .41549 .31361 .41717 .31322 .41623 .31066 Mtetra
.586 .529 .758 r
.41623 .31066 .41717 .31322 .41885 .31291 .41791 .31037 Mtetra
.624 .552 .753 r
.41791 .31037 .41885 .31291 .42056 .31187 .41959 .30981 Mtetra
.634 .595 .792 r
.41959 .30981 .42056 .31187 .42226 .31084 .42128 .30925 Mtetra
.647 .654 .843 r
.42128 .30925 .42226 .31084 .42396 .30993 .42297 .30869 Mtetra
.659 .713 .889 r
.42297 .30869 .42396 .30993 .42566 .30929 .42467 .3081 Mtetra
.661 .724 .896 r
.42467 .3081 .42566 .30929 .42735 .30874 .42636 .30751 Mtetra
.666 .719 .889 r
.42636 .30751 .42735 .30874 .42904 .30821 .42806 .30689 Mtetra
.681 .709 .869 r
.42806 .30689 .42904 .30821 .43073 .30766 .42976 .30618 Mtetra
.659 .676 .855 r
.42976 .30618 .43073 .30766 .43243 .3071 .43145 .30557 Mtetra
.614 .65 .862 r
.43145 .30557 .43243 .3071 .43413 .3065 .43314 .30518 Mtetra
.418 .592 .915 r
.43314 .30518 .43413 .3065 .43583 .30582 .43482 .30541 Mtetra
0 .449 .767 r
.43482 .30541 .43583 .30582 .43753 .30512 .43649 .30588 Mtetra
.471 0 0 r
.43649 .30588 .43753 .30512 .43924 .30438 .43817 .30627 Mtetra
.173 0 .032 r
.43817 .30627 .43924 .30438 .44095 .30336 .43988 .30524 Mtetra
.253 0 .072 r
.43988 .30524 .44095 .30336 .44265 .30267 .44159 .30447 Mtetra
.503 .09 .189 r
.44159 .30447 .44265 .30267 .44434 .30273 .44327 .30476 Mtetra
.901 .578 .425 r
.44327 .30476 .44434 .30273 .44595 .30589 .44467 .31635 Mtetra
.95 .668 .47 r
.44467 .31635 .44595 .30589 .44268 .50706 .44143 .51364 Mtetra
.654 .349 .443 r
.44143 .51364 .44268 .50706 .44428 .51553 .44317 .51673 Mtetra
.326 0 0 r
.44317 .51673 .44428 .51553 .44607 .5163 .44498 .51654 Mtetra
.429 .869 .805 r
.44498 .51654 .44607 .5163 .44788 .51615 .44682 .51574 Mtetra
.739 .921 .953 r
.44682 .51574 .44788 .51615 .44971 .51558 .44866 .51469 Mtetra
.55 .765 .978 r
.44866 .51469 .44971 .51558 .45154 .51515 .45048 .5144 Mtetra
.563 .802 .988 r
.45048 .5144 .45154 .51515 .45337 .51463 .45231 .51402 Mtetra
.624 .856 .987 r
.45231 .51402 .45337 .51463 .4552 .51409 .45414 .51342 Mtetra
.741 .867 .939 r
.45414 .51342 .4552 .51409 .45702 .51412 .45598 .51241 Mtetra
.768 .701 .788 r
.45598 .51241 .45702 .51412 .45885 .51375 .45784 .5108 Mtetra
.778 .623 .688 r
.45784 .5108 .45885 .51375 .46069 .5126 .45972 .50794 Mtetra
.962 .686 .466 r
.45972 .50794 .46069 .5126 .46261 .50743 .46521 .31481 Mtetra
.571 .34 .527 r
.46521 .31481 .46261 .50743 .46815 .30281 .46728 .29619 Mtetra
.703 .502 .613 r
.46728 .29619 .46815 .30281 .47 .2953 .46905 .29255 Mtetra
.657 .559 .733 r
.46905 .29255 .47 .2953 .47174 .29368 .47078 .29163 Mtetra
.602 .582 .804 r
.47078 .29163 .47174 .29368 .47347 .29283 .4725 .29128 Mtetra
.534 .612 .877 r
.4725 .29128 .47347 .29283 .47519 .29236 .47422 .29122 Mtetra
.651 .734 .91 r
.47422 .29122 .47519 .29236 .47691 .29171 .47594 .29066 Mtetra
.665 .758 .92 r
.47594 .29066 .47691 .29171 .47864 .29113 .47767 .29005 Mtetra
.676 .755 .91 r
.47767 .29005 .47864 .29113 .48036 .29057 .4794 .28938 Mtetra
.769 .758 .844 r
.4794 .28938 .48036 .29057 .4821 .28948 .48113 .28812 Mtetra
.708 .715 .854 r
.48113 .28812 .4821 .28948 .48383 .28871 .48287 .28724 Mtetra
.558 .636 .885 r
.48287 .28724 .48383 .28871 .48555 .28856 .48459 .28707 Mtetra
.846 .437 0 r
.48459 .28707 .48555 .28856 .48724 .29192 .48626 .29134 Mtetra
.967 .683 .44 r
.48626 .29134 .48724 .29192 .48662 .49522 .48555 .49771 Mtetra
.817 .461 .384 r
.48555 .49771 .48662 .49522 .48838 .50243 .48733 .50312 Mtetra
.358 0 0 r
.48733 .50312 .48838 .50243 .49022 .50317 .48918 .50328 Mtetra
.48 .898 .863 r
.48918 .50328 .49022 .50317 .49208 .50293 .49104 .50248 Mtetra
.777 .923 .933 r
.49104 .50248 .49208 .50293 .49394 .50224 .4929 .50125 Mtetra
.469 .709 .973 r
.4929 .50125 .49394 .50224 .49579 .50221 .49476 .5012 Mtetra
.566 .746 .961 r
.49476 .5012 .49579 .50221 .49765 .50178 .49662 .50088 Mtetra
.745 .825 .914 r
.49662 .50088 .49765 .50178 .49952 .50054 .49848 .49983 Mtetra
.954 .796 .647 r
.49848 .49983 .49952 .50054 .50141 .49484 .50038 .49457 Mtetra
.97 .691 .446 r
.50038 .49457 .50141 .49484 .50462 .28749 .50365 .28727 Mtetra
.979 .794 .586 r
.50365 .28727 .50462 .28749 .5064 .28121 .50544 .28027 Mtetra
.818 .813 .845 r
.50544 .28027 .5064 .28121 .50815 .27976 .50719 .27873 Mtetra
.651 .76 .93 r
.50719 .27873 .50815 .27976 .5099 .27925 .50894 .27817 Mtetra
.537 .703 .947 r
.50894 .27817 .5099 .27925 .51164 .27915 .51068 .27799 Mtetra
.747 .763 .866 r
.51068 .27799 .51164 .27915 .51339 .27824 .51243 .27691 Mtetra
.709 .723 .86 r
.51243 .27691 .51339 .27824 .51514 .27748 .51419 .27602 Mtetra
.573 .647 .886 r
.51419 .27602 .51514 .27748 .51689 .27729 .51593 .2758 Mtetra
.741 .32 0 r
.51593 .2758 .51689 .27729 .51863 .28007 .51768 .27926 Mtetra
.97 .682 .428 r
.51768 .27926 .51863 .28007 .52009 .48213 .51907 .48569 Mtetra
.809 .468 .411 r
.51907 .48569 .52009 .48213 .52195 .49144 .52093 .49219 Mtetra
.477 0 0 r
.52093 .49219 .52195 .49144 .52383 .49255 .52281 .49269 Mtetra
.414 .863 .83 r
.52281 .49269 .52383 .49255 .52571 .49239 .52469 .49196 Mtetra
.767 .929 .939 r
.52469 .49196 .52571 .49239 .52759 .49175 .52657 .49076 Mtetra
.511 .731 .973 r
.52657 .49076 .52759 .49175 .52947 .49166 .52846 .49059 Mtetra
.547 .729 .959 r
.52846 .49059 .52947 .49166 .53136 .49129 .53034 .49034 Mtetra
.721 .813 .922 r
.53034 .49034 .53136 .49129 .53324 .49018 .53223 .48941 Mtetra
.947 .808 .673 r
.53223 .48941 .53324 .49018 .53511 .48547 .5341 .48492 Mtetra
.972 .689 .435 r
.5341 .48492 .53511 .48547 .53624 .27866 .5353 .27838 Mtetra
.981 .775 .552 r
.5353 .27838 .53624 .27866 .53798 .27069 .53703 .2696 Mtetra
.84 .791 .804 r
.53703 .2696 .53798 .27069 .53974 .26885 .53879 .2677 Mtetra
.668 .744 .907 r
.53879 .2677 .53974 .26885 .5415 .26821 .54056 .26705 Mtetra
.55 .695 .936 r
.54056 .26705 .5415 .26821 .54327 .26801 .54233 .26685 Mtetra
.72 .76 .884 r
.54233 .26685 .54327 .26801 .54504 .2671 .5441 .26594 Mtetra
.713 .757 .887 r
.5441 .26594 .54504 .2671 .54681 .26623 .54586 .26507 Mtetra
.568 .702 .932 r
.54586 .26507 .54681 .26623 .54858 .26598 .54764 .26481 Mtetra
.699 .24 0 r
.54764 .26481 .54858 .26598 .55038 .26883 .54944 .26766 Mtetra
.972 .681 .415 r
.54944 .26766 .55038 .26883 .55397 .47402 .55297 .47292 Mtetra
.934 .559 .194 r
.55297 .47292 .55397 .47402 .55594 .48184 .55494 .48075 Mtetra
0 .244 .736 r
.55494 .48075 .55594 .48184 .55786 .48312 .55686 .48208 Mtetra
.566 .745 .961 r
.55686 .48208 .55786 .48312 .55977 .48277 .55877 .48176 Mtetra
.796 .818 .87 r
.55877 .48176 .55977 .48277 .56166 .48138 .56066 .48032 Mtetra
.938 .785 .664 r
.56066 .48032 .56166 .48138 .56353 .47747 .56252 .47563 Mtetra
.972 .687 .427 r
.56252 .47563 .56353 .47747 .56302 .28042 .56194 .26794 Mtetra
.717 .483 .57 r
.56194 .26794 .56302 .28042 .5646 .26289 .56364 .25992 Mtetra
.73 .591 .701 r
.56364 .25992 .5646 .26289 .56635 .26033 .5654 .25798 Mtetra
.619 .569 .776 r
.5654 .25798 .56635 .26033 .56813 .2593 .56719 .25747 Mtetra
.536 .576 .843 r
.56719 .25747 .56813 .2593 .56992 .25875 .56898 .25743 Mtetra
.595 .685 .904 r
.56898 .25743 .56992 .25875 .5717 .25817 .57077 .2571 Mtetra
.653 .755 .925 r
.57077 .2571 .5717 .25817 .57349 .25758 .57256 .25651 Mtetra
.662 .761 .924 r
.57256 .25651 .57349 .25758 .57528 .25702 .57435 .25589 Mtetra
.739 .773 .88 r
.57435 .25589 .57528 .25702 .57706 .25602 .57613 .25486 Mtetra
.726 .763 .882 r
.57613 .25486 .57706 .25602 .57884 .25508 .57792 .2539 Mtetra
.598 .714 .926 r
.57792 .2539 .57884 .25508 .58064 .25472 .57971 .25353 Mtetra
.567 .109 0 r
.57971 .25353 .58064 .25472 .58249 .25714 .58156 .25593 Mtetra
.973 .68 .402 r
.58156 .25593 .58249 .25714 .58824 .4618 .58726 .46056 Mtetra
.939 .572 .197 r
.58726 .46056 .58824 .4618 .59035 .47082 .58936 .46969 Mtetra
0 .157 .669 r
.58936 .46969 .59035 .47082 .59232 .47243 .59133 .47131 Mtetra
.538 .716 .955 r
.59133 .47131 .59232 .47243 .59426 .47222 .59327 .47109 Mtetra
.768 .796 .876 r
.59327 .47109 .59426 .47222 .59617 .47094 .59519 .46982 Mtetra
.923 .793 .699 r
.59519 .46982 .59617 .47094 .59803 .46713 .59705 .46599 Mtetra
.975 .687 .413 r
.59705 .46599 .59803 .46713 .59537 .2656 .59444 .26418 Mtetra
.968 .719 .507 r
.59444 .26418 .59537 .2656 .59685 .25079 .59593 .2496 Mtetra
.875 .784 .757 r
.59593 .2496 .59685 .25079 .59861 .24826 .59769 .24707 Mtetra
.683 .745 .898 r
.59769 .24707 .59861 .24826 .60041 .24754 .59949 .24633 Mtetra
.559 .693 .93 r
.59949 .24633 .60041 .24754 .60223 .24732 .60131 .2461 Mtetra
.627 .721 .914 r
.60131 .2461 .60223 .24732 .60404 .24691 .60312 .24562 Mtetra
.683 .729 .885 r
.60312 .24562 .60404 .24691 .60585 .24623 .60492 .24488 Mtetra
.658 .708 .884 r
.60492 .24488 .60585 .24623 .60765 .24552 .60673 .24425 Mtetra
.62 .706 .907 r
.60673 .24425 .60765 .24552 .60945 .24447 .60855 .2438 Mtetra
.428 .758 .995 r
.60855 .2438 .60945 .24447 .61125 .24341 .61038 .24369 Mtetra
.427 0 0 r
.61038 .24369 .61125 .24341 .61306 .2429 .61222 .24426 Mtetra
.814 .407 .276 r
.61222 .24426 .61306 .2429 .61495 .24462 .61417 .24804 Mtetra
.971 .672 .398 r
.61417 .24804 .61495 .24462 .62263 .43979 .62209 .45315 Mtetra
.645 .363 .476 r
.62209 .45315 .62263 .43979 .62517 .45904 .62422 .45851 Mtetra
.474 0 0 r
.62422 .45851 .62517 .45904 .6272 .46118 .62623 .45995 Mtetra
.517 .685 .943 r
.62623 .45995 .6272 .46118 .62917 .46111 .6282 .45983 Mtetra
.736 .765 .876 r
.6282 .45983 .62917 .46111 .63111 .45994 .63013 .45872 Mtetra
.911 .792 .716 r
.63013 .45872 .63111 .45994 .63296 .45642 .632 .45525 Mtetra
.976 .685 .4 r
.632 .45525 .63296 .45642 .62898 .27884 .62756 .26258 Mtetra
.826 .557 .532 r
.62756 .26258 .62898 .27884 .6295 .23942 .62859 .23822 Mtetra
.893 .786 .735 r
.62859 .23822 .6295 .23942 .63125 .23653 .63034 .23534 Mtetra
.703 .754 .892 r
.63034 .23534 .63125 .23653 .63307 .23569 .63216 .2345 Mtetra
.586 .709 .928 r
.63216 .2345 .63307 .23569 .6349 .23536 .634 .23416 Mtetra
.666 .742 .907 r
.634 .23416 .6349 .23536 .63673 .2347 .63583 .23351 Mtetra
.733 .765 .879 r
.63583 .23351 .63673 .2347 .63854 .23369 .63764 .23249 Mtetra
.636 .73 .917 r
.63764 .23249 .63854 .23369 .64038 .23316 .63948 .23197 Mtetra
0 .282 .78 r
.63948 .23197 .64038 .23316 .64228 .23448 .64138 .23329 Mtetra
.938 .574 .185 r
.64138 .23329 .64228 .23448 .64453 .24436 .64362 .24317 Mtetra
.975 .675 .374 r
.64362 .24317 .64453 .24436 .65449 .44867 .65353 .44753 Mtetra
0 0 .513 r
.65353 .44753 .65449 .44867 .65657 .45094 .65561 .4498 Mtetra
.629 .756 .938 r
.65561 .4498 .65657 .45094 .65855 .4504 .65759 .44925 Mtetra
.769 .8 .879 r
.65759 .44925 .65855 .4504 .66049 .4491 .65953 .44796 Mtetra
.782 .803 .87 r
.65953 .44796 .66049 .4491 .66243 .44771 .66148 .44657 Mtetra
.73 .791 .901 r
.66148 .44657 .66243 .44771 .66439 .44667 .66343 .44553 Mtetra
.716 .787 .908 r
.66343 .44553 .66439 .44667 .66635 .44571 .66539 .44457 Mtetra
.656 .766 .931 r
.66539 .44457 .66635 .44571 .66832 .44504 .66737 .4439 Mtetra
.564 .728 .952 r
.66737 .4439 .66832 .44504 .67031 .44474 .66936 .4436 Mtetra
.535 .715 .955 r
.66936 .4436 .67031 .44474 .67231 .44453 .67136 .44338 Mtetra
.443 .668 .958 r
.67136 .44338 .67231 .44453 .67432 .4446 .67338 .44345 Mtetra
.414 .652 .957 r
.67338 .44345 .67432 .4446 .67634 .44474 .67539 .44359 Mtetra
.628 .755 .938 r
.67539 .44359 .67634 .44474 .67833 .44419 .67738 .44304 Mtetra
.89 .812 .765 r
.67738 .44304 .67833 .44419 .68022 .44148 .67927 .44033 Mtetra
.981 .723 .465 r
.67927 .44033 .68022 .44148 .68136 .42333 .68042 .4222 Mtetra
.977 .682 .379 r
.68042 .4222 .68136 .42333 .67364 .22414 .67275 .22294 Mtetra
.912 .79 .714 r
.67275 .22294 .67364 .22414 .67537 .22088 .67448 .21967 Mtetra
.709 .759 .891 r
.67448 .21967 .67537 .22088 .67721 .21999 .67632 .21879 Mtetra
.589 .711 .927 r
.67632 .21879 .67721 .21999 .67908 .21964 .67819 .21844 Mtetra
.626 .727 .92 r
.67819 .21844 .67908 .21964 .68094 .21915 .68006 .21795 Mtetra
.734 .768 .88 r
.68006 .21795 .68094 .21915 .68278 .21812 .6819 .21692 Mtetra
.645 .735 .915 r
.6819 .21692 .68278 .21812 .68464 .21755 .68376 .21634 Mtetra
.093 .421 .867 r
.68376 .21634 .68464 .21755 .68659 .21849 .68571 .21729 Mtetra
.911 .53 .104 r
.68571 .21729 .68659 .21849 .68892 .2266 .68804 .2255 Mtetra
.975 .671 .352 r
.68804 .2255 .68892 .2266 .70208 .43348 .70115 .43236 Mtetra
.604 .136 0 r
.70115 .43236 .70208 .43348 .70428 .43641 .70335 .43527 Mtetra
.551 .725 .955 r
.70335 .43527 .70428 .43641 .70631 .43615 .70537 .435 Mtetra
.712 .789 .912 r
.70537 .435 .70631 .43615 .70829 .43521 .70736 .43405 Mtetra
.695 .782 .918 r
.70736 .43405 .70829 .43521 .71029 .43436 .70936 .43319 Mtetra
.514 .703 .955 r
.70936 .43319 .71029 .43436 .71233 .43422 .7114 .43305 Mtetra
.655 .764 .93 r
.7114 .43305 .71233 .43422 .71434 .43356 .7134 .43238 Mtetra
.866 .815 .797 r
.7134 .43238 .71434 .43356 .71625 .43127 .71532 .43008 Mtetra
.979 .751 .524 r
.71532 .43008 .71625 .43127 .71771 .42137 .71678 .4201 Mtetra
.977 .678 .362 r
.71678 .4201 .71771 .42137 .70726 .21327 .70638 .21203 Mtetra
.933 .786 .675 r
.70638 .21203 .70726 .21327 .70893 .20929 .70806 .20806 Mtetra
.728 .763 .881 r
.70806 .20806 .70893 .20929 .71079 .20829 .70992 .20705 Mtetra
.602 .713 .922 r
.70992 .20705 .71079 .20829 .71268 .20789 .71181 .20665 Mtetra
.601 .713 .923 r
.71181 .20665 .71268 .20789 .71457 .20749 .71371 .20625 Mtetra
.74 .768 .875 r
.71371 .20625 .71457 .20749 .71643 .20641 .71556 .20517 Mtetra
.657 .737 .909 r
.71556 .20517 .71643 .20641 .71831 .20577 .71744 .20453 Mtetra
.235 .509 .907 r
.71744 .20453 .71831 .20577 .72028 .20644 .71941 .20521 Mtetra
.884 .492 .037 r
.71941 .20521 .72028 .20644 .72269 .21385 .72182 .21257 Mtetra
.975 .667 .334 r
.72182 .21257 .72269 .21385 .73831 .42194 .73739 .42075 Mtetra
.648 .196 0 r
.73739 .42075 .73831 .42194 .74061 .4254 .73969 .42421 Mtetra
.385 .63 .951 r
.73969 .42421 .74061 .4254 .7427 .42564 .74178 .42446 Mtetra
.692 .778 .917 r
.74178 .42446 .7427 .42564 .74472 .42479 .7438 .4236 Mtetra
.872 .818 .793 r
.7438 .4236 .74472 .42479 .74663 .42243 .74572 .42123 Mtetra
.977 .767 .553 r
.74572 .42123 .74663 .42243 .74817 .41455 .74725 .41329 Mtetra
.977 .675 .348 r
.74725 .41329 .74817 .41455 .7356 .20425 .73474 .20296 Mtetra
.947 .78 .642 r
.73474 .20296 .7356 .20425 .73722 .19956 .73636 .1983 Mtetra
.735 .764 .876 r
.73636 .1983 .73722 .19956 .73908 .19848 .73822 .19723 Mtetra
.601 .711 .922 r
.73822 .19723 .73908 .19848 .741 .19808 .74014 .19683 Mtetra
.539 .683 .932 r
.74014 .19683 .741 .19808 .74293 .1979 .74207 .19666 Mtetra
.662 .741 .909 r
.74207 .19666 .74293 .1979 .74483 .19723 .74397 .196 Mtetra
.667 .744 .908 r
.74397 .196 .74483 .19723 .74673 .19654 .74587 .19531 Mtetra
.691 .756 .901 r
.74587 .19531 .74673 .19654 .74862 .19571 .74777 .19451 Mtetra
.762 .785 .871 r
.74777 .19451 .74862 .19571 .75047 .19444 .74963 .19329 Mtetra
.688 .769 .913 r
.74963 .19329 .75047 .19444 .75236 .19361 .75152 .1925 Mtetra
.366 .619 .949 r
.75152 .1925 .75236 .19361 .75434 .19383 .7535 .19277 Mtetra
.84 .424 0 r
.7535 .19277 .75434 .19383 .75672 .19936 .7559 .19861 Mtetra
.973 .662 .317 r
.7559 .19861 .75672 .19936 .77492 .4093 .77404 .40829 Mtetra
.739 .284 0 r
.77404 .40829 .77492 .4093 .77736 .41361 .77647 .41244 Mtetra
.333 .605 .947 r
.77647 .41244 .77736 .41361 .7795 .41399 .7786 .41281 Mtetra
.671 .774 .927 r
.7786 .41281 .7795 .41399 .78155 .41324 .78065 .41205 Mtetra
.854 .823 .817 r
.78065 .41205 .78155 .41324 .78349 .41114 .7826 .40995 Mtetra
.978 .777 .565 r
.7826 .40995 .78349 .41114 .78503 .40402 .78414 .40281 Mtetra
.976 .671 .329 r
.78414 .40281 .78503 .40402 .76997 .19274 .76913 .19147 Mtetra
.961 .78 .613 r
.76913 .19147 .76997 .19274 .77151 .18742 .77067 .18616 Mtetra
.754 .773 .869 r
.77067 .18616 .77151 .18742 .77338 .18623 .77254 .18497 Mtetra
.621 .722 .919 r
.77254 .18497 .77338 .18623 .77532 .18573 .77448 .18449 Mtetra
.544 .687 .933 r
.77448 .18449 .77532 .18573 .77728 .18552 .77644 .18429 Mtetra
.731 .772 .886 r
.77644 .18429 .77728 .18552 .77916 .18439 .77833 .18326 Mtetra
.674 .771 .923 r
.77833 .18326 .77916 .18439 .78108 .18366 .78025 .18254 Mtetra
.491 .686 .954 r
.78025 .18254 .78108 .18366 .78307 .1838 .78223 .18248 Mtetra
0 0 .485 r
.78223 .18248 .78307 .1838 .78554 .18945 .78447 .18548 Mtetra
.97 .658 .288 r
.78447 .18548 .78554 .18945 .80587 .39967 .80425 .39002 Mtetra
.041 .029 .515 r
.80425 .39002 .80587 .39967 .80838 .40404 .8072 .39942 Mtetra
.432 .365 .681 r
.8072 .39942 .80838 .40404 .81052 .40402 .80945 .40066 Mtetra
.514 .463 .738 r
.80945 .40066 .81052 .40402 .81258 .4032 .81161 .40092 Mtetra
.569 .571 .815 r
.81161 .40092 .81258 .4032 .81461 .40192 .81373 .4007 Mtetra
.42 .646 .952 r
.81373 .4007 .81461 .40192 .8167 .40136 .81589 .40086 Mtetra
.477 .843 .991 r
.81589 .40086 .8167 .40136 .81876 .40039 .81799 .40043 Mtetra
.613 .956 .834 r
.81799 .40043 .81876 .40039 .82074 .3986 .82002 .39914 Mtetra
.909 .747 .667 r
.15496 .60664 .15614 .60748 .15829 .60218 .1571 .60139 Mtetra
.936 .686 .534 r
.1571 .60139 .15829 .60218 .18134 .40075 .18025 .3998 Mtetra
.914 .727 .635 r
.18025 .3998 .18134 .40075 .18353 .3941 .18246 .39305 Mtetra
.776 .752 .832 r
.18246 .39305 .18353 .3941 .18515 .39285 .18408 .3918 Mtetra
.644 .728 .91 r
.18408 .3918 .18515 .39285 .18669 .39237 .18562 .39132 Mtetra
.515 .685 .944 r
.18562 .39132 .18669 .39237 .18819 .39227 .18712 .39124 Mtetra
.751 .753 .854 r
.18712 .39124 .18819 .39227 .1898 .39123 .18872 .3902 Mtetra
.7 .746 .887 r
.18872 .3902 .1898 .39123 .19136 .39051 .19028 .38949 Mtetra
.494 .681 .949 r
.19028 .38949 .19136 .39051 .19286 .39047 .19178 .38944 Mtetra
.926 .543 .243 r
.19178 .38944 .19286 .39047 .19395 .39447 .19287 .39342 Mtetra
.939 .683 .523 r
.19287 .39342 .19395 .39447 .17493 .59477 .17378 .59377 Mtetra
.937 .586 .33 r
.17378 .59377 .17493 .59477 .17596 .60033 .1748 .59936 Mtetra
.253 .593 .949 r
.1748 .59936 .17596 .60033 .17752 .60066 .17636 .59969 Mtetra
.67 .764 .921 r
.17636 .59969 .17752 .60066 .17918 .60005 .17803 .59907 Mtetra
.748 .776 .876 r
.17803 .59907 .17918 .60005 .18089 .59902 .17973 .59804 Mtetra
.477 .699 .966 r
.17973 .59804 .18089 .59902 .18249 .59898 .18134 .59799 Mtetra
.583 .739 .95 r
.18134 .59799 .18249 .59898 .18413 .59866 .18297 .59768 Mtetra
.748 .775 .875 r
.18297 .59768 .18413 .59866 .18583 .59763 .18468 .59664 Mtetra
.906 .741 .667 r
.18468 .59664 .18583 .59763 .18795 .59247 .1868 .59146 Mtetra
.939 .687 .529 r
.1868 .59146 .18795 .59247 .20935 .39089 .20828 .38981 Mtetra
.911 .724 .637 r
.20828 .38981 .20935 .39089 .2115 .38432 .21043 .38329 Mtetra
.794 .759 .821 r
.21043 .38329 .2115 .38432 .21315 .38289 .21208 .38187 Mtetra
.64 .736 .918 r
.21208 .38187 .21315 .38289 .21471 .38241 .21363 .38141 Mtetra
.497 .689 .953 r
.21363 .38141 .21471 .38241 .21622 .38234 .21515 .38135 Mtetra
.689 .753 .9 r
.21515 .38135 .21622 .38234 .21781 .38154 .21673 .38068 Mtetra
.688 .782 .922 r
.21673 .38068 .21781 .38154 .21939 .38084 .2183 .38003 Mtetra
.603 .772 .961 r
.2183 .38003 .21939 .38084 .22093 .38064 .21985 .37966 Mtetra
.126 .5 .907 r
.21985 .37966 .22093 .38064 .22224 .38277 .22132 .38017 Mtetra
.084 .204 .692 r
.22132 .38017 .22224 .38277 .22259 .39523 .22269 .38175 Mtetra
.344 .192 .526 r
.22269 .38175 .22259 .39523 .20617 .58726 .2238 .38619 Mtetra
0 0 .162 r
.2238 .38619 .20617 .58726 .20761 .58921 .20708 .58153 Mtetra
.048 .01 .487 r
.20708 .58153 .20761 .58921 .20919 .58966 .20824 .58645 Mtetra
.116 .192 .666 r
.20824 .58645 .20919 .58966 .21082 .58954 .2097 .58831 Mtetra
.36 .591 .933 r
.2097 .58831 .21082 .58954 .21245 .58949 .21129 .58859 Mtetra
.626 .774 .951 r
.21129 .58859 .21245 .58949 .21411 .58907 .21296 .58813 Mtetra
.75 .787 .883 r
.21296 .58813 .21411 .58907 .21584 .58799 .21469 .58709 Mtetra
.83 .79 .813 r
.21469 .58709 .21584 .58799 .21778 .58448 .21648 .58527 Mtetra
.942 .961 .729 r
.21648 .58527 .21778 .58448 .22073 .56977 .21838 .58226 Mtetra
.163 0 .332 r
.21838 .58226 .22073 .56977 .23953 .37722 .2206 .57561 Mtetra
0 0 .149 r
.2206 .57561 .23953 .37722 .24132 .37428 .23978 .3786 Mtetra
0 0 0 r
.23978 .3786 .24132 .37428 .24298 .37276 .24177 .37344 Mtetra
.933 .967 .743 r
.24177 .37344 .24298 .37276 .24461 .37176 .24354 .3708 Mtetra
.771 .774 .855 r
.24354 .3708 .24461 .37176 .2462 .37105 .24517 .36964 Mtetra
.653 .672 .855 r
.24517 .36964 .2462 .37105 .24778 .37053 .24676 .36909 Mtetra
.594 .645 .87 r
.24676 .36909 .24778 .37053 .24935 .37013 .24832 .36881 Mtetra
.606 .669 .885 r
.24832 .36881 .24935 .37013 .25093 .3697 .24988 .36848 Mtetra
.615 .691 .897 r
.24988 .36848 .25093 .3697 .2525 .36925 .25145 .36811 Mtetra
.624 .71 .908 r
.25145 .36811 .2525 .36925 .25409 .36877 .25303 .36771 Mtetra
.708 .748 .883 r
.25303 .36771 .25409 .36877 .2557 .36787 .25464 .36693 Mtetra
.72 .772 .894 r
.25464 .36693 .2557 .36787 .25732 .36703 .25625 .36611 Mtetra
.66 .765 .927 r
.25625 .36611 .25732 .36703 .25889 .36665 .25784 .36556 Mtetra
.118 .469 .893 r
.25784 .36556 .25889 .36665 .2603 .36833 .25933 .36616 Mtetra
0 .05 .616 r
.25933 .36616 .2603 .36833 .26119 .37622 .26072 .36807 Mtetra
.19 .107 .525 r
.26072 .36807 .26119 .37622 .24653 .57403 .26192 .3723 Mtetra
.519 .298 .519 r
.26192 .3723 .24653 .57403 .24804 .57584 .26305 .37755 Mtetra
.532 .309 .522 r
.26305 .37755 .24804 .57584 .24972 .57543 .26461 .3775 Mtetra
.539 .315 .523 r
.26461 .3775 .24972 .57543 .25146 .57435 .26644 .37415 Mtetra
.538 .314 .523 r
.26644 .37415 .25146 .57435 .2532 .57338 .26823 .37119 Mtetra
.535 .311 .522 r
.26823 .37119 .2532 .57338 .25491 .57266 .26991 .36966 Mtetra
.53 .307 .521 r
.26991 .36966 .25491 .57266 .2566 .57223 .27143 .37024 Mtetra
0 0 .205 r
.27143 .37024 .2566 .57223 .25822 .57272 .25774 .56346 Mtetra
0 0 .437 r
.25774 .56346 .25822 .57272 .25982 .57347 .25887 .57026 Mtetra
0 .048 .592 r
.25887 .57026 .25982 .57347 .26145 .57396 .26033 .57279 Mtetra
.245 .543 .926 r
.26033 .57279 .26145 .57396 .26312 .57384 .26196 .57325 Mtetra
.594 .838 .991 r
.26196 .57325 .26312 .57384 .26483 .57333 .26366 .57278 Mtetra
.693 .87 .965 r
.26366 .57278 .26483 .57333 .26654 .57269 .26539 .57201 Mtetra
.668 .836 .964 r
.26539 .57201 .26654 .57269 .26825 .57213 .26711 .57136 Mtetra
.637 .807 .965 r
.26711 .57136 .26825 .57213 .26996 .57164 .26882 .57083 Mtetra
.641 .799 .958 r
.26882 .57083 .26996 .57164 .27167 .57115 .27053 .57029 Mtetra
.521 .749 .979 r
.27053 .57029 .27167 .57115 .27335 .57098 .27222 .57009 Mtetra
.541 .75 .973 r
.27222 .57009 .27335 .57098 .27504 .57076 .27391 .56985 Mtetra
.716 .794 .913 r
.27391 .56985 .27504 .57076 .27678 .56994 .27565 .569 Mtetra
.895 .772 .718 r
.27565 .569 .27678 .56994 .2787 .56656 .27758 .56553 Mtetra
.949 .689 .509 r
.27758 .56553 .2787 .56656 .29452 .3705 .2937 .36631 Mtetra
.879 .647 .583 r
.2937 .36631 .29452 .3705 .29723 .35481 .29621 .35342 Mtetra
.838 .724 .738 r
.29621 .35342 .29723 .35481 .29898 .35227 .29796 .35093 Mtetra
.686 .698 .856 r
.29796 .35093 .29898 .35227 .30061 .35154 .29959 .35021 Mtetra
.576 .66 .895 r
.29959 .35021 .30061 .35154 .3022 .3513 .30118 .34999 Mtetra
.604 .673 .889 r
.30118 .34999 .3022 .3513 .30381 .35095 .30278 .34966 Mtetra
.655 .696 .876 r
.30278 .34966 .30381 .35095 .30543 .35036 .3044 .34911 Mtetra
.654 .702 .882 r
.3044 .34911 .30543 .35036 .30705 .34979 .30602 .34857 Mtetra
.68 .717 .876 r
.30602 .34857 .30705 .34979 .30868 .34901 .30765 .3479 Mtetra
.687 .738 .89 r
.30765 .3479 .30868 .34901 .31032 .34822 .30928 .34721 Mtetra
.629 .741 .928 r
.30928 .34721 .31032 .34822 .31193 .34785 .31089 .34677 Mtetra
.247 .548 .928 r
.31089 .34677 .31193 .34785 .31343 .34908 .31245 .3472 Mtetra
0 .079 .64 r
.31245 .3472 .31343 .34908 .31462 .35506 .31392 .34897 Mtetra
.096 .069 .535 r
.31392 .34897 .31462 .35506 .30306 .55532 .31526 .35283 Mtetra
.515 .295 .518 r
.31526 .35283 .30306 .55532 .30458 .55813 .31636 .36027 Mtetra
.526 .304 .521 r
.31636 .36027 .30458 .55813 .30629 .55787 .31781 .36261 Mtetra
.543 .318 .524 r
.31781 .36261 .30629 .55787 .30805 .55688 .31974 .35745 Mtetra
.537 .313 .523 r
.31974 .35745 .30805 .55688 .30981 .55594 .3215 .35498 Mtetra
.533 .31 .522 r
.3215 .35498 .30981 .55594 .31155 .55536 .32315 .35421 Mtetra
.32315 .35421 .31155 .55536 .31329 .55477 .3248 .35344 Mtetra
.3248 .35344 .31329 .55477 .31503 .5542 .32645 .35272 Mtetra
.32645 .35272 .31503 .5542 .31677 .55363 .32809 .35207 Mtetra
.32809 .35207 .31677 .55363 .31851 .55308 .32974 .35145 Mtetra
.32974 .35145 .31851 .55308 .32025 .55252 .33138 .35085 Mtetra
.33138 .35085 .32025 .55252 .32199 .55197 .33303 .35026 Mtetra
.33303 .35026 .32199 .55197 .32374 .55143 .33467 .3497 Mtetra
.33467 .3497 .32374 .55143 .32548 .55089 .33631 .34919 Mtetra
.533 .309 .522 r
.33631 .34919 .32548 .55089 .32723 .55037 .33795 .34872 Mtetra
.533 .31 .522 r
.33795 .34872 .32723 .55037 .32897 .54983 .33959 .34824 Mtetra
.53 .307 .521 r
.33959 .34824 .32897 .54983 .3307 .5496 .34117 .34896 Mtetra
.526 .304 .521 r
.34117 .34896 .3307 .5496 .33243 .54952 .34263 .35159 Mtetra
.537 .313 .523 r
.34263 .35159 .33243 .54952 .33419 .54872 .34438 .34929 Mtetra
.548 .322 .524 r
.34438 .34929 .33419 .54872 .33611 .54512 .34642 .34196 Mtetra
.543 .318 .523 r
.34642 .34196 .33611 .54512 .34904 .34334 .34832 .33688 Mtetra
.685 .491 .618 r
.34832 .33688 .34904 .34334 .35107 .33584 .3501 .3339 Mtetra
.76 .658 .75 r
.3501 .3339 .35107 .33584 .35283 .33329 .35181 .33223 Mtetra
.693 .754 .898 r
.35181 .33223 .35283 .33329 .35449 .33247 .35347 .33151 Mtetra
.629 .755 .938 r
.35347 .33151 .35449 .33247 .35613 .33209 .35511 .33105 Mtetra
.626 .738 .928 r
.35511 .33105 .35613 .33209 .35777 .33175 .35675 .33061 Mtetra
.661 .729 .9 r
.35675 .33061 .35777 .33175 .35942 .33119 .35841 .33004 Mtetra
.655 .724 .9 r
.35841 .33004 .35942 .33119 .36107 .33066 .36006 .32948 Mtetra
.639 .716 .903 r
.36006 .32948 .36107 .33066 .36272 .33017 .36171 .329 Mtetra
.619 .709 .91 r
.36171 .329 .36272 .33017 .36437 .32973 .36335 .32859 Mtetra
.623 .718 .914 r
.36335 .32859 .36437 .32973 .36602 .32928 .365 .32817 Mtetra
.656 .734 .907 r
.365 .32817 .36602 .32928 .36767 .32874 .36666 .32761 Mtetra
.697 .742 .886 r
.36666 .32761 .36767 .32874 .36934 .32808 .36833 .32686 Mtetra
.7 .728 .872 r
.36833 .32686 .36934 .32808 .371 .32738 .37 .32608 Mtetra
.705 .715 .857 r
.37 .32608 .371 .32738 .37267 .32665 .37167 .32525 Mtetra
.702 .698 .843 r
.37167 .32525 .37267 .32665 .37434 .32592 .37335 .3244 Mtetra
.648 .661 .849 r
.37335 .3244 .37434 .32592 .376 .32533 .37501 .32384 Mtetra
.459 .58 .888 r
.37501 .32384 .376 .32533 .37765 .32495 .37663 .32401 Mtetra
.625 .115 0 r
.37663 .32401 .37765 .32495 .37929 .32492 .37819 .32581 Mtetra
.877 .519 .367 r
.37819 .32581 .37929 .32492 .3809 .32552 .37958 .33133 Mtetra
.95 .675 .482 r
.37958 .33133 .3809 .32552 .38242 .32824 .37215 .53049 Mtetra
.539 .31 .516 r
.37215 .53049 .38242 .32824 .37508 .52939 .37371 .53472 Mtetra
.614 .302 .417 r
.37371 .53472 .37508 .52939 .37653 .53616 .37539 .53644 Mtetra
.476 0 0 r
.37539 .53644 .37653 .53616 .3782 .53801 .37712 .53706 Mtetra
.522 .736 .972 r
.37712 .53706 .3782 .53801 .37997 .53788 .37888 .53687 Mtetra
.632 .764 .942 r
.37888 .53687 .37997 .53788 .38176 .53723 .38067 .53636 Mtetra
.652 .799 .954 r
.38067 .53636 .38176 .53723 .38355 .53644 .38245 .53577 Mtetra
.594 .827 .988 r
.38245 .53577 .38355 .53644 .38534 .53586 .38424 .53529 Mtetra
.686 .875 .969 r
.38424 .53529 .38534 .53586 .38713 .53513 .38604 .53451 Mtetra
.826 .87 .877 r
.38604 .53451 .38713 .53513 .38894 .53411 .38787 .53298 Mtetra
.895 .768 .714 r
.38787 .53298 .38894 .53411 .39077 .53251 .38977 .52949 Mtetra
.871 .663 .617 r
.38977 .52949 .39077 .53251 .39261 .53065 .39183 .52234 Mtetra
.951 .681 .488 r
.39183 .52234 .39261 .53065 .39444 .52909 .40134 .32504 Mtetra
.534 .311 .522 r
.40134 .32504 .39444 .52909 .39622 .52891 .40304 .32387 Mtetra
.531 .308 .522 r
.40304 .32387 .39622 .52891 .39801 .52837 .40471 .32397 Mtetra
.537 .313 .522 r
.40471 .32397 .39801 .52837 .39987 .52597 .40647 .3213 Mtetra
.543 .318 .523 r
.40647 .3213 .39987 .52597 .40903 .3253 .40834 .31596 Mtetra
.651 .447 .594 r
.40834 .31596 .40903 .3253 .41107 .3152 .41012 .31283 Mtetra
.756 .63 .721 r
.41012 .31283 .41107 .3152 .41285 .31205 .41185 .31089 Mtetra
.703 .741 .881 r
.41185 .31089 .41285 .31205 .41455 .31111 .41355 .31009 Mtetra
.642 .751 .928 r
.41355 .31009 .41455 .31111 .41623 .31066 .41523 .30958 Mtetra
.618 .731 .927 r
.41523 .30958 .41623 .31066 .41791 .31037 .41691 .30916 Mtetra
.661 .721 .893 r
.41691 .30916 .41791 .31037 .41959 .30981 .4186 .30857 Mtetra
.661 .715 .889 r
.4186 .30857 .41959 .30981 .42128 .30925 .42029 .30797 Mtetra
.661 .709 .883 r
.42029 .30797 .42128 .30925 .42297 .30869 .42199 .30738 Mtetra
.662 .703 .878 r
.42199 .30738 .42297 .30869 .42467 .3081 .42368 .30677 Mtetra
.662 .699 .874 r
.42368 .30677 .42467 .3081 .42636 .30751 .42538 .30616 Mtetra
.669 .699 .869 r
.42538 .30616 .42636 .30751 .42806 .30689 .42707 .30551 Mtetra
.701 .705 .851 r
.42707 .30551 .42806 .30689 .42976 .30618 .42878 .30467 Mtetra
.658 .67 .851 r
.42878 .30467 .42976 .30618 .43145 .30557 .43047 .30406 Mtetra
.536 .617 .88 r
.43047 .30406 .43145 .30557 .43314 .30518 .43216 .30399 Mtetra
0 .004 .535 r
.43216 .30399 .43314 .30518 .43482 .30541 .43379 .30574 Mtetra
.88 .487 .284 r
.43379 .30574 .43482 .30541 .43649 .30588 .43535 .31019 Mtetra
.957 .677 .464 r
.43535 .31019 .43649 .30588 .43817 .30627 .43151 .50727 Mtetra
.531 .303 .515 r
.43151 .50727 .43817 .30627 .43988 .30524 .4333 .50747 Mtetra
.527 .3 .514 r
.4333 .50747 .43988 .30524 .44159 .30447 .43515 .50563 Mtetra
.532 .304 .515 r
.43515 .50563 .44159 .30447 .44327 .30476 .43694 .50612 Mtetra
.542 .312 .516 r
.43694 .50612 .44327 .30476 .44467 .31635 .43858 .51213 Mtetra
.536 .307 .515 r
.43858 .51213 .44467 .31635 .44143 .51364 .44032 .51475 Mtetra
.637 .178 .148 r
.44032 .51475 .44143 .51364 .44317 .51673 .44211 .51594 Mtetra
.597 .805 .98 r
.44211 .51594 .44317 .51673 .44498 .51654 .44393 .51548 Mtetra
.7 .777 .912 r
.44393 .51548 .44498 .51654 .44682 .51574 .44576 .51467 Mtetra
.714 .779 .903 r
.44576 .51467 .44682 .51574 .44866 .51469 .4476 .51377 Mtetra
.462 .719 .98 r
.4476 .51377 .44866 .51469 .45048 .5144 .44942 .5137 Mtetra
.518 .798 .996 r
.44942 .5137 .45048 .5144 .45231 .51402 .45124 .51341 Mtetra
.696 .873 .965 r
.45124 .51341 .45231 .51402 .45414 .51342 .45308 .51258 Mtetra
.897 .819 .763 r
.45308 .51258 .45414 .51342 .45598 .51241 .45496 .50982 Mtetra
.866 .675 .642 r
.45496 .50982 .45598 .51241 .45784 .5108 .4569 .50446 Mtetra
.96 .684 .468 r
.4569 .50446 .45784 .5108 .45972 .50794 .46272 .30309 Mtetra
.546 .32 .524 r
.46272 .30309 .45972 .50794 .46521 .31481 .46457 .29615 Mtetra
.595 .381 .56 r
.46457 .29615 .46521 .31481 .46728 .29619 .46634 .29314 Mtetra
.72 .58 .697 r
.46634 .29314 .46728 .29619 .46905 .29255 .46808 .29129 Mtetra
.676 .721 .883 r
.46808 .29129 .46905 .29255 .47078 .29163 .46981 .29061 Mtetra
.587 .736 .946 r
.46981 .29061 .47078 .29163 .4725 .29128 .47152 .29028 Mtetra
.528 .717 .959 r
.47152 .29028 .4725 .29128 .47422 .29122 .47324 .29011 Mtetra
.653 .742 .915 r
.47324 .29011 .47422 .29122 .47594 .29066 .47497 .28954 Mtetra
.672 .746 .906 r
.47497 .28954 .47594 .29066 .47767 .29005 .4767 .28889 Mtetra
.686 .744 .895 r
.4767 .28889 .47767 .29005 .4794 .28938 .47843 .28817 Mtetra
.777 .758 .836 r
.47843 .28817 .4794 .28938 .48113 .28812 .48017 .28684 Mtetra
.721 .732 .86 r
.48017 .28684 .48113 .28812 .48287 .28724 .4819 .28589 Mtetra
.569 .664 .902 r
.4819 .28589 .48287 .28724 .48459 .28707 .48363 .28567 Mtetra
.844 .428 0 r
.48363 .28567 .48459 .28707 .48626 .29134 .4853 .28977 Mtetra
.968 .684 .439 r
.4853 .28977 .48626 .29134 .48555 .49771 .48451 .49649 Mtetra
.912 .515 .125 r
.48451 .49649 .48555 .49771 .48733 .50312 .48629 .50214 Mtetra
.379 .664 .97 r
.48629 .50214 .48733 .50312 .48918 .50328 .48814 .50228 Mtetra
.7 .794 .923 r
.48814 .50228 .48918 .50328 .49104 .50248 .49 .50145 Mtetra
.771 .803 .879 r
.49 .50145 .49104 .50248 .4929 .50125 .49187 .5002 Mtetra
.451 .685 .966 r
.49187 .5002 .4929 .50125 .49476 .5012 .49372 .50021 Mtetra
.535 .74 .97 r
.49372 .50021 .49476 .5012 .49662 .50088 .49558 .49998 Mtetra
.73 .821 .921 r
.49558 .49998 .49662 .50088 .49848 .49983 .49745 .49901 Mtetra
.947 .791 .654 r
.49745 .49901 .49848 .49983 .50038 .49457 .49935 .49394 Mtetra
.969 .69 .447 r
.49935 .49394 .50038 .49457 .50365 .28727 .50269 .28663 Mtetra
.966 .769 .586 r
.50269 .28663 .50365 .28727 .50544 .28027 .50448 .27918 Mtetra
.811 .785 .829 r
.50448 .27918 .50544 .28027 .50719 .27873 .50623 .2776 Mtetra
.656 .741 .913 r
.50623 .2776 .50719 .27873 .50894 .27817 .50798 .27702 Mtetra
.55 .696 .936 r
.50798 .27702 .50894 .27817 .51068 .27799 .50973 .27682 Mtetra
.758 .763 .857 r
.50973 .27682 .51068 .27799 .51243 .27691 .51148 .27566 Mtetra
.725 .741 .865 r
.51148 .27566 .51243 .27691 .51419 .27602 .51323 .2747 Mtetra
.586 .676 .902 r
.51323 .2747 .51419 .27602 .51593 .2758 .51498 .2744 Mtetra
.745 .314 0 r
.51498 .2744 .51593 .2758 .51768 .27926 .51672 .27774 Mtetra
.97 .683 .427 r
.51672 .27774 .51768 .27926 .51907 .48569 .51805 .48434 Mtetra
.925 .543 .152 r
.51805 .48434 .51907 .48569 .52093 .49219 .51991 .49117 Mtetra
.208 .558 .935 r
.51991 .49117 .52093 .49219 .52281 .49269 .52179 .49166 Mtetra
.685 .787 .928 r
.52179 .49166 .52281 .49269 .52469 .49196 .52367 .4909 Mtetra
.766 .8 .88 r
.52367 .4909 .52469 .49196 .52657 .49076 .52555 .48967 Mtetra
.503 .703 .96 r
.52555 .48967 .52657 .49076 .52846 .49059 .52744 .48956 Mtetra
.514 .722 .967 r
.52744 .48956 .52846 .49059 .53034 .49034 .52932 .48939 Mtetra
.704 .809 .93 r
.52932 .48939 .53034 .49034 .53223 .48941 .53121 .48854 Mtetra
.94 .802 .679 r
.53121 .48854 .53223 .48941 .5341 .48492 .53309 .4842 Mtetra
.972 .689 .435 r
.53309 .4842 .5341 .48492 .5353 .27838 .53435 .27802 Mtetra
.98 .766 .545 r
.53435 .27802 .5353 .27838 .53703 .2696 .53609 .2685 Mtetra
.843 .791 .8 r
.53609 .2685 .53703 .2696 .53879 .2677 .53785 .26656 Mtetra
.67 .746 .908 r
.53785 .26656 .53879 .2677 .54056 .26705 .53961 .2659 Mtetra
.55 .697 .937 r
.53961 .2659 .54056 .26705 .54233 .26685 .54138 .2657 Mtetra
.721 .76 .884 r
.54138 .2657 .54233 .26685 .5441 .26594 .54315 .26478 Mtetra
.714 .757 .886 r
.54315 .26478 .5441 .26594 .54586 .26507 .54492 .2639 Mtetra
.569 .702 .931 r
.54492 .2639 .54586 .26507 .54764 .26481 .5467 .26364 Mtetra
.697 .238 0 r
.5467 .26364 .54764 .26481 .54944 .26766 .54849 .26648 Mtetra
.972 .681 .415 r
.54849 .26648 .54944 .26766 .55297 .47292 .55196 .47179 Mtetra
.934 .559 .192 r
.55196 .47179 .55297 .47292 .55494 .48075 .55393 .47965 Mtetra
0 .241 .734 r
.55393 .47965 .55494 .48075 .55686 .48208 .55585 .481 Mtetra
.567 .735 .955 r
.55585 .481 .55686 .48208 .55877 .48176 .55776 .48069 Mtetra
.791 .805 .864 r
.55776 .48069 .55877 .48176 .56066 .48032 .55966 .47925 Mtetra
.938 .783 .663 r
.55966 .47925 .56066 .48032 .56252 .47563 .56152 .47452 Mtetra
.973 .688 .426 r
.56152 .47452 .56252 .47563 .56194 .26794 .561 .26652 Mtetra
.949 .735 .581 r
.561 .26652 .56194 .26794 .56364 .25992 .5627 .25865 Mtetra
.828 .766 .794 r
.5627 .25865 .56364 .25992 .5654 .25798 .56447 .25675 Mtetra
.627 .714 .909 r
.56447 .25675 .5654 .25798 .56719 .25747 .56625 .25627 Mtetra
.481 .656 .937 r
.56625 .25627 .56719 .25747 .56898 .25743 .56805 .25628 Mtetra
.584 .714 .933 r
.56805 .25628 .56898 .25743 .57077 .2571 .56984 .25597 Mtetra
.655 .746 .917 r
.56984 .25597 .57077 .2571 .57256 .25651 .57163 .25537 Mtetra
.666 .748 .911 r
.57163 .25537 .57256 .25651 .57435 .25589 .57342 .25473 Mtetra
.74 .767 .875 r
.57342 .25473 .57435 .25589 .57613 .25486 .5752 .25368 Mtetra
.727 .761 .88 r
.5752 .25368 .57613 .25486 .57792 .2539 .57699 .25271 Mtetra
.6 .713 .924 r
.57699 .25271 .57792 .2539 .57971 .25353 .57878 .25234 Mtetra
.559 .102 0 r
.57878 .25234 .57971 .25353 .58156 .25593 .58063 .25472 Mtetra
.974 .68 .402 r
.58063 .25472 .58156 .25593 .58726 .46056 .58626 .45928 Mtetra
.94 .574 .197 r
.58626 .45928 .58726 .46056 .58936 .46969 .58837 .46855 Mtetra
0 .155 .667 r
.58837 .46855 .58936 .46969 .59133 .47131 .59034 .47018 Mtetra
.538 .715 .954 r
.59034 .47018 .59133 .47131 .59327 .47109 .59228 .46997 Mtetra
.768 .796 .876 r
.59228 .46997 .59327 .47109 .59519 .46982 .5942 .46869 Mtetra
.923 .793 .699 r
.5942 .46869 .59519 .46982 .59705 .46599 .59606 .46486 Mtetra
.975 .687 .413 r
.59606 .46486 .59705 .46599 .59444 .26418 .59351 .26274 Mtetra
.967 .719 .509 r
.59351 .26274 .59444 .26418 .59593 .2496 .59501 .2484 Mtetra
.875 .784 .757 r
.59501 .2484 .59593 .2496 .59769 .24707 .59677 .24587 Mtetra
.684 .745 .897 r
.59677 .24587 .59769 .24707 .59949 .24633 .59857 .24513 Mtetra
.561 .693 .929 r
.59857 .24513 .59949 .24633 .60131 .2461 .60039 .24489 Mtetra
.651 .73 .907 r
.60039 .24489 .60131 .2461 .60312 .24562 .6022 .2443 Mtetra
.698 .729 .874 r
.6022 .2443 .60312 .24562 .60492 .24488 .604 .24347 Mtetra
.635 .689 .884 r
.604 .24347 .60492 .24488 .60673 .24425 .60581 .24295 Mtetra
.299 .535 .911 r
.60581 .24295 .60673 .24425 .60855 .2438 .60766 .24348 Mtetra
.743 .223 0 r
.60766 .24348 .60855 .2438 .61038 .24369 .60955 .2458 Mtetra
.903 .553 .371 r
.60955 .2458 .61038 .24369 .61222 .24426 .61168 .25645 Mtetra
.961 .661 .417 r
.61168 .25645 .61222 .24426 .61417 .24804 .61921 .4537 Mtetra
.536 .307 .515 r
.61921 .4537 .61417 .24804 .62209 .45315 .62126 .45687 Mtetra
.601 .25 .347 r
.62126 .45687 .62209 .45315 .62422 .45851 .62327 .45818 Mtetra
0 .459 .747 r
.62327 .45818 .62422 .45851 .62623 .45995 .62525 .45867 Mtetra
.54 .689 .935 r
.62525 .45867 .62623 .45995 .6282 .45983 .62722 .45849 Mtetra
.718 .749 .876 r
.62722 .45849 .6282 .45983 .63013 .45872 .62916 .45748 Mtetra
.907 .789 .719 r
.62916 .45748 .63013 .45872 .632 .45525 .63102 .45408 Mtetra
.976 .685 .4 r
.63102 .45408 .632 .45525 .62756 .26258 .62654 .25839 Mtetra
.942 .672 .498 r
.62654 .25839 .62756 .26258 .62859 .23822 .62768 .23701 Mtetra
.893 .786 .736 r
.62768 .23701 .62859 .23822 .63034 .23534 .62943 .23414 Mtetra
.702 .754 .892 r
.62943 .23414 .63034 .23534 .63216 .2345 .63125 .2333 Mtetra
.586 .709 .928 r
.63125 .2333 .63216 .2345 .634 .23416 .63309 .23297 Mtetra
.665 .742 .907 r
.63309 .23297 .634 .23416 .63583 .23351 .63492 .23231 Mtetra
.733 .765 .879 r
.63492 .23231 .63583 .23351 .63764 .23249 .63674 .2313 Mtetra
.636 .73 .917 r
.63674 .2313 .63764 .23249 .63948 .23197 .63857 .23077 Mtetra
0 .282 .78 r
.63857 .23077 .63948 .23197 .64138 .23329 .64048 .23209 Mtetra
.938 .574 .186 r
.64048 .23209 .64138 .23329 .64362 .24317 .64272 .24198 Mtetra
.975 .675 .374 r
.64272 .24198 .64362 .24317 .65353 .44753 .65257 .44639 Mtetra
0 0 .512 r
.65257 .44639 .65353 .44753 .65561 .4498 .65465 .44866 Mtetra
.629 .756 .938 r
.65465 .44866 .65561 .4498 .65759 .44925 .65663 .44811 Mtetra
.769 .801 .879 r
.65663 .44811 .65759 .44925 .65953 .44796 .65858 .44682 Mtetra
.782 .804 .87 r
.65858 .44682 .65953 .44796 .66148 .44657 .66052 .44542 Mtetra
.73 .791 .901 r
.66052 .44542 .66148 .44657 .66343 .44553 .66248 .44439 Mtetra
.716 .787 .908 r
.66248 .44439 .66343 .44553 .66539 .44457 .66444 .44343 Mtetra
.656 .767 .931 r
.66444 .44343 .66539 .44457 .66737 .4439 .66642 .44276 Mtetra
.565 .729 .952 r
.66642 .44276 .66737 .4439 .66936 .4436 .66841 .44245 Mtetra
.536 .715 .955 r
.66841 .44245 .66936 .4436 .67136 .44338 .67041 .44224 Mtetra
.443 .668 .958 r
.67041 .44224 .67136 .44338 .67338 .44345 .67243 .4423 Mtetra
.414 .652 .957 r
.67243 .4423 .67338 .44345 .67539 .44359 .67444 .44244 Mtetra
.628 .755 .938 r
.67444 .44244 .67539 .44359 .67738 .44304 .67644 .44189 Mtetra
.89 .812 .765 r
.67644 .44189 .67738 .44304 .67927 .44033 .67832 .43917 Mtetra
.981 .723 .465 r
.67832 .43917 .67927 .44033 .68042 .4222 .67948 .42107 Mtetra
.977 .682 .379 r
.67948 .42107 .68042 .4222 .67275 .22294 .67186 .22173 Mtetra
.912 .79 .714 r
.67186 .22173 .67275 .22294 .67448 .21967 .67359 .21846 Mtetra
.709 .759 .891 r
.67359 .21846 .67448 .21967 .67632 .21879 .67544 .21758 Mtetra
.589 .71 .928 r
.67544 .21758 .67632 .21879 .67819 .21844 .67731 .21723 Mtetra
.625 .727 .92 r
.67731 .21723 .67819 .21844 .68006 .21795 .67917 .21674 Mtetra
.734 .768 .88 r
.67917 .21674 .68006 .21795 .6819 .21692 .68101 .21571 Mtetra
.644 .736 .915 r
.68101 .21571 .6819 .21692 .68376 .21634 .68288 .21514 Mtetra
.087 .418 .866 r
.68288 .21514 .68376 .21634 .68571 .21729 .68483 .2161 Mtetra
.913 .533 .109 r
.68483 .2161 .68571 .21729 .68804 .2255 .68717 .22444 Mtetra
.975 .671 .352 r
.68717 .22444 .68804 .2255 .70115 .43236 .70022 .43125 Mtetra
.603 .134 0 r
.70022 .43125 .70115 .43236 .70335 .43527 .70241 .43414 Mtetra
.552 .728 .956 r
.70241 .43414 .70335 .43527 .70537 .435 .70444 .43386 Mtetra
.713 .791 .912 r
.70444 .43386 .70537 .435 .70736 .43405 .70643 .43291 Mtetra
.697 .784 .918 r
.70643 .43291 .70736 .43405 .70936 .43319 .70843 .43204 Mtetra
.515 .706 .957 r
.70843 .43204 .70936 .43319 .7114 .43305 .71046 .43189 Mtetra
.656 .767 .931 r
.71046 .43189 .7114 .43305 .7134 .43238 .71247 .43121 Mtetra
.867 .817 .797 r
.71247 .43121 .7134 .43238 .71532 .43008 .71439 .42891 Mtetra
.979 .752 .523 r
.71439 .42891 .71532 .43008 .71678 .4201 .71585 .41889 Mtetra
.977 .678 .362 r
.71585 .41889 .71678 .4201 .70638 .21203 .70551 .21079 Mtetra
.933 .787 .676 r
.70551 .21079 .70638 .21203 .70806 .20806 .70719 .20683 Mtetra
.728 .764 .882 r
.70719 .20683 .70806 .20806 .70992 .20705 .70904 .20582 Mtetra
.602 .714 .923 r
.70904 .20582 .70992 .20705 .71181 .20665 .71094 .20542 Mtetra
.601 .714 .923 r
.71094 .20542 .71181 .20665 .71371 .20625 .71283 .20502 Mtetra
.74 .768 .876 r
.71283 .20502 .71371 .20625 .71556 .20517 .71469 .20393 Mtetra
.657 .738 .909 r
.71469 .20393 .71556 .20517 .71744 .20453 .71657 .2033 Mtetra
.236 .51 .907 r
.71657 .2033 .71744 .20453 .71941 .20521 .71854 .20396 Mtetra
.883 .491 .035 r
.71854 .20396 .71941 .20521 .72182 .21257 .72095 .21129 Mtetra
.975 .667 .334 r
.72095 .21129 .72182 .21257 .73739 .42075 .73647 .41955 Mtetra
.649 .197 0 r
.73647 .41955 .73739 .42075 .73969 .42421 .73877 .42303 Mtetra
.385 .63 .951 r
.73877 .42303 .73969 .42421 .74178 .42446 .74086 .42327 Mtetra
.693 .778 .917 r
.74086 .42327 .74178 .42446 .7438 .4236 .74288 .42241 Mtetra
.872 .817 .792 r
.74288 .42241 .7438 .4236 .74572 .42123 .7448 .42003 Mtetra
.977 .766 .551 r
.7448 .42003 .74572 .42123 .74725 .41329 .74633 .412 Mtetra
.977 .675 .348 r
.74633 .412 .74725 .41329 .73474 .20296 .73387 .20167 Mtetra
.946 .78 .643 r
.73387 .20167 .73474 .20296 .73636 .1983 .73549 .19703 Mtetra
.734 .762 .876 r
.73549 .19703 .73636 .1983 .73822 .19723 .73736 .19597 Mtetra
.599 .709 .921 r
.73736 .19597 .73822 .19723 .74014 .19683 .73928 .19558 Mtetra
.537 .68 .93 r
.73928 .19558 .74014 .19683 .74207 .19666 .74122 .19541 Mtetra
.659 .738 .908 r
.74122 .19541 .74207 .19666 .74397 .196 .74312 .19476 Mtetra
.665 .742 .908 r
.74312 .19476 .74397 .196 .74587 .19531 .74502 .19408 Mtetra
.689 .754 .901 r
.74502 .19408 .74587 .19531 .74777 .19451 .74691 .19328 Mtetra
.761 .78 .869 r
.74691 .19328 .74777 .19451 .74963 .19329 .74878 .19206 Mtetra
.686 .754 .903 r
.74878 .19206 .74963 .19329 .75152 .1925 .75067 .19128 Mtetra
.388 .607 .935 r
.75067 .19128 .75152 .1925 .7535 .19277 .75265 .19156 Mtetra
.826 .416 0 r
.75265 .19156 .7535 .19277 .7559 .19861 .75506 .19745 Mtetra
.973 .662 .315 r
.75506 .19745 .7559 .19861 .77404 .40829 .77314 .40714 Mtetra
.71 .264 0 r
.77314 .40714 .77404 .40829 .77647 .41244 .77557 .41126 Mtetra
.339 .605 .947 r
.77557 .41126 .77647 .41244 .7786 .41281 .7777 .41163 Mtetra
.672 .774 .927 r
.7777 .41163 .7786 .41281 .78065 .41205 .77976 .41086 Mtetra
.854 .822 .816 r
.77976 .41086 .78065 .41205 .7826 .40995 .7817 .40875 Mtetra
.978 .776 .564 r
.7817 .40875 .7826 .40995 .78414 .40281 .78324 .40158 Mtetra
.976 .671 .329 r
.78324 .40158 .78414 .40281 .76913 .19147 .76828 .19019 Mtetra
.96 .779 .614 r
.76828 .19019 .76913 .19147 .77067 .18616 .76982 .18489 Mtetra
.752 .772 .87 r
.76982 .18489 .77067 .18616 .77254 .18497 .7717 .18372 Mtetra
.618 .721 .919 r
.7717 .18372 .77254 .18497 .77448 .18449 .77364 .18324 Mtetra
.539 .684 .933 r
.77364 .18324 .77448 .18449 .77644 .18429 .7756 .18306 Mtetra
.704 .762 .897 r
.7756 .18306 .77644 .18429 .77833 .18326 .77751 .18218 Mtetra
.671 .78 .931 r
.77751 .18218 .77833 .18326 .78025 .18254 .77943 .18146 Mtetra
.578 .741 .954 r
.77943 .18146 .78025 .18254 .78223 .18248 .78138 .1811 Mtetra
.27 .503 .896 r
.78138 .1811 .78223 .18248 .78447 .18548 .78343 .1818 Mtetra
.296 .298 .692 r
.78343 .1818 .78447 .18548 .80425 .39002 .78559 .18377 Mtetra
.518 .299 .521 r
.78559 .18377 .80425 .39002 .8072 .39942 .78822 .19116 Mtetra
.04 0 .432 r
.78822 .19116 .8072 .39942 .80945 .40066 .80809 .39406 Mtetra
.273 .219 .612 r
.80809 .39406 .80945 .40066 .81161 .40092 .81056 .39789 Mtetra
.307 .352 .745 r
.81056 .39789 .81161 .40092 .81373 .4007 .81284 .39943 Mtetra
.337 .586 .935 r
.81284 .39943 .81373 .4007 .81589 .40086 .81503 .39986 Mtetra
.574 .775 .974 r
.81503 .39986 .81589 .40086 .81799 .40043 .81713 .39944 Mtetra
.787 .855 .901 r
.81713 .39944 .81799 .40043 .82002 .39914 .81916 .39805 Mtetra
.892 .718 .659 r
.15383 .60532 .15496 .60664 .1571 .60139 .15601 .59978 Mtetra
.935 .685 .535 r
.15601 .59978 .1571 .60139 .18025 .3998 .17922 .39823 Mtetra
.889 .7 .641 r
.17922 .39823 .18025 .3998 .18246 .39305 .18138 .39199 Mtetra
.772 .751 .834 r
.18138 .39199 .18246 .39305 .18408 .3918 .183 .39077 Mtetra
.643 .733 .914 r
.183 .39077 .18408 .3918 .18562 .39132 .18454 .3903 Mtetra
.515 .691 .947 r
.18454 .3903 .18562 .39132 .18712 .39124 .18604 .39021 Mtetra
.75 .754 .855 r
.18604 .39021 .18712 .39124 .18872 .3902 .18764 .38918 Mtetra
.699 .747 .889 r
.18764 .38918 .18872 .3902 .19028 .38949 .18921 .38846 Mtetra
.493 .682 .95 r
.18921 .38846 .19028 .38949 .19178 .38944 .1907 .38842 Mtetra
.926 .542 .242 r
.1907 .38842 .19178 .38944 .19287 .39342 .19179 .39239 Mtetra
.939 .683 .523 r
.19179 .39239 .19287 .39342 .17378 .59377 .17262 .59278 Mtetra
.936 .586 .331 r
.17262 .59278 .17378 .59377 .1748 .59936 .17364 .59839 Mtetra
.251 .593 .949 r
.17364 .59839 .1748 .59936 .17636 .59969 .1752 .59872 Mtetra
.671 .766 .922 r
.1752 .59872 .17636 .59969 .17803 .59907 .17687 .5981 Mtetra
.749 .777 .876 r
.17687 .5981 .17803 .59907 .17973 .59804 .17857 .59706 Mtetra
.477 .701 .967 r
.17857 .59706 .17973 .59804 .18134 .59799 .18018 .59701 Mtetra
.584 .74 .95 r
.18018 .59701 .18134 .59799 .18297 .59768 .18181 .59669 Mtetra
.749 .775 .875 r
.18181 .59669 .18297 .59768 .18468 .59664 .18352 .59565 Mtetra
.906 .741 .666 r
.18352 .59565 .18468 .59664 .1868 .59146 .18565 .59044 Mtetra
.939 .687 .529 r
.18565 .59044 .1868 .59146 .20828 .38981 .20721 .38874 Mtetra
.911 .725 .637 r
.20721 .38874 .20828 .38981 .21043 .38329 .20935 .38227 Mtetra
.793 .76 .823 r
.20935 .38227 .21043 .38329 .21208 .38187 .211 .38086 Mtetra
.636 .736 .92 r
.211 .38086 .21208 .38187 .21363 .38141 .21256 .38041 Mtetra
.491 .687 .954 r
.21256 .38041 .21363 .38141 .21515 .38135 .21407 .38036 Mtetra
.657 .746 .916 r
.21407 .38036 .21515 .38135 .21673 .38068 .21564 .37983 Mtetra
.676 .781 .929 r
.21564 .37983 .21673 .38068 .2183 .38003 .21721 .37922 Mtetra
.66 .788 .943 r
.21721 .37922 .2183 .38003 .21985 .37966 .21878 .37868 Mtetra
.694 .758 .901 r
.21878 .37868 .21985 .37966 .22132 .38017 .22036 .37799 Mtetra
.612 .565 .777 r
.22036 .37799 .22132 .38017 .22269 .38175 .22192 .37758 Mtetra
.516 .409 .671 r
.22192 .37758 .22269 .38175 .2238 .38619 .22341 .37783 Mtetra
.196 .108 .522 r
.22341 .37783 .2238 .38619 .20708 .58153 .22454 .38202 Mtetra
0 0 .141 r
.22454 .38202 .20708 .58153 .20824 .58645 .20742 .58197 Mtetra
0 0 .251 r
.20742 .58197 .20824 .58645 .2097 .58831 .20857 .58707 Mtetra
.157 .476 .896 r
.20857 .58707 .2097 .58831 .21129 .58859 .21014 .5877 Mtetra
.639 .776 .946 r
.21014 .5877 .21129 .58859 .21296 .58813 .21181 .58719 Mtetra
.745 .787 .886 r
.21181 .58719 .21296 .58813 .21469 .58709 .21353 .58618 Mtetra
.661 .78 .937 r
.21353 .58618 .21469 .58709 .21648 .58527 .21521 .58559 Mtetra
.461 .887 .818 r
.21521 .58559 .21648 .58527 .21838 .58226 .21692 .58481 Mtetra
.075 0 .026 r
.21692 .58481 .21838 .58226 .2206 .57561 .21869 .58327 Mtetra
0 0 .153 r
.21869 .58327 .2206 .57561 .23978 .3786 .22086 .57722 Mtetra
0 0 .134 r
.22086 .57722 .23978 .3786 .24177 .37344 .24041 .37578 Mtetra
.955 .908 .536 r
.24041 .37578 .24177 .37344 .24354 .3708 .24242 .3704 Mtetra
.852 .875 .857 r
.24242 .3704 .24354 .3708 .24517 .36964 .2441 .3688 Mtetra
.663 .784 .939 r
.2441 .3688 .24517 .36964 .24676 .36909 .24568 .36824 Mtetra
.528 .739 .972 r
.24568 .36824 .24676 .36909 .24832 .36881 .24723 .36806 Mtetra
.598 .787 .971 r
.24723 .36806 .24832 .36881 .24988 .36848 .2488 .36768 Mtetra
.638 .787 .953 r
.2488 .36768 .24988 .36848 .25145 .36811 .25039 .3672 Mtetra
.646 .763 .934 r
.25039 .3672 .25145 .36811 .25303 .36771 .25197 .3667 Mtetra
.676 .751 .907 r
.25197 .3667 .25303 .36771 .25464 .36693 .25356 .36608 Mtetra
.683 .788 .93 r
.25356 .36608 .25464 .36693 .25625 .36611 .25516 .36545 Mtetra
.658 .825 .964 r
.25516 .36545 .25625 .36611 .25784 .36556 .25675 .36488 Mtetra
.539 .787 .99 r
.25675 .36488 .25784 .36556 .25933 .36616 .25832 .36461 Mtetra
.543 .606 .866 r
.25832 .36461 .25933 .36616 .26072 .36807 .25987 .36453 Mtetra
.551 .453 .697 r
.25987 .36453 .26072 .36807 .26192 .3723 .26143 .36448 Mtetra
.56 .387 .604 r
.26143 .36448 .26192 .3723 .26305 .37755 .26301 .36412 Mtetra
.556 .359 .57 r
.26301 .36412 .26305 .37755 .26461 .3775 .26461 .36353 Mtetra
.557 .359 .568 r
.26461 .36353 .26461 .3775 .26644 .37415 .26621 .36287 Mtetra
.573 .38 .581 r
.26621 .36287 .26644 .37415 .26823 .37119 .26784 .36189 Mtetra
.576 .39 .592 r
.26784 .36189 .26823 .37119 .26991 .36966 .26947 .36105 Mtetra
.549 .373 .596 r
.26947 .36105 .26991 .36966 .27143 .37024 .27104 .36086 Mtetra
.357 .223 .557 r
.27104 .36086 .27143 .37024 .25774 .56346 .27235 .36387 Mtetra
0 0 .176 r
.27235 .36387 .25774 .56346 .25887 .57026 .25811 .56458 Mtetra
0 0 .263 r
.25811 .56458 .25887 .57026 .26033 .57279 .25927 .57096 Mtetra
.115 .339 .807 r
.25927 .57096 .26033 .57279 .26196 .57325 .26085 .57203 Mtetra
.623 .711 .909 r
.26085 .57203 .26196 .57325 .26366 .57278 .26255 .5716 Mtetra
.716 .743 .873 r
.26255 .5716 .26366 .57278 .26539 .57201 .26429 .5707 Mtetra
.682 .714 .873 r
.26429 .5707 .26539 .57201 .26711 .57136 .26601 .56998 Mtetra
.645 .691 .879 r
.26601 .56998 .26711 .57136 .26882 .57083 .26772 .56945 Mtetra
.647 .692 .878 r
.26772 .56945 .26882 .57083 .27053 .57029 .26943 .5689 Mtetra
.567 .661 .901 r
.26943 .5689 .27053 .57029 .27222 .57009 .27112 .56869 Mtetra
.579 .664 .896 r
.27112 .56869 .27222 .57009 .27391 .56985 .27282 .56844 Mtetra
.701 .705 .85 r
.27282 .56844 .27391 .56985 .27565 .569 .27456 .56758 Mtetra
.868 .729 .706 r
.27456 .56758 .27565 .569 .27758 .56553 .27649 .56407 Mtetra
.948 .689 .509 r
.27649 .56407 .27758 .56553 .2937 .36631 .29269 .36473 Mtetra
.926 .703 .581 r
.29269 .36473 .2937 .36631 .29621 .35342 .29515 .35263 Mtetra
.878 .795 .765 r
.29515 .35263 .29621 .35342 .29796 .35093 .2969 .35017 Mtetra
.695 .814 .938 r
.2969 .35017 .29796 .35093 .29959 .35021 .29853 .34947 Mtetra
.521 .767 .987 r
.29853 .34947 .29959 .35021 .30118 .34999 .30012 .34926 Mtetra
.568 .787 .982 r
.30012 .34926 .30118 .34999 .30278 .34966 .30172 .34894 Mtetra
.651 .813 .961 r
.30172 .34894 .30278 .34966 .3044 .34911 .30334 .34839 Mtetra
.65 .813 .962 r
.30334 .34839 .3044 .34911 .30602 .34857 .30496 .34784 Mtetra
.661 .814 .957 r
.30496 .34784 .30602 .34857 .30765 .3479 .30658 .34726 Mtetra
.659 .835 .968 r
.30658 .34726 .30765 .3479 .30928 .34721 .30821 .34667 Mtetra
.626 .85 .985 r
.30821 .34667 .30928 .34721 .31089 .34677 .30983 .34614 Mtetra
.541 .804 .994 r
.30983 .34614 .31089 .34677 .31245 .3472 .31143 .34584 Mtetra
.535 .637 .898 r
.31143 .34584 .31245 .3472 .31392 .34897 .31303 .34575 Mtetra
.551 .468 .715 r
.31303 .34575 .31392 .34897 .31526 .35283 .31462 .34571 Mtetra
.558 .391 .612 r
.31462 .34571 .31526 .35283 .31636 .36027 .31623 .34543 Mtetra
.553 .354 .565 r
.31623 .34543 .31636 .36027 .31781 .36261 .31786 .34485 Mtetra
.551 .348 .558 r
.31786 .34485 .31781 .36261 .31974 .35745 .3195 .34418 Mtetra
.557 .361 .571 r
.3195 .34418 .31974 .35745 .3215 .35498 .32113 .34353 Mtetra
.56 .368 .579 r
.32113 .34353 .3215 .35498 .32315 .35421 .32277 .34293 Mtetra
.56 .369 .58 r
.32277 .34293 .32315 .35421 .3248 .35344 .3244 .34233 Mtetra
.56 .37 .58 r
.3244 .34233 .3248 .35344 .32645 .35272 .32604 .34174 Mtetra
.56 .371 .581 r
.32604 .34174 .32645 .35272 .32809 .35207 .32767 .34115 Mtetra
.32767 .34115 .32809 .35207 .32974 .35145 .32931 .34056 Mtetra
.56 .371 .582 r
.32931 .34056 .32974 .35145 .33138 .35085 .33095 .33998 Mtetra
.33095 .33998 .33138 .35085 .33303 .35026 .33259 .3394 Mtetra
.33259 .3394 .33303 .35026 .33467 .3497 .33423 .33882 Mtetra
.33423 .33882 .33467 .3497 .33631 .34919 .33587 .33825 Mtetra
.56 .37 .581 r
.33587 .33825 .33631 .34919 .33795 .34872 .33751 .33768 Mtetra
.559 .37 .581 r
.33751 .33768 .33795 .34872 .33959 .34824 .33915 .33711 Mtetra
.558 .368 .58 r
.33915 .33711 .33959 .34824 .34117 .34896 .34079 .33659 Mtetra
.554 .361 .574 r
.34079 .33659 .34117 .34896 .34263 .35159 .34243 .33609 Mtetra
.552 .352 .563 r
.34243 .33609 .34263 .35159 .34438 .34929 .34408 .33551 Mtetra
.562 .364 .57 r
.34408 .33551 .34438 .34929 .34642 .34196 .34574 .33466 Mtetra
.598 .42 .612 r
.34574 .33466 .34642 .34196 .34832 .33688 .34742 .33356 Mtetra
.655 .529 .699 r
.34742 .33356 .34832 .33688 .3501 .3339 .3491 .3325 Mtetra
.705 .698 .841 r
.3491 .3325 .3501 .3339 .35181 .33223 .35076 .33164 Mtetra
.657 .85 .974 r
.35076 .33164 .35181 .33223 .35347 .33151 .35241 .33102 Mtetra
.616 .865 .99 r
.35241 .33102 .35347 .33151 .35511 .33105 .35406 .33049 Mtetra
.627 .849 .984 r
.35406 .33049 .35511 .33105 .35675 .33061 .35571 .32995 Mtetra
.652 .832 .969 r
.35571 .32995 .35675 .33061 .35841 .33004 .35737 .32937 Mtetra
.651 .831 .969 r
.35737 .32937 .35841 .33004 .36006 .32948 .35902 .32879 Mtetra
.647 .824 .968 r
.35902 .32879 .36006 .32948 .36171 .329 .36067 .32823 Mtetra
.645 .806 .96 r
.36067 .32823 .36171 .329 .36335 .32859 .36233 .32769 Mtetra
.653 .776 .939 r
.36233 .32769 .36335 .32859 .365 .32817 .36398 .32714 Mtetra
.665 .753 .915 r
.36398 .32714 .365 .32817 .36666 .32761 .36564 .32655 Mtetra
.679 .749 .904 r
.36564 .32655 .36666 .32761 .36833 .32686 .36731 .32589 Mtetra
.682 .77 .918 r
.36731 .32589 .36833 .32686 .37 .32608 .36897 .32523 Mtetra
.714 .803 .92 r
.36897 .32523 .37 .32608 .37167 .32525 .37064 .32443 Mtetra
.743 .815 .908 r
.37064 .32443 .37167 .32525 .37335 .3244 .37232 .32348 Mtetra
.646 .773 .94 r
.37232 .32348 .37335 .3244 .37501 .32384 .37398 .32295 Mtetra
0 .406 .84 r
.37398 .32295 .37501 .32384 .37663 .32401 .37559 .32368 Mtetra
.918 .543 .29 r
.37559 .32368 .37663 .32401 .37819 .32581 .37697 .32904 Mtetra
.953 .679 .48 r
.37697 .32904 .37819 .32581 .37958 .33133 .3692 .53201 Mtetra
.538 .309 .516 r
.3692 .53201 .37958 .33133 .37215 .53049 .37077 .53597 Mtetra
.535 .229 .395 r
.37077 .53597 .37215 .53049 .37371 .53472 .3725 .53636 Mtetra
.352 0 .064 r
.3725 .53636 .37371 .53472 .37539 .53644 .37427 .53607 Mtetra
.561 .881 .992 r
.37427 .53607 .37539 .53644 .37712 .53706 .37605 .53554 Mtetra
.622 .667 .872 r
.37605 .53554 .37712 .53706 .37888 .53687 .37783 .53509 Mtetra
.638 .639 .835 r
.37783 .53509 .37888 .53687 .38067 .53636 .37962 .53454 Mtetra
.625 .628 .834 r
.37962 .53454 .38067 .53636 .38245 .53577 .3814 .53406 Mtetra
.58 .623 .859 r
.3814 .53406 .38245 .53577 .38424 .53529 .38318 .53381 Mtetra
.667 .691 .863 r
.38318 .53381 .38424 .53529 .38604 .53451 .38497 .53313 Mtetra
.811 .742 .787 r
.38497 .53313 .38604 .53451 .38787 .53298 .38682 .53121 Mtetra
.909 .713 .626 r
.38682 .53121 .38787 .53298 .38977 .52949 .38886 .5245 Mtetra
.955 .685 .485 r
.38886 .5245 .38977 .52949 .39183 .52234 .39883 .31991 Mtetra
.542 .317 .523 r
.39883 .31991 .39183 .52234 .40134 .32504 .40068 .31501 Mtetra
.578 .389 .588 r
.40068 .31501 .40134 .32504 .40304 .32387 .40238 .31399 Mtetra
.555 .372 .588 r
.40238 .31399 .40304 .32387 .40471 .32397 .40406 .3136 Mtetra
.553 .368 .585 r
.40406 .3136 .40471 .32397 .40647 .3213 .40573 .31325 Mtetra
.592 .41 .604 r
.40573 .31325 .40647 .3213 .40834 .31596 .40744 .31217 Mtetra
.642 .507 .682 r
.40744 .31217 .40834 .31596 .41012 .31283 .40914 .3111 Mtetra
.697 .658 .807 r
.40914 .3111 .41012 .31283 .41185 .31089 .41084 .31018 Mtetra
.671 .831 .96 r
.41084 .31018 .41185 .31089 .41355 .31009 .41253 .30953 Mtetra
.632 .856 .984 r
.41253 .30953 .41355 .31009 .41523 .30958 .41422 .30896 Mtetra
.629 .841 .981 r
.41422 .30896 .41523 .30958 .41691 .30916 .4159 .30841 Mtetra
.654 .817 .962 r
.4159 .30841 .41691 .30916 .4186 .30857 .4176 .30783 Mtetra
.654 .82 .963 r
.4176 .30783 .4186 .30857 .42029 .30797 .41929 .30724 Mtetra
.657 .822 .962 r
.41929 .30724 .42029 .30797 .42199 .30738 .42098 .30664 Mtetra
.665 .823 .96 r
.42098 .30664 .42199 .30738 .42368 .30677 .42268 .30601 Mtetra
.666 .82 .957 r
.42268 .30601 .42368 .30677 .42538 .30616 .42437 .30538 Mtetra
.682 .82 .949 r
.42437 .30538 .42538 .30616 .42707 .30551 .42607 .3047 Mtetra
.745 .824 .912 r
.42607 .3047 .42707 .30551 .42878 .30467 .42778 .30373 Mtetra
.666 .779 .933 r
.42778 .30373 .42878 .30467 .43047 .30406 .42948 .30312 Mtetra
.322 .628 .961 r
.42948 .30312 .43047 .30406 .43216 .30399 .43115 .30336 Mtetra
.897 .478 .152 r
.43115 .30336 .43216 .30399 .43379 .30574 .43272 .30743 Mtetra
.96 .681 .461 r
.43272 .30743 .43379 .30574 .43535 .31019 .42851 .51124 Mtetra
.541 .311 .516 r
.42851 .51124 .43535 .31019 .43151 .50727 .43015 .51675 Mtetra
.518 .245 .44 r
.43015 .51675 .43151 .50727 .4333 .50747 .43196 .51675 Mtetra
.481 .212 .429 r
.43196 .51675 .4333 .50747 .43515 .50563 .43378 .51595 Mtetra
.477 .214 .436 r
.43378 .51595 .43515 .50563 .43694 .50612 .43562 .51494 Mtetra
.514 .238 .433 r
.43562 .51494 .43694 .50612 .43858 .51213 .43743 .51488 Mtetra
.466 .096 .253 r
.43743 .51488 .43858 .51213 .44032 .51475 .43924 .51482 Mtetra
.1 .656 .738 r
.43924 .51482 .44032 .51475 .44211 .51594 .44105 .51463 Mtetra
.643 .715 .9 r
.44105 .51463 .44211 .51594 .44393 .51548 .44288 .51408 Mtetra
.66 .705 .88 r
.44288 .51408 .44393 .51548 .44576 .51467 .44471 .51343 Mtetra
.66 .734 .904 r
.44471 .51343 .44576 .51467 .4476 .51377 .44654 .5128 Mtetra
.465 .71 .975 r
.44654 .5128 .4476 .51377 .44942 .5137 .44836 .51274 Mtetra
.603 .77 .96 r
.44836 .51274 .44942 .5137 .45124 .51341 .45019 .51231 Mtetra
.766 .786 .869 r
.45019 .51231 .45124 .51341 .45308 .51258 .45204 .51107 Mtetra
.913 .736 .65 r
.45204 .51107 .45308 .51258 .45496 .50982 .45398 .50573 Mtetra
.962 .686 .465 r
.45398 .50573 .45496 .50982 .4569 .50446 .46006 .30069 Mtetra
.546 .32 .523 r
.46006 .30069 .4569 .50446 .46272 .30309 .46191 .2936 Mtetra
.604 .41 .593 r
.46191 .2936 .46272 .30309 .46457 .29615 .46365 .29193 Mtetra
.622 .483 .671 r
.46365 .29193 .46457 .29615 .46634 .29314 .46538 .29102 Mtetra
.626 .588 .791 r
.46538 .29102 .46634 .29314 .46808 .29129 .4671 .2905 Mtetra
.647 .809 .961 r
.4671 .2905 .46808 .29129 .46981 .29061 .46882 .28993 Mtetra
.606 .824 .984 r
.46882 .28993 .46981 .29061 .47152 .29028 .47054 .28945 Mtetra
.612 .791 .967 r
.47054 .28945 .47152 .29028 .47324 .29011 .47227 .289 Mtetra
.669 .747 .909 r
.47227 .289 .47324 .29011 .47497 .28954 .47399 .28836 Mtetra
.677 .736 .895 r
.47399 .28836 .47497 .28954 .4767 .28889 .47572 .28768 Mtetra
.681 .732 .889 r
.47572 .28768 .4767 .28889 .47843 .28817 .47745 .28698 Mtetra
.761 .757 .85 r
.47745 .28698 .47843 .28817 .48017 .28684 .47919 .28579 Mtetra
.71 .771 .9 r
.47919 .28579 .48017 .28684 .4819 .28589 .48093 .28496 Mtetra
.502 .722 .971 r
.48093 .28496 .4819 .28589 .48363 .28567 .48265 .28483 Mtetra
.883 .453 .074 r
.48265 .28483 .48363 .28567 .4853 .28977 .48432 .28888 Mtetra
.967 .683 .44 r
.48432 .28888 .4853 .28977 .48451 .49649 .48348 .49493 Mtetra
.901 .51 .08 r
.48348 .49493 .48451 .49649 .48629 .50214 .48526 .50064 Mtetra
.422 .581 .905 r
.48526 .50064 .48629 .50214 .48814 .50228 .48711 .5009 Mtetra
.666 .715 .885 r
.48711 .5009 .48814 .50228 .49 .50145 .48897 .50022 Mtetra
.742 .761 .869 r
.48897 .50022 .49 .50145 .49187 .5002 .49083 .4991 Mtetra
.493 .697 .959 r
.49083 .4991 .49187 .5002 .49372 .50021 .49269 .49902 Mtetra
.591 .72 .933 r
.49269 .49902 .49372 .50021 .49558 .49998 .49455 .49866 Mtetra
.736 .747 .861 r
.49455 .49866 .49558 .49998 .49745 .49901 .49642 .49756 Mtetra
.919 .744 .649 r
.49642 .49756 .49745 .49901 .49935 .49394 .49832 .49226 Mtetra
.968 .689 .448 r
.49832 .49226 .49935 .49394 .50269 .28663 .50173 .285 Mtetra
.928 .723 .605 r
.50173 .285 .50269 .28663 .50448 .27918 .50352 .27805 Mtetra
.808 .78 .827 r
.50352 .27805 .50448 .27918 .50623 .2776 .50527 .27648 Mtetra
.662 .745 .912 r
.50527 .27648 .50623 .2776 .50798 .27702 .50702 .27587 Mtetra
.556 .698 .935 r
.50702 .27587 .50798 .27702 .50973 .27682 .50877 .27565 Mtetra
.741 .76 .868 r
.50877 .27565 .50973 .27682 .51148 .27566 .51052 .27461 Mtetra
.713 .774 .901 r
.51052 .27461 .51148 .27566 .51323 .2747 .51227 .27376 Mtetra
.53 .735 .968 r
.51227 .27376 .51323 .2747 .51498 .2744 .51402 .27355 Mtetra
.828 .368 0 r
.51402 .27355 .51498 .2744 .51672 .27774 .51576 .27686 Mtetra
.97 .682 .428 r
.51576 .27686 .51672 .27774 .51805 .48434 .51703 .48271 Mtetra
.919 .542 .124 r
.51703 .48271 .51805 .48434 .51991 .49117 .51889 .48964 Mtetra
.3 .508 .891 r
.51889 .48964 .51991 .49117 .52179 .49166 .52077 .49025 Mtetra
.653 .706 .886 r
.52077 .49025 .52179 .49166 .52367 .4909 .52265 .48962 Mtetra
.736 .756 .869 r
.52265 .48962 .52367 .4909 .52555 .48967 .52453 .48853 Mtetra
.53 .707 .952 r
.52453 .48853 .52555 .48967 .52744 .48956 .52642 .48835 Mtetra
.571 .71 .937 r
.52642 .48835 .52744 .48956 .52932 .48939 .5283 .48806 Mtetra
.718 .742 .871 r
.5283 .48806 .52932 .48939 .53121 .48854 .53019 .48707 Mtetra
.911 .75 .669 r
.53019 .48707 .53121 .48854 .53309 .4842 .53207 .48253 Mtetra
.971 .688 .437 r
.53207 .48253 .53309 .4842 .53435 .27802 .53339 .27591 Mtetra
.927 .704 .581 r
.53339 .27591 .53435 .27802 .53609 .2685 .53514 .26734 Mtetra
.835 .78 .8 r
.53514 .26734 .53609 .2685 .53785 .26656 .5369 .26544 Mtetra
.672 .752 .911 r
.5369 .26544 .53785 .26656 .53961 .2659 .53867 .26478 Mtetra
.556 .705 .94 r
.53867 .26478 .53961 .2659 .54138 .2657 .54044 .26455 Mtetra
.723 .762 .883 r
.54044 .26455 .54138 .2657 .54315 .26478 .54221 .26362 Mtetra
.714 .757 .886 r
.54221 .26362 .54315 .26478 .54492 .2639 .54398 .26274 Mtetra
.57 .703 .932 r
.54398 .26274 .54492 .2639 .5467 .26364 .54575 .26247 Mtetra
.697 .238 0 r
.54575 .26247 .5467 .26364 .54849 .26648 .54755 .26531 Mtetra
.972 .681 .415 r
.54755 .26531 .54849 .26648 .55196 .47179 .55096 .47064 Mtetra
.935 .56 .193 r
.55096 .47064 .55196 .47179 .55393 .47965 .55293 .47855 Mtetra
0 .243 .736 r
.55293 .47855 .55393 .47965 .55585 .481 .55485 .47989 Mtetra
.568 .731 .952 r
.55485 .47989 .55585 .481 .55776 .48069 .55676 .47958 Mtetra
.786 .799 .863 r
.55676 .47958 .55776 .48069 .55966 .47925 .55866 .47817 Mtetra
.934 .785 .672 r
.55866 .47817 .55966 .47925 .56152 .47452 .56052 .47367 Mtetra
.973 .688 .425 r
.56052 .47367 .56152 .47452 .561 .26652 .56008 .26667 Mtetra
.993 .793 .532 r
.56008 .26667 .561 .26652 .5627 .25865 .56177 .2579 Mtetra
.876 .854 .817 r
.56177 .2579 .5627 .25865 .56447 .25675 .56353 .25587 Mtetra
.645 .798 .956 r
.56353 .25587 .56447 .25675 .56625 .25627 .56532 .25529 Mtetra
.493 .711 .968 r
.56532 .25529 .56625 .25627 .56805 .25628 .56711 .25519 Mtetra
.6 .733 .938 r
.56711 .25519 .56805 .25628 .56984 .25597 .5689 .25481 Mtetra
.66 .742 .911 r
.5689 .25481 .56984 .25597 .57163 .25537 .57069 .25419 Mtetra
.666 .741 .906 r
.57069 .25419 .57163 .25537 .57342 .25473 .57248 .25355 Mtetra
.74 .764 .872 r
.57248 .25355 .57342 .25473 .5752 .25368 .57427 .2525 Mtetra
.727 .76 .879 r
.57427 .2525 .5752 .25368 .57699 .25271 .57605 .25153 Mtetra
.601 .714 .923 r
.57605 .25153 .57699 .25271 .57878 .25234 .57785 .25115 Mtetra
0 0 .437 r
.57785 .25115 .57878 .25234 .58063 .25472 .5797 .25351 Mtetra
.973 .68 .402 r
.5797 .25351 .58063 .25472 .58626 .45928 .58527 .45799 Mtetra
.941 .576 .201 r
.58527 .45799 .58626 .45928 .58837 .46855 .58738 .4674 Mtetra
0 .152 .665 r
.58738 .4674 .58837 .46855 .59034 .47018 .58935 .46904 Mtetra
.537 .714 .954 r
.58935 .46904 .59034 .47018 .59228 .46997 .59129 .46883 Mtetra
.767 .795 .876 r
.59129 .46883 .59228 .46997 .5942 .46869 .59321 .46756 Mtetra
.923 .792 .699 r
.59321 .46756 .5942 .46869 .59606 .46486 .59507 .46371 Mtetra
.975 .687 .413 r
.59507 .46371 .59606 .46486 .59351 .26274 .59257 .26129 Mtetra
.967 .72 .511 r
.59257 .26129 .59351 .26274 .59501 .2484 .59408 .2472 Mtetra
.875 .784 .757 r
.59408 .2472 .59501 .2484 .59677 .24587 .59584 .24467 Mtetra
.686 .746 .897 r
.59584 .24467 .59677 .24587 .59857 .24513 .59765 .24392 Mtetra
.563 .694 .929 r
.59765 .24392 .59857 .24513 .60039 .24489 .59946 .24367 Mtetra
.672 .738 .9 r
.59946 .24367 .60039 .24489 .6022 .2443 .60127 .24299 Mtetra
.712 .735 .869 r
.60127 .24299 .6022 .2443 .604 .24347 .60307 .24208 Mtetra
.613 .682 .891 r
.60307 .24208 .604 .24347 .60581 .24295 .60489 .24166 Mtetra
0 .18 .707 r
.60489 .24166 .60581 .24295 .60766 .24348 .60676 .24327 Mtetra
.948 .596 .295 r
.60676 .24327 .60766 .24348 .60955 .2458 .60892 .25518 Mtetra
.964 .665 .412 r
.60892 .25518 .60955 .2458 .61168 .25645 .61637 .4561 Mtetra
.534 .306 .515 r
.61637 .4561 .61168 .25645 .61921 .4537 .61839 .45831 Mtetra
.499 .178 .353 r
.61839 .45831 .61921 .4537 .62126 .45687 .62036 .45831 Mtetra
.251 0 0 r
.62036 .45831 .62126 .45687 .62327 .45818 .62231 .45774 Mtetra
.446 .828 .988 r
.62231 .45774 .62327 .45818 .62525 .45867 .62427 .4574 Mtetra
.559 .698 .933 r
.62427 .4574 .62525 .45867 .62722 .45849 .62624 .45714 Mtetra
.702 .744 .884 r
.62624 .45714 .62722 .45849 .62916 .45748 .62818 .45623 Mtetra
.905 .79 .723 r
.62818 .45623 .62916 .45748 .63102 .45408 .63005 .45291 Mtetra
.976 .685 .4 r
.63005 .45291 .63102 .45408 .62654 .25839 .62557 .25556 Mtetra
.957 .691 .491 r
.62557 .25556 .62654 .25839 .62768 .23701 .62677 .2358 Mtetra
.892 .786 .737 r
.62677 .2358 .62768 .23701 .62943 .23414 .62853 .23294 Mtetra
.702 .754 .893 r
.62853 .23294 .62943 .23414 .63125 .2333 .63035 .2321 Mtetra
.586 .709 .928 r
.63035 .2321 .63125 .2333 .63309 .23297 .63219 .23177 Mtetra
.665 .742 .907 r
.63219 .23177 .63309 .23297 .63492 .23231 .63401 .23112 Mtetra
.733 .765 .879 r
.63401 .23112 .63492 .23231 .63674 .2313 .63583 .2301 Mtetra
.636 .73 .917 r
.63583 .2301 .63674 .2313 .63857 .23077 .63767 .22957 Mtetra
0 .281 .779 r
.63767 .22957 .63857 .23077 .64048 .23209 .63958 .2309 Mtetra
.938 .574 .186 r
.63958 .2309 .64048 .23209 .64272 .24198 .64181 .24079 Mtetra
.975 .675 .374 r
.64181 .24079 .64272 .24198 .65257 .44639 .65161 .44524 Mtetra
0 0 .512 r
.65161 .44524 .65257 .44639 .65465 .44866 .65369 .44752 Mtetra
.629 .756 .938 r
.65369 .44752 .65465 .44866 .65663 .44811 .65567 .44697 Mtetra
.769 .801 .879 r
.65567 .44697 .65663 .44811 .65858 .44682 .65762 .44567 Mtetra
.782 .804 .87 r
.65762 .44567 .65858 .44682 .66052 .44542 .65956 .44428 Mtetra
.729 .791 .902 r
.65956 .44428 .66052 .44542 .66248 .44439 .66152 .44325 Mtetra
.715 .788 .909 r
.66152 .44325 .66248 .44439 .66444 .44343 .66349 .44229 Mtetra
.656 .768 .932 r
.66349 .44229 .66444 .44343 .66642 .44276 .66546 .44162 Mtetra
.565 .731 .953 r
.66546 .44162 .66642 .44276 .66841 .44245 .66746 .44131 Mtetra
.537 .717 .955 r
.66746 .44131 .66841 .44245 .67041 .44224 .66946 .44109 Mtetra
.444 .669 .958 r
.66946 .44109 .67041 .44224 .67243 .4423 .67147 .44115 Mtetra
.415 .653 .957 r
.67147 .44115 .67243 .4423 .67444 .44244 .67349 .44129 Mtetra
.628 .755 .938 r
.67349 .44129 .67444 .44244 .67644 .44189 .67549 .44073 Mtetra
.89 .812 .765 r
.67549 .44073 .67644 .44189 .67832 .43917 .67738 .43802 Mtetra
.981 .723 .465 r
.67738 .43802 .67832 .43917 .67948 .42107 .67854 .41992 Mtetra
.977 .682 .379 r
.67854 .41992 .67948 .42107 .67186 .22173 .67098 .22052 Mtetra
.912 .79 .714 r
.67098 .22052 .67186 .22173 .67359 .21846 .6727 .21725 Mtetra
.709 .759 .891 r
.6727 .21725 .67359 .21846 .67544 .21758 .67455 .21637 Mtetra
.588 .71 .928 r
.67455 .21637 .67544 .21758 .67731 .21723 .67642 .21602 Mtetra
.624 .727 .92 r
.67642 .21602 .67731 .21723 .67917 .21674 .67829 .21554 Mtetra
.733 .768 .881 r
.67829 .21554 .67917 .21674 .68101 .21571 .68013 .21451 Mtetra
.643 .736 .916 r
.68013 .21451 .68101 .21571 .68288 .21514 .682 .21394 Mtetra
.08 .414 .864 r
.682 .21394 .68288 .21514 .68483 .2161 .68394 .21491 Mtetra
.915 .536 .115 r
.68394 .21491 .68483 .2161 .68717 .22444 .68629 .2234 Mtetra
.975 .671 .352 r
.68629 .2234 .68717 .22444 .70022 .43125 .69928 .43013 Mtetra
.598 .129 0 r
.69928 .43013 .70022 .43125 .70241 .43414 .70148 .433 Mtetra
.553 .727 .955 r
.70148 .433 .70241 .43414 .70444 .43386 .7035 .43272 Mtetra
.713 .791 .912 r
.7035 .43272 .70444 .43386 .70643 .43291 .70549 .43176 Mtetra
.697 .786 .919 r
.70549 .43176 .70643 .43291 .70843 .43204 .70749 .43089 Mtetra
.516 .708 .958 r
.70749 .43089 .70843 .43204 .71046 .43189 .70953 .43073 Mtetra
.657 .769 .932 r
.70953 .43073 .71046 .43189 .71247 .43121 .71154 .43005 Mtetra
.868 .818 .797 r
.71154 .43005 .71247 .43121 .71439 .42891 .71346 .42775 Mtetra
.98 .752 .522 r
.71346 .42775 .71439 .42891 .71585 .41889 .71492 .41772 Mtetra
.977 .678 .362 r
.71492 .41772 .71585 .41889 .70551 .21079 .70463 .20956 Mtetra
.934 .788 .676 r
.70463 .20956 .70551 .21079 .70719 .20683 .70631 .2056 Mtetra
.728 .765 .882 r
.70631 .2056 .70719 .20683 .70904 .20582 .70817 .20459 Mtetra
.603 .715 .923 r
.70817 .20459 .70904 .20582 .71094 .20542 .71007 .20418 Mtetra
.602 .714 .923 r
.71007 .20418 .71094 .20542 .71283 .20502 .71196 .20378 Mtetra
.74 .768 .876 r
.71196 .20378 .71283 .20502 .71469 .20393 .71382 .2027 Mtetra
.657 .738 .909 r
.71382 .2027 .71469 .20393 .71657 .2033 .7157 .20206 Mtetra
.237 .51 .907 r
.7157 .20206 .71657 .2033 .71854 .20396 .71767 .20272 Mtetra
.882 .49 .033 r
.71767 .20272 .71854 .20396 .72095 .21129 .72007 .21001 Mtetra
.975 .667 .334 r
.72007 .21001 .72095 .21129 .73647 .41955 .73555 .41835 Mtetra
.65 .198 0 r
.73555 .41835 .73647 .41955 .73877 .42303 .73785 .42183 Mtetra
.386 .63 .95 r
.73785 .42183 .73877 .42303 .74086 .42327 .73994 .42207 Mtetra
.693 .777 .916 r
.73994 .42207 .74086 .42327 .74288 .42241 .74196 .42121 Mtetra
.873 .817 .791 r
.74196 .42121 .74288 .42241 .7448 .42003 .74388 .41882 Mtetra
.977 .765 .55 r
.74388 .41882 .7448 .42003 .74633 .412 .74541 .41071 Mtetra
.977 .675 .348 r
.74541 .41071 .74633 .412 .73387 .20167 .73301 .20038 Mtetra
.946 .781 .645 r
.73301 .20038 .73387 .20167 .73549 .19703 .73463 .19576 Mtetra
.734 .763 .876 r
.73463 .19576 .73549 .19703 .73736 .19597 .7365 .19471 Mtetra
.599 .709 .921 r
.7365 .19471 .73736 .19597 .73928 .19558 .73842 .19431 Mtetra
.537 .679 .93 r
.73842 .19431 .73928 .19558 .74122 .19541 .74036 .19415 Mtetra
.658 .735 .907 r
.74036 .19415 .74122 .19541 .74312 .19476 .74226 .1935 Mtetra
.662 .739 .907 r
.74226 .1935 .74312 .19476 .74502 .19408 .74416 .19283 Mtetra
.687 .75 .9 r
.74416 .19283 .74502 .19408 .74691 .19328 .74606 .19204 Mtetra
.759 .777 .868 r
.74606 .19204 .74691 .19328 .74878 .19206 .74792 .19083 Mtetra
.685 .753 .903 r
.74792 .19083 .74878 .19206 .75067 .19128 .74982 .19005 Mtetra
.386 .605 .935 r
.74982 .19005 .75067 .19128 .75265 .19156 .7518 .19034 Mtetra
.828 .419 0 r
.7518 .19034 .75265 .19156 .75506 .19745 .75421 .19628 Mtetra
.973 .662 .315 r
.75421 .19628 .75506 .19745 .77314 .40714 .77224 .40597 Mtetra
.705 .26 0 r
.77224 .40597 .77314 .40714 .77557 .41126 .77467 .41007 Mtetra
.343 .606 .946 r
.77467 .41007 .77557 .41126 .7777 .41163 .7768 .41043 Mtetra
.673 .773 .925 r
.7768 .41043 .7777 .41163 .77976 .41086 .77886 .40966 Mtetra
.854 .821 .815 r
.77886 .40966 .77976 .41086 .7817 .40875 .7808 .40754 Mtetra
.978 .776 .564 r
.7808 .40754 .7817 .40875 .78324 .40158 .78234 .40034 Mtetra
.976 .671 .329 r
.78234 .40034 .78324 .40158 .76828 .19019 .76743 .1889 Mtetra
.96 .78 .614 r
.76743 .1889 .76828 .19019 .76982 .18489 .76898 .18363 Mtetra
.751 .773 .871 r
.76898 .18363 .76982 .18489 .7717 .18372 .77086 .18246 Mtetra
.617 .721 .92 r
.77086 .18246 .7717 .18372 .77364 .18324 .77279 .18198 Mtetra
.535 .682 .933 r
.77279 .18198 .77364 .18324 .7756 .18306 .77476 .18182 Mtetra
.675 .749 .907 r
.77476 .18182 .7756 .18306 .77751 .18218 .77668 .18108 Mtetra
.669 .777 .931 r
.77668 .18108 .77751 .18218 .77943 .18146 .7786 .18038 Mtetra
.654 .774 .937 r
.7786 .18038 .77943 .18146 .78138 .1811 .78053 .17973 Mtetra
.684 .73 .885 r
.78053 .17973 .78138 .1811 .78343 .1818 .78245 .17894 Mtetra
.591 .525 .749 r
.78245 .17894 .78343 .1818 .78559 .18377 .78441 .17855 Mtetra
.508 .391 .655 r
.78441 .17855 .78559 .18377 .78822 .19116 .78644 .17903 Mtetra
.275 .172 .552 r
.78644 .17903 .78822 .19116 .80809 .39406 .78904 .18597 Mtetra
.025 0 .427 r
.78904 .18597 .80809 .39406 .81056 .39789 .80947 .39426 Mtetra
0 .1 .622 r
.80947 .39426 .81056 .39789 .81284 .39943 .81195 .39816 Mtetra
.306 .566 .929 r
.81195 .39816 .81284 .39943 .81503 .39986 .81415 .39868 Mtetra
.624 .758 .942 r
.81415 .39868 .81503 .39986 .81713 .39944 .81624 .39811 Mtetra
.804 .796 .845 r
.81624 .39811 .81713 .39944 .81916 .39805 .81824 .39644 Mtetra
.901 .728 .657 r
.15267 .6042 .15383 .60532 .15601 .59978 .15487 .5985 Mtetra
.936 .686 .535 r
.15487 .5985 .15601 .59978 .17922 .39823 .17816 .39697 Mtetra
.898 .715 .645 r
.17816 .39697 .17922 .39823 .18138 .39199 .1803 .39095 Mtetra
.772 .754 .837 r
.1803 .39095 .18138 .39199 .183 .39077 .18191 .38974 Mtetra
.642 .733 .915 r
.18191 .38974 .183 .39077 .18454 .3903 .18345 .38928 Mtetra
.516 .691 .947 r
.18345 .38928 .18454 .3903 .18604 .39021 .18496 .38918 Mtetra
.75 .755 .857 r
.18496 .38918 .18604 .39021 .18764 .38918 .18656 .38815 Mtetra
.699 .748 .889 r
.18656 .38815 .18764 .38918 .18921 .38846 .18812 .38744 Mtetra
.492 .682 .951 r
.18812 .38744 .18921 .38846 .1907 .38842 .18962 .3874 Mtetra
.925 .542 .242 r
.18962 .3874 .1907 .38842 .19179 .39239 .19071 .39136 Mtetra
.939 .683 .523 r
.19071 .39136 .19179 .39239 .17262 .59278 .17146 .5918 Mtetra
.936 .586 .333 r
.17146 .5918 .17262 .59278 .17364 .59839 .17247 .59743 Mtetra
.25 .593 .949 r
.17247 .59743 .17364 .59839 .1752 .59872 .17404 .59775 Mtetra
.671 .767 .922 r
.17404 .59775 .1752 .59872 .17687 .5981 .1757 .59713 Mtetra
.75 .778 .876 r
.1757 .59713 .17687 .5981 .17857 .59706 .17741 .59609 Mtetra
.477 .703 .968 r
.17741 .59609 .17857 .59706 .18018 .59701 .17902 .59603 Mtetra
.584 .742 .951 r
.17902 .59603 .18018 .59701 .18181 .59669 .18065 .59572 Mtetra
.749 .777 .876 r
.18065 .59572 .18181 .59669 .18352 .59565 .18236 .59467 Mtetra
.906 .741 .666 r
.18236 .59467 .18352 .59565 .18565 .59044 .18449 .58945 Mtetra
.939 .687 .529 r
.18449 .58945 .18565 .59044 .20721 .38874 .20613 .38769 Mtetra
.912 .726 .638 r
.20613 .38769 .20721 .38874 .20935 .38227 .20828 .38124 Mtetra
.793 .761 .824 r
.20828 .38124 .20935 .38227 .211 .38086 .20993 .37984 Mtetra
.633 .735 .922 r
.20993 .37984 .211 .38086 .21256 .38041 .21148 .3794 Mtetra
.485 .685 .955 r
.21148 .3794 .21256 .38041 .21407 .38036 .213 .37937 Mtetra
.637 .741 .924 r
.213 .37937 .21407 .38036 .21564 .37983 .21456 .37891 Mtetra
.668 .765 .923 r
.21456 .37891 .21564 .37983 .21721 .37922 .21613 .37834 Mtetra
.679 .775 .923 r
.21613 .37834 .21721 .37922 .21878 .37868 .2177 .37772 Mtetra
.772 .772 .853 r
.2177 .37772 .21878 .37868 .22036 .37799 .21933 .37655 Mtetra
.714 .687 .823 r
.21933 .37655 .22036 .37799 .22192 .37758 .22094 .37563 Mtetra
.591 .577 .805 r
.22094 .37563 .22192 .37758 .22341 .37783 .22248 .37536 Mtetra
0 0 .263 r
.22248 .37536 .22341 .37783 .22454 .38202 .2237 .37854 Mtetra
.946 .687 .514 r
.2237 .37854 .22454 .38202 .20742 .58197 .20641 .57953 Mtetra
.961 .629 .257 r
.20641 .57953 .20742 .58197 .20857 .58707 .20739 .58641 Mtetra
0 .378 .76 r
.20739 .58641 .20857 .58707 .21014 .5877 .20896 .58705 Mtetra
.667 .838 .965 r
.20896 .58705 .21014 .5877 .21181 .58719 .21064 .58641 Mtetra
.767 .819 .893 r
.21064 .58641 .21181 .58719 .21353 .58618 .21237 .5853 Mtetra
.551 .753 .971 r
.21237 .5853 .21353 .58618 .21521 .58559 .21403 .58504 Mtetra
.481 .805 1 r
.21403 .58504 .21521 .58559 .21692 .58481 .21568 .5848 Mtetra
.614 .942 .947 r
.21568 .5848 .21692 .58481 .21869 .58327 .21738 .58401 Mtetra
.958 .939 .718 r
.21738 .58401 .21869 .58327 .22086 .57722 .21932 .58066 Mtetra
1 .833 .524 r
.21932 .58066 .22086 .57722 .24041 .37578 .222 .56888 Mtetra
0 0 .133 r
.222 .56888 .24041 .37578 .24242 .3704 .24106 .37275 Mtetra
0 0 0 r
.24106 .37275 .24242 .3704 .2441 .3688 .24278 .37061 Mtetra
.311 0 .084 r
.24278 .37061 .2441 .3688 .24568 .36824 .24436 .37012 Mtetra
.418 .013 .161 r
.24436 .37012 .24568 .36824 .24723 .36806 .24591 .36998 Mtetra
0 0 0 r
.24591 .36998 .24723 .36806 .2488 .36768 .24757 .36864 Mtetra
.641 .924 .647 r
.24757 .36864 .2488 .36768 .25039 .3672 .24925 .36699 Mtetra
.839 .923 .889 r
.24925 .36699 .25039 .3672 .25197 .3667 .25092 .36556 Mtetra
.72 .736 .864 r
.25092 .36556 .25197 .3667 .25356 .36608 .25253 .36469 Mtetra
.659 .678 .857 r
.25253 .36469 .25356 .36608 .25516 .36545 .25413 .36412 Mtetra
.639 .681 .873 r
.25413 .36412 .25516 .36545 .25675 .36488 .25571 .36364 Mtetra
.654 .703 .882 r
.25571 .36364 .25675 .36488 .25832 .36461 .2573 .36311 Mtetra
.655 .661 .844 r
.2573 .36311 .25832 .36461 .25987 .36453 .2589 .36254 Mtetra
.641 .598 .79 r
.2589 .36254 .25987 .36453 .26143 .36448 .26049 .36196 Mtetra
.628 .551 .748 r
.26049 .36196 .26143 .36448 .26301 .36412 .26209 .36138 Mtetra
.623 .535 .734 r
.26209 .36138 .26301 .36412 .26461 .36353 .26369 .3608 Mtetra
.26369 .3608 .26461 .36353 .26621 .36287 .26529 .36022 Mtetra
.653 .557 .734 r
.26529 .36022 .26621 .36287 .26784 .36189 .26691 .3594 Mtetra
.649 .564 .745 r
.26691 .3594 .26784 .36189 .26947 .36105 .26852 .35865 Mtetra
.593 .539 .764 r
.26852 .35865 .26947 .36105 .27104 .36086 .2701 .35834 Mtetra
.082 .212 .701 r
.2701 .35834 .27104 .36086 .27235 .36387 .27153 .35991 Mtetra
.874 .591 .068 r
.27153 .35991 .27235 .36387 .25811 .56458 .27253 .36701 Mtetra
0 0 .175 r
.27253 .36701 .25811 .56458 .25927 .57096 .25845 .56592 Mtetra
.31 .251 .628 r
.25845 .56592 .25927 .57096 .26085 .57203 .25996 .56787 Mtetra
.593 .469 .681 r
.25996 .56787 .26085 .57203 .26255 .5716 .26167 .56737 Mtetra
.628 .491 .675 r
.26167 .56737 .26255 .5716 .26429 .5707 .26341 .5664 Mtetra
.527 .421 .677 r
.26341 .5664 .26429 .5707 .26601 .56998 .26507 .56656 Mtetra
.432 .392 .714 r
.26507 .56656 .26601 .56998 .26772 .56945 .26668 .56729 Mtetra
.421 .481 .816 r
.26668 .56729 .26772 .56945 .26943 .5689 .26832 .56775 Mtetra
.449 .654 .948 r
.26832 .56775 .26943 .5689 .27112 .56869 .26999 .56782 Mtetra
.596 .774 .965 r
.26999 .56782 .27112 .56869 .27282 .56844 .27169 .56743 Mtetra
.737 .778 .886 r
.27169 .56743 .27282 .56844 .27456 .56758 .27344 .56644 Mtetra
.867 .758 .74 r
.27344 .56644 .27456 .56758 .27649 .56407 .27533 .56357 Mtetra
.946 .752 .609 r
.27533 .56357 .27649 .56407 .29269 .36473 .27763 .55516 Mtetra
0 0 .15 r
.27763 .55516 .29269 .36473 .29515 .35263 .29384 .35517 Mtetra
0 0 0 r
.29384 .35517 .29515 .35263 .2969 .35017 .29564 .35207 Mtetra
.284 0 .083 r
.29564 .35207 .2969 .35017 .29853 .34947 .29727 .35145 Mtetra
.415 .016 .17 r
.29727 .35145 .29853 .34947 .30012 .34926 .29886 .35127 Mtetra
.142 0 .019 r
.29886 .35127 .30012 .34926 .30172 .34894 .30052 .35018 Mtetra
0 0 0 r
.30052 .35018 .30172 .34894 .30334 .34839 .30222 .34846 Mtetra
.834 .978 .881 r
.30222 .34846 .30334 .34839 .30496 .34784 .3039 .34697 Mtetra
.741 .796 .897 r
.3039 .34697 .30496 .34784 .30658 .34726 .30555 .34604 Mtetra
.644 .705 .892 r
.30555 .34604 .30658 .34726 .30821 .34667 .30717 .34554 Mtetra
.615 .714 .916 r
.30717 .34554 .30821 .34667 .30983 .34614 .30878 .34516 Mtetra
.648 .753 .926 r
.30878 .34516 .30983 .34614 .31143 .34584 .3104 .34464 Mtetra
.682 .721 .879 r
.3104 .34464 .31143 .34584 .31303 .34575 .31204 .34396 Mtetra
.665 .632 .807 r
.31204 .34396 .31303 .34575 .31462 .34571 .31367 .34326 Mtetra
.639 .563 .754 r
.31367 .34326 .31462 .34571 .31623 .34543 .31531 .34261 Mtetra
.624 .532 .73 r
.31531 .34261 .31623 .34543 .31786 .34485 .31694 .342 Mtetra
.621 .529 .729 r
.31694 .342 .31786 .34485 .3195 .34418 .31857 .34141 Mtetra
.623 .535 .734 r
.31857 .34141 .3195 .34418 .32113 .34353 .3202 .34082 Mtetra
.624 .539 .738 r
.3202 .34082 .32113 .34353 .32277 .34293 .32184 .34023 Mtetra
.32184 .34023 .32277 .34293 .3244 .34233 .32347 .33964 Mtetra
.624 .54 .739 r
.32347 .33964 .3244 .34233 .32604 .34174 .32511 .33905 Mtetra
.32511 .33905 .32604 .34174 .32767 .34115 .32674 .33847 Mtetra
.624 .54 .74 r
.32674 .33847 .32767 .34115 .32931 .34056 .32838 .33788 Mtetra
.32838 .33788 .32931 .34056 .33095 .33998 .33002 .3373 Mtetra
.33002 .3373 .33095 .33998 .33259 .3394 .33166 .33672 Mtetra
.623 .54 .74 r
.33166 .33672 .33259 .3394 .33423 .33882 .3333 .33614 Mtetra
.3333 .33614 .33423 .33882 .33587 .33825 .33494 .33556 Mtetra
.33494 .33556 .33587 .33825 .33751 .33768 .33658 .33499 Mtetra
.622 .539 .74 r
.33658 .33499 .33751 .33768 .33915 .33711 .33822 .33441 Mtetra
.622 .539 .739 r
.33822 .33441 .33915 .33711 .34079 .33659 .33986 .33384 Mtetra
.621 .535 .736 r
.33986 .33384 .34079 .33659 .34243 .33609 .34151 .33327 Mtetra
.617 .529 .732 r
.34151 .33327 .34243 .33609 .34408 .33551 .34315 .33271 Mtetra
.612 .527 .735 r
.34315 .33271 .34408 .33551 .34574 .33466 .3448 .3322 Mtetra
.611 .548 .759 r
.3448 .3322 .34574 .33466 .34742 .33356 .34644 .33175 Mtetra
.626 .615 .819 r
.34644 .33175 .34742 .33356 .3491 .3325 .34808 .33129 Mtetra
.654 .714 .892 r
.34808 .33129 .3491 .3325 .35076 .33164 .34973 .33074 Mtetra
.684 .786 .927 r
.34973 .33074 .35076 .33164 .35241 .33102 .35138 .33007 Mtetra
.689 .775 .917 r
.35138 .33007 .35241 .33102 .35406 .33049 .35304 .32938 Mtetra
.68 .741 .897 r
.35304 .32938 .35406 .33049 .35571 .32995 .3547 .32872 Mtetra
.666 .714 .884 r
.3547 .32872 .35571 .32995 .35737 .32937 .35635 .32811 Mtetra
.662 .708 .882 r
.35635 .32811 .35737 .32937 .35902 .32879 .35801 .32752 Mtetra
.67 .708 .876 r
.35801 .32752 .35902 .32879 .36067 .32823 .35967 .32688 Mtetra
.678 .698 .862 r
.35967 .32688 .36067 .32823 .36233 .32769 .36133 .32619 Mtetra
.652 .667 .851 r
.36133 .32619 .36233 .32769 .36398 .32714 .36299 .32562 Mtetra
.578 .633 .869 r
.36299 .32562 .36398 .32714 .36564 .32655 .36463 .32539 Mtetra
.334 .583 .934 r
.36463 .32539 .36564 .32655 .36731 .32589 .36624 .32572 Mtetra
.338 0 0 r
.36624 .32572 .36731 .32589 .36897 .32523 .36785 .32628 Mtetra
.418 0 .001 r
.36785 .32628 .36897 .32523 .37064 .32443 .36948 .3264 Mtetra
.184 0 .043 r
.36948 .3264 .37064 .32443 .37232 .32348 .37116 .32541 Mtetra
.307 0 .102 r
.37116 .32541 .37232 .32348 .37398 .32295 .37283 .32482 Mtetra
.672 .283 .3 r
.37283 .32482 .37398 .32295 .37559 .32368 .37439 .32639 Mtetra
.953 .68 .48 r
.37439 .32639 .37559 .32368 .37697 .32904 .36656 .52678 Mtetra
.545 .315 .517 r
.36656 .52678 .37697 .32904 .3692 .53201 .36794 .53454 Mtetra
.681 .313 .343 r
.36794 .53454 .3692 .53201 .37077 .53597 .36961 .53652 Mtetra
.163 0 0 r
.36961 .53652 .37077 .53597 .3725 .53636 .37137 .53636 Mtetra
.561 .929 .928 r
.37137 .53636 .3725 .53636 .37427 .53607 .37316 .53558 Mtetra
.785 .899 .923 r
.37316 .53558 .37427 .53607 .37605 .53554 .37498 .53436 Mtetra
.795 .768 .828 r
.37498 .53436 .37605 .53554 .37783 .53509 .3768 .53281 Mtetra
.752 .642 .74 r
.3768 .53281 .37783 .53509 .37962 .53454 .37864 .53098 Mtetra
.679 .544 .694 r
.37864 .53098 .37962 .53454 .3814 .53406 .38047 .5295 Mtetra
.559 .439 .672 r
.38047 .5295 .3814 .53406 .38318 .53381 .38224 .52933 Mtetra
.593 .463 .673 r
.38224 .52933 .38318 .53381 .38497 .53313 .38403 .52877 Mtetra
.714 .544 .658 r
.38403 .52877 .38497 .53313 .38682 .53121 .3859 .52623 Mtetra
.955 .685 .485 r
.3859 .52623 .38682 .53121 .38886 .5245 .3959 .32527 Mtetra
.552 .325 .524 r
.3959 .32527 .38886 .5245 .39883 .31991 .39796 .31541 Mtetra
.732 .548 .643 r
.39796 .31541 .39883 .31991 .40068 .31501 .39974 .31233 Mtetra
.66 .564 .735 r
.39974 .31233 .40068 .31501 .40238 .31399 .40144 .31141 Mtetra
.608 .54 .753 r
.40144 .31141 .40238 .31399 .40406 .3136 .40311 .31096 Mtetra
.587 .524 .752 r
.40311 .31096 .40406 .3136 .40573 .31325 .40479 .31066 Mtetra
.624 .549 .749 r
.40479 .31066 .40573 .31325 .40744 .31217 .40647 .31008 Mtetra
.635 .594 .79 r
.40647 .31008 .40744 .31217 .40914 .3111 .40816 .30951 Mtetra
.653 .657 .841 r
.40816 .30951 .40914 .3111 .41084 .31018 .40984 .30892 Mtetra
.679 .718 .878 r
.40984 .30892 .41084 .31018 .41253 .30953 .41154 .30823 Mtetra
.659 .704 .88 r
.41154 .30823 .41253 .30953 .41422 .30896 .41323 .30763 Mtetra
.601 .678 .895 r
.41323 .30763 .41422 .30896 .4159 .30841 .41491 .3073 Mtetra
.351 .601 .942 r
.41491 .3073 .4159 .30841 .4176 .30783 .41657 .30758 Mtetra
.263 0 0 r
.41657 .30758 .4176 .30783 .41929 .30724 .41822 .30811 Mtetra
.513 .018 .017 r
.41822 .30811 .41929 .30724 .42098 .30664 .41988 .30861 Mtetra
.361 0 .138 r
.41988 .30861 .42098 .30664 .42268 .30601 .42157 .3082 Mtetra
.307 0 .138 r
.42157 .3082 .42268 .30601 .42437 .30538 .42327 .30748 Mtetra
.242 0 .094 r
.42327 .30748 .42437 .30538 .42607 .3047 .42498 .30657 Mtetra
.108 0 0 r
.42498 .30657 .42607 .3047 .42778 .30373 .4267 .30539 Mtetra
.257 0 .032 r
.4267 .30539 .42778 .30373 .42948 .30312 .4284 .30476 Mtetra
.576 .156 .209 r
.4284 .30476 .42948 .30312 .43115 .30336 .43006 .30549 Mtetra
.959 .68 .462 r
.43006 .30549 .43115 .30336 .43272 .30743 .42597 .49964 Mtetra
.559 .326 .518 r
.42597 .49964 .43272 .30743 .42851 .51124 .42731 .5148 Mtetra
.695 .352 .39 r
.42731 .5148 .42851 .51124 .43015 .51675 .42904 .51758 Mtetra
.317 0 0 r
.42904 .51758 .43015 .51675 .43196 .51675 .43084 .51755 Mtetra
.017 0 0 r
.43084 .51755 .43196 .51675 .43378 .51595 .43267 .51695 Mtetra
0 0 0 r
.43267 .51695 .43378 .51595 .43562 .51494 .4345 .51605 Mtetra
.091 0 0 r
.4345 .51605 .43562 .51494 .43743 .51488 .43633 .51535 Mtetra
0 0 0 r
.43633 .51535 .43743 .51488 .43924 .51482 .43816 .51461 Mtetra
.588 .921 .968 r
.43816 .51461 .43924 .51482 .44105 .51463 .43999 .51389 Mtetra
.599 .817 .983 r
.43999 .51389 .44105 .51463 .44288 .51408 .44182 .51341 Mtetra
.616 .84 .985 r
.44182 .51341 .44288 .51408 .44471 .51343 .44364 .51286 Mtetra
.668 .875 .976 r
.44364 .51286 .44471 .51343 .44654 .5128 .44548 .51211 Mtetra
.751 .865 .932 r
.44548 .51211 .44654 .5128 .44836 .51274 .44732 .51105 Mtetra
.771 .704 .788 r
.44732 .51105 .44836 .51274 .45019 .51231 .44918 .50942 Mtetra
.783 .627 .688 r
.44918 .50942 .45019 .51231 .45204 .51107 .45107 .50651 Mtetra
.961 .686 .467 r
.45107 .50651 .45204 .51107 .45398 .50573 .45712 .31087 Mtetra
.565 .336 .526 r
.45712 .31087 .45398 .50573 .46006 .30069 .45918 .2945 Mtetra
.71 .51 .617 r
.45918 .2945 .46006 .30069 .46191 .2936 .46096 .29091 Mtetra
.659 .564 .736 r
.46096 .29091 .46191 .2936 .46365 .29193 .46269 .28999 Mtetra
.604 .594 .815 r
.46269 .28999 .46365 .29193 .46538 .29102 .46441 .28963 Mtetra
.527 .635 .9 r
.46441 .28963 .46538 .29102 .4671 .2905 .46612 .28956 Mtetra
.64 .773 .944 r
.46612 .28956 .4671 .2905 .46882 .28993 .46784 .28903 Mtetra
.652 .787 .947 r
.46784 .28903 .46882 .28993 .47054 .28945 .46957 .28846 Mtetra
.669 .772 .927 r
.46957 .28846 .47054 .28945 .47227 .289 .47129 .28783 Mtetra
.715 .75 .879 r
.47129 .28783 .47227 .289 .47399 .28836 .47302 .28695 Mtetra
.694 .702 .854 r
.47302 .28695 .47399 .28836 .47572 .28768 .47476 .28614 Mtetra
.658 .669 .849 r
.47476 .28614 .47572 .28768 .47745 .28698 .47649 .28551 Mtetra
.588 .65 .879 r
.47649 .28551 .47745 .28698 .47919 .28579 .47821 .28522 Mtetra
.188 .642 .941 r
.47821 .28522 .47919 .28579 .48093 .28496 .47993 .28543 Mtetra
.636 .118 0 r
.47993 .28543 .48093 .28496 .48265 .28483 .48164 .28658 Mtetra
.897 .559 .399 r
.48164 .28658 .48265 .28483 .48432 .28888 .48324 .29605 Mtetra
.958 .672 .452 r
.48324 .29605 .48432 .28888 .48348 .49493 .48242 .49606 Mtetra
.806 .399 .277 r
.48242 .49606 .48348 .49493 .48526 .50064 .48422 .49946 Mtetra
.335 .598 .943 r
.48422 .49946 .48526 .50064 .48711 .5009 .48607 .49979 Mtetra
.619 .746 .937 r
.48607 .49979 .48711 .5009 .48897 .50022 .48793 .49932 Mtetra
.733 .822 .92 r
.48793 .49932 .48897 .50022 .49083 .4991 .48979 .49833 Mtetra
.738 .85 .933 r
.48979 .49833 .49083 .4991 .49269 .49902 .49166 .49732 Mtetra
.761 .703 .797 r
.49166 .49732 .49269 .49902 .49455 .49866 .49353 .49581 Mtetra
.768 .623 .699 r
.49353 .49581 .49455 .49866 .49642 .49756 .49541 .49327 Mtetra
.878 .644 .581 r
.49541 .49327 .49642 .49756 .49832 .49226 .49736 .48313 Mtetra
.96 .68 .458 r
.49736 .48313 .49832 .49226 .50173 .285 .50078 .28109 Mtetra
.793 .597 .636 r
.50078 .28109 .50173 .285 .50352 .27805 .50256 .2768 Mtetra
.785 .755 .825 r
.50256 .2768 .50352 .27805 .50527 .27648 .50431 .27536 Mtetra
.671 .748 .908 r
.50431 .27536 .50527 .27648 .50702 .27587 .50606 .2747 Mtetra
.553 .693 .932 r
.50606 .2747 .50702 .27587 .50877 .27565 .50781 .2745 Mtetra
.58 .708 .93 r
.50781 .2745 .50877 .27565 .51052 .27461 .50956 .2742 Mtetra
.202 .686 .93 r
.50956 .2742 .51052 .27461 .51227 .27376 .5113 .27427 Mtetra
.576 .045 0 r
.5113 .27427 .51227 .27376 .51402 .27355 .51305 .27516 Mtetra
.873 .515 .366 r
.51305 .27516 .51402 .27355 .51576 .27686 .51478 .28189 Mtetra
.963 .675 .438 r
.51478 .28189 .51576 .27686 .51703 .48271 .516 .48467 Mtetra
.79 .408 .332 r
.516 .48467 .51703 .48271 .51889 .48964 .51787 .48853 Mtetra
.256 .568 .938 r
.51787 .48853 .51889 .48964 .52077 .49025 .51975 .48899 Mtetra
.633 .725 .914 r
.51975 .48899 .52077 .49025 .52265 .48962 .52163 .48846 Mtetra
.735 .775 .885 r
.52163 .48846 .52265 .48962 .52453 .48853 .52351 .48741 Mtetra
.722 .78 .898 r
.52351 .48741 .52453 .48853 .52642 .48835 .5254 .48644 Mtetra
.732 .672 .792 r
.5254 .48644 .52642 .48835 .5283 .48806 .52728 .4851 Mtetra
.748 .609 .704 r
.52728 .4851 .5283 .48806 .53019 .48707 .52917 .48288 Mtetra
.857 .633 .599 r
.52917 .48288 .53019 .48707 .53207 .48253 .53104 .47505 Mtetra
.965 .681 .445 r
.53104 .47505 .53207 .48253 .53339 .27591 .53243 .27077 Mtetra
.771 .563 .617 r
.53243 .27077 .53339 .27591 .53514 .26734 .53419 .26597 Mtetra
.79 .742 .808 r
.53419 .26597 .53514 .26734 .5369 .26544 .53595 .2644 Mtetra
.67 .768 .924 r
.53595 .2644 .5369 .26544 .53867 .26478 .53772 .26375 Mtetra
.582 .738 .95 r
.53772 .26375 .53867 .26478 .54044 .26455 .53949 .26341 Mtetra
.743 .77 .875 r
.53949 .26341 .54044 .26455 .54221 .26362 .54126 .26236 Mtetra
.727 .745 .866 r
.54126 .26236 .54221 .26362 .54398 .26274 .54303 .26138 Mtetra
.603 .681 .896 r
.54303 .26138 .54398 .26274 .54575 .26247 .5448 .26102 Mtetra
0 0 .418 r
.5448 .26102 .54575 .26247 .54755 .26531 .5466 .26366 Mtetra
.972 .682 .414 r
.5466 .26366 .54755 .26531 .55096 .47064 .54994 .46851 Mtetra
.925 .57 .134 r
.54994 .46851 .55096 .47064 .55293 .47855 .55192 .47738 Mtetra
0 .229 .731 r
.55192 .47738 .55293 .47855 .55485 .47989 .55384 .47878 Mtetra
.564 .73 .953 r
.55384 .47878 .55485 .47989 .55676 .47958 .55575 .47848 Mtetra
.786 .801 .865 r
.55575 .47848 .55676 .47958 .55866 .47817 .55765 .47708 Mtetra
.932 .786 .676 r
.55765 .47708 .55866 .47817 .56052 .47367 .55952 .47268 Mtetra
.973 .688 .426 r
.55952 .47268 .56052 .47367 .56008 .26667 .55914 .26628 Mtetra
.982 .768 .541 r
.55914 .26628 .56008 .26667 .56177 .2579 .56083 .25693 Mtetra
.865 .817 .799 r
.56083 .25693 .56177 .2579 .56353 .25587 .5626 .25484 Mtetra
.662 .77 .93 r
.5626 .25484 .56353 .25587 .56532 .25529 .56439 .25422 Mtetra
.526 .704 .952 r
.56439 .25422 .56532 .25529 .56711 .25519 .56618 .25406 Mtetra
.609 .728 .93 r
.56618 .25406 .56711 .25519 .5689 .25481 .56797 .25365 Mtetra
.662 .743 .91 r
.56797 .25365 .5689 .25481 .57069 .25419 .56976 .25302 Mtetra
.671 .744 .905 r
.56976 .25302 .57069 .25419 .57248 .25355 .57155 .25235 Mtetra
.752 .765 .864 r
.57155 .25235 .57248 .25355 .57427 .2525 .57333 .25122 Mtetra
.738 .747 .859 r
.57333 .25122 .57427 .2525 .57605 .25153 .57512 .25015 Mtetra
.627 .689 .888 r
.57512 .25015 .57605 .25153 .57785 .25115 .57692 .24967 Mtetra
0 .016 .577 r
.57692 .24967 .57785 .25115 .5797 .25351 .57876 .25185 Mtetra
.974 .68 .401 r
.57876 .25185 .5797 .25351 .58527 .45799 .58425 .45514 Mtetra
.918 .583 .119 r
.58425 .45514 .58527 .45799 .58738 .4674 .58639 .46617 Mtetra
0 .136 .659 r
.58639 .46617 .58738 .4674 .58935 .46904 .58836 .46791 Mtetra
.533 .713 .954 r
.58836 .46791 .58935 .46904 .59129 .46883 .5903 .46771 Mtetra
.769 .797 .876 r
.5903 .46771 .59129 .46883 .59321 .46756 .59222 .46643 Mtetra
.923 .792 .698 r
.59222 .46643 .59321 .46756 .59507 .46371 .59408 .46257 Mtetra
.975 .687 .413 r
.59408 .46257 .59507 .46371 .59257 .26129 .59164 .25987 Mtetra
.967 .721 .512 r
.59164 .25987 .59257 .26129 .59408 .2472 .59316 .246 Mtetra
.875 .784 .757 r
.59316 .246 .59408 .2472 .59584 .24467 .59492 .24347 Mtetra
.687 .746 .897 r
.59492 .24347 .59584 .24467 .59765 .24392 .59672 .24271 Mtetra
.565 .696 .929 r
.59672 .24271 .59765 .24392 .59946 .24367 .59854 .24246 Mtetra
.681 .742 .897 r
.59854 .24246 .59946 .24367 .60127 .24299 .60035 .24173 Mtetra
.721 .747 .873 r
.60035 .24173 .60127 .24299 .60307 .24208 .60215 .24078 Mtetra
.603 .695 .908 r
.60215 .24078 .60307 .24208 .60489 .24166 .60397 .2404 Mtetra
0 0 .543 r
.60397 .2404 .60489 .24166 .60676 .24327 .60586 .24254 Mtetra
.974 .677 .391 r
.60586 .24254 .60676 .24327 .60892 .25518 .61322 .44728 Mtetra
.548 .316 .516 r
.61322 .44728 .60892 .25518 .61637 .4561 .61545 .45718 Mtetra
.653 .179 .115 r
.61545 .45718 .61637 .4561 .61839 .45831 .61746 .45863 Mtetra
0 0 0 r
.61746 .45863 .61839 .45831 .62036 .45831 .61941 .45803 Mtetra
.73 .961 .942 r
.61941 .45803 .62036 .45831 .62231 .45774 .62134 .45686 Mtetra
.655 .82 .963 r
.62134 .45686 .62231 .45774 .62427 .4574 .62329 .45618 Mtetra
.563 .71 .94 r
.62329 .45618 .62427 .4574 .62624 .45714 .62526 .4559 Mtetra
.696 .758 .9 r
.62526 .4559 .62624 .45714 .62818 .45623 .62721 .45504 Mtetra
.907 .796 .726 r
.62721 .45504 .62818 .45623 .63005 .45291 .62908 .45174 Mtetra
.976 .685 .4 r
.62908 .45174 .63005 .45291 .62557 .25556 .62463 .25353 Mtetra
.966 .704 .485 r
.62463 .25353 .62557 .25556 .62677 .2358 .62586 .2346 Mtetra
.893 .787 .737 r
.62586 .2346 .62677 .2358 .62853 .23294 .62762 .23174 Mtetra
.702 .755 .893 r
.62762 .23174 .62853 .23294 .63035 .2321 .62944 .2309 Mtetra
.585 .709 .928 r
.62944 .2309 .63035 .2321 .63219 .23177 .63128 .23057 Mtetra
.665 .742 .908 r
.63128 .23057 .63219 .23177 .63401 .23112 .63311 .22992 Mtetra
.733 .765 .879 r
.63311 .22992 .63401 .23112 .63583 .2301 .63493 .2289 Mtetra
.635 .731 .917 r
.63493 .2289 .63583 .2301 .63767 .22957 .63676 .22838 Mtetra
0 .281 .779 r
.63676 .22838 .63767 .22957 .63958 .2309 .63867 .2297 Mtetra
.938 .574 .186 r
.63867 .2297 .63958 .2309 .64181 .24079 .64091 .23961 Mtetra
.975 .675 .374 r
.64091 .23961 .64181 .24079 .65161 .44524 .65065 .4441 Mtetra
0 0 .512 r
.65065 .4441 .65161 .44524 .65369 .44752 .65273 .44637 Mtetra
.629 .756 .939 r
.65273 .44637 .65369 .44752 .65567 .44697 .65471 .44582 Mtetra
.768 .801 .879 r
.65471 .44582 .65567 .44697 .65762 .44567 .65666 .44453 Mtetra
.781 .804 .871 r
.65666 .44453 .65762 .44567 .65956 .44428 .65861 .44314 Mtetra
.728 .791 .902 r
.65861 .44314 .65956 .44428 .66152 .44325 .66057 .44211 Mtetra
.714 .788 .91 r
.66057 .44211 .66152 .44325 .66349 .44229 .66253 .44116 Mtetra
.656 .769 .933 r
.66253 .44116 .66349 .44229 .66546 .44162 .66451 .44049 Mtetra
.567 .733 .953 r
.66451 .44049 .66546 .44162 .66746 .44131 .6665 .44017 Mtetra
.539 .718 .956 r
.6665 .44017 .66746 .44131 .66946 .44109 .66851 .43994 Mtetra
.446 .67 .958 r
.66851 .43994 .66946 .44109 .67147 .44115 .67052 .43999 Mtetra
.415 .653 .957 r
.67052 .43999 .67147 .44115 .67349 .44129 .67254 .44013 Mtetra
.629 .755 .938 r
.67254 .44013 .67349 .44129 .67549 .44073 .67453 .43958 Mtetra
.89 .812 .765 r
.67453 .43958 .67549 .44073 .67738 .43802 .67643 .43686 Mtetra
.981 .723 .465 r
.67643 .43686 .67738 .43802 .67854 .41992 .67759 .41875 Mtetra
.977 .682 .379 r
.67759 .41875 .67854 .41992 .67098 .22052 .67008 .21931 Mtetra
.912 .79 .714 r
.67008 .21931 .67098 .22052 .6727 .21725 .67182 .21604 Mtetra
.708 .758 .891 r
.67182 .21604 .6727 .21725 .67455 .21637 .67366 .21516 Mtetra
.587 .71 .928 r
.67366 .21516 .67455 .21637 .67642 .21602 .67553 .21482 Mtetra
.624 .727 .921 r
.67553 .21482 .67642 .21602 .67829 .21554 .6774 .21433 Mtetra
.734 .768 .881 r
.6774 .21433 .67829 .21554 .68013 .21451 .67924 .2133 Mtetra
.641 .734 .916 r
.67924 .2133 .68013 .21451 .682 .21394 .68111 .21274 Mtetra
.044 .389 .849 r
.68111 .21274 .682 .21394 .68394 .21491 .68306 .21379 Mtetra
.932 .564 .164 r
.68306 .21379 .68394 .21491 .68629 .2234 .6855 .22391 Mtetra
.975 .669 .357 r
.6855 .22391 .68629 .2234 .69928 .43013 .69837 .42952 Mtetra
.692 .175 0 r
.69837 .42952 .69928 .43013 .70148 .433 .70056 .43219 Mtetra
.551 .801 .991 r
.70056 .43219 .70148 .433 .7035 .43272 .70258 .43179 Mtetra
.737 .842 .929 r
.70258 .43179 .7035 .43272 .70549 .43176 .70457 .43072 Mtetra
.717 .813 .924 r
.70457 .43072 .70549 .43176 .70749 .43089 .70656 .42975 Mtetra
.522 .713 .959 r
.70656 .42975 .70749 .43089 .70953 .43073 .7086 .42957 Mtetra
.657 .768 .931 r
.7086 .42957 .70953 .43073 .71154 .43005 .71061 .42889 Mtetra
.868 .818 .798 r
.71061 .42889 .71154 .43005 .71346 .42775 .71253 .42659 Mtetra
.98 .752 .523 r
.71253 .42659 .71346 .42775 .71492 .41772 .714 .41659 Mtetra
.977 .678 .362 r
.714 .41659 .71492 .41772 .70463 .20956 .70376 .20834 Mtetra
.934 .789 .675 r
.70376 .20834 .70463 .20956 .70631 .2056 .70544 .20437 Mtetra
.729 .766 .882 r
.70544 .20437 .70631 .2056 .70817 .20459 .7073 .20336 Mtetra
.603 .715 .924 r
.7073 .20336 .70817 .20459 .71007 .20418 .70919 .20295 Mtetra
.602 .715 .924 r
.70919 .20295 .71007 .20418 .71196 .20378 .71109 .20255 Mtetra
.74 .769 .876 r
.71109 .20255 .71196 .20378 .71382 .2027 .71295 .20146 Mtetra
.658 .738 .909 r
.71295 .20146 .71382 .2027 .7157 .20206 .71483 .20082 Mtetra
.238 .511 .908 r
.71483 .20082 .7157 .20206 .71767 .20272 .7168 .20148 Mtetra
.881 .488 .031 r
.7168 .20148 .71767 .20272 .72007 .21001 .7192 .20872 Mtetra
.975 .667 .334 r
.7192 .20872 .72007 .21001 .73555 .41835 .73463 .41714 Mtetra
.65 .2 0 r
.73463 .41714 .73555 .41835 .73785 .42183 .73693 .42064 Mtetra
.383 .628 .95 r
.73693 .42064 .73785 .42183 .73994 .42207 .73902 .42088 Mtetra
.695 .78 .916 r
.73902 .42088 .73994 .42207 .74196 .42121 .74104 .42001 Mtetra
.877 .817 .786 r
.74104 .42001 .74196 .42121 .74388 .41882 .74296 .41756 Mtetra
.978 .758 .537 r
.74296 .41756 .74388 .41882 .74541 .41071 .74444 .4087 Mtetra
.977 .675 .349 r
.74444 .4087 .74541 .41071 .73301 .20038 .73211 .19856 Mtetra
.91 .737 .654 r
.73211 .19856 .73301 .20038 .73463 .19576 .73375 .19419 Mtetra
.704 .703 .846 r
.73375 .19419 .73463 .19576 .7365 .19471 .73563 .19323 Mtetra
.581 .662 .893 r
.73563 .19323 .7365 .19471 .73842 .19431 .73755 .19294 Mtetra
.518 .648 .915 r
.73755 .19294 .73842 .19431 .74036 .19415 .73949 .19287 Mtetra
.652 .729 .906 r
.73949 .19287 .74036 .19415 .74226 .1935 .7414 .19225 Mtetra
.661 .738 .907 r
.7414 .19225 .74226 .1935 .74416 .19283 .7433 .19158 Mtetra
.687 .75 .899 r
.7433 .19158 .74416 .19283 .74606 .19204 .7452 .19079 Mtetra
.757 .775 .868 r
.7452 .19079 .74606 .19204 .74792 .19083 .74707 .18959 Mtetra
.684 .75 .902 r
.74707 .18959 .74792 .19083 .74982 .19005 .74897 .18881 Mtetra
.387 .603 .933 r
.74897 .18881 .74982 .19005 .7518 .19034 .75095 .1891 Mtetra
.827 .419 0 r
.75095 .1891 .7518 .19034 .75421 .19628 .75336 .19507 Mtetra
.973 .662 .315 r
.75336 .19507 .75421 .19628 .77224 .40597 .77134 .40479 Mtetra
.7 .256 0 r
.77134 .40479 .77224 .40597 .77467 .41007 .77376 .40888 Mtetra
.343 .604 .945 r
.77376 .40888 .77467 .41007 .7768 .41043 .7759 .40924 Mtetra
.675 .774 .925 r
.7759 .40924 .7768 .41043 .77886 .40966 .77796 .40845 Mtetra
.858 .822 .812 r
.77796 .40845 .77886 .40966 .7808 .40754 .7799 .40629 Mtetra
.979 .769 .552 r
.7799 .40629 .7808 .40754 .78234 .40034 .7814 .39856 Mtetra
.976 .671 .33 r
.7814 .39856 .78234 .40034 .76743 .1889 .76653 .18705 Mtetra
.925 .737 .63 r
.76653 .18705 .76743 .1889 .76898 .18363 .76811 .18205 Mtetra
.719 .71 .841 r
.76811 .18205 .76898 .18363 .77086 .18246 .76999 .18098 Mtetra
.598 .671 .891 r
.76999 .18098 .77086 .18246 .77279 .18198 .77194 .1806 Mtetra
.514 .646 .916 r
.77194 .1806 .77279 .18198 .77476 .18182 .77392 .18055 Mtetra
.654 .735 .909 r
.77392 .18055 .77476 .18182 .77668 .18108 .77585 .17991 Mtetra
.666 .76 .92 r
.77585 .17991 .77668 .18108 .7786 .18038 .77777 .17922 Mtetra
.685 .77 .916 r
.77777 .17922 .7786 .18038 .78053 .17973 .77969 .17844 Mtetra
.773 .776 .855 r
.77969 .17844 .78053 .17973 .78245 .17894 .78156 .1771 Mtetra
.688 .664 .822 r
.78156 .1771 .78245 .17894 .78441 .17855 .78347 .17617 Mtetra
.557 .541 .792 r
.78347 .17617 .78441 .17855 .78644 .17903 .78545 .17605 Mtetra
0 0 .532 r
.78545 .17605 .78644 .17903 .78904 .18597 .78784 .18053 Mtetra
.969 .658 .28 r
.78784 .18053 .78904 .18597 .80947 .39426 .80845 .39159 Mtetra
0 0 .428 r
.80845 .39159 .80947 .39426 .81195 .39816 .81107 .39693 Mtetra
.281 .56 .93 r
.81107 .39693 .81195 .39816 .81415 .39868 .81327 .39748 Mtetra
.641 .764 .938 r
.81327 .39748 .81415 .39868 .81624 .39811 .81536 .39685 Mtetra
.823 .811 .84 r
.81536 .39685 .81624 .39811 .81824 .39644 .81734 .39504 Mtetra
.908 .736 .658 r
.1515 .60324 .15267 .6042 .15487 .5985 .15371 .59751 Mtetra
.936 .686 .535 r
.15371 .59751 .15487 .5985 .17816 .39697 .17708 .39592 Mtetra
.906 .725 .646 r
.17708 .39592 .17816 .39697 .1803 .39095 .17921 .38992 Mtetra
.772 .756 .839 r
.17921 .38992 .1803 .39095 .18191 .38974 .18083 .38872 Mtetra
.641 .733 .915 r
.18083 .38872 .18191 .38974 .18345 .38928 .18237 .38825 Mtetra
.515 .691 .948 r
.18237 .38825 .18345 .38928 .18496 .38918 .18387 .38816 Mtetra
.75 .756 .857 r
.18387 .38816 .18496 .38918 .18656 .38815 .18547 .38713 Mtetra
.699 .748 .89 r
.18547 .38713 .18656 .38815 .18812 .38744 .18704 .38642 Mtetra
.491 .683 .951 r
.18704 .38642 .18812 .38744 .18962 .3874 .18854 .38638 Mtetra
.925 .542 .243 r
.18854 .38638 .18962 .3874 .19071 .39136 .18962 .39035 Mtetra
.939 .683 .523 r
.18962 .39035 .19071 .39136 .17146 .5918 .1703 .59085 Mtetra
.935 .585 .334 r
.1703 .59085 .17146 .5918 .17247 .59743 .17131 .59647 Mtetra
.248 .594 .949 r
.17131 .59647 .17247 .59743 .17404 .59775 .17287 .59679 Mtetra
.672 .768 .923 r
.17287 .59679 .17404 .59775 .1757 .59713 .17454 .59617 Mtetra
.75 .779 .877 r
.17454 .59617 .1757 .59713 .17741 .59609 .17625 .59512 Mtetra
.476 .704 .969 r
.17625 .59512 .17741 .59609 .17902 .59603 .17786 .59507 Mtetra
.584 .743 .952 r
.17786 .59507 .17902 .59603 .18065 .59572 .17949 .59475 Mtetra
.75 .779 .877 r
.17949 .59475 .18065 .59572 .18236 .59467 .1812 .5937 Mtetra
.907 .742 .666 r
.1812 .5937 .18236 .59467 .18449 .58945 .18333 .58847 Mtetra
.939 .687 .529 r
.18333 .58847 .18449 .58945 .20613 .38769 .20505 .38666 Mtetra
.913 .727 .638 r
.20505 .38666 .20613 .38769 .20828 .38124 .2072 .38022 Mtetra
.792 .762 .825 r
.2072 .38022 .20828 .38124 .20993 .37984 .20885 .37883 Mtetra
.63 .734 .923 r
.20885 .37883 .20993 .37984 .21148 .3794 .21041 .3784 Mtetra
.479 .682 .955 r
.21041 .3784 .21148 .3794 .213 .37937 .21192 .37837 Mtetra
.631 .74 .926 r
.21192 .37837 .213 .37937 .21456 .37891 .21348 .37794 Mtetra
.663 .753 .917 r
.21348 .37794 .21456 .37891 .21613 .37834 .21505 .37739 Mtetra
.677 .761 .914 r
.21505 .37739 .21613 .37834 .2177 .37772 .21662 .37678 Mtetra
.779 .775 .849 r
.21662 .37678 .2177 .37772 .21933 .37655 .21826 .37556 Mtetra
.743 .763 .869 r
.21826 .37556 .21933 .37655 .22094 .37563 .21987 .37458 Mtetra
.59 .716 .931 r
.21987 .37458 .22094 .37563 .22248 .37536 .22141 .37429 Mtetra
.902 .487 .137 r
.22141 .37429 .22248 .37536 .2237 .37854 .22262 .3776 Mtetra
.942 .683 .516 r
.22262 .3776 .2237 .37854 .20641 .57953 .20519 .57928 Mtetra
.918 .579 .383 r
.20519 .57928 .20641 .57953 .20739 .58641 .20621 .58577 Mtetra
0 .432 .798 r
.20621 .58577 .20739 .58641 .20896 .58705 .20778 .58632 Mtetra
.693 .824 .945 r
.20778 .58632 .20896 .58705 .21064 .58641 .20948 .5856 Mtetra
.777 .812 .881 r
.20948 .5856 .21064 .58641 .21237 .5853 .21122 .5844 Mtetra
.601 .766 .958 r
.21122 .5844 .21237 .5853 .21403 .58504 .21288 .58401 Mtetra
.567 .726 .949 r
.21288 .58401 .21403 .58504 .21568 .5848 .21454 .58375 Mtetra
.659 .751 .918 r
.21454 .58375 .21568 .5848 .21738 .58401 .21622 .58317 Mtetra
.844 .799 .807 r
.21622 .58317 .21738 .58401 .21932 .58066 .21803 .58121 Mtetra
.959 .921 .726 r
.21803 .58121 .21932 .58066 .222 .56888 .21997 .57783 Mtetra
.02 0 .239 r
.21997 .57783 .222 .56888 .24106 .37275 .22214 .57186 Mtetra
.523 .297 .512 r
.22214 .57186 .24106 .37275 .24278 .37061 .22405 .56876 Mtetra
.531 .303 .514 r
.22405 .56876 .24278 .37061 .24436 .37012 .22563 .56932 Mtetra
.528 .301 .514 r
.22563 .56932 .24436 .37012 .24591 .36998 .22734 .56851 Mtetra
0 0 .163 r
.22734 .56851 .24591 .36998 .24757 .36864 .24592 .3743 Mtetra
0 0 0 r
.24592 .3743 .24757 .36864 .24925 .36699 .24804 .36772 Mtetra
.957 .944 .713 r
.24804 .36772 .24925 .36699 .25092 .36556 .24985 .36458 Mtetra
.788 .773 .84 r
.24985 .36458 .25092 .36556 .25253 .36469 .25151 .36327 Mtetra
.662 .674 .851 r
.25151 .36327 .25253 .36469 .25413 .36412 .2531 .36267 Mtetra
.609 .651 .866 r
.2531 .36267 .25413 .36412 .25571 .36364 .25468 .36232 Mtetra
.637 .682 .876 r
.25468 .36232 .25571 .36364 .2573 .36311 .25626 .36186 Mtetra
.654 .7 .88 r
.25626 .36186 .2573 .36311 .2589 .36254 .25785 .36132 Mtetra
.654 .707 .886 r
.25785 .36132 .2589 .36254 .26049 .36196 .25945 .36079 Mtetra
.657 .714 .89 r
.25945 .36079 .26049 .36196 .26209 .36138 .26104 .36024 Mtetra
.659 .722 .895 r
.26104 .36024 .26209 .36138 .26369 .3608 .26264 .35969 Mtetra
.661 .727 .899 r
.26264 .35969 .26369 .3608 .26529 .36022 .26424 .35913 Mtetra
.695 .74 .886 r
.26424 .35913 .26529 .36022 .26691 .3594 .26585 .35841 Mtetra
.691 .76 .905 r
.26585 .35841 .26691 .3594 .26852 .35865 .26746 .35772 Mtetra
.621 .756 .943 r
.26746 .35772 .26852 .35865 .2701 .35834 .26905 .35731 Mtetra
.092 .467 .89 r
.26905 .35731 .2701 .35834 .27153 .35991 .27056 .35791 Mtetra
0 .03 .602 r
.27056 .35791 .27153 .35991 .27253 .36701 .27196 .3598 Mtetra
.136 .079 .523 r
.27196 .3598 .27253 .36701 .25845 .56592 .2732 .36395 Mtetra
.524 .302 .519 r
.2732 .36395 .25845 .56592 .25996 .56787 .27451 .36711 Mtetra
.535 .311 .522 r
.27451 .36711 .25996 .56787 .26167 .56737 .27622 .36539 Mtetra
.532 .309 .521 r
.27622 .36539 .26167 .56737 .26341 .5664 .27783 .36476 Mtetra
0 0 .21 r
.27783 .36476 .26341 .5664 .26507 .56656 .26458 .55723 Mtetra
0 0 .442 r
.26458 .55723 .26507 .56656 .26668 .56729 .26573 .56402 Mtetra
0 .065 .6 r
.26573 .56402 .26668 .56729 .26832 .56775 .26721 .56652 Mtetra
.217 .515 .913 r
.26721 .56652 .26832 .56775 .26999 .56782 .26884 .56706 Mtetra
.624 .809 .971 r
.26884 .56706 .26999 .56782 .27169 .56743 .27055 .56656 Mtetra
.756 .809 .895 r
.27055 .56656 .27169 .56743 .27344 .56644 .27231 .56549 Mtetra
.837 .791 .807 r
.27231 .56549 .27344 .56644 .27533 .56357 .27413 .56356 Mtetra
.94 .885 .751 r
.27413 .56356 .27533 .56357 .27763 .55516 .27604 .56047 Mtetra
0 0 .048 r
.27604 .56047 .27763 .55516 .29384 .35517 .27808 .55554 Mtetra
.522 .296 .512 r
.27808 .55554 .29384 .35517 .29564 .35207 .28004 .55167 Mtetra
.531 .303 .514 r
.28004 .55167 .29564 .35207 .29727 .35145 .28169 .55205 Mtetra
.529 .301 .514 r
.28169 .55205 .29727 .35145 .29886 .35127 .2834 .55158 Mtetra
0 0 .211 r
.2834 .55158 .29886 .35127 .30052 .35018 .29878 .35889 Mtetra
0 0 .058 r
.29878 .35889 .30052 .35018 .30222 .34846 .30101 .34974 Mtetra
.932 .951 .624 r
.30101 .34974 .30222 .34846 .3039 .34697 .30284 .34622 Mtetra
.827 .82 .843 r
.30284 .34622 .3039 .34697 .30555 .34604 .30453 .34467 Mtetra
.643 .68 .87 r
.30453 .34467 .30555 .34604 .30717 .34554 .30615 .34417 Mtetra
.574 .651 .888 r
.30615 .34417 .30717 .34554 .30878 .34516 .30775 .34395 Mtetra
.624 .702 .901 r
.30775 .34395 .30878 .34516 .3104 .34464 .30937 .34353 Mtetra
.692 .741 .889 r
.30937 .34353 .3104 .34464 .31204 .34396 .311 .34282 Mtetra
.695 .736 .882 r
.311 .34282 .31204 .34396 .31367 .34326 .31264 .34209 Mtetra
.681 .725 .883 r
.31264 .34209 .31367 .34326 .31531 .34261 .31428 .34142 Mtetra
.666 .718 .888 r
.31428 .34142 .31531 .34261 .31694 .342 .31591 .34082 Mtetra
.662 .719 .891 r
.31591 .34082 .31694 .342 .31857 .34141 .31754 .34024 Mtetra
.662 .722 .893 r
.31754 .34024 .31857 .34141 .3202 .34082 .31917 .33966 Mtetra
.664 .724 .894 r
.31917 .33966 .3202 .34082 .32184 .34023 .32081 .33907 Mtetra
.664 .725 .895 r
.32081 .33907 .32184 .34023 .32347 .33964 .32244 .33849 Mtetra
.663 .726 .896 r
.32244 .33849 .32347 .33964 .32511 .33905 .32408 .3379 Mtetra
.663 .727 .896 r
.32408 .3379 .32511 .33905 .32674 .33847 .32572 .33732 Mtetra
.663 .727 .897 r
.32572 .33732 .32674 .33847 .32838 .33788 .32735 .33674 Mtetra
.32735 .33674 .32838 .33788 .33002 .3373 .32899 .33616 Mtetra
.32899 .33616 .33002 .3373 .33166 .33672 .33063 .33557 Mtetra
.662 .727 .897 r
.33063 .33557 .33166 .33672 .3333 .33614 .33227 .33499 Mtetra
.33227 .33499 .3333 .33614 .33494 .33556 .33391 .33441 Mtetra
.662 .726 .897 r
.33391 .33441 .33494 .33556 .33658 .33499 .33555 .33383 Mtetra
.661 .726 .897 r
.33555 .33383 .33658 .33499 .33822 .33441 .3372 .33326 Mtetra
.663 .726 .896 r
.3372 .33326 .33822 .33441 .33986 .33384 .33884 .33267 Mtetra
.663 .724 .895 r
.33884 .33267 .33986 .33384 .34151 .33327 .34049 .33209 Mtetra
.658 .72 .895 r
.34049 .33209 .34151 .33327 .34315 .33271 .34213 .33152 Mtetra
.64 .713 .9 r
.34213 .33152 .34315 .33271 .3448 .3322 .34378 .33103 Mtetra
.62 .709 .909 r
.34378 .33103 .3448 .3322 .34644 .33175 .34541 .33063 Mtetra
.624 .719 .915 r
.34541 .33063 .34644 .33175 .34808 .33129 .34705 .3302 Mtetra
.659 .738 .908 r
.34705 .3302 .34808 .33129 .34973 .33074 .3487 .32963 Mtetra
.697 .746 .889 r
.3487 .32963 .34973 .33074 .35138 .33007 .35037 .32889 Mtetra
.7 .732 .876 r
.35037 .32889 .35138 .33007 .35304 .32938 .35203 .32811 Mtetra
.687 .714 .869 r
.35203 .32811 .35304 .32938 .3547 .32872 .35369 .32738 Mtetra
.668 .698 .868 r
.35369 .32738 .3547 .32872 .35635 .32811 .35535 .32675 Mtetra
.662 .691 .867 r
.35535 .32675 .35635 .32811 .35801 .32752 .357 .32615 Mtetra
.679 .696 .859 r
.357 .32615 .35801 .32752 .35967 .32688 .35867 .32545 Mtetra
.693 .692 .844 r
.35867 .32545 .35967 .32688 .36133 .32619 .36033 .32465 Mtetra
.642 .657 .849 r
.36033 .32465 .36133 .32619 .36299 .32562 .36199 .32413 Mtetra
.408 .553 .888 r
.36199 .32413 .36299 .32562 .36463 .32539 .3636 .32444 Mtetra
.737 .245 0 r
.3636 .32444 .36463 .32539 .36624 .32572 .36512 .32664 Mtetra
.889 .544 .388 r
.36512 .32664 .36624 .32572 .36785 .32628 .36643 .33323 Mtetra
.947 .673 .486 r
.36643 .33323 .36785 .32628 .36948 .3264 .3584 .52775 Mtetra
.529 .302 .514 r
.3584 .52775 .36948 .3264 .37116 .32541 .36016 .52736 Mtetra
.527 .3 .513 r
.36016 .52736 .37116 .32541 .37283 .32482 .36197 .52603 Mtetra
.534 .306 .515 r
.36197 .52603 .37283 .32482 .37439 .32639 .3636 .52837 Mtetra
.538 .309 .515 r
.3636 .52837 .37439 .32639 .36656 .52678 .36515 .53262 Mtetra
.628 .32 .43 r
.36515 .53262 .36656 .52678 .36794 .53454 .3668 .53475 Mtetra
.558 0 0 r
.3668 .53475 .36794 .53454 .36961 .53652 .36851 .53564 Mtetra
.493 .74 .982 r
.36851 .53564 .36961 .53652 .37137 .53636 .37027 .53549 Mtetra
.681 .807 .942 r
.37027 .53549 .37137 .53636 .37316 .53558 .37206 .53477 Mtetra
.823 .832 .855 r
.37206 .53477 .37316 .53558 .37498 .53436 .3739 .53317 Mtetra
.89 .762 .715 r
.3739 .53317 .37498 .53436 .3768 .53281 .37581 .52971 Mtetra
.868 .659 .618 r
.37581 .52971 .3768 .53281 .37864 .53098 .37788 .5226 Mtetra
.95 .681 .49 r
.37788 .5226 .37864 .53098 .38047 .5295 .38819 .32579 Mtetra
.533 .309 .521 r
.38819 .32579 .38047 .5295 .38224 .52933 .38989 .32474 Mtetra
.53 .307 .521 r
.38989 .32474 .38224 .52933 .38403 .52877 .39154 .32494 Mtetra
.538 .313 .522 r
.39154 .32494 .38403 .52877 .3859 .52623 .39333 .32171 Mtetra
.542 .317 .523 r
.39333 .32171 .3859 .52623 .3959 .32527 .39522 .31624 Mtetra
.655 .451 .596 r
.39522 .31624 .3959 .32527 .39796 .31541 .397 .31308 Mtetra
.757 .633 .723 r
.397 .31308 .39796 .31541 .39974 .31233 .39874 .31116 Mtetra
.701 .739 .881 r
.39874 .31116 .39974 .31233 .40144 .31141 .40043 .31037 Mtetra
.642 .747 .926 r
.40043 .31037 .40144 .31141 .40311 .31096 .40211 .30986 Mtetra
.622 .728 .923 r
.40211 .30986 .40311 .31096 .40479 .31066 .40379 .30943 Mtetra
.664 .718 .889 r
.40379 .30943 .40479 .31066 .40647 .31008 .40548 .30882 Mtetra
.663 .712 .885 r
.40548 .30882 .40647 .31008 .40816 .30951 .40716 .30822 Mtetra
.672 .709 .876 r
.40716 .30822 .40816 .30951 .40984 .30892 .40885 .30756 Mtetra
.7 .709 .855 r
.40885 .30756 .40984 .30892 .41154 .30823 .41055 .30673 Mtetra
.654 .672 .855 r
.41055 .30673 .41154 .30823 .41323 .30763 .41224 .30615 Mtetra
.507 .607 .887 r
.41224 .30615 .41323 .30763 .41491 .3073 .41391 .30617 Mtetra
.55 .07 0 r
.41391 .30617 .41491 .3073 .41657 .30758 .41551 .30804 Mtetra
.885 .506 .315 r
.41551 .30804 .41657 .30758 .41822 .30811 .41702 .31298 Mtetra
.955 .676 .47 r
.41702 .31298 .41822 .30811 .41988 .30861 .41201 .51039 Mtetra
.532 .304 .514 r
.41201 .51039 .41988 .30861 .42157 .3082 .41375 .51171 Mtetra
.528 .3 .513 r
.41375 .51171 .42157 .3082 .42327 .30748 .41558 .51053 Mtetra
.525 .298 .513 r
.41558 .51053 .42327 .30748 .42498 .30657 .41746 .5079 Mtetra
.524 .297 .513 r
.41746 .5079 .42498 .30657 .4267 .30539 .41934 .50492 Mtetra
.528 .301 .513 r
.41934 .50492 .4267 .30539 .4284 .30476 .42116 .50399 Mtetra
.537 .308 .515 r
.42116 .50399 .4284 .30476 .43006 .30549 .42284 .50767 Mtetra
.54 .31 .515 r
.42284 .50767 .43006 .30549 .42597 .49964 .42447 .51297 Mtetra
.589 .32 .476 r
.42447 .51297 .42597 .49964 .42731 .5148 .4262 .51549 Mtetra
.641 .146 .059 r
.4262 .51549 .42731 .5148 .42904 .51758 .42797 .51669 Mtetra
.484 .738 .983 r
.42797 .51669 .42904 .51758 .43084 .51755 .42978 .51656 Mtetra
.621 .767 .95 r
.42978 .51656 .43084 .51755 .43267 .51695 .4316 .51607 Mtetra
.671 .808 .949 r
.4316 .51607 .43267 .51695 .4345 .51605 .43343 .51538 Mtetra
.665 .853 .972 r
.43343 .51538 .4345 .51605 .43633 .51535 .43526 .51468 Mtetra
.681 .856 .966 r
.43526 .51468 .43633 .51535 .43816 .51461 .43709 .51392 Mtetra
.675 .85 .966 r
.43709 .51392 .43816 .51461 .43999 .51389 .43892 .51318 Mtetra
.534 .802 .995 r
.43892 .51318 .43999 .51389 .44182 .51341 .44074 .51286 Mtetra
.593 .858 .994 r
.44074 .51286 .44182 .51341 .44364 .51286 .44257 .51232 Mtetra
.744 .896 .947 r
.44257 .51232 .44364 .51286 .44548 .51211 .44442 .51128 Mtetra
.898 .82 .761 r
.44442 .51128 .44548 .51211 .44732 .51105 .4463 .50849 Mtetra
.866 .676 .644 r
.4463 .50849 .44732 .51105 .44918 .50942 .44824 .5032 Mtetra
.96 .684 .469 r
.44824 .5032 .44918 .50942 .45107 .50651 .45459 .30193 Mtetra
.546 .32 .523 r
.45459 .30193 .45107 .50651 .45712 .31087 .45646 .29462 Mtetra
.605 .391 .565 r
.45646 .29462 .45712 .31087 .45918 .2945 .45824 .29155 Mtetra
.725 .587 .701 r
.45824 .29155 .45918 .2945 .46096 .29091 .45998 .28968 Mtetra
.679 .728 .886 r
.45998 .28968 .46096 .29091 .46269 .28999 .46171 .28899 Mtetra
.587 .742 .95 r
.46171 .28899 .46269 .28999 .46441 .28963 .46342 .28865 Mtetra
.525 .722 .963 r
.46342 .28865 .46441 .28963 .46612 .28956 .46514 .28848 Mtetra
.647 .746 .921 r
.46514 .28848 .46612 .28956 .46784 .28903 .46686 .28794 Mtetra
.664 .748 .912 r
.46686 .28794 .46784 .28903 .46957 .28846 .46859 .28732 Mtetra
.68 .745 .9 r
.46859 .28732 .46957 .28846 .47129 .28783 .47032 .28663 Mtetra
.749 .754 .856 r
.47032 .28663 .47129 .28783 .47302 .28695 .47205 .28552 Mtetra
.707 .705 .846 r
.47205 .28552 .47302 .28695 .47476 .28614 .47379 .28462 Mtetra
.629 .662 .863 r
.47379 .28462 .47476 .28614 .47649 .28551 .47552 .28415 Mtetra
0 .308 .801 r
.47552 .28415 .47649 .28551 .47821 .28522 .47722 .28531 Mtetra
.848 .405 .164 r
.47722 .28531 .47821 .28522 .47993 .28543 .4789 .28851 Mtetra
.962 .678 .447 r
.4789 .28851 .47993 .28543 .48164 .28658 .4778 .48711 Mtetra
.545 .314 .516 r
.4778 .48711 .48164 .28658 .48324 .29605 .47953 .49516 Mtetra
.534 .306 .514 r
.47953 .49516 .48324 .29605 .48242 .49606 .48134 .49752 Mtetra
.603 .162 .174 r
.48134 .49752 .48242 .49606 .48422 .49946 .48318 .49852 Mtetra
.308 .638 .965 r
.48318 .49852 .48422 .49946 .48607 .49979 .48503 .49877 Mtetra
.577 .75 .959 r
.48503 .49877 .48607 .49979 .48793 .49932 .48689 .49843 Mtetra
.73 .824 .923 r
.48689 .49843 .48793 .49932 .48979 .49833 .48875 .49745 Mtetra
.887 .825 .78 r
.48875 .49745 .48979 .49833 .49166 .49732 .49064 .49492 Mtetra
.865 .684 .656 r
.49064 .49492 .49166 .49732 .49353 .49581 .49254 .4902 Mtetra
.964 .684 .455 r
.49254 .4902 .49353 .49581 .49541 .49327 .49624 .29055 Mtetra
.551 .323 .523 r
.49624 .29055 .49541 .49327 .49736 .48313 .49807 .28079 Mtetra
.538 .313 .522 r
.49807 .28079 .49736 .48313 .50078 .28109 .49984 .27748 Mtetra
.71 .555 .676 r
.49984 .27748 .50078 .28109 .50256 .2768 .5016 .27546 Mtetra
.757 .737 .834 r
.5016 .27546 .50256 .2768 .50431 .27536 .50335 .27423 Mtetra
.682 .751 .903 r
.50335 .27423 .50431 .27536 .50606 .2747 .5051 .27352 Mtetra
.542 .686 .933 r
.5051 .27352 .50606 .2747 .50781 .2745 .50685 .27336 Mtetra
0 .34 .816 r
.50685 .27336 .50781 .2745 .50956 .2742 .50859 .27439 Mtetra
.827 .371 .14 r
.50859 .27439 .50956 .2742 .5113 .27427 .51032 .2773 Mtetra
.965 .677 .436 r
.51032 .2773 .5113 .27427 .51305 .27516 .51127 .47328 Mtetra
.549 .318 .516 r
.51127 .47328 .51305 .27516 .51478 .28189 .5131 .48402 Mtetra
.535 .306 .514 r
.5131 .48402 .51478 .28189 .516 .48467 .51496 .48663 Mtetra
.606 .195 .237 r
.51496 .48663 .516 .48467 .51787 .48853 .51684 .48771 Mtetra
.323 .676 .977 r
.51684 .48771 .51787 .48853 .51975 .48899 .51872 .48786 Mtetra
.618 .745 .937 r
.51872 .48786 .51975 .48899 .52163 .48846 .5206 .48738 Mtetra
.744 .793 .893 r
.5206 .48738 .52163 .48846 .52351 .48741 .52249 .4863 Mtetra
.867 .798 .78 r
.52249 .4863 .52351 .48741 .5254 .48644 .52438 .48388 Mtetra
.854 .675 .659 r
.52438 .48388 .5254 .48644 .52728 .4851 .52626 .47942 Mtetra
.966 .683 .445 r
.52626 .47942 .52728 .4851 .52917 .48288 .52795 .28299 Mtetra
.557 .328 .524 r
.52795 .28299 .52917 .48288 .53104 .47505 .52971 .27013 Mtetra
.538 .313 .522 r
.52971 .27013 .53104 .47505 .53243 .27077 .53147 .26661 Mtetra
.699 .534 .661 r
.53147 .26661 .53243 .27077 .53419 .26597 .53324 .26448 Mtetra
.728 .709 .832 r
.53324 .26448 .53419 .26597 .53595 .2644 .535 .2634 Mtetra
.666 .775 .931 r
.535 .2634 .53595 .2644 .53772 .26375 .53677 .26276 Mtetra
.624 .764 .947 r
.53677 .26276 .53772 .26375 .53949 .26341 .53854 .26228 Mtetra
.759 .775 .866 r
.53854 .26228 .53949 .26341 .54126 .26236 .54031 .26113 Mtetra
.738 .752 .863 r
.54031 .26113 .54126 .26236 .54303 .26138 .54208 .26008 Mtetra
.618 .697 .901 r
.54208 .26008 .54303 .26138 .5448 .26102 .54386 .25965 Mtetra
0 0 .426 r
.54386 .25965 .5448 .26102 .5466 .26366 .54565 .26216 Mtetra
.972 .682 .415 r
.54565 .26216 .5466 .26366 .54994 .46851 .54893 .46644 Mtetra
.938 .587 .172 r
.54893 .46644 .54994 .46851 .55192 .47738 .55091 .47621 Mtetra
0 .207 .713 r
.55091 .47621 .55192 .47738 .55384 .47878 .55283 .47767 Mtetra
.561 .728 .952 r
.55283 .47767 .55384 .47878 .55575 .47848 .55474 .47738 Mtetra
.785 .8 .865 r
.55474 .47738 .55575 .47848 .55765 .47708 .55664 .47598 Mtetra
.932 .785 .676 r
.55664 .47598 .55765 .47708 .55952 .47268 .55851 .4716 Mtetra
.973 .688 .426 r
.55851 .4716 .55952 .47268 .55914 .26628 .5582 .26523 Mtetra
.965 .744 .553 r
.5582 .26523 .55914 .26628 .56083 .25693 .55989 .25579 Mtetra
.852 .788 .788 r
.55989 .25579 .56083 .25693 .5626 .25484 .56166 .25369 Mtetra
.663 .744 .911 r
.56166 .25369 .5626 .25484 .56439 .25422 .56345 .25306 Mtetra
.536 .691 .939 r
.56345 .25306 .56439 .25422 .56618 .25406 .56524 .25289 Mtetra
.611 .722 .924 r
.56524 .25289 .56618 .25406 .56797 .25365 .56703 .25248 Mtetra
.664 .741 .908 r
.56703 .25248 .56797 .25365 .56976 .25302 .56882 .25184 Mtetra
.675 .743 .902 r
.56882 .25184 .56976 .25302 .57155 .25235 .57061 .25115 Mtetra
.759 .765 .857 r
.57061 .25115 .57155 .25235 .57333 .25122 .5724 .24995 Mtetra
.748 .752 .855 r
.5724 .24995 .57333 .25122 .57512 .25015 .57418 .24881 Mtetra
.641 .703 .892 r
.57418 .24881 .57512 .25015 .57692 .24967 .57598 .24827 Mtetra
0 .036 .589 r
.57598 .24827 .57692 .24967 .57876 .25185 .57782 .25033 Mtetra
.974 .68 .401 r
.57782 .25033 .57876 .25185 .58425 .45514 .58323 .45212 Mtetra
.933 .605 .158 r
.58323 .45212 .58425 .45514 .58639 .46617 .58539 .46496 Mtetra
0 .109 .634 r
.58539 .46496 .58639 .46617 .58836 .46791 .58737 .46676 Mtetra
.53 .71 .954 r
.58737 .46676 .58836 .46791 .5903 .46771 .58931 .46657 Mtetra
.768 .796 .875 r
.58931 .46657 .5903 .46771 .59222 .46643 .59123 .46529 Mtetra
.923 .792 .698 r
.59123 .46529 .59222 .46643 .59408 .46257 .59309 .46142 Mtetra
.975 .687 .413 r
.59309 .46142 .59408 .46257 .59164 .25987 .5907 .25846 Mtetra
.967 .722 .513 r
.5907 .25846 .59164 .25987 .59316 .246 .59223 .2448 Mtetra
.875 .784 .757 r
.59223 .2448 .59316 .246 .59492 .24347 .594 .24227 Mtetra
.688 .747 .897 r
.594 .24227 .59492 .24347 .59672 .24271 .5958 .24151 Mtetra
.566 .698 .93 r
.5958 .24151 .59672 .24271 .59854 .24246 .59762 .24126 Mtetra
.684 .744 .897 r
.59762 .24126 .59854 .24246 .60035 .24173 .59943 .24051 Mtetra
.724 .756 .878 r
.59943 .24051 .60035 .24173 .60215 .24078 .60123 .23955 Mtetra
.602 .708 .919 r
.60123 .23955 .60215 .24078 .60397 .2404 .60305 .23916 Mtetra
0 0 .528 r
.60305 .23916 .60397 .2404 .60586 .24254 .60493 .24133 Mtetra
.975 .678 .39 r
.60493 .24133 .60586 .24254 .61322 .44728 .61225 .44648 Mtetra
.941 .572 .225 r
.61225 .44648 .61322 .44728 .61545 .45718 .61447 .45618 Mtetra
0 .221 .709 r
.61447 .45618 .61545 .45718 .61746 .45863 .61648 .45759 Mtetra
.651 .783 .944 r
.61648 .45759 .61746 .45863 .61941 .45803 .61843 .45694 Mtetra
.762 .805 .887 r
.61843 .45694 .61941 .45803 .62134 .45686 .62036 .45571 Mtetra
.668 .767 .924 r
.62036 .45571 .62134 .45686 .62329 .45618 .62232 .455 Mtetra
.558 .717 .947 r
.62232 .455 .62329 .45618 .62526 .4559 .62428 .45472 Mtetra
.695 .772 .911 r
.62428 .45472 .62526 .4559 .62721 .45504 .62623 .45388 Mtetra
.909 .8 .727 r
.62623 .45388 .62721 .45504 .62908 .45174 .6281 .45058 Mtetra
.976 .685 .399 r
.6281 .45058 .62908 .45174 .62463 .25353 .6237 .25197 Mtetra
.972 .712 .48 r
.6237 .25197 .62463 .25353 .62586 .2346 .62495 .2334 Mtetra
.893 .788 .738 r
.62495 .2334 .62586 .2346 .62762 .23174 .62671 .23055 Mtetra
.702 .755 .893 r
.62671 .23055 .62762 .23174 .62944 .2309 .62853 .22971 Mtetra
.585 .709 .929 r
.62853 .22971 .62944 .2309 .63128 .23057 .63037 .22938 Mtetra
.665 .742 .908 r
.63037 .22938 .63128 .23057 .63311 .22992 .6322 .22872 Mtetra
.733 .765 .879 r
.6322 .22872 .63311 .22992 .63493 .2289 .63402 .2277 Mtetra
.635 .731 .917 r
.63402 .2277 .63493 .2289 .63676 .22838 .63586 .22718 Mtetra
0 .281 .779 r
.63586 .22718 .63676 .22838 .63867 .2297 .63776 .2285 Mtetra
.938 .575 .187 r
.63776 .2285 .63867 .2297 .64091 .23961 .64 .23844 Mtetra
.975 .675 .374 r
.64 .23844 .64091 .23961 .65065 .4441 .64969 .44296 Mtetra
0 0 .512 r
.64969 .44296 .65065 .4441 .65273 .44637 .65177 .44523 Mtetra
.629 .756 .939 r
.65177 .44523 .65273 .44637 .65471 .44582 .65375 .44468 Mtetra
.768 .801 .88 r
.65375 .44468 .65471 .44582 .65666 .44453 .6557 .44339 Mtetra
.781 .804 .872 r
.6557 .44339 .65666 .44453 .65861 .44314 .65765 .442 Mtetra
.727 .792 .904 r
.65765 .442 .65861 .44314 .66057 .44211 .65961 .44098 Mtetra
.713 .789 .911 r
.65961 .44098 .66057 .44211 .66253 .44116 .66158 .44003 Mtetra
.656 .771 .934 r
.66158 .44003 .66253 .44116 .66451 .44049 .66355 .43937 Mtetra
.569 .736 .954 r
.66355 .43937 .66451 .44049 .6665 .44017 .66555 .43903 Mtetra
.541 .721 .956 r
.66555 .43903 .6665 .44017 .66851 .43994 .66755 .43879 Mtetra
.448 .672 .959 r
.66755 .43879 .66851 .43994 .67052 .43999 .66957 .43884 Mtetra
.416 .653 .957 r
.66957 .43884 .67052 .43999 .67254 .44013 .67159 .43897 Mtetra
.629 .755 .938 r
.67159 .43897 .67254 .44013 .67453 .43958 .67358 .43842 Mtetra
.89 .812 .765 r
.67358 .43842 .67453 .43958 .67643 .43686 .67548 .4357 Mtetra
.981 .722 .465 r
.67548 .4357 .67643 .43686 .67759 .41875 .67665 .41754 Mtetra
.977 .681 .379 r
.67665 .41754 .67759 .41875 .67008 .21931 .66919 .21809 Mtetra
.912 .79 .714 r
.66919 .21809 .67008 .21931 .67182 .21604 .67092 .21483 Mtetra
.708 .758 .892 r
.67092 .21483 .67182 .21604 .67366 .21516 .67277 .21395 Mtetra
.585 .709 .928 r
.67277 .21395 .67366 .21516 .67553 .21482 .67465 .21361 Mtetra
.623 .727 .921 r
.67465 .21361 .67553 .21482 .6774 .21433 .67651 .21313 Mtetra
.734 .769 .881 r
.67651 .21313 .6774 .21433 .67924 .2133 .67836 .2121 Mtetra
.638 .734 .918 r
.67836 .2121 .67924 .2133 .68111 .21274 .68023 .21155 Mtetra
.009 .366 .836 r
.68023 .21155 .68111 .21274 .68306 .21379 .68218 .21266 Mtetra
.943 .585 .198 r
.68218 .21266 .68306 .21379 .6855 .22391 .68472 .22474 Mtetra
.974 .669 .358 r
.68472 .22474 .6855 .22391 .69837 .42952 .69745 .42875 Mtetra
.633 .121 0 r
.69745 .42875 .69837 .42952 .70056 .43219 .69963 .43128 Mtetra
.588 .794 .978 r
.69963 .43128 .70056 .43219 .70258 .43179 .70165 .43081 Mtetra
.75 .833 .915 r
.70165 .43081 .70258 .43179 .70457 .43072 .70363 .42966 Mtetra
.73 .813 .916 r
.70363 .42966 .70457 .43072 .70656 .42975 .70562 .42862 Mtetra
.527 .718 .96 r
.70562 .42862 .70656 .42975 .7086 .42957 .70766 .42842 Mtetra
.658 .771 .933 r
.70766 .42842 .7086 .42957 .71061 .42889 .70967 .42773 Mtetra
.868 .82 .799 r
.70967 .42773 .71061 .42889 .71253 .42659 .7116 .42544 Mtetra
.98 .753 .523 r
.7116 .42544 .71253 .42659 .714 .41659 .71307 .41548 Mtetra
.977 .678 .362 r
.71307 .41548 .714 .41659 .70376 .20834 .70288 .20713 Mtetra
.935 .789 .675 r
.70288 .20713 .70376 .20834 .70544 .20437 .70456 .20314 Mtetra
.729 .766 .882 r
.70456 .20314 .70544 .20437 .7073 .20336 .70642 .20213 Mtetra
.603 .716 .924 r
.70642 .20213 .7073 .20336 .70919 .20295 .70832 .20172 Mtetra
.602 .715 .924 r
.70832 .20172 .70919 .20295 .71109 .20255 .71022 .20131 Mtetra
.741 .769 .876 r
.71022 .20131 .71109 .20255 .71295 .20146 .71208 .20022 Mtetra
.658 .739 .909 r
.71208 .20022 .71295 .20146 .71483 .20082 .71396 .19958 Mtetra
.24 .513 .908 r
.71396 .19958 .71483 .20082 .7168 .20148 .71593 .20024 Mtetra
.88 .487 .029 r
.71593 .20024 .7168 .20148 .7192 .20872 .71832 .20743 Mtetra
.975 .667 .334 r
.71832 .20743 .7192 .20872 .73463 .41714 .7337 .41593 Mtetra
.651 .201 0 r
.7337 .41593 .73463 .41714 .73693 .42064 .73601 .41944 Mtetra
.383 .627 .95 r
.73601 .41944 .73693 .42064 .73902 .42088 .7381 .41969 Mtetra
.697 .779 .915 r
.7381 .41969 .73902 .42088 .74104 .42001 .74012 .4188 Mtetra
.879 .816 .782 r
.74012 .4188 .74104 .42001 .74296 .41756 .74204 .4163 Mtetra
.98 .753 .525 r
.74204 .4163 .74296 .41756 .74444 .4087 .74347 .40674 Mtetra
.977 .675 .349 r
.74347 .40674 .74444 .4087 .73211 .19856 .73121 .19692 Mtetra
.917 .752 .662 r
.73121 .19692 .73211 .19856 .73375 .19419 .73287 .19271 Mtetra
.699 .715 .861 r
.73287 .19271 .73375 .19419 .73563 .19323 .73475 .19182 Mtetra
.565 .664 .904 r
.73475 .19182 .73563 .19323 .73755 .19294 .73668 .19158 Mtetra
.499 .641 .919 r
.73668 .19158 .73755 .19294 .73949 .19287 .73863 .19158 Mtetra
.647 .725 .906 r
.73863 .19158 .73949 .19287 .7414 .19225 .74054 .19098 Mtetra
.659 .735 .905 r
.74054 .19098 .7414 .19225 .7433 .19158 .74245 .19032 Mtetra
.686 .747 .898 r
.74245 .19032 .7433 .19158 .7452 .19079 .74434 .18953 Mtetra
.755 .772 .867 r
.74434 .18953 .7452 .19079 .74707 .18959 .74621 .18833 Mtetra
.683 .748 .9 r
.74621 .18833 .74707 .18959 .74897 .18881 .74811 .18756 Mtetra
.389 .601 .932 r
.74811 .18756 .74897 .18881 .75095 .1891 .75009 .18785 Mtetra
.825 .418 0 r
.75009 .18785 .75095 .1891 .75336 .19507 .7525 .19381 Mtetra
.973 .662 .315 r
.7525 .19381 .75336 .19507 .77134 .40479 .77044 .40358 Mtetra
.696 .254 0 r
.77044 .40358 .77134 .40479 .77376 .40888 .77286 .40767 Mtetra
.344 .603 .944 r
.77286 .40767 .77376 .40888 .7759 .40924 .775 .40803 Mtetra
.676 .773 .923 r
.775 .40803 .7759 .40924 .77796 .40845 .77705 .40724 Mtetra
.86 .82 .808 r
.77705 .40724 .77796 .40845 .7799 .40629 .779 .40504 Mtetra
.98 .765 .541 r
.779 .40504 .7799 .40629 .7814 .39856 .78046 .39684 Mtetra
.976 .671 .33 r
.78046 .39684 .7814 .39856 .76653 .18705 .76565 .18537 Mtetra
.932 .752 .636 r
.76565 .18537 .76653 .18705 .76811 .18205 .76724 .18056 Mtetra
.714 .722 .856 r
.76724 .18056 .76811 .18205 .76999 .18098 .76914 .17955 Mtetra
.581 .673 .902 r
.76914 .17955 .76999 .18098 .77194 .1806 .77109 .17925 Mtetra
.491 .638 .92 r
.77109 .17925 .77194 .1806 .77392 .18055 .77307 .17926 Mtetra
.646 .729 .909 r
.77307 .17926 .77392 .18055 .77585 .17991 .775 .17866 Mtetra
.662 .743 .91 r
.775 .17866 .77585 .17991 .77777 .17922 .77693 .17798 Mtetra
.685 .756 .905 r
.77693 .17798 .77777 .17922 .77969 .17844 .77885 .17719 Mtetra
.783 .788 .857 r
.77885 .17719 .77969 .17844 .78156 .1771 .78072 .17581 Mtetra
.718 .757 .883 r
.78072 .17581 .78156 .1771 .78347 .17617 .78263 .17483 Mtetra
.543 .669 .92 r
.78263 .17483 .78347 .17617 .78545 .17605 .7846 .17466 Mtetra
.673 .261 0 r
.7846 .17466 .78545 .17605 .78784 .18053 .78698 .17903 Mtetra
.971 .657 .294 r
.78698 .17903 .78784 .18053 .80845 .39159 .80756 .39026 Mtetra
.76 .342 0 r
.80756 .39026 .80845 .39159 .81107 .39693 .81019 .39573 Mtetra
.271 .561 .933 r
.81019 .39573 .81107 .39693 .81327 .39748 .81238 .39629 Mtetra
.643 .764 .937 r
.81238 .39629 .81327 .39748 .81536 .39685 .81448 .39564 Mtetra
.828 .822 .843 r
.81448 .39564 .81536 .39685 .81734 .39504 .81646 .39382 Mtetra
.908 .736 .657 r
.15033 .60227 .1515 .60324 .15371 .59751 .15254 .59653 Mtetra
.936 .686 .535 r
.15254 .59653 .15371 .59751 .17708 .39592 .17599 .39487 Mtetra
.906 .726 .647 r
.17599 .39487 .17708 .39592 .17921 .38992 .17813 .3889 Mtetra
.772 .758 .84 r
.17813 .3889 .17921 .38992 .18083 .38872 .17974 .3877 Mtetra
.641 .734 .916 r
.17974 .3877 .18083 .38872 .18237 .38825 .18128 .38723 Mtetra
.514 .692 .949 r
.18128 .38723 .18237 .38825 .18387 .38816 .18279 .38714 Mtetra
.75 .757 .858 r
.18279 .38714 .18387 .38816 .18547 .38713 .18439 .38612 Mtetra
.698 .749 .891 r
.18439 .38612 .18547 .38713 .18704 .38642 .18596 .38541 Mtetra
.489 .683 .952 r
.18596 .38541 .18704 .38642 .18854 .38638 .18746 .38537 Mtetra
.925 .542 .244 r
.18746 .38537 .18854 .38638 .18962 .39035 .18854 .38935 Mtetra
.939 .683 .523 r
.18854 .38935 .18962 .39035 .1703 .59085 .16913 .58991 Mtetra
.935 .584 .335 r
.16913 .58991 .1703 .59085 .17131 .59647 .17014 .59551 Mtetra
.247 .595 .95 r
.17014 .59551 .17131 .59647 .17287 .59679 .17171 .59584 Mtetra
.672 .769 .923 r
.17171 .59584 .17287 .59679 .17454 .59617 .17337 .59521 Mtetra
.751 .781 .877 r
.17337 .59521 .17454 .59617 .17625 .59512 .17508 .59416 Mtetra
.476 .706 .97 r
.17508 .59416 .17625 .59512 .17786 .59507 .17669 .5941 Mtetra
.584 .745 .953 r
.17669 .5941 .17786 .59507 .17949 .59475 .17833 .59378 Mtetra
.75 .78 .877 r
.17833 .59378 .17949 .59475 .1812 .5937 .18004 .59273 Mtetra
.907 .742 .666 r
.18004 .59273 .1812 .5937 .18333 .58847 .18217 .5875 Mtetra
.939 .687 .529 r
.18217 .5875 .18333 .58847 .20505 .38666 .20397 .38564 Mtetra
.913 .727 .638 r
.20397 .38564 .20505 .38666 .2072 .38022 .20613 .3792 Mtetra
.792 .762 .826 r
.20613 .3792 .2072 .38022 .20885 .37883 .20777 .37781 Mtetra
.628 .734 .923 r
.20777 .37781 .20885 .37883 .21041 .3784 .20933 .37739 Mtetra
.472 .679 .955 r
.20933 .37739 .21041 .3784 .21192 .37837 .21084 .37738 Mtetra
.629 .739 .926 r
.21084 .37738 .21192 .37837 .21348 .37794 .2124 .37695 Mtetra
.659 .748 .916 r
.2124 .37695 .21348 .37794 .21505 .37739 .21397 .37641 Mtetra
.668 .753 .914 r
.21397 .37641 .21505 .37739 .21662 .37678 .21554 .37584 Mtetra
.765 .776 .862 r
.21554 .37584 .21662 .37678 .21826 .37556 .21716 .37473 Mtetra
.733 .797 .903 r
.21716 .37473 .21826 .37556 .21987 .37458 .21876 .37387 Mtetra
.516 .768 .988 r
.21876 .37387 .21987 .37458 .22141 .37429 .2203 .37367 Mtetra
.9 .496 .225 r
.2203 .37367 .22141 .37429 .22262 .3776 .2215 .37709 Mtetra
.942 .683 .516 r
.2215 .37709 .22262 .3776 .20519 .57928 .20404 .57829 Mtetra
.94 .593 .338 r
.20404 .57829 .20519 .57928 .20621 .58577 .20508 .58452 Mtetra
.168 .48 .898 r
.20508 .58452 .20621 .58577 .20778 .58632 .20665 .58513 Mtetra
.666 .726 .894 r
.20665 .58513 .20778 .58632 .20948 .5856 .20833 .58452 Mtetra
.748 .762 .865 r
.20833 .58452 .20948 .5856 .21122 .5844 .21006 .58344 Mtetra
.663 .77 .93 r
.21006 .58344 .21122 .5844 .21288 .58401 .21175 .58285 Mtetra
.63 .721 .913 r
.21175 .58285 .21288 .58401 .21454 .58375 .21342 .58239 Mtetra
.648 .693 .878 r
.21342 .58239 .21454 .58375 .21622 .58317 .2151 .58185 Mtetra
.708 .717 .856 r
.2151 .58185 .21622 .58317 .21803 .58121 .21682 .58097 Mtetra
.754 .933 .946 r
.21682 .58097 .21803 .58121 .21997 .57783 .21855 .57992 Mtetra
.142 0 .005 r
.21855 .57992 .21997 .57783 .22214 .57186 .22028 .57884 Mtetra
.496 .21 .409 r
.22028 .57884 .22214 .57186 .22405 .56876 .22194 .57858 Mtetra
.506 .237 .441 r
.22194 .57858 .22405 .56876 .22563 .56932 .2236 .57832 Mtetra
.467 .198 .421 r
.2236 .57832 .22563 .56932 .22734 .56851 .22533 .57737 Mtetra
.124 0 .285 r
.22533 .57737 .22734 .56851 .24592 .3743 .22741 .57233 Mtetra
0 0 .134 r
.22741 .57233 .24592 .3743 .24804 .36772 .24665 .37037 Mtetra
.962 .894 .515 r
.24665 .37037 .24804 .36772 .24985 .36458 .24873 .36418 Mtetra
.866 .87 .839 r
.24873 .36418 .24985 .36458 .25151 .36327 .25043 .36241 Mtetra
.676 .784 .931 r
.25043 .36241 .25151 .36327 .2531 .36267 .25203 .3618 Mtetra
.546 .743 .967 r
.25203 .3618 .2531 .36267 .25468 .36232 .25359 .36158 Mtetra
.61 .793 .969 r
.25359 .36158 .25468 .36232 .25626 .36186 .25517 .36116 Mtetra
.649 .815 .963 r
.25517 .36116 .25626 .36186 .25785 .36132 .25676 .36062 Mtetra
.647 .814 .964 r
.25676 .36062 .25785 .36132 .25945 .36079 .25836 .36009 Mtetra
.645 .815 .965 r
.25836 .36009 .25945 .36079 .26104 .36024 .25995 .35956 Mtetra
.644 .82 .967 r
.25995 .35956 .26104 .36024 .26264 .35969 .26155 .35903 Mtetra
.644 .826 .97 r
.26155 .35903 .26264 .35969 .26424 .35913 .26314 .3585 Mtetra
.664 .835 .965 r
.26314 .3585 .26424 .35913 .26585 .35841 .26475 .3579 Mtetra
.656 .862 .978 r
.26475 .3579 .26585 .35841 .26746 .35772 .26635 .35729 Mtetra
.618 .872 .99 r
.26635 .35729 .26746 .35772 .26905 .35731 .26795 .35675 Mtetra
.513 .81 .999 r
.26795 .35675 .26905 .35731 .27056 .35791 .26953 .35648 Mtetra
.54 .626 .885 r
.26953 .35648 .27056 .35791 .27196 .3598 .2711 .35639 Mtetra
.551 .459 .704 r
.2711 .35639 .27196 .3598 .2732 .36395 .27266 .35633 Mtetra
.578 .402 .607 r
.27266 .35633 .2732 .36395 .27451 .36711 .27428 .35561 Mtetra
.569 .375 .579 r
.27428 .35561 .27451 .36711 .27622 .36539 .27591 .35472 Mtetra
.55 .364 .581 r
.27591 .35472 .27622 .36539 .27783 .36476 .2775 .35441 Mtetra
.391 .243 .557 r
.2775 .35441 .27783 .36476 .26458 .55723 .27885 .35722 Mtetra
0 0 .18 r
.27885 .35722 .26458 .55723 .26573 .56402 .26498 .55802 Mtetra
0 0 .274 r
.26498 .55802 .26573 .56402 .26721 .56652 .26615 .56463 Mtetra
.08 .307 .788 r
.26615 .56463 .26721 .56652 .26884 .56706 .26773 .56581 Mtetra
.617 .704 .907 r
.26773 .56581 .26884 .56706 .27055 .56656 .26944 .5654 Mtetra
.725 .75 .872 r
.26944 .5654 .27055 .56656 .27231 .56549 .27119 .56445 Mtetra
.744 .774 .878 r
.27119 .56445 .27231 .56549 .27413 .56356 .27294 .5634 Mtetra
.726 .951 .95 r
.27294 .5634 .27413 .56356 .27604 .56047 .2747 .56239 Mtetra
.129 0 0 r
.2747 .56239 .27604 .56047 .27808 .55554 .27646 .56134 Mtetra
.473 .176 .38 r
.27646 .56134 .27808 .55554 .28004 .55167 .27817 .56089 Mtetra
.507 .235 .436 r
.27817 .56089 .28004 .55167 .28169 .55205 .27987 .56068 Mtetra
.474 .202 .42 r
.27987 .56068 .28169 .55205 .2834 .55158 .28161 .55989 Mtetra
.25 .006 .335 r
.28161 .55989 .2834 .55158 .29878 .35889 .28356 .55619 Mtetra
0 0 .174 r
.28356 .55619 .29878 .35889 .30101 .34974 .29953 .35485 Mtetra
.833 .796 .301 r
.29953 .35485 .30101 .34974 .30284 .34622 .30173 .34612 Mtetra
.918 .904 .794 r
.30173 .34612 .30284 .34622 .30453 .34467 .30348 .34378 Mtetra
.692 .785 .922 r
.30348 .34378 .30453 .34467 .30615 .34417 .30511 .34309 Mtetra
.569 .707 .935 r
.30511 .34309 .30615 .34417 .30775 .34395 .30671 .34285 Mtetra
.604 .714 .923 r
.30671 .34285 .30775 .34395 .30937 .34353 .30833 .3425 Mtetra
.669 .749 .91 r
.30833 .3425 .30937 .34353 .311 .34282 .30996 .3419 Mtetra
.67 .773 .927 r
.30996 .3419 .311 .34282 .31264 .34209 .31159 .34129 Mtetra
.665 .802 .948 r
.31159 .34129 .31264 .34209 .31428 .34142 .31322 .3407 Mtetra
.657 .819 .961 r
.31322 .3407 .31428 .34142 .31591 .34082 .31485 .34013 Mtetra
.655 .823 .964 r
.31485 .34013 .31591 .34082 .31754 .34024 .31648 .33955 Mtetra
.656 .824 .964 r
.31648 .33955 .31754 .34024 .31917 .33966 .31811 .33897 Mtetra
.657 .825 .964 r
.31811 .33897 .31917 .33966 .32081 .33907 .31975 .33839 Mtetra
.656 .826 .965 r
.31975 .33839 .32081 .33907 .32244 .33849 .32138 .33781 Mtetra
.656 .827 .965 r
.32138 .33781 .32244 .33849 .32408 .3379 .32302 .33723 Mtetra
.656 .828 .966 r
.32302 .33723 .32408 .3379 .32572 .33732 .32466 .33664 Mtetra
.32466 .33664 .32572 .33732 .32735 .33674 .32629 .33606 Mtetra
.655 .828 .966 r
.32629 .33606 .32735 .33674 .32899 .33616 .32793 .33548 Mtetra
.32793 .33548 .32899 .33616 .33063 .33557 .32957 .3349 Mtetra
.32957 .3349 .33063 .33557 .33227 .33499 .33121 .33431 Mtetra
.33121 .33431 .33227 .33499 .33391 .33441 .33286 .33373 Mtetra
.33286 .33373 .33391 .33441 .33555 .33383 .3345 .33315 Mtetra
.655 .827 .966 r
.3345 .33315 .33555 .33383 .3372 .33326 .33614 .33257 Mtetra
.656 .826 .965 r
.33614 .33257 .3372 .33326 .33884 .33267 .33779 .33198 Mtetra
.33779 .33198 .33884 .33267 .34049 .33209 .33944 .3314 Mtetra
.654 .826 .966 r
.33944 .3314 .34049 .33209 .34213 .33152 .34108 .33082 Mtetra
.648 .821 .966 r
.34108 .33082 .34213 .33152 .34378 .33103 .34273 .33026 Mtetra
.645 .803 .959 r
.34273 .33026 .34378 .33103 .34541 .33063 .34438 .32972 Mtetra
.652 .775 .939 r
.34438 .32972 .34541 .33063 .34705 .3302 .34603 .32917 Mtetra
.664 .753 .917 r
.34603 .32917 .34705 .3302 .3487 .32963 .34768 .32859 Mtetra
.676 .753 .908 r
.34768 .32859 .3487 .32963 .35037 .32889 .34933 .32795 Mtetra
.68 .776 .923 r
.34933 .32795 .35037 .32889 .35203 .32811 .35099 .32729 Mtetra
.679 .803 .941 r
.35099 .32729 .35203 .32811 .35369 .32738 .35265 .32664 Mtetra
.673 .818 .953 r
.35265 .32664 .35369 .32738 .35535 .32675 .35431 .326 Mtetra
.67 .816 .954 r
.35431 .326 .35535 .32675 .357 .32615 .35596 .32537 Mtetra
.708 .819 .934 r
.35596 .32537 .357 .32615 .35867 .32545 .35763 .3246 Mtetra
.735 .807 .909 r
.35763 .3246 .35867 .32545 .36033 .32465 .35931 .3237 Mtetra
.636 .761 .938 r
.35931 .3237 .36033 .32465 .36199 .32413 .36096 .32321 Mtetra
0 .332 .787 r
.36096 .32321 .36199 .32413 .3636 .32444 .36255 .32408 Mtetra
.925 .56 .312 r
.36255 .32408 .3636 .32444 .36512 .32664 .36387 .33002 Mtetra
.952 .679 .483 r
.36387 .33002 .36512 .32664 .36643 .33323 .35527 .53269 Mtetra
.536 .307 .515 r
.35527 .53269 .36643 .33323 .3584 .52775 .35684 .53606 Mtetra
.505 .227 .426 r
.35684 .53606 .3584 .52775 .36016 .52736 .3586 .53586 Mtetra
.472 .199 .418 r
.3586 .53586 .36016 .52736 .36197 .52603 .36039 .53502 Mtetra
.481 .21 .426 r
.36039 .53502 .36197 .52603 .3636 .52837 .36217 .5343 Mtetra
.51 .21 .394 r
.36217 .5343 .3636 .52837 .36515 .53262 .36392 .53433 Mtetra
.427 0 .118 r
.36392 .53433 .36515 .53262 .3668 .53475 .36568 .53431 Mtetra
.317 .752 .968 r
.36568 .53431 .3668 .53475 .36851 .53564 .36744 .53423 Mtetra
.554 .657 .905 r
.36744 .53423 .36851 .53564 .37027 .53549 .3692 .53405 Mtetra
.67 .699 .868 r
.3692 .53405 .37027 .53549 .37206 .53477 .37099 .53336 Mtetra
.816 .739 .779 r
.37099 .53336 .37206 .53477 .3739 .53317 .37284 .53133 Mtetra
.907 .709 .624 r
.37284 .53133 .3739 .53317 .37581 .52971 .37491 .52443 Mtetra
.954 .685 .488 r
.37491 .52443 .37581 .52971 .37788 .5226 .38572 .32001 Mtetra
.541 .315 .522 r
.38572 .32001 .37788 .5226 .38819 .32579 .38758 .31532 Mtetra
.575 .384 .585 r
.38758 .31532 .38819 .32579 .38989 .32474 .38928 .31434 Mtetra
.553 .367 .584 r
.38928 .31434 .38989 .32474 .39154 .32494 .39095 .31398 Mtetra
.552 .365 .581 r
.39095 .31398 .39154 .32494 .39333 .32171 .39262 .31359 Mtetra
.592 .409 .603 r
.39262 .31359 .39333 .32171 .39522 .31624 .39432 .31248 Mtetra
.645 .509 .683 r
.39432 .31248 .39522 .31624 .397 .31308 .39602 .31139 Mtetra
.7 .663 .81 r
.39602 .31139 .397 .31308 .39874 .31116 .39772 .31045 Mtetra
.672 .831 .959 r
.39772 .31045 .39874 .31116 .40043 .31037 .3994 .3098 Mtetra
.635 .854 .983 r
.3994 .3098 .40043 .31037 .40211 .30986 .40109 .30923 Mtetra
.635 .839 .979 r
.40109 .30923 .40211 .30986 .40379 .30943 .40277 .30867 Mtetra
.661 .816 .958 r
.40277 .30867 .40379 .30943 .40548 .30882 .40446 .30806 Mtetra
.66 .816 .959 r
.40446 .30806 .40548 .30882 .40716 .30822 .40615 .30746 Mtetra
.683 .822 .95 r
.40615 .30746 .40716 .30822 .40885 .30756 .40784 .30677 Mtetra
.743 .826 .916 r
.40784 .30677 .40885 .30756 .41055 .30673 .40954 .30582 Mtetra
.659 .78 .938 r
.40954 .30582 .41055 .30673 .41224 .30615 .41123 .30523 Mtetra
.226 .58 .944 r
.41123 .30523 .41224 .30615 .41391 .30617 .41289 .30561 Mtetra
.907 .502 .199 r
.41289 .30561 .41391 .30617 .41551 .30804 .4144 .31005 Mtetra
.958 .681 .467 r
.4144 .31005 .41551 .30804 .41702 .31298 .409 .51402 Mtetra
.539 .309 .515 r
.409 .51402 .41702 .31298 .41201 .51039 .41062 .51891 Mtetra
.518 .239 .431 r
.41062 .51891 .41201 .51039 .41375 .51171 .41241 .51896 Mtetra
.467 .186 .402 r
.41241 .51896 .41375 .51171 .41558 .51053 .41422 .51821 Mtetra
.45 .174 .402 r
.41422 .51821 .41558 .51053 .41746 .5079 .41605 .51712 Mtetra
.485 .215 .429 r
.41605 .51712 .41746 .5079 .41934 .50492 .41787 .51644 Mtetra
.497 .235 .447 r
.41787 .51644 .41934 .50492 .42116 .50399 .41969 .51582 Mtetra
.505 .243 .451 r
.41969 .51582 .42116 .50399 .42284 .50767 .4215 .51539 Mtetra
.513 .23 .421 r
.4215 .51539 .42284 .50767 .42447 .51297 .4233 .51538 Mtetra
.464 .078 .221 r
.4233 .51538 .42447 .51297 .4262 .51549 .42511 .51538 Mtetra
.163 .698 .835 r
.42511 .51538 .4262 .51549 .42797 .51669 .42691 .51525 Mtetra
.621 .684 .888 r
.42691 .51525 .42797 .51669 .42978 .51656 .42873 .5148 Mtetra
.637 .645 .842 r
.42873 .5148 .42978 .51656 .4316 .51607 .43056 .51424 Mtetra
.645 .64 .831 r
.43056 .51424 .4316 .51607 .43343 .51538 .43238 .51363 Mtetra
.646 .65 .84 r
.43238 .51363 .43343 .51538 .43526 .51468 .43421 .51302 Mtetra
.651 .664 .85 r
.43421 .51302 .43526 .51468 .43709 .51392 .43604 .51239 Mtetra
.647 .682 .869 r
.43604 .51239 .43709 .51392 .43892 .51318 .43787 .51181 Mtetra
.544 .662 .913 r
.43787 .51181 .43892 .51318 .44074 .51286 .43969 .51165 Mtetra
.635 .731 .917 r
.43969 .51165 .44074 .51286 .44257 .51232 .44152 .51113 Mtetra
.772 .771 .852 r
.44152 .51113 .44257 .51232 .44442 .51128 .44337 .5098 Mtetra
.912 .738 .653 r
.44337 .5098 .44442 .51128 .4463 .50849 .44531 .50456 Mtetra
.962 .687 .467 r
.44531 .50456 .4463 .50849 .44824 .5032 .45192 .29955 Mtetra
.546 .32 .523 r
.45192 .29955 .44824 .5032 .45459 .30193 .4538 .29216 Mtetra
.604 .408 .59 r
.4538 .29216 .45459 .30193 .45646 .29462 .45555 .29043 Mtetra
.626 .486 .671 r
.45555 .29043 .45646 .29462 .45824 .29155 .45727 .28947 Mtetra
.633 .596 .795 r
.45727 .28947 .45824 .29155 .45998 .28968 .45899 .28891 Mtetra
.65 .816 .963 r
.45899 .28891 .45998 .28968 .46171 .28899 .46072 .28833 Mtetra
.605 .829 .985 r
.46072 .28833 .46171 .28899 .46342 .28865 .46244 .28785 Mtetra
.609 .796 .971 r
.46244 .28785 .46342 .28865 .46514 .28848 .46416 .2874 Mtetra
.665 .752 .915 r
.46416 .2874 .46514 .28848 .46686 .28794 .46588 .28678 Mtetra
.673 .739 .9 r
.46588 .28678 .46686 .28794 .46859 .28732 .46761 .28612 Mtetra
.677 .733 .892 r
.46761 .28612 .46859 .28732 .47032 .28663 .46934 .28544 Mtetra
.751 .756 .856 r
.46934 .28544 .47032 .28663 .47205 .28552 .47108 .28432 Mtetra
.698 .739 .883 r
.47108 .28432 .47205 .28552 .47379 .28462 .47281 .28352 Mtetra
.537 .7 .944 r
.47281 .28352 .47379 .28462 .47552 .28415 .47453 .28335 Mtetra
.837 .376 0 r
.47453 .28335 .47552 .28415 .47722 .28531 .47621 .28654 Mtetra
.965 .681 .445 r
.47621 .28654 .47722 .28531 .4789 .28851 .47487 .48945 Mtetra
.544 .314 .516 r
.47487 .48945 .4789 .28851 .4778 .48711 .47659 .49751 Mtetra
.548 .274 .452 r
.47659 .49751 .4778 .48711 .47953 .49516 .47843 .49834 Mtetra
.462 .108 .278 r
.47843 .49834 .47953 .49516 .48134 .49752 .48028 .49818 Mtetra
0 0 0 r
.48028 .49818 .48134 .49752 .48318 .49852 .48214 .49757 Mtetra
.451 .709 .977 r
.48214 .49757 .48318 .49852 .48503 .49877 .48399 .49753 Mtetra
.611 .718 .921 r
.48399 .49753 .48503 .49877 .48689 .49843 .48585 .4971 Mtetra
.743 .748 .856 r
.48585 .4971 .48689 .49843 .48875 .49745 .48772 .49594 Mtetra
.906 .743 .668 r
.48772 .49594 .48875 .49745 .49064 .49492 .48963 .49131 Mtetra
.966 .687 .453 r
.48963 .49131 .49064 .49492 .49254 .4902 .49354 .28699 Mtetra
.55 .322 .523 r
.49354 .28699 .49254 .4902 .49624 .29055 .49538 .27774 Mtetra
.594 .391 .575 r
.49538 .27774 .49624 .29055 .49807 .28079 .49713 .27574 Mtetra
.615 .461 .649 r
.49713 .27574 .49807 .28079 .49984 .27748 .49888 .27473 Mtetra
.621 .54 .742 r
.49888 .27473 .49984 .27748 .5016 .27546 .50063 .27414 Mtetra
.733 .732 .85 r
.50063 .27414 .5016 .27546 .50335 .27423 .50238 .2731 Mtetra
.691 .753 .899 r
.50238 .2731 .50335 .27423 .5051 .27352 .50413 .27235 Mtetra
.528 .681 .935 r
.50413 .27235 .5051 .27352 .50685 .27336 .50588 .27222 Mtetra
.718 .254 0 r
.50588 .27222 .50685 .27336 .50859 .27439 .50762 .27498 Mtetra
.968 .681 .433 r
.50762 .27498 .50859 .27439 .51032 .2773 .50836 .47669 Mtetra
.547 .316 .516 r
.50836 .47669 .51032 .2773 .51127 .47328 .51018 .4865 Mtetra
.553 .287 .466 r
.51018 .4865 .51127 .47328 .5131 .48402 .51205 .48763 Mtetra
.474 .132 .306 r
.51205 .48763 .5131 .48402 .51496 .48663 .51393 .4875 Mtetra
.053 0 0 r
.51393 .4875 .51496 .48663 .51684 .48771 .51581 .48687 Mtetra
.473 .749 .99 r
.51581 .48687 .51684 .48771 .51872 .48786 .5177 .48673 Mtetra
.604 .74 .94 r
.5177 .48673 .51872 .48786 .5206 .48738 .51958 .4863 Mtetra
.748 .794 .89 r
.51958 .4863 .5206 .48738 .52249 .4863 .52147 .48518 Mtetra
.925 .781 .683 r
.52147 .48518 .52249 .4863 .52438 .48388 .52335 .48094 Mtetra
.969 .687 .441 r
.52335 .48094 .52438 .48388 .52626 .47942 .52522 .27783 Mtetra
.553 .325 .523 r
.52522 .27783 .52626 .47942 .52795 .28299 .52698 .26688 Mtetra
.587 .378 .564 r
.52698 .26688 .52795 .28299 .52971 .27013 .52875 .26463 Mtetra
.61 .45 .64 r
.52875 .26463 .52971 .27013 .53147 .26661 .53051 .26361 Mtetra
.615 .524 .728 r
.53051 .26361 .53147 .26661 .53324 .26448 .53228 .26302 Mtetra
.662 .689 .865 r
.53228 .26302 .53324 .26448 .535 .2634 .53405 .26238 Mtetra
.664 .77 .928 r
.53405 .26238 .535 .2634 .53677 .26276 .53582 .26175 Mtetra
.656 .768 .932 r
.53582 .26175 .53677 .26276 .53854 .26228 .53759 .26115 Mtetra
.748 .771 .872 r
.53759 .26115 .53854 .26228 .54031 .26113 .53936 .26006 Mtetra
.727 .779 .894 r
.53936 .26006 .54031 .26113 .54208 .26008 .54114 .25912 Mtetra
.573 .752 .962 r
.54114 .25912 .54208 .26008 .54386 .25965 .54291 .2588 Mtetra
.745 .258 0 r
.54291 .2588 .54386 .25965 .54565 .26216 .54471 .26148 Mtetra
.971 .681 .416 r
.54471 .26148 .54565 .26216 .54893 .46644 .54793 .46648 Mtetra
.93 .563 .293 r
.54793 .46648 .54893 .46644 .55091 .47621 .5499 .47512 Mtetra
0 .211 .708 r
.5499 .47512 .55091 .47621 .55283 .47767 .55182 .47653 Mtetra
.561 .722 .949 r
.55182 .47653 .55283 .47767 .55474 .47738 .55373 .47625 Mtetra
.781 .794 .864 r
.55373 .47625 .55474 .47738 .55664 .47598 .55563 .47487 Mtetra
.93 .784 .677 r
.55563 .47487 .55664 .47598 .55851 .4716 .55751 .4705 Mtetra
.973 .688 .426 r
.55751 .4705 .55851 .4716 .5582 .26523 .55726 .2642 Mtetra
.966 .744 .552 r
.55726 .2642 .5582 .26523 .55989 .25579 .55895 .25465 Mtetra
.853 .789 .788 r
.55895 .25465 .55989 .25579 .56166 .25369 .56072 .25254 Mtetra
.665 .746 .91 r
.56072 .25254 .56166 .25369 .56345 .25306 .56251 .25189 Mtetra
.54 .692 .938 r
.56251 .25189 .56345 .25306 .56524 .25289 .5643 .25172 Mtetra
.619 .724 .921 r
.5643 .25172 .56524 .25289 .56703 .25248 .5661 .25127 Mtetra
.669 .737 .901 r
.5661 .25127 .56703 .25248 .56882 .25184 .56789 .25061 Mtetra
.674 .735 .896 r
.56789 .25061 .56882 .25184 .57061 .25115 .56968 .24992 Mtetra
.744 .758 .864 r
.56968 .24992 .57061 .25115 .5724 .24995 .57146 .24883 Mtetra
.737 .775 .884 r
.57146 .24883 .5724 .24995 .57418 .24881 .57325 .24782 Mtetra
.605 .757 .951 r
.57325 .24782 .57418 .24881 .57598 .24827 .57505 .24739 Mtetra
.626 .124 0 r
.57505 .24739 .57598 .24827 .57782 .25033 .5769 .2496 Mtetra
.973 .679 .403 r
.5769 .2496 .57782 .25033 .58323 .45212 .58227 .45301 Mtetra
.926 .571 .337 r
.58227 .45301 .58323 .45212 .58539 .46496 .5844 .46386 Mtetra
0 .106 .618 r
.5844 .46386 .58539 .46496 .58737 .46676 .58637 .46559 Mtetra
.531 .705 .951 r
.58637 .46559 .58737 .46676 .58931 .46657 .58831 .46541 Mtetra
.765 .79 .874 r
.58831 .46541 .58931 .46657 .59123 .46529 .59023 .46414 Mtetra
.922 .791 .698 r
.59023 .46414 .59123 .46529 .59309 .46142 .5921 .46028 Mtetra
.975 .687 .413 r
.5921 .46028 .59309 .46142 .5907 .25846 .58977 .2571 Mtetra
.968 .723 .514 r
.58977 .2571 .5907 .25846 .59223 .2448 .5913 .24361 Mtetra
.875 .785 .757 r
.5913 .24361 .59223 .2448 .594 .24227 .59307 .24108 Mtetra
.688 .748 .897 r
.59307 .24108 .594 .24227 .5958 .24151 .59488 .24031 Mtetra
.568 .699 .93 r
.59488 .24031 .5958 .24151 .59762 .24126 .59669 .24005 Mtetra
.683 .745 .898 r
.59669 .24005 .59762 .24126 .59943 .24051 .5985 .23931 Mtetra
.725 .759 .88 r
.5985 .23931 .59943 .24051 .60123 .23955 .60031 .23835 Mtetra
.607 .716 .922 r
.60031 .23835 .60123 .23955 .60305 .23916 .60212 .23794 Mtetra
0 .031 .572 r
.60212 .23794 .60305 .23916 .60493 .24133 .60401 .23995 Mtetra
.975 .678 .389 r
.60401 .23995 .60493 .24133 .61225 .44648 .61121 .44293 Mtetra
.88 .562 .054 r
.61121 .44293 .61225 .44648 .61447 .45618 .61348 .45454 Mtetra
0 .267 .774 r
.61348 .45454 .61447 .45618 .61648 .45759 .61549 .45611 Mtetra
.629 .693 .89 r
.61549 .45611 .61648 .45759 .61843 .45694 .61744 .45558 Mtetra
.732 .75 .867 r
.61744 .45558 .61843 .45694 .62036 .45571 .61938 .45447 Mtetra
.65 .743 .918 r
.61938 .45447 .62036 .45571 .62232 .455 .62134 .45384 Mtetra
.55 .718 .951 r
.62134 .45384 .62232 .455 .62428 .45472 .6233 .45358 Mtetra
.696 .779 .915 r
.6233 .45358 .62428 .45472 .62623 .45388 .62525 .45273 Mtetra
.911 .803 .728 r
.62525 .45273 .62623 .45388 .6281 .45058 .62713 .44944 Mtetra
.976 .685 .399 r
.62713 .44944 .6281 .45058 .6237 .25197 .62278 .25078 Mtetra
.976 .717 .474 r
.62278 .25078 .6237 .25197 .62495 .2334 .62404 .23221 Mtetra
.893 .789 .738 r
.62404 .23221 .62495 .2334 .62671 .23055 .62579 .22935 Mtetra
.702 .756 .894 r
.62579 .22935 .62671 .23055 .62853 .22971 .62762 .22851 Mtetra
.585 .71 .929 r
.62762 .22851 .62853 .22971 .63037 .22938 .62946 .22818 Mtetra
.665 .743 .908 r
.62946 .22818 .63037 .22938 .6322 .22872 .63129 .22752 Mtetra
.733 .766 .879 r
.63129 .22752 .6322 .22872 .63402 .2277 .63311 .22651 Mtetra
.635 .731 .917 r
.63311 .22651 .63402 .2277 .63586 .22718 .63495 .22598 Mtetra
0 .28 .778 r
.63495 .22598 .63586 .22718 .63776 .2285 .63686 .2273 Mtetra
.939 .575 .187 r
.63686 .2273 .63776 .2285 .64 .23844 .63909 .23727 Mtetra
.975 .675 .374 r
.63909 .23727 .64 .23844 .64969 .44296 .64872 .44182 Mtetra
0 0 .512 r
.64872 .44182 .64969 .44296 .65177 .44523 .65081 .44409 Mtetra
.628 .756 .939 r
.65081 .44409 .65177 .44523 .65375 .44468 .65279 .44354 Mtetra
.768 .801 .88 r
.65279 .44354 .65375 .44468 .6557 .44339 .65474 .44225 Mtetra
.78 .805 .873 r
.65474 .44225 .6557 .44339 .65765 .442 .65669 .44087 Mtetra
.725 .792 .905 r
.65669 .44087 .65765 .442 .65961 .44098 .65865 .43986 Mtetra
.711 .791 .913 r
.65865 .43986 .65961 .44098 .66158 .44003 .66062 .43892 Mtetra
.656 .774 .936 r
.66062 .43892 .66158 .44003 .66355 .43937 .6626 .43825 Mtetra
.572 .74 .955 r
.6626 .43825 .66355 .43937 .66555 .43903 .66459 .4379 Mtetra
.545 .724 .957 r
.66459 .4379 .66555 .43903 .66755 .43879 .6666 .43765 Mtetra
.451 .674 .96 r
.6666 .43765 .66755 .43879 .66957 .43884 .66861 .43768 Mtetra
.417 .654 .957 r
.66861 .43768 .66957 .43884 .67159 .43897 .67063 .43781 Mtetra
.629 .755 .938 r
.67063 .43781 .67159 .43897 .67358 .43842 .67263 .43726 Mtetra
.89 .812 .765 r
.67263 .43726 .67358 .43842 .67548 .4357 .67452 .43453 Mtetra
.981 .722 .464 r
.67452 .43453 .67548 .4357 .67665 .41754 .67569 .41623 Mtetra
.977 .681 .379 r
.67569 .41623 .67665 .41754 .66919 .21809 .6683 .21687 Mtetra
.911 .79 .714 r
.6683 .21687 .66919 .21809 .67092 .21483 .67003 .21361 Mtetra
.707 .758 .892 r
.67003 .21361 .67092 .21483 .67277 .21395 .67188 .21273 Mtetra
.584 .709 .929 r
.67188 .21273 .67277 .21395 .67465 .21361 .67376 .2124 Mtetra
.619 .725 .922 r
.67376 .2124 .67465 .21361 .67651 .21313 .67563 .21193 Mtetra
.731 .77 .884 r
.67563 .21193 .67651 .21313 .67836 .2121 .67747 .21092 Mtetra
.636 .739 .923 r
.67747 .21092 .67836 .2121 .68023 .21155 .67934 .21038 Mtetra
.027 .384 .846 r
.67934 .21038 .68023 .21155 .68218 .21266 .68129 .21143 Mtetra
.93 .562 .154 r
.68129 .21143 .68218 .21266 .68472 .22474 .68372 .22151 Mtetra
.976 .672 .346 r
.68372 .22151 .68472 .22474 .69745 .42875 .69649 .42709 Mtetra
0 .011 .578 r
.69649 .42709 .69745 .42875 .69963 .43128 .69867 .42978 Mtetra
.585 .675 .902 r
.69867 .42978 .69963 .43128 .70165 .43081 .7007 .42944 Mtetra
.714 .751 .881 r
.7007 .42944 .70165 .43081 .70363 .42966 .70269 .42843 Mtetra
.705 .772 .904 r
.70269 .42843 .70363 .42966 .70562 .42862 .70469 .42751 Mtetra
.524 .719 .962 r
.70469 .42751 .70562 .42862 .70766 .42842 .70673 .42731 Mtetra
.661 .78 .937 r
.70673 .42731 .70766 .42842 .70967 .42773 .70874 .4266 Mtetra
.871 .824 .799 r
.70874 .4266 .70967 .42773 .7116 .42544 .71066 .42429 Mtetra
.98 .754 .524 r
.71066 .42429 .7116 .42544 .71307 .41548 .71215 .4144 Mtetra
.977 .678 .362 r
.71215 .4144 .71307 .41548 .70288 .20713 .702 .20591 Mtetra
.936 .79 .674 r
.702 .20591 .70288 .20713 .70456 .20314 .70369 .20192 Mtetra
.73 .767 .883 r
.70369 .20192 .70456 .20314 .70642 .20213 .70555 .2009 Mtetra
.604 .717 .924 r
.70555 .2009 .70642 .20213 .70832 .20172 .70745 .20049 Mtetra
.603 .716 .924 r
.70745 .20049 .70832 .20172 .71022 .20131 .70934 .20008 Mtetra
.741 .77 .876 r
.70934 .20008 .71022 .20131 .71208 .20022 .7112 .19899 Mtetra
.659 .739 .909 r
.7112 .19899 .71208 .20022 .71396 .19958 .71309 .19834 Mtetra
.242 .514 .909 r
.71309 .19834 .71396 .19958 .71593 .20024 .71506 .19899 Mtetra
.879 .485 .027 r
.71506 .19899 .71593 .20024 .71832 .20743 .71745 .20613 Mtetra
.975 .667 .334 r
.71745 .20613 .71832 .20743 .7337 .41593 .73278 .41471 Mtetra
.651 .201 0 r
.73278 .41471 .7337 .41593 .73601 .41944 .73508 .41823 Mtetra
.391 .63 .949 r
.73508 .41823 .73601 .41944 .7381 .41969 .73717 .41846 Mtetra
.698 .773 .91 r
.73717 .41846 .7381 .41969 .74012 .4188 .7392 .41756 Mtetra
.875 .812 .784 r
.7392 .41756 .74012 .4188 .74204 .4163 .74112 .4151 Mtetra
.98 .761 .536 r
.74112 .4151 .74204 .4163 .74347 .40674 .7426 .40629 Mtetra
.977 .676 .345 r
.7426 .40629 .74347 .40674 .73121 .19692 .73038 .19618 Mtetra
.973 .834 .646 r
.73038 .19618 .73121 .19692 .73287 .19271 .73203 .19178 Mtetra
.738 .833 .923 r
.73203 .19178 .73287 .19271 .73475 .19182 .7339 .19077 Mtetra
.579 .746 .956 r
.7339 .19077 .73475 .19182 .73668 .19158 .73583 .19041 Mtetra
.518 .689 .945 r
.73583 .19041 .73668 .19158 .73863 .19158 .73777 .19028 Mtetra
.65 .726 .904 r
.73777 .19028 .73863 .19158 .74054 .19098 .73967 .18966 Mtetra
.656 .726 .901 r
.73967 .18966 .74054 .19098 .74245 .19032 .74158 .18902 Mtetra
.68 .739 .895 r
.74158 .18902 .74245 .19032 .74434 .18953 .74348 .18826 Mtetra
.754 .77 .867 r
.74348 .18826 .74434 .18953 .74621 .18833 .74535 .18707 Mtetra
.681 .746 .9 r
.74535 .18707 .74621 .18833 .74811 .18756 .74725 .1863 Mtetra
.389 .6 .931 r
.74725 .1863 .74811 .18756 .75009 .18785 .74924 .18659 Mtetra
.824 .416 0 r
.74924 .18659 .75009 .18785 .7525 .19381 .75165 .19253 Mtetra
.973 .662 .315 r
.75165 .19253 .7525 .19381 .77044 .40358 .76953 .40235 Mtetra
.694 .253 0 r
.76953 .40235 .77044 .40358 .77286 .40767 .77195 .40645 Mtetra
.353 .607 .945 r
.77195 .40645 .77286 .40767 .775 .40803 .77409 .40679 Mtetra
.678 .768 .919 r
.77409 .40679 .775 .40803 .77705 .40724 .77615 .40599 Mtetra
.856 .815 .808 r
.77615 .40599 .77705 .40724 .779 .40504 .77809 .40382 Mtetra
.979 .771 .553 r
.77809 .40382 .779 .40504 .78046 .39684 .7796 .39615 Mtetra
.976 .671 .327 r
.7796 .39615 .78046 .39684 .76565 .18537 .76485 .18467 Mtetra
.984 .829 .608 r
.76485 .18467 .76565 .18537 .76724 .18056 .76642 .17963 Mtetra
.756 .843 .917 r
.76642 .17963 .76724 .18056 .76914 .17955 .76831 .17851 Mtetra
.596 .758 .956 r
.76831 .17851 .76914 .17955 .77109 .17925 .77025 .17808 Mtetra
.508 .688 .948 r
.77025 .17808 .77109 .17925 .77307 .17926 .77222 .17798 Mtetra
.651 .731 .908 r
.77222 .17798 .77307 .17926 .775 .17866 .77416 .17735 Mtetra
.658 .729 .902 r
.77416 .17735 .775 .17866 .77693 .17798 .77609 .17669 Mtetra
.672 .739 .901 r
.77609 .17669 .77693 .17798 .77885 .17719 .77801 .17596 Mtetra
.767 .786 .868 r
.77801 .17596 .77885 .17719 .78072 .17581 .77989 .17469 Mtetra
.704 .787 .916 r
.77989 .17469 .78072 .17581 .78263 .17483 .78181 .17381 Mtetra
.473 .705 .97 r
.78181 .17381 .78263 .17483 .7846 .17466 .78379 .17375 Mtetra
.79 .349 0 r
.78379 .17375 .7846 .17466 .78698 .17903 .7862 .1785 Mtetra
.971 .656 .297 r
.7862 .1785 .78698 .17903 .80756 .39026 .80671 .38949 Mtetra
.808 .359 0 r
.80671 .38949 .80756 .39026 .81019 .39573 .8093 .39455 Mtetra
.282 .57 .936 r
.8093 .39455 .81019 .39573 .81238 .39629 .8115 .39506 Mtetra
.645 .76 .933 r
.8115 .39506 .81238 .39629 .81448 .39564 .81359 .39441 Mtetra
.826 .818 .842 r
.81359 .39441 .81448 .39564 .81646 .39382 .81558 .39259 Mtetra
.908 .736 .657 r
.14915 .60131 .15033 .60227 .15254 .59653 .15137 .59555 Mtetra
.936 .686 .535 r
.15137 .59555 .15254 .59653 .17599 .39487 .1749 .39384 Mtetra
.907 .727 .647 r
.1749 .39384 .17599 .39487 .17813 .3889 .17704 .38788 Mtetra
.772 .758 .84 r
.17704 .38788 .17813 .3889 .17974 .3877 .17866 .38668 Mtetra
.64 .735 .917 r
.17866 .38668 .17974 .3877 .18128 .38723 .1802 .38622 Mtetra
.512 .692 .95 r
.1802 .38622 .18128 .38723 .18279 .38714 .1817 .38613 Mtetra
.75 .758 .859 r
.1817 .38613 .18279 .38714 .18439 .38612 .1833 .3851 Mtetra
.698 .75 .892 r
.1833 .3851 .18439 .38612 .18596 .38541 .18487 .3844 Mtetra
.487 .683 .953 r
.18487 .3844 .18596 .38541 .18746 .38537 .18637 .38436 Mtetra
.926 .543 .247 r
.18637 .38436 .18746 .38537 .18854 .38935 .18745 .38836 Mtetra
.939 .683 .523 r
.18745 .38836 .18854 .38935 .16913 .58991 .16796 .589 Mtetra
.933 .582 .336 r
.16796 .589 .16913 .58991 .17014 .59551 .16897 .59458 Mtetra
.245 .598 .951 r
.16897 .59458 .17014 .59551 .17171 .59584 .17054 .59489 Mtetra
.673 .772 .925 r
.17054 .59489 .17171 .59584 .17337 .59521 .1722 .59426 Mtetra
.752 .782 .878 r
.1722 .59426 .17337 .59521 .17508 .59416 .17392 .59321 Mtetra
.477 .707 .97 r
.17392 .59321 .17508 .59416 .17669 .5941 .17553 .59314 Mtetra
.585 .746 .954 r
.17553 .59314 .17669 .5941 .17833 .59378 .17716 .59282 Mtetra
.751 .78 .877 r
.17716 .59282 .17833 .59378 .18004 .59273 .17888 .59177 Mtetra
.907 .743 .666 r
.17888 .59177 .18004 .59273 .18217 .5875 .18101 .58653 Mtetra
.939 .687 .529 r
.18101 .58653 .18217 .5875 .20397 .38564 .20289 .38462 Mtetra
.913 .728 .638 r
.20289 .38462 .20397 .38564 .20613 .3792 .20505 .37818 Mtetra
.792 .762 .826 r
.20505 .37818 .20613 .3792 .20777 .37781 .2067 .37679 Mtetra
.626 .733 .924 r
.2067 .37679 .20777 .37781 .20933 .37739 .20825 .37638 Mtetra
.466 .676 .955 r
.20825 .37638 .20933 .37739 .21084 .37738 .20976 .37638 Mtetra
.625 .737 .928 r
.20976 .37638 .21084 .37738 .2124 .37695 .21132 .37597 Mtetra
.654 .748 .919 r
.21132 .37597 .2124 .37695 .21397 .37641 .21288 .37544 Mtetra
.662 .754 .919 r
.21288 .37544 .21397 .37641 .21554 .37584 .21445 .37489 Mtetra
.745 .774 .877 r
.21445 .37489 .21554 .37584 .21716 .37473 .21607 .37393 Mtetra
.718 .799 .915 r
.21607 .37393 .21716 .37473 .21876 .37387 .21766 .37314 Mtetra
.545 .776 .984 r
.21766 .37314 .21876 .37387 .2203 .37367 .21921 .37289 Mtetra
.818 .338 0 r
.21921 .37289 .2203 .37367 .2215 .37709 .22052 .37505 Mtetra
.96 .676 .453 r
.22052 .37505 .2215 .37709 .20404 .57829 .22035 .39293 Mtetra
0 0 .132 r
.22035 .39293 .20404 .57829 .20508 .58452 .20423 .58027 Mtetra
.235 .221 .638 r
.20423 .58027 .20508 .58452 .20665 .58513 .20568 .58222 Mtetra
.454 .433 .746 r
.20568 .58222 .20665 .58513 .20833 .58452 .20726 .58271 Mtetra
.541 .584 .847 r
.20726 .58271 .20833 .58452 .21006 .58344 .20889 .58265 Mtetra
.583 .784 .975 r
.20889 .58265 .21006 .58344 .21175 .58285 .21056 .58229 Mtetra
.626 .849 .985 r
.21056 .58229 .21175 .58285 .21342 .58239 .21224 .58174 Mtetra
.661 .837 .968 r
.21224 .58174 .21342 .58239 .2151 .58185 .21393 .58111 Mtetra
.604 .804 .977 r
.21393 .58111 .2151 .58185 .21682 .58097 .21561 .58068 Mtetra
.478 .854 .985 r
.21561 .58068 .21682 .58097 .21855 .57992 .21728 .5803 Mtetra
0 0 0 r
.21728 .5803 .21855 .57992 .22028 .57884 .21895 .57989 Mtetra
.265 0 0 r
.21895 .57989 .22028 .57884 .22194 .57858 .22061 .57964 Mtetra
.168 0 0 r
.22061 .57964 .22194 .57858 .2236 .57832 .22229 .5792 Mtetra
0 0 0 r
.22229 .5792 .2236 .57832 .22533 .57737 .22402 .57823 Mtetra
.95 .955 .712 r
.22402 .57823 .22533 .57737 .22741 .57233 .22595 .57499 Mtetra
.999 .84 .545 r
.22595 .57499 .22741 .57233 .24665 .37037 .22846 .56508 Mtetra
0 0 .134 r
.22846 .56508 .24665 .37037 .24873 .36418 .24737 .36663 Mtetra
0 0 0 r
.24737 .36663 .24873 .36418 .25043 .36241 .24912 .36421 Mtetra
.286 0 .065 r
.24912 .36421 .25043 .36241 .25203 .3618 .25071 .36365 Mtetra
.41 .001 .15 r
.25071 .36365 .25203 .3618 .25359 .36158 .25227 .36349 Mtetra
.014 0 0 r
.25227 .36349 .25359 .36158 .25517 .36116 .25393 .3622 Mtetra
.594 .893 .604 r
.25393 .3622 .25517 .36116 .25676 .36062 .25562 .36055 Mtetra
.832 .952 .895 r
.25562 .36055 .25676 .36062 .25836 .36009 .25729 .35915 Mtetra
.714 .774 .899 r
.25729 .35915 .25836 .36009 .25995 .35956 .25891 .35835 Mtetra
.634 .701 .895 r
.25891 .35835 .25995 .35956 .26155 .35903 .2605 .35791 Mtetra
.602 .706 .917 r
.2605 .35791 .26155 .35903 .26314 .3585 .26208 .35757 Mtetra
.628 .757 .94 r
.26208 .35757 .26314 .3585 .26475 .3579 .26367 .35713 Mtetra
.651 .8 .954 r
.26367 .35713 .26475 .3579 .26635 .35729 .26527 .35659 Mtetra
.663 .819 .958 r
.26527 .35659 .26635 .35729 .26795 .35675 .26687 .356 Mtetra
.69 .812 .941 r
.26687 .356 .26795 .35675 .26953 .35648 .26848 .35533 Mtetra
.694 .731 .879 r
.26848 .35533 .26953 .35648 .2711 .35639 .2701 .3546 Mtetra
.669 .633 .805 r
.2701 .3546 .2711 .35639 .27266 .35633 .27172 .35388 Mtetra
.669 .578 .744 r
.27172 .35388 .27266 .35633 .27428 .35561 .27335 .35297 Mtetra
.652 .557 .735 r
.27335 .35297 .27428 .35561 .27591 .35472 .27498 .35215 Mtetra
.597 .53 .751 r
.27498 .35215 .27591 .35472 .2775 .35441 .27657 .35179 Mtetra
.181 .27 .72 r
.27657 .35179 .2775 .35441 .27885 .35722 .27803 .35317 Mtetra
.774 .513 0 r
.27803 .35317 .27885 .35722 .26498 .55802 .27912 .35934 Mtetra
0 0 .178 r
.27912 .35934 .26498 .55802 .26615 .56463 .26533 .55945 Mtetra
.103 .101 .569 r
.26533 .55945 .26615 .56463 .26773 .56581 .26677 .56261 Mtetra
.423 .398 .727 r
.26677 .56261 .26773 .56581 .26944 .5654 .26839 .56333 Mtetra
.516 .543 .822 r
.26839 .56333 .26944 .5654 .27119 .56445 .27006 .5634 Mtetra
.541 .718 .955 r
.27006 .5634 .27119 .56445 .27294 .5634 .27175 .5632 Mtetra
.42 .843 .958 r
.27175 .5632 .27294 .5634 .2747 .56239 .27346 .56284 Mtetra
0 0 0 r
.27346 .56284 .2747 .56239 .27646 .56134 .27518 .56232 Mtetra
.193 0 0 r
.27518 .56232 .27646 .56134 .27817 .56089 .27689 .56196 Mtetra
.198 0 0 r
.27689 .56196 .27817 .56089 .27987 .56068 .27861 .56156 Mtetra
0 0 0 r
.27861 .56156 .27987 .56068 .28161 .55989 .28035 .56069 Mtetra
.883 .988 .73 r
.28035 .56069 .28161 .55989 .28356 .55619 .28222 .55818 Mtetra
.99 .885 .56 r
.28222 .55818 .28356 .55619 .29953 .35485 .28438 .55155 Mtetra
0 0 .169 r
.28438 .55155 .29953 .35485 .30173 .34612 .30037 .3495 Mtetra
0 0 0 r
.30037 .3495 .30173 .34612 .30348 .34378 .30229 .34484 Mtetra
.637 .906 .598 r
.30229 .34484 .30348 .34378 .30511 .34309 .304 .343 Mtetra
.777 .963 .925 r
.304 .343 .30511 .34309 .30671 .34285 .30567 .34184 Mtetra
.714 .766 .893 r
.30567 .34184 .30671 .34285 .30833 .3425 .30731 .34103 Mtetra
.66 .671 .85 r
.30731 .34103 .30833 .3425 .30996 .3419 .30894 .34042 Mtetra
.635 .661 .858 r
.30894 .34042 .30996 .3419 .31159 .34129 .31056 .33995 Mtetra
.642 .684 .874 r
.31056 .33995 .31159 .34129 .31322 .3407 .31219 .33945 Mtetra
.658 .705 .882 r
.31219 .33945 .31322 .3407 .31485 .34013 .31382 .33888 Mtetra
.659 .707 .883 r
.31382 .33888 .31485 .34013 .31648 .33955 .31545 .33831 Mtetra
.66 .709 .884 r
.31545 .33831 .31648 .33955 .31811 .33897 .31709 .33774 Mtetra
.66 .71 .884 r
.31709 .33774 .31811 .33897 .31975 .33839 .31872 .33716 Mtetra
.661 .711 .885 r
.31872 .33716 .31975 .33839 .32138 .33781 .32036 .33658 Mtetra
.32036 .33658 .32138 .33781 .32302 .33723 .32199 .336 Mtetra
.661 .712 .886 r
.32199 .336 .32302 .33723 .32466 .33664 .32363 .33542 Mtetra
.32363 .33542 .32466 .33664 .32629 .33606 .32527 .33484 Mtetra
.32527 .33484 .32629 .33606 .32793 .33548 .32691 .33425 Mtetra
.32691 .33425 .32793 .33548 .32957 .3349 .32855 .33367 Mtetra
.32855 .33367 .32957 .3349 .33121 .33431 .33019 .33309 Mtetra
.33019 .33309 .33121 .33431 .33286 .33373 .33183 .3325 Mtetra
.33183 .3325 .33286 .33373 .3345 .33315 .33348 .33192 Mtetra
.662 .712 .885 r
.33348 .33192 .3345 .33315 .33614 .33257 .33512 .33133 Mtetra
.662 .711 .884 r
.33512 .33133 .33614 .33257 .33779 .33198 .33677 .33074 Mtetra
.663 .711 .884 r
.33677 .33074 .33779 .33198 .33944 .3314 .33842 .33015 Mtetra
.662 .71 .883 r
.33842 .33015 .33944 .3314 .34108 .33082 .34006 .32956 Mtetra
.672 .711 .877 r
.34006 .32956 .34108 .33082 .34273 .33026 .34172 .32891 Mtetra
.676 .699 .863 r
.34172 .32891 .34273 .33026 .34438 .32972 .34337 .32824 Mtetra
.65 .668 .854 r
.34337 .32824 .34438 .32972 .34603 .32917 .34502 .32768 Mtetra
.568 .632 .875 r
.34502 .32768 .34603 .32917 .34768 .32859 .34665 .32749 Mtetra
.305 .58 .938 r
.34665 .32749 .34768 .32859 .34933 .32795 .34825 .32783 Mtetra
.37 0 0 r
.34825 .32783 .34933 .32795 .35099 .32729 .34984 .3284 Mtetra
.476 .005 .056 r
.34984 .3284 .35099 .32729 .35265 .32664 .35145 .3287 Mtetra
.339 0 .135 r
.35145 .3287 .35265 .32664 .35431 .326 .3531 .32818 Mtetra
.284 0 .122 r
.3531 .32818 .35431 .326 .35596 .32537 .35477 .32741 Mtetra
.183 0 .049 r
.35477 .32741 .35596 .32537 .35763 .3246 .35646 .32639 Mtetra
.102 0 0 r
.35646 .32639 .35763 .3246 .35931 .3237 .35814 .3253 Mtetra
.305 0 .046 r
.35814 .3253 .35931 .3237 .36096 .32321 .3598 .32486 Mtetra
.706 .312 .3 r
.3598 .32486 .36096 .32321 .36255 .32408 .36133 .32672 Mtetra
.953 .68 .483 r
.36133 .32672 .36255 .32408 .36387 .33002 .35265 .52743 Mtetra
.544 .313 .516 r
.35265 .52743 .36387 .33002 .35527 .53269 .354 .53494 Mtetra
.683 .306 .326 r
.354 .53494 .35527 .53269 .35684 .53606 .35565 .53684 Mtetra
.243 0 0 r
.35565 .53684 .35684 .53606 .3586 .53586 .35741 .53669 Mtetra
0 0 0 r
.35741 .53669 .3586 .53586 .36039 .53502 .35919 .53603 Mtetra
.35919 .53603 .36039 .53502 .36217 .5343 .36098 .53525 Mtetra
.082 0 0 r
.36098 .53525 .36217 .5343 .36392 .53433 .36276 .53468 Mtetra
.333 .807 .734 r
.36276 .53468 .36392 .53433 .36568 .53431 .36455 .53396 Mtetra
.701 .923 .967 r
.36455 .53396 .36568 .53431 .36744 .53423 .36635 .53306 Mtetra
.753 .764 .862 r
.36635 .53306 .36744 .53423 .3692 .53405 .36816 .5319 Mtetra
.756 .653 .748 r
.36816 .5319 .3692 .53405 .37099 .53336 .37 .53011 Mtetra
.799 .622 .662 r
.37 .53011 .37099 .53336 .37284 .53133 .37194 .52627 Mtetra
.954 .685 .488 r
.37194 .52627 .37284 .53133 .37491 .52443 .38284 .32386 Mtetra
.548 .322 .523 r
.38284 .32386 .37491 .52443 .38572 .32001 .38487 .31546 Mtetra
.721 .54 .644 r
.38487 .31546 .38572 .32001 .38758 .31532 .38664 .3126 Mtetra
.657 .559 .732 r
.38664 .3126 .38758 .31532 .38928 .31434 .38833 .3117 Mtetra
.605 .534 .749 r
.38833 .3117 .38928 .31434 .39095 .31398 .39001 .31126 Mtetra
.587 .52 .747 r
.39001 .31126 .39095 .31398 .39262 .31359 .39167 .31096 Mtetra
.623 .545 .746 r
.39167 .31096 .39262 .31359 .39432 .31248 .39335 .31038 Mtetra
.635 .593 .789 r
.39335 .31038 .39432 .31248 .39602 .31139 .39503 .30981 Mtetra
.655 .66 .843 r
.39503 .30981 .39602 .31139 .39772 .31045 .39672 .30921 Mtetra
.68 .72 .88 r
.39672 .30921 .39772 .31045 .3994 .3098 .3984 .30852 Mtetra
.66 .707 .882 r
.3984 .30852 .3994 .3098 .40109 .30923 .40009 .30792 Mtetra
.599 .681 .898 r
.40009 .30792 .40109 .30923 .40277 .30867 .40177 .30759 Mtetra
.36 .615 .948 r
.40177 .30759 .40277 .30867 .40446 .30806 .40342 .30783 Mtetra
.236 0 0 r
.40342 .30783 .40446 .30806 .40615 .30746 .40507 .30831 Mtetra
.445 0 0 r
.40507 .30831 .40615 .30746 .40784 .30677 .40673 .30859 Mtetra
.167 0 .01 r
.40673 .30859 .40784 .30677 .40954 .30582 .40843 .30762 Mtetra
.273 0 .064 r
.40843 .30762 .40954 .30582 .41123 .30523 .41013 .30697 Mtetra
.591 .179 .231 r
.41013 .30697 .41123 .30523 .41289 .30561 .41177 .30781 Mtetra
.958 .68 .467 r
.41177 .30781 .41289 .30561 .4144 .31005 .40641 .50544 Mtetra
.552 .319 .517 r
.40641 .50544 .4144 .31005 .409 .51402 .40778 .51716 Mtetra
.696 .343 .375 r
.40778 .51716 .409 .51402 .41062 .51891 .40948 .51971 Mtetra
.299 0 0 r
.40948 .51971 .41062 .51891 .41241 .51896 .41127 .51966 Mtetra
0 0 0 r
.41127 .51966 .41241 .51896 .41422 .51821 .41309 .51907 Mtetra
.41309 .51907 .41422 .51821 .41605 .51712 .41491 .51825 Mtetra
.163 0 0 r
.41491 .51825 .41605 .51712 .41787 .51644 .41673 .5177 Mtetra
.18 0 0 r
.41673 .5177 .41787 .51644 .41969 .51582 .41855 .51711 Mtetra
.173 0 0 r
.41855 .51711 .41969 .51582 .4215 .51539 .42037 .51648 Mtetra
.132 0 0 r
.42037 .51648 .4215 .51539 .4233 .51538 .42219 .51589 Mtetra
0 0 0 r
.42219 .51589 .4233 .51538 .42511 .51538 .42401 .51519 Mtetra
.673 .947 .958 r
.42401 .51519 .42511 .51538 .42691 .51525 .42585 .51426 Mtetra
.808 .806 .85 r
.42585 .51426 .42691 .51525 .42873 .5148 .4277 .51271 Mtetra
.761 .664 .754 r
.4277 .51271 .42873 .5148 .43056 .51424 .42956 .51091 Mtetra
.707 .57 .698 r
.42956 .51091 .43056 .51424 .43238 .51363 .43142 .5091 Mtetra
.611 .475 .671 r
.43142 .5091 .43238 .51363 .43421 .51302 .43325 .50827 Mtetra
.583 .451 .667 r
.43325 .50827 .43421 .51302 .43604 .51239 .43507 .50779 Mtetra
.568 .445 .672 r
.43507 .50779 .43604 .51239 .43787 .51181 .43689 .5075 Mtetra
.534 .43 .683 r
.43689 .5075 .43787 .51181 .43969 .51165 .4387 .5076 Mtetra
.589 .474 .69 r
.4387 .5076 .43969 .51165 .44152 .51113 .44053 .50712 Mtetra
.681 .533 .678 r
.44053 .50712 .44152 .51113 .44337 .5098 .44239 .5054 Mtetra
.902 .657 .559 r
.44239 .5054 .44337 .5098 .44531 .50456 .44458 .49037 Mtetra
.95 .673 .478 r
.44458 .49037 .44531 .50456 .45192 .29955 .45106 .29329 Mtetra
.717 .515 .615 r
.45106 .29329 .45192 .29955 .4538 .29216 .45285 .28942 Mtetra
.66 .562 .733 r
.45285 .28942 .4538 .29216 .45555 .29043 .45458 .28848 Mtetra
.607 .595 .814 r
.45458 .28848 .45555 .29043 .45727 .28947 .4563 .28809 Mtetra
.534 .641 .902 r
.4563 .28809 .45727 .28947 .45899 .28891 .45801 .288 Mtetra
.643 .78 .947 r
.45801 .288 .45899 .28891 .46072 .28833 .45973 .28746 Mtetra
.653 .794 .95 r
.45973 .28746 .46072 .28833 .46244 .28785 .46145 .28688 Mtetra
.669 .776 .93 r
.46145 .28688 .46244 .28785 .46416 .2874 .46318 .28624 Mtetra
.714 .753 .883 r
.46318 .28624 .46416 .2874 .46588 .28678 .46491 .28538 Mtetra
.691 .704 .857 r
.46491 .28538 .46588 .28678 .46761 .28612 .46664 .28458 Mtetra
.655 .669 .852 r
.46664 .28458 .46761 .28612 .46934 .28544 .46837 .28397 Mtetra
.588 .652 .88 r
.46837 .28397 .46934 .28544 .47108 .28432 .47009 .28368 Mtetra
.215 .644 .953 r
.47009 .28368 .47108 .28432 .47281 .28352 .47181 .2839 Mtetra
.646 .121 0 r
.47181 .2839 .47281 .28352 .47453 .28335 .47351 .28511 Mtetra
.918 .594 .414 r
.47351 .28511 .47453 .28335 .47621 .28654 .47502 .29873 Mtetra
.951 .665 .461 r
.47502 .29873 .47621 .28654 .47487 .48945 .47372 .49532 Mtetra
.664 .349 .43 r
.47372 .49532 .47487 .48945 .47659 .49751 .47552 .49844 Mtetra
.359 0 0 r
.47552 .49844 .47659 .49751 .47843 .49834 .47737 .49849 Mtetra
.421 .867 .832 r
.47737 .49849 .47843 .49834 .48028 .49818 .47923 .49775 Mtetra
.78 .927 .932 r
.47923 .49775 .48028 .49818 .48214 .49757 .4811 .4965 Mtetra
.73 .79 .9 r
.4811 .4965 .48214 .49757 .48399 .49753 .48296 .49551 Mtetra
.737 .663 .777 r
.48296 .49551 .48399 .49753 .48585 .4971 .48483 .49405 Mtetra
.757 .61 .694 r
.48483 .49405 .48585 .4971 .48772 .49594 .48672 .49156 Mtetra
.896 .653 .563 r
.48672 .49156 .48772 .49594 .48963 .49131 .48872 .47852 Mtetra
.956 .675 .464 r
.48872 .47852 .48963 .49131 .49354 .28699 .49265 .27877 Mtetra
.689 .479 .598 r
.49265 .27877 .49354 .28699 .49538 .27774 .49443 .27475 Mtetra
.672 .556 .716 r
.49443 .27475 .49538 .27774 .49713 .27574 .49618 .27357 Mtetra
.617 .581 .791 r
.49618 .27357 .49713 .27574 .49888 .27473 .49792 .2731 Mtetra
.562 .616 .864 r
.49792 .2731 .49888 .27473 .50063 .27414 .49967 .27293 Mtetra
.742 .753 .861 r
.49967 .27293 .50063 .27414 .50238 .2731 .50142 .27186 Mtetra
.71 .74 .875 r
.50142 .27186 .50238 .2731 .50413 .27235 .50317 .27098 Mtetra
.566 .662 .902 r
.50317 .27098 .50413 .27235 .50588 .27222 .50492 .27077 Mtetra
.765 .34 0 r
.50492 .27077 .50588 .27222 .50762 .27498 .50665 .27429 Mtetra
.969 .682 .431 r
.50665 .27429 .50762 .27498 .50836 .47669 .5073 .48098 Mtetra
.789 .455 .423 r
.5073 .48098 .50836 .47669 .51018 .4865 .50914 .48741 Mtetra
.477 0 0 r
.50914 .48741 .51018 .4865 .51205 .48763 .51102 .48786 Mtetra
.372 .836 .78 r
.51102 .48786 .51205 .48763 .51393 .4875 .5129 .48711 Mtetra
.769 .938 .938 r
.5129 .48711 .51393 .4875 .51581 .48687 .51479 .48589 Mtetra
.506 .731 .974 r
.51479 .48589 .51581 .48687 .5177 .48673 .51667 .48573 Mtetra
.55 .746 .968 r
.51667 .48573 .5177 .48673 .51958 .4863 .51855 .48545 Mtetra
.736 .836 .926 r
.51855 .48545 .51958 .4863 .52147 .48518 .52044 .48443 Mtetra
.954 .801 .654 r
.52044 .48443 .52147 .48518 .52335 .48094 .52233 .47941 Mtetra
.97 .688 .439 r
.52233 .47941 .52335 .48094 .52522 .27783 .52426 .27116 Mtetra
.787 .559 .591 r
.52426 .27116 .52522 .27783 .52698 .26688 .52603 .26394 Mtetra
.713 .583 .708 r
.52603 .26394 .52698 .26688 .52875 .26463 .52779 .26228 Mtetra
.615 .566 .775 r
.52779 .26228 .52875 .26463 .53051 .26361 .52956 .26179 Mtetra
.536 .578 .844 r
.52956 .26179 .53051 .26361 .53228 .26302 .53133 .26175 Mtetra
.642 .711 .898 r
.53133 .26175 .53228 .26302 .53405 .26238 .5331 .26121 Mtetra
.673 .744 .904 r
.5331 .26121 .53405 .26238 .53582 .26175 .53487 .26054 Mtetra
.647 .727 .907 r
.53487 .26054 .53582 .26175 .53759 .26115 .53664 .25998 Mtetra
.609 .72 .924 r
.53664 .25998 .53759 .26115 .53936 .26006 .53842 .25958 Mtetra
.309 .737 .972 r
.53842 .25958 .53936 .26006 .54114 .25912 .54019 .25954 Mtetra
.518 0 0 r
.54019 .25954 .54114 .25912 .54291 .2588 .54198 .26028 Mtetra
.857 .482 .336 r
.54198 .26028 .54291 .2588 .54471 .26148 .54379 .26578 Mtetra
.966 .675 .425 r
.54379 .26578 .54471 .26148 .54793 .46648 .54695 .47003 Mtetra
.752 .401 .388 r
.54695 .47003 .54793 .46648 .5499 .47512 .54889 .47431 Mtetra
0 .325 .761 r
.54889 .47431 .5499 .47512 .55182 .47653 .55081 .47531 Mtetra
.568 .71 .938 r
.55081 .47531 .55182 .47653 .55373 .47625 .55272 .47502 Mtetra
.765 .776 .862 r
.55272 .47502 .55373 .47625 .55563 .47487 .55462 .47373 Mtetra
.928 .783 .679 r
.55462 .47373 .55563 .47487 .55751 .4705 .5565 .46941 Mtetra
.973 .688 .426 r
.5565 .46941 .55751 .4705 .55726 .2642 .55632 .26312 Mtetra
.965 .742 .552 r
.55632 .26312 .55726 .2642 .55895 .25465 .55801 .25349 Mtetra
.853 .787 .786 r
.55801 .25349 .55895 .25465 .56072 .25254 .55978 .25137 Mtetra
.668 .744 .907 r
.55978 .25137 .56072 .25254 .56251 .25189 .56157 .25072 Mtetra
.544 .691 .936 r
.56157 .25072 .56251 .25189 .5643 .25172 .56336 .25053 Mtetra
.64 .73 .913 r
.56336 .25053 .5643 .25172 .5661 .25127 .56516 .24999 Mtetra
.679 .728 .887 r
.56516 .24999 .5661 .25127 .56789 .25061 .56695 .24927 Mtetra
.653 .708 .887 r
.56695 .24927 .56789 .25061 .56968 .24992 .56874 .24868 Mtetra
.619 .71 .911 r
.56874 .24868 .56968 .24992 .57146 .24883 .57054 .24823 Mtetra
.394 .759 .993 r
.57054 .24823 .57146 .24883 .57325 .24782 .57234 .24814 Mtetra
.462 0 0 r
.57234 .24814 .57325 .24782 .57505 .24739 .57416 .24876 Mtetra
.839 .447 .304 r
.57416 .24876 .57505 .24739 .5769 .2496 .57604 .25333 Mtetra
.969 .674 .412 r
.57604 .25333 .5769 .2496 .58227 .45301 .58139 .45839 Mtetra
.723 .394 .421 r
.58139 .45839 .58227 .45301 .5844 .46386 .58341 .46315 Mtetra
0 .217 .651 r
.58341 .46315 .5844 .46386 .58637 .46559 .58537 .46436 Mtetra
.543 .698 .941 r
.58537 .46436 .58637 .46559 .58831 .46541 .58731 .46416 Mtetra
.75 .771 .87 r
.58731 .46416 .58831 .46541 .59023 .46414 .58924 .46296 Mtetra
.92 .789 .699 r
.58924 .46296 .59023 .46414 .5921 .46028 .59111 .45914 Mtetra
.975 .687 .413 r
.59111 .45914 .5921 .46028 .58977 .2571 .58883 .25582 Mtetra
.969 .725 .513 r
.58883 .25582 .58977 .2571 .5913 .24361 .59038 .24242 Mtetra
.876 .785 .758 r
.59038 .24242 .5913 .24361 .59307 .24108 .59214 .23988 Mtetra
.689 .749 .898 r
.59214 .23988 .59307 .24108 .59488 .24031 .59395 .23912 Mtetra
.569 .701 .931 r
.59395 .23912 .59488 .24031 .59669 .24005 .59577 .23885 Mtetra
.684 .746 .899 r
.59577 .23885 .59669 .24005 .5985 .23931 .59758 .23811 Mtetra
.725 .76 .88 r
.59758 .23811 .5985 .23931 .60031 .23835 .59938 .23714 Mtetra
.609 .717 .921 r
.59938 .23714 .60031 .23835 .60212 .23794 .6012 .23673 Mtetra
0 .055 .594 r
.6012 .23673 .60212 .23794 .60401 .23995 .60308 .23865 Mtetra
.975 .678 .39 r
.60308 .23865 .60401 .23995 .61121 .44293 .61018 .43995 Mtetra
.929 .599 .147 r
.61018 .43995 .61121 .44293 .61348 .45454 .61249 .45314 Mtetra
0 .208 .73 r
.61249 .45314 .61348 .45454 .61549 .45611 .6145 .45479 Mtetra
.615 .716 .917 r
.6145 .45479 .61549 .45611 .61744 .45558 .61646 .45432 Mtetra
.727 .767 .885 r
.61646 .45432 .61744 .45558 .61938 .45447 .6184 .45328 Mtetra
.639 .749 .928 r
.6184 .45328 .61938 .45447 .62134 .45384 .62036 .45269 Mtetra
.545 .718 .953 r
.62036 .45269 .62134 .45384 .6233 .45358 .62233 .45245 Mtetra
.695 .78 .917 r
.62233 .45245 .6233 .45358 .62525 .45273 .62428 .45161 Mtetra
.911 .804 .728 r
.62428 .45161 .62525 .45273 .62713 .44944 .62615 .44832 Mtetra
.976 .685 .399 r
.62615 .44832 .62713 .44944 .62278 .25078 .62188 .25028 Mtetra
.984 .727 .459 r
.62188 .25028 .62278 .25078 .62404 .23221 .62312 .23102 Mtetra
.894 .79 .738 r
.62312 .23102 .62404 .23221 .62579 .22935 .62488 .22816 Mtetra
.702 .757 .894 r
.62488 .22816 .62579 .22935 .62762 .22851 .62671 .22732 Mtetra
.585 .71 .929 r
.62671 .22732 .62762 .22851 .62946 .22818 .62855 .22699 Mtetra
.665 .743 .908 r
.62855 .22699 .62946 .22818 .63129 .22752 .63038 .22633 Mtetra
.733 .766 .879 r
.63038 .22633 .63129 .22752 .63311 .22651 .6322 .22531 Mtetra
.636 .731 .917 r
.6322 .22531 .63311 .22651 .63495 .22598 .63404 .22478 Mtetra
0 .279 .778 r
.63404 .22478 .63495 .22598 .63686 .2273 .63595 .2261 Mtetra
.939 .576 .188 r
.63595 .2261 .63686 .2273 .63909 .23727 .63818 .23611 Mtetra
.975 .675 .374 r
.63818 .23611 .63909 .23727 .64872 .44182 .64776 .44068 Mtetra
0 0 .511 r
.64776 .44068 .64872 .44182 .65081 .44409 .64984 .44294 Mtetra
.628 .757 .94 r
.64984 .44294 .65081 .44409 .65279 .44354 .65182 .4424 Mtetra
.767 .802 .881 r
.65182 .4424 .65279 .44354 .65474 .44225 .65377 .44111 Mtetra
.779 .805 .874 r
.65377 .44111 .65474 .44225 .65669 .44087 .65573 .43974 Mtetra
.722 .793 .908 r
.65573 .43974 .65669 .44087 .65865 .43986 .65769 .43875 Mtetra
.709 .792 .916 r
.65769 .43875 .65865 .43986 .66062 .43892 .65966 .43782 Mtetra
.655 .777 .938 r
.65966 .43782 .66062 .43892 .6626 .43825 .66164 .43715 Mtetra
.577 .745 .957 r
.66164 .43715 .6626 .43825 .66459 .4379 .66364 .43678 Mtetra
.551 .729 .958 r
.66364 .43678 .66459 .4379 .6666 .43765 .66564 .43651 Mtetra
.455 .678 .96 r
.66564 .43651 .6666 .43765 .66861 .43768 .66766 .43653 Mtetra
.419 .655 .957 r
.66766 .43653 .66861 .43768 .67063 .43781 .66968 .43665 Mtetra
.63 .755 .937 r
.66968 .43665 .67063 .43781 .67263 .43726 .67167 .43609 Mtetra
.89 .811 .764 r
.67167 .43609 .67263 .43726 .67452 .43453 .67357 .43336 Mtetra
.981 .721 .463 r
.67357 .43336 .67452 .43453 .67569 .41623 .67472 .41462 Mtetra
.977 .681 .38 r
.67472 .41462 .67569 .41623 .6683 .21687 .6674 .21564 Mtetra
.91 .788 .714 r
.6674 .21564 .6683 .21687 .67003 .21361 .66914 .21239 Mtetra
.705 .756 .891 r
.66914 .21239 .67003 .21361 .67188 .21273 .67099 .21152 Mtetra
.581 .707 .929 r
.67099 .21152 .67188 .21273 .67376 .2124 .67287 .21119 Mtetra
.607 .72 .925 r
.67287 .21119 .67376 .2124 .67563 .21193 .67474 .21077 Mtetra
.719 .773 .895 r
.67474 .21077 .67563 .21193 .67747 .21092 .67659 .20984 Mtetra
.641 .761 .935 r
.67659 .20984 .67747 .21092 .67934 .21038 .67846 .20927 Mtetra
.22 .529 .921 r
.67846 .20927 .67934 .21038 .68129 .21143 .68039 .20986 Mtetra
.693 .29 0 r
.68039 .20986 .68129 .21143 .68372 .22151 .68251 .21405 Mtetra
.977 .676 .334 r
.68251 .21405 .68372 .22151 .69649 .42709 .69526 .42051 Mtetra
.111 .103 .567 r
.69526 .42051 .69649 .42709 .69867 .42978 .69758 .42571 Mtetra
.453 .392 .7 r
.69758 .42571 .69867 .42978 .7007 .42944 .69967 .42656 Mtetra
.536 .502 .765 r
.69967 .42656 .7007 .42944 .70269 .42843 .70171 .42659 Mtetra
.559 .612 .862 r
.70171 .42659 .70269 .42843 .70469 .42751 .70375 .42641 Mtetra
.492 .708 .967 r
.70375 .42641 .70469 .42751 .70673 .42731 .7058 .4263 Mtetra
.671 .806 .947 r
.7058 .4263 .70673 .42731 .70874 .4266 .70781 .42554 Mtetra
.881 .835 .796 r
.70781 .42554 .70874 .4266 .71066 .42429 .70973 .42315 Mtetra
.98 .754 .525 r
.70973 .42315 .71066 .42429 .71215 .4144 .71122 .41336 Mtetra
.977 .678 .362 r
.71122 .41336 .71215 .4144 .702 .20591 .70113 .20471 Mtetra
.937 .791 .673 r
.70113 .20471 .702 .20591 .70369 .20192 .70281 .20069 Mtetra
.73 .768 .883 r
.70281 .20069 .70369 .20192 .70555 .2009 .70467 .19967 Mtetra
.604 .717 .924 r
.70467 .19967 .70555 .2009 .70745 .20049 .70657 .19926 Mtetra
.603 .716 .924 r
.70657 .19926 .70745 .20049 .70934 .20008 .70847 .19884 Mtetra
.742 .77 .876 r
.70847 .19884 .70934 .20008 .7112 .19899 .71033 .19775 Mtetra
.659 .739 .909 r
.71033 .19775 .7112 .19899 .71309 .19834 .71222 .1971 Mtetra
.244 .515 .909 r
.71222 .1971 .71309 .19834 .71506 .19899 .71419 .19774 Mtetra
.877 .483 .023 r
.71419 .19774 .71506 .19899 .71745 .20613 .71657 .20482 Mtetra
.975 .667 .334 r
.71657 .20482 .71745 .20613 .73278 .41471 .73185 .41349 Mtetra
.648 .198 0 r
.73185 .41349 .73278 .41471 .73508 .41823 .73415 .41699 Mtetra
.426 .644 .949 r
.73415 .41699 .73508 .41823 .73717 .41846 .73624 .41714 Mtetra
.695 .756 .899 r
.73624 .41714 .73717 .41846 .7392 .41756 .73827 .41625 Mtetra
.845 .797 .805 r
.73827 .41625 .7392 .41756 .74112 .4151 .74021 .41412 Mtetra
.97 .809 .627 r
.74021 .41412 .74112 .4151 .7426 .40629 .74194 .40887 Mtetra
.978 .678 .337 r
.74194 .40887 .7426 .40629 .73038 .19618 .72994 .20118 Mtetra
0 0 .11 r
.72994 .20118 .73038 .19618 .73203 .19178 .73135 .19331 Mtetra
0 0 0 r
.73135 .19331 .73203 .19178 .7339 .19077 .73315 .19119 Mtetra
.467 .854 .644 r
.73315 .19119 .7339 .19077 .73583 .19041 .73501 .18989 Mtetra
.69 .915 .971 r
.73501 .18989 .73583 .19041 .73777 .19028 .7369 .18899 Mtetra
.676 .739 .898 r
.7369 .18899 .73777 .19028 .73967 .18966 .7388 .18825 Mtetra
.647 .704 .888 r
.7388 .18825 .73967 .18966 .74158 .18902 .74071 .18764 Mtetra
.659 .716 .89 r
.74071 .18764 .74158 .18902 .74348 .18826 .74262 .18698 Mtetra
.752 .769 .867 r
.74262 .18698 .74348 .18826 .74535 .18707 .74449 .18579 Mtetra
.68 .744 .899 r
.74449 .18579 .74535 .18707 .74725 .1863 .7464 .18503 Mtetra
.389 .599 .93 r
.7464 .18503 .74725 .1863 .74924 .18659 .74838 .18533 Mtetra
.821 .413 0 r
.74838 .18533 .74924 .18659 .75165 .19253 .75078 .19122 Mtetra
.973 .662 .315 r
.75078 .19122 .75165 .19253 .76953 .40235 .76862 .40111 Mtetra
.691 .251 0 r
.76862 .40111 .76953 .40235 .77195 .40645 .77104 .40521 Mtetra
.389 .625 .947 r
.77104 .40521 .77195 .40645 .77409 .40679 .77318 .40546 Mtetra
.678 .751 .906 r
.77318 .40546 .77409 .40679 .77615 .40599 .77523 .40466 Mtetra
.829 .797 .821 r
.77523 .40466 .77615 .40599 .77809 .40382 .7772 .40272 Mtetra
.964 .81 .642 r
.7772 .40272 .77809 .40382 .7796 .39615 .77893 .39785 Mtetra
.976 .673 .321 r
.77893 .39785 .7796 .39615 .76485 .18467 .76461 .19111 Mtetra
0 0 .176 r
.76461 .19111 .76485 .18467 .76642 .17963 .7658 .18127 Mtetra
0 0 0 r
.7658 .18127 .76642 .17963 .76831 .17851 .7676 .17902 Mtetra
.424 .812 .577 r
.7676 .17902 .76831 .17851 .77025 .17808 .76947 .17765 Mtetra
.681 .934 .967 r
.76947 .17765 .77025 .17808 .77222 .17798 .77138 .17671 Mtetra
.682 .749 .902 r
.77138 .17671 .77222 .17798 .77416 .17735 .7733 .17594 Mtetra
.65 .709 .89 r
.7733 .17594 .77416 .17735 .77609 .17669 .77523 .17531 Mtetra
.645 .712 .896 r
.77523 .17531 .77609 .17669 .77801 .17596 .77717 .1747 Mtetra
.757 .778 .87 r
.77717 .1747 .77801 .17596 .77989 .17469 .77906 .17349 Mtetra
.691 .766 .909 r
.77906 .17349 .77989 .17469 .78181 .17381 .78098 .17267 Mtetra
.472 .674 .953 r
.78098 .17267 .78181 .17381 .78379 .17375 .78297 .17267 Mtetra
.778 .35 0 r
.78297 .17267 .78379 .17375 .7862 .1785 .7854 .17764 Mtetra
.971 .656 .296 r
.7854 .17764 .7862 .1785 .80671 .38949 .80585 .38849 Mtetra
.77 .326 0 r
.80585 .38849 .80671 .38949 .8093 .39455 .80842 .39335 Mtetra
.292 .575 .937 r
.80842 .39335 .8093 .39455 .8115 .39506 .81061 .39385 Mtetra
.646 .762 .934 r
.81061 .39385 .8115 .39506 .81359 .39441 .8127 .39319 Mtetra
.827 .82 .842 r
.8127 .39319 .81359 .39441 .81558 .39259 .81469 .39137 Mtetra
.908 .736 .657 r
.14798 .60036 .14915 .60131 .15137 .59555 .15019 .5946 Mtetra
.936 .686 .535 r
.15019 .5946 .15137 .59555 .1749 .39384 .17381 .39283 Mtetra
.907 .727 .647 r
.17381 .39283 .1749 .39384 .17704 .38788 .17595 .38687 Mtetra
.773 .759 .841 r
.17595 .38687 .17704 .38788 .17866 .38668 .17757 .38566 Mtetra
.64 .736 .918 r
.17757 .38566 .17866 .38668 .1802 .38622 .17911 .3852 Mtetra
.511 .692 .95 r
.17911 .3852 .1802 .38622 .1817 .38613 .18061 .38511 Mtetra
.75 .758 .86 r
.18061 .38511 .1817 .38613 .1833 .3851 .18221 .38409 Mtetra
.698 .751 .893 r
.18221 .38409 .1833 .3851 .18487 .3844 .18378 .38339 Mtetra
.484 .683 .954 r
.18378 .38339 .18487 .3844 .18637 .38436 .18528 .38335 Mtetra
.926 .545 .251 r
.18528 .38335 .18637 .38436 .18745 .38836 .18636 .38739 Mtetra
.939 .683 .523 r
.18636 .38739 .18745 .38836 .16796 .589 .16678 .58812 Mtetra
.932 .581 .335 r
.16678 .58812 .16796 .589 .16897 .59458 .1678 .59365 Mtetra
.247 .601 .952 r
.1678 .59365 .16897 .59458 .17054 .59489 .16937 .59395 Mtetra
.674 .774 .925 r
.16937 .59395 .17054 .59489 .1722 .59426 .17103 .59332 Mtetra
.753 .784 .878 r
.17103 .59332 .1722 .59426 .17392 .59321 .17275 .59226 Mtetra
.479 .709 .971 r
.17275 .59226 .17392 .59321 .17553 .59314 .17436 .59219 Mtetra
.586 .747 .954 r
.17436 .59219 .17553 .59314 .17716 .59282 .176 .59186 Mtetra
.751 .781 .878 r
.176 .59186 .17716 .59282 .17888 .59177 .17771 .59081 Mtetra
.907 .743 .666 r
.17771 .59081 .17888 .59177 .18101 .58653 .17985 .58557 Mtetra
.939 .687 .529 r
.17985 .58557 .18101 .58653 .20289 .38462 .20181 .38361 Mtetra
.913 .728 .638 r
.20181 .38361 .20289 .38462 .20505 .37818 .20397 .37716 Mtetra
.791 .762 .826 r
.20397 .37716 .20505 .37818 .2067 .37679 .20562 .37577 Mtetra
.624 .732 .924 r
.20562 .37577 .2067 .37679 .20825 .37638 .20717 .37536 Mtetra
.462 .673 .955 r
.20717 .37536 .20825 .37638 .20976 .37638 .20868 .37537 Mtetra
.619 .734 .929 r
.20868 .37537 .20976 .37638 .21132 .37597 .21024 .37498 Mtetra
.649 .747 .921 r
.21024 .37498 .21132 .37597 .21288 .37544 .2118 .37448 Mtetra
.658 .754 .921 r
.2118 .37448 .21288 .37544 .21445 .37489 .21337 .37395 Mtetra
.722 .77 .891 r
.21337 .37395 .21445 .37489 .21607 .37393 .21497 .37312 Mtetra
.708 .797 .92 r
.21497 .37312 .21607 .37393 .21766 .37314 .21656 .37238 Mtetra
.62 .789 .963 r
.21656 .37238 .21766 .37314 .21921 .37289 .21812 .37194 Mtetra
.073 .478 .892 r
.21812 .37194 .21921 .37289 .22052 .37505 .21959 .37249 Mtetra
0 .135 .659 r
.21959 .37249 .22052 .37505 .22035 .39293 .22095 .37427 Mtetra
.351 .186 .512 r
.22095 .37427 .22035 .39293 .20423 .58027 .22192 .38013 Mtetra
0 0 .154 r
.22192 .38013 .20423 .58027 .20568 .58222 .20504 .57577 Mtetra
.03 .016 .504 r
.20504 .57577 .20568 .58222 .20726 .58271 .20627 .57997 Mtetra
.055 .189 .687 r
.20627 .57997 .20726 .58271 .20889 .58265 .20774 .5817 Mtetra
.398 .674 .972 r
.20774 .5817 .20889 .58265 .21056 .58229 .20936 .58178 Mtetra
.614 .859 .99 r
.20936 .58178 .21056 .58229 .21224 .58174 .21104 .58125 Mtetra
.692 .877 .967 r
.21104 .58125 .21224 .58174 .21393 .58111 .21275 .58048 Mtetra
.597 .827 .987 r
.21275 .58048 .21393 .58111 .21561 .58068 .21442 .58003 Mtetra
.556 .812 .993 r
.21442 .58003 .21561 .58068 .21728 .5803 .21609 .57968 Mtetra
.572 .823 .992 r
.21609 .57968 .21728 .5803 .21895 .57989 .21777 .57928 Mtetra
.579 .827 .992 r
.21777 .57928 .21895 .57989 .22061 .57964 .21944 .57887 Mtetra
.655 .808 .957 r
.21944 .57887 .22061 .57964 .22229 .5792 .22114 .57828 Mtetra
.728 .791 .902 r
.22114 .57828 .22229 .5792 .22402 .57823 .22286 .57737 Mtetra
.848 .797 .801 r
.22286 .57737 .22402 .57823 .22595 .57499 .22468 .57533 Mtetra
.954 .903 .734 r
.22468 .57533 .22595 .57499 .22846 .56508 .22662 .57199 Mtetra
0 0 .124 r
.22662 .57199 .22846 .56508 .24737 .36663 .22876 .56634 Mtetra
.522 .295 .512 r
.22876 .56634 .24737 .36663 .24912 .36421 .23069 .56299 Mtetra
.53 .302 .513 r
.23069 .56299 .24912 .36421 .25071 .36365 .2323 .56334 Mtetra
.528 .3 .513 r
.2323 .56334 .25071 .36365 .25227 .36349 .23401 .56261 Mtetra
0 0 .169 r
.23401 .56261 .25227 .36349 .25393 .3622 .25225 .36838 Mtetra
0 0 0 r
.25225 .36838 .25393 .3622 .25562 .36055 .2544 .36141 Mtetra
.953 .952 .699 r
.2544 .36141 .25562 .36055 .25729 .35915 .25622 .35823 Mtetra
.784 .786 .854 r
.25622 .35823 .25729 .35915 .25891 .35835 .25787 .35698 Mtetra
.627 .671 .873 r
.25787 .35698 .25891 .35835 .2605 .35791 .25946 .35656 Mtetra
.55 .645 .897 r
.25946 .35656 .2605 .35791 .26208 .35757 .26102 .35642 Mtetra
.599 .702 .916 r
.26102 .35642 .26208 .35757 .26367 .35713 .26261 .3561 Mtetra
.646 .741 .919 r
.26261 .3561 .26367 .35713 .26527 .35659 .2642 .35561 Mtetra
.663 .755 .918 r
.2642 .35561 .26527 .35659 .26687 .356 .26581 .35504 Mtetra
.692 .766 .908 r
.26581 .35504 .26687 .356 .26848 .35533 .26742 .35435 Mtetra
.707 .766 .898 r
.26742 .35435 .26848 .35533 .2701 .3546 .26904 .35358 Mtetra
.706 .758 .893 r
.26904 .35358 .2701 .3546 .27172 .35388 .27066 .35281 Mtetra
.719 .752 .878 r
.27066 .35281 .27172 .35388 .27335 .35297 .27229 .35197 Mtetra
.704 .763 .897 r
.27229 .35197 .27335 .35297 .27498 .35215 .27392 .35121 Mtetra
.631 .758 .938 r
.27392 .35121 .27498 .35215 .27657 .35179 .27552 .35076 Mtetra
.271 .575 .94 r
.27552 .35076 .27657 .35179 .27803 .35317 .27705 .35111 Mtetra
0 .183 .708 r
.27705 .35111 .27803 .35317 .27912 .35934 .2785 .35264 Mtetra
.073 .04 .511 r
.2785 .35264 .27912 .35934 .26533 .55945 .27974 .35691 Mtetra
0 0 .197 r
.27974 .35691 .26533 .55945 .26677 .56261 .26617 .55458 Mtetra
.025 0 .479 r
.26617 .55458 .26677 .56261 .26839 .56333 .26743 .56005 Mtetra
.081 .167 .655 r
.26743 .56005 .26839 .56333 .27006 .5634 .26895 .56212 Mtetra
.247 .522 .913 r
.26895 .56212 .27006 .5634 .27175 .5632 .27059 .56263 Mtetra
.496 .81 1 r
.27059 .56263 .27175 .5632 .27346 .56284 .27229 .56236 Mtetra
.626 .872 .988 r
.27229 .56236 .27346 .56284 .27518 .56232 .27402 .56176 Mtetra
.618 .853 .988 r
.27402 .56176 .27518 .56232 .27689 .56196 .27574 .56121 Mtetra
.641 .816 .967 r
.27574 .56121 .27689 .56196 .27861 .56156 .27747 .56065 Mtetra
.717 .797 .914 r
.27747 .56065 .27861 .56156 .28035 .56069 .27922 .55979 Mtetra
.814 .803 .841 r
.27922 .55979 .28035 .56069 .28222 .55818 .28102 .5582 Mtetra
.93 .911 .779 r
.28102 .5582 .28222 .55818 .28438 .55155 .2829 .55551 Mtetra
0 0 0 r
.2829 .55551 .28438 .55155 .30037 .3495 .28494 .55061 Mtetra
0 0 .196 r
.28494 .55061 .30037 .3495 .30229 .34484 .30065 .35217 Mtetra
0 0 .024 r
.30065 .35217 .30229 .34484 .304 .343 .30279 .34429 Mtetra
.895 .958 .62 r
.30279 .34429 .304 .343 .30567 .34184 .3046 .34113 Mtetra
.83 .829 .847 r
.3046 .34113 .30567 .34184 .30731 .34103 .3063 .33958 Mtetra
.675 .68 .847 r
.3063 .33958 .30731 .34103 .30894 .34042 .30793 .3389 Mtetra
.617 .647 .857 r
.30793 .3389 .30894 .34042 .31056 .33995 .30955 .33851 Mtetra
.626 .663 .866 r
.30955 .33851 .31056 .33995 .31219 .33945 .31117 .33808 Mtetra
.655 .685 .866 r
.31117 .33808 .31219 .33945 .31382 .33888 .3128 .33751 Mtetra
.655 .686 .867 r
.3128 .33751 .31382 .33888 .31545 .33831 .31443 .33695 Mtetra
.656 .687 .868 r
.31443 .33695 .31545 .33831 .31709 .33774 .31607 .33638 Mtetra
.657 .689 .868 r
.31607 .33638 .31709 .33774 .31872 .33716 .3177 .33581 Mtetra
.658 .689 .868 r
.3177 .33581 .31872 .33716 .32036 .33658 .31934 .33523 Mtetra
.658 .69 .868 r
.31934 .33523 .32036 .33658 .32199 .336 .32097 .33465 Mtetra
.32097 .33465 .32199 .336 .32363 .33542 .32261 .33407 Mtetra
.659 .69 .869 r
.32261 .33407 .32363 .33542 .32527 .33484 .32425 .33349 Mtetra
.659 .691 .869 r
.32425 .33349 .32527 .33484 .32691 .33425 .32589 .3329 Mtetra
.32589 .3329 .32691 .33425 .32855 .33367 .32753 .33232 Mtetra
.32753 .33232 .32855 .33367 .33019 .33309 .32917 .33173 Mtetra
.659 .691 .868 r
.32917 .33173 .33019 .33309 .33183 .3325 .33082 .33115 Mtetra
.33082 .33115 .33183 .3325 .33348 .33192 .33246 .33056 Mtetra
.659 .69 .868 r
.33246 .33056 .33348 .33192 .33512 .33133 .33411 .32997 Mtetra
.661 .69 .867 r
.33411 .32997 .33512 .33133 .33677 .33074 .33575 .32938 Mtetra
.661 .69 .866 r
.33575 .32938 .33677 .33074 .33842 .33015 .3374 .32878 Mtetra
.661 .688 .865 r
.3374 .32878 .33842 .33015 .34006 .32956 .33905 .32818 Mtetra
.681 .694 .856 r
.33905 .32818 .34006 .32956 .34172 .32891 .34071 .32747 Mtetra
.689 .688 .843 r
.34071 .32747 .34172 .32891 .34337 .32824 .34237 .32669 Mtetra
.637 .654 .85 r
.34237 .32669 .34337 .32824 .34502 .32768 .34402 .3262 Mtetra
.366 .532 .888 r
.34402 .3262 .34502 .32768 .34665 .32749 .34561 .3266 Mtetra
.777 .29 0 r
.34561 .3266 .34665 .32749 .34825 .32783 .3471 .32891 Mtetra
.89 .554 .405 r
.3471 .32891 .34825 .32783 .34984 .3284 .34832 .33618 Mtetra
.944 .672 .491 r
.34832 .33618 .34984 .3284 .35145 .3287 .33919 .53035 Mtetra
.53 .302 .513 r
.33919 .53035 .35145 .3287 .3531 .32818 .3409 .5308 Mtetra
.526 .299 .512 r
.3409 .5308 .3531 .32818 .35477 .32741 .34272 .52925 Mtetra
.524 .297 .512 r
.34272 .52925 .35477 .32741 .35646 .32639 .3446 .52649 Mtetra
.524 .296 .512 r
.3446 .52649 .35646 .32639 .35814 .3253 .34648 .52368 Mtetra
.529 .301 .513 r
.34648 .52368 .35814 .3253 .3598 .32486 .34822 .5237 Mtetra
.539 .309 .515 r
.34822 .5237 .3598 .32486 .36133 .32672 .3497 .52853 Mtetra
.537 .308 .515 r
.3497 .52853 .36133 .32672 .35265 .52743 .35122 .53287 Mtetra
.635 .323 .425 r
.35122 .53287 .35265 .52743 .354 .53494 .35285 .53505 Mtetra
.537 0 0 r
.35285 .53505 .354 .53494 .35565 .53684 .35455 .53591 Mtetra
.521 .74 .974 r
.35455 .53591 .35565 .53684 .35741 .53669 .35631 .53571 Mtetra
.631 .77 .947 r
.35631 .53571 .35741 .53669 .35919 .53603 .35809 .5352 Mtetra
.644 .807 .961 r
.35809 .5352 .35919 .53603 .36098 .53525 .35987 .53462 Mtetra
.59 .836 .991 r
.35987 .53462 .36098 .53525 .36276 .53468 .36165 .53414 Mtetra
.687 .88 .97 r
.36165 .53414 .36276 .53468 .36455 .53396 .36344 .53335 Mtetra
.824 .871 .88 r
.36344 .53335 .36455 .53396 .36635 .53306 .36527 .53185 Mtetra
.877 .761 .73 r
.36527 .53185 .36635 .53306 .36816 .5319 .36717 .52874 Mtetra
.855 .652 .627 r
.36717 .52874 .36816 .5319 .37 .53011 .36922 .52243 Mtetra
.951 .682 .491 r
.36922 .52243 .37 .53011 .37194 .52627 .38022 .3216 Mtetra
.542 .317 .522 r
.38022 .3216 .37194 .52627 .38284 .32386 .38213 .31587 Mtetra
.656 .458 .604 r
.38213 .31587 .38284 .32386 .38487 .31546 .38391 .31308 Mtetra
.735 .62 .73 r
.38391 .31308 .38487 .31546 .38664 .3126 .38563 .31143 Mtetra
.7 .739 .882 r
.38563 .31143 .38664 .3126 .38833 .3117 .38732 .31065 Mtetra
.639 .744 .925 r
.38732 .31065 .38833 .3117 .39001 .31126 .38899 .31015 Mtetra
.622 .726 .921 r
.38899 .31015 .39001 .31126 .39167 .31096 .39067 .30972 Mtetra
.664 .716 .887 r
.39067 .30972 .39167 .31096 .39335 .31038 .39235 .30911 Mtetra
.663 .71 .883 r
.39235 .30911 .39335 .31038 .39503 .30981 .39403 .3085 Mtetra
.674 .708 .874 r
.39403 .3085 .39503 .30981 .39672 .30921 .39572 .30784 Mtetra
.699 .706 .854 r
.39572 .30784 .39672 .30921 .3984 .30852 .39741 .30701 Mtetra
.653 .67 .854 r
.39741 .30701 .3984 .30852 .40009 .30792 .3991 .30643 Mtetra
.495 .601 .888 r
.3991 .30643 .40009 .30792 .40177 .30759 .40076 .30649 Mtetra
.569 .083 0 r
.40076 .30649 .40177 .30759 .40342 .30783 .40235 .30835 Mtetra
.881 .503 .32 r
.40235 .30835 .40342 .30783 .40507 .30831 .40383 .31321 Mtetra
.954 .676 .473 r
.40383 .31321 .40507 .30831 .40673 .30859 .39802 .5096 Mtetra
.529 .301 .513 r
.39802 .5096 .40673 .30859 .40843 .30762 .3998 .50973 Mtetra
.526 .299 .513 r
.3998 .50973 .40843 .30762 .41013 .30697 .40163 .50833 Mtetra
.532 .304 .514 r
.40163 .50833 .41013 .30697 .41177 .30781 .40335 .51006 Mtetra
.539 .309 .515 r
.40335 .51006 .41177 .30781 .40641 .50544 .40495 .51521 Mtetra
.605 .322 .461 r
.40495 .51521 .40641 .50544 .40778 .51716 .40665 .51767 Mtetra
.627 .112 .002 r
.40665 .51767 .40778 .51716 .40948 .51971 .4084 .51879 Mtetra
.495 .737 .98 r
.4084 .51879 .40948 .51971 .41127 .51966 .4102 .51865 Mtetra
.618 .761 .948 r
.4102 .51865 .41127 .51966 .41309 .51907 .41201 .51817 Mtetra
.653 .799 .953 r
.41201 .51817 .41309 .51907 .41491 .51825 .41383 .51756 Mtetra
.608 .83 .985 r
.41383 .51756 .41491 .51825 .41673 .5177 .41564 .51704 Mtetra
.626 .842 .983 r
.41564 .51704 .41673 .5177 .41855 .51711 .41746 .51646 Mtetra
.634 .848 .982 r
.41746 .51646 .41855 .51711 .42037 .51648 .41928 .51585 Mtetra
.587 .838 .992 r
.41928 .51585 .42037 .51648 .42219 .51589 .4211 .51536 Mtetra
.662 .883 .979 r
.4211 .51536 .42219 .51589 .42401 .51519 .42293 .51462 Mtetra
.795 .891 .913 r
.42293 .51462 .42401 .51519 .42585 .51426 .42477 .51333 Mtetra
.904 .798 .733 r
.42477 .51333 .42585 .51426 .4277 .51271 .42668 .5101 Mtetra
.874 .677 .632 r
.42668 .5101 .4277 .51271 .42956 .51091 .42866 .50409 Mtetra
.957 .683 .474 r
.42866 .50409 .42956 .51091 .43142 .5091 .43611 .30516 Mtetra
.537 .312 .521 r
.43611 .30516 .43142 .5091 .43325 .50827 .43789 .30211 Mtetra
.53 .307 .52 r
.43789 .30211 .43325 .50827 .43507 .50779 .4396 .30202 Mtetra
.526 .304 .52 r
.4396 .30202 .43507 .50779 .43689 .5075 .44125 .30373 Mtetra
.524 .301 .519 r
.44125 .30373 .43689 .5075 .4387 .5076 .44288 .30676 Mtetra
.528 .305 .52 r
.44288 .30676 .4387 .5076 .44053 .50712 .44456 .30784 Mtetra
.544 .318 .522 r
.44456 .30784 .44053 .50712 .44239 .5054 .44643 .3015 Mtetra
.546 .319 .522 r
.44643 .3015 .44239 .5054 .44458 .49037 .44832 .29406 Mtetra
.538 .313 .521 r
.44832 .29406 .44458 .49037 .45106 .29329 .45011 .29045 Mtetra
.753 .607 .696 r
.45011 .29045 .45106 .29329 .45285 .28942 .45187 .2882 Mtetra
.683 .729 .885 r
.45187 .2882 .45285 .28942 .45458 .28848 .45359 .28748 Mtetra
.593 .745 .949 r
.45359 .28748 .45458 .28848 .4563 .28809 .45531 .28712 Mtetra
.534 .727 .963 r
.45531 .28712 .4563 .28809 .45801 .288 .45702 .28692 Mtetra
.65 .749 .922 r
.45702 .28692 .45801 .288 .45973 .28746 .45874 .28637 Mtetra
.666 .751 .913 r
.45874 .28637 .45973 .28746 .46145 .28688 .46047 .28575 Mtetra
.681 .747 .901 r
.46047 .28575 .46145 .28688 .46318 .28624 .4622 .28505 Mtetra
.749 .755 .857 r
.4622 .28505 .46318 .28624 .46491 .28538 .46393 .28395 Mtetra
.705 .704 .847 r
.46393 .28395 .46491 .28538 .46664 .28458 .46567 .28306 Mtetra
.626 .66 .863 r
.46567 .28306 .46664 .28458 .46837 .28397 .46739 .2826 Mtetra
0 .306 .8 r
.46739 .2826 .46837 .28397 .47009 .28368 .46909 .28376 Mtetra
.849 .406 .165 r
.46909 .28376 .47009 .28368 .47181 .2839 .47076 .28696 Mtetra
.962 .678 .449 r
.47076 .28696 .47181 .2839 .47351 .28511 .46913 .48594 Mtetra
.544 .313 .515 r
.46913 .48594 .47351 .28511 .47502 .29873 .47083 .4942 Mtetra
.534 .305 .514 r
.47083 .4942 .47502 .29873 .47372 .49532 .47264 .49662 Mtetra
.599 .145 .145 r
.47264 .49662 .47372 .49532 .47552 .49844 .47447 .49759 Mtetra
.465 .742 .989 r
.47447 .49759 .47552 .49844 .47737 .49849 .47632 .49747 Mtetra
.68 .786 .93 r
.47632 .49747 .47737 .49849 .47923 .49775 .47818 .49674 Mtetra
.786 .808 .87 r
.47818 .49674 .47923 .49775 .4811 .4965 .48005 .49537 Mtetra
.876 .788 .761 r
.48005 .49537 .4811 .4965 .48296 .49551 .48194 .4927 Mtetra
.852 .663 .647 r
.48194 .4927 .48296 .49551 .48483 .49405 .48386 .48776 Mtetra
.963 .683 .458 r
.48386 .48776 .48483 .49405 .48672 .49156 .48808 .28735 Mtetra
.548 .321 .522 r
.48808 .28735 .48672 .49156 .48872 .47852 .48992 .27868 Mtetra
.537 .312 .521 r
.48992 .27868 .48872 .47852 .49265 .27877 .4917 .27536 Mtetra
.718 .566 .682 r
.4917 .27536 .49265 .27877 .49443 .27475 .49346 .27333 Mtetra
.696 .705 .855 r
.49346 .27333 .49443 .27475 .49618 .27357 .49521 .27249 Mtetra
.614 .738 .934 r
.49521 .27249 .49618 .27357 .49792 .2731 .49695 .27207 Mtetra
.564 .728 .951 r
.49695 .27207 .49792 .2731 .49967 .27293 .4987 .27179 Mtetra
.76 .771 .862 r
.4987 .27179 .49967 .27293 .50142 .27186 .50045 .27063 Mtetra
.725 .746 .869 r
.50045 .27063 .50142 .27186 .50317 .27098 .50221 .26967 Mtetra
.587 .681 .906 r
.50221 .26967 .50317 .27098 .50492 .27077 .50396 .26937 Mtetra
.763 .332 0 r
.50396 .26937 .50492 .27077 .50665 .27429 .50569 .27279 Mtetra
.97 .683 .429 r
.50569 .27279 .50665 .27429 .5073 .48098 .50627 .47973 Mtetra
.925 .542 .161 r
.50627 .47973 .5073 .48098 .50914 .48741 .50811 .48642 Mtetra
.225 .579 .943 r
.50811 .48642 .50914 .48741 .51102 .48786 .50999 .48685 Mtetra
.69 .794 .929 r
.50999 .48685 .51102 .48786 .5129 .48711 .51187 .48607 Mtetra
.77 .804 .88 r
.51187 .48607 .5129 .48711 .51479 .48589 .51376 .48481 Mtetra
.49 .701 .963 r
.51376 .48481 .51479 .48589 .51667 .48573 .51564 .48472 Mtetra
.517 .731 .971 r
.51564 .48472 .51667 .48573 .51855 .48545 .51752 .48454 Mtetra
.718 .822 .93 r
.51752 .48454 .51855 .48545 .52044 .48443 .51941 .48361 Mtetra
.949 .798 .659 r
.51941 .48361 .52044 .48443 .52233 .47941 .52131 .47872 Mtetra
.971 .689 .437 r
.52131 .47872 .52233 .47941 .52426 .27116 .5233 .27021 Mtetra
.96 .757 .586 r
.5233 .27021 .52426 .27116 .52603 .26394 .52507 .26271 Mtetra
.809 .766 .813 r
.52507 .26271 .52603 .26394 .52779 .26228 .52684 .26104 Mtetra
.623 .711 .909 r
.52684 .26104 .52779 .26228 .52956 .26179 .52861 .26059 Mtetra
.481 .655 .937 r
.52861 .26059 .52956 .26179 .53133 .26175 .53038 .2606 Mtetra
.668 .746 .908 r
.53038 .2606 .53133 .26175 .5331 .26121 .53215 .25995 Mtetra
.685 .73 .885 r
.53215 .25995 .5331 .26121 .53487 .26054 .53392 .2592 Mtetra
.614 .69 .898 r
.53392 .2592 .53487 .26054 .53664 .25998 .53569 .25879 Mtetra
.095 .431 .873 r
.53569 .25879 .53664 .25998 .53842 .25958 .53747 .25962 Mtetra
.81 .332 .07 r
.53747 .25962 .53842 .25958 .54019 .25954 .53926 .26231 Mtetra
.967 .676 .424 r
.53926 .26231 .54019 .25954 .54198 .26028 .54205 .45444 Mtetra
.557 .323 .516 r
.54205 .45444 .54198 .26028 .54379 .26578 .54404 .46963 Mtetra
.534 .305 .514 r
.54404 .46963 .54379 .26578 .54695 .47003 .54596 .47246 Mtetra
.609 .217 .277 r
.54596 .47246 .54695 .47003 .54889 .47431 .54788 .47364 Mtetra
.105 .574 .912 r
.54788 .47364 .54889 .47431 .55081 .47531 .54979 .47405 Mtetra
.576 .705 .93 r
.54979 .47405 .55081 .47531 .55272 .47502 .55171 .47374 Mtetra
.746 .762 .866 r
.55171 .47374 .55272 .47502 .55462 .47373 .55361 .47257 Mtetra
.926 .782 .681 r
.55361 .47257 .55462 .47373 .5565 .46941 .55549 .46831 Mtetra
.973 .688 .426 r
.55549 .46831 .5565 .46941 .55632 .26312 .55537 .262 Mtetra
.964 .74 .552 r
.55537 .262 .55632 .26312 .55801 .25349 .55707 .25233 Mtetra
.853 .785 .785 r
.55707 .25233 .55801 .25349 .55978 .25137 .55884 .2502 Mtetra
.67 .743 .905 r
.55884 .2502 .55978 .25137 .56157 .25072 .56063 .24953 Mtetra
.548 .691 .934 r
.56063 .24953 .56157 .25072 .56336 .25053 .56242 .24933 Mtetra
.668 .739 .903 r
.56242 .24933 .56336 .25053 .56516 .24999 .56421 .24868 Mtetra
.692 .726 .876 r
.56421 .24868 .56516 .24999 .56695 .24927 .566 .24788 Mtetra
.624 .686 .888 r
.566 .24788 .56695 .24927 .56874 .24868 .5678 .24741 Mtetra
.215 .492 .899 r
.5678 .24741 .56874 .24868 .57054 .24823 .56961 .24808 Mtetra
.782 .28 0 r
.56961 .24808 .57054 .24823 .57234 .24814 .57146 .25055 Mtetra
.918 .586 .396 r
.57146 .25055 .57234 .24814 .57416 .24876 .5735 .26555 Mtetra
.952 .655 .436 r
.5735 .26555 .57416 .24876 .57604 .25333 .57847 .45832 Mtetra
.534 .305 .514 r
.57847 .45832 .57604 .25333 .58139 .45839 .58046 .46136 Mtetra
.607 .235 .311 r
.58046 .46136 .58139 .45839 .58341 .46315 .58242 .46263 Mtetra
0 .526 .851 r
.58242 .46263 .58341 .46315 .58537 .46436 .58437 .46309 Mtetra
.556 .696 .933 r
.58437 .46309 .58537 .46436 .58731 .46416 .58631 .46284 Mtetra
.731 .756 .873 r
.58631 .46284 .58731 .46416 .58924 .46296 .58824 .46176 Mtetra
.917 .787 .702 r
.58824 .46176 .58924 .46296 .59111 .45914 .59012 .458 Mtetra
.975 .687 .413 r
.59012 .458 .59111 .45914 .58883 .25582 .5879 .25459 Mtetra
.97 .727 .512 r
.5879 .25459 .58883 .25582 .59038 .24242 .58945 .24123 Mtetra
.876 .786 .758 r
.58945 .24123 .59038 .24242 .59214 .23988 .59122 .2387 Mtetra
.689 .75 .898 r
.59122 .2387 .59214 .23988 .59395 .23912 .59302 .23793 Mtetra
.569 .702 .931 r
.59302 .23793 .59395 .23912 .59577 .23885 .59484 .23766 Mtetra
.685 .748 .899 r
.59484 .23766 .59577 .23885 .59758 .23811 .59665 .23691 Mtetra
.726 .76 .88 r
.59665 .23691 .59758 .23811 .59938 .23714 .59846 .23594 Mtetra
.61 .718 .921 r
.59846 .23594 .59938 .23714 .6012 .23673 .60028 .23552 Mtetra
0 .059 .596 r
.60028 .23552 .6012 .23673 .60308 .23865 .60216 .23743 Mtetra
.974 .678 .39 r
.60216 .23743 .60308 .23865 .61018 .43995 .60919 .43842 Mtetra
.954 .609 .241 r
.60919 .43842 .61018 .43995 .61249 .45314 .6115 .45197 Mtetra
0 .161 .675 r
.6115 .45197 .61249 .45314 .6145 .45479 .61352 .45364 Mtetra
.609 .744 .941 r
.61352 .45364 .6145 .45479 .61646 .45432 .61548 .45317 Mtetra
.73 .787 .898 r
.61548 .45317 .61646 .45432 .6184 .45328 .61742 .45213 Mtetra
.637 .757 .935 r
.61742 .45213 .6184 .45328 .62036 .45269 .61938 .45155 Mtetra
.541 .718 .955 r
.61938 .45155 .62036 .45269 .62233 .45245 .62135 .45132 Mtetra
.693 .78 .918 r
.62135 .45132 .62233 .45245 .62428 .45161 .6233 .45048 Mtetra
.911 .805 .729 r
.6233 .45048 .62428 .45161 .62615 .44832 .62518 .44721 Mtetra
.976 .685 .399 r
.62518 .44721 .62615 .44832 .62188 .25028 .62101 .25054 Mtetra
.989 .733 .44 r
.62101 .25054 .62188 .25028 .62312 .23102 .62221 .22984 Mtetra
.895 .791 .738 r
.62221 .22984 .62312 .23102 .62488 .22816 .62397 .22697 Mtetra
.703 .758 .895 r
.62397 .22697 .62488 .22816 .62671 .22732 .62579 .22613 Mtetra
.585 .711 .93 r
.62579 .22613 .62671 .22732 .62855 .22699 .62764 .22579 Mtetra
.666 .744 .909 r
.62764 .22579 .62855 .22699 .63038 .22633 .62947 .22513 Mtetra
.733 .767 .88 r
.62947 .22513 .63038 .22633 .6322 .22531 .63129 .22411 Mtetra
.636 .732 .917 r
.63129 .22411 .6322 .22531 .63404 .22478 .63313 .22358 Mtetra
0 .279 .777 r
.63313 .22358 .63404 .22478 .63595 .2261 .63504 .2249 Mtetra
.939 .576 .19 r
.63504 .2249 .63595 .2261 .63818 .23611 .63727 .23496 Mtetra
.975 .675 .374 r
.63727 .23496 .63818 .23611 .64776 .44068 .64679 .43954 Mtetra
0 0 .511 r
.64679 .43954 .64776 .44068 .64984 .44294 .64888 .4418 Mtetra
.627 .757 .94 r
.64888 .4418 .64984 .44294 .65182 .4424 .65086 .44126 Mtetra
.766 .802 .882 r
.65086 .44126 .65182 .4424 .65377 .44111 .65281 .43998 Mtetra
.777 .806 .876 r
.65281 .43998 .65377 .44111 .65573 .43974 .65476 .43862 Mtetra
.719 .794 .911 r
.65476 .43862 .65573 .43974 .65769 .43875 .65673 .43765 Mtetra
.706 .794 .92 r
.65673 .43765 .65769 .43875 .65966 .43782 .6587 .43674 Mtetra
.655 .781 .941 r
.6587 .43674 .65966 .43782 .66164 .43715 .66068 .43607 Mtetra
.582 .751 .958 r
.66068 .43607 .66164 .43715 .66364 .43678 .66268 .43568 Mtetra
.558 .735 .959 r
.66268 .43568 .66364 .43678 .66564 .43651 .66468 .43537 Mtetra
.461 .683 .961 r
.66468 .43537 .66564 .43651 .66766 .43653 .6667 .43537 Mtetra
.422 .657 .958 r
.6667 .43537 .66766 .43653 .66968 .43665 .66872 .43549 Mtetra
.631 .755 .937 r
.66872 .43549 .66968 .43665 .67167 .43609 .67072 .43492 Mtetra
.891 .811 .763 r
.67072 .43492 .67167 .43609 .67357 .43336 .67261 .43218 Mtetra
.981 .72 .46 r
.67261 .43218 .67357 .43336 .67472 .41462 .67374 .41279 Mtetra
.977 .681 .38 r
.67374 .41279 .67472 .41462 .6674 .21564 .66651 .2144 Mtetra
.909 .788 .715 r
.66651 .2144 .6674 .21564 .66914 .21239 .66825 .21116 Mtetra
.703 .754 .892 r
.66825 .21116 .66914 .21239 .67099 .21152 .6701 .2103 Mtetra
.579 .706 .929 r
.6701 .2103 .67099 .21152 .67287 .21119 .67197 .20998 Mtetra
.59 .712 .928 r
.67197 .20998 .67287 .21119 .67474 .21077 .67385 .20962 Mtetra
.697 .769 .907 r
.67385 .20962 .67474 .21077 .67659 .20984 .67571 .20881 Mtetra
.651 .777 .941 r
.67571 .20881 .67659 .20984 .67846 .20927 .67758 .20819 Mtetra
.487 .693 .959 r
.67758 .20819 .67846 .20927 .68039 .20986 .67947 .20813 Mtetra
.23 .416 .839 r
.67947 .20813 .68039 .20986 .68251 .21405 .68143 .20913 Mtetra
.278 .241 .637 r
.68143 .20913 .68251 .21405 .69526 .42051 .68347 .21175 Mtetra
.005 0 .406 r
.68347 .21175 .69526 .42051 .69758 .42571 .69575 .40785 Mtetra
.134 .053 .492 r
.69575 .40785 .69758 .42571 .69967 .42656 .69851 .42135 Mtetra
.265 .235 .637 r
.69851 .42135 .69967 .42656 .70171 .42659 .70071 .42424 Mtetra
.309 .406 .8 r
.70071 .42424 .70171 .42659 .70375 .42641 .70282 .42533 Mtetra
.442 .685 .968 r
.70282 .42533 .70375 .42641 .7058 .4263 .70487 .42535 Mtetra
.687 .824 .949 r
.70487 .42535 .7058 .4263 .70781 .42554 .70688 .42452 Mtetra
.891 .84 .789 r
.70688 .42452 .70781 .42554 .70973 .42315 .70879 .42201 Mtetra
.98 .755 .527 r
.70879 .42201 .70973 .42315 .71122 .41336 .7103 .41234 Mtetra
.978 .678 .362 r
.7103 .41234 .71122 .41336 .70113 .20471 .70025 .20351 Mtetra
.938 .791 .672 r
.70025 .20351 .70113 .20471 .70281 .20069 .70193 .19947 Mtetra
.731 .768 .883 r
.70193 .19947 .70281 .20069 .70467 .19967 .70379 .19844 Mtetra
.605 .718 .925 r
.70379 .19844 .70467 .19967 .70657 .19926 .70569 .19802 Mtetra
.604 .717 .924 r
.70569 .19802 .70657 .19926 .70847 .19884 .70759 .19761 Mtetra
.742 .771 .876 r
.70759 .19761 .70847 .19884 .71033 .19775 .70945 .19651 Mtetra
.66 .74 .909 r
.70945 .19651 .71033 .19775 .71222 .1971 .71134 .19586 Mtetra
.245 .517 .91 r
.71134 .19586 .71222 .1971 .71419 .19774 .71331 .1965 Mtetra
.876 .481 .02 r
.71331 .1965 .71419 .19774 .71657 .20482 .71569 .20351 Mtetra
.975 .667 .334 r
.71569 .20351 .71657 .20482 .73185 .41349 .73092 .41226 Mtetra
.644 .195 0 r
.73092 .41226 .73185 .41349 .73415 .41699 .73322 .41574 Mtetra
.47 .666 .948 r
.73322 .41574 .73415 .41699 .73624 .41714 .7353 .41576 Mtetra
.692 .745 .892 r
.7353 .41576 .73624 .41714 .73827 .41625 .73733 .41487 Mtetra
.794 .78 .84 r
.73733 .41487 .73827 .41625 .74021 .41412 .73931 .41326 Mtetra
.895 .874 .808 r
.73931 .41326 .74021 .41412 .74194 .40887 .74123 .41088 Mtetra
0 0 0 r
.74123 .41088 .74194 .40887 .72994 .20118 .74306 .40696 Mtetra
.508 .286 .511 r
.74306 .40696 .72994 .20118 .73135 .19331 .74433 .39501 Mtetra
0 0 .401 r
.74433 .39501 .73135 .19331 .73315 .19119 .73259 .19424 Mtetra
0 0 .058 r
.73259 .19424 .73315 .19119 .73501 .18989 .73424 .18998 Mtetra
.875 .992 .749 r
.73424 .18998 .73501 .18989 .7369 .18899 .73604 .1877 Mtetra
.711 .753 .886 r
.73604 .1877 .7369 .18899 .7388 .18825 .73792 .18678 Mtetra
.637 .69 .883 r
.73792 .18678 .7388 .18825 .74071 .18764 .73984 .18622 Mtetra
.63 .696 .892 r
.73984 .18622 .74071 .18764 .74262 .18698 .74176 .18569 Mtetra
.751 .768 .867 r
.74176 .18569 .74262 .18698 .74449 .18579 .74363 .18451 Mtetra
.678 .743 .899 r
.74363 .18451 .74449 .18579 .7464 .18503 .74554 .18376 Mtetra
.388 .598 .929 r
.74554 .18376 .7464 .18503 .74838 .18533 .74752 .18406 Mtetra
.819 .41 0 r
.74752 .18406 .74838 .18533 .75078 .19122 .74992 .1899 Mtetra
.973 .662 .315 r
.74992 .1899 .75078 .19122 .76862 .40111 .76771 .39986 Mtetra
.69 .251 0 r
.76771 .39986 .76862 .40111 .77104 .40521 .77013 .40397 Mtetra
.438 .65 .949 r
.77013 .40397 .77104 .40521 .77318 .40546 .77226 .40408 Mtetra
.679 .742 .898 r
.77226 .40408 .77318 .40546 .77523 .40466 .77431 .40326 Mtetra
.788 .778 .844 r
.77431 .40326 .77523 .40466 .7772 .40272 .77631 .40169 Mtetra
.881 .852 .81 r
.77631 .40169 .7772 .40272 .77893 .39785 .77825 .3994 Mtetra
0 0 0 r
.77825 .3994 .77893 .39785 .76461 .19111 .78007 .39566 Mtetra
.513 .289 .512 r
.78007 .39566 .76461 .19111 .7658 .18127 .78143 .38605 Mtetra
.014 0 .412 r
.78143 .38605 .7658 .18127 .7676 .17902 .76714 .18252 Mtetra
0 0 .125 r
.76714 .18252 .7676 .17902 .76947 .17765 .76875 .17794 Mtetra
.844 .976 .673 r
.76875 .17794 .76947 .17765 .77138 .17671 .77053 .17546 Mtetra
.722 .767 .889 r
.77053 .17546 .77138 .17671 .7733 .17594 .77244 .17447 Mtetra
.643 .697 .885 r
.77244 .17447 .7733 .17594 .77523 .17531 .77437 .17388 Mtetra
.613 .689 .897 r
.77437 .17388 .77523 .17531 .77717 .1747 .77632 .17343 Mtetra
.756 .775 .869 r
.77632 .17343 .77717 .1747 .77906 .17349 .77821 .17222 Mtetra
.688 .751 .899 r
.77821 .17222 .77906 .17349 .78098 .17267 .78013 .17141 Mtetra
.484 .655 .935 r
.78013 .17141 .78098 .17267 .78297 .17267 .78213 .17141 Mtetra
.753 .335 0 r
.78213 .17141 .78297 .17267 .7854 .17764 .78456 .17642 Mtetra
.971 .656 .295 r
.78456 .17642 .7854 .17764 .80585 .38849 .80496 .38731 Mtetra
.741 .307 0 r
.80496 .38731 .80585 .38849 .80842 .39335 .80753 .39214 Mtetra
.295 .575 .937 r
.80753 .39214 .80842 .39335 .81061 .39385 .80972 .39263 Mtetra
.647 .764 .934 r
.80972 .39263 .81061 .39385 .8127 .39319 .81182 .39197 Mtetra
.828 .821 .843 r
.81182 .39197 .8127 .39319 .81469 .39137 .81381 .39015 Mtetra
.908 .737 .657 r
.1468 .5994 .14798 .60036 .15019 .5946 .14902 .59364 Mtetra
.936 .686 .535 r
.14902 .59364 .15019 .5946 .17381 .39283 .17271 .39182 Mtetra
.908 .728 .647 r
.17271 .39182 .17381 .39283 .17595 .38687 .17486 .38585 Mtetra
.773 .76 .841 r
.17486 .38585 .17595 .38687 .17757 .38566 .17648 .38465 Mtetra
.639 .736 .919 r
.17648 .38465 .17757 .38566 .17911 .3852 .17802 .38419 Mtetra
.508 .692 .951 r
.17802 .38419 .17911 .3852 .18061 .38511 .17952 .38411 Mtetra
.75 .759 .86 r
.17952 .38411 .18061 .38511 .18221 .38409 .18112 .38309 Mtetra
.697 .752 .894 r
.18112 .38309 .18221 .38409 .18378 .38339 .18269 .38238 Mtetra
.481 .683 .955 r
.18269 .38238 .18378 .38339 .18528 .38335 .18419 .38235 Mtetra
.926 .547 .255 r
.18419 .38235 .18528 .38335 .18636 .38739 .18526 .38643 Mtetra
.939 .683 .523 r
.18526 .38643 .18636 .38739 .16678 .58812 .1656 .58723 Mtetra
.932 .58 .332 r
.1656 .58723 .16678 .58812 .1678 .59365 .16663 .59271 Mtetra
.252 .602 .952 r
.16663 .59271 .1678 .59365 .16937 .59395 .16819 .59301 Mtetra
.674 .773 .925 r
.16819 .59301 .16937 .59395 .17103 .59332 .16986 .59237 Mtetra
.753 .784 .878 r
.16986 .59237 .17103 .59332 .17275 .59226 .17157 .59131 Mtetra
.481 .712 .972 r
.17157 .59131 .17275 .59226 .17436 .59219 .17319 .59124 Mtetra
.587 .749 .954 r
.17319 .59124 .17436 .59219 .176 .59186 .17483 .5909 Mtetra
.752 .782 .878 r
.17483 .5909 .176 .59186 .17771 .59081 .17654 .58984 Mtetra
.907 .743 .666 r
.17654 .58984 .17771 .59081 .17985 .58557 .17868 .5846 Mtetra
.939 .687 .529 r
.17868 .5846 .17985 .58557 .20181 .38361 .20072 .38258 Mtetra
.913 .727 .638 r
.20072 .38258 .20181 .38361 .20397 .37716 .20289 .37613 Mtetra
.791 .761 .826 r
.20289 .37613 .20397 .37716 .20562 .37577 .20454 .37474 Mtetra
.623 .731 .924 r
.20454 .37474 .20562 .37577 .20717 .37536 .20609 .37434 Mtetra
.458 .67 .955 r
.20609 .37434 .20717 .37536 .20868 .37537 .2076 .37436 Mtetra
.613 .731 .929 r
.2076 .37436 .20868 .37537 .21024 .37498 .20915 .37399 Mtetra
.643 .743 .922 r
.20915 .37399 .21024 .37498 .2118 .37448 .21072 .3735 Mtetra
.654 .75 .921 r
.21072 .3735 .2118 .37448 .21337 .37395 .21229 .37298 Mtetra
.692 .762 .906 r
.21229 .37298 .21337 .37395 .21497 .37312 .21387 .3723 Mtetra
.696 .795 .926 r
.21387 .3723 .21497 .37312 .21656 .37238 .21546 .37162 Mtetra
.674 .803 .944 r
.21546 .37162 .21656 .37238 .21812 .37194 .21704 .37101 Mtetra
.689 .767 .912 r
.21704 .37101 .21812 .37194 .21959 .37249 .21862 .37034 Mtetra
.601 .563 .784 r
.21862 .37034 .21959 .37249 .22095 .37427 .22018 .37 Mtetra
.5 .395 .666 r
.22018 .37 .22095 .37427 .22192 .38013 .22167 .37039 Mtetra
.181 .084 .502 r
.22167 .37039 .22192 .38013 .20504 .57577 .22272 .37537 Mtetra
0 0 .14 r
.22272 .37537 .20504 .57577 .20627 .57997 .20542 .57566 Mtetra
0 0 .334 r
.20542 .57566 .20627 .57997 .20774 .5817 .20663 .58013 Mtetra
.303 .498 .882 r
.20663 .58013 .20774 .5817 .20936 .58178 .20822 .58066 Mtetra
.646 .735 .914 r
.20822 .58066 .20936 .58178 .21104 .58125 .2099 .58014 Mtetra
.723 .755 .878 r
.2099 .58014 .21104 .58125 .21275 .58048 .21162 .57923 Mtetra
.662 .714 .887 r
.21162 .57923 .21275 .58048 .21442 .58003 .21331 .57862 Mtetra
.635 .681 .876 r
.21331 .57862 .21442 .58003 .21609 .57968 .21499 .57814 Mtetra
.636 .662 .858 r
.21499 .57814 .21609 .57968 .21777 .57928 .21667 .57764 Mtetra
.635 .647 .845 r
.21667 .57764 .21777 .57928 .21944 .57887 .21836 .57714 Mtetra
.641 .64 .833 r
.21836 .57714 .21944 .57887 .22114 .57828 .22005 .57659 Mtetra
.658 .651 .832 r
.22005 .57659 .22114 .57828 .22286 .57737 .22175 .57594 Mtetra
.71 .703 .841 r
.22175 .57594 .22286 .57737 .22468 .57533 .22347 .57501 Mtetra
.767 .918 .939 r
.22347 .57501 .22468 .57533 .22662 .57199 .22522 .57392 Mtetra
.09 0 0 r
.22522 .57392 .22662 .57199 .22876 .56634 .22696 .5728 Mtetra
.487 .196 .397 r
.22696 .5728 .22876 .56634 .23069 .56299 .22863 .57247 Mtetra
.504 .233 .437 r
.22863 .57247 .23069 .56299 .2323 .56334 .23031 .57221 Mtetra
.467 .196 .419 r
.23031 .57221 .2323 .56334 .23401 .56261 .23203 .5713 Mtetra
.155 0 .296 r
.23203 .5713 .23401 .56261 .25225 .36838 .23409 .56662 Mtetra
0 0 .138 r
.23409 .56662 .25225 .36838 .2544 .36141 .25297 .36462 Mtetra
.937 .879 .465 r
.25297 .36462 .2544 .36141 .25622 .35823 .25509 .35792 Mtetra
.877 .886 .836 r
.25509 .35792 .25622 .35823 .25787 .35698 .2568 .35607 Mtetra
.664 .771 .929 r
.2568 .35607 .25787 .35698 .25946 .35656 .2584 .3555 Mtetra
.534 .696 .943 r
.2584 .3555 .25946 .35656 .26102 .35642 .25997 .35536 Mtetra
.597 .717 .928 r
.25997 .35536 .26102 .35642 .26261 .3561 .26155 .35503 Mtetra
.642 .731 .913 r
.26155 .35503 .26261 .3561 .2642 .35561 .26314 .35455 Mtetra
.648 .736 .913 r
.26314 .35455 .2642 .35561 .26581 .35504 .26474 .35404 Mtetra
.665 .753 .915 r
.26474 .35404 .26581 .35504 .26742 .35435 .26635 .35346 Mtetra
.678 .78 .927 r
.26635 .35346 .26742 .35435 .26904 .35358 .26796 .35283 Mtetra
.682 .812 .945 r
.26796 .35283 .26904 .35358 .27066 .35281 .26957 .35218 Mtetra
.692 .842 .955 r
.26957 .35218 .27066 .35281 .27229 .35197 .27119 .35149 Mtetra
.677 .875 .973 r
.27119 .35149 .27229 .35197 .27392 .35121 .27281 .35081 Mtetra
.63 .883 .988 r
.27281 .35081 .27392 .35121 .27552 .35076 .27442 .35023 Mtetra
.644 .857 .981 r
.27442 .35023 .27552 .35076 .27705 .35111 .27603 .34965 Mtetra
.607 .651 .867 r
.27603 .34965 .27705 .35111 .2785 .35264 .27762 .34931 Mtetra
.502 .432 .71 r
.27762 .34931 .2785 .35264 .27974 .35691 .27917 .3496 Mtetra
.244 .157 .554 r
.27917 .3496 .27974 .35691 .26617 .55458 .28048 .35297 Mtetra
0 0 .183 r
.28048 .35297 .26617 .55458 .26743 .56005 .26665 .55436 Mtetra
0 0 .333 r
.26665 .55436 .26743 .56005 .26895 .56212 .26789 .56021 Mtetra
.099 .318 .793 r
.26789 .56021 .26895 .56212 .27059 .56263 .26948 .56136 Mtetra
.6 .696 .91 r
.26948 .56136 .27059 .56263 .27229 .56236 .27119 .56101 Mtetra
.695 .715 .864 r
.27119 .56101 .27229 .56236 .27402 .56176 .27293 .5602 Mtetra
.671 .676 .847 r
.27293 .5602 .27402 .56176 .27574 .56121 .27467 .5595 Mtetra
.642 .645 .838 r
.27467 .5595 .27574 .56121 .27747 .56065 .27639 .55894 Mtetra
.659 .652 .832 r
.27639 .55894 .27747 .56065 .27922 .55979 .27813 .55827 Mtetra
.66 .679 .857 r
.27813 .55827 .27922 .55979 .28102 .5582 .27986 .55764 Mtetra
.699 .869 .962 r
.27986 .55764 .28102 .5582 .2829 .55551 .28161 .55684 Mtetra
0 0 0 r
.28161 .55684 .2829 .55551 .28494 .55061 .2834 .55543 Mtetra
0 0 .071 r
.2834 .55543 .28494 .55061 .30065 .35217 .28539 .55129 Mtetra
0 0 .177 r
.28539 .55129 .30065 .35217 .30279 .34429 .30133 .34912 Mtetra
.814 .792 .295 r
.30133 .34912 .30279 .34429 .3046 .34113 .30349 .34106 Mtetra
.92 .908 .794 r
.30349 .34106 .3046 .34113 .3063 .33958 .30524 .33871 Mtetra
.705 .791 .918 r
.30524 .33871 .3063 .33958 .30793 .3389 .30688 .33795 Mtetra
.582 .742 .953 r
.30688 .33795 .30793 .3389 .30955 .33851 .30849 .33764 Mtetra
.593 .765 .961 r
.30849 .33764 .30955 .33851 .31117 .33808 .31011 .33728 Mtetra
.655 .8 .952 r
.31011 .33728 .31117 .33808 .3128 .33751 .31174 .33672 Mtetra
.654 .8 .953 r
.31174 .33672 .3128 .33751 .31443 .33695 .31337 .33617 Mtetra
.655 .802 .953 r
.31337 .33617 .31443 .33695 .31607 .33638 .31501 .3356 Mtetra
.658 .804 .953 r
.31501 .3356 .31607 .33638 .3177 .33581 .31664 .33503 Mtetra
.659 .805 .953 r
.31664 .33503 .3177 .33581 .31934 .33523 .31828 .33445 Mtetra
.31828 .33445 .31934 .33523 .32097 .33465 .31992 .33387 Mtetra
.66 .806 .953 r
.31992 .33387 .32097 .33465 .32261 .33407 .32155 .33329 Mtetra
.32155 .33329 .32261 .33407 .32425 .33349 .32319 .33271 Mtetra
.32319 .33271 .32425 .33349 .32589 .3329 .32484 .33213 Mtetra
.32484 .33213 .32589 .3329 .32753 .33232 .32648 .33154 Mtetra
.661 .806 .953 r
.32648 .33154 .32753 .33232 .32917 .33173 .32812 .33096 Mtetra
.32812 .33096 .32917 .33173 .33082 .33115 .32976 .33037 Mtetra
.661 .806 .952 r
.32976 .33037 .33082 .33115 .33246 .33056 .33141 .32978 Mtetra
.662 .806 .952 r
.33141 .32978 .33246 .33056 .33411 .32997 .33306 .32919 Mtetra
.665 .806 .951 r
.33306 .32919 .33411 .32997 .33575 .32938 .3347 .32859 Mtetra
.667 .806 .949 r
.3347 .32859 .33575 .32938 .3374 .32878 .33635 .32798 Mtetra
.665 .804 .949 r
.33635 .32798 .3374 .32878 .33905 .32818 .338 .32738 Mtetra
.709 .812 .929 r
.338 .32738 .33905 .32818 .34071 .32747 .33966 .3266 Mtetra
.729 .801 .909 r
.33966 .3266 .34071 .32747 .34237 .32669 .34133 .32573 Mtetra
.625 .755 .94 r
.34133 .32573 .34237 .32669 .34402 .3262 .34298 .32528 Mtetra
0 .233 .703 r
.34298 .32528 .34402 .3262 .34561 .3266 .34454 .32631 Mtetra
.927 .574 .34 r
.34454 .32631 .34561 .3266 .3471 .32891 .34579 .33287 Mtetra
.95 .678 .488 r
.34579 .33287 .3471 .32891 .34832 .33618 .33604 .53502 Mtetra
.535 .306 .514 r
.33604 .53502 .34832 .33618 .33919 .53035 .33761 .53808 Mtetra
.503 .221 .418 r
.33761 .53808 .33919 .53035 .3409 .5308 .33935 .5379 Mtetra
.456 .173 .395 r
.33935 .5379 .3409 .5308 .34272 .52925 .34114 .53703 Mtetra
.454 .178 .404 r
.34114 .53703 .34272 .52925 .3446 .52649 .34293 .53603 Mtetra
.486 .217 .431 r
.34293 .53603 .3446 .52649 .34648 .52368 .3447 .53537 Mtetra
.498 .236 .448 r
.3447 .53537 .34648 .52368 .34822 .5237 .34648 .53479 Mtetra
.507 .242 .447 r
.34648 .53479 .34822 .5237 .3497 .52853 .34823 .5345 Mtetra
.51 .211 .394 r
.34823 .5345 .3497 .52853 .35122 .53287 .34998 .53453 Mtetra
.433 0 .114 r
.34998 .53453 .35122 .53287 .35285 .53505 .35172 .53455 Mtetra
.398 .785 .99 r
.35172 .53455 .35285 .53505 .35455 .53591 .35348 .53439 Mtetra
.619 .667 .874 r
.35348 .53439 .35455 .53591 .35631 .53571 .35525 .53395 Mtetra
.635 .641 .838 r
.35525 .53395 .35631 .53571 .35809 .5352 .35703 .53341 Mtetra
.619 .63 .84 r
.35703 .53341 .35809 .5352 .35987 .53462 .3588 .53297 Mtetra
.582 .632 .866 r
.3588 .53297 .35987 .53462 .36165 .53414 .36057 .5327 Mtetra
.672 .699 .867 r
.36057 .5327 .36165 .53414 .36344 .53335 .36236 .53199 Mtetra
.819 .746 .783 r
.36236 .53199 .36344 .53335 .36527 .53185 .36421 .52998 Mtetra
.903 .708 .629 r
.36421 .52998 .36527 .53185 .36717 .52874 .36628 .52343 Mtetra
.954 .685 .489 r
.36628 .52343 .36717 .52874 .36922 .52243 .37763 .31887 Mtetra
.541 .315 .522 r
.37763 .31887 .36922 .52243 .38022 .3216 .37951 .31378 Mtetra
.612 .426 .606 r
.37951 .31378 .38022 .3216 .38213 .31587 .38123 .31224 Mtetra
.632 .505 .69 r
.38123 .31224 .38213 .31587 .38391 .31308 .38292 .31135 Mtetra
.654 .64 .824 r
.38292 .31135 .38391 .31308 .38563 .31143 .3846 .31072 Mtetra
.672 .831 .96 r
.3846 .31072 .38563 .31143 .38732 .31065 .38628 .31007 Mtetra
.632 .852 .983 r
.38628 .31007 .38732 .31065 .38899 .31015 .38796 .30951 Mtetra
.634 .837 .978 r
.38796 .30951 .38899 .31015 .39067 .30972 .38964 .30896 Mtetra
.662 .817 .958 r
.38964 .30896 .39067 .30972 .39235 .30911 .39132 .30835 Mtetra
.662 .816 .957 r
.39132 .30835 .39235 .30911 .39403 .3085 .39301 .30774 Mtetra
.689 .822 .946 r
.39301 .30774 .39403 .3085 .39572 .30784 .3947 .30703 Mtetra
.742 .822 .914 r
.3947 .30703 .39572 .30784 .39741 .30701 .3964 .30608 Mtetra
.656 .776 .937 r
.3964 .30608 .39741 .30701 .3991 .30643 .39808 .30551 Mtetra
.177 .549 .93 r
.39808 .30551 .3991 .30643 .40076 .30649 .39973 .30596 Mtetra
.91 .51 .216 r
.39973 .30596 .40076 .30649 .40235 .30835 .40121 .31052 Mtetra
.957 .68 .47 r
.40121 .31052 .40235 .30835 .40383 .31321 .39494 .51442 Mtetra
.538 .308 .514 r
.39494 .51442 .40383 .31321 .39802 .5096 .39654 .51908 Mtetra
.514 .24 .437 r
.39654 .51908 .39802 .5096 .3998 .50973 .39833 .51902 Mtetra
.48 .21 .427 r
.39833 .51902 .3998 .50973 .40163 .50833 .40015 .51824 Mtetra
.48 .213 .432 r
.40015 .51824 .40163 .50833 .40335 .51006 .40196 .51739 Mtetra
.514 .227 .416 r
.40196 .51739 .40335 .51006 .40495 .51521 .40375 .51743 Mtetra
.46 .063 .198 r
.40375 .51743 .40495 .51521 .40665 .51767 .40554 .51745 Mtetra
.227 .733 .896 r
.40554 .51745 .40665 .51767 .4084 .51879 .40734 .51733 Mtetra
.618 .678 .885 r
.40734 .51733 .4084 .51879 .4102 .51865 .40915 .51689 Mtetra
.633 .643 .843 r
.40915 .51689 .4102 .51865 .41201 .51817 .41096 .51636 Mtetra
.638 .639 .834 r
.41096 .51636 .41201 .51817 .41383 .51756 .41278 .51579 Mtetra
.632 .641 .841 r
.41278 .51579 .41383 .51756 .41564 .51704 .41459 .51525 Mtetra
.636 .642 .839 r
.41459 .51525 .41564 .51704 .41746 .51646 .41641 .5147 Mtetra
.632 .643 .843 r
.41641 .5147 .41746 .51646 .41928 .51585 .41823 .51417 Mtetra
.576 .628 .867 r
.41823 .51417 .41928 .51585 .4211 .51536 .42004 .51393 Mtetra
.656 .699 .878 r
.42004 .51393 .4211 .51536 .42293 .51462 .42187 .5133 Mtetra
.785 .752 .823 r
.42187 .5133 .42293 .51462 .42477 .51333 .42372 .51177 Mtetra
.912 .731 .644 r
.42372 .51177 .42477 .51333 .42668 .5101 .42569 .50615 Mtetra
.961 .687 .471 r
.42569 .50615 .42668 .5101 .42866 .50409 .43351 .30071 Mtetra
.544 .317 .522 r
.43351 .30071 .42866 .50409 .43611 .30516 .43539 .29422 Mtetra
.581 .386 .583 r
.43539 .29422 .43611 .30516 .43789 .30211 .43712 .29298 Mtetra
.559 .378 .593 r
.43712 .29298 .43789 .30211 .4396 .30202 .43883 .29251 Mtetra
.542 .364 .589 r
.43883 .29251 .4396 .30202 .44125 .30373 .44053 .29242 Mtetra
.554 .365 .579 r
.44053 .29242 .44125 .30373 .44288 .30676 .44225 .29194 Mtetra
.55 .352 .565 r
.44225 .29194 .44288 .30676 .44456 .30784 .44396 .29141 Mtetra
.552 .35 .56 r
.44396 .29141 .44456 .30784 .44643 .3015 .44568 .29072 Mtetra
.578 .385 .583 r
.44568 .29072 .44643 .3015 .44832 .29406 .44741 .28958 Mtetra
.633 .484 .662 r
.44741 .28958 .44832 .29406 .45011 .29045 .44914 .28844 Mtetra
.695 .632 .782 r
.44914 .28844 .45011 .29045 .45187 .2882 .45087 .28742 Mtetra
.655 .817 .961 r
.45087 .28742 .45187 .2882 .45359 .28748 .45259 .28682 Mtetra
.613 .831 .984 r
.45259 .28682 .45359 .28748 .45531 .28712 .45431 .28632 Mtetra
.617 .798 .969 r
.45431 .28632 .45531 .28712 .45702 .28692 .45603 .28584 Mtetra
.667 .752 .914 r
.45603 .28584 .45702 .28692 .45874 .28637 .45776 .28521 Mtetra
.674 .74 .9 r
.45776 .28521 .45874 .28637 .46047 .28575 .45949 .28455 Mtetra
.678 .734 .893 r
.45949 .28455 .46047 .28575 .4622 .28505 .46121 .28386 Mtetra
.751 .756 .856 r
.46121 .28386 .4622 .28505 .46393 .28395 .46295 .28274 Mtetra
.697 .738 .883 r
.46295 .28274 .46393 .28395 .46567 .28306 .46468 .28195 Mtetra
.534 .696 .944 r
.46468 .28195 .46567 .28306 .46739 .2826 .4664 .28179 Mtetra
.841 .382 0 r
.4664 .28179 .46739 .2826 .46909 .28376 .46807 .28501 Mtetra
.964 .681 .447 r
.46807 .28501 .46909 .28376 .47076 .28696 .46619 .48802 Mtetra
.544 .313 .515 r
.46619 .48802 .47076 .28696 .46913 .48594 .46789 .49603 Mtetra
.55 .273 .449 r
.46789 .49603 .46913 .48594 .47083 .4942 .46972 .4969 Mtetra
.456 .082 .24 r
.46972 .4969 .47083 .4942 .47264 .49662 .47157 .4968 Mtetra
.305 .797 .785 r
.47157 .4968 .47264 .49662 .47447 .49759 .47342 .49622 Mtetra
.536 .662 .918 r
.47342 .49622 .47447 .49759 .47632 .49747 .47528 .49609 Mtetra
.642 .705 .892 r
.47528 .49609 .47632 .49747 .47818 .49674 .47714 .49552 Mtetra
.767 .77 .855 r
.47714 .49552 .47818 .49674 .48005 .49537 .47901 .49421 Mtetra
.928 .767 .661 r
.47901 .49421 .48005 .49537 .48194 .4927 .48093 .4893 Mtetra
.966 .687 .454 r
.48093 .4893 .48194 .4927 .48386 .48776 .48539 .2842 Mtetra
.547 .32 .522 r
.48539 .2842 .48386 .48776 .48808 .28735 .48723 .276 Mtetra
.6 .399 .581 r
.48723 .276 .48808 .28735 .48992 .27868 .48899 .27404 Mtetra
.623 .474 .659 r
.48899 .27404 .48992 .27868 .4917 .27536 .49074 .273 Mtetra
.634 .574 .77 r
.49074 .273 .4917 .27536 .49346 .27333 .49249 .27237 Mtetra
.665 .782 .936 r
.49249 .27237 .49346 .27333 .49521 .27249 .49423 .27175 Mtetra
.633 .82 .972 r
.49423 .27175 .49521 .27249 .49695 .27207 .49598 .2712 Mtetra
.63 .79 .959 r
.49598 .2712 .49695 .27207 .4987 .27179 .49773 .27068 Mtetra
.752 .774 .871 r
.49773 .27068 .4987 .27179 .50045 .27063 .49949 .26958 Mtetra
.714 .777 .901 r
.49949 .26958 .50045 .27063 .50221 .26967 .50124 .26872 Mtetra
.534 .735 .967 r
.50124 .26872 .50221 .26967 .50396 .26937 .50299 .26851 Mtetra
.836 .38 0 r
.50299 .26851 .50396 .26937 .50569 .27279 .50472 .2719 Mtetra
.969 .683 .43 r
.50472 .2719 .50569 .27279 .50627 .47973 .50524 .47812 Mtetra
.919 .54 .125 r
.50524 .47812 .50627 .47973 .50811 .48642 .50708 .48491 Mtetra
.318 .524 .898 r
.50708 .48491 .50811 .48642 .50999 .48685 .50896 .48546 Mtetra
.658 .712 .887 r
.50896 .48546 .50999 .48685 .51187 .48607 .51084 .4848 Mtetra
.74 .76 .869 r
.51084 .4848 .51187 .48607 .51376 .48481 .51273 .48368 Mtetra
.521 .707 .956 r
.51273 .48368 .51376 .48481 .51564 .48472 .51461 .48352 Mtetra
.572 .714 .938 r
.51461 .48352 .51564 .48472 .51752 .48454 .5165 .48322 Mtetra
.724 .748 .871 r
.5165 .48322 .51752 .48454 .51941 .48361 .51839 .48219 Mtetra
.918 .752 .66 r
.51839 .48219 .51941 .48361 .52131 .47872 .52028 .47733 Mtetra
.971 .689 .438 r
.52028 .47733 .52131 .47872 .5233 .27021 .52234 .26958 Mtetra
.97 .77 .578 r
.52234 .26958 .5233 .27021 .52507 .26271 .52411 .26193 Mtetra
.851 .849 .841 r
.52411 .26193 .52507 .26271 .52684 .26104 .52588 .26018 Mtetra
.642 .799 .958 r
.52588 .26018 .52684 .26104 .52861 .26059 .52765 .25962 Mtetra
.499 .716 .969 r
.52765 .25962 .52861 .26059 .53038 .2606 .52942 .2595 Mtetra
.706 .767 .9 r
.52942 .2595 .53038 .2606 .53215 .25995 .53119 .25867 Mtetra
.697 .731 .877 r
.53119 .25867 .53215 .25995 .53392 .2592 .53296 .25785 Mtetra
.576 .671 .903 r
.53296 .25785 .53392 .2592 .53569 .25879 .53474 .25759 Mtetra
.591 .13 0 r
.53474 .25759 .53569 .25879 .53747 .25962 .53652 .25997 Mtetra
.97 .68 .42 r
.53652 .25997 .53747 .25962 .53926 .26231 .53918 .46005 Mtetra
.551 .318 .515 r
.53918 .46005 .53926 .26231 .54205 .45444 .54113 .47212 Mtetra
.553 .295 .478 r
.54113 .47212 .54205 .45444 .54404 .46963 .54305 .47357 Mtetra
.485 .15 .323 r
.54305 .47357 .54404 .46963 .54596 .47246 .54496 .47351 Mtetra
.146 0 0 r
.54496 .47351 .54596 .47246 .54788 .47364 .54687 .47293 Mtetra
.439 .766 .997 r
.54687 .47293 .54788 .47364 .54979 .47405 .54878 .47279 Mtetra
.582 .707 .929 r
.54878 .47279 .54979 .47405 .55171 .47374 .55069 .47245 Mtetra
.728 .757 .875 r
.55069 .47245 .55171 .47374 .55361 .47257 .5526 .4714 Mtetra
.925 .782 .683 r
.5526 .4714 .55361 .47257 .55549 .46831 .55448 .46719 Mtetra
.973 .688 .426 r
.55448 .46719 .55549 .46831 .55537 .262 .55442 .26085 Mtetra
.963 .739 .552 r
.55442 .26085 .55537 .262 .55707 .25233 .55612 .25116 Mtetra
.853 .785 .784 r
.55612 .25116 .55707 .25233 .55884 .2502 .5579 .24902 Mtetra
.672 .744 .905 r
.5579 .24902 .55884 .2502 .56063 .24953 .55969 .24834 Mtetra
.551 .693 .933 r
.55969 .24834 .56063 .24953 .56242 .24933 .56148 .24813 Mtetra
.691 .746 .894 r
.56148 .24813 .56242 .24933 .56421 .24868 .56327 .24736 Mtetra
.704 .731 .871 r
.56327 .24736 .56421 .24868 .566 .24788 .56506 .24649 Mtetra
.596 .675 .896 r
.56506 .24649 .566 .24788 .5678 .24741 .56686 .24615 Mtetra
0 .027 .57 r
.56686 .24615 .5678 .24741 .56961 .24808 .56869 .24813 Mtetra
.972 .678 .406 r
.56869 .24813 .56961 .24808 .57146 .25055 .57334 .43941 Mtetra
.568 .331 .517 r
.57334 .43941 .57146 .25055 .5735 .26555 .57559 .46077 Mtetra
.532 .303 .513 r
.57559 .46077 .5735 .26555 .57847 .45832 .57756 .4626 Mtetra
.494 .166 .339 r
.57756 .4626 .57847 .45832 .58046 .46136 .5795 .46259 Mtetra
.21 0 0 r
.5795 .46259 .58046 .46136 .58242 .46263 .58143 .46204 Mtetra
.438 .794 .997 r
.58143 .46204 .58242 .46263 .58437 .46309 .58337 .46182 Mtetra
.568 .702 .932 r
.58337 .46182 .58437 .46309 .58631 .46284 .58531 .46153 Mtetra
.714 .751 .881 r
.58531 .46153 .58631 .46284 .58824 .46176 .58724 .46056 Mtetra
.915 .787 .705 r
.58724 .46056 .58824 .46176 .59012 .458 .58912 .45686 Mtetra
.975 .687 .413 r
.58912 .45686 .59012 .458 .5879 .25459 .58696 .25337 Mtetra
.97 .727 .512 r
.58696 .25337 .5879 .25459 .58945 .24123 .58852 .24005 Mtetra
.877 .787 .758 r
.58852 .24005 .58945 .24123 .59122 .2387 .59029 .23751 Mtetra
.69 .752 .899 r
.59029 .23751 .59122 .2387 .59302 .23793 .59209 .23674 Mtetra
.57 .704 .932 r
.59209 .23674 .59302 .23793 .59484 .23766 .59391 .23646 Mtetra
.685 .749 .9 r
.59391 .23646 .59484 .23766 .59665 .23691 .59572 .23571 Mtetra
.726 .762 .881 r
.59572 .23571 .59665 .23691 .59846 .23594 .59753 .23474 Mtetra
.611 .719 .922 r
.59753 .23474 .59846 .23594 .60028 .23552 .59935 .23431 Mtetra
0 .062 .598 r
.59935 .23431 .60028 .23552 .60216 .23743 .60123 .23621 Mtetra
.974 .678 .39 r
.60123 .23621 .60216 .23743 .60919 .43842 .6082 .43689 Mtetra
.955 .612 .246 r
.6082 .43689 .60919 .43842 .6115 .45197 .61052 .4508 Mtetra
0 .156 .671 r
.61052 .4508 .6115 .45197 .61352 .45364 .61253 .45248 Mtetra
.607 .743 .941 r
.61253 .45248 .61352 .45364 .61548 .45317 .61449 .45202 Mtetra
.729 .787 .899 r
.61449 .45202 .61548 .45317 .61742 .45213 .61644 .45099 Mtetra
.634 .758 .937 r
.61644 .45099 .61742 .45213 .61938 .45155 .6184 .45042 Mtetra
.539 .719 .956 r
.6184 .45042 .61938 .45155 .62135 .45132 .62037 .45019 Mtetra
.693 .781 .919 r
.62037 .45019 .62135 .45132 .6233 .45048 .62232 .44936 Mtetra
.911 .805 .73 r
.62232 .44936 .6233 .45048 .62518 .44721 .6242 .44609 Mtetra
.976 .685 .4 r
.6242 .44609 .62518 .44721 .62101 .25054 .62016 .25172 Mtetra
.992 .737 .417 r
.62016 .25172 .62101 .25054 .62221 .22984 .6213 .22867 Mtetra
.896 .792 .737 r
.6213 .22867 .62221 .22984 .62397 .22697 .62306 .22578 Mtetra
.703 .759 .895 r
.62306 .22578 .62397 .22697 .62579 .22613 .62488 .22494 Mtetra
.585 .712 .931 r
.62488 .22494 .62579 .22613 .62764 .22579 .62672 .2246 Mtetra
.666 .745 .909 r
.62672 .2246 .62764 .22579 .62947 .22513 .62856 .22394 Mtetra
.734 .767 .88 r
.62856 .22394 .62947 .22513 .63129 .22411 .63038 .22291 Mtetra
.636 .732 .917 r
.63038 .22291 .63129 .22411 .63313 .22358 .63222 .22238 Mtetra
0 .278 .777 r
.63222 .22238 .63313 .22358 .63504 .2249 .63413 .2237 Mtetra
.94 .577 .191 r
.63413 .2237 .63504 .2249 .63727 .23496 .63636 .23383 Mtetra
.975 .675 .374 r
.63636 .23383 .63727 .23496 .64679 .43954 .64582 .4384 Mtetra
0 0 .511 r
.64582 .4384 .64679 .43954 .64888 .4418 .64791 .44066 Mtetra
.626 .757 .941 r
.64791 .44066 .64888 .4418 .65086 .44126 .64989 .44012 Mtetra
.765 .803 .883 r
.64989 .44012 .65086 .44126 .65281 .43998 .65185 .43885 Mtetra
.775 .807 .879 r
.65185 .43885 .65281 .43998 .65476 .43862 .6538 .43752 Mtetra
.714 .795 .915 r
.6538 .43752 .65476 .43862 .65673 .43765 .65577 .43656 Mtetra
.702 .796 .924 r
.65577 .43656 .65673 .43765 .6587 .43674 .65774 .43568 Mtetra
.655 .785 .943 r
.65774 .43568 .6587 .43674 .66068 .43607 .65973 .43501 Mtetra
.589 .759 .959 r
.65973 .43501 .66068 .43607 .66268 .43568 .66172 .43459 Mtetra
.566 .743 .96 r
.66172 .43459 .66268 .43568 .66468 .43537 .66372 .43425 Mtetra
.469 .689 .963 r
.66372 .43425 .66468 .43537 .6667 .43537 .66574 .43422 Mtetra
.426 .661 .958 r
.66574 .43422 .6667 .43537 .66872 .43549 .66776 .43432 Mtetra
.633 .756 .936 r
.66776 .43432 .66872 .43549 .67072 .43492 .66976 .43374 Mtetra
.891 .81 .762 r
.66976 .43374 .67072 .43492 .67261 .43218 .67166 .43099 Mtetra
.981 .718 .457 r
.67166 .43099 .67261 .43218 .67374 .41279 .67276 .41093 Mtetra
.977 .681 .38 r
.67276 .41093 .67374 .41279 .66651 .2144 .66561 .21316 Mtetra
.909 .789 .716 r
.66561 .21316 .66651 .2144 .66825 .21116 .66735 .20993 Mtetra
.702 .755 .893 r
.66735 .20993 .66825 .21116 .6701 .2103 .6692 .20908 Mtetra
.578 .705 .929 r
.6692 .20908 .6701 .2103 .67197 .20998 .67108 .20877 Mtetra
.573 .704 .931 r
.67108 .20877 .67197 .20998 .67385 .20962 .67296 .20847 Mtetra
.671 .758 .916 r
.67296 .20847 .67385 .20962 .67571 .20881 .67483 .20777 Mtetra
.661 .78 .937 r
.67483 .20777 .67571 .20881 .67758 .20819 .67669 .20712 Mtetra
.664 .772 .93 r
.67669 .20712 .67758 .20819 .67947 .20813 .67856 .20645 Mtetra
.652 .663 .847 r
.67856 .20645 .67947 .20813 .68143 .20913 .68043 .2058 Mtetra
.563 .481 .721 r
.68043 .2058 .68143 .20913 .68347 .21175 .68232 .20562 Mtetra
.438 .326 .629 r
.68232 .20562 .68347 .21175 .69575 .40785 .68431 .20708 Mtetra
0 0 .401 r
.68431 .20708 .69575 .40785 .69851 .42135 .69651 .40041 Mtetra
0 0 .428 r
.69651 .40041 .69851 .42135 .70071 .42424 .69969 .42165 Mtetra
0 .157 .682 r
.69969 .42165 .70071 .42424 .70282 .42533 .70188 .42424 Mtetra
.395 .659 .965 r
.70188 .42424 .70282 .42533 .70487 .42535 .70394 .42439 Mtetra
.702 .826 .941 r
.70394 .42439 .70487 .42535 .70688 .42452 .70595 .42348 Mtetra
.896 .838 .78 r
.70595 .42348 .70688 .42452 .70879 .42201 .70786 .42087 Mtetra
.98 .756 .529 r
.70786 .42087 .70879 .42201 .7103 .41234 .70937 .41131 Mtetra
.978 .678 .362 r
.70937 .41131 .7103 .41234 .70025 .20351 .69937 .20231 Mtetra
.938 .791 .671 r
.69937 .20231 .70025 .20351 .70193 .19947 .70105 .19824 Mtetra
.732 .769 .882 r
.70105 .19824 .70193 .19947 .70379 .19844 .70292 .19721 Mtetra
.605 .718 .925 r
.70292 .19721 .70379 .19844 .70569 .19802 .70482 .19679 Mtetra
.604 .717 .925 r
.70482 .19679 .70569 .19802 .70759 .19761 .70672 .19638 Mtetra
.742 .771 .876 r
.70672 .19638 .70759 .19761 .70945 .19651 .70858 .19528 Mtetra
.66 .741 .91 r
.70858 .19528 .70945 .19651 .71134 .19586 .71047 .19462 Mtetra
.246 .518 .911 r
.71047 .19462 .71134 .19586 .71331 .1965 .71244 .19525 Mtetra
.875 .48 .019 r
.71244 .19525 .71331 .1965 .71569 .20351 .71481 .20222 Mtetra
.975 .667 .334 r
.71481 .20222 .71569 .20351 .73092 .41226 .72999 .41104 Mtetra
.643 .192 0 r
.72999 .41104 .73092 .41226 .73322 .41574 .73229 .41449 Mtetra
.51 .688 .947 r
.73229 .41449 .73322 .41574 .7353 .41576 .73437 .41438 Mtetra
.69 .745 .893 r
.73437 .41438 .7353 .41576 .73733 .41487 .73639 .4135 Mtetra
.732 .762 .876 r
.73639 .4135 .73733 .41487 .73931 .41326 .7384 .41238 Mtetra
.63 .822 .974 r
.7384 .41238 .73931 .41326 .74123 .41088 .74045 .41174 Mtetra
0 0 0 r
.74045 .41174 .74123 .41088 .74306 .40696 .74246 .41061 Mtetra
.177 0 .221 r
.74246 .41061 .74306 .40696 .74433 .39501 .74438 .40813 Mtetra
.097 0 .368 r
.74438 .40813 .74433 .39501 .73259 .19424 .74572 .39718 Mtetra
0 0 .396 r
.74572 .39718 .73259 .19424 .73424 .18998 .7335 .19047 Mtetra
.947 .921 .557 r
.7335 .19047 .73424 .18998 .73604 .1877 .73517 .18642 Mtetra
.739 .764 .873 r
.73517 .18642 .73604 .1877 .73792 .18678 .73705 .18532 Mtetra
.628 .689 .888 r
.73705 .18532 .73792 .18678 .73984 .18622 .73897 .18481 Mtetra
.602 .684 .9 r
.73897 .18481 .73984 .18622 .74176 .18569 .74089 .18441 Mtetra
.75 .768 .867 r
.74089 .18441 .74176 .18569 .74363 .18451 .74277 .18323 Mtetra
.677 .742 .9 r
.74277 .18323 .74363 .18451 .74554 .18376 .74467 .18249 Mtetra
.387 .597 .929 r
.74467 .18249 .74554 .18376 .74752 .18406 .74666 .18279 Mtetra
.817 .408 0 r
.74666 .18279 .74752 .18406 .74992 .1899 .74906 .18858 Mtetra
.973 .662 .315 r
.74906 .18858 .74992 .1899 .76771 .39986 .7668 .39861 Mtetra
.691 .252 0 r
.7668 .39861 .76771 .39986 .77013 .40397 .76922 .40272 Mtetra
.482 .675 .95 r
.76922 .40272 .77013 .40397 .77226 .40408 .77134 .40269 Mtetra
.681 .743 .898 r
.77134 .40269 .77226 .40408 .77431 .40326 .77339 .40187 Mtetra
.742 .764 .871 r
.77339 .40187 .77431 .40326 .77631 .40169 .77542 .40066 Mtetra
.631 .791 .959 r
.77542 .40066 .77631 .40169 .77825 .3994 .77749 .40004 Mtetra
0 0 0 r
.77749 .40004 .77825 .3994 .78007 .39566 .77953 .39896 Mtetra
.198 0 .208 r
.77953 .39896 .78007 .39566 .78143 .38605 .78148 .39681 Mtetra
.103 0 .36 r
.78148 .39681 .78143 .38605 .76714 .18252 .78288 .38771 Mtetra
0 0 .407 r
.78288 .38771 .76714 .18252 .76875 .17794 .76807 .17879 Mtetra
.902 .881 .452 r
.76807 .17879 .76875 .17794 .77053 .17546 .76968 .17421 Mtetra
.754 .777 .872 r
.76968 .17421 .77053 .17546 .77244 .17447 .77157 .17302 Mtetra
.637 .695 .888 r
.77157 .17302 .77244 .17447 .77437 .17388 .77351 .17245 Mtetra
.579 .673 .903 r
.77351 .17245 .77437 .17388 .77632 .17343 .77548 .17215 Mtetra
.754 .773 .869 r
.77548 .17215 .77632 .17343 .77821 .17222 .77737 .17094 Mtetra
.686 .75 .9 r
.77737 .17094 .77821 .17222 .78013 .17141 .77929 .17014 Mtetra
.479 .653 .936 r
.77929 .17014 .78013 .17141 .78213 .17141 .78129 .17016 Mtetra
.757 .339 0 r
.78129 .17016 .78213 .17141 .78456 .17642 .78372 .17521 Mtetra
.971 .656 .295 r
.78372 .17521 .78456 .17642 .80496 .38731 .80408 .38613 Mtetra
.739 .304 0 r
.80408 .38613 .80496 .38731 .80753 .39214 .80664 .39093 Mtetra
.297 .576 .937 r
.80664 .39093 .80753 .39214 .80972 .39263 .80884 .39142 Mtetra
.647 .764 .934 r
.80884 .39142 .80972 .39263 .81182 .39197 .81093 .39075 Mtetra
.828 .822 .843 r
.81093 .39075 .81182 .39197 .81381 .39015 .81292 .38893 Mtetra
.908 .737 .657 r
.14562 .59845 .1468 .5994 .14902 .59364 .14784 .5927 Mtetra
.936 .686 .535 r
.14784 .5927 .14902 .59364 .17271 .39182 .17162 .39082 Mtetra
.908 .728 .647 r
.17162 .39082 .17271 .39182 .17486 .38585 .17376 .38484 Mtetra
.773 .76 .842 r
.17376 .38484 .17486 .38585 .17648 .38465 .17539 .38364 Mtetra
.638 .737 .92 r
.17539 .38364 .17648 .38465 .17802 .38419 .17693 .38319 Mtetra
.505 .692 .952 r
.17693 .38319 .17802 .38419 .17952 .38411 .17843 .3831 Mtetra
.751 .76 .86 r
.17843 .3831 .17952 .38411 .18112 .38309 .18003 .38208 Mtetra
.696 .751 .894 r
.18003 .38208 .18112 .38309 .18269 .38238 .1816 .38138 Mtetra
.469 .677 .956 r
.1816 .38138 .18269 .38238 .18419 .38235 .1831 .38137 Mtetra
.931 .56 .281 r
.1831 .38137 .18419 .38235 .18526 .38643 .18413 .38577 Mtetra
.938 .682 .523 r
.18413 .38577 .18526 .38643 .1656 .58723 .16435 .58702 Mtetra
.905 .551 .359 r
.16435 .58702 .1656 .58723 .16663 .59271 .16541 .5921 Mtetra
.182 .639 .939 r
.16541 .5921 .16663 .59271 .16819 .59301 .16699 .5923 Mtetra
.697 .826 .944 r
.16699 .5923 .16819 .59301 .16986 .59237 .16867 .59156 Mtetra
.774 .809 .881 r
.16867 .59156 .16986 .59237 .17157 .59131 .1704 .59039 Mtetra
.495 .723 .974 r
.1704 .59039 .17157 .59131 .17319 .59124 .17202 .59028 Mtetra
.59 .748 .953 r
.17202 .59028 .17319 .59124 .17483 .5909 .17366 .58994 Mtetra
.751 .78 .877 r
.17366 .58994 .17483 .5909 .17654 .58984 .17537 .58888 Mtetra
.907 .743 .666 r
.17537 .58888 .17654 .58984 .17868 .5846 .17752 .58364 Mtetra
.939 .687 .529 r
.17752 .58364 .17868 .5846 .20072 .38258 .19964 .38155 Mtetra
.913 .727 .638 r
.19964 .38155 .20072 .38258 .20289 .37613 .2018 .3751 Mtetra
.791 .76 .826 r
.2018 .3751 .20289 .37613 .20454 .37474 .20345 .37371 Mtetra
.623 .73 .923 r
.20345 .37371 .20454 .37474 .20609 .37434 .20501 .37331 Mtetra
.457 .668 .954 r
.20501 .37331 .20609 .37434 .2076 .37436 .20652 .37333 Mtetra
.609 .727 .929 r
.20652 .37333 .2076 .37436 .20915 .37399 .20807 .37297 Mtetra
.639 .739 .921 r
.20807 .37297 .20915 .37399 .21072 .3735 .20963 .37251 Mtetra
.65 .745 .919 r
.20963 .37251 .21072 .3735 .21229 .37298 .2112 .372 Mtetra
.671 .754 .913 r
.2112 .372 .21229 .37298 .21387 .3723 .21278 .37141 Mtetra
.685 .776 .92 r
.21278 .37141 .21387 .3723 .21546 .37162 .21436 .37077 Mtetra
.695 .787 .922 r
.21436 .37077 .21546 .37162 .21704 .37101 .21595 .37008 Mtetra
.764 .779 .865 r
.21595 .37008 .21704 .37101 .21862 .37034 .21758 .36899 Mtetra
.713 .7 .836 r
.21758 .36899 .21862 .37034 .22018 .37 .21919 .36809 Mtetra
.606 .589 .808 r
.21919 .36809 .22018 .37 .22167 .37039 .22074 .36774 Mtetra
0 .021 .584 r
.22074 .36774 .22167 .37039 .22272 .37537 .22207 .36991 Mtetra
.987 .716 .366 r
.22207 .36991 .22272 .37537 .20542 .57566 .22204 .38642 Mtetra
0 0 .139 r
.22204 .38642 .20542 .57566 .20663 .58013 .20579 .57578 Mtetra
.397 .33 .665 r
.20579 .57578 .20663 .58013 .20822 .58066 .20732 .57691 Mtetra
.601 .486 .694 r
.20732 .57691 .20822 .58066 .2099 .58014 .209 .57636 Mtetra
.65 .517 .687 r
.209 .57636 .2099 .58014 .21162 .57923 .21074 .57522 Mtetra
.628 .496 .682 r
.21074 .57522 .21162 .57923 .21331 .57862 .21246 .57431 Mtetra
.604 .472 .674 r
.21246 .57431 .21331 .57862 .21499 .57814 .21416 .57365 Mtetra
.577 .449 .67 r
.21416 .57365 .21499 .57814 .21667 .57764 .21583 .57328 Mtetra
.487 .392 .673 r
.21583 .57328 .21667 .57764 .21836 .57714 .21742 .57377 Mtetra
.441 .4 .717 r
.21742 .57377 .21836 .57714 .22005 .57659 .219 .57442 Mtetra
.426 .481 .814 r
.219 .57442 .22005 .57659 .22175 .57594 .22061 .57485 Mtetra
.508 .692 .951 r
.22061 .57485 .22175 .57594 .22347 .57501 .22226 .57475 Mtetra
.462 .853 .977 r
.22226 .57475 .22347 .57501 .22522 .57392 .22394 .57437 Mtetra
0 0 0 r
.22394 .57437 .22522 .57392 .22696 .5728 .22563 .57386 Mtetra
.24 0 0 r
.22563 .57386 .22696 .5728 .22863 .57247 .2273 .57356 Mtetra
.178 0 0 r
.2273 .57356 .22863 .57247 .23031 .57221 .22899 .57313 Mtetra
0 0 0 r
.22899 .57313 .23031 .57221 .23203 .5713 .23072 .57218 Mtetra
.93 .971 .719 r
.23072 .57218 .23203 .5713 .23409 .56662 .23263 .56922 Mtetra
.994 .868 .544 r
.23263 .56922 .23409 .56662 .25297 .36462 .23498 .56112 Mtetra
0 0 .137 r
.23498 .56112 .25297 .36462 .25509 .35792 .25371 .36064 Mtetra
.644 .785 .329 r
.25371 .36064 .25509 .35792 .2568 .35607 .25558 .35693 Mtetra
.679 .949 .689 r
.25558 .35693 .2568 .35607 .2584 .3555 .25727 .35528 Mtetra
.758 .936 .943 r
.25727 .35528 .2584 .3555 .25997 .35536 .25891 .35426 Mtetra
.681 .739 .894 r
.25891 .35426 .25997 .35536 .26155 .35503 .26052 .35361 Mtetra
.625 .664 .868 r
.26052 .35361 .26155 .35503 .26314 .35455 .26211 .35319 Mtetra
.595 .663 .886 r
.26211 .35319 .26314 .35455 .26474 .35404 .26369 .3529 Mtetra
.625 .713 .909 r
.26369 .3529 .26474 .35404 .26635 .35346 .26528 .35248 Mtetra
.653 .754 .924 r
.26528 .35248 .26635 .35346 .26796 .35283 .26689 .35195 Mtetra
.662 .778 .935 r
.26689 .35195 .26796 .35283 .26957 .35218 .26849 .35139 Mtetra
.667 .798 .945 r
.26849 .35139 .26957 .35218 .27119 .35149 .2701 .35079 Mtetra
.671 .823 .956 r
.2701 .35079 .27119 .35149 .27281 .35081 .27172 .35017 Mtetra
.676 .838 .961 r
.27172 .35017 .27281 .35081 .27442 .35023 .27333 .34953 Mtetra
.753 .833 .913 r
.27333 .34953 .27442 .35023 .27603 .34965 .27498 .34856 Mtetra
.732 .752 .868 r
.27498 .34856 .27603 .34965 .27762 .34931 .27662 .34763 Mtetra
.628 .628 .831 r
.27662 .34763 .27762 .34931 .27917 .3496 .27822 .34717 Mtetra
.101 .236 .718 r
.27822 .34717 .27917 .3496 .28048 .35297 .27968 .34864 Mtetra
.865 .593 .063 r
.27968 .34864 .28048 .35297 .26665 .55436 .28066 .3563 Mtetra
0 0 .18 r
.28066 .3563 .26665 .55436 .26789 .56021 .26704 .55538 Mtetra
.28 .236 .63 r
.26704 .55538 .26789 .56021 .26948 .56136 .26857 .55742 Mtetra
.591 .475 .689 r
.26857 .55742 .26948 .56136 .27119 .56101 .27028 .55695 Mtetra
.628 .496 .681 r
.27028 .55695 .27119 .56101 .27293 .5602 .27204 .55601 Mtetra
.546 .438 .682 r
.27204 .55601 .27293 .5602 .27467 .5595 .27372 .55598 Mtetra
.456 .404 .711 r
.27372 .55598 .27467 .5595 .27639 .55894 .27536 .55657 Mtetra
.45 .478 .796 r
.27536 .55657 .27639 .55894 .27813 .55827 .27702 .55697 Mtetra
.444 .623 .928 r
.27702 .55697 .27813 .55827 .27986 .55764 .2787 .55709 Mtetra
.48 .809 1 r
.2787 .55709 .27986 .55764 .28161 .55684 .28041 .55683 Mtetra
.617 .946 .941 r
.28041 .55683 .28161 .55684 .2834 .55543 .28216 .55599 Mtetra
.919 .976 .76 r
.28216 .55599 .2834 .55543 .28539 .55129 .28404 .5534 Mtetra
.993 .874 .552 r
.28404 .5534 .28539 .55129 .30133 .34912 .28625 .54614 Mtetra
0 0 .17 r
.28625 .54614 .30133 .34912 .30349 .34106 .30215 .3441 Mtetra
0 0 0 r
.30215 .3441 .30349 .34106 .30524 .33871 .30401 .34033 Mtetra
.144 0 0 r
.30401 .34033 .30524 .33871 .30688 .33795 .30566 .33948 Mtetra
.38 0 .077 r
.30566 .33948 .30688 .33795 .30849 .33764 .30726 .33932 Mtetra
.375 0 .099 r
.30726 .33932 .30849 .33764 .31011 .33728 .30887 .33909 Mtetra
.293 0 .07 r
.30887 .33909 .31011 .33728 .31174 .33672 .3105 .33854 Mtetra
.297 0 .075 r
.3105 .33854 .31174 .33672 .31337 .33617 .31213 .338 Mtetra
.296 0 .077 r
.31213 .338 .31337 .33617 .31501 .3356 .31377 .33745 Mtetra
.293 0 .077 r
.31377 .33745 .31501 .3356 .31664 .33503 .31541 .33688 Mtetra
.292 0 .078 r
.31541 .33688 .31664 .33503 .31828 .33445 .31704 .33631 Mtetra
.31704 .33631 .31828 .33445 .31992 .33387 .31868 .33573 Mtetra
.292 0 .079 r
.31868 .33573 .31992 .33387 .32155 .33329 .32032 .33515 Mtetra
.32032 .33515 .32155 .33329 .32319 .33271 .32197 .33457 Mtetra
.291 0 .079 r
.32197 .33457 .32319 .33271 .32484 .33213 .32361 .33399 Mtetra
.32361 .33399 .32484 .33213 .32648 .33154 .32525 .33341 Mtetra
.29 0 .079 r
.32525 .33341 .32648 .33154 .32812 .33096 .3269 .33282 Mtetra
.289 0 .078 r
.3269 .33282 .32812 .33096 .32976 .33037 .32855 .33223 Mtetra
.288 0 .077 r
.32855 .33223 .32976 .33037 .33141 .32978 .33019 .33164 Mtetra
.286 0 .075 r
.33019 .33164 .33141 .32978 .33306 .32919 .33184 .33104 Mtetra
.281 0 .071 r
.33184 .33104 .33306 .32919 .3347 .32859 .33349 .33042 Mtetra
.275 0 .067 r
.33349 .33042 .3347 .32859 .33635 .32798 .33515 .3298 Mtetra
.276 0 .064 r
.33515 .3298 .33635 .32798 .338 .32738 .3368 .32918 Mtetra
.179 0 .007 r
.3368 .32918 .338 .32738 .33966 .3266 .33847 .3283 Mtetra
.091 0 0 r
.33847 .3283 .33966 .3266 .34133 .32573 .34015 .32726 Mtetra
.313 0 .035 r
.34015 .32726 .34133 .32573 .34298 .32528 .34179 .32688 Mtetra
.731 .342 .314 r
.34179 .32688 .34298 .32528 .34454 .32631 .34329 .32905 Mtetra
.951 .68 .487 r
.34329 .32905 .34454 .32631 .34579 .33287 .33342 .53023 Mtetra
.542 .312 .515 r
.33342 .53023 .34579 .33287 .33604 .53502 .33476 .53712 Mtetra
.675 .291 .311 r
.33476 .53712 .33604 .53502 .33761 .53808 .3364 .53885 Mtetra
.219 0 0 r
.3364 .53885 .33761 .53808 .33935 .5379 .33815 .53866 Mtetra
0 0 0 r
.33815 .53866 .33935 .5379 .34114 .53703 .33992 .53799 Mtetra
.33992 .53799 .34114 .53703 .34293 .53603 .3417 .53724 Mtetra
.17 0 0 r
.3417 .53724 .34293 .53603 .3447 .53537 .34347 .53669 Mtetra
.181 0 0 r
.34347 .53669 .3447 .53537 .34648 .53479 .34525 .53609 Mtetra
.174 0 0 r
.34525 .53609 .34648 .53479 .34823 .5345 .34702 .53549 Mtetra
.081 0 0 r
.34702 .53549 .34823 .5345 .34998 .53453 .3488 .5349 Mtetra
.332 .806 .734 r
.3488 .5349 .34998 .53453 .35172 .53455 .35059 .53418 Mtetra
.739 .921 .953 r
.35059 .53418 .35172 .53455 .35348 .53439 .35239 .53315 Mtetra
.79 .759 .825 r
.35239 .53315 .35348 .53439 .35525 .53395 .35422 .53162 Mtetra
.744 .636 .741 r
.35422 .53162 .35525 .53395 .35703 .53341 .35605 .52988 Mtetra
.666 .537 .698 r
.35605 .52988 .35703 .53341 .3588 .53297 .35787 .5286 Mtetra
.559 .443 .678 r
.35787 .5286 .3588 .53297 .36057 .5327 .35963 .52843 Mtetra
.597 .471 .679 r
.35963 .52843 .36057 .5327 .36236 .53199 .36142 .52783 Mtetra
.728 .557 .66 r
.36142 .52783 .36236 .53199 .36421 .52998 .3633 .52509 Mtetra
.954 .685 .489 r
.3633 .52509 .36421 .52998 .36628 .52343 .37467 .32374 Mtetra
.55 .323 .523 r
.37467 .32374 .36628 .52343 .37763 .31887 .37678 .31412 Mtetra
.719 .536 .641 r
.37678 .31412 .37763 .31887 .37951 .31378 .37856 .31119 Mtetra
.65 .563 .744 r
.37856 .31119 .37951 .31378 .38123 .31224 .38025 .31039 Mtetra
.599 .6 .824 r
.38025 .31039 .38123 .31224 .38292 .31135 .38192 .31006 Mtetra
.589 .679 .903 r
.38192 .31006 .38292 .31135 .3846 .31072 .38358 .30977 Mtetra
.703 .782 .913 r
.38358 .30977 .3846 .31072 .38628 .31007 .38527 .309 Mtetra
.682 .753 .905 r
.38527 .309 .38628 .31007 .38796 .30951 .38695 .30832 Mtetra
.612 .707 .912 r
.38695 .30832 .38796 .30951 .38964 .30896 .38863 .30793 Mtetra
.36 .627 .954 r
.38863 .30793 .38964 .30896 .39132 .30835 .39027 .30814 Mtetra
.231 0 0 r
.39027 .30814 .39132 .30835 .39301 .30774 .39191 .30859 Mtetra
.417 0 0 r
.39191 .30859 .39301 .30774 .3947 .30703 .39357 .30879 Mtetra
.144 0 0 r
.39357 .30879 .3947 .30703 .3964 .30608 .39527 .30781 Mtetra
.262 0 .042 r
.39527 .30781 .3964 .30608 .39808 .30551 .39696 .30718 Mtetra
.61 .196 .233 r
.39696 .30718 .39808 .30551 .39973 .30596 .39859 .30815 Mtetra
.957 .68 .47 r
.39859 .30815 .39973 .30596 .40121 .31052 .39236 .50648 Mtetra
.55 .318 .516 r
.39236 .50648 .40121 .31052 .39494 .51442 .3937 .51753 Mtetra
.691 .338 .372 r
.3937 .51753 .39494 .51442 .39654 .51908 .39539 .51998 Mtetra
.313 0 0 r
.39539 .51998 .39654 .51908 .39833 .51902 .39717 .51992 Mtetra
.04 0 0 r
.39717 .51992 .39833 .51902 .40015 .51824 .39899 .5193 Mtetra
0 0 0 r
.39899 .5193 .40015 .51824 .40196 .51739 .40081 .51847 Mtetra
.135 0 0 r
.40081 .51847 .40196 .51739 .40375 .51743 .40262 .51791 Mtetra
0 0 0 r
.40262 .51791 .40375 .51743 .40554 .51745 .40443 .5172 Mtetra
.695 .942 .961 r
.40443 .5172 .40554 .51745 .40734 .51733 .40626 .51625 Mtetra
.798 .79 .845 r
.40626 .51625 .40734 .51733 .40915 .51689 .40811 .51474 Mtetra
.753 .655 .754 r
.40811 .51474 .40915 .51689 .41096 .51636 .40996 .51301 Mtetra
.697 .564 .7 r
.40996 .51301 .41096 .51636 .41278 .51579 .41182 .51135 Mtetra
.607 .474 .674 r
.41182 .51135 .41278 .51579 .41459 .51525 .41364 .5106 Mtetra
.582 .452 .669 r
.41364 .5106 .41459 .51525 .41641 .5147 .41545 .51014 Mtetra
.567 .445 .673 r
.41545 .51014 .41641 .5147 .41823 .51417 .41726 .50986 Mtetra
.539 .433 .682 r
.41726 .50986 .41823 .51417 .42004 .51393 .41906 .5099 Mtetra
.595 .478 .69 r
.41906 .5099 .42004 .51393 .42187 .5133 .42088 .50935 Mtetra
.696 .544 .676 r
.42088 .50935 .42187 .5133 .42372 .51177 .42275 .5074 Mtetra
.91 .662 .551 r
.42275 .5074 .42372 .51177 .42569 .50615 .42509 .48981 Mtetra
.946 .67 .485 r
.42509 .48981 .42569 .50615 .43351 .30071 .43264 .29515 Mtetra
.728 .53 .623 r
.43264 .29515 .43351 .30071 .43539 .29422 .43445 .29142 Mtetra
.667 .561 .727 r
.43445 .29142 .43539 .29422 .43712 .29298 .43617 .29037 Mtetra
.614 .544 .752 r
.43617 .29037 .43712 .29298 .43883 .29251 .43788 .28987 Mtetra
.58 .522 .755 r
.43788 .28987 .43883 .29251 .44053 .29242 .43959 .28961 Mtetra
.62 .535 .737 r
.43959 .28961 .44053 .29242 .44225 .29194 .4413 .28901 Mtetra
.615 .526 .73 r
.4413 .28901 .44225 .29194 .44396 .29141 .44302 .28844 Mtetra
.611 .521 .729 r
.44302 .28844 .44396 .29141 .44568 .29072 .44473 .28791 Mtetra
.605 .526 .739 r
.44473 .28791 .44568 .29072 .44741 .28958 .44645 .28743 Mtetra
.617 .581 .791 r
.44645 .28743 .44741 .28958 .44914 .28844 .44816 .28697 Mtetra
.631 .669 .868 r
.44816 .28697 .44914 .28844 .45087 .28742 .44988 .28649 Mtetra
.647 .777 .943 r
.44988 .28649 .45087 .28742 .45259 .28682 .4516 .28593 Mtetra
.659 .792 .946 r
.4516 .28593 .45259 .28682 .45431 .28632 .45332 .28533 Mtetra
.674 .775 .926 r
.45332 .28533 .45431 .28632 .45603 .28584 .45505 .28468 Mtetra
.714 .751 .881 r
.45505 .28468 .45603 .28584 .45776 .28521 .45678 .28381 Mtetra
.691 .703 .857 r
.45678 .28381 .45776 .28521 .45949 .28455 .45851 .28301 Mtetra
.655 .67 .853 r
.45851 .28301 .45949 .28455 .46121 .28386 .46024 .2824 Mtetra
.591 .655 .882 r
.46024 .2824 .46121 .28386 .46295 .28274 .46196 .2821 Mtetra
.228 .652 .957 r
.46196 .2821 .46295 .28274 .46468 .28195 .46367 .28229 Mtetra
.639 .11 0 r
.46367 .28229 .46468 .28195 .4664 .28179 .46537 .28348 Mtetra
.918 .594 .414 r
.46537 .28348 .4664 .28179 .46807 .28501 .46684 .29684 Mtetra
.951 .665 .462 r
.46684 .29684 .46807 .28501 .46619 .48802 .46502 .49383 Mtetra
.665 .349 .429 r
.46502 .49383 .46619 .48802 .46789 .49603 .4668 .49696 Mtetra
.306 0 0 r
.4668 .49696 .46789 .49603 .46972 .4969 .46865 .49687 Mtetra
.537 .921 .92 r
.46865 .49687 .46972 .4969 .47157 .4968 .47051 .49609 Mtetra
.758 .867 .928 r
.47051 .49609 .47157 .4968 .47342 .49622 .47238 .49498 Mtetra
.487 .665 .941 r
.47238 .49498 .47342 .49622 .47528 .49609 .47423 .49496 Mtetra
.587 .733 .944 r
.47423 .49496 .47528 .49609 .47714 .49552 .47609 .4946 Mtetra
.76 .824 .902 r
.47609 .4946 .47714 .49552 .47901 .49421 .47796 .49345 Mtetra
.955 .782 .628 r
.47796 .49345 .47901 .49421 .48093 .4893 .47989 .48744 Mtetra
.967 .689 .452 r
.47989 .48744 .48093 .4893 .48539 .2842 .48446 .27918 Mtetra
.802 .585 .608 r
.48446 .27918 .48539 .2842 .48723 .276 .48628 .27314 Mtetra
.689 .573 .719 r
.48628 .27314 .48723 .276 .48899 .27404 .48803 .27182 Mtetra
.611 .574 .788 r
.48803 .27182 .48899 .27404 .49074 .273 .48977 .27138 Mtetra
.528 .601 .871 r
.48977 .27138 .49074 .273 .49249 .27237 .49151 .27135 Mtetra
.663 .766 .926 r
.49151 .27135 .49249 .27237 .49423 .27175 .49326 .27072 Mtetra
.67 .77 .925 r
.49326 .27072 .49423 .27175 .49598 .2712 .49501 .27007 Mtetra
.64 .739 .92 r
.49501 .27007 .49598 .2712 .49773 .27068 .49676 .26955 Mtetra
.602 .722 .929 r
.49676 .26955 .49773 .27068 .49949 .26958 .49851 .26917 Mtetra
.241 .71 .944 r
.49851 .26917 .49949 .26958 .50124 .26872 .50026 .26918 Mtetra
.553 .011 0 r
.50026 .26918 .50124 .26872 .50299 .26851 .502 .27 Mtetra
.875 .514 .361 r
.502 .27 .50299 .26851 .50472 .2719 .50371 .2766 Mtetra
.963 .675 .44 r
.50371 .2766 .50472 .2719 .50524 .47812 .50419 .47986 Mtetra
.8 .413 .321 r
.50419 .47986 .50524 .47812 .50708 .48491 .50605 .48377 Mtetra
.28 .576 .939 r
.50605 .48377 .50708 .48491 .50896 .48546 .50792 .48419 Mtetra
.637 .727 .913 r
.50792 .48419 .50896 .48546 .51084 .4848 .50981 .48364 Mtetra
.737 .777 .885 r
.50981 .48364 .51084 .4848 .51273 .48368 .51169 .48257 Mtetra
.717 .781 .902 r
.51169 .48257 .51273 .48368 .51461 .48352 .51358 .48163 Mtetra
.73 .674 .796 r
.51358 .48163 .51461 .48352 .5165 .48322 .51547 .48032 Mtetra
.749 .613 .708 r
.51547 .48032 .5165 .48322 .51839 .48219 .51736 .47812 Mtetra
.863 .639 .597 r
.51736 .47812 .51839 .48219 .52028 .47733 .51926 .47012 Mtetra
.965 .682 .447 r
.51926 .47012 .52028 .47733 .52234 .26958 .52138 .26556 Mtetra
.804 .602 .628 r
.52138 .26556 .52234 .26958 .52411 .26193 .52315 .2608 Mtetra
.803 .782 .834 r
.52315 .2608 .52411 .26193 .52588 .26018 .52492 .25928 Mtetra
.658 .795 .948 r
.52492 .25928 .52588 .26018 .52765 .25962 .52669 .25866 Mtetra
.553 .744 .965 r
.52669 .25866 .52765 .25962 .52942 .2595 .52846 .25839 Mtetra
.728 .773 .889 r
.52846 .25839 .52942 .2595 .53119 .25867 .53024 .25744 Mtetra
.706 .745 .882 r
.53024 .25744 .53119 .25867 .53296 .25785 .53201 .25659 Mtetra
.557 .679 .92 r
.53201 .25659 .53296 .25785 .53474 .25759 .53378 .25638 Mtetra
.759 .311 0 r
.53378 .25638 .53474 .25759 .53652 .25997 .53557 .25964 Mtetra
.971 .681 .419 r
.53557 .25964 .53652 .25997 .53918 .46005 .53819 .46655 Mtetra
.747 .429 .445 r
.53819 .46655 .53918 .46005 .54113 .47212 .54013 .47316 Mtetra
.541 .051 .042 r
.54013 .47316 .54113 .47212 .54305 .47357 .54204 .47387 Mtetra
.287 .776 .714 r
.54204 .47387 .54305 .47357 .54496 .47351 .54394 .47317 Mtetra
.749 .949 .944 r
.54394 .47317 .54496 .47351 .54687 .47293 .54585 .472 Mtetra
.548 .762 .976 r
.54585 .472 .54687 .47293 .54878 .47279 .54776 .47169 Mtetra
.54 .724 .958 r
.54776 .47169 .54878 .47279 .55069 .47245 .54968 .47146 Mtetra
.707 .805 .926 r
.54968 .47146 .55069 .47245 .5526 .4714 .55159 .47057 Mtetra
.94 .816 .694 r
.55159 .47057 .5526 .4714 .55448 .46719 .55347 .46656 Mtetra
.973 .689 .425 r
.55347 .46656 .55448 .46719 .55442 .26085 .55349 .26108 Mtetra
.992 .775 .508 r
.55349 .26108 .55442 .26085 .55612 .25116 .55518 .25006 Mtetra
.862 .794 .783 r
.55518 .25006 .55612 .25116 .5579 .24902 .55695 .24784 Mtetra
.676 .746 .903 r
.55695 .24784 .5579 .24902 .55969 .24834 .55874 .24715 Mtetra
.553 .693 .932 r
.55874 .24715 .55969 .24834 .56148 .24813 .56054 .24693 Mtetra
.702 .75 .889 r
.56054 .24693 .56148 .24813 .56327 .24736 .56233 .2461 Mtetra
.714 .743 .875 r
.56233 .2461 .56327 .24736 .56506 .24649 .56412 .24519 Mtetra
.582 .685 .911 r
.56412 .24519 .56506 .24649 .56686 .24615 .56592 .24489 Mtetra
.621 .17 0 r
.56592 .24489 .56686 .24615 .56869 .24813 .56776 .24757 Mtetra
.973 .679 .406 r
.56776 .24757 .56869 .24813 .57334 .43941 .57257 .45402 Mtetra
.677 .392 .482 r
.57257 .45402 .57334 .43941 .57559 .46077 .57463 .46188 Mtetra
.601 .123 .09 r
.57463 .46188 .57559 .46077 .57756 .4626 .57658 .46294 Mtetra
0 0 0 r
.57658 .46294 .57756 .4626 .5795 .46259 .57851 .4623 Mtetra
.733 .957 .945 r
.57851 .4623 .5795 .46259 .58143 .46204 .58044 .46114 Mtetra
.589 .789 .975 r
.58044 .46114 .58143 .46204 .58337 .46182 .58237 .46069 Mtetra
.529 .715 .958 r
.58237 .46069 .58337 .46182 .58531 .46153 .58432 .4605 Mtetra
.69 .796 .931 r
.58432 .4605 .58531 .46153 .58724 .46056 .58625 .45969 Mtetra
.931 .826 .719 r
.58625 .45969 .58724 .46056 .58912 .45686 .58813 .45618 Mtetra
.975 .687 .412 r
.58813 .45618 .58912 .45686 .58696 .25337 .58612 .25701 Mtetra
.981 .769 .357 r
.58612 .25701 .58696 .25337 .58852 .24005 .58759 .23895 Mtetra
.887 .799 .756 r
.58759 .23895 .58852 .24005 .59029 .23751 .58936 .23633 Mtetra
.692 .753 .898 r
.58936 .23633 .59029 .23751 .59209 .23674 .59116 .23555 Mtetra
.57 .703 .931 r
.59116 .23555 .59209 .23674 .59391 .23646 .59299 .23527 Mtetra
.685 .749 .9 r
.59299 .23527 .59391 .23646 .59572 .23571 .5948 .23452 Mtetra
.727 .763 .881 r
.5948 .23452 .59572 .23571 .59753 .23474 .5966 .23354 Mtetra
.612 .72 .923 r
.5966 .23354 .59753 .23474 .59935 .23431 .59842 .23311 Mtetra
0 .063 .599 r
.59842 .23311 .59935 .23431 .60123 .23621 .6003 .235 Mtetra
.974 .678 .39 r
.6003 .235 .60123 .23621 .6082 .43689 .60721 .43554 Mtetra
.956 .612 .257 r
.60721 .43554 .6082 .43689 .61052 .4508 .60953 .44964 Mtetra
0 .151 .665 r
.60953 .44964 .61052 .4508 .61253 .45248 .61155 .45133 Mtetra
.606 .744 .942 r
.61155 .45133 .61253 .45248 .61449 .45202 .61351 .45087 Mtetra
.725 .786 .901 r
.61351 .45087 .61449 .45202 .61644 .45099 .61545 .44986 Mtetra
.613 .752 .944 r
.61545 .44986 .61644 .45099 .6184 .45042 .61741 .44937 Mtetra
.491 .715 .97 r
.61741 .44937 .6184 .45042 .62037 .45019 .61939 .44925 Mtetra
.667 .812 .953 r
.61939 .44925 .62037 .45019 .62232 .44936 .62135 .44852 Mtetra
.925 .844 .745 r
.62135 .44852 .62232 .44936 .6242 .44609 .62324 .44541 Mtetra
.983 .733 .476 r
.62324 .44541 .6242 .44609 .62016 .25172 .62469 .42836 Mtetra
0 0 .313 r
.62469 .42836 .62016 .25172 .6213 .22867 .62038 .2276 Mtetra
.908 .804 .733 r
.62038 .2276 .6213 .22867 .62306 .22578 .62214 .2246 Mtetra
.706 .761 .895 r
.62214 .2246 .62306 .22578 .62488 .22494 .62397 .22374 Mtetra
.585 .711 .93 r
.62397 .22374 .62488 .22494 .62672 .2246 .62581 .22341 Mtetra
.666 .744 .909 r
.62581 .22341 .62672 .2246 .62856 .22394 .62765 .22274 Mtetra
.735 .768 .88 r
.62765 .22274 .62856 .22394 .63038 .22291 .62947 .22171 Mtetra
.636 .732 .918 r
.62947 .22171 .63038 .22291 .63222 .22238 .63131 .22118 Mtetra
0 .277 .776 r
.63131 .22118 .63222 .22238 .63413 .2237 .63322 .2225 Mtetra
.94 .578 .193 r
.63322 .2225 .63413 .2237 .63636 .23383 .63545 .23271 Mtetra
.975 .675 .374 r
.63545 .23271 .63636 .23383 .64582 .4384 .64485 .43726 Mtetra
0 0 .51 r
.64485 .43726 .64582 .4384 .64791 .44066 .64694 .43952 Mtetra
.624 .757 .942 r
.64694 .43952 .64791 .44066 .64989 .44012 .64892 .43899 Mtetra
.763 .804 .885 r
.64892 .43899 .64989 .44012 .65185 .43885 .65088 .43773 Mtetra
.771 .808 .882 r
.65088 .43773 .65185 .43885 .6538 .43752 .65284 .43643 Mtetra
.707 .797 .92 r
.65284 .43643 .6538 .43752 .65577 .43656 .65481 .43551 Mtetra
.695 .801 .93 r
.65481 .43551 .65577 .43656 .65774 .43568 .65679 .43466 Mtetra
.654 .794 .949 r
.65679 .43466 .65774 .43568 .65973 .43501 .65877 .43399 Mtetra
.597 .772 .963 r
.65877 .43399 .65973 .43501 .66172 .43459 .66076 .43353 Mtetra
.577 .755 .962 r
.66076 .43353 .66172 .43459 .66372 .43425 .66276 .43314 Mtetra
.478 .698 .965 r
.66276 .43314 .66372 .43425 .66574 .43422 .66478 .43308 Mtetra
.429 .665 .96 r
.66478 .43308 .66574 .43422 .66776 .43432 .6668 .43317 Mtetra
.639 .761 .937 r
.6668 .43317 .66776 .43432 .66976 .43374 .6688 .43257 Mtetra
.896 .81 .755 r
.6688 .43257 .66976 .43374 .67166 .43099 .67069 .4297 Mtetra
.977 .682 .38 r
.67069 .4297 .67166 .43099 .67276 .41093 .6636 .2291 Mtetra
.567 .334 .523 r
.6636 .2291 .67276 .41093 .66561 .21316 .66469 .21154 Mtetra
.876 .744 .713 r
.66469 .21154 .66561 .21316 .66735 .20993 .66644 .20844 Mtetra
.677 .701 .865 r
.66644 .20844 .66735 .20993 .6692 .20908 .6683 .20768 Mtetra
.56 .663 .906 r
.6683 .20768 .6692 .20908 .67108 .20877 .67018 .20746 Mtetra
.547 .675 .922 r
.67018 .20746 .67108 .20877 .67296 .20847 .67207 .20728 Mtetra
.653 .744 .916 r
.67207 .20728 .67296 .20847 .67483 .20777 .67394 .20666 Mtetra
.666 .765 .924 r
.67394 .20666 .67483 .20777 .67669 .20712 .6758 .20598 Mtetra
.721 .78 .899 r
.6758 .20598 .67669 .20712 .67856 .20645 .67766 .20504 Mtetra
.749 .741 .845 r
.67766 .20504 .67856 .20645 .68043 .2058 .6795 .20382 Mtetra
.657 .63 .811 r
.6795 .20382 .68043 .2058 .68232 .20562 .68137 .20309 Mtetra
.403 .433 .777 r
.68137 .20309 .68232 .20562 .68431 .20708 .68331 .20383 Mtetra
0 0 .245 r
.68331 .20383 .68431 .20708 .69651 .40041 .6856 .2109 Mtetra
0 0 .368 r
.6856 .2109 .69651 .40041 .69969 .42165 .69871 .41972 Mtetra
0 0 .495 r
.69871 .41972 .69969 .42165 .70188 .42424 .70094 .42313 Mtetra
.381 .646 .961 r
.70094 .42313 .70188 .42424 .70394 .42439 .70301 .42332 Mtetra
.709 .808 .927 r
.70301 .42332 .70394 .42439 .70595 .42348 .70501 .42239 Mtetra
.895 .828 .774 r
.70501 .42239 .70595 .42348 .70786 .42087 .70692 .41972 Mtetra
.979 .756 .53 r
.70692 .41972 .70786 .42087 .70937 .41131 .70844 .41025 Mtetra
.977 .678 .362 r
.70844 .41025 .70937 .41131 .69937 .20231 .69849 .2011 Mtetra
.938 .79 .67 r
.69849 .2011 .69937 .20231 .70105 .19824 .70017 .19702 Mtetra
.732 .769 .882 r
.70017 .19702 .70105 .19824 .70292 .19721 .70204 .19598 Mtetra
.605 .718 .925 r
.70204 .19598 .70292 .19721 .70482 .19679 .70394 .19556 Mtetra
.604 .718 .925 r
.70394 .19556 .70482 .19679 .70672 .19638 .70584 .19514 Mtetra
.743 .771 .876 r
.70584 .19514 .70672 .19638 .70858 .19528 .7077 .19404 Mtetra
.66 .741 .91 r
.7077 .19404 .70858 .19528 .71047 .19462 .70959 .19338 Mtetra
.245 .518 .911 r
.70959 .19338 .71047 .19462 .71244 .19525 .71156 .19402 Mtetra
.876 .48 .02 r
.71156 .19402 .71244 .19525 .71481 .20222 .71393 .20099 Mtetra
.975 .667 .334 r
.71393 .20099 .71481 .20222 .72999 .41104 .72907 .40985 Mtetra
.648 .193 0 r
.72907 .40985 .72999 .41104 .73229 .41449 .73136 .41328 Mtetra
.528 .704 .951 r
.73136 .41328 .73229 .41449 .73437 .41438 .73343 .41309 Mtetra
.693 .763 .905 r
.73343 .41309 .73437 .41438 .73639 .4135 .73546 .41222 Mtetra
.7 .764 .902 r
.73546 .41222 .73639 .4135 .7384 .41238 .73749 .4113 Mtetra
.448 .694 .971 r
.73749 .4113 .7384 .41238 .74045 .41174 .73957 .4113 Mtetra
.492 .86 .986 r
.73957 .4113 .74045 .41174 .74246 .41061 .74163 .41081 Mtetra
.724 .982 .777 r
.74163 .41081 .74246 .41061 .74438 .40813 .7436 .40904 Mtetra
.975 .844 .443 r
.7436 .40904 .74438 .40813 .74572 .39718 .7452 .40182 Mtetra
.978 .678 .329 r
.7452 .40182 .74572 .39718 .7335 .19047 .7327 .19023 Mtetra
.994 .857 .589 r
.7327 .19023 .7335 .19047 .73517 .18642 .7343 .18512 Mtetra
.749 .766 .866 r
.7343 .18512 .73517 .18642 .73705 .18532 .73617 .18395 Mtetra
.622 .702 .902 r
.73617 .18395 .73705 .18532 .73897 .18481 .7381 .18346 Mtetra
.585 .689 .913 r
.7381 .18346 .73897 .18481 .74089 .18441 .74003 .18313 Mtetra
.75 .769 .869 r
.74003 .18313 .74089 .18441 .74277 .18323 .74191 .18196 Mtetra
.676 .743 .901 r
.74191 .18196 .74277 .18323 .74467 .18249 .74381 .18122 Mtetra
.384 .597 .93 r
.74381 .18122 .74467 .18249 .74666 .18279 .7458 .18152 Mtetra
.818 .408 0 r
.7458 .18152 .74666 .18279 .74906 .18858 .74819 .18731 Mtetra
.973 .662 .315 r
.74819 .18731 .74906 .18858 .7668 .39861 .76589 .3974 Mtetra
.698 .255 0 r
.76589 .3974 .7668 .39861 .76922 .40272 .76831 .4015 Mtetra
.502 .691 .953 r
.76831 .4015 .76922 .40272 .77134 .40269 .77042 .4014 Mtetra
.684 .761 .909 r
.77042 .4014 .77134 .40269 .77339 .40187 .77248 .40056 Mtetra
.721 .772 .893 r
.77248 .40056 .77339 .40187 .77542 .40066 .77452 .39951 Mtetra
.452 .68 .963 r
.77452 .39951 .77542 .40066 .77749 .40004 .77664 .39953 Mtetra
.487 .845 .993 r
.77664 .39953 .77749 .40004 .77953 .39896 .77873 .39909 Mtetra
.641 .962 .804 r
.77873 .39909 .77953 .39896 .78148 .39681 .78074 .39764 Mtetra
.962 .855 .444 r
.78074 .39764 .78148 .39681 .78288 .38771 .78235 .39118 Mtetra
.975 .672 .312 r
.78235 .39118 .78288 .38771 .76807 .17879 .76733 .17885 Mtetra
.997 .852 .524 r
.76733 .17885 .76807 .17879 .76968 .17421 .76883 .17292 Mtetra
.764 .775 .862 r
.76883 .17292 .76968 .17421 .77157 .17302 .77072 .17164 Mtetra
.633 .708 .901 r
.77072 .17164 .77157 .17302 .77351 .17245 .77266 .17109 Mtetra
.559 .676 .917 r
.77266 .17109 .77351 .17245 .77548 .17215 .77463 .17086 Mtetra
.752 .772 .869 r
.77463 .17086 .77548 .17215 .77737 .17094 .77652 .16967 Mtetra
.684 .749 .9 r
.77652 .16967 .77737 .17094 .77929 .17014 .77845 .16888 Mtetra
.477 .65 .935 r
.77845 .16888 .77929 .17014 .78129 .17016 .78045 .1689 Mtetra
.757 .34 0 r
.78045 .1689 .78129 .17016 .78372 .17521 .78288 .17397 Mtetra
.971 .656 .295 r
.78288 .17397 .78372 .17521 .80408 .38613 .80319 .38493 Mtetra
.736 .302 0 r
.80319 .38493 .80408 .38613 .80664 .39093 .80575 .38972 Mtetra
.299 .577 .937 r
.80575 .38972 .80664 .39093 .80884 .39142 .80795 .3902 Mtetra
.647 .764 .934 r
.80795 .3902 .80884 .39142 .81093 .39075 .81004 .38954 Mtetra
.828 .822 .843 r
.81004 .38954 .81093 .39075 .81292 .38893 .81204 .38771 Mtetra
.908 .737 .658 r
.14444 .5975 .14562 .59845 .14784 .5927 .14666 .59175 Mtetra
.936 .686 .535 r
.14666 .59175 .14784 .5927 .17162 .39082 .17052 .38983 Mtetra
.908 .728 .647 r
.17052 .38983 .17162 .39082 .17376 .38484 .17267 .38383 Mtetra
.773 .761 .842 r
.17267 .38383 .17376 .38484 .17539 .38364 .17429 .38263 Mtetra
.637 .737 .921 r
.17429 .38263 .17539 .38364 .17693 .38319 .17583 .38218 Mtetra
.502 .692 .953 r
.17583 .38218 .17693 .38319 .17843 .3831 .17734 .3821 Mtetra
.752 .761 .861 r
.17734 .3821 .17843 .3831 .18003 .38208 .17894 .38107 Mtetra
.696 .752 .895 r
.17894 .38107 .18003 .38208 .1816 .38138 .18051 .38038 Mtetra
.455 .674 .958 r
.18051 .38038 .1816 .38138 .1831 .38137 .18201 .3804 Mtetra
.934 .571 .301 r
.18201 .3804 .1831 .38137 .18413 .38577 .183 .3851 Mtetra
.938 .682 .523 r
.183 .3851 .18413 .38577 .16435 .58702 .16312 .58663 Mtetra
.909 .547 .337 r
.16312 .58663 .16435 .58702 .16541 .5921 .16421 .59143 Mtetra
.286 .682 .973 r
.16421 .59143 .16541 .5921 .16699 .5923 .1658 .59154 Mtetra
.715 .818 .929 r
.1658 .59154 .16699 .5923 .16867 .59156 .16749 .59073 Mtetra
.783 .805 .87 r
.16749 .59073 .16867 .59156 .1704 .59039 .16922 .58947 Mtetra
.51 .73 .972 r
.16922 .58947 .1704 .59039 .17202 .59028 .17084 .58932 Mtetra
.593 .751 .953 r
.17084 .58932 .17202 .59028 .17366 .58994 .17249 .58897 Mtetra
.751 .781 .878 r
.17249 .58897 .17366 .58994 .17537 .58888 .1742 .58792 Mtetra
.908 .743 .666 r
.1742 .58792 .17537 .58888 .17752 .58364 .17635 .58266 Mtetra
.939 .687 .529 r
.17635 .58266 .17752 .58364 .19964 .38155 .19855 .3805 Mtetra
.912 .726 .638 r
.19855 .3805 .19964 .38155 .2018 .3751 .20072 .37406 Mtetra
.79 .759 .825 r
.20072 .37406 .2018 .3751 .20345 .37371 .20237 .37267 Mtetra
.623 .728 .922 r
.20237 .37267 .20345 .37371 .20501 .37331 .20393 .37226 Mtetra
.458 .666 .952 r
.20393 .37226 .20501 .37331 .20652 .37333 .20544 .37229 Mtetra
.607 .724 .927 r
.20544 .37229 .20652 .37333 .20807 .37297 .20699 .37194 Mtetra
.636 .734 .919 r
.20699 .37194 .20807 .37297 .20963 .37251 .20855 .37148 Mtetra
.645 .739 .917 r
.20855 .37148 .20963 .37251 .2112 .372 .21012 .371 Mtetra
.662 .747 .913 r
.21012 .371 .2112 .372 .21278 .37141 .21169 .37044 Mtetra
.678 .758 .912 r
.21169 .37044 .21278 .37141 .21436 .37077 .21327 .36982 Mtetra
.692 .767 .909 r
.21327 .36982 .21436 .37077 .21595 .37008 .21486 .36914 Mtetra
.753 .777 .872 r
.21486 .36914 .21595 .37008 .21758 .36899 .21648 .36812 Mtetra
.74 .79 .892 r
.21648 .36812 .21758 .36899 .21919 .36809 .2181 .3672 Mtetra
.665 .773 .93 r
.2181 .3672 .21919 .36809 .22074 .36774 .21968 .36663 Mtetra
0 .349 .818 r
.21968 .36663 .22074 .36774 .22207 .36991 .22112 .36745 Mtetra
0 0 .536 r
.22112 .36745 .22207 .36991 .22204 .38642 .22244 .36972 Mtetra
.323 .167 .508 r
.22244 .36972 .22204 .38642 .20579 .57578 .22342 .37557 Mtetra
.498 .279 .512 r
.22342 .37557 .20579 .57578 .20732 .57691 .22375 .3884 Mtetra
.541 .315 .522 r
.22375 .3884 .20732 .57691 .209 .57636 .22572 .38377 Mtetra
.547 .32 .523 r
.22572 .38377 .209 .57636 .21074 .57522 .22795 .37638 Mtetra
.538 .313 .521 r
.22795 .37638 .21074 .57522 .21246 .57431 .22982 .37275 Mtetra
.533 .308 .52 r
.22982 .37275 .21246 .57431 .21416 .57365 .2315 .37128 Mtetra
.526 .303 .519 r
.2315 .37128 .21416 .57365 .21583 .57328 .23292 .37258 Mtetra
0 0 .17 r
.23292 .37258 .21583 .57328 .21742 .57377 .21687 .56611 Mtetra
0 0 .456 r
.21687 .56611 .21742 .57377 .219 .57442 .21802 .57154 Mtetra
0 .051 .603 r
.21802 .57154 .219 .57442 .22061 .57485 .21946 .57381 Mtetra
.219 .561 .936 r
.21946 .57381 .22061 .57485 .22226 .57475 .22106 .57422 Mtetra
.513 .822 1 r
.22106 .57422 .22226 .57475 .22394 .57437 .22274 .5739 Mtetra
.636 .873 .986 r
.22274 .5739 .22394 .57437 .22563 .57386 .22444 .57329 Mtetra
.602 .844 .99 r
.22444 .57329 .22563 .57386 .2273 .57356 .22613 .5728 Mtetra
.651 .812 .96 r
.22613 .5728 .2273 .57356 .22899 .57313 .22783 .57222 Mtetra
.727 .795 .906 r
.22783 .57222 .22899 .57313 .23072 .57218 .22956 .57131 Mtetra
.829 .802 .826 r
.22956 .57131 .23072 .57218 .23263 .56922 .23137 .56957 Mtetra
.943 .931 .76 r
.23137 .56957 .23263 .56922 .23498 .56112 .23327 .56668 Mtetra
0 0 0 r
.23327 .56668 .23498 .56112 .25371 .36064 .2354 .56112 Mtetra
0 0 .158 r
.2354 .56112 .25371 .36064 .25558 .35693 .25395 .36252 Mtetra
0 0 0 r
.25395 .36252 .25558 .35693 .25727 .35528 .25604 .35622 Mtetra
.923 .973 .7 r
.25604 .35622 .25727 .35528 .25891 .35426 .25783 .35339 Mtetra
.778 .795 .867 r
.25783 .35339 .25891 .35426 .26052 .35361 .25948 .35221 Mtetra
.622 .665 .871 r
.25948 .35221 .26052 .35361 .26211 .35319 .26107 .35181 Mtetra
.541 .635 .893 r
.26107 .35181 .26211 .35319 .26369 .3529 .26264 .3517 Mtetra
.593 .691 .911 r
.26264 .3517 .26369 .3529 .26528 .35248 .26422 .3514 Mtetra
.643 .731 .913 r
.26422 .3514 .26528 .35248 .26689 .35195 .26582 .35091 Mtetra
.653 .743 .915 r
.26582 .35091 .26689 .35195 .26849 .35139 .26743 .35038 Mtetra
.658 .751 .919 r
.26743 .35038 .26849 .35139 .2701 .35079 .26904 .34983 Mtetra
.665 .762 .923 r
.26904 .34983 .2701 .35079 .27172 .35017 .27065 .34925 Mtetra
.678 .774 .923 r
.27065 .34925 .27172 .35017 .27333 .34953 .27226 .34862 Mtetra
.737 .788 .894 r
.27226 .34862 .27333 .34953 .27498 .34856 .2739 .34771 Mtetra
.743 .799 .898 r
.2739 .34771 .27498 .34856 .27662 .34763 .27555 .34677 Mtetra
.678 .789 .933 r
.27555 .34677 .27662 .34763 .27822 .34717 .27716 .34614 Mtetra
.178 .523 .919 r
.27716 .34614 .27822 .34717 .27968 .34864 .2787 .34662 Mtetra
0 0 .577 r
.2787 .34662 .27968 .34864 .28066 .3563 .28011 .34862 Mtetra
.077 .029 .495 r
.28011 .34862 .28066 .3563 .26704 .55538 .28132 .35347 Mtetra
.513 .292 .516 r
.28132 .35347 .26704 .55538 .26857 .55742 .28237 .36038 Mtetra
.537 .312 .521 r
.28237 .36038 .26857 .55742 .27028 .55695 .28419 .35718 Mtetra
.532 .308 .52 r
.28419 .35718 .27028 .55695 .27204 .55601 .28586 .35615 Mtetra
0 0 .212 r
.28586 .35615 .27204 .55601 .27372 .55598 .27317 .54716 Mtetra
.019 0 .466 r
.27317 .54716 .27372 .55598 .27536 .55657 .2744 .55323 Mtetra
0 .091 .614 r
.2744 .55323 .27536 .55657 .27702 .55697 .27591 .55566 Mtetra
.153 .461 .888 r
.27591 .55566 .27702 .55697 .2787 .55709 .27755 .55635 Mtetra
.548 .79 .988 r
.27755 .55635 .2787 .55709 .28041 .55683 .27926 .55603 Mtetra
.721 .822 .928 r
.27926 .55603 .28041 .55683 .28216 .55599 .28102 .55516 Mtetra
.837 .814 .827 r
.28102 .55516 .28216 .55599 .28404 .5534 .28284 .55335 Mtetra
.939 .883 .75 r
.28284 .55335 .28404 .5534 .28625 .54614 .28476 .55024 Mtetra
0 0 0 r
.28476 .55024 .28625 .54614 .30215 .3441 .28682 .5451 Mtetra
.514 .288 .509 r
.28682 .5451 .30215 .3441 .30401 .34033 .289 .53816 Mtetra
.524 .296 .511 r
.289 .53816 .30401 .34033 .30566 .33948 .29083 .5361 Mtetra
.532 .303 .513 r
.29083 .5361 .30566 .33948 .30726 .33932 .2924 .53794 Mtetra
.53 .301 .513 r
.2924 .53794 .30726 .33932 .30887 .33909 .29404 .53872 Mtetra
.528 .299 .512 r
.29404 .53872 .30887 .33909 .3105 .33854 .29576 .5383 Mtetra
.29576 .5383 .3105 .33854 .31213 .338 .29749 .53791 Mtetra
.29749 .53791 .31213 .338 .31377 .33745 .29922 .53747 Mtetra
.527 .299 .512 r
.29922 .53747 .31377 .33745 .31541 .33688 .30095 .53698 Mtetra
.30095 .53698 .31541 .33688 .31704 .33631 .30269 .53646 Mtetra
.30269 .53646 .31704 .33631 .31868 .33573 .30443 .53594 Mtetra
.30443 .53594 .31868 .33573 .32032 .33515 .30617 .53541 Mtetra
.30617 .53541 .32032 .33515 .32197 .33457 .30791 .53487 Mtetra
.30791 .53487 .32197 .33457 .32361 .33399 .30966 .53432 Mtetra
.30966 .53432 .32361 .33399 .32525 .33341 .3114 .53376 Mtetra
.3114 .53376 .32525 .33341 .3269 .33282 .31315 .5332 Mtetra
.31315 .5332 .3269 .33282 .32855 .33223 .3149 .53262 Mtetra
.3149 .53262 .32855 .33223 .33019 .33164 .31665 .53204 Mtetra
.31665 .53204 .33019 .33164 .33184 .33104 .3184 .53143 Mtetra
.3184 .53143 .33184 .33104 .33349 .33042 .32016 .53078 Mtetra
.32016 .53078 .33349 .33042 .33515 .3298 .32192 .53008 Mtetra
.32192 .53008 .33515 .3298 .3368 .32918 .32368 .52939 Mtetra
.525 .297 .512 r
.32368 .52939 .3368 .32918 .33847 .3283 .3255 .52774 Mtetra
.522 .295 .511 r
.3255 .52774 .33847 .3283 .34015 .32726 .3274 .52481 Mtetra
.529 .301 .512 r
.3274 .52481 .34015 .32726 .34179 .32688 .32909 .52535 Mtetra
.539 .309 .514 r
.32909 .52535 .34179 .32688 .34329 .32905 .3305 .53075 Mtetra
.537 .307 .514 r
.3305 .53075 .34329 .32905 .33342 .53023 .33198 .535 Mtetra
.643 .322 .414 r
.33198 .535 .33342 .53023 .33476 .53712 .33359 .53713 Mtetra
.493 0 0 r
.33359 .53713 .33476 .53712 .3364 .53885 .33528 .53791 Mtetra
.535 .744 .972 r
.33528 .53791 .3364 .53885 .33815 .53866 .33704 .53768 Mtetra
.633 .77 .946 r
.33704 .53768 .33815 .53866 .33992 .53799 .3388 .53717 Mtetra
.647 .808 .961 r
.3388 .53717 .33992 .53799 .3417 .53724 .34058 .53658 Mtetra
.613 .835 .985 r
.34058 .53658 .3417 .53724 .34347 .53669 .34235 .53605 Mtetra
.631 .846 .982 r
.34235 .53605 .34347 .53669 .34525 .53609 .34412 .53547 Mtetra
.621 .846 .985 r
.34412 .53547 .34525 .53609 .34702 .53549 .3459 .53491 Mtetra
.6 .849 .991 r
.3459 .53491 .34702 .53549 .3488 .5349 .34767 .53439 Mtetra
.688 .887 .971 r
.34767 .53439 .3488 .5349 .35059 .53418 .34946 .53359 Mtetra
.837 .87 .868 r
.34946 .53359 .35059 .53418 .35239 .53315 .35129 .53196 Mtetra
.889 .76 .713 r
.35129 .53196 .35239 .53315 .35422 .53162 .35322 .52845 Mtetra
.864 .656 .62 r
.35322 .52845 .35422 .53162 .35605 .52988 .35533 .52147 Mtetra
.949 .681 .494 r
.35533 .52147 .35605 .52988 .35787 .5286 .36689 .32585 Mtetra
.532 .307 .52 r
.36689 .32585 .35787 .5286 .35963 .52843 .36859 .32489 Mtetra
.528 .305 .519 r
.36859 .32489 .35963 .52843 .36142 .52783 .37022 .32534 Mtetra
.539 .314 .521 r
.37022 .32534 .36142 .52783 .3633 .52509 .37209 .32079 Mtetra
.542 .316 .521 r
.37209 .32079 .3633 .52509 .37467 .32374 .37402 .315 Mtetra
.659 .455 .597 r
.37402 .315 .37467 .32374 .37678 .31412 .37582 .31182 Mtetra
.751 .632 .728 r
.37582 .31182 .37678 .31412 .37856 .31119 .37755 .31 Mtetra
.668 .726 .893 r
.37755 .31 .37856 .31119 .38025 .31039 .37923 .30938 Mtetra
.591 .736 .944 r
.37923 .30938 .38025 .31039 .38192 .31006 .3809 .30904 Mtetra
.623 .745 .934 r
.3809 .30904 .38192 .31006 .38358 .30977 .38257 .30859 Mtetra
.73 .747 .865 r
.38257 .30859 .38358 .30977 .38527 .309 .38426 .30763 Mtetra
.684 .701 .86 r
.38426 .30763 .38527 .309 .38695 .30832 .38595 .3069 Mtetra
.513 .622 .896 r
.38595 .3069 .38695 .30832 .38863 .30793 .38761 .30688 Mtetra
.598 .102 0 r
.38761 .30688 .38863 .30793 .39027 .30814 .38919 .30874 Mtetra
.879 .505 .331 r
.38919 .30874 .39027 .30814 .39191 .30859 .39064 .31368 Mtetra
.953 .676 .476 r
.39064 .31368 .39191 .30859 .39357 .30879 .38402 .5096 Mtetra
.528 .3 .512 r
.38402 .5096 .39357 .30879 .39527 .30781 .38579 .50954 Mtetra
.525 .298 .512 r
.38579 .50954 .39527 .30781 .39696 .30718 .38762 .50803 Mtetra
.533 .304 .513 r
.38762 .50803 .39696 .30718 .39859 .30815 .38931 .5103 Mtetra
.538 .308 .514 r
.38931 .5103 .39859 .30815 .39236 .50648 .39087 .51553 Mtetra
.609 .323 .457 r
.39087 .51553 .39236 .50648 .3937 .51753 .39256 .51799 Mtetra
.62 .099 0 r
.39256 .51799 .3937 .51753 .39539 .51998 .3943 .51908 Mtetra
.487 .738 .982 r
.3943 .51908 .39539 .51998 .39717 .51992 .39609 .51894 Mtetra
.619 .771 .953 r
.39609 .51894 .39717 .51992 .39899 .5193 .39789 .51846 Mtetra
.653 .81 .959 r
.39789 .51846 .39899 .5193 .40081 .51847 .39971 .51784 Mtetra
.579 .834 .993 r
.39971 .51784 .40081 .51847 .40262 .51791 .40152 .51737 Mtetra
.668 .883 .978 r
.40152 .51737 .40262 .51791 .40443 .5172 .40334 .51662 Mtetra
.807 .886 .902 r
.40334 .51662 .40443 .5172 .40626 .51625 .40518 .51525 Mtetra
.899 .789 .731 r
.40518 .51525 .40626 .51625 .40811 .51474 .40709 .51202 Mtetra
.868 .67 .633 r
.40709 .51202 .40811 .51474 .40996 .51301 .40909 .50607 Mtetra
.956 .683 .479 r
.40909 .50607 .40996 .51301 .41182 .51135 .41766 .30831 Mtetra
.536 .311 .52 r
.41766 .30831 .41182 .51135 .41364 .5106 .41946 .30511 Mtetra
.529 .305 .519 r
.41946 .30511 .41364 .5106 .41545 .51014 .42114 .30532 Mtetra
.524 .301 .518 r
.42114 .30532 .41545 .51014 .41726 .50986 .42274 .30802 Mtetra
.512 .291 .516 r
.42274 .30802 .41726 .50986 .41906 .5099 .42418 .31603 Mtetra
.508 .289 .516 r
.42418 .31603 .41906 .5099 .42088 .50935 .42559 .32519 Mtetra
.576 .344 .526 r
.42559 .32519 .42088 .50935 .42275 .5074 .42795 .30397 Mtetra
.546 .319 .522 r
.42795 .30397 .42275 .5074 .42509 .48981 .42989 .29614 Mtetra
.538 .312 .521 r
.42989 .29614 .42509 .48981 .43264 .29515 .43169 .29247 Mtetra
.76 .618 .701 r
.43169 .29247 .43264 .29515 .43445 .29142 .43345 .29022 Mtetra
.711 .742 .876 r
.43345 .29022 .43445 .29142 .43617 .29037 .43517 .28935 Mtetra
.645 .757 .931 r
.43517 .28935 .43617 .29037 .43788 .28987 .43689 .28882 Mtetra
.605 .737 .938 r
.43689 .28882 .43788 .28987 .43959 .28961 .43859 .28843 Mtetra
.663 .731 .901 r
.43859 .28843 .43959 .28961 .4413 .28901 .44031 .28782 Mtetra
.658 .726 .9 r
.44031 .28782 .4413 .28901 .44302 .28844 .44203 .28723 Mtetra
.649 .719 .9 r
.44203 .28723 .44302 .28844 .44473 .28791 .44374 .28668 Mtetra
.622 .708 .907 r
.44374 .28668 .44473 .28791 .44645 .28743 .44546 .28624 Mtetra
.618 .713 .913 r
.44546 .28624 .44645 .28743 .44816 .28697 .44717 .28581 Mtetra
.623 .723 .918 r
.44717 .28581 .44816 .28697 .44988 .28649 .44889 .28537 Mtetra
.652 .74 .914 r
.44889 .28537 .44988 .28649 .4516 .28593 .45061 .2848 Mtetra
.667 .743 .907 r
.45061 .2848 .4516 .28593 .45332 .28533 .45234 .28417 Mtetra
.683 .742 .896 r
.45234 .28417 .45332 .28533 .45505 .28468 .45406 .28346 Mtetra
.747 .751 .855 r
.45406 .28346 .45505 .28468 .45678 .28381 .4558 .28236 Mtetra
.703 .702 .846 r
.4558 .28236 .45678 .28381 .45851 .28301 .45753 .28148 Mtetra
.623 .658 .863 r
.45753 .28148 .45851 .28301 .46024 .2824 .45926 .28103 Mtetra
0 .306 .8 r
.45926 .28103 .46024 .2824 .46196 .2821 .46095 .28218 Mtetra
.846 .403 .165 r
.46095 .28218 .46196 .2821 .46367 .28229 .4626 .28533 Mtetra
.962 .678 .451 r
.4626 .28533 .46367 .28229 .46537 .28348 .46045 .484 Mtetra
.544 .313 .515 r
.46045 .484 .46537 .28348 .46684 .29684 .46213 .49261 Mtetra
.533 .304 .513 r
.46213 .49261 .46684 .29684 .46502 .49383 .46392 .49509 Mtetra
.602 .144 .139 r
.46392 .49509 .46502 .49383 .4668 .49696 .46575 .49608 Mtetra
.58 .784 .976 r
.46575 .49608 .4668 .49696 .46865 .49687 .4676 .49568 Mtetra
.694 .758 .901 r
.4676 .49568 .46865 .49687 .47051 .49609 .46946 .49487 Mtetra
.723 .76 .882 r
.46946 .49487 .47051 .49609 .47238 .49498 .47133 .49389 Mtetra
.425 .666 .962 r
.47133 .49389 .47238 .49498 .47423 .49496 .47318 .49397 Mtetra
.544 .744 .969 r
.47318 .49397 .47423 .49496 .47609 .4946 .47503 .49371 Mtetra
.745 .827 .915 r
.47503 .49371 .47609 .4946 .47796 .49345 .4769 .49265 Mtetra
.953 .782 .633 r
.4769 .49265 .47796 .49345 .47989 .48744 .47884 .4868 Mtetra
.968 .69 .45 r
.47884 .4868 .47989 .48744 .48446 .27918 .48348 .27812 Mtetra
.945 .756 .617 r
.48348 .27812 .48446 .27918 .48628 .27314 .4853 .2719 Mtetra
.771 .755 .839 r
.4853 .2719 .48628 .27314 .48803 .27182 .48706 .2706 Mtetra
.611 .707 .913 r
.48706 .2706 .48803 .27182 .48977 .27138 .4888 .2702 Mtetra
.476 .655 .939 r
.4888 .2702 .48977 .27138 .49151 .27135 .49054 .27022 Mtetra
.692 .755 .899 r
.49054 .27022 .49151 .27135 .49326 .27072 .49229 .26946 Mtetra
.678 .725 .885 r
.49229 .26946 .49326 .27072 .49501 .27007 .49404 .26875 Mtetra
.601 .685 .901 r
.49404 .26875 .49501 .27007 .49676 .26955 .49579 .2684 Mtetra
0 .356 .827 r
.49579 .2684 .49676 .26955 .49851 .26917 .49753 .26939 Mtetra
.821 .363 .138 r
.49753 .26939 .49851 .26917 .50026 .26918 .49925 .2722 Mtetra
.965 .677 .438 r
.49925 .2722 .50026 .26918 .502 .27 .49951 .46686 Mtetra
.551 .318 .515 r
.49951 .46686 .502 .27 .50371 .2766 .50128 .47908 Mtetra
.533 .304 .513 r
.50128 .47908 .50371 .2766 .50419 .47986 .50314 .4818 Mtetra
.611 .198 .235 r
.50314 .4818 .50419 .47986 .50605 .48377 .50501 .48293 Mtetra
.331 .679 .978 r
.50501 .48293 .50605 .48377 .50792 .48419 .50689 .48307 Mtetra
.621 .749 .938 r
.50689 .48307 .50792 .48419 .50981 .48364 .50877 .48257 Mtetra
.747 .797 .893 r
.50877 .48257 .50981 .48364 .51169 .48257 .51066 .48146 Mtetra
.867 .8 .782 r
.51066 .48146 .51169 .48257 .51358 .48163 .51256 .47906 Mtetra
.852 .674 .661 r
.51256 .47906 .51358 .48163 .51547 .48032 .51445 .47467 Mtetra
.966 .684 .447 r
.51445 .47467 .51547 .48032 .51736 .47812 .51684 .28014 Mtetra
.56 .33 .523 r
.51684 .28014 .51736 .47812 .51926 .47012 .51865 .26515 Mtetra
.537 .311 .52 r
.51865 .26515 .51926 .47012 .52138 .26556 .52042 .26153 Mtetra
.705 .541 .664 r
.52042 .26153 .52138 .26556 .52315 .2608 .5222 .25936 Mtetra
.73 .718 .839 r
.5222 .25936 .52315 .2608 .52492 .25928 .52396 .25829 Mtetra
.657 .777 .937 r
.52396 .25829 .52492 .25928 .52669 .25866 .52574 .25769 Mtetra
.601 .759 .954 r
.52574 .25769 .52669 .25866 .52846 .25839 .52751 .25728 Mtetra
.737 .773 .882 r
.52751 .25728 .52846 .25839 .53024 .25744 .52928 .25626 Mtetra
.712 .755 .886 r
.52928 .25626 .53024 .25744 .53201 .25659 .53105 .25539 Mtetra
.558 .692 .93 r
.53105 .25539 .53201 .25659 .53378 .25638 .53283 .25516 Mtetra
.764 .318 0 r
.53283 .25516 .53378 .25638 .53557 .25964 .53462 .25847 Mtetra
.972 .682 .417 r
.53462 .25847 .53557 .25964 .53819 .46655 .53717 .46572 Mtetra
.921 .528 .174 r
.53717 .46572 .53819 .46655 .54013 .47316 .53911 .4722 Mtetra
.086 .496 .899 r
.53911 .4722 .54013 .47316 .54204 .47387 .54102 .47287 Mtetra
.679 .795 .936 r
.54102 .47287 .54204 .47387 .54394 .47317 .54293 .47211 Mtetra
.764 .805 .886 r
.54293 .47211 .54394 .47317 .54585 .472 .54483 .47089 Mtetra
.547 .726 .957 r
.54483 .47089 .54585 .472 .54776 .47169 .54675 .47064 Mtetra
.505 .718 .968 r
.54675 .47064 .54776 .47169 .54968 .47146 .54866 .47049 Mtetra
.688 .807 .939 r
.54866 .47049 .54968 .47146 .55159 .47057 .55057 .4697 Mtetra
.936 .814 .7 r
.55057 .4697 .55159 .47057 .55347 .46656 .55246 .46582 Mtetra
.973 .688 .425 r
.55246 .46582 .55347 .46656 .55349 .26108 .55255 .26161 Mtetra
.994 .77 .488 r
.55255 .26161 .55349 .26108 .55518 .25006 .55423 .24895 Mtetra
.866 .794 .778 r
.55423 .24895 .55518 .25006 .55695 .24784 .55601 .24667 Mtetra
.679 .749 .903 r
.55601 .24667 .55695 .24784 .55874 .24715 .5578 .24596 Mtetra
.555 .696 .933 r
.5578 .24596 .55874 .24715 .56054 .24693 .55959 .24574 Mtetra
.706 .752 .888 r
.55959 .24574 .56054 .24693 .56233 .2461 .56139 .24488 Mtetra
.718 .753 .879 r
.56139 .24488 .56233 .2461 .56412 .24519 .56318 .24395 Mtetra
.582 .698 .922 r
.56318 .24395 .56412 .24519 .56592 .24489 .56498 .24365 Mtetra
.632 .179 0 r
.56498 .24365 .56592 .24489 .56776 .24757 .56682 .24635 Mtetra
.973 .68 .404 r
.56682 .24635 .56776 .24757 .57257 .45402 .57158 .45316 Mtetra
.93 .549 .195 r
.57158 .45316 .57257 .45402 .57463 .46188 .57362 .4609 Mtetra
0 .359 .812 r
.57362 .4609 .57463 .46188 .57658 .46294 .57558 .46192 Mtetra
.664 .79 .941 r
.57558 .46192 .57658 .46294 .57851 .4623 .57751 .46122 Mtetra
.759 .805 .89 r
.57751 .46122 .57851 .4623 .58044 .46114 .57943 .46002 Mtetra
.592 .743 .948 r
.57943 .46002 .58044 .46114 .58237 .46069 .58137 .45961 Mtetra
.493 .708 .966 r
.58137 .45961 .58237 .46069 .58432 .4605 .58332 .45951 Mtetra
.669 .799 .944 r
.58332 .45951 .58432 .4605 .58625 .45969 .58526 .45879 Mtetra
.926 .825 .727 r
.58526 .45879 .58625 .45969 .58813 .45618 .58714 .4554 Mtetra
.979 .721 .472 r
.58714 .4554 .58813 .45618 .58612 .25701 .58867 .43383 Mtetra
0 0 .306 r
.58867 .43383 .58612 .25701 .58759 .23895 .58666 .23785 Mtetra
.891 .799 .751 r
.58666 .23785 .58759 .23895 .58936 .23633 .58843 .23516 Mtetra
.695 .756 .899 r
.58843 .23516 .58936 .23633 .59116 .23555 .59023 .23436 Mtetra
.57 .705 .933 r
.59023 .23436 .59116 .23555 .59299 .23527 .59206 .23409 Mtetra
.686 .751 .901 r
.59206 .23409 .59299 .23527 .5948 .23452 .59387 .23333 Mtetra
.728 .764 .881 r
.59387 .23333 .5948 .23452 .5966 .23354 .59568 .23235 Mtetra
.612 .721 .923 r
.59568 .23235 .5966 .23354 .59842 .23311 .5975 .23192 Mtetra
0 .063 .599 r
.5975 .23192 .59842 .23311 .6003 .235 .59938 .2338 Mtetra
.974 .678 .39 r
.59938 .2338 .6003 .235 .60721 .43554 .60622 .43435 Mtetra
.956 .612 .265 r
.60622 .43435 .60721 .43554 .60953 .44964 .60854 .4485 Mtetra
0 .147 .66 r
.60854 .4485 .60953 .44964 .61155 .45133 .61056 .45019 Mtetra
.605 .747 .945 r
.61056 .45019 .61155 .45133 .61351 .45087 .61252 .44973 Mtetra
.723 .789 .904 r
.61252 .44973 .61351 .45087 .61545 .44986 .61447 .44874 Mtetra
.595 .747 .95 r
.61447 .44874 .61545 .44986 .61741 .44937 .61643 .44831 Mtetra
.461 .699 .97 r
.61643 .44831 .61741 .44937 .61939 .44925 .61841 .44828 Mtetra
.649 .799 .955 r
.61841 .44828 .61939 .44925 .62135 .44852 .62037 .44763 Mtetra
.917 .839 .753 r
.62037 .44763 .62135 .44852 .62324 .44541 .62227 .44464 Mtetra
.982 .741 .496 r
.62227 .44464 .62324 .44541 .62469 .42836 .62382 .43067 Mtetra
.978 .688 .391 r
.62382 .43067 .62469 .42836 .62038 .2276 .61947 .22652 Mtetra
.912 .803 .727 r
.61947 .22652 .62038 .2276 .62214 .2246 .62122 .22343 Mtetra
.709 .763 .895 r
.62122 .22343 .62214 .2246 .62397 .22374 .62305 .22255 Mtetra
.585 .712 .931 r
.62305 .22255 .62397 .22374 .62581 .22341 .6249 .22221 Mtetra
.666 .746 .909 r
.6249 .22221 .62581 .22341 .62765 .22274 .62673 .22155 Mtetra
.736 .769 .879 r
.62673 .22155 .62765 .22274 .62947 .22171 .62856 .22051 Mtetra
.637 .733 .918 r
.62856 .22051 .62947 .22171 .63131 .22118 .6304 .21997 Mtetra
0 .276 .775 r
.6304 .21997 .63131 .22118 .63322 .2225 .63231 .2213 Mtetra
.941 .579 .195 r
.63231 .2213 .63322 .2225 .63545 .23271 .63454 .2316 Mtetra
.975 .675 .374 r
.63454 .2316 .63545 .23271 .64485 .43726 .64388 .43613 Mtetra
0 0 .509 r
.64388 .43613 .64485 .43726 .64694 .43952 .64597 .43839 Mtetra
.621 .757 .943 r
.64597 .43839 .64694 .43952 .64892 .43899 .64796 .43786 Mtetra
.761 .804 .888 r
.64796 .43786 .64892 .43899 .65088 .43773 .64991 .43662 Mtetra
.767 .809 .887 r
.64991 .43662 .65088 .43773 .65284 .43643 .65187 .43535 Mtetra
.699 .797 .926 r
.65187 .43535 .65284 .43643 .65481 .43551 .65385 .43448 Mtetra
.688 .802 .936 r
.65385 .43448 .65481 .43551 .65679 .43466 .65583 .43366 Mtetra
.653 .797 .952 r
.65583 .43366 .65679 .43466 .65877 .43399 .65781 .43298 Mtetra
.607 .78 .964 r
.65781 .43298 .65877 .43399 .66076 .43353 .65981 .43248 Mtetra
.59 .764 .962 r
.65981 .43248 .66076 .43353 .66276 .43314 .6618 .43205 Mtetra
.489 .707 .967 r
.6618 .43205 .66276 .43314 .66478 .43308 .66382 .43195 Mtetra
.435 .67 .961 r
.66382 .43195 .66478 .43308 .6668 .43317 .66584 .43201 Mtetra
.645 .764 .935 r
.66584 .43201 .6668 .43317 .6688 .43257 .66784 .43138 Mtetra
.9 .808 .748 r
.66784 .43138 .6688 .43257 .67069 .4297 .66973 .42841 Mtetra
.977 .682 .38 r
.66973 .42841 .67069 .4297 .6636 .2291 .66251 .22367 Mtetra
.896 .636 .536 r
.66251 .22367 .6636 .2291 .66469 .21154 .66378 .21 Mtetra
.878 .754 .721 r
.66378 .21 .66469 .21154 .66644 .20844 .66553 .20701 Mtetra
.667 .705 .876 r
.66553 .20701 .66644 .20844 .6683 .20768 .6674 .20631 Mtetra
.539 .658 .913 r
.6674 .20631 .6683 .20768 .67018 .20746 .66928 .20617 Mtetra
.527 .666 .925 r
.66928 .20617 .67018 .20746 .67207 .20728 .67118 .20605 Mtetra
.646 .734 .913 r
.67118 .20605 .67207 .20728 .67394 .20666 .67305 .20546 Mtetra
.664 .747 .912 r
.67305 .20546 .67394 .20666 .6758 .20598 .67491 .20479 Mtetra
.723 .77 .89 r
.67491 .20479 .6758 .20598 .67766 .20504 .67677 .20382 Mtetra
.768 .779 .861 r
.67677 .20382 .67766 .20504 .6795 .20382 .67861 .20255 Mtetra
.687 .742 .893 r
.67861 .20255 .6795 .20382 .68137 .20309 .68047 .20176 Mtetra
.236 .494 .897 r
.68047 .20176 .68137 .20309 .68331 .20383 .68242 .20246 Mtetra
.876 .485 .021 r
.68242 .20246 .68331 .20383 .6856 .2109 .68469 .20933 Mtetra
.975 .671 .348 r
.68469 .20933 .6856 .2109 .69871 .41972 .69776 .41854 Mtetra
.673 .217 0 r
.69776 .41854 .69871 .41972 .70094 .42313 .7 .42199 Mtetra
.387 .645 .959 r
.7 .42199 .70094 .42313 .70301 .42332 .70206 .42218 Mtetra
.71 .793 .916 r
.70206 .42218 .70301 .42332 .70501 .42239 .70407 .42124 Mtetra
.891 .821 .772 r
.70407 .42124 .70501 .42239 .70692 .41972 .70598 .41857 Mtetra
.979 .757 .532 r
.70598 .41857 .70692 .41972 .70844 .41025 .70751 .40916 Mtetra
.977 .678 .362 r
.70751 .40916 .70844 .41025 .69849 .2011 .6976 .19989 Mtetra
.938 .79 .67 r
.6976 .19989 .69849 .2011 .70017 .19702 .69929 .19579 Mtetra
.732 .769 .882 r
.69929 .19579 .70017 .19702 .70204 .19598 .70116 .19475 Mtetra
.605 .718 .925 r
.70116 .19475 .70204 .19598 .70394 .19556 .70306 .19433 Mtetra
.604 .718 .925 r
.70306 .19433 .70394 .19556 .70584 .19514 .70496 .19391 Mtetra
.743 .772 .877 r
.70496 .19391 .70584 .19514 .7077 .19404 .70682 .19281 Mtetra
.66 .742 .91 r
.70682 .19281 .7077 .19404 .70959 .19338 .70871 .19215 Mtetra
.242 .517 .911 r
.70871 .19215 .70959 .19338 .71156 .19402 .71069 .19279 Mtetra
.877 .482 .024 r
.71069 .19279 .71156 .19402 .71393 .20099 .71306 .19981 Mtetra
.975 .667 .334 r
.71306 .19981 .71393 .20099 .72907 .40985 .72814 .40868 Mtetra
.65 .194 0 r
.72814 .40868 .72907 .40985 .73136 .41328 .73043 .4121 Mtetra
.531 .711 .954 r
.73043 .4121 .73136 .41328 .73343 .41309 .7325 .41189 Mtetra
.697 .779 .915 r
.7325 .41189 .73343 .41309 .73546 .41222 .73453 .411 Mtetra
.699 .777 .912 r
.73453 .411 .73546 .41222 .73749 .4113 .73656 .41009 Mtetra
.449 .664 .954 r
.73656 .41009 .73749 .4113 .73957 .4113 .73865 .41015 Mtetra
.593 .749 .952 r
.73865 .41015 .73957 .4113 .74163 .41081 .74071 .40971 Mtetra
.823 .833 .857 r
.74071 .40971 .74163 .41081 .7436 .40904 .74269 .408 Mtetra
.98 .783 .567 r
.74269 .408 .7436 .40904 .7452 .40182 .7443 .40087 Mtetra
.977 .675 .344 r
.7443 .40087 .7452 .40182 .7327 .19023 .73183 .189 Mtetra
.959 .782 .621 r
.73183 .189 .7327 .19023 .7343 .18512 .73343 .18382 Mtetra
.749 .765 .866 r
.73343 .18382 .7343 .18512 .73617 .18395 .73531 .18265 Mtetra
.619 .714 .914 r
.73531 .18265 .73617 .18395 .7381 .18346 .73723 .18217 Mtetra
.579 .697 .923 r
.73723 .18217 .7381 .18346 .74003 .18313 .73916 .18185 Mtetra
.749 .77 .87 r
.73916 .18185 .74003 .18313 .74191 .18196 .74104 .18069 Mtetra
.675 .744 .903 r
.74104 .18069 .74191 .18196 .74381 .18122 .74295 .17996 Mtetra
.38 .596 .931 r
.74295 .17996 .74381 .18122 .7458 .18152 .74494 .18027 Mtetra
.819 .41 0 r
.74494 .18027 .7458 .18152 .74819 .18731 .74733 .18608 Mtetra
.973 .662 .315 r
.74733 .18608 .74819 .18731 .76589 .3974 .76498 .39621 Mtetra
.701 .257 0 r
.76498 .39621 .76589 .3974 .76831 .4015 .7674 .4003 Mtetra
.505 .697 .955 r
.7674 .4003 .76831 .4015 .77042 .4014 .76951 .40018 Mtetra
.688 .776 .918 r
.76951 .40018 .77042 .4014 .77248 .40056 .77156 .39932 Mtetra
.722 .786 .903 r
.77156 .39932 .77248 .40056 .77452 .39951 .77361 .39828 Mtetra
.444 .659 .952 r
.77361 .39828 .77452 .39951 .77664 .39953 .77574 .39836 Mtetra
.577 .74 .953 r
.77574 .39836 .77664 .39953 .77873 .39909 .77783 .39797 Mtetra
.782 .827 .887 r
.77783 .39797 .77873 .39909 .78074 .39764 .77985 .39657 Mtetra
.98 .794 .583 r
.77985 .39657 .78074 .39764 .78235 .39118 .78147 .3902 Mtetra
.976 .67 .325 r
.78147 .3902 .78235 .39118 .76733 .17885 .76648 .17763 Mtetra
.972 .779 .586 r
.76648 .17763 .76733 .17885 .76883 .17292 .76798 .17161 Mtetra
.763 .771 .86 r
.76798 .17161 .76883 .17292 .77072 .17164 .76986 .17033 Mtetra
.631 .719 .911 r
.76986 .17033 .77072 .17164 .77266 .17109 .77181 .16979 Mtetra
.552 .683 .926 r
.77181 .16979 .77266 .17109 .77463 .17086 .77378 .16957 Mtetra
.751 .772 .87 r
.77378 .16957 .77463 .17086 .77652 .16967 .77567 .16839 Mtetra
.683 .748 .901 r
.77567 .16839 .77652 .16967 .77845 .16888 .7776 .1676 Mtetra
.476 .649 .934 r
.7776 .1676 .77845 .16888 .78045 .1689 .7796 .16763 Mtetra
.757 .34 0 r
.7796 .16763 .78045 .1689 .78288 .17397 .78204 .17272 Mtetra
.971 .656 .295 r
.78204 .17272 .78288 .17397 .80319 .38493 .8023 .38373 Mtetra
.733 .3 0 r
.8023 .38373 .80319 .38493 .80575 .38972 .80486 .3885 Mtetra
.299 .577 .937 r
.80486 .3885 .80575 .38972 .80795 .3902 .80706 .38899 Mtetra
.647 .764 .934 r
.80706 .38899 .80795 .3902 .81004 .38954 .80915 .38832 Mtetra
.828 .822 .843 r
.80915 .38832 .81004 .38954 .81204 .38771 .81115 .38649 Mtetra
.908 .737 .658 r
.14325 .59654 .14444 .5975 .14666 .59175 .14548 .59081 Mtetra
.936 .686 .535 r
.14548 .59081 .14666 .59175 .17052 .38983 .16942 .38884 Mtetra
.909 .729 .646 r
.16942 .38884 .17052 .38983 .17267 .38383 .17157 .38283 Mtetra
.773 .761 .843 r
.17157 .38283 .17267 .38383 .17429 .38263 .1732 .38162 Mtetra
.636 .737 .921 r
.1732 .38162 .17429 .38263 .17583 .38218 .17474 .38118 Mtetra
.498 .691 .954 r
.17474 .38118 .17583 .38218 .17734 .3821 .17624 .38111 Mtetra
.749 .762 .863 r
.17624 .38111 .17734 .3821 .17894 .38107 .17784 .3801 Mtetra
.695 .757 .9 r
.17784 .3801 .17894 .38107 .18051 .38038 .17941 .37941 Mtetra
.456 .681 .962 r
.17941 .37941 .18051 .38038 .18201 .3804 .18091 .37941 Mtetra
.931 .561 .283 r
.18091 .37941 .18201 .3804 .183 .3851 .18194 .38384 Mtetra
.939 .683 .523 r
.18194 .38384 .183 .3851 .16312 .58663 .16201 .58506 Mtetra
.944 .581 .252 r
.16201 .58506 .16312 .58663 .16421 .59143 .16307 .59012 Mtetra
.398 .596 .925 r
.16307 .59012 .16421 .59143 .1658 .59154 .16465 .59034 Mtetra
.683 .728 .884 r
.16465 .59034 .1658 .59154 .16749 .59073 .16633 .58964 Mtetra
.754 .761 .858 r
.16633 .58964 .16749 .59073 .16922 .58947 .16805 .58852 Mtetra
.503 .72 .969 r
.16805 .58852 .16922 .58947 .17084 .58932 .16967 .5884 Mtetra
.596 .757 .956 r
.16967 .5884 .17084 .58932 .17249 .58897 .17131 .58803 Mtetra
.756 .786 .878 r
.17131 .58803 .17249 .58897 .1742 .58792 .17303 .58695 Mtetra
.908 .743 .666 r
.17303 .58695 .1742 .58792 .17635 .58266 .17518 .58168 Mtetra
.939 .687 .529 r
.17518 .58168 .17635 .58266 .19855 .3805 .19747 .37943 Mtetra
.911 .726 .638 r
.19747 .37943 .19855 .3805 .20072 .37406 .19964 .37301 Mtetra
.79 .758 .824 r
.19964 .37301 .20072 .37406 .20237 .37267 .20129 .37162 Mtetra
.624 .726 .92 r
.20129 .37162 .20237 .37267 .20393 .37226 .20285 .37121 Mtetra
.461 .664 .95 r
.20285 .37121 .20393 .37226 .20544 .37229 .20436 .37123 Mtetra
.607 .72 .925 r
.20436 .37123 .20544 .37229 .20699 .37194 .20591 .37088 Mtetra
.634 .729 .916 r
.20591 .37088 .20699 .37194 .20855 .37148 .20747 .37043 Mtetra
.642 .733 .914 r
.20747 .37043 .20855 .37148 .21012 .371 .20904 .36996 Mtetra
.659 .74 .91 r
.20904 .36996 .21012 .371 .21169 .37044 .21061 .36941 Mtetra
.672 .746 .906 r
.21061 .36941 .21169 .37044 .21327 .36982 .21219 .36882 Mtetra
.682 .753 .905 r
.21219 .36882 .21327 .36982 .21486 .36914 .21377 .36818 Mtetra
.711 .766 .896 r
.21377 .36818 .21486 .36914 .21648 .36812 .21537 .3674 Mtetra
.713 .819 .931 r
.21537 .3674 .21648 .36812 .2181 .3672 .21697 .36664 Mtetra
.681 .851 .964 r
.21697 .36664 .2181 .3672 .21968 .36663 .21856 .36598 Mtetra
.523 .788 .993 r
.21856 .36598 .21968 .36663 .22112 .36745 .22011 .36573 Mtetra
.539 .581 .845 r
.22011 .36573 .22112 .36745 .22244 .36972 .22164 .36568 Mtetra
.545 .433 .676 r
.22164 .36568 .22244 .36972 .22342 .37557 .22318 .36566 Mtetra
.556 .371 .585 r
.22318 .36566 .22342 .37557 .22375 .3884 .22475 .36522 Mtetra
.545 .336 .547 r
.22475 .36522 .22375 .3884 .22572 .38377 .22634 .36456 Mtetra
.55 .343 .553 r
.22634 .36456 .22572 .38377 .22795 .37638 .22794 .36383 Mtetra
.57 .372 .574 r
.22794 .36383 .22795 .37638 .22982 .37275 .22958 .36278 Mtetra
.57 .381 .586 r
.22958 .36278 .22982 .37275 .2315 .37128 .23118 .36199 Mtetra
.541 .363 .588 r
.23118 .36199 .2315 .37128 .23292 .37258 .23273 .3619 Mtetra
.316 .182 .534 r
.23273 .3619 .23292 .37258 .21687 .56611 .23391 .36577 Mtetra
0 0 .144 r
.23391 .36577 .21687 .56611 .21802 .57154 .2172 .56686 Mtetra
0 0 .257 r
.2172 .56686 .21802 .57154 .21946 .57381 .21836 .57215 Mtetra
.191 .417 .851 r
.21836 .57215 .21946 .57381 .22106 .57422 .21994 .57295 Mtetra
.617 .699 .903 r
.21994 .57295 .22106 .57422 .22274 .5739 .22162 .57254 Mtetra
.699 .71 .857 r
.22162 .57254 .22274 .5739 .22444 .57329 .22334 .57171 Mtetra
.656 .665 .847 r
.22334 .57171 .22444 .57329 .22613 .5728 .22504 .57109 Mtetra
.642 .644 .836 r
.22504 .57109 .22613 .5728 .22783 .57222 .22674 .57053 Mtetra
.661 .654 .833 r
.22674 .57053 .22783 .57222 .22956 .57131 .22845 .56987 Mtetra
.659 .686 .864 r
.22845 .56987 .22956 .57131 .23137 .56957 .23016 .56926 Mtetra
.702 .917 .967 r
.23016 .56926 .23137 .56957 .23327 .56668 .23189 .5684 Mtetra
0 0 0 r
.23189 .5684 .23327 .56668 .2354 .56112 .23367 .56687 Mtetra
0 0 .07 r
.23367 .56687 .2354 .56112 .25395 .36252 .23575 .5619 Mtetra
0 0 .142 r
.23575 .5619 .25395 .36252 .25604 .35622 .25459 .35967 Mtetra
.902 .868 .428 r
.25459 .35967 .25604 .35622 .25783 .35339 .2567 .35313 Mtetra
.88 .895 .837 r
.2567 .35313 .25783 .35339 .25948 .35221 .25841 .35127 Mtetra
.661 .765 .926 r
.25841 .35127 .25948 .35221 .26107 .35181 .26001 .35071 Mtetra
.528 .686 .939 r
.26001 .35071 .26107 .35181 .26264 .3517 .26158 .35058 Mtetra
.589 .705 .923 r
.26158 .35058 .26264 .3517 .26422 .3514 .26317 .35029 Mtetra
.637 .722 .91 r
.26317 .35029 .26422 .3514 .26582 .35091 .26477 .34982 Mtetra
.64 .728 .912 r
.26477 .34982 .26582 .35091 .26743 .35038 .26637 .34934 Mtetra
.647 .741 .918 r
.26637 .34934 .26743 .35038 .26904 .34983 .26797 .34883 Mtetra
.657 .752 .92 r
.26797 .34883 .26904 .34983 .27065 .34925 .26958 .34829 Mtetra
.667 .762 .921 r
.26958 .34829 .27065 .34925 .27226 .34862 .27119 .3477 Mtetra
.696 .777 .914 r
.27119 .3477 .27226 .34862 .2739 .34771 .27282 .34699 Mtetra
.707 .824 .937 r
.27282 .34699 .2739 .34771 .27555 .34677 .27445 .34624 Mtetra
.676 .863 .97 r
.27445 .34624 .27555 .34677 .27716 .34614 .27607 .34557 Mtetra
.546 .82 .997 r
.27607 .34557 .27716 .34614 .2787 .34662 .27767 .34523 Mtetra
.53 .631 .895 r
.27767 .34523 .2787 .34662 .28011 .34862 .27924 .34516 Mtetra
.544 .453 .703 r
.27924 .34516 .28011 .34862 .28132 .35347 .28082 .34515 Mtetra
.572 .392 .599 r
.28082 .34515 .28132 .35347 .28237 .36038 .28245 .34447 Mtetra
.559 .356 .562 r
.28245 .34447 .28237 .36038 .28419 .35718 .28409 .34353 Mtetra
.546 .351 .567 r
.28409 .34353 .28419 .35718 .28586 .35615 .2857 .34317 Mtetra
.428 .26 .55 r
.2857 .34317 .28586 .35615 .27317 .54716 .28707 .34586 Mtetra
0 0 .186 r
.28707 .34586 .27317 .54716 .2744 .55323 .27365 .54716 Mtetra
0 0 .292 r
.27365 .54716 .2744 .55323 .27591 .55566 .27485 .55371 Mtetra
.032 .268 .766 r
.27485 .55371 .27591 .55566 .27755 .55635 .27644 .55502 Mtetra
.598 .687 .904 r
.27644 .55502 .27755 .55635 .27926 .55603 .27816 .55468 Mtetra
.706 .718 .859 r
.27816 .55468 .27926 .55603 .28102 .55516 .27991 .5538 Mtetra
.733 .724 .843 r
.27991 .5538 .28102 .55516 .28284 .55335 .28168 .55272 Mtetra
.773 .861 .915 r
.28168 .55272 .28284 .55335 .28476 .55024 .28346 .55158 Mtetra
0 0 0 r
.28346 .55158 .28476 .55024 .28682 .5451 .28524 .55038 Mtetra
.419 .117 .345 r
.28524 .55038 .28682 .5451 .289 .53816 .28701 .54946 Mtetra
.495 .232 .444 r
.28701 .54946 .289 .53816 .29083 .5361 .28874 .54888 Mtetra
.504 .244 .454 r
.28874 .54888 .29083 .5361 .2924 .53794 .29048 .54842 Mtetra
.497 .23 .44 r
.29048 .54842 .2924 .53794 .29404 .53872 .29221 .54794 Mtetra
.49 .218 .428 r
.29221 .54794 .29404 .53872 .29576 .5383 .29395 .54741 Mtetra
.489 .216 .427 r
.29395 .54741 .29576 .5383 .29749 .53791 .29569 .54688 Mtetra
.488 .215 .426 r
.29569 .54688 .29749 .53791 .29922 .53747 .29743 .54634 Mtetra
.487 .214 .424 r
.29743 .54634 .29922 .53747 .30095 .53698 .29918 .54579 Mtetra
.487 .213 .424 r
.29918 .54579 .30095 .53698 .30269 .53646 .30092 .54525 Mtetra
.487 .213 .423 r
.30092 .54525 .30269 .53646 .30443 .53594 .30267 .5447 Mtetra
.487 .212 .423 r
.30267 .5447 .30443 .53594 .30617 .53541 .30441 .54415 Mtetra
.486 .212 .423 r
.30441 .54415 .30617 .53541 .30791 .53487 .30616 .5436 Mtetra
.30616 .5436 .30791 .53487 .30966 .53432 .30791 .54304 Mtetra
.30791 .54304 .30966 .53432 .3114 .53376 .30966 .54249 Mtetra
.30966 .54249 .3114 .53376 .31315 .5332 .31142 .54193 Mtetra
.31142 .54193 .31315 .5332 .3149 .53262 .31317 .54137 Mtetra
.31317 .54137 .3149 .53262 .31665 .53204 .31492 .54081 Mtetra
.31492 .54081 .31665 .53204 .3184 .53143 .31668 .54025 Mtetra
.486 .212 .424 r
.31668 .54025 .3184 .53143 .32016 .53078 .31844 .53968 Mtetra
.486 .213 .424 r
.31844 .53968 .32016 .53078 .32192 .53008 .3202 .53911 Mtetra
.487 .214 .426 r
.3202 .53911 .32192 .53008 .32368 .52939 .32196 .53853 Mtetra
.485 .213 .426 r
.32196 .53853 .32368 .52939 .3255 .52774 .32372 .53791 Mtetra
.488 .221 .435 r
.32372 .53791 .3255 .52774 .3274 .52481 .32549 .53725 Mtetra
.5 .24 .451 r
.32549 .53725 .3274 .52481 .32909 .52535 .32725 .53671 Mtetra
.509 .244 .448 r
.32725 .53671 .32909 .52535 .3305 .53075 .329 .53646 Mtetra
.51 .207 .389 r
.329 .53646 .3305 .53075 .33198 .535 .33072 .53653 Mtetra
.427 0 .087 r
.33072 .53653 .33198 .535 .33359 .53713 .33246 .53657 Mtetra
.43 .785 .997 r
.33246 .53657 .33359 .53713 .33528 .53791 .3342 .53639 Mtetra
.622 .667 .873 r
.3342 .53639 .33528 .53791 .33704 .53768 .33597 .53594 Mtetra
.635 .643 .84 r
.33597 .53594 .33704 .53768 .3388 .53717 .33774 .5354 Mtetra
.638 .641 .837 r
.33774 .5354 .3388 .53717 .34058 .53658 .33951 .53485 Mtetra
.634 .644 .842 r
.33951 .53485 .34058 .53658 .34235 .53605 .34128 .53432 Mtetra
.639 .645 .84 r
.34128 .53432 .34235 .53605 .34412 .53547 .34305 .53376 Mtetra
.617 .64 .85 r
.34305 .53376 .34412 .53547 .3459 .53491 .34482 .53332 Mtetra
.59 .645 .873 r
.34482 .53332 .3459 .53491 .34767 .53439 .34658 .53302 Mtetra
.68 .713 .873 r
.34658 .53302 .34767 .53439 .34946 .53359 .34837 .53228 Mtetra
.83 .752 .778 r
.34837 .53228 .34946 .53359 .35129 .53196 .35023 .53014 Mtetra
.908 .709 .623 r
.35023 .53014 .35129 .53196 .35322 .52845 .35235 .5231 Mtetra
.952 .685 .492 r
.35235 .5231 .35322 .52845 .35533 .52147 .36453 .31872 Mtetra
.539 .313 .521 r
.36453 .31872 .35533 .52147 .36689 .32585 .3664 .31423 Mtetra
.569 .374 .578 r
.3664 .31423 .36689 .32585 .36859 .32489 .36809 .31328 Mtetra
.549 .359 .576 r
.36809 .31328 .36859 .32489 .37022 .32534 .36975 .31293 Mtetra
.551 .358 .573 r
.36975 .31293 .37022 .32534 .37209 .32079 .37142 .31247 Mtetra
.593 .408 .601 r
.37142 .31247 .37209 .32079 .37402 .315 .37312 .31129 Mtetra
.649 .514 .684 r
.37312 .31129 .37402 .315 .37582 .31182 .37482 .31016 Mtetra
.701 .668 .815 r
.37482 .31016 .37582 .31182 .37755 .31 .37652 .30924 Mtetra
.659 .815 .958 r
.37652 .30924 .37755 .31 .37923 .30938 .37819 .30864 Mtetra
.63 .813 .97 r
.37819 .30864 .37923 .30938 .3809 .30904 .37987 .30812 Mtetra
.675 .785 .932 r
.37987 .30812 .3809 .30904 .38257 .30859 .38155 .30748 Mtetra
.736 .759 .871 r
.38155 .30748 .38257 .30859 .38426 .30763 .38325 .3065 Mtetra
.664 .737 .904 r
.38325 .3065 .38426 .30763 .38595 .3069 .38493 .3059 Mtetra
.17 .526 .92 r
.38493 .3059 .38595 .3069 .38761 .30688 .38657 .3064 Mtetra
.914 .521 .241 r
.38657 .3064 .38761 .30688 .38919 .30874 .38802 .3112 Mtetra
.956 .68 .473 r
.38802 .3112 .38919 .30874 .39064 .31368 .38088 .51501 Mtetra
.536 .306 .513 r
.38088 .51501 .39064 .31368 .38402 .5096 .38247 .51934 Mtetra
.511 .239 .438 r
.38247 .51934 .38402 .5096 .38579 .50954 .38425 .51923 Mtetra
.479 .211 .429 r
.38425 .51923 .38579 .50954 .38762 .50803 .38607 .51843 Mtetra
.483 .217 .435 r
.38607 .51843 .38762 .50803 .38931 .5103 .38788 .51761 Mtetra
.515 .227 .415 r
.38788 .51761 .38931 .5103 .39087 .51553 .38966 .51768 Mtetra
.461 .059 .191 r
.38966 .51768 .39087 .51553 .39256 .51799 .39144 .51773 Mtetra
.242 .737 .912 r
.39144 .51773 .39256 .51799 .3943 .51908 .39323 .51761 Mtetra
.613 .676 .886 r
.39323 .51761 .3943 .51908 .39609 .51894 .39503 .5172 Mtetra
.632 .645 .845 r
.39503 .5172 .39609 .51894 .39789 .51846 .39684 .51667 Mtetra
.628 .638 .841 r
.39684 .51667 .39789 .51846 .39971 .51784 .39865 .51616 Mtetra
.574 .628 .868 r
.39865 .51616 .39971 .51784 .40152 .51737 .40045 .51593 Mtetra
.658 .697 .875 r
.40045 .51593 .40152 .51737 .40334 .51662 .40227 .51529 Mtetra
.795 .751 .812 r
.40227 .51529 .40334 .51662 .40518 .51525 .40412 .51363 Mtetra
.91 .726 .642 r
.40412 .51363 .40518 .51525 .40709 .51202 .40612 .50785 Mtetra
.959 .687 .476 r
.40612 .50785 .40709 .51202 .40909 .50607 .41513 .30252 Mtetra
.542 .316 .521 r
.41513 .30252 .40909 .50607 .41766 .30831 .41702 .29641 Mtetra
.575 .378 .577 r
.41702 .29641 .41766 .30831 .41946 .30511 .41875 .29522 Mtetra
.555 .371 .587 r
.41875 .29522 .41946 .30511 .42114 .30532 .42045 .29479 Mtetra
.54 .357 .582 r
.42045 .29479 .42114 .30532 .42274 .30802 .42214 .2947 Mtetra
.55 .355 .569 r
.42214 .2947 .42274 .30802 .42418 .31603 .42384 .29422 Mtetra
.543 .336 .549 r
.42384 .29422 .42418 .31603 .42559 .32519 .42555 .29368 Mtetra
.541 .328 .539 r
.42555 .29368 .42559 .32519 .42795 .30397 .42726 .29294 Mtetra
.579 .384 .582 r
.42726 .29294 .42795 .30397 .42989 .29614 .42899 .29174 Mtetra
.638 .489 .663 r
.42899 .29174 .42989 .29614 .43169 .29247 .43072 .29055 Mtetra
.703 .643 .787 r
.43072 .29055 .43169 .29247 .43345 .29022 .43245 .2895 Mtetra
.673 .834 .961 r
.43245 .2895 .43345 .29022 .43517 .28935 .43416 .28883 Mtetra
.62 .866 .989 r
.43416 .28883 .43517 .28935 .43689 .28882 .43587 .28826 Mtetra
.609 .854 .99 r
.43587 .28826 .43689 .28882 .43859 .28843 .43759 .28773 Mtetra
.653 .834 .97 r
.43759 .28773 .43859 .28843 .44031 .28782 .4393 .28712 Mtetra
.652 .834 .97 r
.4393 .28712 .44031 .28782 .44203 .28723 .44102 .28651 Mtetra
.649 .83 .97 r
.44102 .28651 .44203 .28723 .44374 .28668 .44274 .28592 Mtetra
.638 .816 .968 r
.44274 .28592 .44374 .28668 .44546 .28624 .44446 .28536 Mtetra
.645 .791 .952 r
.44446 .28536 .44546 .28624 .44717 .28581 .44618 .28481 Mtetra
.653 .765 .931 r
.44618 .28481 .44717 .28581 .44889 .28537 .4479 .28424 Mtetra
.668 .744 .907 r
.4479 .28424 .44889 .28537 .45061 .2848 .44962 .2836 Mtetra
.673 .732 .895 r
.44962 .2836 .45061 .2848 .45234 .28417 .45135 .28294 Mtetra
.678 .729 .888 r
.45135 .28294 .45234 .28417 .45406 .28346 .45308 .28225 Mtetra
.749 .752 .855 r
.45308 .28225 .45406 .28346 .4558 .28236 .45481 .28113 Mtetra
.695 .735 .882 r
.45481 .28113 .4558 .28236 .45753 .28148 .45654 .28036 Mtetra
.527 .691 .942 r
.45654 .28036 .45753 .28148 .45926 .28103 .45826 .28022 Mtetra
.843 .385 0 r
.45826 .28022 .45926 .28103 .46095 .28218 .45991 .28345 Mtetra
.964 .681 .449 r
.45991 .28345 .46095 .28218 .4626 .28533 .4575 .48645 Mtetra
.543 .312 .514 r
.4575 .48645 .4626 .28533 .46045 .484 .45917 .49449 Mtetra
.547 .273 .45 r
.45917 .49449 .46045 .484 .46213 .49261 .461 .49533 Mtetra
.456 .082 .24 r
.461 .49533 .46213 .49261 .46392 .49509 .46284 .49523 Mtetra
.311 .802 .799 r
.46284 .49523 .46392 .49509 .46575 .49608 .4647 .49468 Mtetra
.638 .701 .891 r
.4647 .49468 .46575 .49608 .4676 .49568 .46656 .49413 Mtetra
.658 .685 .864 r
.46656 .49413 .4676 .49568 .46946 .49487 .46842 .49346 Mtetra
.669 .712 .88 r
.46842 .49346 .46946 .49487 .47133 .49389 .47028 .49275 Mtetra
.465 .678 .957 r
.47028 .49275 .47133 .49389 .47318 .49397 .47213 .49275 Mtetra
.592 .716 .93 r
.47213 .49275 .47318 .49397 .47503 .49371 .47399 .49239 Mtetra
.741 .749 .858 r
.47399 .49239 .47503 .49371 .4769 .49265 .47586 .49124 Mtetra
.926 .745 .637 r
.47586 .49124 .4769 .49265 .47884 .4868 .4778 .48546 Mtetra
.968 .689 .451 r
.4778 .48546 .47884 .4868 .48348 .27812 .4825 .27743 Mtetra
.96 .777 .611 r
.4825 .27743 .48348 .27812 .4853 .2719 .48432 .27112 Mtetra
.811 .845 .876 r
.48432 .27112 .4853 .2719 .48706 .2706 .48608 .26973 Mtetra
.628 .79 .96 r
.48608 .26973 .48706 .2706 .4888 .2702 .48782 .26922 Mtetra
.496 .712 .967 r
.48782 .26922 .4888 .2702 .49054 .27022 .48957 .26911 Mtetra
.726 .769 .887 r
.48957 .26911 .49054 .27022 .49229 .26946 .49132 .26817 Mtetra
.687 .725 .879 r
.49132 .26817 .49229 .26946 .49404 .26875 .49307 .26742 Mtetra
.553 .662 .909 r
.49307 .26742 .49404 .26875 .49579 .2684 .49482 .26724 Mtetra
.724 .262 0 r
.49482 .26724 .49579 .2684 .49753 .26939 .49654 .27003 Mtetra
.967 .681 .435 r
.49654 .27003 .49753 .26939 .49925 .2722 .49656 .47195 Mtetra
.546 .314 .514 r
.49656 .47195 .49925 .2722 .49951 .46686 .49834 .48166 Mtetra
.549 .286 .47 r
.49834 .48166 .49951 .46686 .50128 .47908 .50021 .48277 Mtetra
.477 .136 .309 r
.50021 .48277 .50128 .47908 .50314 .4818 .50209 .48267 Mtetra
.066 0 0 r
.50209 .48267 .50314 .4818 .50501 .48293 .50397 .48208 Mtetra
.469 .746 .989 r
.50397 .48208 .50501 .48293 .50689 .48307 .50585 .48195 Mtetra
.607 .744 .942 r
.50585 .48195 .50689 .48307 .50877 .48257 .50774 .4815 Mtetra
.752 .798 .89 r
.50774 .4815 .50877 .48257 .51066 .48146 .50963 .48036 Mtetra
.925 .782 .683 r
.50963 .48036 .51066 .48146 .51256 .47906 .51153 .47609 Mtetra
.969 .687 .443 r
.51153 .47609 .51256 .47906 .51445 .47467 .51412 .27294 Mtetra
.552 .323 .522 r
.51412 .27294 .51445 .47467 .51684 .28014 .51592 .26188 Mtetra
.58 .368 .558 r
.51592 .26188 .51684 .28014 .51865 .26515 .5177 .25962 Mtetra
.611 .45 .639 r
.5177 .25962 .51865 .26515 .52042 .26153 .51947 .25857 Mtetra
.618 .528 .731 r
.51947 .25857 .52042 .26153 .5222 .25936 .52123 .25796 Mtetra
.662 .697 .872 r
.52123 .25796 .5222 .25936 .52396 .25829 .523 .25731 Mtetra
.656 .777 .938 r
.523 .25731 .52396 .25829 .52574 .25769 .52478 .25671 Mtetra
.644 .774 .942 r
.52478 .25671 .52574 .25769 .52751 .25728 .52655 .25615 Mtetra
.743 .773 .877 r
.52655 .25615 .52751 .25728 .52928 .25626 .52832 .2551 Mtetra
.714 .758 .887 r
.52832 .2551 .52928 .25626 .53105 .25539 .5301 .25421 Mtetra
.565 .701 .932 r
.5301 .25421 .53105 .25539 .53283 .25516 .53187 .25395 Mtetra
.731 .278 0 r
.53187 .25395 .53283 .25516 .53462 .25847 .53366 .25701 Mtetra
.972 .682 .417 r
.53366 .25701 .53462 .25847 .53717 .46572 .53615 .46348 Mtetra
.885 .522 .041 r
.53615 .46348 .53717 .46572 .53911 .4722 .53808 .47066 Mtetra
.22 .46 .876 r
.53808 .47066 .53911 .4722 .54102 .47287 .54 .47147 Mtetra
.65 .712 .893 r
.54 .47147 .54102 .47287 .54293 .47211 .54191 .47085 Mtetra
.737 .763 .873 r
.54191 .47085 .54293 .47211 .54483 .47089 .54381 .46974 Mtetra
.565 .724 .948 r
.54381 .46974 .54483 .47089 .54675 .47064 .54573 .46944 Mtetra
.557 .711 .943 r
.54573 .46944 .54675 .47064 .54866 .47049 .54764 .46918 Mtetra
.706 .746 .883 r
.54764 .46918 .54866 .47049 .55057 .4697 .54956 .46826 Mtetra
.906 .759 .688 r
.54956 .46826 .55057 .4697 .55246 .46582 .55144 .46423 Mtetra
.972 .687 .427 r
.55144 .46423 .55246 .46582 .55255 .26161 .55158 .2587 Mtetra
.922 .682 .558 r
.55158 .2587 .55255 .26161 .55423 .24895 .55328 .24775 Mtetra
.856 .781 .777 r
.55328 .24775 .55423 .24895 .55601 .24667 .55506 .24552 Mtetra
.682 .754 .906 r
.55506 .24552 .55601 .24667 .5578 .24596 .55685 .2448 Mtetra
.562 .704 .936 r
.55685 .2448 .5578 .24596 .55959 .24574 .55865 .24455 Mtetra
.708 .755 .889 r
.55865 .24455 .55959 .24574 .56139 .24488 .56044 .24368 Mtetra
.72 .757 .881 r
.56044 .24368 .56139 .24488 .56318 .24395 .56223 .24275 Mtetra
.587 .707 .925 r
.56223 .24275 .56318 .24395 .56498 .24365 .56403 .24242 Mtetra
.589 .134 0 r
.56403 .24242 .56498 .24365 .56682 .24635 .56587 .24492 Mtetra
.973 .68 .404 r
.56587 .24492 .56682 .24635 .57158 .45316 .57055 .45051 Mtetra
.888 .544 .054 r
.57055 .45051 .57158 .45316 .57362 .4609 .57261 .45931 Mtetra
.086 .365 .832 r
.57261 .45931 .57362 .4609 .57558 .46192 .57457 .46048 Mtetra
.637 .703 .894 r
.57457 .46048 .57558 .46192 .57751 .46122 .5765 .45992 Mtetra
.732 .759 .874 r
.5765 .45992 .57751 .46122 .57943 .46002 .57843 .45883 Mtetra
.601 .734 .938 r
.57843 .45883 .57943 .46002 .58137 .45961 .58037 .4584 Mtetra
.544 .704 .945 r
.58037 .4584 .58137 .45961 .58332 .45951 .58231 .45818 Mtetra
.691 .743 .891 r
.58231 .45818 .58332 .45951 .58526 .45879 .58425 .45734 Mtetra
.895 .765 .709 r
.58425 .45734 .58526 .45879 .58714 .4554 .58613 .45381 Mtetra
.974 .686 .414 r
.58613 .45381 .58714 .4554 .58867 .43383 .58424 .25432 Mtetra
.568 .336 .523 r
.58424 .25432 .58867 .43383 .58666 .23785 .58572 .23663 Mtetra
.878 .782 .751 r
.58572 .23663 .58666 .23785 .58843 .23516 .58749 .23401 Mtetra
.696 .761 .902 r
.58749 .23401 .58843 .23516 .59023 .23436 .5893 .23321 Mtetra
.573 .713 .937 r
.5893 .23321 .59023 .23436 .59206 .23409 .59113 .23291 Mtetra
.689 .755 .902 r
.59113 .23291 .59206 .23409 .59387 .23333 .59294 .23214 Mtetra
.729 .765 .881 r
.59294 .23214 .59387 .23333 .59568 .23235 .59475 .23115 Mtetra
.613 .722 .923 r
.59475 .23115 .59568 .23235 .5975 .23192 .59657 .23072 Mtetra
0 .063 .598 r
.59657 .23072 .5975 .23192 .59938 .2338 .59845 .2326 Mtetra
.974 .678 .39 r
.59845 .2326 .59938 .2338 .60622 .43435 .60524 .43324 Mtetra
.956 .611 .268 r
.60524 .43324 .60622 .43435 .60854 .4485 .60756 .44737 Mtetra
0 .14 .653 r
.60756 .44737 .60854 .4485 .61056 .45019 .60957 .44907 Mtetra
.598 .749 .949 r
.60957 .44907 .61056 .45019 .61252 .44973 .61153 .44863 Mtetra
.723 .796 .909 r
.61153 .44863 .61252 .44973 .61447 .44874 .61348 .44764 Mtetra
.617 .76 .947 r
.61348 .44764 .61447 .44874 .61643 .44831 .61545 .44713 Mtetra
.524 .702 .951 r
.61545 .44713 .61643 .44831 .61841 .44828 .61742 .44696 Mtetra
.677 .742 .899 r
.61742 .44696 .61841 .44828 .62037 .44763 .61938 .44619 Mtetra
.885 .77 .73 r
.61938 .44619 .62037 .44763 .62227 .44464 .62127 .44307 Mtetra
.971 .718 .493 r
.62127 .44307 .62227 .44464 .62382 .43067 .62275 .42639 Mtetra
.974 .681 .405 r
.62275 .42639 .62382 .43067 .61947 .22652 .61855 .22528 Mtetra
.896 .783 .728 r
.61855 .22528 .61947 .22652 .62122 .22343 .62031 .22227 Mtetra
.709 .767 .897 r
.62031 .22227 .62122 .22343 .62305 .22255 .62213 .22139 Mtetra
.588 .72 .935 r
.62213 .22139 .62305 .22255 .6249 .22221 .62398 .22104 Mtetra
.67 .75 .91 r
.62398 .22104 .6249 .22221 .62673 .22155 .62582 .22035 Mtetra
.736 .769 .879 r
.62582 .22035 .62673 .22155 .62856 .22051 .62764 .21931 Mtetra
.637 .733 .918 r
.62764 .21931 .62856 .22051 .6304 .21997 .62948 .21877 Mtetra
0 .275 .775 r
.62948 .21877 .6304 .21997 .63231 .2213 .63139 .2201 Mtetra
.941 .58 .197 r
.63139 .2201 .63231 .2213 .63454 .2316 .63363 .2305 Mtetra
.975 .675 .374 r
.63363 .2305 .63454 .2316 .64388 .43613 .64291 .435 Mtetra
0 0 .508 r
.64291 .435 .64388 .43613 .64597 .43839 .645 .43726 Mtetra
.617 .756 .945 r
.645 .43726 .64597 .43839 .64796 .43786 .64699 .43675 Mtetra
.758 .805 .891 r
.64699 .43675 .64796 .43786 .64991 .43662 .64895 .43553 Mtetra
.763 .811 .891 r
.64895 .43553 .64991 .43662 .65187 .43535 .65091 .43428 Mtetra
.693 .797 .929 r
.65091 .43428 .65187 .43535 .65385 .43448 .65289 .43344 Mtetra
.683 .8 .937 r
.65289 .43344 .65385 .43448 .65583 .43366 .65487 .43264 Mtetra
.653 .794 .95 r
.65487 .43264 .65583 .43366 .65781 .43298 .65685 .43196 Mtetra
.615 .78 .96 r
.65685 .43196 .65781 .43298 .65981 .43248 .65885 .43143 Mtetra
.601 .768 .96 r
.65885 .43143 .65981 .43248 .6618 .43205 .66084 .43096 Mtetra
.504 .717 .967 r
.66084 .43096 .6618 .43205 .66382 .43195 .66286 .43081 Mtetra
.451 .679 .962 r
.66286 .43081 .66382 .43195 .66584 .43201 .66488 .43083 Mtetra
.649 .761 .931 r
.66488 .43083 .66584 .43201 .66784 .43138 .66688 .43019 Mtetra
.896 .807 .753 r
.66688 .43019 .66784 .43138 .66973 .42841 .66877 .4273 Mtetra
.977 .682 .379 r
.66877 .4273 .66973 .42841 .66251 .22367 .6618 .22688 Mtetra
.97 .756 .324 r
.6618 .22688 .66251 .22367 .66378 .21 .6629 .20916 Mtetra
.933 .841 .73 r
.6629 .20916 .66378 .21 .66553 .20701 .66465 .20605 Mtetra
.694 .808 .936 r
.66465 .20605 .66553 .20701 .6674 .20631 .66651 .20525 Mtetra
.547 .727 .958 r
.66651 .20525 .6674 .20631 .66928 .20617 .66839 .205 Mtetra
.543 .701 .943 r
.66839 .205 .66928 .20617 .67118 .20605 .67028 .20479 Mtetra
.649 .731 .909 r
.67028 .20479 .67118 .20605 .67305 .20546 .67215 .20419 Mtetra
.658 .732 .904 r
.67215 .20419 .67305 .20546 .67491 .20479 .67402 .20355 Mtetra
.708 .757 .89 r
.67402 .20355 .67491 .20479 .67677 .20382 .67588 .20266 Mtetra
.756 .786 .878 r
.67588 .20266 .67677 .20382 .67861 .20255 .67772 .2015 Mtetra
.668 .78 .933 r
.67772 .2015 .67861 .20255 .68047 .20176 .67959 .20081 Mtetra
.038 .444 .874 r
.67959 .20081 .68047 .20176 .68242 .20246 .68155 .20164 Mtetra
.916 .525 .128 r
.68155 .20164 .68242 .20246 .68469 .20933 .68387 .20947 Mtetra
.975 .669 .353 r
.68387 .20947 .68469 .20933 .69776 .41854 .69683 .41762 Mtetra
.702 .22 0 r
.69683 .41762 .69776 .41854 .7 .42199 .69906 .42085 Mtetra
.398 .649 .959 r
.69906 .42085 .7 .42199 .70206 .42218 .70112 .42101 Mtetra
.709 .788 .913 r
.70112 .42101 .70206 .42218 .70407 .42124 .70313 .42007 Mtetra
.889 .818 .772 r
.70313 .42007 .70407 .42124 .70598 .41857 .70504 .41741 Mtetra
.979 .757 .532 r
.70504 .41741 .70598 .41857 .70751 .40916 .70657 .40804 Mtetra
.977 .678 .362 r
.70657 .40804 .70751 .40916 .6976 .19989 .69672 .19867 Mtetra
.938 .789 .669 r
.69672 .19867 .6976 .19989 .69929 .19579 .69841 .19456 Mtetra
.732 .769 .882 r
.69841 .19456 .69929 .19579 .70116 .19475 .70027 .19352 Mtetra
.605 .718 .925 r
.70027 .19352 .70116 .19475 .70306 .19433 .70218 .1931 Mtetra
.603 .718 .925 r
.70218 .1931 .70306 .19433 .70496 .19391 .70408 .19268 Mtetra
.743 .772 .877 r
.70408 .19268 .70496 .19391 .70682 .19281 .70594 .19158 Mtetra
.66 .743 .911 r
.70594 .19158 .70682 .19281 .70871 .19215 .70784 .19092 Mtetra
.238 .516 .911 r
.70784 .19092 .70871 .19215 .71069 .19279 .70981 .19156 Mtetra
.879 .484 .028 r
.70981 .19156 .71069 .19279 .71306 .19981 .71218 .19865 Mtetra
.975 .667 .334 r
.71218 .19865 .71306 .19981 .72814 .40868 .72721 .40751 Mtetra
.648 .191 0 r
.72721 .40751 .72814 .40868 .73043 .4121 .7295 .41091 Mtetra
.529 .711 .955 r
.7295 .41091 .73043 .4121 .7325 .41189 .73158 .41071 Mtetra
.699 .785 .917 r
.73158 .41071 .7325 .41189 .73453 .411 .7336 .4098 Mtetra
.71 .787 .912 r
.7336 .4098 .73453 .411 .73656 .41009 .73563 .40884 Mtetra
.495 .681 .949 r
.73563 .40884 .73656 .41009 .73865 .41015 .73771 .40877 Mtetra
.628 .72 .913 r
.73771 .40877 .73865 .41015 .74071 .40971 .73977 .40822 Mtetra
.809 .767 .814 r
.73977 .40822 .74071 .40971 .74269 .408 .74174 .40637 Mtetra
.963 .75 .568 r
.74174 .40637 .74269 .408 .7443 .40087 .74331 .39871 Mtetra
.977 .674 .347 r
.74331 .39871 .7443 .40087 .73183 .189 .73094 .1874 Mtetra
.935 .756 .636 r
.73094 .1874 .73183 .189 .73343 .18382 .73256 .18253 Mtetra
.745 .764 .868 r
.73256 .18253 .73343 .18382 .73531 .18265 .73444 .18138 Mtetra
.617 .719 .918 r
.73444 .18138 .73531 .18265 .73723 .18217 .73636 .18091 Mtetra
.578 .701 .926 r
.73636 .18091 .73723 .18217 .73916 .18185 .7383 .18058 Mtetra
.748 .771 .872 r
.7383 .18058 .73916 .18185 .74104 .18069 .74018 .17943 Mtetra
.674 .745 .904 r
.74018 .17943 .74104 .18069 .74295 .17996 .74209 .1787 Mtetra
.377 .596 .932 r
.74209 .1787 .74295 .17996 .74494 .18027 .74408 .17901 Mtetra
.821 .412 0 r
.74408 .17901 .74494 .18027 .74733 .18608 .74647 .18485 Mtetra
.973 .662 .315 r
.74647 .18485 .74733 .18608 .76498 .39621 .76407 .39502 Mtetra
.7 .255 0 r
.76407 .39502 .76498 .39621 .7674 .4003 .76649 .3991 Mtetra
.503 .696 .955 r
.76649 .3991 .7674 .4003 .76951 .40018 .7686 .39898 Mtetra
.69 .782 .921 r
.7686 .39898 .76951 .40018 .77156 .39932 .77065 .39812 Mtetra
.731 .795 .903 r
.77065 .39812 .77156 .39932 .77361 .39828 .77269 .39703 Mtetra
.488 .678 .95 r
.77269 .39703 .77361 .39828 .77574 .39836 .77481 .39698 Mtetra
.614 .716 .918 r
.77481 .39698 .77574 .39836 .77783 .39797 .7769 .39647 Mtetra
.776 .761 .839 r
.7769 .39647 .77783 .39797 .77985 .39657 .77891 .39495 Mtetra
.961 .758 .583 r
.77891 .39495 .77985 .39657 .78147 .3902 .7805 .38815 Mtetra
.976 .67 .328 r
.7805 .38815 .78147 .3902 .76648 .17763 .76559 .17592 Mtetra
.945 .749 .607 r
.76559 .17592 .76648 .17763 .76798 .17161 .76713 .17029 Mtetra
.758 .769 .861 r
.76713 .17029 .76798 .17161 .76986 .17033 .76901 .16904 Mtetra
.629 .723 .915 r
.76901 .16904 .76986 .17033 .77181 .16979 .77096 .16851 Mtetra
.552 .687 .929 r
.77096 .16851 .77181 .16979 .77378 .16957 .77293 .16828 Mtetra
.75 .772 .871 r
.77293 .16828 .77378 .16957 .77567 .16839 .77483 .16711 Mtetra
.682 .748 .901 r
.77483 .16711 .77567 .16839 .7776 .1676 .77676 .16632 Mtetra
.475 .648 .934 r
.77676 .16632 .7776 .1676 .7796 .16763 .77876 .16636 Mtetra
.757 .341 0 r
.77876 .16636 .7796 .16763 .78204 .17272 .78119 .17145 Mtetra
.971 .656 .295 r
.78119 .17145 .78204 .17272 .8023 .38373 .80141 .38252 Mtetra
.732 .299 0 r
.80141 .38252 .8023 .38373 .80486 .3885 .80397 .38729 Mtetra
.3 .577 .937 r
.80397 .38729 .80486 .3885 .80706 .38899 .80617 .38777 Mtetra
.647 .764 .934 r
.80617 .38777 .80706 .38899 .80915 .38832 .80826 .3871 Mtetra
.828 .822 .843 r
.80826 .3871 .80915 .38832 .81115 .38649 .81026 .38527 Mtetra
.908 .737 .658 r
.14207 .59559 .14325 .59654 .14548 .59081 .14429 .58987 Mtetra
.936 .686 .535 r
.14429 .58987 .14548 .59081 .16942 .38884 .16832 .38786 Mtetra
.909 .729 .646 r
.16832 .38786 .16942 .38884 .17157 .38283 .17048 .38182 Mtetra
.772 .762 .843 r
.17048 .38182 .17157 .38283 .1732 .38162 .1721 .38062 Mtetra
.634 .738 .923 r
.1721 .38062 .1732 .38162 .17474 .38118 .17364 .38018 Mtetra
.495 .691 .955 r
.17364 .38018 .17474 .38118 .17624 .38111 .17514 .38011 Mtetra
.736 .761 .873 r
.17514 .38011 .17624 .38111 .17784 .3801 .17674 .37919 Mtetra
.693 .773 .913 r
.17674 .37919 .17784 .3801 .17941 .37941 .17831 .37852 Mtetra
.505 .722 .97 r
.17831 .37852 .17941 .37941 .18091 .37941 .17982 .3784 Mtetra
.869 .425 .056 r
.17982 .3784 .18091 .37941 .18194 .38384 .18103 .38105 Mtetra
.941 .685 .522 r
.18103 .38105 .18194 .38384 .16201 .58506 .16191 .57404 Mtetra
0 0 .126 r
.16191 .57404 .16201 .58506 .16307 .59012 .16223 .58601 Mtetra
.328 .29 .663 r
.16223 .58601 .16307 .59012 .16465 .59034 .16368 .58742 Mtetra
.494 .456 .744 r
.16368 .58742 .16465 .59034 .16633 .58964 .16525 .58769 Mtetra
.58 .585 .822 r
.16525 .58769 .16633 .58964 .16805 .58852 .16688 .58746 Mtetra
.418 .66 .96 r
.16688 .58746 .16805 .58852 .16967 .5884 .16848 .58755 Mtetra
.594 .775 .967 r
.16848 .58755 .16967 .5884 .17131 .58803 .17013 .58717 Mtetra
.773 .802 .876 r
.17013 .58717 .17131 .58803 .17303 .58695 .17186 .58599 Mtetra
.908 .743 .665 r
.17186 .58599 .17303 .58695 .17518 .58168 .17401 .58068 Mtetra
.939 .687 .529 r
.17401 .58068 .17518 .58168 .19747 .37943 .19639 .37833 Mtetra
.91 .724 .639 r
.19639 .37833 .19747 .37943 .19964 .37301 .19856 .37194 Mtetra
.789 .755 .822 r
.19856 .37194 .19964 .37301 .20129 .37162 .20021 .37055 Mtetra
.626 .723 .917 r
.20021 .37055 .20129 .37162 .20285 .37121 .20177 .37013 Mtetra
.467 .663 .947 r
.20177 .37013 .20285 .37121 .20436 .37123 .20328 .37015 Mtetra
.61 .716 .921 r
.20328 .37015 .20436 .37123 .20591 .37088 .20483 .36979 Mtetra
.635 .723 .911 r
.20483 .36979 .20591 .37088 .20747 .37043 .20639 .36934 Mtetra
.642 .724 .908 r
.20639 .36934 .20747 .37043 .20904 .36996 .20796 .36886 Mtetra
.656 .729 .903 r
.20796 .36886 .20904 .36996 .21061 .36941 .20953 .36833 Mtetra
.666 .733 .9 r
.20953 .36833 .21061 .36941 .21219 .36882 .21111 .36775 Mtetra
.674 .739 .899 r
.21111 .36775 .21219 .36882 .21377 .36818 .21269 .36714 Mtetra
.679 .746 .902 r
.21269 .36714 .21377 .36818 .21537 .3674 .21428 .36651 Mtetra
.687 .778 .92 r
.21428 .36651 .21537 .3674 .21697 .36664 .21587 .36585 Mtetra
.694 .802 .932 r
.21587 .36585 .21697 .36664 .21856 .36598 .21746 .36516 Mtetra
.706 .797 .921 r
.21746 .36516 .21856 .36598 .22011 .36573 .21906 .36443 Mtetra
.693 .702 .854 r
.21906 .36443 .22011 .36573 .22164 .36568 .22066 .36368 Mtetra
.663 .608 .782 r
.22066 .36368 .22164 .36568 .22318 .36566 .22226 .36294 Mtetra
.634 .542 .733 r
.22226 .36294 .22318 .36566 .22475 .36522 .22385 .36227 Mtetra
.624 .524 .72 r
.22385 .36227 .22475 .36522 .22634 .36456 .22544 .36163 Mtetra
.622 .524 .722 r
.22544 .36163 .22634 .36456 .22794 .36383 .22703 .36102 Mtetra
.653 .548 .723 r
.22703 .36102 .22794 .36383 .22958 .36278 .22865 .36014 Mtetra
.642 .551 .736 r
.22865 .36014 .22958 .36278 .23118 .36199 .23025 .35941 Mtetra
.579 .52 .752 r
.23025 .35941 .23118 .36199 .23273 .3619 .23181 .35917 Mtetra
0 .103 .634 r
.23181 .35917 .23273 .3619 .23391 .36577 .23317 .36113 Mtetra
.955 .677 .232 r
.23317 .36113 .23391 .36577 .2172 .56686 .23379 .3712 Mtetra
0 0 .144 r
.23379 .3712 .2172 .56686 .21836 .57215 .21753 .56763 Mtetra
.369 .306 .655 r
.21753 .56763 .21836 .57215 .21994 .57295 .21905 .56898 Mtetra
.596 .477 .687 r
.21905 .56898 .21994 .57295 .22162 .57254 .22074 .56845 Mtetra
.628 .494 .68 r
.22074 .56845 .22162 .57254 .22334 .57171 .22247 .56752 Mtetra
.517 .418 .681 r
.22247 .56752 .22334 .57171 .22504 .57109 .2241 .56775 Mtetra
.45 .408 .719 r
.2241 .56775 .22504 .57109 .22674 .57053 .2257 .56834 Mtetra
.446 .49 .812 r
.2257 .56834 .22674 .57053 .22845 .56987 .22732 .5687 Mtetra
.433 .644 .946 r
.22732 .5687 .22845 .56987 .23016 .56926 .22896 .5688 Mtetra
.486 .829 .998 r
.22896 .5688 .23016 .56926 .23189 .5684 .23064 .56849 Mtetra
.63 .956 .923 r
.23064 .56849 .23189 .5684 .23367 .56687 .23238 .56758 Mtetra
.936 .965 .739 r
.23238 .56758 .23367 .56687 .23575 .5619 .23428 .56468 Mtetra
.989 .875 .531 r
.23428 .56468 .23575 .5619 .25459 .35967 .23661 .55678 Mtetra
0 0 .138 r
.23661 .55678 .25459 .35967 .2567 .35313 .25531 .35588 Mtetra
.649 .786 .329 r
.25531 .35588 .2567 .35313 .25841 .35127 .25719 .35211 Mtetra
.68 .952 .696 r
.25719 .35211 .25841 .35127 .26001 .35071 .25888 .35047 Mtetra
.753 .934 .946 r
.25888 .35047 .26001 .35071 .26158 .35058 .26052 .34947 Mtetra
.676 .735 .895 r
.26052 .34947 .26158 .35058 .26317 .35029 .26214 .34884 Mtetra
.621 .658 .865 r
.26214 .34884 .26317 .35029 .26477 .34982 .26373 .34844 Mtetra
.589 .656 .883 r
.26373 .34844 .26477 .34982 .26637 .34934 .26532 .34816 Mtetra
.616 .703 .907 r
.26532 .34816 .26637 .34934 .26797 .34883 .26691 .34777 Mtetra
.645 .736 .916 r
.26691 .34777 .26797 .34883 .26958 .34829 .26852 .34727 Mtetra
.656 .749 .918 r
.26852 .34727 .26958 .34829 .27119 .3477 .27013 .34673 Mtetra
.665 .761 .921 r
.27013 .34673 .27119 .3477 .27282 .34699 .27174 .34615 Mtetra
.674 .791 .937 r
.27174 .34615 .27282 .34699 .27445 .34624 .27336 .34553 Mtetra
.684 .823 .95 r
.27336 .34553 .27445 .34624 .27607 .34557 .27498 .34486 Mtetra
.703 .827 .942 r
.27498 .34486 .27607 .34557 .27767 .34523 .27661 .34413 Mtetra
.704 .744 .882 r
.27661 .34413 .27767 .34523 .27924 .34516 .27824 .34335 Mtetra
.674 .634 .802 r
.27824 .34335 .27924 .34516 .28082 .34515 .27988 .34258 Mtetra
.667 .571 .737 r
.27988 .34258 .28082 .34515 .28245 .34447 .28152 .34163 Mtetra
.651 .547 .724 r
.28152 .34163 .28245 .34447 .28409 .34353 .28317 .34076 Mtetra
.599 .521 .738 r
.28317 .34076 .28409 .34353 .2857 .34317 .28477 .34036 Mtetra
.238 .293 .718 r
.28477 .34036 .2857 .34317 .28707 .34586 .28626 .34166 Mtetra
.76 .507 0 r
.28626 .34166 .28707 .34586 .27365 .54716 .28736 .34801 Mtetra
0 0 .182 r
.28736 .34801 .27365 .54716 .27485 .55371 .27401 .54868 Mtetra
.081 .091 .568 r
.27401 .54868 .27485 .55371 .27644 .55502 .27547 .55184 Mtetra
.432 .406 .731 r
.27547 .55184 .27644 .55502 .27816 .55468 .27711 .55251 Mtetra
.528 .54 .811 r
.27711 .55251 .27816 .55468 .27991 .5538 .2788 .55253 Mtetra
.571 .686 .919 r
.2788 .55253 .27991 .5538 .28168 .55272 .28051 .55228 Mtetra
.521 .848 .998 r
.28051 .55228 .28168 .55272 .28346 .55158 .28224 .55188 Mtetra
.247 .755 .728 r
.28224 .55188 .28346 .55158 .28524 .55038 .28397 .55136 Mtetra
.09 0 0 r
.28397 .55136 .28524 .55038 .28701 .54946 .28571 .55082 Mtetra
.208 0 0 r
.28571 .55082 .28701 .54946 .28874 .54888 .28745 .55029 Mtetra
.212 0 0 r
.28745 .55029 .28874 .54888 .29048 .54842 .28919 .54974 Mtetra
.191 0 0 r
.28919 .54974 .29048 .54842 .29221 .54794 .29093 .54919 Mtetra
.175 0 0 r
.29093 .54919 .29221 .54794 .29395 .54741 .29267 .54864 Mtetra
.172 0 0 r
.29267 .54864 .29395 .54741 .29569 .54688 .29441 .5481 Mtetra
.169 0 0 r
.29441 .5481 .29569 .54688 .29743 .54634 .29616 .54755 Mtetra
.166 0 0 r
.29616 .54755 .29743 .54634 .29918 .54579 .2979 .547 Mtetra
.164 0 0 r
.2979 .547 .29918 .54579 .30092 .54525 .29965 .54645 Mtetra
.163 0 0 r
.29965 .54645 .30092 .54525 .30267 .5447 .3014 .5459 Mtetra
.162 0 0 r
.3014 .5459 .30267 .5447 .30441 .54415 .30315 .54535 Mtetra
.30315 .54535 .30441 .54415 .30616 .5436 .3049 .5448 Mtetra
.161 0 0 r
.3049 .5448 .30616 .5436 .30791 .54304 .30665 .54425 Mtetra
.30665 .54425 .30791 .54304 .30966 .54249 .3084 .54369 Mtetra
.16 0 0 r
.3084 .54369 .30966 .54249 .31142 .54193 .31015 .54314 Mtetra
.31015 .54314 .31142 .54193 .31317 .54137 .31191 .54258 Mtetra
.31191 .54258 .31317 .54137 .31492 .54081 .31367 .54202 Mtetra
.31367 .54202 .31492 .54081 .31668 .54025 .31542 .54146 Mtetra
.31542 .54146 .31668 .54025 .31844 .53968 .31718 .5409 Mtetra
.161 0 0 r
.31718 .5409 .31844 .53968 .3202 .53911 .31894 .54033 Mtetra
.163 0 0 r
.31894 .54033 .3202 .53911 .32196 .53853 .3207 .53977 Mtetra
.167 0 0 r
.3207 .53977 .32196 .53853 .32372 .53791 .32247 .5392 Mtetra
.183 0 0 r
.32247 .5392 .32372 .53791 .32549 .53725 .32423 .53864 Mtetra
.198 0 0 r
.32423 .53864 .32549 .53725 .32725 .53671 .326 .53806 Mtetra
.19 0 0 r
.326 .53806 .32725 .53671 .329 .53646 .32776 .53747 Mtetra
.078 0 0 r
.32776 .53747 .329 .53646 .33072 .53653 .32953 .53687 Mtetra
.353 .821 .754 r
.32953 .53687 .33072 .53653 .33246 .53657 .33131 .53615 Mtetra
.748 .912 .948 r
.33131 .53615 .33246 .53657 .3342 .53639 .33311 .53511 Mtetra
.785 .751 .821 r
.33311 .53511 .3342 .53639 .33597 .53594 .33493 .53359 Mtetra
.74 .633 .741 r
.33493 .53359 .33597 .53594 .33774 .5354 .33677 .53189 Mtetra
.676 .544 .696 r
.33677 .53189 .33774 .5354 .33951 .53485 .33858 .53047 Mtetra
.602 .471 .675 r
.33858 .53047 .33951 .53485 .34128 .53432 .34036 .52979 Mtetra
.581 .454 .672 r
.34036 .52979 .34128 .53432 .34305 .53376 .34213 .52936 Mtetra
.559 .442 .677 r
.34213 .52936 .34305 .53376 .34482 .53332 .34388 .52919 Mtetra
.55 .444 .686 r
.34388 .52919 .34482 .53332 .34658 .53302 .34563 .52911 Mtetra
.614 .492 .691 r
.34563 .52911 .34658 .53302 .34837 .53228 .34742 .52838 Mtetra
.748 .576 .662 r
.34742 .52838 .34837 .53228 .35023 .53014 .34933 .52536 Mtetra
.953 .685 .492 r
.34933 .52536 .35023 .53014 .35235 .5231 .36155 .32363 Mtetra
.549 .322 .522 r
.36155 .32363 .35235 .5231 .36453 .31872 .36367 .31427 Mtetra
.726 .545 .646 r
.36367 .31427 .36453 .31872 .3664 .31423 .36546 .31138 Mtetra
.651 .549 .726 r
.36546 .31138 .3664 .31423 .36809 .31328 .36715 .31049 Mtetra
.6 .523 .74 r
.36715 .31049 .36809 .31328 .36975 .31293 .36881 .31007 Mtetra
.586 .511 .737 r
.36881 .31007 .36975 .31293 .37142 .31247 .37047 .30975 Mtetra
.621 .539 .741 r
.37047 .30975 .37142 .31247 .37312 .31129 .37215 .30917 Mtetra
.634 .59 .787 r
.37215 .30917 .37312 .31129 .37482 .31016 .37382 .3086 Mtetra
.656 .662 .844 r
.37382 .3086 .37482 .31016 .37652 .30924 .3755 .30799 Mtetra
.68 .719 .879 r
.3755 .30799 .37652 .30924 .37819 .30864 .37719 .3073 Mtetra
.658 .697 .875 r
.37719 .3073 .37819 .30864 .37987 .30812 .37886 .30671 Mtetra
.62 .67 .876 r
.37886 .30671 .37987 .30812 .38155 .30748 .38054 .30629 Mtetra
.541 .679 .928 r
.38054 .30629 .38155 .30748 .38325 .3065 .3822 .30614 Mtetra
0 .463 .757 r
.3822 .30614 .38325 .3065 .38493 .3059 .38384 .30654 Mtetra
.767 .324 .198 r
.38384 .30654 .38493 .3059 .38657 .3064 .3854 .30866 Mtetra
.956 .68 .473 r
.3854 .30866 .38657 .3064 .38802 .3112 .37823 .50925 Mtetra
.545 .313 .515 r
.37823 .50925 .38802 .3112 .38088 .51501 .37961 .51812 Mtetra
.676 .321 .366 r
.37961 .51812 .38088 .51501 .38247 .51934 .3813 .52029 Mtetra
.309 0 0 r
.3813 .52029 .38247 .51934 .38425 .51923 .38308 .5202 Mtetra
.05 0 0 r
.38308 .5202 .38425 .51923 .38607 .51843 .38489 .51956 Mtetra
.015 0 0 r
.38489 .51956 .38607 .51843 .38788 .51761 .3867 .51873 Mtetra
.139 0 0 r
.3867 .51873 .38788 .51761 .38966 .51768 .38851 .51816 Mtetra
0 0 0 r
.38851 .51816 .38966 .51768 .39144 .51773 .39032 .51745 Mtetra
.701 .939 .962 r
.39032 .51745 .39144 .51773 .39323 .51761 .39214 .51649 Mtetra
.791 .782 .844 r
.39214 .51649 .39323 .51761 .39503 .5172 .39399 .51502 Mtetra
.747 .651 .754 r
.39399 .51502 .39503 .5172 .39684 .51667 .39584 .51335 Mtetra
.683 .556 .705 r
.39584 .51335 .39684 .51667 .39865 .51616 .39769 .5119 Mtetra
.557 .446 .683 r
.39769 .5119 .39865 .51616 .40045 .51593 .39948 .51174 Mtetra
.59 .47 .684 r
.39948 .51174 .40045 .51593 .40227 .51529 .40129 .51124 Mtetra
.696 .541 .673 r
.40129 .51124 .40227 .51529 .40412 .51363 .40316 .50924 Mtetra
.936 .676 .518 r
.40316 .50924 .40412 .51363 .40612 .50785 .40621 .47429 Mtetra
.919 .644 .504 r
.40621 .47429 .40612 .50785 .41513 .30252 .41427 .29709 Mtetra
.726 .53 .626 r
.41427 .29709 .41513 .30252 .41702 .29641 .41608 .29353 Mtetra
.661 .554 .723 r
.41608 .29353 .41702 .29641 .41875 .29522 .4178 .29253 Mtetra
.608 .535 .747 r
.4178 .29253 .41875 .29522 .42045 .29479 .4195 .29205 Mtetra
.58 .515 .747 r
.4195 .29205 .42045 .29479 .42214 .2947 .42119 .29178 Mtetra
.617 .527 .73 r
.42119 .29178 .42214 .2947 .42384 .29422 .4229 .29119 Mtetra
.613 .519 .724 r
.4229 .29119 .42384 .29422 .42555 .29368 .42461 .29062 Mtetra
.609 .515 .723 r
.42461 .29062 .42555 .29368 .42726 .29294 .42632 .29008 Mtetra
.606 .524 .736 r
.42632 .29008 .42726 .29294 .42899 .29174 .42802 .28959 Mtetra
.619 .582 .791 r
.42802 .28959 .42899 .29174 .43072 .29055 .42973 .28912 Mtetra
.635 .677 .872 r
.42973 .28912 .43072 .29055 .43245 .2895 .43144 .28862 Mtetra
.648 .79 .95 r
.43144 .28862 .43245 .2895 .43416 .28883 .43315 .28806 Mtetra
.655 .817 .961 r
.43315 .28806 .43416 .28883 .43587 .28826 .43487 .28745 Mtetra
.669 .814 .953 r
.43487 .28745 .43587 .28826 .43759 .28773 .43658 .28681 Mtetra
.687 .792 .93 r
.43658 .28681 .43759 .28773 .4393 .28712 .4383 .2861 Mtetra
.69 .772 .914 r
.4383 .2861 .4393 .28712 .44102 .28651 .44003 .28537 Mtetra
.685 .747 .898 r
.44003 .28537 .44102 .28651 .44274 .28592 .44175 .28466 Mtetra
.669 .72 .887 r
.44175 .28466 .44274 .28592 .44446 .28536 .44347 .28401 Mtetra
.663 .701 .875 r
.44347 .28401 .44446 .28536 .44618 .28481 .44519 .28338 Mtetra
.662 .688 .864 r
.44519 .28338 .44618 .28481 .4479 .28424 .44692 .28274 Mtetra
.683 .687 .847 r
.44692 .28274 .4479 .28424 .44962 .2836 .44864 .28197 Mtetra
.664 .661 .837 r
.44864 .28197 .44962 .2836 .45135 .28294 .45037 .28129 Mtetra
.634 .646 .845 r
.45037 .28129 .45135 .28294 .45308 .28225 .45209 .28078 Mtetra
.588 .653 .881 r
.45209 .28078 .45308 .28225 .45481 .28113 .45381 .28049 Mtetra
.239 .657 .96 r
.45381 .28049 .45481 .28113 .45654 .28036 .45552 .28067 Mtetra
.633 .1 0 r
.45552 .28067 .45654 .28036 .45826 .28022 .45721 .28183 Mtetra
.917 .592 .413 r
.45721 .28183 .45826 .28022 .45991 .28345 .45866 .29473 Mtetra
.951 .666 .463 r
.45866 .29473 .45991 .28345 .4575 .48645 .4563 .49234 Mtetra
.664 .349 .429 r
.4563 .49234 .4575 .48645 .45917 .49449 .45807 .49547 Mtetra
.296 0 0 r
.45807 .49547 .45917 .49449 .461 .49533 .45992 .49533 Mtetra
.536 .921 .911 r
.45992 .49533 .461 .49533 .46284 .49523 .46178 .49453 Mtetra
.76 .868 .927 r
.46178 .49453 .46284 .49523 .4647 .49468 .46365 .49341 Mtetra
.603 .712 .921 r
.46365 .49341 .4647 .49468 .46656 .49413 .4655 .49301 Mtetra
.609 .743 .94 r
.4655 .49301 .46656 .49413 .46842 .49346 .46736 .49257 Mtetra
.648 .804 .958 r
.46736 .49257 .46842 .49346 .47028 .49275 .46922 .49195 Mtetra
.72 .841 .939 r
.46922 .49195 .47028 .49275 .47213 .49275 .47109 .49102 Mtetra
.753 .698 .8 r
.47109 .49102 .47213 .49275 .47399 .49239 .47296 .48958 Mtetra
.766 .625 .704 r
.47296 .48958 .47399 .49239 .47586 .49124 .47486 .48713 Mtetra
.883 .649 .58 r
.47486 .48713 .47586 .49124 .4778 .48546 .47686 .47674 Mtetra
.96 .68 .461 r
.47686 .47674 .4778 .48546 .4825 .27743 .48155 .27438 Mtetra
.825 .637 .648 r
.48155 .27438 .4825 .27743 .48432 .27112 .48334 .2701 Mtetra
.78 .795 .865 r
.48334 .2701 .48432 .27112 .48608 .26973 .4851 .26884 Mtetra
.65 .792 .95 r
.4851 .26884 .48608 .26973 .48782 .26922 .48685 .26826 Mtetra
.56 .743 .962 r
.48685 .26826 .48782 .26922 .48957 .26911 .48859 .26797 Mtetra
.754 .77 .866 r
.48859 .26797 .48957 .26911 .49132 .26817 .49035 .26685 Mtetra
.706 .724 .864 r
.49035 .26685 .49132 .26817 .49307 .26742 .4921 .26597 Mtetra
.561 .647 .892 r
.4921 .26597 .49307 .26742 .49482 .26724 .49385 .26578 Mtetra
.788 .365 0 r
.49385 .26578 .49482 .26724 .49654 .27003 .49556 .26946 Mtetra
.969 .682 .433 r
.49556 .26946 .49654 .27003 .49656 .47195 .49547 .47651 Mtetra
.777 .446 .425 r
.49547 .47651 .49656 .47195 .49834 .48166 .49729 .48269 Mtetra
.471 0 0 r
.49729 .48269 .49834 .48166 .50021 .48277 .49916 .48309 Mtetra
.327 .803 .731 r
.49916 .48309 .50021 .48277 .50209 .48267 .50104 .48233 Mtetra
.763 .946 .939 r
.50104 .48233 .50209 .48267 .50397 .48208 .50293 .48112 Mtetra
.499 .733 .977 r
.50293 .48112 .50397 .48208 .50585 .48195 .50481 .48096 Mtetra
.557 .753 .969 r
.50481 .48096 .50585 .48195 .50774 .4815 .5067 .48065 Mtetra
.742 .839 .924 r
.5067 .48065 .50774 .4815 .50963 .48036 .50859 .4796 Mtetra
.954 .799 .651 r
.50859 .4796 .50963 .48036 .51153 .47609 .5105 .47446 Mtetra
.97 .688 .441 r
.5105 .47446 .51153 .47609 .51412 .27294 .51318 .2659 Mtetra
.777 .549 .59 r
.51318 .2659 .51412 .27294 .51592 .26188 .51497 .25883 Mtetra
.705 .574 .705 r
.51497 .25883 .51592 .26188 .5177 .25962 .51674 .25721 Mtetra
.612 .56 .772 r
.51674 .25721 .5177 .25962 .51947 .25857 .5185 .25673 Mtetra
.534 .576 .843 r
.5185 .25673 .51947 .25857 .52123 .25796 .52027 .2567 Mtetra
.619 .707 .908 r
.52027 .2567 .52123 .25796 .523 .25731 .52204 .25625 Mtetra
.66 .762 .926 r
.52204 .25625 .523 .25731 .52478 .25671 .52382 .25564 Mtetra
.671 .764 .92 r
.52382 .25564 .52478 .25671 .52655 .25615 .52559 .25498 Mtetra
.756 .768 .863 r
.52559 .25498 .52655 .25615 .52832 .2551 .52736 .25382 Mtetra
.725 .742 .865 r
.52736 .25382 .52832 .2551 .5301 .25421 .52914 .25284 Mtetra
.6 .678 .896 r
.52914 .25284 .5301 .25421 .53187 .25395 .53091 .25248 Mtetra
0 0 .386 r
.53091 .25248 .53187 .25395 .53366 .25701 .5327 .25522 Mtetra
.972 .682 .416 r
.5327 .25522 .53366 .25701 .53615 .46348 .53512 .4608 Mtetra
.892 .549 .062 r
.53512 .4608 .53615 .46348 .53808 .47066 .53706 .46925 Mtetra
.077 .392 .851 r
.53706 .46925 .53808 .47066 .54 .47147 .53897 .47028 Mtetra
.622 .739 .93 r
.53897 .47028 .54 .47147 .54191 .47085 .54088 .46978 Mtetra
.75 .802 .894 r
.54088 .46978 .54191 .47085 .54381 .46974 .54279 .46864 Mtetra
.726 .791 .904 r
.54279 .46864 .54381 .46974 .54573 .46944 .5447 .46765 Mtetra
.726 .687 .813 r
.5447 .46765 .54573 .46944 .54764 .46918 .54661 .46643 Mtetra
.745 .62 .72 r
.54661 .46643 .54764 .46918 .54956 .46826 .54852 .46441 Mtetra
.846 .634 .615 r
.54852 .46441 .54956 .46826 .55144 .46423 .55039 .45809 Mtetra
.968 .682 .434 r
.55039 .45809 .55144 .46423 .55158 .2587 .55058 .2518 Mtetra
.75 .53 .598 r
.55058 .2518 .55158 .2587 .55328 .24775 .55233 .24626 Mtetra
.805 .735 .786 r
.55233 .24626 .55328 .24775 .55506 .24552 .55411 .24444 Mtetra
.679 .767 .917 r
.55411 .24444 .55506 .24552 .55685 .2448 .55591 .24374 Mtetra
.586 .736 .947 r
.55591 .24374 .55685 .2448 .55865 .24455 .5577 .24339 Mtetra
.729 .766 .883 r
.5577 .24339 .55865 .24455 .56044 .24368 .55949 .24241 Mtetra
.732 .747 .864 r
.55949 .24241 .56044 .24368 .56223 .24275 .56129 .24137 Mtetra
.617 .688 .893 r
.56129 .24137 .56223 .24275 .56403 .24242 .56309 .24094 Mtetra
0 0 .554 r
.56309 .24094 .56403 .24242 .56587 .24492 .56492 .24317 Mtetra
.974 .681 .403 r
.56492 .24317 .56587 .24492 .57055 .45051 .56951 .44685 Mtetra
.879 .564 .054 r
.56951 .44685 .57055 .45051 .57261 .45931 .5716 .45784 Mtetra
0 .282 .784 r
.5716 .45784 .57261 .45931 .57457 .46048 .57356 .45925 Mtetra
.605 .726 .93 r
.57356 .45925 .57457 .46048 .5765 .45992 .5755 .45881 Mtetra
.742 .797 .896 r
.5755 .45881 .5765 .45992 .57843 .45883 .57743 .45771 Mtetra
.733 .792 .9 r
.57743 .45771 .57843 .45883 .58037 .4584 .57936 .45667 Mtetra
.722 .695 .823 r
.57936 .45667 .58037 .4584 .58231 .45818 .58128 .4555 Mtetra
.741 .623 .727 r
.58128 .4555 .58231 .45818 .58425 .45734 .5832 .45358 Mtetra
.834 .63 .626 r
.5832 .45358 .58425 .45734 .58613 .45381 .58505 .44811 Mtetra
.971 .682 .421 r
.58505 .44811 .58613 .45381 .58424 .25432 .58307 .24123 Mtetra
.681 .453 .569 r
.58307 .24123 .58424 .25432 .58572 .23663 .58478 .235 Mtetra
.817 .725 .763 r
.58478 .235 .58572 .23663 .58749 .23401 .58656 .23291 Mtetra
.69 .77 .913 r
.58656 .23291 .58749 .23401 .5893 .23321 .58837 .23215 Mtetra
.589 .739 .948 r
.58837 .23215 .5893 .23321 .59113 .23291 .59019 .23178 Mtetra
.7 .766 .903 r
.59019 .23178 .59113 .23291 .59294 .23214 .59201 .23096 Mtetra
.73 .765 .881 r
.59201 .23096 .59294 .23214 .59475 .23115 .59382 .22996 Mtetra
.615 .723 .922 r
.59382 .22996 .59475 .23115 .59657 .23072 .59564 .22951 Mtetra
0 .065 .601 r
.59564 .22951 .59657 .23072 .59845 .2326 .59752 .23139 Mtetra
.974 .678 .39 r
.59752 .23139 .59845 .2326 .60524 .43324 .60425 .43211 Mtetra
.956 .611 .267 r
.60425 .43211 .60524 .43324 .60756 .44737 .60657 .44624 Mtetra
0 .116 .631 r
.60657 .44624 .60756 .44737 .60957 .44907 .60858 .448 Mtetra
.575 .751 .961 r
.60858 .448 .60957 .44907 .61153 .44863 .61055 .44764 Mtetra
.736 .82 .917 r
.61055 .44764 .61153 .44863 .61348 .44764 .6125 .44659 Mtetra
.742 .811 .906 r
.6125 .44659 .61348 .44764 .61545 .44713 .61445 .44549 Mtetra
.723 .709 .837 r
.61445 .44549 .61545 .44713 .61742 .44696 .61639 .44435 Mtetra
.74 .628 .735 r
.61639 .44435 .61742 .44696 .61938 .44619 .61832 .4425 Mtetra
.824 .627 .635 r
.61832 .4425 .61938 .44619 .62127 .44307 .62016 .4376 Mtetra
.973 .68 .407 r
.62016 .4376 .62127 .44307 .62275 .42639 .61596 .23039 Mtetra
.543 .316 .52 r
.61596 .23039 .62275 .42639 .61855 .22528 .61761 .22351 Mtetra
.826 .716 .743 r
.61761 .22351 .61855 .22528 .62031 .22227 .61939 .22115 Mtetra
.702 .773 .907 r
.61939 .22115 .62031 .22227 .62213 .22139 .62122 .22032 Mtetra
.601 .746 .946 r
.62122 .22032 .62213 .22139 .62398 .22104 .62306 .2199 Mtetra
.683 .764 .912 r
.62306 .2199 .62398 .22104 .62582 .22035 .6249 .21916 Mtetra
.738 .77 .879 r
.6249 .21916 .62582 .22035 .62764 .21931 .62673 .21811 Mtetra
.639 .733 .917 r
.62673 .21811 .62764 .21931 .62948 .21877 .62857 .21756 Mtetra
0 .277 .776 r
.62857 .21756 .62948 .21877 .63139 .2201 .63048 .21889 Mtetra
.941 .581 .197 r
.63048 .21889 .63139 .2201 .63363 .2305 .63272 .22934 Mtetra
.975 .675 .374 r
.63272 .22934 .63363 .2305 .64291 .435 .64194 .43387 Mtetra
0 0 .508 r
.64194 .43387 .64291 .435 .645 .43726 .64403 .43613 Mtetra
.614 .755 .946 r
.64403 .43613 .645 .43726 .64699 .43675 .64602 .43562 Mtetra
.753 .804 .893 r
.64602 .43562 .64699 .43675 .64895 .43553 .64798 .43444 Mtetra
.748 .809 .901 r
.64798 .43444 .64895 .43553 .65091 .43428 .64995 .43329 Mtetra
.656 .802 .953 r
.64995 .43329 .65091 .43428 .65289 .43344 .65193 .4326 Mtetra
.64 .831 .974 r
.65193 .4326 .65289 .43344 .65487 .43264 .65392 .43194 Mtetra
.625 .857 .987 r
.65392 .43194 .65487 .43264 .65685 .43196 .65591 .43128 Mtetra
.622 .86 .988 r
.65591 .43128 .65685 .43196 .65885 .43143 .6579 .43063 Mtetra
.627 .833 .979 r
.6579 .43063 .65885 .43143 .66084 .43096 .65989 .43 Mtetra
.549 .765 .978 r
.65989 .43 .66084 .43096 .66286 .43081 .66189 .42967 Mtetra
.498 .701 .961 r
.66189 .42967 .66286 .43081 .66488 .43083 .66391 .42956 Mtetra
.643 .741 .92 r
.66391 .42956 .66488 .43083 .66688 .43019 .66591 .42894 Mtetra
.856 .802 .797 r
.66591 .42894 .66688 .43019 .66877 .4273 .66784 .4267 Mtetra
.987 .795 .561 r
.66784 .4267 .66877 .4273 .6618 .22688 .66953 .41924 Mtetra
0 0 .351 r
.66953 .41924 .6618 .22688 .6629 .20916 .66217 .2118 Mtetra
0 0 0 r
.66217 .2118 .6629 .20916 .66465 .20605 .66385 .20711 Mtetra
.66385 .20711 .66465 .20605 .66651 .20525 .66567 .2054 Mtetra
.561 .933 .817 r
.66567 .2054 .66651 .20525 .66839 .205 .66752 .20431 Mtetra
.685 .868 .968 r
.66752 .20431 .66839 .205 .67028 .20479 .66938 .20351 Mtetra
.666 .732 .899 r
.66938 .20351 .67028 .20479 .67215 .20419 .67125 .20283 Mtetra
.643 .708 .894 r
.67125 .20283 .67215 .20419 .67402 .20355 .67312 .20225 Mtetra
.685 .736 .889 r
.67312 .20225 .67402 .20355 .67588 .20266 .67499 .20146 Mtetra
.744 .777 .879 r
.67499 .20146 .67588 .20266 .67772 .2015 .67684 .20036 Mtetra
.655 .758 .926 r
.67684 .20036 .67772 .2015 .67959 .20081 .67871 .19974 Mtetra
.053 .427 .869 r
.67871 .19974 .67959 .20081 .68155 .20164 .68067 .20064 Mtetra
.92 .538 .134 r
.68067 .20064 .68155 .20164 .68387 .20947 .68302 .20922 Mtetra
.975 .669 .352 r
.68302 .20922 .68387 .20947 .69683 .41762 .69589 .41659 Mtetra
.66 .184 0 r
.69589 .41659 .69683 .41762 .69906 .42085 .69811 .41969 Mtetra
.405 .651 .958 r
.69811 .41969 .69906 .42085 .70112 .42101 .70017 .41984 Mtetra
.709 .788 .913 r
.70017 .41984 .70112 .42101 .70313 .42007 .70218 .4189 Mtetra
.889 .818 .772 r
.70218 .4189 .70313 .42007 .70504 .41741 .7041 .41624 Mtetra
.979 .757 .533 r
.7041 .41624 .70504 .41741 .70657 .40804 .70563 .40691 Mtetra
.977 .678 .362 r
.70563 .40691 .70657 .40804 .69672 .19867 .69584 .19744 Mtetra
.938 .789 .669 r
.69584 .19744 .69672 .19867 .69841 .19456 .69753 .19332 Mtetra
.732 .768 .882 r
.69753 .19332 .69841 .19456 .70027 .19352 .69939 .19229 Mtetra
.604 .718 .925 r
.69939 .19229 .70027 .19352 .70218 .1931 .70129 .19187 Mtetra
.603 .718 .925 r
.70129 .19187 .70218 .1931 .70408 .19268 .7032 .19145 Mtetra
.744 .773 .877 r
.7032 .19145 .70408 .19268 .70594 .19158 .70506 .19034 Mtetra
.658 .741 .911 r
.70506 .19034 .70594 .19158 .70784 .19092 .70696 .18969 Mtetra
.215 .501 .905 r
.70696 .18969 .70784 .19092 .70981 .19156 .70893 .19039 Mtetra
.899 .512 .073 r
.70893 .19039 .70981 .19156 .71218 .19865 .71136 .19838 Mtetra
.974 .666 .337 r
.71136 .19838 .71218 .19865 .72721 .40751 .72631 .40685 Mtetra
.729 .231 0 r
.72631 .40685 .72721 .40751 .7295 .41091 .72859 .41004 Mtetra
.522 .779 .991 r
.72859 .41004 .7295 .41091 .73158 .41071 .73066 .40973 Mtetra
.723 .835 .934 r
.73066 .40973 .73158 .41071 .7336 .4098 .73268 .40872 Mtetra
.735 .815 .914 r
.73268 .40872 .7336 .4098 .73563 .40884 .7347 .40763 Mtetra
.519 .7 .952 r
.7347 .40763 .73563 .40884 .73771 .40877 .73678 .40747 Mtetra
.642 .739 .92 r
.73678 .40747 .73771 .40877 .73977 .40822 .73883 .40684 Mtetra
.824 .788 .819 r
.73883 .40684 .73977 .40822 .74174 .40637 .7408 .40493 Mtetra
.971 .756 .556 r
.7408 .40493 .74174 .40637 .74331 .39871 .74235 .39689 Mtetra
.977 .674 .346 r
.74235 .39689 .74331 .39871 .73094 .1874 .73006 .18596 Mtetra
.941 .769 .641 r
.73006 .18596 .73094 .1874 .73256 .18253 .73169 .18124 Mtetra
.743 .766 .871 r
.73169 .18124 .73256 .18253 .73444 .18138 .73357 .18011 Mtetra
.616 .719 .919 r
.73357 .18011 .73444 .18138 .73636 .18091 .7355 .17964 Mtetra
.578 .702 .927 r
.7355 .17964 .73636 .18091 .7383 .18058 .73743 .17932 Mtetra
.748 .772 .872 r
.73743 .17932 .7383 .18058 .74018 .17943 .73931 .17817 Mtetra
.672 .744 .905 r
.73931 .17817 .74018 .17943 .74209 .1787 .74123 .17744 Mtetra
.361 .587 .93 r
.74123 .17744 .74209 .1787 .74408 .17901 .74322 .1778 Mtetra
.846 .442 0 r
.74322 .1778 .74408 .17901 .74647 .18485 .74566 .18421 Mtetra
.973 .662 .317 r
.74566 .18421 .74647 .18485 .76407 .39502 .7632 .39439 Mtetra
.771 .29 0 r
.7632 .39439 .76407 .39502 .76649 .3991 .7656 .39822 Mtetra
.489 .763 .992 r
.7656 .39822 .76649 .3991 .7686 .39898 .7677 .398 Mtetra
.712 .834 .94 r
.7677 .398 .7686 .39898 .77065 .39812 .76975 .39703 Mtetra
.756 .825 .906 r
.76975 .39703 .77065 .39812 .77269 .39703 .77178 .3958 Mtetra
.512 .698 .953 r
.77178 .3958 .77269 .39703 .77481 .39698 .7739 .39566 Mtetra
.628 .735 .924 r
.7739 .39566 .77481 .39698 .7769 .39647 .77598 .39509 Mtetra
.791 .783 .845 r
.77598 .39509 .7769 .39647 .77891 .39495 .77799 .3935 Mtetra
.97 .765 .572 r
.77799 .3935 .77891 .39495 .7805 .38815 .77955 .38642 Mtetra
.976 .67 .327 r
.77955 .38642 .7805 .38815 .76559 .17592 .76472 .17441 Mtetra
.952 .764 .612 r
.76472 .17441 .76559 .17592 .76713 .17029 .76627 .16898 Mtetra
.757 .771 .864 r
.76627 .16898 .76713 .17029 .76901 .16904 .76816 .16775 Mtetra
.628 .723 .915 r
.76816 .16775 .76901 .16904 .77096 .16851 .77011 .16722 Mtetra
.552 .687 .929 r
.77011 .16722 .77096 .16851 .77293 .16828 .77208 .167 Mtetra
.749 .772 .872 r
.77208 .167 .77293 .16828 .77483 .16711 .77398 .16582 Mtetra
.681 .748 .901 r
.77398 .16582 .77483 .16711 .77676 .16632 .77591 .16505 Mtetra
.473 .648 .934 r
.77591 .16505 .77676 .16632 .77876 .16636 .77791 .16508 Mtetra
.758 .342 0 r
.77791 .16508 .77876 .16636 .78119 .17145 .78035 .17019 Mtetra
.971 .656 .295 r
.78035 .17019 .78119 .17145 .80141 .38252 .80051 .3813 Mtetra
.732 .298 0 r
.80051 .3813 .80141 .38252 .80397 .38729 .80308 .38607 Mtetra
.3 .577 .937 r
.80308 .38607 .80397 .38729 .80617 .38777 .80527 .38655 Mtetra
.647 .764 .934 r
.80527 .38655 .80617 .38777 .80826 .3871 .80737 .38587 Mtetra
.827 .822 .844 r
.80737 .38587 .80826 .3871 .81026 .38527 .80937 .38405 Mtetra
.908 .737 .658 r
.14088 .59464 .14207 .59559 .14429 .58987 .14311 .58893 Mtetra
.936 .686 .535 r
.14311 .58893 .14429 .58987 .16832 .38786 .16721 .38688 Mtetra
.909 .729 .646 r
.16721 .38688 .16832 .38786 .17048 .38182 .16938 .38081 Mtetra
.772 .762 .844 r
.16938 .38081 .17048 .38182 .1721 .38062 .171 .37962 Mtetra
.633 .738 .924 r
.171 .37962 .1721 .38062 .17364 .38018 .17254 .37918 Mtetra
.493 .691 .956 r
.17254 .37918 .17364 .38018 .17514 .38011 .17404 .37912 Mtetra
.712 .758 .889 r
.17404 .37912 .17514 .38011 .17674 .37919 .17562 .37834 Mtetra
.688 .783 .923 r
.17562 .37834 .17674 .37919 .17831 .37852 .17719 .37769 Mtetra
.589 .764 .963 r
.17719 .37769 .17831 .37852 .17982 .3784 .17873 .37736 Mtetra
0 .382 .836 r
.17873 .37736 .17982 .3784 .18103 .38105 .18015 .37808 Mtetra
.002 .116 .632 r
.18015 .37808 .18103 .38105 .16191 .57404 .18144 .38001 Mtetra
.512 .291 .515 r
.18144 .38001 .16191 .57404 .16223 .58601 .18226 .38642 Mtetra
0 0 .123 r
.18226 .38642 .16223 .58601 .16368 .58742 .1631 .58083 Mtetra
.074 .043 .514 r
.1631 .58083 .16368 .58742 .16525 .58769 .16429 .58474 Mtetra
.137 .226 .693 r
.16429 .58474 .16525 .58769 .16688 .58746 .16572 .58633 Mtetra
.238 .55 .93 r
.16572 .58633 .16688 .58746 .16848 .58755 .16728 .58675 Mtetra
.595 .786 .972 r
.16728 .58675 .16848 .58755 .17013 .58717 .16893 .58636 Mtetra
.793 .809 .865 r
.16893 .58636 .17013 .58717 .17186 .58599 .17068 .58503 Mtetra
.909 .742 .664 r
.17068 .58503 .17186 .58599 .17401 .58068 .17285 .57967 Mtetra
.939 .687 .529 r
.17285 .57967 .17401 .58068 .19639 .37833 .19531 .3772 Mtetra
.909 .723 .639 r
.19531 .3772 .19639 .37833 .19856 .37194 .19747 .37085 Mtetra
.788 .753 .821 r
.19747 .37085 .19856 .37194 .20021 .37055 .19913 .36946 Mtetra
.628 .722 .914 r
.19913 .36946 .20021 .37055 .20177 .37013 .20069 .36904 Mtetra
.475 .663 .944 r
.20069 .36904 .20177 .37013 .20328 .37015 .2022 .36904 Mtetra
.614 .713 .916 r
.2022 .36904 .20328 .37015 .20483 .36979 .20375 .36867 Mtetra
.638 .718 .906 r
.20375 .36867 .20483 .36979 .20639 .36934 .20532 .36821 Mtetra
.643 .718 .903 r
.20532 .36821 .20639 .36934 .20796 .36886 .20689 .36773 Mtetra
.654 .72 .897 r
.20689 .36773 .20796 .36886 .20953 .36833 .20846 .3672 Mtetra
.662 .724 .895 r
.20846 .3672 .20953 .36833 .21111 .36775 .21004 .36664 Mtetra
.669 .729 .894 r
.21004 .36664 .21111 .36775 .21269 .36714 .21162 .36605 Mtetra
.671 .733 .896 r
.21162 .36605 .21269 .36714 .21428 .36651 .2132 .36545 Mtetra
.678 .741 .898 r
.2132 .36545 .21428 .36651 .21587 .36585 .21479 .36481 Mtetra
.688 .749 .898 r
.21479 .36481 .21587 .36585 .21746 .36516 .21638 .36414 Mtetra
.709 .755 .889 r
.21638 .36414 .21746 .36516 .21906 .36443 .21798 .36336 Mtetra
.712 .749 .881 r
.21798 .36336 .21906 .36443 .22066 .36368 .21959 .36256 Mtetra
.706 .738 .876 r
.21959 .36256 .22066 .36368 .22226 .36294 .22119 .36178 Mtetra
.685 .725 .88 r
.22119 .36178 .22226 .36294 .22385 .36227 .22278 .3611 Mtetra
.674 .721 .885 r
.22278 .3611 .22385 .36227 .22544 .36163 .22438 .36048 Mtetra
.668 .722 .89 r
.22438 .36048 .22544 .36163 .22703 .36102 .22596 .35988 Mtetra
.702 .734 .875 r
.22596 .35988 .22703 .36102 .22865 .36014 .22757 .35912 Mtetra
.689 .753 .9 r
.22757 .35912 .22865 .36014 .23025 .35941 .22917 .35844 Mtetra
.61 .742 .939 r
.22917 .35844 .23025 .35941 .23181 .35917 .23074 .35806 Mtetra
0 .364 .828 r
.23074 .35806 .23181 .35917 .23317 .36113 .2322 .35886 Mtetra
0 0 .543 r
.2322 .35886 .23317 .36113 .23379 .3712 .23355 .36102 Mtetra
.18 .082 .498 r
.23355 .36102 .23379 .3712 .21753 .56763 .23461 .36624 Mtetra
.52 .297 .517 r
.23461 .36624 .21753 .56763 .21905 .56898 .23582 .37002 Mtetra
.533 .309 .52 r
.23582 .37002 .21905 .56898 .22074 .56845 .23755 .368 Mtetra
.529 .305 .519 r
.23755 .368 .22074 .56845 .22247 .56752 .23911 .3679 Mtetra
0 0 .174 r
.23911 .3679 .22247 .56752 .2241 .56775 .22353 .56014 Mtetra
0 0 .468 r
.22353 .56014 .2241 .56775 .2257 .56834 .22472 .56538 Mtetra
0 .083 .621 r
.22472 .56538 .2257 .56834 .22732 .5687 .22617 .56758 Mtetra
.202 .534 .924 r
.22617 .56758 .22732 .5687 .22896 .5688 .22778 .56806 Mtetra
.573 .798 .985 r
.22778 .56806 .22896 .5688 .23064 .56849 .22947 .56769 Mtetra
.734 .82 .918 r
.22947 .56769 .23064 .56849 .23238 .56758 .23121 .56677 Mtetra
.832 .812 .831 r
.23121 .56677 .23238 .56758 .23428 .56468 .23302 .56503 Mtetra
.942 .933 .762 r
.23302 .56503 .23428 .56468 .23661 .55678 .23492 .56216 Mtetra
0 0 0 r
.23492 .56216 .23661 .55678 .25531 .35588 .23705 .55662 Mtetra
0 0 .158 r
.23705 .55662 .25531 .35588 .25719 .35211 .25554 .35785 Mtetra
0 0 0 r
.25554 .35785 .25719 .35211 .25888 .35047 .25764 .35145 Mtetra
.919 .973 .694 r
.25764 .35145 .25888 .35047 .26052 .34947 .25944 .3486 Mtetra
.78 .796 .866 r
.25944 .3486 .26052 .34947 .26214 .34884 .2611 .3474 Mtetra
.619 .66 .868 r
.2611 .3474 .26214 .34884 .26373 .34844 .2627 .34701 Mtetra
.536 .626 .888 r
.2627 .34701 .26373 .34844 .26532 .34816 .26427 .34692 Mtetra
.582 .68 .908 r
.26427 .34692 .26532 .34816 .26691 .34777 .26585 .34666 Mtetra
.633 .723 .912 r
.26585 .34666 .26691 .34777 .26852 .34727 .26745 .34621 Mtetra
.645 .735 .915 r
.26745 .34621 .26852 .34727 .27013 .34673 .26906 .3457 Mtetra
.652 .746 .919 r
.26906 .3457 .27013 .34673 .27174 .34615 .27067 .34517 Mtetra
.663 .76 .922 r
.27067 .34517 .27174 .34615 .27336 .34553 .27229 .3446 Mtetra
.679 .773 .922 r
.27229 .3446 .27336 .34553 .27498 .34486 .27391 .34396 Mtetra
.708 .785 .911 r
.27391 .34396 .27498 .34486 .27661 .34413 .27554 .34319 Mtetra
.722 .781 .899 r
.27554 .34319 .27661 .34413 .27824 .34335 .27718 .34235 Mtetra
.719 .767 .891 r
.27718 .34235 .27824 .34335 .27988 .34258 .27882 .34151 Mtetra
.727 .756 .875 r
.27882 .34151 .27988 .34258 .28152 .34163 .28046 .34061 Mtetra
.713 .762 .891 r
.28046 .34061 .28152 .34163 .28317 .34076 .2821 .33979 Mtetra
.642 .757 .932 r
.2821 .33979 .28317 .34076 .28477 .34036 .28372 .3393 Mtetra
.295 .583 .941 r
.28372 .3393 .28477 .34036 .28626 .34166 .28527 .33962 Mtetra
0 .159 .694 r
.28527 .33962 .28626 .34166 .28736 .34801 .28673 .34121 Mtetra
.025 .004 .492 r
.28673 .34121 .28736 .34801 .27401 .54868 .28797 .34583 Mtetra
0 0 .2 r
.28797 .34583 .27401 .54868 .27547 .55184 .27484 .54402 Mtetra
.051 .015 .492 r
.27484 .54402 .27547 .55184 .27711 .55251 .27615 .54917 Mtetra
.111 .185 .661 r
.27615 .54917 .27711 .55251 .2788 .55253 .27769 .55117 Mtetra
.261 .517 .908 r
.27769 .55117 .2788 .55253 .28051 .55228 .27935 .5517 Mtetra
.498 .81 1 r
.27935 .5517 .28051 .55228 .28224 .55188 .28106 .55141 Mtetra
.611 .873 .991 r
.28106 .55141 .28224 .55188 .28397 .55136 .2828 .55084 Mtetra
.626 .866 .987 r
.2828 .55084 .28397 .55136 .28571 .55082 .28455 .55024 Mtetra
.612 .851 .989 r
.28455 .55024 .28571 .55082 .28745 .55029 .28628 .54971 Mtetra
.623 .852 .986 r
.28628 .54971 .28745 .55029 .28919 .54974 .28803 .54914 Mtetra
.623 .849 .986 r
.28803 .54914 .28919 .54974 .29093 .54919 .28977 .54858 Mtetra
.619 .846 .986 r
.28977 .54858 .29093 .54919 .29267 .54864 .29151 .54803 Mtetra
.62 .845 .985 r
.29151 .54803 .29267 .54864 .29441 .5481 .29326 .54749 Mtetra
.29326 .54749 .29441 .5481 .29616 .54755 .295 .54694 Mtetra
.621 .844 .985 r
.295 .54694 .29616 .54755 .2979 .547 .29675 .54639 Mtetra
.29675 .54639 .2979 .547 .29965 .54645 .2985 .54584 Mtetra
.2985 .54584 .29965 .54645 .3014 .5459 .30024 .54529 Mtetra
.30024 .54529 .3014 .5459 .30315 .54535 .30199 .54473 Mtetra
.622 .844 .985 r
.30199 .54473 .30315 .54535 .3049 .5448 .30375 .54418 Mtetra
.30375 .54418 .3049 .5448 .30665 .54425 .3055 .54363 Mtetra
.3055 .54363 .30665 .54425 .3084 .54369 .30725 .54307 Mtetra
.30725 .54307 .3084 .54369 .31015 .54314 .30901 .54251 Mtetra
.622 .845 .985 r
.30901 .54251 .31015 .54314 .31191 .54258 .31076 .54196 Mtetra
.623 .845 .984 r
.31076 .54196 .31191 .54258 .31367 .54202 .31252 .5414 Mtetra
.31252 .5414 .31367 .54202 .31542 .54146 .31428 .54084 Mtetra
.623 .845 .985 r
.31428 .54084 .31542 .54146 .31718 .5409 .31604 .54028 Mtetra
.623 .846 .985 r
.31604 .54028 .31718 .5409 .31894 .54033 .3178 .53972 Mtetra
.3178 .53972 .31894 .54033 .3207 .53977 .31956 .53915 Mtetra
.62 .846 .986 r
.31956 .53915 .3207 .53977 .32247 .5392 .32132 .5386 Mtetra
.616 .847 .987 r
.32132 .5386 .32247 .5392 .32423 .53864 .32309 .53805 Mtetra
.625 .853 .986 r
.32309 .53805 .32423 .53864 .326 .53806 .32486 .53747 Mtetra
.61 .85 .989 r
.32486 .53747 .326 .53806 .32776 .53747 .32662 .53693 Mtetra
.602 .857 .992 r
.32662 .53693 .32776 .53747 .32953 .53687 .32839 .53639 Mtetra
.692 .892 .97 r
.32839 .53639 .32953 .53687 .33131 .53615 .33017 .53557 Mtetra
.844 .869 .861 r
.33017 .53557 .33131 .53615 .33311 .53511 .33201 .53388 Mtetra
.886 .755 .712 r
.33201 .53388 .33311 .53511 .33493 .53359 .33394 .53037 Mtetra
.86 .653 .621 r
.33394 .53037 .33493 .53359 .33677 .53189 .33607 .52346 Mtetra
.947 .68 .498 r
.33607 .52346 .33677 .53189 .33858 .53047 .34873 .32808 Mtetra
.534 .309 .52 r
.34873 .32808 .33858 .53047 .34036 .52979 .3505 .32567 Mtetra
.527 .303 .518 r
.3505 .32567 .34036 .52979 .34213 .52936 .3521 .32641 Mtetra
.52 .298 .517 r
.3521 .32641 .34213 .52936 .34388 .52919 .35354 .33006 Mtetra
0 0 .298 r
.35354 .33006 .34388 .52919 .34563 .52911 .34593 .50199 Mtetra
.92 .65 .513 r
.34593 .50199 .34563 .52911 .34742 .52838 .35655 .33526 Mtetra
.559 .33 .524 r
.35655 .33526 .34742 .52838 .34933 .52536 .35893 .32143 Mtetra
.542 .315 .521 r
.35893 .32143 .34933 .52536 .36155 .32363 .36089 .31533 Mtetra
.667 .463 .6 r
.36089 .31533 .36155 .32363 .36367 .31427 .3627 .31206 Mtetra
.759 .642 .731 r
.3627 .31206 .36367 .31427 .36546 .31138 .36444 .31019 Mtetra
.698 .736 .88 r
.36444 .31019 .36546 .31138 .36715 .31049 .36612 .30942 Mtetra
.638 .739 .922 r
.36612 .30942 .36715 .31049 .36881 .31007 .36779 .30892 Mtetra
.626 .72 .915 r
.36779 .30892 .36881 .31007 .37047 .30975 .36946 .30848 Mtetra
.663 .711 .883 r
.36946 .30848 .37047 .30975 .37215 .30917 .37114 .30787 Mtetra
.662 .705 .879 r
.37114 .30787 .37215 .30917 .37382 .3086 .37281 .30726 Mtetra
.675 .704 .869 r
.37281 .30726 .37382 .3086 .3755 .30799 .3745 .30658 Mtetra
.696 .7 .85 r
.3745 .30658 .3755 .30799 .37719 .3073 .37618 .30577 Mtetra
.649 .665 .852 r
.37618 .30577 .37719 .3073 .37886 .30671 .37786 .3052 Mtetra
.494 .599 .887 r
.37786 .3052 .37886 .30671 .38054 .30629 .37951 .30526 Mtetra
0 .025 .527 r
.37951 .30526 .38054 .30629 .3822 .30614 .3811 .30679 Mtetra
.862 .478 .315 r
.3811 .30679 .3822 .30614 .38384 .30654 .38256 .31104 Mtetra
.953 .677 .476 r
.38256 .31104 .38384 .30654 .3854 .30866 .37525 .51101 Mtetra
.538 .308 .513 r
.37525 .51101 .3854 .30866 .37823 .50925 .37677 .51657 Mtetra
.608 .311 .44 r
.37677 .51657 .37823 .50925 .37961 .51812 .37845 .51862 Mtetra
.547 .012 0 r
.37845 .51862 .37961 .51812 .3813 .52029 .3802 .5194 Mtetra
.493 .741 .982 r
.3802 .5194 .3813 .52029 .38308 .5202 .38198 .51924 Mtetra
.623 .776 .954 r
.38198 .51924 .38308 .5202 .38489 .51956 .38378 .51874 Mtetra
.652 .815 .962 r
.38378 .51874 .38489 .51956 .3867 .51873 .38559 .51811 Mtetra
.58 .839 .994 r
.38559 .51811 .3867 .51873 .38851 .51816 .3874 .51764 Mtetra
.671 .886 .977 r
.3874 .51764 .38851 .51816 .39032 .51745 .38921 .51688 Mtetra
.812 .886 .898 r
.38921 .51688 .39032 .51745 .39214 .51649 .39106 .51546 Mtetra
.896 .785 .731 r
.39106 .51546 .39214 .51649 .39399 .51502 .39297 .51224 Mtetra
.864 .667 .634 r
.39297 .51224 .39399 .51502 .39584 .51335 .39499 .50638 Mtetra
.955 .683 .482 r
.39499 .50638 .39584 .51335 .39769 .5119 .40432 .31041 Mtetra
.532 .307 .519 r
.40432 .31041 .39769 .5119 .39948 .51174 .40606 .30884 Mtetra
.526 .302 .518 r
.40606 .30884 .39948 .51174 .40129 .51124 .40769 .31018 Mtetra
.538 .313 .52 r
.40769 .31018 .40129 .51124 .40316 .50924 .40954 .30568 Mtetra
.545 .318 .521 r
.40954 .30568 .40316 .50924 .40621 .47429 .41151 .2981 Mtetra
.538 .312 .521 r
.41151 .2981 .40621 .47429 .41427 .29709 .41332 .2945 Mtetra
.76 .622 .707 r
.41332 .2945 .41427 .29709 .41608 .29353 .41508 .29233 Mtetra
.707 .74 .877 r
.41508 .29233 .41608 .29353 .4178 .29253 .41679 .29149 Mtetra
.64 .752 .93 r
.41679 .29149 .4178 .29253 .4195 .29205 .41849 .29098 Mtetra
.607 .733 .934 r
.41849 .29098 .4195 .29205 .42119 .29178 .42019 .29058 Mtetra
.662 .728 .898 r
.42019 .29058 .42119 .29178 .4229 .29119 .4219 .28997 Mtetra
.657 .723 .897 r
.4219 .28997 .4229 .29119 .42461 .29062 .42361 .28939 Mtetra
.648 .716 .898 r
.42361 .28939 .42461 .29062 .42632 .29008 .42532 .28884 Mtetra
.622 .706 .905 r
.42532 .28884 .42632 .29008 .42802 .28959 .42702 .2884 Mtetra
.618 .713 .914 r
.42702 .2884 .42802 .28959 .42973 .28912 .42873 .28798 Mtetra
.624 .727 .92 r
.42873 .28798 .42973 .28912 .43144 .28862 .43044 .28753 Mtetra
.651 .745 .918 r
.43044 .28753 .43144 .28862 .43315 .28806 .43215 .28697 Mtetra
.667 .751 .913 r
.43215 .28697 .43315 .28806 .43487 .28745 .43387 .28634 Mtetra
.682 .751 .904 r
.43387 .28634 .43487 .28745 .43658 .28681 .43559 .28565 Mtetra
.702 .747 .887 r
.43559 .28565 .43658 .28681 .4383 .2861 .43731 .28484 Mtetra
.701 .731 .874 r
.43731 .28484 .4383 .2861 .44003 .28537 .43904 .28403 Mtetra
.693 .713 .864 r
.43904 .28403 .44003 .28537 .44175 .28466 .44076 .28323 Mtetra
.67 .693 .862 r
.44076 .28323 .44175 .28466 .44347 .28401 .44248 .28255 Mtetra
.664 .685 .861 r
.44248 .28255 .44347 .28401 .44519 .28338 .44421 .2819 Mtetra
.662 .683 .859 r
.44421 .2819 .44519 .28338 .44692 .28274 .44593 .28126 Mtetra
.705 .697 .841 r
.44593 .28126 .44692 .28274 .44864 .28197 .44766 .28036 Mtetra
.666 .664 .839 r
.44766 .28036 .44864 .28197 .45037 .28129 .44939 .27967 Mtetra
.586 .628 .86 r
.44939 .27967 .45037 .28129 .45209 .28078 .45111 .27939 Mtetra
0 .296 .793 r
.45111 .27939 .45209 .28078 .45381 .28049 .45279 .28057 Mtetra
.844 .4 .162 r
.45279 .28057 .45381 .28049 .45552 .28067 .45444 .28367 Mtetra
.961 .678 .452 r
.45444 .28367 .45552 .28067 .45721 .28183 .45177 .48181 Mtetra
.545 .313 .514 r
.45177 .48181 .45721 .28183 .45866 .29473 .45341 .49104 Mtetra
.533 .303 .512 r
.45341 .49104 .45866 .29473 .4563 .49234 .45519 .49358 Mtetra
.604 .146 .137 r
.45519 .49358 .4563 .49234 .45807 .49547 .45701 .49459 Mtetra
.589 .787 .974 r
.45701 .49459 .45807 .49547 .45992 .49533 .45886 .49416 Mtetra
.698 .762 .901 r
.45886 .49416 .45992 .49533 .46178 .49453 .46072 .49333 Mtetra
.726 .763 .882 r
.46072 .49333 .46178 .49453 .46365 .49341 .46259 .49232 Mtetra
.514 .71 .96 r
.46259 .49232 .46365 .49341 .4655 .49301 .46444 .49217 Mtetra
.544 .78 .986 r
.46444 .49217 .4655 .49301 .46736 .49257 .4663 .49186 Mtetra
.677 .852 .966 r
.4663 .49186 .46736 .49257 .46922 .49195 .46816 .4911 Mtetra
.888 .829 .783 r
.46816 .4911 .46922 .49195 .47109 .49102 .47006 .48858 Mtetra
.861 .681 .658 r
.47006 .48858 .47109 .49102 .47296 .48958 .47198 .48395 Mtetra
.963 .684 .458 r
.47198 .48395 .47296 .48958 .47486 .48713 .47691 .28503 Mtetra
.551 .322 .522 r
.47691 .28503 .47486 .48713 .47686 .47674 .47881 .27432 Mtetra
.536 .31 .52 r
.47881 .27432 .47686 .47674 .48155 .27438 .4806 .2709 Mtetra
.718 .564 .68 r
.4806 .2709 .48155 .27438 .48334 .2701 .48237 .26883 Mtetra
.724 .738 .863 r
.48237 .26883 .48334 .2701 .4851 .26884 .48412 .26786 Mtetra
.657 .776 .936 r
.48412 .26786 .4851 .26884 .48685 .26826 .48587 .26726 Mtetra
.616 .758 .946 r
.48587 .26726 .48685 .26826 .48859 .26797 .48762 .26681 Mtetra
.767 .768 .854 r
.48762 .26681 .48859 .26797 .49035 .26685 .48937 .26558 Mtetra
.722 .739 .866 r
.48937 .26558 .49035 .26685 .4921 .26597 .49113 .26463 Mtetra
.577 .671 .903 r
.49113 .26463 .4921 .26597 .49385 .26578 .49288 .26436 Mtetra
.782 .356 0 r
.49288 .26436 .49385 .26578 .49556 .26946 .49459 .26793 Mtetra
.97 .684 .431 r
.49459 .26793 .49556 .26946 .49547 .47651 .49443 .47533 Mtetra
.923 .536 .16 r
.49443 .47533 .49547 .47651 .49729 .48269 .49624 .48174 Mtetra
.243 .599 .951 r
.49624 .48174 .49729 .48269 .49916 .48309 .49812 .48211 Mtetra
.691 .801 .933 r
.49812 .48211 .49916 .48309 .50104 .48233 .5 .48131 Mtetra
.771 .81 .884 r
.5 .48131 .50104 .48233 .50293 .48112 .50189 .48005 Mtetra
.482 .703 .967 r
.50189 .48005 .50293 .48112 .50481 .48096 .50378 .47998 Mtetra
.521 .739 .974 r
.50378 .47998 .50481 .48096 .5067 .48065 .50566 .47976 Mtetra
.724 .829 .93 r
.50566 .47976 .5067 .48065 .50859 .4796 .50755 .47881 Mtetra
.951 .798 .656 r
.50755 .47881 .50859 .4796 .5105 .47446 .50946 .47381 Mtetra
.971 .69 .439 r
.50946 .47381 .5105 .47446 .51318 .2659 .51221 .26495 Mtetra
.958 .757 .589 r
.51221 .26495 .51318 .2659 .51497 .25883 .514 .25758 Mtetra
.803 .763 .816 r
.514 .25758 .51497 .25883 .51674 .25721 .51577 .25597 Mtetra
.618 .709 .91 r
.51577 .25597 .51674 .25721 .5185 .25673 .51754 .25553 Mtetra
.475 .653 .938 r
.51754 .25553 .5185 .25673 .52027 .2567 .51931 .25555 Mtetra
.615 .728 .926 r
.51931 .25555 .52027 .2567 .52204 .25625 .52108 .25512 Mtetra
.665 .748 .912 r
.52108 .25512 .52204 .25625 .52382 .25564 .52285 .25448 Mtetra
.679 .749 .903 r
.52285 .25448 .52382 .25564 .52559 .25498 .52463 .25377 Mtetra
.765 .765 .853 r
.52463 .25377 .52559 .25498 .52736 .25382 .5264 .25254 Mtetra
.736 .744 .859 r
.5264 .25254 .52736 .25382 .52914 .25284 .52818 .25148 Mtetra
.616 .689 .895 r
.52818 .25148 .52914 .25284 .53091 .25248 .52996 .25105 Mtetra
0 0 .41 r
.52996 .25105 .53091 .25248 .5327 .25522 .53174 .25365 Mtetra
.972 .682 .417 r
.53174 .25365 .5327 .25522 .53512 .4608 .5341 .4587 Mtetra
.934 .582 .161 r
.5341 .4587 .53512 .4608 .53706 .46925 .53604 .46806 Mtetra
0 .3 .786 r
.53604 .46806 .53706 .46925 .53897 .47028 .53795 .46928 Mtetra
.59 .767 .963 r
.53795 .46928 .53897 .47028 .54088 .46978 .53986 .46886 Mtetra
.777 .835 .897 r
.53986 .46886 .54088 .46978 .54279 .46864 .54177 .46759 Mtetra
.866 .813 .795 r
.54177 .46759 .54279 .46864 .5447 .46765 .54368 .4653 Mtetra
.853 .687 .676 r
.54368 .4653 .5447 .46765 .54661 .46643 .54557 .46135 Mtetra
.881 .636 .564 r
.54557 .46135 .54661 .46643 .54852 .46441 .5474 .44933 Mtetra
.958 .671 .448 r
.5474 .44933 .54852 .46441 .55039 .45809 .54784 .25109 Mtetra
.537 .311 .52 r
.54784 .25109 .55039 .45809 .55058 .2518 .5496 .24698 Mtetra
.693 .516 .644 r
.5496 .24698 .55058 .2518 .55233 .24626 .55138 .24462 Mtetra
.735 .694 .812 r
.55138 .24462 .55233 .24626 .55411 .24444 .55317 .2434 Mtetra
.672 .773 .926 r
.55317 .2434 .55411 .24444 .55591 .24374 .55496 .24273 Mtetra
.624 .764 .946 r
.55496 .24273 .55591 .24374 .5577 .24339 .55676 .24224 Mtetra
.749 .775 .874 r
.55676 .24224 .5577 .24339 .55949 .24241 .55855 .24114 Mtetra
.744 .752 .859 r
.55855 .24114 .55949 .24241 .56129 .24137 .56034 .24003 Mtetra
.635 .7 .893 r
.56034 .24003 .56129 .24137 .56309 .24094 .56214 .23951 Mtetra
0 .021 .577 r
.56214 .23951 .56309 .24094 .56492 .24317 .56397 .24161 Mtetra
.974 .68 .403 r
.56397 .24161 .56492 .24317 .56951 .44685 .56848 .4437 Mtetra
.933 .607 .157 r
.56848 .4437 .56951 .44685 .5716 .45784 .57059 .45661 Mtetra
0 .177 .693 r
.57059 .45661 .5716 .45784 .57356 .45925 .57256 .45821 Mtetra
.567 .751 .964 r
.57256 .45821 .57356 .45925 .5755 .45881 .57449 .45786 Mtetra
.766 .832 .903 r
.57449 .45786 .5755 .45881 .57743 .45771 .57642 .45665 Mtetra
.861 .817 .805 r
.57642 .45665 .57743 .45771 .57936 .45667 .57833 .45446 Mtetra
.856 .698 .685 r
.57833 .45446 .57936 .45667 .58128 .4555 .58022 .45071 Mtetra
.87 .632 .576 r
.58022 .45071 .58128 .4555 .5832 .45358 .582 .44092 Mtetra
.964 .673 .433 r
.582 .44092 .5832 .45358 .58505 .44811 .58031 .24006 Mtetra
.537 .311 .52 r
.58031 .24006 .58505 .44811 .58307 .24123 .58205 .23565 Mtetra
.68 .496 .63 r
.58205 .23565 .58307 .24123 .58478 .235 .58383 .23318 Mtetra
.738 .677 .792 r
.58383 .23318 .58478 .235 .58656 .23291 .58563 .23185 Mtetra
.677 .773 .923 r
.58563 .23185 .58656 .23291 .58837 .23215 .58744 .23114 Mtetra
.618 .765 .95 r
.58744 .23114 .58837 .23215 .59019 .23178 .58926 .23067 Mtetra
.716 .775 .899 r
.58926 .23067 .59019 .23178 .59201 .23096 .59107 .22977 Mtetra
.732 .766 .88 r
.59107 .22977 .59201 .23096 .59382 .22996 .59288 .22876 Mtetra
.617 .723 .922 r
.59288 .22876 .59382 .22996 .59564 .22951 .59471 .22831 Mtetra
0 .067 .603 r
.59471 .22831 .59564 .22951 .59752 .23139 .59659 .23018 Mtetra
.974 .678 .39 r
.59659 .23018 .59752 .23139 .60425 .43211 .60326 .43099 Mtetra
.956 .611 .267 r
.60326 .43099 .60425 .43211 .60657 .44624 .60557 .44511 Mtetra
0 .083 .601 r
.60557 .44511 .60657 .44624 .60858 .448 .60759 .44697 Mtetra
.542 .743 .969 r
.60759 .44697 .60858 .448 .61055 .44764 .60956 .4467 Mtetra
.752 .836 .915 r
.60956 .4467 .61055 .44764 .6125 .44659 .61151 .44556 Mtetra
.859 .829 .817 r
.61151 .44556 .6125 .44659 .61445 .44549 .61343 .44346 Mtetra
.865 .714 .694 r
.61343 .44346 .61445 .44549 .61639 .44435 .61531 .43985 Mtetra
.868 .634 .583 r
.61531 .43985 .61639 .44435 .61832 .4425 .61705 .43114 Mtetra
.967 .674 .419 r
.61705 .43114 .61832 .4425 .62016 .4376 .61317 .22875 Mtetra
.538 .312 .52 r
.61317 .22875 .62016 .4376 .61596 .23039 .61489 .22407 Mtetra
.67 .48 .619 r
.61489 .22407 .61596 .23039 .61761 .22351 .61666 .22151 Mtetra
.739 .662 .774 r
.61666 .22151 .61761 .22351 .61939 .22115 .61847 .22006 Mtetra
.685 .774 .918 r
.61847 .22006 .61939 .22115 .62122 .22032 .62031 .21931 Mtetra
.626 .769 .949 r
.62031 .21931 .62122 .22032 .62306 .2199 .62215 .2188 Mtetra
.702 .776 .909 r
.62215 .2188 .62306 .2199 .6249 .21916 .62398 .21796 Mtetra
.739 .77 .878 r
.62398 .21796 .6249 .21916 .62673 .21811 .62581 .2169 Mtetra
.641 .734 .916 r
.62581 .2169 .62673 .21811 .62857 .21756 .62765 .21634 Mtetra
0 .278 .777 r
.62765 .21634 .62857 .21756 .63048 .21889 .62956 .21767 Mtetra
.942 .581 .198 r
.62956 .21767 .63048 .21889 .63272 .22934 .6318 .22818 Mtetra
.975 .675 .374 r
.6318 .22818 .63272 .22934 .64194 .43387 .64097 .43273 Mtetra
0 0 .506 r
.64097 .43273 .64194 .43387 .64403 .43613 .64305 .435 Mtetra
.609 .755 .948 r
.64305 .435 .64403 .43613 .64602 .43562 .64504 .43451 Mtetra
.748 .805 .898 r
.64504 .43451 .64602 .43562 .64798 .43444 .64701 .43337 Mtetra
.735 .809 .91 r
.64701 .43337 .64798 .43444 .64995 .43329 .64898 .4323 Mtetra
.628 .791 .96 r
.64898 .4323 .64995 .43329 .65193 .4326 .65097 .43172 Mtetra
.618 .811 .974 r
.65097 .43172 .65193 .4326 .65392 .43194 .65296 .43115 Mtetra
.632 .837 .979 r
.65296 .43115 .65392 .43194 .65591 .43128 .65495 .4305 Mtetra
.658 .849 .973 r
.65495 .4305 .65591 .43128 .6579 .43063 .65694 .42976 Mtetra
.661 .831 .965 r
.65694 .42976 .6579 .43063 .65989 .43 .65893 .42903 Mtetra
.604 .787 .969 r
.65893 .42903 .65989 .43 .66189 .42967 .66093 .42853 Mtetra
.554 .727 .955 r
.66093 .42853 .66189 .42967 .66391 .42956 .66294 .42824 Mtetra
.631 .727 .916 r
.66294 .42824 .66391 .42956 .66591 .42894 .66494 .42768 Mtetra
.765 .784 .868 r
.66494 .42768 .66591 .42894 .66784 .4267 .66691 .42636 Mtetra
.934 .933 .777 r
.66691 .42636 .66784 .4267 .66953 .41924 .66882 .42364 Mtetra
0 0 .135 r
.66882 .42364 .66953 .41924 .66217 .2118 .67062 .41862 Mtetra
0 0 .379 r
.67062 .41862 .66217 .2118 .66385 .20711 .66341 .21592 Mtetra
0 0 .29 r
.66341 .21592 .66385 .20711 .66567 .2054 .66492 .20743 Mtetra
0 0 0 r
.66492 .20743 .66567 .2054 .66752 .20431 .66666 .20405 Mtetra
.87 .971 .853 r
.66666 .20405 .66752 .20431 .66938 .20351 .66848 .20221 Mtetra
.69 .739 .888 r
.66848 .20221 .66938 .20351 .67125 .20283 .67034 .2014 Mtetra
.626 .69 .89 r
.67034 .2014 .67125 .20283 .67312 .20225 .67222 .2009 Mtetra
.662 .72 .892 r
.67222 .2009 .67312 .20225 .67499 .20146 .67409 .20023 Mtetra
.742 .769 .875 r
.67409 .20023 .67499 .20146 .67684 .20036 .67594 .19913 Mtetra
.653 .738 .912 r
.67594 .19913 .67684 .20036 .67871 .19974 .67782 .19851 Mtetra
.107 .431 .873 r
.67782 .19851 .67871 .19974 .68067 .20064 .67977 .19943 Mtetra
.916 .538 .116 r
.67977 .19943 .68067 .20064 .68302 .20922 .68214 .20814 Mtetra
.975 .67 .35 r
.68214 .20814 .68302 .20922 .69589 .41659 .69494 .41544 Mtetra
.628 .163 0 r
.69494 .41544 .69589 .41659 .69811 .41969 .69716 .41853 Mtetra
.409 .651 .957 r
.69716 .41853 .69811 .41969 .70017 .41984 .69923 .41867 Mtetra
.71 .788 .913 r
.69923 .41867 .70017 .41984 .70218 .4189 .70124 .41772 Mtetra
.889 .818 .772 r
.70124 .41772 .70218 .4189 .7041 .41624 .70315 .41506 Mtetra
.979 .757 .534 r
.70315 .41506 .7041 .41624 .70563 .40691 .7047 .40576 Mtetra
.977 .678 .362 r
.7047 .40576 .70563 .40691 .69584 .19744 .69495 .19621 Mtetra
.938 .788 .669 r
.69495 .19621 .69584 .19744 .69753 .19332 .69664 .19209 Mtetra
.732 .768 .881 r
.69664 .19209 .69753 .19332 .69939 .19229 .69851 .19105 Mtetra
.603 .717 .925 r
.69851 .19105 .69939 .19229 .70129 .19187 .70041 .19063 Mtetra
.602 .718 .926 r
.70041 .19063 .70129 .19187 .7032 .19145 .70232 .19022 Mtetra
.744 .774 .877 r
.70232 .19022 .7032 .19145 .70506 .19034 .70418 .18911 Mtetra
.656 .741 .913 r
.70418 .18911 .70506 .19034 .70696 .18969 .70608 .18847 Mtetra
.188 .485 .899 r
.70608 .18847 .70696 .18969 .70893 .19039 .70806 .18922 Mtetra
.913 .534 .107 r
.70806 .18922 .70893 .19039 .71136 .19838 .71055 .19825 Mtetra
.974 .666 .337 r
.71055 .19825 .71136 .19838 .72631 .40685 .72541 .4061 Mtetra
.692 .193 0 r
.72541 .4061 .72631 .40685 .72859 .41004 .72768 .40912 Mtetra
.559 .784 .983 r
.72768 .40912 .72859 .41004 .73066 .40973 .72974 .40872 Mtetra
.739 .832 .922 r
.72974 .40872 .73066 .40973 .73268 .40872 .73176 .40762 Mtetra
.749 .818 .906 r
.73176 .40762 .73268 .40872 .7347 .40763 .73377 .40645 Mtetra
.523 .709 .957 r
.73377 .40645 .7347 .40763 .73678 .40747 .73585 .40626 Mtetra
.642 .759 .934 r
.73585 .40626 .73678 .40747 .73883 .40684 .7379 .40563 Mtetra
.835 .815 .83 r
.7379 .40563 .73883 .40684 .7408 .40493 .73987 .40371 Mtetra
.978 .766 .549 r
.73987 .40371 .7408 .40493 .74235 .39689 .74142 .39561 Mtetra
.977 .674 .345 r
.74142 .39561 .74235 .39689 .73006 .18596 .72918 .18466 Mtetra
.949 .782 .641 r
.72918 .18466 .73006 .18596 .73169 .18124 .73082 .17996 Mtetra
.743 .768 .873 r
.73082 .17996 .73169 .18124 .73357 .18011 .7327 .17884 Mtetra
.614 .718 .919 r
.7327 .17884 .73357 .18011 .7355 .17964 .73463 .17837 Mtetra
.576 .701 .927 r
.73463 .17837 .7355 .17964 .73743 .17932 .73657 .17806 Mtetra
.748 .773 .873 r
.73657 .17806 .73743 .17932 .73931 .17817 .73845 .17691 Mtetra
.669 .745 .907 r
.73845 .17691 .73931 .17817 .74123 .17744 .74036 .1762 Mtetra
.343 .578 .929 r
.74036 .1762 .74123 .17744 .74322 .1778 .74236 .17659 Mtetra
.864 .466 0 r
.74236 .17659 .74322 .1778 .74566 .18421 .74484 .18361 Mtetra
.973 .662 .317 r
.74484 .18361 .74566 .18421 .7632 .39439 .76232 .39365 Mtetra
.741 .258 0 r
.76232 .39365 .7632 .39439 .7656 .39822 .76471 .39729 Mtetra
.528 .77 .986 r
.76471 .39729 .7656 .39822 .7677 .398 .76681 .39698 Mtetra
.729 .832 .928 r
.76681 .39698 .7677 .398 .76975 .39703 .76885 .39592 Mtetra
.77 .826 .896 r
.76885 .39592 .76975 .39703 .77178 .3958 .77087 .39461 Mtetra
.517 .706 .957 r
.77087 .39461 .77178 .3958 .7739 .39566 .77299 .39444 Mtetra
.628 .753 .937 r
.77299 .39444 .7739 .39566 .77598 .39509 .77507 .39386 Mtetra
.801 .811 .86 r
.77507 .39386 .77598 .39509 .77799 .3935 .77708 .39227 Mtetra
.978 .777 .566 r
.77708 .39227 .77799 .3935 .77955 .38642 .77864 .38514 Mtetra
.976 .67 .326 r
.77864 .38514 .77955 .38642 .76472 .17441 .76386 .17309 Mtetra
.961 .778 .61 r
.76386 .17309 .76472 .17441 .76627 .16898 .76542 .16769 Mtetra
.757 .773 .866 r
.76542 .16769 .76627 .16898 .76816 .16775 .76731 .16646 Mtetra
.628 .722 .915 r
.76731 .16646 .76816 .16775 .77011 .16722 .76925 .16593 Mtetra
.551 .686 .929 r
.76925 .16593 .77011 .16722 .77208 .167 .77123 .16571 Mtetra
.749 .772 .872 r
.77123 .16571 .77208 .167 .77398 .16582 .77313 .16454 Mtetra
.68 .747 .902 r
.77313 .16454 .77398 .16582 .77591 .16505 .77506 .16377 Mtetra
.472 .647 .935 r
.77506 .16377 .77591 .16505 .77791 .16508 .77706 .16381 Mtetra
.759 .343 0 r
.77706 .16381 .77791 .16508 .78035 .17019 .7795 .16893 Mtetra
.971 .656 .295 r
.7795 .16893 .78035 .17019 .80051 .3813 .79962 .38009 Mtetra
.732 .298 0 r
.79962 .38009 .80051 .3813 .80308 .38607 .80218 .38485 Mtetra
.3 .578 .938 r
.80218 .38485 .80308 .38607 .80527 .38655 .80438 .38533 Mtetra
.647 .764 .934 r
.80438 .38533 .80527 .38655 .80737 .38587 .80648 .38465 Mtetra
.827 .822 .844 r
.80648 .38465 .80737 .38587 .80937 .38405 .80848 .38283 Mtetra
.908 .738 .659 r
.13969 .59369 .14088 .59464 .14311 .58893 .14192 .588 Mtetra
.936 .686 .535 r
.14192 .588 .14311 .58893 .16721 .38688 .16611 .3859 Mtetra
.91 .729 .645 r
.16611 .3859 .16721 .38688 .16938 .38081 .16828 .37981 Mtetra
.771 .762 .845 r
.16828 .37981 .16938 .38081 .171 .37962 .1699 .37862 Mtetra
.631 .738 .925 r
.1699 .37862 .171 .37962 .17254 .37918 .17144 .37819 Mtetra
.491 .69 .956 r
.17144 .37819 .17254 .37918 .17404 .37912 .17294 .37813 Mtetra
.683 .752 .904 r
.17294 .37813 .17404 .37912 .17562 .37834 .17451 .37749 Mtetra
.682 .782 .926 r
.17451 .37749 .17562 .37834 .17719 .37769 .17608 .37686 Mtetra
.66 .783 .94 r
.17608 .37686 .17719 .37769 .17873 .37736 .17763 .37632 Mtetra
.683 .743 .897 r
.17763 .37632 .17873 .37736 .18015 .37808 .1792 .37567 Mtetra
.589 .536 .763 r
.1792 .37567 .18015 .37808 .18144 .38001 .18073 .37538 Mtetra
.495 .381 .653 r
.18073 .37538 .18144 .38001 .18226 .38642 .18219 .37581 Mtetra
.174 .071 .488 r
.18219 .37581 .18226 .38642 .1631 .58083 .18312 .38114 Mtetra
0 0 .105 r
.18312 .38114 .1631 .58083 .16429 .58474 .16342 .58085 Mtetra
0 0 .261 r
.16342 .58085 .16429 .58474 .16572 .58633 .16456 .58519 Mtetra
0 .401 .851 r
.16456 .58519 .16572 .58633 .16728 .58675 .16609 .58594 Mtetra
.602 .784 .968 r
.16609 .58594 .16728 .58675 .16893 .58636 .16774 .58553 Mtetra
.807 .805 .849 r
.16774 .58553 .16893 .58636 .17068 .58503 .16951 .58405 Mtetra
.908 .741 .663 r
.16951 .58405 .17068 .58503 .17285 .57967 .17168 .57863 Mtetra
.939 .687 .529 r
.17168 .57863 .17285 .57967 .19531 .3772 .19423 .37605 Mtetra
.908 .723 .64 r
.19423 .37605 .19531 .3772 .19747 .37085 .19639 .36977 Mtetra
.788 .753 .821 r
.19639 .36977 .19747 .37085 .19913 .36946 .19805 .36837 Mtetra
.631 .721 .912 r
.19805 .36837 .19913 .36946 .20069 .36904 .19961 .36793 Mtetra
.485 .665 .942 r
.19961 .36793 .20069 .36904 .2022 .36904 .20112 .36792 Mtetra
.618 .711 .912 r
.20112 .36792 .2022 .36904 .20375 .36867 .20268 .36753 Mtetra
.64 .715 .902 r
.20268 .36753 .20375 .36867 .20532 .36821 .20424 .36706 Mtetra
.644 .715 .899 r
.20424 .36706 .20532 .36821 .20689 .36773 .20581 .36658 Mtetra
.653 .717 .895 r
.20581 .36658 .20689 .36773 .20846 .3672 .20738 .36605 Mtetra
.66 .72 .893 r
.20738 .36605 .20846 .3672 .21004 .36664 .20896 .3655 Mtetra
.665 .723 .892 r
.20896 .3655 .21004 .36664 .21162 .36605 .21054 .36492 Mtetra
.668 .727 .894 r
.21054 .36492 .21162 .36605 .2132 .36545 .21212 .36433 Mtetra
.672 .73 .894 r
.21212 .36433 .2132 .36545 .21479 .36481 .21371 .36373 Mtetra
.677 .736 .895 r
.21371 .36373 .21479 .36481 .21638 .36414 .2153 .3631 Mtetra
.687 .748 .898 r
.2153 .3631 .21638 .36414 .21798 .36336 .21689 .36243 Mtetra
.692 .77 .912 r
.21689 .36243 .21798 .36336 .21959 .36256 .21848 .36175 Mtetra
.691 .796 .93 r
.21848 .36175 .21959 .36256 .22119 .36178 .22008 .36107 Mtetra
.678 .818 .95 r
.22008 .36107 .22119 .36178 .22278 .3611 .22167 .36044 Mtetra
.669 .828 .96 r
.22167 .36044 .22278 .3611 .22438 .36048 .22326 .35983 Mtetra
.664 .831 .963 r
.22326 .35983 .22438 .36048 .22596 .35988 .22485 .35924 Mtetra
.682 .834 .956 r
.22485 .35924 .22596 .35988 .22757 .35912 .22644 .35859 Mtetra
.666 .858 .973 r
.22644 .35859 .22757 .35912 .22917 .35844 .22804 .35796 Mtetra
.624 .861 .988 r
.22804 .35796 .22917 .35844 .23074 .35806 .22962 .35743 Mtetra
.493 .783 .997 r
.22962 .35743 .23074 .35806 .2322 .35886 .23118 .35723 Mtetra
.525 .587 .859 r
.23118 .35723 .2322 .35886 .23355 .36102 .23272 .35721 Mtetra
.539 .436 .686 r
.23272 .35721 .23355 .36102 .23461 .36624 .23426 .35724 Mtetra
.572 .388 .593 r
.23426 .35724 .23461 .36624 .23582 .37002 .23587 .35647 Mtetra
.56 .361 .568 r
.23587 .35647 .23582 .37002 .23755 .368 .23749 .35565 Mtetra
.542 .35 .57 r
.23749 .35565 .23755 .368 .23911 .3679 .23906 .35545 Mtetra
.366 .212 .536 r
.23906 .35545 .23911 .3679 .22353 .56014 .24027 .35912 Mtetra
0 0 .149 r
.24027 .35912 .22353 .56014 .22472 .56538 .22391 .56044 Mtetra
0 0 .278 r
.22391 .56044 .22472 .56538 .22617 .56758 .22508 .56584 Mtetra
.161 .385 .833 r
.22508 .56584 .22617 .56758 .22778 .56806 .22666 .56674 Mtetra
.615 .692 .898 r
.22666 .56674 .22778 .56806 .22947 .56769 .22835 .56634 Mtetra
.712 .716 .853 r
.22835 .56634 .22947 .56769 .23121 .56677 .23009 .56542 Mtetra
.683 .71 .869 r
.23009 .56542 .23121 .56677 .23302 .56503 .23181 .56469 Mtetra
.707 .913 .966 r
.23181 .56469 .23302 .56503 .23492 .56216 .23354 .56382 Mtetra
0 0 0 r
.23354 .56382 .23492 .56216 .23705 .55662 .23534 .56227 Mtetra
0 0 .069 r
.23534 .56227 .23705 .55662 .25554 .35785 .23741 .55741 Mtetra
0 0 .142 r
.23741 .55741 .25554 .35785 .25764 .35145 .25618 .35509 Mtetra
.892 .86 .412 r
.25618 .35509 .25764 .35145 .25944 .3486 .25831 .34835 Mtetra
.884 .896 .833 r
.25831 .34835 .25944 .3486 .2611 .3474 .26003 .34644 Mtetra
.66 .761 .925 r
.26003 .34644 .2611 .3474 .2627 .34701 .26164 .34588 Mtetra
.524 .679 .936 r
.26164 .34588 .2627 .34701 .26427 .34692 .26321 .34577 Mtetra
.578 .696 .922 r
.26321 .34577 .26427 .34692 .26585 .34666 .2648 .34551 Mtetra
.628 .714 .908 r
.2648 .34551 .26585 .34666 .26745 .34621 .2664 .34508 Mtetra
.631 .719 .91 r
.2664 .34508 .26745 .34621 .26906 .3457 .268 .34463 Mtetra
.641 .733 .916 r
.268 .34463 .26906 .3457 .27067 .34517 .26961 .34414 Mtetra
.652 .746 .918 r
.26961 .34414 .27067 .34517 .27229 .3446 .27122 .34361 Mtetra
.664 .758 .92 r
.27122 .34361 .27229 .3446 .27391 .34396 .27284 .34303 Mtetra
.684 .776 .92 r
.27284 .34303 .27391 .34396 .27554 .34319 .27446 .34237 Mtetra
.698 .802 .929 r
.27446 .34237 .27554 .34319 .27718 .34235 .27609 .34165 Mtetra
.702 .831 .944 r
.27609 .34165 .27718 .34235 .27882 .34151 .27772 .34092 Mtetra
.709 .856 .952 r
.27772 .34092 .27882 .34151 .28046 .34061 .27936 .34015 Mtetra
.694 .884 .968 r
.27936 .34015 .28046 .34061 .2821 .33979 .28099 .3394 Mtetra
.644 .89 .984 r
.28099 .3394 .2821 .33979 .28372 .3393 .28262 .33877 Mtetra
.64 .859 .983 r
.28262 .33877 .28372 .3393 .28527 .33962 .28424 .3382 Mtetra
.602 .656 .876 r
.28424 .3382 .28527 .33962 .28673 .34121 .28585 .33787 Mtetra
.497 .428 .71 r
.28585 .33787 .28673 .34121 .28797 .34583 .28741 .33818 Mtetra
.268 .171 .555 r
.28741 .33818 .28797 .34583 .27484 .54402 .28874 .34149 Mtetra
0 0 .188 r
.28874 .34149 .27484 .54402 .27615 .54917 .27537 .54334 Mtetra
0 0 .348 r
.27537 .54334 .27615 .54917 .27769 .55117 .27663 .54919 Mtetra
.071 .291 .777 r
.27663 .54919 .27769 .55117 .27935 .5517 .27823 .55045 Mtetra
.59 .698 .918 r
.27823 .55045 .27935 .5517 .28106 .55141 .27995 .55012 Mtetra
.69 .725 .876 r
.27995 .55012 .28106 .55141 .2828 .55084 .2817 .54935 Mtetra
.676 .69 .856 r
.2817 .54935 .2828 .55084 .28455 .55024 .28346 .54862 Mtetra
.642 .659 .851 r
.28346 .54862 .28455 .55024 .28628 .54971 .2852 .54807 Mtetra
.644 .658 .849 r
.2852 .54807 .28628 .54971 .28803 .54914 .28694 .5475 Mtetra
.643 .657 .849 r
.28694 .5475 .28803 .54914 .28977 .54858 .28868 .54694 Mtetra
.641 .656 .849 r
.28868 .54694 .28977 .54858 .29151 .54803 .29043 .54639 Mtetra
.29043 .54639 .29151 .54803 .29326 .54749 .29217 .54584 Mtetra
.64 .656 .849 r
.29217 .54584 .29326 .54749 .295 .54694 .29392 .54529 Mtetra
.29392 .54529 .295 .54694 .29675 .54639 .29566 .54474 Mtetra
.29566 .54474 .29675 .54639 .2985 .54584 .29741 .54419 Mtetra
.29741 .54419 .2985 .54584 .30024 .54529 .29916 .54364 Mtetra
.641 .656 .85 r
.29916 .54364 .30024 .54529 .30199 .54473 .30091 .54309 Mtetra
.30091 .54309 .30199 .54473 .30375 .54418 .30266 .54253 Mtetra
.641 .657 .85 r
.30266 .54253 .30375 .54418 .3055 .54363 .30441 .54198 Mtetra
.30441 .54198 .3055 .54363 .30725 .54307 .30617 .54142 Mtetra
.30617 .54142 .30725 .54307 .30901 .54251 .30792 .54087 Mtetra
.30792 .54087 .30901 .54251 .31076 .54196 .30968 .54031 Mtetra
.642 .657 .85 r
.30968 .54031 .31076 .54196 .31252 .5414 .31144 .53975 Mtetra
.31144 .53975 .31252 .5414 .31428 .54084 .3132 .53919 Mtetra
.3132 .53919 .31428 .54084 .31604 .54028 .31496 .53863 Mtetra
.642 .658 .85 r
.31496 .53863 .31604 .54028 .3178 .53972 .31672 .53807 Mtetra
.31672 .53807 .3178 .53972 .31956 .53915 .31848 .53751 Mtetra
.641 .658 .851 r
.31848 .53751 .31956 .53915 .32132 .5386 .32024 .53695 Mtetra
.64 .657 .851 r
.32024 .53695 .32132 .5386 .32309 .53805 .32201 .5364 Mtetra
.643 .658 .85 r
.32201 .5364 .32309 .53805 .32486 .53747 .32377 .53583 Mtetra
.616 .649 .86 r
.32377 .53583 .32486 .53747 .32662 .53693 .32553 .53541 Mtetra
.595 .657 .881 r
.32553 .53541 .32662 .53693 .32839 .53639 .32729 .53508 Mtetra
.687 .724 .877 r
.32729 .53508 .32839 .53639 .33017 .53557 .32907 .53431 Mtetra
.838 .756 .773 r
.32907 .53431 .33017 .53557 .33201 .53388 .33094 .53205 Mtetra
.907 .708 .623 r
.33094 .53205 .33201 .53388 .33394 .53037 .33309 .52491 Mtetra
.951 .684 .496 r
.33309 .52491 .33394 .53037 .33607 .52346 .34642 .32075 Mtetra
.538 .312 .52 r
.34642 .32075 .33607 .52346 .34873 .32808 .34829 .31639 Mtetra
.57 .374 .577 r
.34829 .31639 .34873 .32808 .3505 .32567 .34998 .3154 Mtetra
.549 .364 .583 r
.34998 .3154 .3505 .32567 .3521 .32641 .35163 .31507 Mtetra
.542 .355 .576 r
.35163 .31507 .3521 .32641 .35354 .33006 .35328 .31489 Mtetra
.548 .348 .562 r
.35328 .31489 .35354 .33006 .34593 .50199 .35494 .31439 Mtetra
.53 .306 .519 r
.35494 .31439 .34593 .50199 .35655 .33526 .35661 .31379 Mtetra
.549 .341 .55 r
.35661 .31379 .35655 .33526 .35893 .32143 .35829 .3129 Mtetra
.594 .407 .599 r
.35829 .3129 .35893 .32143 .36089 .31533 .36 .31166 Mtetra
.655 .518 .685 r
.36 .31166 .36089 .31533 .3627 .31206 .3617 .31046 Mtetra
.71 .678 .817 r
.3617 .31046 .3627 .31206 .36444 .31019 .3634 .30949 Mtetra
.675 .832 .959 r
.3634 .30949 .36444 .31019 .36612 .30942 .36507 .30883 Mtetra
.637 .85 .981 r
.36507 .30883 .36612 .30942 .36779 .30892 .36675 .30825 Mtetra
.641 .832 .974 r
.36675 .30825 .36779 .30892 .36946 .30848 .36842 .30769 Mtetra
.665 .811 .953 r
.36842 .30769 .36946 .30848 .37114 .30787 .3701 .30708 Mtetra
.664 .809 .953 r
.3701 .30708 .37114 .30787 .37281 .30726 .37178 .30646 Mtetra
.695 .815 .939 r
.37178 .30646 .37281 .30726 .3745 .30658 .37346 .30573 Mtetra
.738 .812 .91 r
.37346 .30573 .3745 .30658 .37618 .30577 .37516 .3048 Mtetra
.651 .767 .934 r
.37516 .3048 .37618 .30577 .37786 .3052 .37683 .30425 Mtetra
.121 .508 .909 r
.37683 .30425 .37786 .3052 .37951 .30526 .37846 .30479 Mtetra
.908 .509 .227 r
.37846 .30479 .37951 .30526 .3811 .30679 .37991 .30928 Mtetra
.955 .68 .475 r
.37991 .30928 .3811 .30679 .38256 .31104 .37224 .51313 Mtetra
.537 .306 .513 r
.37224 .51313 .38256 .31104 .37525 .51101 .37379 .51795 Mtetra
.542 .248 .417 r
.37379 .51795 .37525 .51101 .37677 .51657 .37554 .51853 Mtetra
.409 0 .139 r
.37554 .51853 .37677 .51657 .37845 .51862 .37732 .51837 Mtetra
.469 .865 .969 r
.37732 .51837 .37845 .51862 .3802 .5194 .37912 .51792 Mtetra
.612 .673 .885 r
.37912 .51792 .3802 .5194 .38198 .51924 .38092 .5175 Mtetra
.633 .646 .845 r
.38092 .5175 .38198 .51924 .38378 .51874 .38272 .51697 Mtetra
.628 .64 .843 r
.38272 .51697 .38378 .51874 .38559 .51811 .38453 .51646 Mtetra
.576 .633 .871 r
.38453 .51646 .38559 .51811 .3874 .51764 .38632 .51621 Mtetra
.662 .702 .876 r
.38632 .51621 .3874 .51764 .38921 .51688 .38813 .51555 Mtetra
.802 .753 .807 r
.38813 .51555 .38921 .51688 .39106 .51546 .38999 .51382 Mtetra
.908 .724 .64 r
.38999 .51382 .39106 .51546 .39297 .51224 .39201 .50795 Mtetra
.958 .686 .479 r
.39201 .50795 .39297 .51224 .39499 .50638 .40188 .30269 Mtetra
.541 .314 .52 r
.40188 .30269 .39499 .50638 .40432 .31041 .40379 .2968 Mtetra
.566 .366 .569 r
.40379 .2968 .40432 .31041 .40606 .30884 .4055 .29573 Mtetra
.547 .353 .569 r
.4055 .29573 .40606 .30884 .40769 .31018 .4072 .29535 Mtetra
.543 .345 .563 r
.4072 .29535 .40769 .31018 .40954 .30568 .40889 .29505 Mtetra
.581 .387 .583 r
.40889 .29505 .40954 .30568 .41151 .2981 .41061 .29383 Mtetra
.64 .493 .667 r
.41061 .29383 .41151 .2981 .41332 .2945 .41234 .29265 Mtetra
.703 .65 .794 r
.41234 .29265 .41332 .2945 .41508 .29233 .41406 .29162 Mtetra
.669 .835 .963 r
.41406 .29162 .41508 .29233 .41679 .29149 .41576 .29097 Mtetra
.616 .864 .99 r
.41576 .29097 .41679 .29149 .41849 .29098 .41747 .29041 Mtetra
.61 .852 .99 r
.41747 .29041 .41849 .29098 .42019 .29058 .41917 .28988 Mtetra
.653 .833 .969 r
.41917 .28988 .42019 .29058 .4219 .28997 .42088 .28928 Mtetra
.652 .833 .97 r
.42088 .28928 .4219 .28997 .42361 .28939 .42259 .28867 Mtetra
.648 .828 .969 r
.42259 .28867 .42361 .28939 .42532 .28884 .4243 .28808 Mtetra
.638 .815 .968 r
.4243 .28808 .42532 .28884 .42702 .2884 .42601 .28753 Mtetra
.643 .791 .953 r
.42601 .28753 .42702 .2884 .42873 .28798 .42772 .28699 Mtetra
.651 .766 .933 r
.42772 .28699 .42873 .28798 .43044 .28753 .42944 .28642 Mtetra
.664 .747 .911 r
.42944 .28642 .43044 .28753 .43215 .28697 .43115 .28581 Mtetra
.67 .738 .901 r
.43115 .28581 .43215 .28697 .43387 .28634 .43287 .28516 Mtetra
.675 .736 .896 r
.43287 .28516 .43387 .28634 .43559 .28565 .43459 .28449 Mtetra
.682 .743 .897 r
.43459 .28449 .43559 .28565 .43731 .28484 .43631 .28379 Mtetra
.686 .764 .911 r
.43631 .28379 .43731 .28484 .43904 .28403 .43803 .28308 Mtetra
.686 .787 .927 r
.43803 .28308 .43904 .28403 .44076 .28323 .43976 .28237 Mtetra
.679 .804 .942 r
.43976 .28237 .44076 .28323 .44248 .28255 .44148 .28169 Mtetra
.676 .803 .943 r
.44148 .28169 .44248 .28255 .44421 .2819 .44321 .28102 Mtetra
.677 .798 .939 r
.44321 .28102 .44421 .2819 .44593 .28126 .44493 .28034 Mtetra
.75 .807 .898 r
.44493 .28034 .44593 .28126 .44766 .28036 .44667 .27931 Mtetra
.683 .766 .914 r
.44667 .27931 .44766 .28036 .44939 .27967 .44839 .27861 Mtetra
.485 .687 .956 r
.44839 .27861 .44939 .27967 .45111 .27939 .45011 .27856 Mtetra
.842 .384 0 r
.45011 .27856 .45111 .27939 .45279 .28057 .45175 .28177 Mtetra
.963 .681 .45 r
.45175 .28177 .45279 .28057 .45444 .28367 .4488 .48467 Mtetra
.543 .311 .513 r
.4488 .48467 .45444 .28367 .45177 .48181 .45044 .49293 Mtetra
.547 .274 .453 r
.45044 .49293 .45177 .48181 .45341 .49104 .45226 .49378 Mtetra
.459 .086 .242 r
.45226 .49378 .45341 .49104 .45519 .49358 .4541 .49372 Mtetra
.306 .799 .801 r
.4541 .49372 .45519 .49358 .45701 .49459 .45596 .49317 Mtetra
.639 .7 .89 r
.45596 .49317 .45701 .49459 .45886 .49416 .45781 .49262 Mtetra
.661 .689 .865 r
.45781 .49262 .45886 .49416 .46072 .49333 .45967 .49194 Mtetra
.674 .717 .881 r
.45967 .49194 .46072 .49333 .46259 .49232 .46153 .4912 Mtetra
.492 .694 .958 r
.46153 .4912 .46259 .49232 .46444 .49217 .46338 .49112 Mtetra
.594 .752 .953 r
.46338 .49112 .46444 .49217 .4663 .49186 .46524 .49072 Mtetra
.741 .78 .884 r
.46524 .49072 .4663 .49186 .46816 .4911 .46711 .48963 Mtetra
.91 .745 .666 r
.46711 .48963 .46816 .4911 .47006 .48858 .46904 .48491 Mtetra
.965 .687 .456 r
.46904 .48491 .47006 .48858 .47198 .48395 .47424 .28031 Mtetra
.547 .319 .521 r
.47424 .28031 .47198 .48395 .47691 .28503 .47612 .2712 Mtetra
.588 .382 .57 r
.47612 .2712 .47691 .28503 .47881 .27432 .47789 .26923 Mtetra
.616 .46 .648 r
.47789 .26923 .47881 .27432 .4806 .2709 .47964 .26819 Mtetra
.626 .547 .745 r
.47964 .26819 .4806 .2709 .48237 .26883 .48139 .26756 Mtetra
.677 .724 .885 r
.48139 .26756 .48237 .26883 .48412 .26786 .48314 .26686 Mtetra
.664 .773 .931 r
.48314 .26686 .48412 .26786 .48587 .26726 .48489 .26623 Mtetra
.654 .764 .931 r
.48489 .26623 .48587 .26726 .48762 .26681 .48664 .26565 Mtetra
.754 .766 .863 r
.48664 .26565 .48762 .26681 .48937 .26558 .4884 .26451 Mtetra
.712 .773 .9 r
.4884 .26451 .48937 .26558 .49113 .26463 .49015 .26365 Mtetra
.527 .728 .966 r
.49015 .26365 .49113 .26463 .49288 .26436 .4919 .26346 Mtetra
.846 .396 0 r
.4919 .26346 .49288 .26436 .49459 .26793 .49361 .267 Mtetra
.969 .683 .432 r
.49361 .267 .49459 .26793 .49443 .47533 .49339 .47375 Mtetra
.916 .534 .117 r
.49339 .47375 .49443 .47533 .49624 .48174 .4952 .48025 Mtetra
.334 .539 .904 r
.4952 .48025 .49624 .48174 .49812 .48211 .49708 .48073 Mtetra
.66 .717 .891 r
.49708 .48073 .49812 .48211 .5 .48131 .49896 .48007 Mtetra
.741 .765 .872 r
.49896 .48007 .5 .48131 .50189 .48005 .50085 .47895 Mtetra
.513 .708 .959 r
.50085 .47895 .50189 .48005 .50378 .47998 .50274 .4788 Mtetra
.574 .72 .942 r
.50274 .4788 .50378 .47998 .50566 .47976 .50462 .47848 Mtetra
.728 .755 .874 r
.50462 .47848 .50566 .47976 .50755 .47881 .50651 .47743 Mtetra
.921 .755 .659 r
.50651 .47743 .50755 .47881 .50946 .47381 .50843 .4725 Mtetra
.97 .689 .44 r
.50843 .4725 .50946 .47381 .51221 .26495 .51123 .26438 Mtetra
.972 .774 .579 r
.51123 .26438 .51221 .26495 .514 .25758 .51303 .2568 Mtetra
.845 .849 .847 r
.51303 .2568 .514 .25758 .51577 .25597 .51481 .2551 Mtetra
.636 .797 .96 r
.51481 .2551 .51577 .25597 .51754 .25553 .51658 .25455 Mtetra
.494 .714 .969 r
.51658 .25455 .51754 .25553 .51931 .25555 .51835 .25444 Mtetra
.635 .743 .926 r
.51835 .25444 .51931 .25555 .52108 .25512 .52012 .25393 Mtetra
.671 .74 .902 r
.52012 .25393 .52108 .25512 .52285 .25448 .52189 .25326 Mtetra
.676 .736 .896 r
.52189 .25326 .52285 .25448 .52463 .25377 .52367 .25256 Mtetra
.752 .761 .86 r
.52367 .25256 .52463 .25377 .5264 .25254 .52544 .25142 Mtetra
.727 .772 .889 r
.52544 .25142 .5264 .25254 .52818 .25148 .52722 .25047 Mtetra
.576 .742 .955 r
.52722 .25047 .52818 .25148 .52996 .25105 .529 .25014 Mtetra
.747 .265 0 r
.529 .25014 .52996 .25105 .53174 .25365 .53078 .25289 Mtetra
.971 .681 .418 r
.53078 .25289 .53174 .25365 .5341 .4587 .53308 .45846 Mtetra
.934 .564 .277 r
.53308 .45846 .5341 .4587 .53604 .46806 .53501 .46695 Mtetra
0 .255 .745 r
.53501 .46695 .53604 .46806 .53795 .46928 .53693 .46825 Mtetra
.571 .752 .963 r
.53693 .46825 .53795 .46928 .53986 .46886 .53884 .4679 Mtetra
.791 .829 .881 r
.53884 .4679 .53986 .46886 .54177 .46759 .54075 .46651 Mtetra
.922 .794 .701 r
.54075 .46651 .54177 .46759 .54368 .4653 .54265 .46268 Mtetra
.953 .695 .507 r
.54265 .46268 .54368 .4653 .54557 .46135 .54444 .44221 Mtetra
.953 .666 .454 r
.54444 .44221 .54557 .46135 .5474 .44933 .54507 .24758 Mtetra
.534 .309 .519 r
.54507 .24758 .5474 .44933 .54784 .25109 .54685 .24487 Mtetra
.608 .439 .627 r
.54685 .24487 .54784 .25109 .5496 .24698 .54863 .24371 Mtetra
.619 .515 .714 r
.54863 .24371 .5496 .24698 .55138 .24462 .55043 .24301 Mtetra
.66 .671 .849 r
.55043 .24301 .55138 .24462 .55317 .2434 .55222 .24234 Mtetra
.666 .767 .925 r
.55222 .24234 .55317 .2434 .55496 .24273 .55401 .24169 Mtetra
.656 .769 .932 r
.55401 .24169 .55496 .24273 .55676 .24224 .55581 .24108 Mtetra
.743 .772 .876 r
.55581 .24108 .55676 .24224 .55855 .24114 .5576 .24001 Mtetra
.735 .776 .886 r
.5576 .24001 .55855 .24114 .56034 .24003 .55939 .23901 Mtetra
.603 .754 .95 r
.55939 .23901 .56034 .24003 .56214 .23951 .5612 .23859 Mtetra
.625 .127 0 r
.5612 .23859 .56214 .23951 .56397 .24161 .56303 .24082 Mtetra
.973 .68 .405 r
.56303 .24082 .56397 .24161 .56848 .4437 .5675 .44438 Mtetra
.93 .577 .333 r
.5675 .44438 .56848 .4437 .57059 .45661 .56958 .45549 Mtetra
0 .136 .645 r
.56958 .45549 .57059 .45661 .57256 .45821 .57155 .45714 Mtetra
.543 .734 .964 r
.57155 .45714 .57256 .45821 .57449 .45786 .57349 .45688 Mtetra
.777 .827 .891 r
.57349 .45688 .57449 .45786 .57642 .45665 .57542 .45558 Mtetra
.918 .803 .718 r
.57542 .45558 .57642 .45665 .57833 .45446 .57731 .45207 Mtetra
.947 .703 .536 r
.57731 .45207 .57833 .45446 .58022 .45071 .57904 .43895 Mtetra
.965 .675 .432 r
.57904 .43895 .58022 .45071 .582 .44092 .5775 .23645 Mtetra
.535 .309 .519 r
.5775 .23645 .582 .44092 .58031 .24006 .57927 .23336 Mtetra
.606 .432 .62 r
.57927 .23336 .58031 .24006 .58205 .23565 .58107 .23214 Mtetra
.616 .504 .703 r
.58107 .23214 .58205 .23565 .58383 .23318 .58288 .23143 Mtetra
.651 .649 .835 r
.58288 .23143 .58383 .23318 .58563 .23185 .5847 .23079 Mtetra
.663 .768 .928 r
.5847 .23079 .58563 .23185 .58744 .23114 .58651 .23014 Mtetra
.649 .776 .941 r
.58651 .23014 .58744 .23114 .58926 .23067 .58833 .22955 Mtetra
.729 .778 .892 r
.58833 .22955 .58926 .23067 .59107 .22977 .59014 .22858 Mtetra
.732 .766 .88 r
.59014 .22858 .59107 .22977 .59288 .22876 .59195 .22756 Mtetra
.619 .724 .922 r
.59195 .22756 .59288 .22876 .59471 .22831 .59378 .2271 Mtetra
0 .065 .601 r
.59378 .2271 .59471 .22831 .59659 .23018 .59566 .22898 Mtetra
.974 .678 .39 r
.59566 .22898 .59659 .23018 .60326 .43099 .60228 .42993 Mtetra
.956 .611 .269 r
.60228 .42993 .60326 .43099 .60557 .44511 .60458 .44397 Mtetra
0 .053 .573 r
.60458 .44397 .60557 .44511 .60759 .44697 .6066 .44593 Mtetra
.512 .728 .971 r
.6066 .44593 .60759 .44697 .60956 .4467 .60858 .44575 Mtetra
.765 .836 .906 r
.60858 .44575 .60956 .4467 .61151 .44556 .61052 .44453 Mtetra
.915 .817 .736 r
.61052 .44453 .61151 .44556 .61343 .44346 .61242 .44131 Mtetra
.948 .713 .551 r
.61242 .44131 .61343 .44346 .61531 .43985 .61411 .43077 Mtetra
.97 .677 .415 r
.61411 .43077 .61531 .43985 .61705 .43114 .61032 .22519 Mtetra
.535 .31 .519 r
.61032 .22519 .61705 .43114 .61317 .22875 .61207 .22167 Mtetra
.605 .427 .615 r
.61207 .22167 .61317 .22875 .61489 .22407 .61389 .22038 Mtetra
.616 .498 .695 r
.61389 .22038 .61489 .22407 .61666 .22151 .61572 .21962 Mtetra
.646 .631 .821 r
.61572 .21962 .61666 .22151 .61847 .22006 .61756 .21897 Mtetra
.667 .767 .925 r
.61756 .21897 .61847 .22006 .62031 .21931 .61939 .2183 Mtetra
.653 .779 .941 r
.61939 .2183 .62031 .21931 .62215 .2188 .62123 .21769 Mtetra
.719 .78 .901 r
.62123 .21769 .62215 .2188 .62398 .21796 .62306 .21676 Mtetra
.739 .77 .877 r
.62306 .21676 .62398 .21796 .62581 .2169 .62489 .2157 Mtetra
.642 .735 .916 r
.62489 .2157 .62581 .2169 .62765 .21634 .62674 .21513 Mtetra
0 .277 .776 r
.62674 .21513 .62765 .21634 .62956 .21767 .62865 .21646 Mtetra
.943 .583 .201 r
.62865 .21646 .62956 .21767 .6318 .22818 .63088 .2271 Mtetra
.975 .675 .374 r
.63088 .2271 .6318 .22818 .64097 .43273 .63999 .43161 Mtetra
0 0 .5 r
.63999 .43161 .64097 .43273 .64305 .435 .64208 .43389 Mtetra
.599 .753 .952 r
.64208 .43389 .64305 .435 .64504 .43451 .64407 .43344 Mtetra
.745 .811 .905 r
.64407 .43344 .64504 .43451 .64701 .43337 .64604 .43231 Mtetra
.747 .817 .906 r
.64604 .43231 .64701 .43337 .64898 .4323 .64801 .43118 Mtetra
.674 .781 .93 r
.64801 .43118 .64898 .4323 .65097 .43172 .64999 .43042 Mtetra
.668 .745 .908 r
.64999 .43042 .65097 .43172 .65296 .43115 .65198 .42968 Mtetra
.654 .712 .89 r
.65198 .42968 .65296 .43115 .65495 .4305 .65397 .42901 Mtetra
.639 .701 .891 r
.65397 .42901 .65495 .4305 .65694 .42976 .65597 .42842 Mtetra
.63 .722 .914 r
.65597 .42842 .65694 .42976 .65893 .42903 .65796 .42786 Mtetra
.608 .748 .944 r
.65796 .42786 .65893 .42903 .66093 .42853 .65997 .42738 Mtetra
.594 .747 .95 r
.65997 .42738 .66093 .42853 .66294 .42824 .66197 .42695 Mtetra
.619 .729 .925 r
.66197 .42695 .66294 .42824 .66494 .42768 .66398 .42644 Mtetra
.623 .74 .931 r
.66398 .42644 .66494 .42768 .66691 .42636 .66598 .42591 Mtetra
.567 .889 .988 r
.66598 .42591 .66691 .42636 .66882 .42364 .66798 .42527 Mtetra
.088 0 0 r
.66798 .42527 .66882 .42364 .67062 .41862 .66996 .42403 Mtetra
.199 0 .291 r
.66996 .42403 .67062 .41862 .66341 .21592 .67184 .42068 Mtetra
0 0 .374 r
.67184 .42068 .66341 .21592 .66492 .20743 .6645 .21653 Mtetra
0 0 .18 r
.6645 .21653 .66492 .20743 .66666 .20405 .66582 .20396 Mtetra
.959 .94 .714 r
.66582 .20396 .66666 .20405 .66848 .20221 .66757 .2009 Mtetra
.711 .746 .879 r
.66757 .2009 .66848 .20221 .67034 .2014 .66943 .19998 Mtetra
.61 .684 .895 r
.66943 .19998 .67034 .2014 .67222 .2009 .67132 .19955 Mtetra
.639 .71 .898 r
.67132 .19955 .67222 .2009 .67409 .20023 .67319 .19899 Mtetra
.74 .768 .875 r
.67319 .19899 .67409 .20023 .67594 .19913 .67505 .1979 Mtetra
.65 .737 .913 r
.67505 .1979 .67594 .19913 .67782 .19851 .67692 .19729 Mtetra
.1 .427 .87 r
.67692 .19729 .67782 .19851 .67977 .19943 .67888 .19822 Mtetra
.918 .541 .121 r
.67888 .19822 .67977 .19943 .68214 .20814 .68125 .20708 Mtetra
.975 .67 .35 r
.68125 .20708 .68214 .20814 .69494 .41544 .694 .41428 Mtetra
.623 .158 0 r
.694 .41428 .69494 .41544 .69716 .41853 .69621 .41735 Mtetra
.412 .651 .957 r
.69621 .41735 .69716 .41853 .69923 .41867 .69828 .41749 Mtetra
.71 .787 .912 r
.69828 .41749 .69923 .41867 .70124 .41772 .70029 .41654 Mtetra
.888 .817 .772 r
.70029 .41654 .70124 .41772 .70315 .41506 .70221 .41388 Mtetra
.978 .757 .534 r
.70221 .41388 .70315 .41506 .7047 .40576 .70375 .40457 Mtetra
.977 .678 .362 r
.70375 .40457 .7047 .40576 .69495 .19621 .69406 .19497 Mtetra
.937 .787 .669 r
.69406 .19497 .69495 .19621 .69664 .19209 .69576 .19084 Mtetra
.731 .767 .881 r
.69576 .19084 .69664 .19209 .69851 .19105 .69762 .18981 Mtetra
.602 .716 .925 r
.69762 .18981 .69851 .19105 .70041 .19063 .69953 .1894 Mtetra
.599 .716 .926 r
.69953 .1894 .70041 .19063 .70232 .19022 .70144 .18899 Mtetra
.741 .774 .879 r
.70144 .18899 .70232 .19022 .70418 .18911 .7033 .1879 Mtetra
.655 .746 .917 r
.7033 .1879 .70418 .18911 .70608 .18847 .7052 .18727 Mtetra
.197 .496 .904 r
.7052 .18727 .70608 .18847 .70806 .18922 .70718 .18798 Mtetra
.898 .513 .07 r
.70718 .18798 .70806 .18922 .71055 .19825 .70961 .19609 Mtetra
.975 .667 .331 r
.70961 .19609 .71055 .19825 .72541 .4061 .72444 .40443 Mtetra
0 0 .5 r
.72444 .40443 .72541 .4061 .72768 .40912 .72672 .40761 Mtetra
.569 .67 .907 r
.72672 .40761 .72768 .40912 .72974 .40872 .72879 .40733 Mtetra
.708 .75 .885 r
.72879 .40733 .72974 .40872 .73176 .40762 .73082 .40634 Mtetra
.726 .777 .893 r
.73082 .40634 .73176 .40762 .73377 .40645 .73284 .40527 Mtetra
.521 .711 .958 r
.73284 .40527 .73377 .40645 .73585 .40626 .73492 .40509 Mtetra
.646 .768 .938 r
.73492 .40509 .73585 .40626 .7379 .40563 .73697 .40444 Mtetra
.839 .819 .83 r
.73697 .40444 .7379 .40563 .73987 .40371 .73894 .40249 Mtetra
.978 .766 .548 r
.73894 .40249 .73987 .40371 .74142 .39561 .74049 .39433 Mtetra
.977 .674 .345 r
.74049 .39433 .74142 .39561 .72918 .18466 .72831 .18337 Mtetra
.949 .782 .642 r
.72831 .18337 .72918 .18466 .73082 .17996 .72995 .17869 Mtetra
.742 .769 .874 r
.72995 .17869 .73082 .17996 .7327 .17884 .73183 .17757 Mtetra
.613 .718 .92 r
.73183 .17757 .7327 .17884 .73463 .17837 .73376 .17711 Mtetra
.573 .701 .928 r
.73376 .17711 .73463 .17837 .73657 .17806 .7357 .17681 Mtetra
.745 .774 .876 r
.7357 .17681 .73657 .17806 .73845 .17691 .73758 .17568 Mtetra
.668 .75 .912 r
.73758 .17568 .73845 .17691 .74036 .1762 .7395 .17497 Mtetra
.347 .586 .933 r
.7395 .17497 .74036 .1762 .74236 .17659 .74149 .17534 Mtetra
.845 .442 0 r
.74149 .17534 .74236 .17659 .74484 .18361 .74393 .1818 Mtetra
.973 .662 .313 r
.74393 .1818 .74484 .18361 .76232 .39365 .76137 .39193 Mtetra
0 0 .429 r
.76137 .39193 .76232 .39365 .76471 .39729 .76377 .39575 Mtetra
.548 .657 .907 r
.76377 .39575 .76471 .39729 .76681 .39698 .76588 .39555 Mtetra
.699 .745 .887 r
.76588 .39555 .76681 .39698 .76885 .39592 .76793 .39461 Mtetra
.743 .781 .883 r
.76793 .39461 .76885 .39592 .77087 .39461 .76996 .39342 Mtetra
.515 .706 .957 r
.76996 .39342 .77087 .39461 .77299 .39444 .77208 .39325 Mtetra
.632 .762 .941 r
.77208 .39325 .77299 .39444 .77507 .39386 .77416 .39265 Mtetra
.806 .816 .86 r
.77416 .39265 .77507 .39386 .77708 .39227 .77617 .39103 Mtetra
.978 .776 .564 r
.77617 .39103 .77708 .39227 .77864 .38514 .77773 .38385 Mtetra
.976 .67 .326 r
.77773 .38385 .77864 .38514 .76386 .17309 .763 .17177 Mtetra
.961 .778 .611 r
.763 .17177 .76386 .17309 .76542 .16769 .76456 .16639 Mtetra
.756 .773 .867 r
.76456 .16639 .76542 .16769 .76731 .16646 .76645 .16517 Mtetra
.627 .723 .916 r
.76645 .16517 .76731 .16646 .76925 .16593 .7684 .16464 Mtetra
.55 .686 .929 r
.7684 .16464 .76925 .16593 .77123 .16571 .77038 .16442 Mtetra
.748 .772 .873 r
.77038 .16442 .77123 .16571 .77313 .16454 .77228 .16326 Mtetra
.679 .747 .902 r
.77228 .16326 .77313 .16454 .77506 .16377 .77421 .16249 Mtetra
.471 .646 .935 r
.77421 .16249 .77506 .16377 .77706 .16381 .77621 .16253 Mtetra
.76 .344 0 r
.77621 .16253 .77706 .16381 .7795 .16893 .77865 .16767 Mtetra
.971 .656 .295 r
.77865 .16767 .7795 .16893 .79962 .38009 .79873 .37889 Mtetra
.732 .297 0 r
.79873 .37889 .79962 .38009 .80218 .38485 .80129 .38363 Mtetra
.3 .578 .938 r
.80129 .38363 .80218 .38485 .80438 .38533 .80348 .38411 Mtetra
.647 .765 .935 r
.80348 .38411 .80438 .38533 .80648 .38465 .80559 .38343 Mtetra
.827 .822 .844 r
.80559 .38343 .80648 .38465 .80848 .38283 .80759 .38161 Mtetra
.908 .738 .659 r
.13851 .59273 .13969 .59369 .14192 .588 .14073 .58707 Mtetra
.936 .686 .535 r
.14073 .58707 .14192 .588 .16611 .3859 .165 .38492 Mtetra
.91 .729 .645 r
.165 .38492 .16611 .3859 .16828 .37981 .16718 .3788 Mtetra
.771 .762 .845 r
.16718 .3788 .16828 .37981 .1699 .37862 .1688 .37761 Mtetra
.63 .737 .925 r
.1688 .37761 .1699 .37862 .17144 .37819 .17034 .37718 Mtetra
.49 .689 .956 r
.17034 .37718 .17144 .37819 .17294 .37813 .17184 .37713 Mtetra
.665 .748 .912 r
.17184 .37713 .17294 .37813 .17451 .37749 .1734 .37657 Mtetra
.678 .766 .917 r
.1734 .37657 .17451 .37749 .17608 .37686 .17497 .37595 Mtetra
.687 .771 .915 r
.17497 .37595 .17608 .37686 .17763 .37632 .17654 .3753 Mtetra
.773 .761 .843 r
.17654 .3753 .17763 .37632 .1792 .37567 .17817 .37409 Mtetra
.7 .665 .813 r
.17817 .37409 .1792 .37567 .18073 .37538 .17976 .37322 Mtetra
.576 .549 .787 r
.17976 .37322 .18073 .37538 .18219 .37581 .18128 .37302 Mtetra
.678 .375 0 r
.18128 .37302 .18219 .37581 .18312 .38114 .18241 .37652 Mtetra
.944 .688 .519 r
.18241 .37652 .18312 .38114 .16342 .58085 .16248 .57761 Mtetra
.939 .623 .176 r
.16248 .57761 .16342 .58085 .16456 .58519 .16339 .58413 Mtetra
0 .291 .76 r
.16339 .58413 .16456 .58519 .16609 .58594 .1649 .58504 Mtetra
.612 .77 .956 r
.1649 .58504 .16609 .58594 .16774 .58553 .16656 .58462 Mtetra
.811 .791 .834 r
.16656 .58462 .16774 .58553 .16951 .58405 .16833 .58304 Mtetra
.909 .737 .656 r
.16833 .58304 .16951 .58405 .17168 .57863 .17054 .57728 Mtetra
.939 .687 .529 r
.17054 .57728 .17168 .57863 .19423 .37605 .19322 .37426 Mtetra
.881 .693 .643 r
.19322 .37426 .19423 .37605 .19639 .36977 .19534 .36839 Mtetra
.76 .708 .802 r
.19534 .36839 .19639 .36977 .19805 .36837 .19699 .36708 Mtetra
.615 .678 .887 r
.19699 .36708 .19805 .36837 .19961 .36793 .19854 .36671 Mtetra
.478 .636 .924 r
.19854 .36671 .19961 .36793 .20112 .36792 .20005 .36674 Mtetra
.635 .707 .898 r
.20005 .36674 .20112 .36792 .20268 .36753 .20161 .36629 Mtetra
.663 .704 .877 r
.20161 .36629 .20268 .36753 .20424 .36706 .20319 .36571 Mtetra
.664 .686 .861 r
.20319 .36571 .20424 .36706 .20581 .36658 .20477 .36511 Mtetra
.654 .666 .849 r
.20477 .36511 .20581 .36658 .20738 .36605 .20635 .36455 Mtetra
.651 .66 .845 r
.20635 .36455 .20738 .36605 .20896 .3655 .20792 .364 Mtetra
.652 .661 .845 r
.20792 .364 .20896 .3655 .21054 .36492 .2095 .36344 Mtetra
.656 .665 .846 r
.2095 .36344 .21054 .36492 .21212 .36433 .21108 .36287 Mtetra
.659 .668 .847 r
.21108 .36287 .21212 .36433 .21371 .36373 .21266 .36228 Mtetra
.661 .671 .849 r
.21266 .36228 .21371 .36373 .2153 .3631 .21425 .36168 Mtetra
.663 .677 .853 r
.21425 .36168 .2153 .3631 .21689 .36243 .21584 .36108 Mtetra
.665 .688 .862 r
.21584 .36108 .21689 .36243 .21848 .36175 .21742 .36048 Mtetra
.667 .702 .873 r
.21742 .36048 .21848 .36175 .22008 .36107 .21901 .35988 Mtetra
.668 .716 .884 r
.21901 .35988 .22008 .36107 .22167 .36044 .2206 .35928 Mtetra
.667 .721 .889 r
.2206 .35928 .22167 .36044 .22326 .35983 .22219 .35869 Mtetra
.663 .723 .894 r
.22219 .35869 .22326 .35983 .22485 .35924 .22378 .35812 Mtetra
.648 .723 .903 r
.22378 .35812 .22485 .35924 .22644 .35859 .22536 .35761 Mtetra
.643 .751 .928 r
.22536 .35761 .22644 .35859 .22804 .35796 .22694 .35712 Mtetra
.648 .782 .945 r
.22694 .35712 .22804 .35796 .22962 .35743 .22853 .3566 Mtetra
.684 .793 .932 r
.22853 .3566 .22962 .35743 .23118 .35723 .23013 .35595 Mtetra
.687 .707 .863 r
.23013 .35595 .23118 .35723 .23272 .35721 .23173 .35524 Mtetra
.66 .611 .788 r
.23173 .35524 .23272 .35721 .23426 .35724 .23334 .35454 Mtetra
.66 .559 .729 r
.23334 .35454 .23426 .35724 .23587 .35647 .23496 .35362 Mtetra
.639 .539 .724 r
.23496 .35362 .23587 .35647 .23749 .35565 .23658 .35286 Mtetra
.581 .508 .738 r
.23658 .35286 .23749 .35565 .23906 .35545 .23814 .35259 Mtetra
.078 .18 .67 r
.23814 .35259 .23906 .35545 .24027 .35912 .23953 .35433 Mtetra
.876 .616 .091 r
.23953 .35433 .24027 .35912 .22391 .56044 .24035 .36251 Mtetra
0 0 .148 r
.24035 .36251 .22391 .56044 .22508 .56584 .22425 .56122 Mtetra
.153 .152 .603 r
.22425 .56122 .22508 .56584 .22666 .56674 .22568 .56373 Mtetra
.44 .42 .74 r
.22568 .56373 .22666 .56674 .22835 .56634 .22729 .56429 Mtetra
.54 .558 .822 r
.22729 .56429 .22835 .56634 .23009 .56542 .22895 .56425 Mtetra
.492 .671 .944 r
.22895 .56425 .23009 .56542 .23181 .56469 .23061 .56421 Mtetra
.489 .826 .999 r
.23061 .56421 .23181 .56469 .23354 .56382 .2323 .5639 Mtetra
.629 .955 .924 r
.2323 .5639 .23354 .56382 .23534 .56227 .23403 .56299 Mtetra
.932 .969 .739 r
.23403 .56299 .23534 .56227 .23741 .55741 .23594 .56014 Mtetra
.987 .877 .532 r
.23594 .56014 .23741 .55741 .25618 .35509 .23826 .55243 Mtetra
0 0 .137 r
.23826 .55243 .25618 .35509 .25831 .34835 .25692 .35111 Mtetra
.663 .793 .335 r
.25692 .35111 .25831 .34835 .26003 .34644 .2588 .34726 Mtetra
.681 .953 .701 r
.2588 .34726 .26003 .34644 .26164 .34588 .2605 .34564 Mtetra
.747 .933 .949 r
.2605 .34564 .26164 .34588 .26321 .34577 .26215 .34466 Mtetra
.671 .734 .898 r
.26215 .34466 .26321 .34577 .2648 .34551 .26376 .34405 Mtetra
.614 .654 .866 r
.26376 .34405 .2648 .34551 .2664 .34508 .26536 .34367 Mtetra
.581 .65 .883 r
.26536 .34367 .2664 .34508 .268 .34463 .26695 .34343 Mtetra
.607 .697 .907 r
.26695 .34343 .268 .34463 .26961 .34414 .26854 .34307 Mtetra
.639 .733 .916 r
.26854 .34307 .26961 .34414 .27122 .34361 .27015 .34259 Mtetra
.651 .747 .92 r
.27015 .34259 .27122 .34361 .27284 .34303 .27177 .34206 Mtetra
.663 .761 .923 r
.27177 .34206 .27284 .34303 .27446 .34237 .27339 .34148 Mtetra
.674 .781 .931 r
.27339 .34148 .27446 .34237 .27609 .34165 .27501 .34086 Mtetra
.682 .805 .941 r
.27501 .34086 .27609 .34165 .27772 .34092 .27663 .34021 Mtetra
.687 .825 .949 r
.27663 .34021 .27772 .34092 .27936 .34015 .27826 .33953 Mtetra
.689 .847 .959 r
.27826 .33953 .27936 .34015 .28099 .3394 .2799 .33883 Mtetra
.69 .859 .963 r
.2799 .33883 .28099 .3394 .28262 .33877 .28153 .33812 Mtetra
.759 .847 .917 r
.28153 .33812 .28262 .33877 .28424 .3382 .28319 .33712 Mtetra
.74 .758 .868 r
.28319 .33712 .28424 .3382 .28585 .33787 .28484 .33614 Mtetra
.633 .627 .826 r
.28484 .33614 .28585 .33787 .28741 .33818 .28646 .33564 Mtetra
.165 .269 .726 r
.28646 .33564 .28741 .33818 .28874 .34149 .28794 .33701 Mtetra
.847 .582 .041 r
.28794 .33701 .28874 .34149 .27537 .54334 .28895 .34473 Mtetra
0 0 .183 r
.28895 .34473 .27537 .54334 .27663 .54919 .27576 .54448 Mtetra
.219 .198 .621 r
.27576 .54448 .27663 .54919 .27823 .55045 .27729 .54679 Mtetra
.578 .477 .703 r
.27729 .54679 .27823 .55045 .27995 .55012 .27901 .54646 Mtetra
.64 .516 .696 r
.27901 .54646 .27995 .55012 .2817 .54935 .28078 .54548 Mtetra
.627 .501 .689 r
.28078 .54548 .2817 .54935 .28346 .54862 .28254 .54459 Mtetra
.598 .478 .686 r
.28254 .54459 .28346 .54862 .2852 .54807 .28428 .54402 Mtetra
.598 .477 .686 r
.28428 .54402 .2852 .54807 .28694 .5475 .28602 .54344 Mtetra
.597 .476 .685 r
.28602 .54344 .28694 .5475 .28868 .54694 .28776 .54288 Mtetra
.596 .475 .685 r
.28776 .54288 .28868 .54694 .29043 .54639 .28951 .54232 Mtetra
.28951 .54232 .29043 .54639 .29217 .54584 .29125 .54177 Mtetra
.595 .475 .685 r
.29125 .54177 .29217 .54584 .29392 .54529 .293 .54123 Mtetra
.595 .475 .686 r
.293 .54123 .29392 .54529 .29566 .54474 .29474 .54068 Mtetra
.29474 .54068 .29566 .54474 .29741 .54419 .29649 .54014 Mtetra
.29649 .54014 .29741 .54419 .29916 .54364 .29824 .53959 Mtetra
.596 .476 .686 r
.29824 .53959 .29916 .54364 .30091 .54309 .29999 .53904 Mtetra
.29999 .53904 .30091 .54309 .30266 .54253 .30174 .53849 Mtetra
.596 .476 .687 r
.30174 .53849 .30266 .54253 .30441 .54198 .30349 .53794 Mtetra
.30349 .53794 .30441 .54198 .30617 .54142 .30524 .53739 Mtetra
.596 .477 .687 r
.30524 .53739 .30617 .54142 .30792 .54087 .30699 .53683 Mtetra
.597 .477 .687 r
.30699 .53683 .30792 .54087 .30968 .54031 .30875 .53628 Mtetra
.30875 .53628 .30968 .54031 .31144 .53975 .31051 .53572 Mtetra
.31051 .53572 .31144 .53975 .3132 .53919 .31227 .53516 Mtetra
.31227 .53516 .3132 .53919 .31496 .53863 .31402 .53459 Mtetra
.31402 .53459 .31496 .53863 .31672 .53807 .31579 .53403 Mtetra
.31579 .53403 .31672 .53807 .31848 .53751 .31755 .53347 Mtetra
.596 .477 .687 r
.31755 .53347 .31848 .53751 .32024 .53695 .31931 .53291 Mtetra
.596 .476 .687 r
.31931 .53291 .32024 .53695 .32201 .5364 .32107 .53236 Mtetra
.597 .477 .687 r
.32107 .53236 .32201 .5364 .32377 .53583 .32284 .5318 Mtetra
.572 .462 .689 r
.32284 .5318 .32377 .53583 .32553 .53541 .32459 .5315 Mtetra
.555 .455 .695 r
.32459 .5315 .32553 .53541 .32729 .53508 .32633 .53138 Mtetra
.621 .504 .698 r
.32633 .53138 .32729 .53508 .32907 .53431 .32811 .5306 Mtetra
.759 .588 .664 r
.32811 .5306 .32907 .53431 .33094 .53205 .33003 .52744 Mtetra
.952 .685 .496 r
.33003 .52744 .33094 .53205 .33309 .52491 .34339 .32589 Mtetra
.549 .321 .522 r
.34339 .32589 .33309 .52491 .34642 .32075 .34557 .31636 Mtetra
.724 .545 .648 r
.34557 .31636 .34642 .32075 .34829 .31639 .34736 .31354 Mtetra
.65 .548 .726 r
.34736 .31354 .34829 .31639 .34998 .3154 .34904 .31267 Mtetra
.6 .526 .743 r
.34904 .31267 .34998 .3154 .35163 .31507 .35069 .31226 Mtetra
.59 .516 .739 r
.35069 .31226 .35163 .31507 .35328 .31489 .35235 .31191 Mtetra
.617 .522 .724 r
.35235 .31191 .35328 .31489 .35494 .31439 .35401 .31131 Mtetra
.615 .516 .719 r
.35401 .31131 .35494 .31439 .35661 .31379 .35568 .31072 Mtetra
.615 .517 .72 r
.35568 .31072 .35661 .31379 .35829 .3129 .35735 .31013 Mtetra
.622 .537 .737 r
.35735 .31013 .35829 .3129 .36 .31166 .35902 .30953 Mtetra
.638 .591 .785 r
.35902 .30953 .36 .31166 .3617 .31046 .3607 .30893 Mtetra
.662 .668 .845 r
.3607 .30893 .3617 .31046 .3634 .30949 .36237 .30829 Mtetra
.681 .729 .886 r
.36237 .30829 .3634 .30949 .36507 .30883 .36405 .3076 Mtetra
.66 .717 .89 r
.36405 .3076 .36507 .30883 .36675 .30825 .36573 .307 Mtetra
.591 .688 .909 r
.36573 .307 .36675 .30825 .36842 .30769 .36739 .30669 Mtetra
.36 .636 .959 r
.36739 .30669 .36842 .30769 .3701 .30708 .36903 .30688 Mtetra
.195 0 0 r
.36903 .30688 .3701 .30708 .37178 .30646 .37066 .30727 Mtetra
.347 0 0 r
.37066 .30727 .37178 .30646 .37346 .30573 .37231 .30731 Mtetra
.092 0 0 r
.37231 .30731 .37346 .30573 .37516 .3048 .37401 .30634 Mtetra
.236 0 0 r
.37401 .30634 .37516 .3048 .37683 .30425 .37569 .30575 Mtetra
.638 .218 .229 r
.37569 .30575 .37683 .30425 .37846 .30479 .37729 .30691 Mtetra
.956 .68 .475 r
.37729 .30691 .37846 .30479 .37991 .30928 .36966 .50612 Mtetra
.547 .315 .514 r
.36966 .50612 .37991 .30928 .37224 .51313 .37094 .51648 Mtetra
.677 .328 .377 r
.37094 .51648 .37224 .51313 .37379 .51795 .37261 .51878 Mtetra
.271 0 0 r
.37261 .51878 .37379 .51795 .37554 .51853 .37439 .51866 Mtetra
.476 .896 .869 r
.37439 .51866 .37554 .51853 .37732 .51837 .3762 .51791 Mtetra
.774 .908 .933 r
.3762 .51791 .37732 .51837 .37912 .51792 .37803 .51673 Mtetra
.783 .77 .841 r
.37803 .51673 .37912 .51792 .38092 .5175 .37987 .5153 Mtetra
.744 .647 .753 r
.37987 .5153 .38092 .5175 .38272 .51697 .38173 .51365 Mtetra
.679 .554 .706 r
.38173 .51365 .38272 .51697 .38453 .51646 .38357 .51226 Mtetra
.557 .447 .685 r
.38357 .51226 .38453 .51646 .38632 .51621 .38536 .51211 Mtetra
.592 .473 .687 r
.38536 .51211 .38632 .51621 .38813 .51555 .38716 .51158 Mtetra
.705 .549 .673 r
.38716 .51158 .38813 .51555 .38999 .51382 .38904 .50946 Mtetra
.957 .686 .481 r
.38904 .50946 .38999 .51382 .39201 .50795 .39858 .31659 Mtetra
.57 .338 .525 r
.39858 .31659 .39201 .50795 .40188 .30269 .40103 .29729 Mtetra
.723 .528 .627 r
.40103 .29729 .40188 .30269 .40379 .2968 .40285 .29383 Mtetra
.655 .547 .719 r
.40285 .29383 .40379 .2968 .4055 .29573 .40456 .29286 Mtetra
.601 .52 .735 r
.40456 .29286 .4055 .29573 .4072 .29535 .40625 .29241 Mtetra
.572 .499 .735 r
.40625 .29241 .4072 .29535 .40889 .29505 .40794 .29219 Mtetra
.605 .523 .736 r
.40794 .29219 .40889 .29505 .41061 .29383 .40964 .29171 Mtetra
.616 .583 .794 r
.40964 .29171 .41061 .29383 .41234 .29265 .41134 .29125 Mtetra
.632 .681 .879 r
.41134 .29125 .41234 .29265 .41406 .29162 .41304 .29077 Mtetra
.646 .794 .954 r
.41304 .29077 .41406 .29162 .41576 .29097 .41474 .29021 Mtetra
.653 .821 .964 r
.41474 .29021 .41576 .29097 .41747 .29041 .41645 .28962 Mtetra
.668 .816 .954 r
.41645 .28962 .41747 .29041 .41917 .28988 .41816 .28897 Mtetra
.687 .794 .931 r
.41816 .28897 .41917 .28988 .42088 .28928 .41987 .28827 Mtetra
.689 .773 .916 r
.41987 .28827 .42088 .28928 .42259 .28867 .42159 .28755 Mtetra
.684 .749 .9 r
.42159 .28755 .42259 .28867 .4243 .28808 .4233 .28684 Mtetra
.668 .722 .89 r
.4233 .28684 .4243 .28808 .42601 .28753 .42502 .2862 Mtetra
.663 .704 .878 r
.42502 .2862 .42601 .28753 .42772 .28699 .42673 .28557 Mtetra
.662 .691 .866 r
.42673 .28557 .42772 .28699 .42944 .28642 .42845 .28494 Mtetra
.679 .687 .85 r
.42845 .28494 .42944 .28642 .43115 .28581 .43017 .28419 Mtetra
.66 .662 .841 r
.43017 .28419 .43115 .28581 .43287 .28516 .43188 .28354 Mtetra
.624 .645 .851 r
.43188 .28354 .43287 .28516 .43459 .28449 .4336 .28308 Mtetra
.453 .598 .906 r
.4336 .28308 .43459 .28449 .43631 .28379 .4353 .28323 Mtetra
.049 .552 .882 r
.4353 .28323 .43631 .28379 .43803 .28308 .43699 .2836 Mtetra
.431 0 0 r
.43699 .2836 .43803 .28308 .43976 .28237 .43868 .28399 Mtetra
.296 0 .041 r
.43868 .28399 .43976 .28237 .44148 .28169 .4404 .28351 Mtetra
.242 0 .048 r
.4404 .28351 .44148 .28169 .44321 .28102 .44213 .28276 Mtetra
.182 0 .002 r
.44213 .28276 .44321 .28102 .44493 .28034 .44387 .28187 Mtetra
0 0 0 r
.44387 .28187 .44493 .28034 .44667 .27931 .44561 .28063 Mtetra
.134 0 0 r
.44561 .28063 .44667 .27931 .44839 .27861 .44734 .27989 Mtetra
.465 .002 .069 r
.44734 .27989 .44839 .27861 .45011 .27856 .44905 .28013 Mtetra
.902 .566 .401 r
.44905 .28013 .45011 .27856 .45175 .28177 .45053 .28987 Mtetra
.955 .671 .46 r
.45053 .28987 .45175 .28177 .4488 .48467 .44757 .49059 Mtetra
.672 .357 .431 r
.44757 .49059 .4488 .48467 .45044 .49293 .44933 .49398 Mtetra
.306 0 0 r
.44933 .49398 .45044 .49293 .45226 .49378 .45117 .49383 Mtetra
.519 .916 .896 r
.45117 .49383 .45226 .49378 .4541 .49372 .45303 .49303 Mtetra
.761 .871 .928 r
.45303 .49303 .4541 .49372 .45596 .49317 .4549 .4919 Mtetra
.602 .711 .921 r
.4549 .4919 .45596 .49317 .45781 .49262 .45675 .4915 Mtetra
.613 .745 .94 r
.45675 .4915 .45781 .49262 .45967 .49194 .45861 .49105 Mtetra
.653 .806 .957 r
.45861 .49105 .45967 .49194 .46153 .4912 .46047 .49041 Mtetra
.72 .843 .94 r
.46047 .49041 .46153 .4912 .46338 .49112 .46233 .48948 Mtetra
.759 .71 .806 r
.46233 .48948 .46338 .49112 .46524 .49072 .46421 .48801 Mtetra
.775 .634 .705 r
.46421 .48801 .46524 .49072 .46711 .48963 .46611 .48548 Mtetra
.9 .658 .563 r
.46611 .48548 .46711 .48963 .46904 .48491 .46819 .47232 Mtetra
.955 .675 .467 r
.46819 .47232 .46904 .48491 .47424 .28031 .47337 .2721 Mtetra
.689 .479 .597 r
.47337 .2721 .47424 .28031 .47612 .2712 .47517 .26808 Mtetra
.663 .546 .712 r
.47517 .26808 .47612 .2712 .47789 .26923 .47692 .26697 Mtetra
.612 .571 .784 r
.47692 .26697 .47789 .26923 .47964 .26819 .47867 .26651 Mtetra
.56 .609 .859 r
.47867 .26651 .47964 .26819 .48139 .26756 .48041 .26634 Mtetra
.689 .738 .889 r
.48041 .26634 .48139 .26756 .48314 .26686 .48216 .26559 Mtetra
.689 .729 .881 r
.48216 .26559 .48314 .26686 .48489 .26623 .48391 .26483 Mtetra
.657 .695 .873 r
.48391 .26483 .48489 .26623 .48664 .26565 .48566 .26421 Mtetra
.605 .668 .885 r
.48566 .26421 .48664 .26565 .4884 .26451 .48741 .26384 Mtetra
.327 .704 .982 r
.48741 .26384 .4884 .26451 .49015 .26365 .48916 .2639 Mtetra
.551 0 0 r
.48916 .2639 .49015 .26365 .4919 .26346 .4909 .2648 Mtetra
.881 .519 .357 r
.4909 .2648 .4919 .26346 .49361 .267 .49258 .27149 Mtetra
.963 .676 .441 r
.49258 .27149 .49361 .267 .49339 .47375 .49232 .47518 Mtetra
.812 .417 .303 r
.49232 .47518 .49339 .47375 .4952 .48025 .49416 .47909 Mtetra
.252 .558 .933 r
.49416 .47909 .4952 .48025 .49708 .48073 .49603 .47957 Mtetra
.612 .739 .936 r
.49603 .47957 .49708 .48073 .49896 .48007 .49792 .47911 Mtetra
.727 .816 .92 r
.49792 .47911 .49896 .48007 .50085 .47895 .49981 .47814 Mtetra
.72 .845 .941 r
.49981 .47814 .50085 .47895 .50274 .4788 .5017 .4772 Mtetra
.751 .716 .82 r
.5017 .4772 .50274 .4788 .50462 .47848 .50359 .47585 Mtetra
.764 .635 .717 r
.50359 .47585 .50462 .47848 .50651 .47743 .50549 .4736 Mtetra
.866 .645 .601 r
.50549 .4736 .50651 .47743 .50843 .4725 .50742 .46585 Mtetra
.965 .683 .448 r
.50742 .46585 .50843 .4725 .51123 .26438 .51028 .26058 Mtetra
.814 .612 .629 r
.51028 .26058 .51123 .26438 .51303 .2568 .51207 .2557 Mtetra
.803 .789 .84 r
.51207 .2557 .51303 .2568 .51481 .2551 .51384 .25421 Mtetra
.655 .797 .951 r
.51384 .25421 .51481 .2551 .51658 .25455 .51561 .2536 Mtetra
.556 .747 .966 r
.51561 .2536 .51658 .25455 .51835 .25444 .51738 .25331 Mtetra
.688 .758 .905 r
.51738 .25331 .51835 .25444 .52012 .25393 .51915 .25257 Mtetra
.695 .719 .868 r
.51915 .25257 .52012 .25393 .52189 .25326 .52093 .25174 Mtetra
.664 .683 .858 r
.52093 .25174 .52189 .25326 .52367 .25256 .5227 .25107 Mtetra
.619 .668 .875 r
.5227 .25107 .52367 .25256 .52544 .25142 .52448 .25063 Mtetra
.416 .722 .988 r
.52448 .25063 .52544 .25142 .52722 .25047 .52626 .2506 Mtetra
.471 0 0 r
.52626 .2506 .52722 .25047 .529 .25014 .52804 .25135 Mtetra
.862 .479 .317 r
.52804 .25135 .529 .25014 .53078 .25289 .52983 .2566 Mtetra
.967 .675 .426 r
.52983 .2566 .53078 .25289 .53308 .45846 .53206 .46166 Mtetra
.768 .41 .378 r
.53206 .46166 .53308 .45846 .53501 .46695 .53398 .46611 Mtetra
0 .296 .742 r
.53398 .46611 .53501 .46695 .53693 .46825 .5359 .46718 Mtetra
.534 .728 .963 r
.5359 .46718 .53693 .46825 .53884 .4679 .53782 .46695 Mtetra
.773 .829 .895 r
.53782 .46695 .53884 .4679 .54075 .46651 .53973 .46569 Mtetra
.948 .808 .672 r
.53973 .46569 .54075 .46651 .54265 .46268 .54162 .46117 Mtetra
.972 .688 .429 r
.54162 .46117 .54265 .46268 .54444 .44221 .54236 .25303 Mtetra
.547 .319 .521 r
.54236 .25303 .54444 .44221 .54507 .24758 .5441 .2443 Mtetra
.721 .574 .689 r
.5441 .2443 .54507 .24758 .54685 .24487 .54588 .24231 Mtetra
.62 .554 .759 r
.54588 .24231 .54685 .24487 .54863 .24371 .54768 .24174 Mtetra
.548 .569 .828 r
.54768 .24174 .54863 .24371 .55043 .24301 .54947 .24165 Mtetra
.628 .694 .892 r
.54947 .24165 .55043 .24301 .55222 .24234 .55127 .24116 Mtetra
.674 .746 .904 r
.55127 .24116 .55222 .24234 .55401 .24169 .55306 .24047 Mtetra
.652 .73 .907 r
.55306 .24047 .55401 .24169 .55581 .24108 .55486 .23988 Mtetra
.626 .724 .917 r
.55486 .23988 .55581 .24108 .5576 .24001 .55666 .23939 Mtetra
.435 .776 .997 r
.55666 .23939 .5576 .24001 .55939 .23901 .55846 .23923 Mtetra
.397 0 0 r
.55846 .23923 .55939 .23901 .5612 .23859 .56028 .23975 Mtetra
.838 .436 .282 r
.56028 .23975 .5612 .23859 .56303 .24082 .56214 .244 Mtetra
.969 .675 .413 r
.56214 .244 .56303 .24082 .5675 .44438 .56657 .44972 Mtetra
.731 .4 .42 r
.56657 .44972 .5675 .44438 .56958 .45549 .56858 .45475 Mtetra
0 .22 .659 r
.56858 .45475 .56958 .45549 .57155 .45714 .57054 .45596 Mtetra
.545 .713 .949 r
.57054 .45596 .57155 .45714 .57349 .45688 .57248 .45572 Mtetra
.765 .794 .876 r
.57248 .45572 .57349 .45688 .57542 .45558 .57441 .45445 Mtetra
.931 .79 .683 r
.57441 .45445 .57542 .45558 .57731 .45207 .57629 .45024 Mtetra
.974 .686 .416 r
.57629 .45024 .57731 .45207 .57904 .43895 .57485 .24256 Mtetra
.548 .319 .52 r
.57485 .24256 .57904 .43895 .5775 .23645 .57652 .23299 Mtetra
.73 .574 .679 r
.57652 .23299 .5775 .23645 .57927 .23336 .5783 .23072 Mtetra
.623 .552 .754 r
.5783 .23072 .57927 .23336 .58107 .23214 .58012 .23011 Mtetra
.552 .566 .822 r
.58012 .23011 .58107 .23214 .58288 .23143 .58194 .23 Mtetra
.589 .668 .894 r
.58194 .23 .58288 .23143 .5847 .23079 .58376 .22968 Mtetra
.657 .757 .924 r
.58376 .22968 .5847 .23079 .58651 .23014 .58558 .22906 Mtetra
.669 .767 .924 r
.58558 .22906 .58651 .23014 .58833 .22955 .5874 .22839 Mtetra
.745 .775 .877 r
.5874 .22839 .58833 .22955 .59014 .22858 .58921 .2273 Mtetra
.743 .755 .862 r
.58921 .2273 .59014 .22858 .59195 .22756 .59102 .2262 Mtetra
.64 .702 .891 r
.59102 .2262 .59195 .22756 .59378 .2271 .59284 .22565 Mtetra
0 .159 .696 r
.59284 .22565 .59378 .2271 .59566 .22898 .59471 .22739 Mtetra
.975 .678 .389 r
.59471 .22739 .59566 .22898 .60228 .42993 .60116 .42354 Mtetra
.876 .601 .078 r
.60116 .42354 .60228 .42993 .60458 .44397 .60359 .44274 Mtetra
0 .03 .562 r
.60359 .44274 .60458 .44397 .6066 .44593 .60561 .44484 Mtetra
.498 .711 .966 r
.60561 .44484 .6066 .44593 .60858 .44575 .60759 .44471 Mtetra
.768 .82 .894 r
.60759 .44471 .60858 .44575 .61052 .44453 .60953 .44345 Mtetra
.929 .805 .701 r
.60953 .44345 .61052 .44453 .61242 .44131 .61141 .43964 Mtetra
.976 .685 .403 r
.61141 .43964 .61242 .44131 .61411 .43077 .60781 .234 Mtetra
.554 .323 .521 r
.60781 .234 .61411 .43077 .61032 .22519 .60933 .22161 Mtetra
.746 .579 .669 r
.60933 .22161 .61032 .22519 .61207 .22167 .61111 .21897 Mtetra
.63 .553 .749 r
.61111 .21897 .61207 .22167 .61389 .22038 .61294 .21828 Mtetra
.562 .566 .815 r
.61294 .21828 .61389 .22038 .61572 .21962 .61479 .21812 Mtetra
.578 .653 .888 r
.61479 .21812 .61572 .21962 .61756 .21897 .61664 .21784 Mtetra
.657 .755 .922 r
.61664 .21784 .61756 .21897 .61939 .2183 .61848 .21721 Mtetra
.67 .769 .924 r
.61848 .21721 .61939 .2183 .62123 .21769 .62031 .21653 Mtetra
.736 .777 .885 r
.62031 .21653 .62123 .21769 .62306 .21676 .62214 .21549 Mtetra
.75 .761 .862 r
.62214 .21549 .62306 .21676 .62489 .2157 .62397 .21434 Mtetra
.659 .713 .888 r
.62397 .21434 .62489 .2157 .62674 .21513 .62581 .21369 Mtetra
.035 .337 .818 r
.62581 .21369 .62674 .21513 .62865 .21646 .62772 .21491 Mtetra
.927 .563 .142 r
.62772 .21491 .62865 .21646 .63088 .2271 .62991 .22422 Mtetra
.976 .677 .37 r
.62991 .22422 .63088 .2271 .63999 .43161 .63901 .43037 Mtetra
0 0 .49 r
.63901 .43037 .63999 .43161 .64208 .43389 .64111 .43282 Mtetra
.565 .749 .964 r
.64111 .43282 .64208 .43389 .64407 .43344 .6431 .43248 Mtetra
.752 .835 .916 r
.6431 .43248 .64407 .43344 .64604 .43231 .64507 .43133 Mtetra
.827 .842 .859 r
.64507 .43133 .64604 .43231 .64801 .43118 .64702 .42963 Mtetra
.821 .754 .789 r
.64702 .42963 .64801 .43118 .64999 .43042 .64896 .42756 Mtetra
.753 .622 .714 r
.64896 .42756 .64999 .43042 .65198 .42968 .65089 .42535 Mtetra
.609 .482 .683 r
.65089 .42535 .65198 .42968 .65397 .42901 .65287 .42455 Mtetra
.441 .371 .682 r
.65287 .42455 .65397 .42901 .65597 .42842 .65493 .42555 Mtetra
.392 .415 .765 r
.65493 .42555 .65597 .42842 .65796 .42786 .65698 .42643 Mtetra
.434 .611 .923 r
.65698 .42643 .65796 .42786 .65997 .42738 .65901 .42662 Mtetra
.59 .83 .99 r
.65901 .42662 .65997 .42738 .66197 .42695 .66102 .42609 Mtetra
.644 .828 .971 r
.66102 .42609 .66197 .42695 .66398 .42644 .66302 .42541 Mtetra
.555 .755 .97 r
.66302 .42541 .66398 .42644 .66598 .42591 .66503 .42508 Mtetra
.373 .709 .986 r
.66503 .42508 .66598 .42591 .66798 .42527 .66706 .42512 Mtetra
.409 .854 .915 r
.66706 .42512 .66798 .42527 .66996 .42403 .66907 .42458 Mtetra
.783 .965 .658 r
.66907 .42458 .66996 .42403 .67184 .42068 .671 .42215 Mtetra
.986 .809 .413 r
.671 .42215 .67184 .42068 .6645 .21653 .67256 .41186 Mtetra
0 0 .354 r
.67256 .41186 .6645 .21653 .66582 .20396 .66495 .20338 Mtetra
.965 .858 .685 r
.66495 .20338 .66582 .20396 .66757 .2009 .66667 .19962 Mtetra
.721 .754 .878 r
.66667 .19962 .66757 .2009 .66943 .19998 .66853 .19864 Mtetra
.599 .695 .91 r
.66853 .19864 .66943 .19998 .67132 .19955 .67041 .19825 Mtetra
.626 .714 .909 r
.67041 .19825 .67132 .19955 .67319 .19899 .67229 .19775 Mtetra
.739 .767 .876 r
.67229 .19775 .67319 .19899 .67505 .1979 .67415 .19667 Mtetra
.649 .736 .913 r
.67415 .19667 .67505 .1979 .67692 .19729 .67603 .19606 Mtetra
.098 .424 .869 r
.67603 .19606 .67692 .19729 .67888 .19822 .67799 .197 Mtetra
.918 .542 .122 r
.67799 .197 .67888 .19822 .68125 .20708 .68036 .20594 Mtetra
.975 .67 .349 r
.68036 .20594 .68125 .20708 .694 .41428 .69305 .41312 Mtetra
.617 .154 0 r
.69305 .41312 .694 .41428 .69621 .41735 .69526 .41617 Mtetra
.414 .651 .956 r
.69526 .41617 .69621 .41735 .69828 .41749 .69733 .41631 Mtetra
.71 .786 .911 r
.69733 .41631 .69828 .41749 .70029 .41654 .69934 .41535 Mtetra
.888 .816 .771 r
.69934 .41535 .70029 .41654 .70221 .41388 .70126 .41269 Mtetra
.978 .756 .534 r
.70126 .41269 .70221 .41388 .70375 .40457 .70281 .40334 Mtetra
.977 .678 .362 r
.70281 .40334 .70375 .40457 .69406 .19497 .69317 .19371 Mtetra
.936 .785 .669 r
.69317 .19371 .69406 .19497 .69576 .19084 .69487 .18959 Mtetra
.729 .764 .881 r
.69487 .18959 .69576 .19084 .69762 .18981 .69674 .18856 Mtetra
.6 .714 .925 r
.69674 .18856 .69762 .18981 .69953 .1894 .69864 .18816 Mtetra
.589 .712 .928 r
.69864 .18816 .69953 .1894 .70144 .18899 .70055 .18779 Mtetra
.729 .774 .889 r
.70055 .18779 .70144 .18899 .7033 .1879 .70243 .18678 Mtetra
.657 .765 .929 r
.70243 .18678 .7033 .1879 .7052 .18727 .70432 .18613 Mtetra
.323 .592 .942 r
.70432 .18613 .7052 .18727 .70718 .18798 .70628 .1865 Mtetra
.668 .256 0 r
.70628 .1865 .70718 .18798 .70961 .19609 .70846 .19049 Mtetra
.975 .67 .321 r
.70846 .19049 .70961 .19609 .72444 .40443 .72318 .39794 Mtetra
.06 .071 .555 r
.72318 .39794 .72444 .40443 .72672 .40761 .72561 .40363 Mtetra
.454 .398 .705 r
.72561 .40363 .72672 .40761 .72879 .40733 .72775 .40444 Mtetra
.541 .507 .767 r
.72775 .40444 .72879 .40733 .73082 .40634 .72984 .40441 Mtetra
.581 .616 .852 r
.72984 .40441 .73082 .40634 .73284 .40527 .73191 .40411 Mtetra
.488 .696 .961 r
.73191 .40411 .73284 .40527 .73492 .40509 .734 .40402 Mtetra
.654 .794 .949 r
.734 .40402 .73492 .40509 .73697 .40444 .73605 .40332 Mtetra
.853 .834 .827 r
.73605 .40332 .73697 .40444 .73894 .40249 .73801 .40128 Mtetra
.979 .766 .547 r
.73801 .40128 .73894 .40249 .74049 .39433 .73956 .39308 Mtetra
.977 .675 .344 r
.73956 .39308 .74049 .39433 .72831 .18337 .72743 .18207 Mtetra
.948 .783 .643 r
.72743 .18207 .72831 .18337 .72995 .17869 .72908 .17741 Mtetra
.74 .767 .874 r
.72908 .17741 .72995 .17869 .73183 .17757 .73096 .1763 Mtetra
.611 .717 .921 r
.73096 .1763 .73183 .17757 .73376 .17711 .73289 .17585 Mtetra
.565 .698 .93 r
.73289 .17585 .73376 .17711 .7357 .17681 .73483 .17557 Mtetra
.731 .772 .886 r
.73483 .17557 .7357 .17681 .73758 .17568 .73672 .17453 Mtetra
.668 .767 .924 r
.73672 .17453 .73758 .17568 .7395 .17497 .73864 .17383 Mtetra
.424 .648 .952 r
.73864 .17383 .7395 .17497 .74149 .17534 .74062 .17395 Mtetra
0 0 .385 r
.74062 .17395 .74149 .17534 .74393 .1818 .74284 .17744 Mtetra
.973 .664 .305 r
.74284 .17744 .74393 .1818 .76137 .39193 .76 .38457 Mtetra
.023 .036 .532 r
.76 .38457 .76137 .39193 .76377 .39575 .76263 .39161 Mtetra
.445 .388 .699 r
.76263 .39161 .76377 .39575 .76588 .39555 .76483 .39254 Mtetra
.535 .496 .76 r
.76483 .39254 .76588 .39555 .76793 .39461 .76695 .39257 Mtetra
.589 .609 .839 r
.76695 .39257 .76793 .39461 .76996 .39342 .76905 .39221 Mtetra
.478 .684 .957 r
.76905 .39221 .76996 .39342 .77208 .39325 .77118 .39217 Mtetra
.637 .786 .954 r
.77118 .39217 .77208 .39325 .77416 .39265 .77326 .39153 Mtetra
.823 .835 .858 r
.77326 .39153 .77416 .39265 .77617 .39103 .77526 .3898 Mtetra
.978 .777 .563 r
.77526 .3898 .77617 .39103 .77773 .38385 .77682 .38259 Mtetra
.976 .67 .326 r
.77682 .38259 .77773 .38385 .763 .17177 .76214 .17045 Mtetra
.961 .779 .612 r
.76214 .17045 .763 .17177 .76456 .16639 .7637 .16509 Mtetra
.755 .772 .866 r
.7637 .16509 .76456 .16639 .76645 .16517 .7656 .16387 Mtetra
.626 .721 .915 r
.7656 .16387 .76645 .16517 .7684 .16464 .76755 .16335 Mtetra
.549 .685 .929 r
.76755 .16335 .7684 .16464 .77038 .16442 .76952 .16313 Mtetra
.747 .772 .873 r
.76952 .16313 .77038 .16442 .77228 .16326 .77142 .16197 Mtetra
.678 .747 .903 r
.77142 .16197 .77228 .16326 .77421 .16249 .77336 .1612 Mtetra
.469 .646 .935 r
.77336 .1612 .77421 .16249 .77621 .16253 .77536 .16125 Mtetra
.763 .347 0 r
.77536 .16125 .77621 .16253 .77865 .16767 .7778 .16643 Mtetra
.971 .656 .295 r
.7778 .16643 .77865 .16767 .79873 .37889 .79783 .3777 Mtetra
.734 .297 0 r
.79783 .3777 .79873 .37889 .80129 .38363 .80039 .38242 Mtetra
.299 .58 .939 r
.80039 .38242 .80129 .38363 .80348 .38411 .80259 .38289 Mtetra
.647 .766 .936 r
.80259 .38289 .80348 .38411 .80559 .38343 .80469 .38222 Mtetra
.827 .823 .845 r
.80469 .38222 .80559 .38343 .80759 .38161 .80669 .38039 Mtetra
.908 .738 .66 r
.13731 .59179 .13851 .59273 .14073 .58707 .13954 .58614 Mtetra
.936 .686 .535 r
.13954 .58614 .14073 .58707 .165 .38492 .16389 .38395 Mtetra
.91 .729 .644 r
.16389 .38395 .165 .38492 .16718 .3788 .16607 .37779 Mtetra
.771 .762 .845 r
.16607 .37779 .16718 .3788 .1688 .37761 .1677 .3766 Mtetra
.629 .736 .924 r
.1677 .3766 .1688 .37761 .17034 .37718 .16924 .37618 Mtetra
.489 .687 .955 r
.16924 .37618 .17034 .37718 .17184 .37713 .17074 .37612 Mtetra
.662 .746 .912 r
.17074 .37612 .17184 .37713 .1734 .37657 .1723 .37557 Mtetra
.676 .752 .908 r
.1723 .37557 .1734 .37657 .17497 .37595 .17386 .37496 Mtetra
.688 .755 .903 r
.17386 .37496 .17497 .37595 .17654 .3753 .17543 .3743 Mtetra
.781 .765 .838 r
.17543 .3743 .17654 .3753 .17817 .37409 .17707 .37302 Mtetra
.734 .749 .864 r
.17707 .37302 .17817 .37409 .17976 .37322 .17867 .37209 Mtetra
.581 .697 .921 r
.17867 .37209 .17976 .37322 .18128 .37302 .1802 .37183 Mtetra
.91 .503 .151 r
.1802 .37183 .18128 .37302 .18241 .37652 .18134 .37523 Mtetra
.94 .683 .522 r
.18134 .37523 .18241 .37652 .16248 .57761 .16134 .57635 Mtetra
.948 .613 .355 r
.16134 .57635 .16248 .57761 .16339 .58413 .16221 .58315 Mtetra
0 .266 .727 r
.16221 .58315 .16339 .58413 .1649 .58504 .16372 .58407 Mtetra
.621 .757 .943 r
.16372 .58407 .1649 .58504 .16656 .58462 .16538 .58363 Mtetra
.81 .778 .823 r
.16538 .58363 .16656 .58462 .16833 .58304 .16716 .582 Mtetra
.911 .734 .649 r
.16716 .582 .16833 .58304 .17054 .57728 .16941 .57588 Mtetra
.939 .687 .529 r
.16941 .57588 .17054 .57728 .19322 .37426 .19219 .37257 Mtetra
.882 .698 .649 r
.19219 .37257 .19322 .37426 .19534 .36839 .19428 .36704 Mtetra
.755 .711 .81 r
.19428 .36704 .19534 .36839 .19699 .36708 .19592 .3658 Mtetra
.601 .676 .894 r
.19592 .3658 .19699 .36708 .19854 .36671 .19747 .36548 Mtetra
.463 .629 .925 r
.19747 .36548 .19854 .36671 .20005 .36674 .19898 .36555 Mtetra
.649 .708 .891 r
.19898 .36555 .20005 .36674 .20161 .36629 .20055 .36504 Mtetra
.681 .708 .868 r
.20055 .36504 .20161 .36629 .20319 .36571 .20213 .36437 Mtetra
.68 .694 .856 r
.20213 .36437 .20319 .36571 .20477 .36511 .20372 .36369 Mtetra
.66 .674 .852 r
.20372 .36369 .20477 .36511 .20635 .36455 .2053 .3631 Mtetra
.653 .667 .851 r
.2053 .3631 .20635 .36455 .20792 .364 .20688 .36254 Mtetra
.651 .666 .852 r
.20688 .36254 .20792 .364 .2095 .36344 .20845 .362 Mtetra
.655 .669 .851 r
.20845 .362 .2095 .36344 .21108 .36287 .21004 .36143 Mtetra
.657 .672 .852 r
.21004 .36143 .21108 .36287 .21266 .36228 .21162 .36085 Mtetra
.659 .674 .853 r
.21162 .36085 .21266 .36228 .21425 .36168 .2132 .36027 Mtetra
.66 .677 .855 r
.2132 .36027 .21425 .36168 .21584 .36108 .21479 .35969 Mtetra
.661 .679 .857 r
.21479 .35969 .21584 .36108 .21742 .36048 .21637 .3591 Mtetra
.66 .681 .859 r
.21637 .3591 .21742 .36048 .21901 .35988 .21796 .35851 Mtetra
.662 .684 .861 r
.21796 .35851 .21901 .35988 .2206 .35928 .21955 .35792 Mtetra
.659 .685 .863 r
.21955 .35792 .2206 .35928 .22219 .35869 .22114 .35735 Mtetra
.653 .685 .868 r
.22114 .35735 .22219 .35869 .22378 .35812 .22272 .3568 Mtetra
.628 .681 .881 r
.22272 .3568 .22378 .35812 .22536 .35761 .2243 .35637 Mtetra
.62 .692 .895 r
.2243 .35637 .22536 .35761 .22694 .35712 .22587 .35598 Mtetra
.63 .713 .907 r
.22587 .35598 .22694 .35712 .22853 .3566 .22745 .35554 Mtetra
.682 .744 .898 r
.22745 .35554 .22853 .3566 .23013 .35595 .22905 .35489 Mtetra
.703 .748 .887 r
.22905 .35489 .23013 .35595 .23173 .35524 .23066 .35413 Mtetra
.702 .739 .88 r
.23066 .35413 .23173 .35524 .23334 .35454 .23227 .35336 Mtetra
.712 .731 .866 r
.23227 .35336 .23334 .35454 .23496 .35362 .23389 .35253 Mtetra
.691 .742 .89 r
.23389 .35253 .23496 .35362 .23658 .35286 .2355 .35183 Mtetra
.613 .732 .93 r
.2355 .35183 .23658 .35286 .23814 .35259 .23708 .35144 Mtetra
.185 .501 .908 r
.23708 .35144 .23814 .35259 .23953 .35433 .23858 .35197 Mtetra
0 .119 .658 r
.23858 .35197 .23953 .35433 .24035 .36251 .23997 .35374 Mtetra
.083 .02 .479 r
.23997 .35374 .24035 .36251 .22425 .56122 .24104 .35905 Mtetra
0 0 .164 r
.24104 .35905 .22425 .56122 .22568 .56373 .22506 .55672 Mtetra
.035 .012 .496 r
.22506 .55672 .22568 .56373 .22729 .56429 .22631 .56128 Mtetra
.096 .195 .679 r
.22631 .56128 .22729 .56429 .22895 .56425 .22781 .56307 Mtetra
.271 .561 .932 r
.22781 .56307 .22895 .56425 .23061 .56421 .22943 .56347 Mtetra
.571 .798 .985 r
.22943 .56347 .23061 .56421 .2323 .5639 .23112 .56311 Mtetra
.733 .821 .919 r
.23112 .56311 .2323 .5639 .23403 .56299 .23286 .56218 Mtetra
.832 .813 .832 r
.23286 .56218 .23403 .56299 .23594 .56014 .23468 .56044 Mtetra
.941 .929 .763 r
.23468 .56044 .23594 .56014 .23826 .55243 .23659 .55757 Mtetra
0 0 0 r
.23659 .55757 .23826 .55243 .25692 .35111 .23872 .55206 Mtetra
0 0 .159 r
.23872 .55206 .25692 .35111 .2588 .34726 .25715 .35319 Mtetra
0 0 0 r
.25715 .35319 .2588 .34726 .2605 .34564 .25926 .34667 Mtetra
.913 .973 .685 r
.25926 .34667 .2605 .34564 .26215 .34466 .26106 .3438 Mtetra
.782 .8 .868 r
.26106 .3438 .26215 .34466 .26376 .34405 .26273 .3426 Mtetra
.614 .657 .869 r
.26273 .3426 .26376 .34405 .26536 .34367 .26433 .34222 Mtetra
.525 .619 .888 r
.26433 .34222 .26536 .34367 .26695 .34343 .2659 .34217 Mtetra
.57 .674 .909 r
.2659 .34217 .26695 .34343 .26854 .34307 .26748 .34195 Mtetra
.627 .72 .914 r
.26748 .34195 .26854 .34307 .27015 .34259 .26909 .34152 Mtetra
.64 .734 .917 r
.26909 .34152 .27015 .34259 .27177 .34206 .2707 .34103 Mtetra
.652 .747 .919 r
.2707 .34103 .27177 .34206 .27339 .34148 .27232 .3405 Mtetra
.664 .759 .921 r
.27232 .3405 .27339 .34148 .27501 .34086 .27394 .33992 Mtetra
.674 .77 .923 r
.27394 .33992 .27501 .34086 .27663 .34021 .27556 .3393 Mtetra
.681 .779 .925 r
.27556 .3393 .27663 .34021 .27826 .33953 .27719 .33865 Mtetra
.688 .787 .926 r
.27719 .33865 .27826 .33953 .2799 .33883 .27882 .33797 Mtetra
.698 .793 .924 r
.27882 .33797 .2799 .33883 .28153 .33812 .28045 .33725 Mtetra
.748 .798 .893 r
.28045 .33725 .28153 .33812 .28319 .33712 .28211 .33627 Mtetra
.753 .803 .893 r
.28211 .33627 .28319 .33712 .28484 .33614 .28377 .33526 Mtetra
.688 .789 .927 r
.28377 .33526 .28484 .33614 .28646 .33564 .2854 .33458 Mtetra
.225 .546 .929 r
.2854 .33458 .28646 .33564 .28794 .33701 .28695 .33501 Mtetra
0 0 .552 r
.28695 .33501 .28794 .33701 .28895 .34473 .28838 .33709 Mtetra
0 0 .465 r
.28838 .33709 .28895 .34473 .27576 .54448 .28957 .3425 Mtetra
0 0 .224 r
.28957 .3425 .27576 .54448 .27729 .54679 .27724 .53109 Mtetra
.511 .32 .557 r
.27724 .53109 .27729 .54679 .27901 .54646 .27887 .53187 Mtetra
.664 .444 .575 r
.27887 .53187 .27901 .54646 .28078 .54548 .28098 .52614 Mtetra
.926 .663 .519 r
.28098 .52614 .28078 .54548 .28254 .54459 .29524 .35224 Mtetra
.533 .307 .519 r
.29524 .35224 .28254 .54459 .28428 .54402 .29699 .3503 Mtetra
.531 .306 .519 r
.29699 .3503 .28428 .54402 .28602 .54344 .29869 .34886 Mtetra
.53 .305 .518 r
.29869 .34886 .28602 .54344 .28776 .54288 .30037 .34793 Mtetra
.529 .305 .518 r
.30037 .34793 .28776 .54288 .28951 .54232 .30201 .34742 Mtetra
.529 .304 .518 r
.30201 .34742 .28951 .54232 .29125 .54177 .30363 .34714 Mtetra
.528 .304 .518 r
.30363 .34714 .29125 .54177 .293 .54123 .30525 .34704 Mtetra
.30525 .34704 .293 .54123 .29474 .54068 .30686 .34711 Mtetra
.527 .303 .518 r
.30686 .34711 .29474 .54068 .29649 .54014 .30845 .34736 Mtetra
.30845 .34736 .29649 .54014 .29824 .53959 .31004 .34776 Mtetra
.31004 .34776 .29824 .53959 .29999 .53904 .31162 .34828 Mtetra
.526 .302 .518 r
.31162 .34828 .29999 .53904 .30174 .53849 .31319 .349 Mtetra
.31319 .349 .30174 .53849 .30349 .53794 .31475 .34991 Mtetra
.525 .302 .518 r
.31475 .34991 .30349 .53794 .30524 .53739 .3163 .35094 Mtetra
.525 .301 .518 r
.3163 .35094 .30524 .53739 .30699 .53683 .31785 .3521 Mtetra
.526 .302 .518 r
.31785 .3521 .30699 .53683 .30875 .53628 .31942 .35295 Mtetra
.528 .304 .518 r
.31942 .35295 .30875 .53628 .31051 .53572 .32106 .35277 Mtetra
.531 .306 .519 r
.32106 .35277 .31051 .53572 .31227 .53516 .32277 .3516 Mtetra
.533 .308 .519 r
.32277 .3516 .31227 .53516 .31402 .53459 .32451 .34977 Mtetra
.32451 .34977 .31402 .53459 .31579 .53403 .32626 .34792 Mtetra
.531 .306 .519 r
.32626 .34792 .31579 .53403 .31755 .53347 .32797 .34658 Mtetra
.527 .303 .518 r
.32797 .34658 .31755 .53347 .31931 .53291 .32959 .34691 Mtetra
.515 .293 .516 r
.32959 .34691 .31931 .53291 .32107 .53236 .33091 .3521 Mtetra
0 0 .322 r
.33091 .3521 .32107 .53236 .32284 .5318 .32392 .49452 Mtetra
.234 .084 .462 r
.32392 .49452 .32284 .5318 .32459 .5315 .32456 .51227 Mtetra
.418 .241 .532 r
.32456 .51227 .32459 .5315 .32633 .53138 .32603 .51658 Mtetra
.592 .385 .57 r
.32603 .51658 .32633 .53138 .32811 .5306 .32789 .51437 Mtetra
.937 .669 .506 r
.32789 .51437 .32811 .5306 .33003 .52744 .34073 .32453 Mtetra
.543 .316 .52 r
.34073 .32453 .33003 .52744 .34339 .32589 .34276 .31765 Mtetra
.671 .467 .601 r
.34276 .31765 .34339 .32589 .34557 .31636 .34459 .31427 Mtetra
.764 .651 .737 r
.34459 .31427 .34557 .31636 .34736 .31354 .34632 .31241 Mtetra
.699 .746 .888 r
.34632 .31241 .34736 .31354 .34904 .31267 .348 .31164 Mtetra
.635 .748 .93 r
.348 .31164 .34904 .31267 .35069 .31226 .34966 .31116 Mtetra
.628 .731 .921 r
.34966 .31116 .35069 .31226 .35235 .31191 .35132 .3107 Mtetra
.666 .723 .892 r
.35132 .3107 .35235 .31191 .35401 .31131 .35299 .31009 Mtetra
.666 .72 .889 r
.35299 .31009 .35401 .31131 .35568 .31072 .35466 .30947 Mtetra
.667 .715 .885 r
.35466 .30947 .35568 .31072 .35735 .31013 .35633 .30885 Mtetra
.668 .71 .88 r
.35633 .30885 .35735 .31013 .35902 .30953 .35801 .30821 Mtetra
.666 .705 .876 r
.35801 .30821 .35902 .30953 .3607 .30893 .35968 .30758 Mtetra
.68 .705 .866 r
.35968 .30758 .3607 .30893 .36237 .30829 .36136 .30688 Mtetra
.696 .699 .849 r
.36136 .30688 .36237 .30829 .36405 .3076 .36305 .30606 Mtetra
.648 .663 .851 r
.36305 .30606 .36405 .3076 .36573 .307 .36472 .30549 Mtetra
.459 .581 .889 r
.36472 .30549 .36573 .307 .36739 .30669 .36636 .30566 Mtetra
.624 .126 0 r
.36636 .30566 .36739 .30669 .36903 .30688 .36791 .30754 Mtetra
.874 .501 .336 r
.36791 .30754 .36903 .30688 .37066 .30727 .36932 .31237 Mtetra
.951 .676 .48 r
.36932 .31237 .37066 .30727 .37231 .30731 .36143 .50692 Mtetra
.527 .298 .511 r
.36143 .50692 .37231 .30731 .37401 .30634 .36319 .50678 Mtetra
.523 .295 .51 r
.36319 .50678 .37401 .30634 .37569 .30575 .36504 .50505 Mtetra
.534 .304 .512 r
.36504 .50505 .37569 .30575 .37729 .30691 .36662 .50885 Mtetra
.538 .307 .513 r
.36662 .50885 .37729 .30691 .36966 .50612 .36812 .51442 Mtetra
.615 .324 .451 r
.36812 .51442 .36966 .50612 .37094 .51648 .36978 .51689 Mtetra
.609 .08 0 r
.36978 .51689 .37094 .51648 .37261 .51878 .3715 .51794 Mtetra
.464 .742 .988 r
.3715 .51794 .37261 .51878 .37439 .51866 .37328 .51782 Mtetra
.671 .815 .952 r
.37328 .51782 .37439 .51866 .3762 .51791 .37509 .51713 Mtetra
.814 .843 .872 r
.37509 .51713 .3762 .51791 .37803 .51673 .37694 .51563 Mtetra
.89 .777 .73 r
.37694 .51563 .37803 .51673 .37987 .5153 .37886 .51243 Mtetra
.861 .663 .634 r
.37886 .51243 .37987 .5153 .38173 .51365 .38089 .50653 Mtetra
.953 .682 .485 r
.38089 .50653 .38173 .51365 .38357 .51226 .39102 .3112 Mtetra
.531 .306 .518 r
.39102 .3112 .38357 .51226 .38536 .51211 .39275 .30991 Mtetra
.524 .3 .517 r
.39275 .30991 .38536 .51211 .38716 .51158 .39434 .31187 Mtetra
.541 .314 .52 r
.39434 .31187 .38716 .51158 .38904 .50946 .39627 .30599 Mtetra
.544 .317 .52 r
.39627 .30599 .38904 .50946 .39858 .31659 .39826 .29834 Mtetra
.606 .388 .56 r
.39826 .29834 .39858 .31659 .40103 .29729 .40008 .29475 Mtetra
.759 .624 .71 r
.40008 .29475 .40103 .29729 .40285 .29383 .40184 .29262 Mtetra
.705 .737 .876 r
.40184 .29262 .40285 .29383 .40456 .29286 .40354 .29179 Mtetra
.634 .744 .927 r
.40354 .29179 .40456 .29286 .40625 .29241 .40524 .2913 Mtetra
.589 .718 .933 r
.40524 .2913 .40625 .29241 .40794 .29219 .40693 .29097 Mtetra
.619 .708 .909 r
.40693 .29097 .40794 .29219 .40964 .29171 .40863 .29055 Mtetra
.614 .717 .919 r
.40863 .29055 .40964 .29171 .41134 .29125 .41033 .29014 Mtetra
.622 .73 .924 r
.41033 .29014 .41134 .29125 .41304 .29077 .41203 .28969 Mtetra
.651 .748 .921 r
.41203 .28969 .41304 .29077 .41474 .29021 .41373 .28914 Mtetra
.667 .752 .914 r
.41373 .28914 .41474 .29021 .41645 .28962 .41544 .28851 Mtetra
.683 .752 .904 r
.41544 .28851 .41645 .28962 .41816 .28897 .41715 .28781 Mtetra
.702 .747 .887 r
.41715 .28781 .41816 .28897 .41987 .28827 .41887 .28701 Mtetra
.701 .73 .873 r
.41887 .28701 .41987 .28827 .42159 .28755 .42059 .2862 Mtetra
.691 .712 .864 r
.42059 .2862 .42159 .28755 .4233 .28684 .42231 .28541 Mtetra
.67 .692 .862 r
.42231 .28541 .4233 .28684 .42502 .2862 .42402 .28474 Mtetra
.662 .684 .86 r
.42402 .28474 .42502 .2862 .42673 .28557 .42574 .2841 Mtetra
.664 .683 .858 r
.42574 .2841 .42673 .28557 .42845 .28494 .42745 .28345 Mtetra
.701 .694 .841 r
.42745 .28345 .42845 .28494 .43017 .28419 .42918 .28257 Mtetra
.66 .66 .839 r
.42918 .28257 .43017 .28419 .43188 .28354 .4309 .28191 Mtetra
.562 .616 .864 r
.4309 .28191 .43188 .28354 .4336 .28308 .4326 .28174 Mtetra
0 .092 .633 r
.4326 .28174 .4336 .28308 .4353 .28323 .43426 .28337 Mtetra
.877 .467 .239 r
.43426 .28337 .4353 .28323 .43699 .2836 .43585 .28743 Mtetra
.959 .677 .459 r
.43585 .28743 .43699 .2836 .43868 .28399 .432 .48509 Mtetra
.531 .301 .511 r
.432 .48509 .43868 .28399 .4404 .28351 .43377 .48712 Mtetra
.524 .296 .51 r
.43377 .48712 .4404 .28351 .44213 .28276 .43563 .48578 Mtetra
.52 .292 .509 r
.43563 .48578 .44213 .28276 .44387 .28187 .43755 .48212 Mtetra
.514 .288 .508 r
.43755 .48212 .44387 .28187 .44561 .28063 .43954 .47563 Mtetra
.517 .29 .509 r
.43954 .47563 .44561 .28063 .44734 .27989 .44148 .47067 Mtetra
.546 .313 .513 r
.44148 .47067 .44734 .27989 .44905 .28013 .44306 .48034 Mtetra
.543 .31 .513 r
.44306 .48034 .44905 .28013 .45053 .28987 .44469 .48868 Mtetra
.533 .303 .511 r
.44469 .48868 .45053 .28987 .44757 .49059 .44645 .4917 Mtetra
.662 .204 .156 r
.44645 .4917 .44757 .49059 .44933 .49398 .44826 .49312 Mtetra
.59 .793 .977 r
.44826 .49312 .44933 .49398 .45117 .49383 .45011 .49268 Mtetra
.699 .767 .904 r
.45011 .49268 .45117 .49383 .45303 .49303 .45197 .49184 Mtetra
.727 .767 .885 r
.45197 .49184 .45303 .49303 .4549 .4919 .45384 .49084 Mtetra
.509 .713 .964 r
.45384 .49084 .4549 .4919 .45675 .4915 .45568 .49069 Mtetra
.547 .786 .987 r
.45568 .49069 .45675 .4915 .45861 .49105 .45754 .49036 Mtetra
.682 .858 .966 r
.45754 .49036 .45861 .49105 .46047 .49041 .4594 .48957 Mtetra
.89 .831 .782 r
.4594 .48957 .46047 .49041 .46233 .48948 .4613 .48704 Mtetra
.862 .682 .657 r
.4613 .48704 .46233 .48948 .46421 .48801 .46324 .48236 Mtetra
.962 .684 .46 r
.46324 .48236 .46421 .48801 .46611 .48548 .46871 .28243 Mtetra
.549 .321 .521 r
.46871 .28243 .46611 .48548 .46819 .47232 .47063 .27219 Mtetra
.535 .31 .519 r
.47063 .27219 .46819 .47232 .47337 .2721 .47242 .26874 Mtetra
.722 .571 .683 r
.47242 .26874 .47337 .2721 .47517 .26808 .47419 .26667 Mtetra
.693 .706 .858 r
.47419 .26667 .47517 .26808 .47692 .26697 .47594 .26585 Mtetra
.611 .731 .931 r
.47594 .26585 .47692 .26697 .47867 .26651 .47768 .26544 Mtetra
.561 .72 .948 r
.47768 .26544 .47867 .26651 .48041 .26634 .47943 .26518 Mtetra
.729 .759 .877 r
.47943 .26518 .48041 .26634 .48216 .26559 .48118 .2642 Mtetra
.705 .715 .857 r
.48118 .2642 .48216 .26559 .48391 .26483 .48294 .26332 Mtetra
.634 .67 .867 r
.48294 .26332 .48391 .26483 .48566 .26421 .48469 .26281 Mtetra
.109 .399 .852 r
.48469 .26281 .48566 .26421 .48741 .26384 .48642 .26374 Mtetra
.816 .338 .059 r
.48642 .26374 .48741 .26384 .48916 .2639 .48814 .2664 Mtetra
.965 .678 .439 r
.48814 .2664 .48916 .2639 .4909 .2648 .48774 .45611 Mtetra
.561 .325 .515 r
.48774 .45611 .4909 .2648 .49258 .27149 .4894 .47416 Mtetra
.532 .302 .511 r
.4894 .47416 .49258 .27149 .49232 .47518 .49125 .47704 Mtetra
.62 .203 .229 r
.49125 .47704 .49232 .47518 .49416 .47909 .49311 .47826 Mtetra
.234 .623 .957 r
.49311 .47826 .49416 .47909 .49603 .47957 .49499 .47856 Mtetra
.563 .75 .965 r
.49499 .47856 .49603 .47957 .49792 .47911 .49687 .47823 Mtetra
.72 .829 .933 r
.49687 .47823 .49792 .47911 .49981 .47814 .49876 .4773 Mtetra
.879 .84 .803 r
.49876 .4773 .49981 .47814 .5017 .4772 .50066 .47501 Mtetra
.863 .696 .674 r
.50066 .47501 .5017 .4772 .50359 .47585 .50258 .47088 Mtetra
.898 .648 .552 r
.50258 .47088 .50359 .47585 .50549 .4736 .50455 .45602 Mtetra
.952 .668 .463 r
.50455 .45602 .50549 .4736 .50742 .46585 .50753 .26042 Mtetra
.536 .31 .519 r
.50753 .26042 .50742 .46585 .51028 .26058 .50932 .25653 Mtetra
.709 .543 .662 r
.50932 .25653 .51028 .26058 .51207 .2557 .5111 .25429 Mtetra
.73 .721 .842 r
.5111 .25429 .51207 .2557 .51384 .25421 .51287 .25322 Mtetra
.657 .776 .937 r
.51287 .25322 .51384 .25421 .51561 .2536 .51464 .25261 Mtetra
.611 .76 .95 r
.51464 .25261 .51561 .2536 .51738 .25331 .51641 .25216 Mtetra
.732 .766 .88 r
.51641 .25216 .51738 .25331 .51915 .25257 .51819 .25117 Mtetra
.716 .72 .853 r
.51819 .25117 .51915 .25257 .52093 .25174 .51996 .25021 Mtetra
.648 .674 .861 r
.51996 .25021 .52093 .25174 .5227 .25107 .52174 .24962 Mtetra
.238 .471 .88 r
.52174 .24962 .5227 .25107 .52448 .25063 .52352 .25033 Mtetra
.778 .273 0 r
.52352 .25033 .52448 .25063 .52626 .2506 .5253 .25273 Mtetra
.906 .569 .396 r
.5253 .25273 .52626 .2506 .52804 .25135 .52709 .26443 Mtetra
.955 .662 .442 r
.52709 .26443 .52804 .25135 .52983 .2566 .52913 .46093 Mtetra
.533 .302 .511 r
.52913 .46093 .52983 .2566 .53206 .46166 .53104 .46409 Mtetra
.62 .228 .279 r
.53104 .46409 .53206 .46166 .53398 .46611 .53296 .46542 Mtetra
0 .49 .859 r
.53296 .46542 .53398 .46611 .5359 .46718 .53487 .46601 Mtetra
.519 .7 .952 r
.53487 .46601 .5359 .46718 .53782 .46695 .53679 .46586 Mtetra
.735 .795 .9 r
.53679 .46586 .53782 .46695 .53973 .46569 .5387 .4648 Mtetra
.943 .805 .678 r
.5387 .4648 .53973 .46569 .54162 .46117 .5406 .46042 Mtetra
.973 .689 .427 r
.5406 .46042 .54162 .46117 .54236 .25303 .5414 .25211 Mtetra
.968 .751 .557 r
.5414 .25211 .54236 .25303 .5441 .2443 .54315 .243 Mtetra
.832 .766 .789 r
.54315 .243 .5441 .2443 .54588 .24231 .54493 .24101 Mtetra
.637 .711 .901 r
.54493 .24101 .54588 .24231 .54768 .24174 .54672 .24049 Mtetra
.495 .656 .932 r
.54672 .24049 .54768 .24174 .54947 .24165 .54852 .24046 Mtetra
.649 .736 .913 r
.54852 .24046 .54947 .24165 .55127 .24116 .55031 .23988 Mtetra
.688 .733 .885 r
.55031 .23988 .55127 .24116 .55306 .24047 .55211 .23911 Mtetra
.625 .694 .894 r
.55211 .23911 .55306 .24047 .55486 .23988 .55391 .23864 Mtetra
.225 .506 .907 r
.55391 .23864 .55486 .23988 .55666 .23939 .55572 .23925 Mtetra
.762 .248 0 r
.55572 .23925 .55666 .23939 .55846 .23923 .55755 .24152 Mtetra
.888 .541 .383 r
.55755 .24152 .55846 .23923 .56028 .23975 .55947 .25112 Mtetra
.959 .664 .428 r
.55947 .25112 .56028 .23975 .56214 .244 .56363 .44943 Mtetra
.533 .303 .511 r
.56363 .44943 .56214 .244 .56657 .44972 .56561 .45282 Mtetra
.613 .243 .317 r
.56561 .45282 .56657 .44972 .56858 .45475 .56757 .45421 Mtetra
0 .51 .84 r
.56757 .45421 .56858 .45475 .57054 .45596 .56952 .4547 Mtetra
.559 .702 .937 r
.56952 .4547 .57054 .45596 .57248 .45572 .57147 .45444 Mtetra
.742 .766 .872 r
.57147 .45444 .57248 .45572 .57441 .45445 .5734 .45329 Mtetra
.928 .787 .683 r
.5734 .45329 .57441 .45445 .57629 .45024 .57528 .44908 Mtetra
.974 .687 .415 r
.57528 .44908 .57629 .45024 .57485 .24256 .5739 .24082 Mtetra
.949 .722 .561 r
.5739 .24082 .57485 .24256 .57652 .23299 .57558 .23162 Mtetra
.844 .762 .771 r
.57558 .23162 .57652 .23299 .5783 .23072 .57736 .22941 Mtetra
.642 .712 .898 r
.57736 .22941 .5783 .23072 .58012 .23011 .57918 .22885 Mtetra
.503 .66 .931 r
.57918 .22885 .58012 .23011 .58194 .23 .581 .2288 Mtetra
.572 .705 .932 r
.581 .2288 .58194 .23 .58376 .22968 .58282 .22852 Mtetra
.658 .747 .916 r
.58282 .22852 .58376 .22968 .58558 .22906 .58464 .22789 Mtetra
.676 .752 .908 r
.58464 .22789 .58558 .22906 .5874 .22839 .58646 .22718 Mtetra
.753 .77 .866 r
.58646 .22718 .5874 .22839 .58921 .2273 .58827 .22603 Mtetra
.754 .758 .856 r
.58827 .22603 .58921 .2273 .59102 .2262 .59008 .22484 Mtetra
.655 .71 .888 r
.59008 .22484 .59102 .2262 .59284 .22565 .5919 .22422 Mtetra
0 .189 .719 r
.5919 .22422 .59284 .22565 .59471 .22739 .59377 .22586 Mtetra
.964 .634 .288 r
.59377 .22586 .59471 .22739 .60116 .42354 .59603 .24365 Mtetra
0 0 .326 r
.59603 .24365 .60116 .42354 .60359 .44274 .60259 .4415 Mtetra
0 .002 .536 r
.60259 .4415 .60359 .44274 .60561 .44484 .60462 .4437 Mtetra
.496 .699 .96 r
.60462 .4437 .60561 .44484 .60759 .44471 .60659 .44359 Mtetra
.763 .804 .885 r
.60659 .44359 .60759 .44471 .60953 .44345 .60854 .44234 Mtetra
.928 .8 .699 r
.60854 .44234 .60953 .44345 .61141 .43964 .61042 .43847 Mtetra
.976 .685 .402 r
.61042 .43847 .61141 .43964 .60781 .234 .60686 .23189 Mtetra
.952 .709 .533 r
.60686 .23189 .60781 .234 .60933 .22161 .6084 .22022 Mtetra
.867 .765 .749 r
.6084 .22022 .60933 .22161 .61111 .21897 .61018 .21764 Mtetra
.657 .717 .892 r
.61018 .21764 .61111 .21897 .61294 .21828 .61201 .217 Mtetra
.52 .666 .928 r
.61201 .217 .61294 .21828 .61479 .21812 .61386 .2169 Mtetra
.556 .695 .933 r
.61386 .2169 .61479 .21812 .61664 .21784 .61571 .21667 Mtetra
.658 .747 .916 r
.61571 .21667 .61664 .21784 .61848 .21721 .61755 .21603 Mtetra
.675 .753 .909 r
.61755 .21603 .61848 .21721 .62031 .21653 .61939 .21532 Mtetra
.745 .77 .874 r
.61939 .21532 .62031 .21653 .62214 .21549 .62122 .21422 Mtetra
.761 .763 .855 r
.62122 .21422 .62214 .21549 .62397 .21434 .62304 .21298 Mtetra
.673 .72 .885 r
.62304 .21298 .62397 .21434 .62581 .21369 .62488 .21227 Mtetra
.059 .359 .831 r
.62488 .21227 .62581 .21369 .62772 .21491 .62679 .21341 Mtetra
.919 .548 .12 r
.62679 .21341 .62772 .21491 .62991 .22422 .62895 .22189 Mtetra
.976 .676 .371 r
.62895 .22189 .62991 .22422 .63901 .43037 .63803 .42913 Mtetra
.556 .095 0 r
.63803 .42913 .63901 .43037 .64111 .43282 .64013 .43178 Mtetra
.519 .734 .972 r
.64013 .43178 .64111 .43282 .6431 .43248 .64214 .43157 Mtetra
.761 .849 .917 r
.64214 .43157 .6431 .43248 .64507 .43133 .64411 .43037 Mtetra
.9 .842 .778 r
.64411 .43037 .64507 .43133 .64702 .42963 .64602 .42773 Mtetra
.923 .733 .627 r
.64602 .42773 .64702 .42963 .64896 .42756 .64782 .42197 Mtetra
.974 .678 .395 r
.64782 .42197 .64896 .42756 .65089 .42535 .64204 .2197 Mtetra
.533 .307 .518 r
.64204 .2197 .65089 .42535 .65287 .42455 .64384 .21738 Mtetra
0 0 .381 r
.64384 .21738 .65287 .42455 .65493 .42555 .65376 .41953 Mtetra
.065 .079 .562 r
.65376 .41953 .65493 .42555 .65698 .42643 .65598 .4245 Mtetra
.144 .351 .81 r
.65598 .4245 .65698 .42643 .65901 .42662 .65806 .42585 Mtetra
.583 .824 .99 r
.65806 .42585 .65901 .42662 .66102 .42609 .66007 .42534 Mtetra
.689 .867 .966 r
.66007 .42534 .66102 .42609 .66302 .42541 .66206 .42447 Mtetra
.595 .791 .974 r
.66206 .42447 .66302 .42541 .66503 .42508 .66407 .42398 Mtetra
.419 .671 .966 r
.66407 .42398 .66503 .42508 .66706 .42512 .6661 .42407 Mtetra
.605 .771 .96 r
.6661 .42407 .66706 .42512 .66907 .42458 .66811 .42357 Mtetra
.882 .842 .801 r
.66811 .42357 .66907 .42458 .671 .42215 .67004 .42121 Mtetra
.982 .76 .527 r
.67004 .42121 .671 .42215 .67256 .41186 .67164 .41136 Mtetra
.978 .681 .374 r
.67164 .41136 .67256 .41186 .66495 .20338 .66404 .20219 Mtetra
.931 .791 .684 r
.66404 .20219 .66495 .20338 .66667 .19962 .66577 .19836 Mtetra
.722 .758 .881 r
.66577 .19836 .66667 .19962 .66853 .19864 .66763 .19737 Mtetra
.595 .707 .922 r
.66763 .19737 .66853 .19864 .67041 .19825 .66951 .197 Mtetra
.623 .721 .917 r
.66951 .197 .67041 .19825 .67229 .19775 .6714 .1965 Mtetra
.738 .767 .876 r
.6714 .1965 .67229 .19775 .67415 .19667 .67325 .19543 Mtetra
.648 .735 .913 r
.67325 .19543 .67415 .19667 .67603 .19606 .67513 .19483 Mtetra
.099 .423 .868 r
.67513 .19483 .67603 .19606 .67799 .197 .67709 .19577 Mtetra
.918 .543 .122 r
.67709 .19577 .67799 .197 .68036 .20594 .67946 .20475 Mtetra
.975 .67 .349 r
.67946 .20475 .68036 .20594 .69305 .41312 .6921 .41193 Mtetra
.613 .151 0 r
.6921 .41193 .69305 .41312 .69526 .41617 .69431 .41499 Mtetra
.415 .651 .956 r
.69431 .41499 .69526 .41617 .69733 .41631 .69638 .41512 Mtetra
.711 .786 .91 r
.69638 .41512 .69733 .41631 .69934 .41535 .69839 .41416 Mtetra
.888 .816 .771 r
.69839 .41416 .69934 .41535 .70126 .41269 .70031 .41149 Mtetra
.978 .755 .533 r
.70031 .41149 .70126 .41269 .70281 .40334 .70186 .40207 Mtetra
.977 .678 .362 r
.70186 .40207 .70281 .40334 .69317 .19371 .69228 .19243 Mtetra
.935 .784 .67 r
.69228 .19243 .69317 .19371 .69487 .18959 .69398 .18833 Mtetra
.727 .762 .881 r
.69398 .18833 .69487 .18959 .69674 .18856 .69585 .18731 Mtetra
.597 .713 .925 r
.69585 .18731 .69674 .18856 .69864 .18816 .69776 .18692 Mtetra
.576 .705 .93 r
.69776 .18692 .69864 .18816 .70055 .18779 .69967 .1866 Mtetra
.706 .769 .902 r
.69967 .1866 .70055 .18779 .70243 .18678 .70155 .18572 Mtetra
.662 .78 .936 r
.70155 .18572 .70243 .18678 .70432 .18613 .70345 .18505 Mtetra
.515 .709 .959 r
.70345 .18505 .70432 .18613 .70628 .1865 .70538 .18489 Mtetra
.196 .416 .849 r
.70538 .18489 .70628 .1865 .70846 .19049 .70738 .1859 Mtetra
.241 .227 .643 r
.70738 .1859 .70846 .19049 .72318 .39794 .70949 .18862 Mtetra
.01 0 .41 r
.70949 .18862 .72318 .39794 .72561 .40363 .72368 .38637 Mtetra
.154 .07 .5 r
.72368 .38637 .72561 .40363 .72775 .40444 .72655 .39899 Mtetra
.284 .244 .636 r
.72655 .39899 .72775 .40444 .72984 .40441 .72882 .40184 Mtetra
.328 .401 .785 r
.72882 .40184 .72984 .40441 .73191 .40411 .73098 .40295 Mtetra
.431 .667 .961 r
.73098 .40295 .73191 .40411 .734 .40402 .73308 .40303 Mtetra
.667 .813 .954 r
.73308 .40303 .734 .40402 .73605 .40332 .73513 .40226 Mtetra
.868 .844 .818 r
.73513 .40226 .73605 .40332 .73801 .40128 .73708 .40008 Mtetra
.979 .766 .546 r
.73708 .40008 .73801 .40128 .73956 .39308 .73863 .39186 Mtetra
.977 .675 .344 r
.73863 .39186 .73956 .39308 .72743 .18207 .72656 .18079 Mtetra
.949 .783 .643 r
.72656 .18079 .72743 .18207 .72908 .17741 .7282 .17613 Mtetra
.739 .767 .875 r
.7282 .17613 .72908 .17741 .73096 .1763 .73009 .17503 Mtetra
.608 .716 .921 r
.73009 .17503 .73096 .1763 .73289 .17585 .73202 .17459 Mtetra
.556 .693 .931 r
.73202 .17459 .73289 .17585 .73483 .17557 .73396 .17434 Mtetra
.706 .765 .898 r
.73396 .17434 .73483 .17557 .73672 .17453 .73587 .17344 Mtetra
.669 .78 .932 r
.73587 .17344 .73672 .17453 .73864 .17383 .73778 .17273 Mtetra
.55 .727 .956 r
.73778 .17273 .73864 .17383 .74062 .17395 .73973 .17246 Mtetra
.211 .448 .87 r
.73973 .17246 .74062 .17395 .74284 .17744 .74177 .17337 Mtetra
.245 .248 .665 r
.74177 .17337 .74284 .17744 .76 .38457 .74392 .17581 Mtetra
.492 .278 .516 r
.74392 .17581 .76 .38457 .76263 .39161 .74724 .19393 Mtetra
.01 0 .415 r
.74724 .19393 .76263 .39161 .76483 .39254 .76356 .38661 Mtetra
.286 .237 .626 r
.76356 .38661 .76483 .39254 .76695 .39257 .76592 .38976 Mtetra
.329 .383 .767 r
.76592 .38976 .76695 .39257 .76905 .39221 .76814 .391 Mtetra
.413 .646 .954 r
.76814 .391 .76905 .39221 .77118 .39217 .77028 .39115 Mtetra
.646 .804 .959 r
.77028 .39115 .77118 .39217 .77326 .39153 .77236 .39047 Mtetra
.842 .848 .848 r
.77236 .39047 .77326 .39153 .77526 .3898 .77434 .38859 Mtetra
.979 .777 .562 r
.77434 .38859 .77526 .3898 .77682 .38259 .77591 .38135 Mtetra
.976 .67 .326 r
.77591 .38135 .77682 .38259 .76214 .17045 .76128 .16914 Mtetra
.961 .78 .612 r
.76128 .16914 .76214 .17045 .7637 .16509 .76284 .16379 Mtetra
.755 .772 .867 r
.76284 .16379 .7637 .16509 .7656 .16387 .76474 .16257 Mtetra
.625 .721 .915 r
.76474 .16257 .7656 .16387 .76755 .16335 .76669 .16205 Mtetra
.548 .684 .929 r
.76669 .16205 .76755 .16335 .76952 .16313 .76867 .16184 Mtetra
.746 .771 .874 r
.76867 .16184 .76952 .16313 .77142 .16197 .77057 .16069 Mtetra
.677 .746 .903 r
.77057 .16069 .77142 .16197 .77336 .1612 .77251 .15992 Mtetra
.466 .644 .935 r
.77251 .15992 .77336 .1612 .77536 .16125 .77451 .15998 Mtetra
.766 .35 0 r
.77451 .15998 .77536 .16125 .7778 .16643 .77696 .16519 Mtetra
.971 .656 .295 r
.77696 .16519 .7778 .16643 .79783 .3777 .79694 .37652 Mtetra
.733 .296 0 r
.79694 .37652 .79783 .3777 .80039 .38242 .79949 .38121 Mtetra
.3 .581 .94 r
.79949 .38121 .80039 .38242 .80259 .38289 .80169 .38168 Mtetra
.648 .767 .936 r
.80169 .38168 .80259 .38289 .80469 .38222 .8038 .381 Mtetra
.828 .824 .845 r
.8038 .381 .80469 .38222 .80669 .38039 .8058 .37918 Mtetra
.908 .739 .66 r
.13612 .59084 .13731 .59179 .13954 .58614 .13835 .58522 Mtetra
.936 .686 .535 r
.13835 .58522 .13954 .58614 .16389 .38395 .16278 .38298 Mtetra
.911 .729 .644 r
.16278 .38298 .16389 .38395 .16607 .37779 .16497 .37678 Mtetra
.772 .762 .844 r
.16497 .37678 .16607 .37779 .1677 .3766 .1666 .37559 Mtetra
.629 .735 .924 r
.1666 .37559 .1677 .3766 .16924 .37618 .16814 .37516 Mtetra
.489 .686 .954 r
.16814 .37516 .16924 .37618 .17074 .37612 .16964 .37511 Mtetra
.664 .745 .91 r
.16964 .37511 .17074 .37612 .1723 .37557 .1712 .37455 Mtetra
.676 .745 .903 r
.1712 .37455 .1723 .37557 .17386 .37496 .17276 .37394 Mtetra
.683 .747 .9 r
.17276 .37394 .17386 .37496 .17543 .3743 .17433 .3733 Mtetra
.771 .764 .847 r
.17433 .3733 .17543 .3743 .17707 .37302 .17596 .37212 Mtetra
.727 .778 .893 r
.17596 .37212 .17707 .37302 .17867 .37209 .17756 .37127 Mtetra
.52 .745 .977 r
.17756 .37127 .17867 .37209 .1802 .37183 .17908 .37109 Mtetra
.909 .515 .244 r
.17908 .37109 .1802 .37183 .18134 .37523 .18019 .37469 Mtetra
.939 .682 .522 r
.18019 .37469 .18134 .37523 .16134 .57635 .1601 .57591 Mtetra
.922 .583 .38 r
.1601 .57591 .16134 .57635 .16221 .58315 .16103 .58218 Mtetra
0 .301 .755 r
.16103 .58218 .16221 .58315 .16372 .58407 .16255 .58304 Mtetra
.629 .747 .933 r
.16255 .58304 .16372 .58407 .16538 .58363 .16421 .58258 Mtetra
.806 .769 .818 r
.16421 .58258 .16538 .58363 .16716 .582 .16599 .58095 Mtetra
.909 .734 .652 r
.16599 .58095 .16716 .582 .16941 .57588 .16822 .57499 Mtetra
.939 .687 .529 r
.16822 .57499 .16941 .57588 .19219 .37257 .19106 .3719 Mtetra
.923 .751 .651 r
.19106 .3719 .19219 .37257 .19428 .36704 .19317 .36621 Mtetra
.8 .798 .85 r
.19317 .36621 .19428 .36704 .19592 .3658 .19482 .36487 Mtetra
.626 .754 .939 r
.19482 .36487 .19592 .3658 .19747 .36548 .19638 .36444 Mtetra
.489 .681 .951 r
.19638 .36444 .19747 .36548 .19898 .36555 .1979 .3644 Mtetra
.638 .712 .901 r
.1979 .3644 .19898 .36555 .20055 .36504 .19946 .36393 Mtetra
.662 .728 .898 r
.19946 .36393 .20055 .36504 .20213 .36437 .20104 .36337 Mtetra
.666 .75 .913 r
.20104 .36337 .20213 .36437 .20372 .36369 .20262 .3628 Mtetra
.662 .772 .931 r
.20262 .3628 .20372 .36369 .2053 .3631 .20419 .36224 Mtetra
.66 .779 .937 r
.20419 .36224 .2053 .3631 .20688 .36254 .20577 .36168 Mtetra
.661 .779 .937 r
.20577 .36168 .20688 .36254 .20845 .362 .20735 .36113 Mtetra
.663 .778 .934 r
.20735 .36113 .20845 .362 .21004 .36143 .20893 .36056 Mtetra
.664 .779 .934 r
.20893 .36056 .21004 .36143 .21162 .36085 .21051 .35999 Mtetra
.664 .781 .935 r
.21051 .35999 .21162 .36085 .2132 .36027 .2121 .35942 Mtetra
.665 .783 .937 r
.2121 .35942 .2132 .36027 .21479 .35969 .21368 .35885 Mtetra
.664 .786 .939 r
.21368 .35885 .21479 .35969 .21637 .3591 .21527 .35827 Mtetra
.663 .789 .942 r
.21527 .35827 .21637 .3591 .21796 .35851 .21685 .3577 Mtetra
.661 .792 .944 r
.21685 .3577 .21796 .35851 .21955 .35792 .21844 .35714 Mtetra
.658 .798 .949 r
.21844 .35714 .21955 .35792 .22114 .35735 .22003 .35658 Mtetra
.654 .801 .953 r
.22003 .35658 .22114 .35735 .22272 .3568 .22161 .35604 Mtetra
.642 .798 .958 r
.22161 .35604 .22272 .3568 .2243 .35637 .2232 .35553 Mtetra
.642 .781 .948 r
.2232 .35553 .2243 .35637 .22587 .35598 .22478 .35503 Mtetra
.649 .76 .93 r
.22478 .35503 .22587 .35598 .22745 .35554 .22637 .35451 Mtetra
.67 .748 .909 r
.22637 .35451 .22745 .35554 .22905 .35489 .22796 .35392 Mtetra
.68 .763 .914 r
.22796 .35392 .22905 .35489 .23066 .35413 .22956 .35328 Mtetra
.683 .789 .93 r
.22956 .35328 .23066 .35413 .23227 .35336 .23116 .35263 Mtetra
.69 .817 .943 r
.23116 .35263 .23227 .35336 .23389 .35253 .23277 .35195 Mtetra
.672 .85 .968 r
.23277 .35195 .23389 .35253 .2355 .35183 .23437 .35131 Mtetra
.626 .855 .986 r
.23437 .35131 .2355 .35183 .23708 .35144 .23596 .35079 Mtetra
.633 .823 .973 r
.23596 .35079 .23708 .35144 .23858 .35197 .23756 .35028 Mtetra
.579 .606 .843 r
.23756 .35028 .23858 .35197 .23997 .35374 .23913 .35006 Mtetra
.48 .402 .691 r
.23913 .35006 .23997 .35374 .24104 .35905 .24063 .3505 Mtetra
.206 .113 .523 r
.24063 .3505 .24104 .35905 .22506 .55672 .24181 .35466 Mtetra
0 0 .152 r
.24181 .35466 .22506 .55672 .22631 .56128 .22551 .55621 Mtetra
0 0 .343 r
.22551 .55621 .22631 .56128 .22781 .56307 .22672 .56127 Mtetra
.185 .391 .831 r
.22672 .56127 .22781 .56307 .22943 .56347 .2283 .56215 Mtetra
.614 .693 .899 r
.2283 .56215 .22943 .56347 .23112 .56311 .23 .56175 Mtetra
.712 .717 .853 r
.23 .56175 .23112 .56311 .23286 .56218 .23174 .56083 Mtetra
.687 .711 .867 r
.23174 .56083 .23286 .56218 .23468 .56044 .23347 .56007 Mtetra
.714 .908 .963 r
.23347 .56007 .23468 .56044 .23659 .55757 .23521 .55918 Mtetra
0 0 0 r
.23521 .55918 .23659 .55757 .23872 .55206 .23701 .55763 Mtetra
0 0 .07 r
.23701 .55763 .23872 .55206 .25715 .35319 .23908 .55289 Mtetra
0 0 .142 r
.23908 .55289 .25715 .35319 .25926 .34667 .25777 .35056 Mtetra
.877 .848 .389 r
.25777 .35056 .25926 .34667 .26106 .3438 .25993 .34358 Mtetra
.889 .9 .83 r
.25993 .34358 .26106 .3438 .26273 .3426 .26165 .34163 Mtetra
.656 .76 .926 r
.26165 .34163 .26273 .3426 .26433 .34222 .26327 .34108 Mtetra
.513 .672 .936 r
.26327 .34108 .26433 .34222 .2659 .34217 .26484 .341 Mtetra
.564 .688 .923 r
.26484 .341 .2659 .34217 .26748 .34195 .26643 .34078 Mtetra
.621 .709 .909 r
.26643 .34078 .26748 .34195 .26909 .34152 .26803 .34038 Mtetra
.625 .716 .912 r
.26803 .34038 .26909 .34152 .2707 .34103 .26964 .33995 Mtetra
.637 .732 .916 r
.26964 .33995 .2707 .34103 .27232 .3405 .27125 .33947 Mtetra
.651 .748 .92 r
.27125 .33947 .27232 .3405 .27394 .33992 .27286 .33894 Mtetra
.663 .761 .923 r
.27286 .33894 .27394 .33992 .27556 .3393 .27449 .33837 Mtetra
.675 .774 .925 r
.27449 .33837 .27556 .3393 .27719 .33865 .27611 .33774 Mtetra
.686 .781 .923 r
.27611 .33774 .27719 .33865 .27882 .33797 .27774 .33707 Mtetra
.694 .785 .92 r
.27774 .33707 .27882 .33797 .28045 .33725 .27938 .33636 Mtetra
.717 .792 .91 r
.27938 .33636 .28045 .33725 .28211 .33627 .28102 .33555 Mtetra
.725 .829 .929 r
.28102 .33555 .28211 .33627 .28377 .33526 .28267 .33471 Mtetra
.692 .863 .963 r
.28267 .33471 .28377 .33526 .2854 .33458 .28431 .33399 Mtetra
.556 .818 .995 r
.28431 .33399 .2854 .33458 .28695 .33501 .28592 .33363 Mtetra
.51 .625 .901 r
.28592 .33363 .28695 .33501 .28838 .33709 .28751 .33361 Mtetra
.532 .446 .703 r
.28751 .33361 .28838 .33709 .28957 .3425 .28909 .33368 Mtetra
.548 .371 .593 r
.28909 .33368 .28957 .3425 .27724 .53109 .29069 .33344 Mtetra
.529 .304 .518 r
.29069 .33344 .27724 .53109 .27887 .53187 .29233 .33282 Mtetra
.529 .305 .518 r
.29233 .33282 .27887 .53187 .28098 .52614 .29397 .33209 Mtetra
.29397 .33209 .28098 .52614 .29524 .35224 .29562 .33141 Mtetra
.544 .337 .549 r
.29562 .33141 .29524 .35224 .29699 .3503 .29726 .33079 Mtetra
.545 .339 .551 r
.29726 .33079 .29699 .3503 .29869 .34886 .29889 .33019 Mtetra
.546 .34 .553 r
.29889 .33019 .29869 .34886 .30037 .34793 .30053 .3296 Mtetra
.546 .341 .554 r
.30053 .3296 .30037 .34793 .30201 .34742 .30217 .32902 Mtetra
.30217 .32902 .30201 .34742 .30363 .34714 .30381 .32845 Mtetra
.545 .34 .553 r
.30381 .32845 .30363 .34714 .30525 .34704 .30545 .32788 Mtetra
.545 .339 .552 r
.30545 .32788 .30525 .34704 .30686 .34711 .30709 .32731 Mtetra
.544 .338 .551 r
.30709 .32731 .30686 .34711 .30845 .34736 .30873 .32674 Mtetra
.543 .336 .549 r
.30873 .32674 .30845 .34736 .31004 .34776 .31038 .32618 Mtetra
.543 .335 .548 r
.31038 .32618 .31004 .34776 .31162 .34828 .31202 .32561 Mtetra
.542 .333 .546 r
.31202 .32561 .31162 .34828 .31319 .349 .31367 .32503 Mtetra
.541 .331 .545 r
.31367 .32503 .31319 .349 .31475 .34991 .31531 .32446 Mtetra
.541 .33 .543 r
.31531 .32446 .31475 .34991 .3163 .35094 .31696 .32388 Mtetra
.54 .328 .541 r
.31696 .32388 .3163 .35094 .31785 .3521 .31861 .32329 Mtetra
.539 .326 .54 r
.31861 .32329 .31785 .3521 .31942 .35295 .32026 .32271 Mtetra
.539 .325 .538 r
.32026 .32271 .31942 .35295 .32106 .35277 .32191 .32212 Mtetra
.32191 .32212 .32106 .35277 .32277 .3516 .32357 .32153 Mtetra
.539 .325 .539 r
.32357 .32153 .32277 .3516 .32451 .34977 .32522 .32093 Mtetra
.539 .327 .54 r
.32522 .32093 .32451 .34977 .32626 .34792 .32688 .32033 Mtetra
.54 .328 .541 r
.32688 .32033 .32626 .34792 .32797 .34658 .32853 .31974 Mtetra
.32853 .31974 .32797 .34658 .32959 .34691 .33019 .31914 Mtetra
.54 .327 .541 r
.33019 .31914 .32959 .34691 .33091 .3521 .33185 .31855 Mtetra
.538 .323 .536 r
.33185 .31855 .33091 .3521 .32392 .49452 .33351 .31796 Mtetra
.529 .305 .518 r
.33351 .31796 .32392 .49452 .32456 .51227 .33516 .31742 Mtetra
.529 .304 .518 r
.33516 .31742 .32456 .51227 .32603 .51658 .33682 .31692 Mtetra
.33682 .31692 .32603 .51658 .32789 .51437 .33848 .3163 Mtetra
.53 .305 .518 r
.33848 .3163 .32789 .51437 .34073 .32453 .34017 .31534 Mtetra
.592 .402 .593 r
.34017 .31534 .34073 .32453 .34276 .31765 .34187 .31402 Mtetra
.66 .523 .685 r
.34187 .31402 .34276 .31765 .34459 .31427 .34357 .31277 Mtetra
.717 .693 .826 r
.34357 .31277 .34459 .31427 .34632 .31241 .34526 .31178 Mtetra
.671 .848 .968 r
.34526 .31178 .34632 .31241 .348 .31164 .34693 .31113 Mtetra
.628 .864 .987 r
.34693 .31113 .348 .31164 .34966 .31116 .3486 .31056 Mtetra
.638 .847 .98 r
.3486 .31056 .34966 .31116 .35132 .3107 .35026 .30999 Mtetra
.669 .828 .96 r
.35026 .30999 .35132 .3107 .35299 .31009 .35194 .30935 Mtetra
.671 .823 .957 r
.35194 .30935 .35299 .31009 .35466 .30947 .35361 .30871 Mtetra
.672 .818 .953 r
.35361 .30871 .35466 .30947 .35633 .30885 .35528 .30806 Mtetra
.673 .813 .95 r
.35528 .30806 .35633 .30885 .35801 .30821 .35696 .30742 Mtetra
.672 .81 .949 r
.35696 .30742 .35801 .30821 .35968 .30758 .35863 .30678 Mtetra
.704 .815 .934 r
.35863 .30678 .35968 .30758 .36136 .30688 .36032 .30601 Mtetra
.738 .808 .907 r
.36032 .30601 .36136 .30688 .36305 .30606 .36201 .30508 Mtetra
.649 .763 .932 r
.36201 .30508 .36305 .30606 .36472 .30549 .36368 .30453 Mtetra
.048 .458 .88 r
.36368 .30453 .36472 .30549 .36636 .30566 .3653 .30518 Mtetra
.916 .528 .254 r
.3653 .30518 .36636 .30566 .36791 .30754 .3667 .31007 Mtetra
.954 .68 .478 r
.3667 .31007 .36791 .30754 .36932 .31237 .35817 .51387 Mtetra
.535 .304 .512 r
.35817 .51387 .36932 .31237 .36143 .50692 .35973 .51799 Mtetra
.511 .243 .445 r
.35973 .51799 .36143 .50692 .36319 .50678 .3615 .51785 Mtetra
.483 .219 .437 r
.3615 .51785 .36319 .50678 .36504 .50505 .36331 .51703 Mtetra
.49 .229 .444 r
.36331 .51703 .36504 .50505 .36662 .50885 .36511 .5163 Mtetra
.519 .23 .416 r
.36511 .5163 .36662 .50885 .36812 .51442 .36687 .51647 Mtetra
.465 .057 .179 r
.36687 .51647 .36812 .51442 .36978 .51689 .36864 .51657 Mtetra
.199 .701 .909 r
.36864 .51657 .36978 .51689 .3715 .51794 .37042 .51656 Mtetra
.539 .66 .914 r
.37042 .51656 .3715 .51794 .37328 .51782 .3722 .51641 Mtetra
.661 .704 .879 r
.3722 .51641 .37328 .51782 .37509 .51713 .37401 .51576 Mtetra
.807 .747 .797 r
.37401 .51576 .37509 .51713 .37694 .51563 .37587 .51392 Mtetra
.907 .719 .637 r
.37587 .51392 .37694 .51563 .37886 .51243 .37792 .50784 Mtetra
.956 .686 .483 r
.37792 .50784 .37886 .51243 .38089 .50653 .38865 .30259 Mtetra
.54 .313 .52 r
.38865 .30259 .38089 .50653 .39102 .3112 .39055 .29707 Mtetra
.563 .362 .567 r
.39055 .29707 .39102 .3112 .39275 .30991 .39227 .29605 Mtetra
.544 .348 .566 r
.39227 .29605 .39275 .30991 .39434 .31187 .39395 .2957 Mtetra
.541 .341 .558 r
.39395 .2957 .39434 .31187 .39627 .30599 .39564 .29536 Mtetra
.581 .387 .583 r
.39564 .29536 .39627 .30599 .39826 .29834 .39736 .29413 Mtetra
.642 .496 .668 r
.39736 .29413 .39826 .29834 .40008 .29475 .39909 .29293 Mtetra
.704 .654 .797 r
.39909 .29293 .40008 .29475 .40184 .29262 .4008 .29191 Mtetra
.667 .834 .963 r
.4008 .29191 .40184 .29262 .40354 .29179 .40251 .29126 Mtetra
.611 .861 .99 r
.40251 .29126 .40354 .29179 .40524 .2913 .40421 .29072 Mtetra
.599 .845 .991 r
.40421 .29072 .40524 .2913 .40693 .29097 .40591 .29022 Mtetra
.631 .816 .971 r
.40591 .29022 .40693 .29097 .40863 .29055 .40761 .2897 Mtetra
.639 .793 .956 r
.40761 .2897 .40863 .29055 .41033 .29014 .40931 .28916 Mtetra
.65 .769 .936 r
.40931 .28916 .41033 .29014 .41203 .28969 .41102 .2886 Mtetra
.664 .749 .913 r
.41102 .2886 .41203 .28969 .41373 .28914 .41272 .28799 Mtetra
.67 .74 .903 r
.41272 .28799 .41373 .28914 .41544 .28851 .41443 .28734 Mtetra
.676 .738 .897 r
.41443 .28734 .41544 .28851 .41715 .28781 .41615 .28667 Mtetra
.683 .745 .898 r
.41615 .28667 .41715 .28781 .41887 .28701 .41786 .28597 Mtetra
.686 .766 .912 r
.41786 .28597 .41887 .28701 .42059 .2862 .41958 .28526 Mtetra
.686 .788 .928 r
.41958 .28526 .42059 .2862 .42231 .28541 .42129 .28455 Mtetra
.679 .803 .942 r
.42129 .28455 .42231 .28541 .42402 .28474 .42301 .28387 Mtetra
.675 .801 .943 r
.42301 .28387 .42402 .28474 .42574 .2841 .42473 .28321 Mtetra
.681 .798 .937 r
.42473 .28321 .42574 .2841 .42745 .28345 .42644 .28252 Mtetra
.747 .804 .898 r
.42644 .28252 .42745 .28345 .42918 .28257 .42817 .28151 Mtetra
.675 .76 .915 r
.42817 .28151 .42918 .28257 .4309 .28191 .42989 .28085 Mtetra
.421 .655 .957 r
.42989 .28085 .4309 .28191 .4326 .28174 .43159 .28094 Mtetra
.881 .447 .082 r
.43159 .28094 .4326 .28174 .43426 .28337 .43318 .28471 Mtetra
.962 .681 .456 r
.43318 .28471 .43426 .28337 .43585 .28743 .42897 .489 Mtetra
.539 .307 .512 r
.42897 .489 .43585 .28743 .432 .48509 .43061 .49526 Mtetra
.52 .247 .441 r
.43061 .49526 .432 .48509 .43377 .48712 .43244 .4954 Mtetra
.472 .195 .412 r
.43244 .4954 .43377 .48712 .43563 .48578 .43429 .49465 Mtetra
.452 .182 .412 r
.43429 .49465 .43563 .48578 .43755 .48212 .43615 .49345 Mtetra
.488 .224 .44 r
.43615 .49345 .43755 .48212 .43954 .47563 .438 .49271 Mtetra
.504 .252 .466 r
.438 .49271 .43954 .47563 .44148 .47067 .43985 .49204 Mtetra
.512 .265 .477 r
.43985 .49204 .44148 .47067 .44306 .48034 .44169 .49156 Mtetra
.52 .251 .447 r
.44169 .49156 .44306 .48034 .44469 .48868 .44352 .49166 Mtetra
.488 .122 .271 r
.44352 .49166 .44469 .48868 .44645 .4917 .44536 .49177 Mtetra
.004 0 0 r
.44536 .49177 .44645 .4917 .44826 .49312 .4472 .49172 Mtetra
.64 .704 .893 r
.4472 .49172 .44826 .49312 .45011 .49268 .44905 .49116 Mtetra
.662 .693 .869 r
.44905 .49116 .45011 .49268 .45197 .49184 .45091 .49048 Mtetra
.674 .722 .885 r
.45091 .49048 .45197 .49184 .45384 .49084 .45277 .48975 Mtetra
.488 .699 .963 r
.45277 .48975 .45384 .49084 .45568 .49069 .45462 .48966 Mtetra
.598 .759 .956 r
.45462 .48966 .45568 .49069 .45754 .49036 .45647 .48924 Mtetra
.746 .785 .885 r
.45647 .48924 .45754 .49036 .4594 .48957 .45835 .48813 Mtetra
.911 .747 .664 r
.45835 .48813 .4594 .48957 .4613 .48704 .46029 .48334 Mtetra
.965 .687 .458 r
.46029 .48334 .4613 .48704 .46324 .48236 .46603 .27848 Mtetra
.546 .318 .52 r
.46603 .27848 .46324 .48236 .46871 .28243 .46793 .26955 Mtetra
.593 .388 .573 r
.46793 .26955 .46871 .28243 .47063 .27219 .4697 .26754 Mtetra
.628 .477 .658 r
.4697 .26754 .47063 .27219 .47242 .26874 .47145 .26642 Mtetra
.643 .583 .772 r
.47145 .26642 .47242 .26874 .47419 .26667 .4732 .26572 Mtetra
.669 .788 .937 r
.4732 .26572 .47419 .26667 .47594 .26585 .47495 .26507 Mtetra
.632 .814 .97 r
.47495 .26507 .47594 .26585 .47768 .26544 .4767 .26453 Mtetra
.625 .782 .957 r
.4767 .26453 .47768 .26544 .47943 .26518 .47844 .26403 Mtetra
.742 .767 .873 r
.47844 .26403 .47943 .26518 .48118 .2642 .4802 .26299 Mtetra
.7 .742 .885 r
.4802 .26299 .48118 .2642 .48294 .26332 .48195 .26218 Mtetra
.56 .704 .937 r
.48195 .26218 .48294 .26332 .48469 .26281 .4837 .26193 Mtetra
.764 .28 0 r
.4837 .26193 .48469 .26281 .48642 .26374 .48541 .2646 Mtetra
.967 .681 .437 r
.48541 .2646 .48642 .26374 .48814 .2664 .48471 .46538 Mtetra
.548 .314 .513 r
.48471 .46538 .48814 .2664 .48774 .45611 .48644 .47668 Mtetra
.544 .29 .481 r
.48644 .47668 .48774 .45611 .4894 .47416 .4883 .47789 Mtetra
.485 .143 .311 r
.4883 .47789 .4894 .47416 .49125 .47704 .49018 .47788 Mtetra
.096 0 0 r
.49018 .47788 .49125 .47704 .49311 .47826 .49206 .47739 Mtetra
.432 .724 .987 r
.49206 .47739 .49311 .47826 .49499 .47856 .49394 .47734 Mtetra
.595 .721 .932 r
.49394 .47734 .49499 .47856 .49687 .47823 .49583 .47695 Mtetra
.733 .757 .872 r
.49583 .47695 .49687 .47823 .49876 .4773 .49772 .47587 Mtetra
.903 .755 .688 r
.49772 .47587 .49876 .4773 .50066 .47501 .49964 .4718 Mtetra
.968 .687 .445 r
.49964 .4718 .50066 .47501 .50258 .47088 .50293 .2729 Mtetra
.561 .329 .522 r
.50293 .2729 .50258 .47088 .50455 .45602 .50481 .25711 Mtetra
.533 .307 .518 r
.50481 .25711 .50455 .45602 .50753 .26042 .50659 .25472 Mtetra
.613 .448 .635 r
.50659 .25472 .50753 .26042 .50932 .25653 .50836 .25358 Mtetra
.625 .533 .73 r
.50836 .25358 .50932 .25653 .5111 .25429 .51013 .25289 Mtetra
.67 .704 .873 r
.51013 .25289 .5111 .25429 .51287 .25322 .5119 .2522 Mtetra
.661 .774 .932 r
.5119 .2522 .51287 .25322 .51464 .25261 .51367 .25158 Mtetra
.65 .767 .934 r
.51367 .25158 .51464 .25261 .51641 .25216 .51545 .251 Mtetra
.741 .766 .874 r
.51545 .251 .51641 .25216 .51819 .25117 .51722 .24995 Mtetra
.714 .748 .879 r
.51722 .24995 .51819 .25117 .51996 .25021 .519 .24904 Mtetra
.591 .715 .93 r
.519 .24904 .51996 .25021 .52174 .24962 .52077 .24869 Mtetra
.643 .143 0 r
.52077 .24869 .52174 .24962 .52352 .25033 .52255 .2509 Mtetra
.969 .679 .422 r
.52255 .2509 .52352 .25033 .5253 .25273 .52429 .44456 Mtetra
.562 .325 .514 r
.52429 .44456 .5253 .25273 .52709 .26443 .5262 .4635 Mtetra
.53 .3 .511 r
.5262 .4635 .52709 .26443 .52913 .46093 .52811 .46512 Mtetra
.496 .163 .333 r
.52811 .46512 .52913 .46093 .53104 .46409 .53002 .46517 Mtetra
.188 0 0 r
.53002 .46517 .53104 .46409 .53296 .46542 .53193 .4647 Mtetra
.385 .736 .991 r
.53193 .4647 .53296 .46542 .53487 .46601 .53384 .46465 Mtetra
.568 .687 .921 r
.53384 .46465 .53487 .46601 .53679 .46586 .53576 .46438 Mtetra
.715 .724 .857 r
.53576 .46438 .53679 .46586 .5387 .4648 .53767 .46335 Mtetra
.911 .757 .678 r
.53767 .46335 .5387 .4648 .5406 .46042 .53957 .45904 Mtetra
.972 .688 .428 r
.53957 .45904 .5406 .46042 .5414 .25211 .54044 .25155 Mtetra
.977 .763 .546 r
.54044 .25155 .5414 .25211 .54315 .243 .54219 .24219 Mtetra
.875 .845 .812 r
.54219 .24219 .54315 .243 .54493 .24101 .54398 .24012 Mtetra
.657 .802 .952 r
.54398 .24012 .54493 .24101 .54672 .24049 .54577 .2395 Mtetra
.51 .719 .967 r
.54577 .2395 .54672 .24049 .54852 .24046 .54757 .23934 Mtetra
.689 .763 .909 r
.54757 .23934 .54852 .24046 .55031 .23988 .54936 .23859 Mtetra
.703 .735 .876 r
.54936 .23859 .55031 .23988 .55211 .23911 .55115 .23773 Mtetra
.594 .678 .899 r
.55115 .23773 .55211 .23911 .55391 .23864 .55296 .23738 Mtetra
0 .026 .567 r
.55296 .23738 .55391 .23864 .55572 .23925 .55478 .23934 Mtetra
.956 .629 .358 r
.55478 .23934 .55572 .23925 .55755 .24152 .55678 .25804 Mtetra
.952 .656 .438 r
.55678 .25804 .55755 .24152 .55947 .25112 .56073 .45217 Mtetra
.53 .3 .511 r
.56073 .45217 .55947 .25112 .56363 .44943 .56269 .45406 Mtetra
.499 .175 .348 r
.56269 .45406 .56363 .44943 .56561 .45282 .56463 .45412 Mtetra
.235 0 0 r
.56463 .45412 .56561 .45282 .56757 .45421 .56657 .45362 Mtetra
.418 .784 .995 r
.56657 .45362 .56757 .45421 .56952 .4547 .56851 .45343 Mtetra
.571 .705 .933 r
.56851 .45343 .56952 .4547 .57147 .45444 .57045 .45312 Mtetra
.721 .755 .879 r
.57045 .45312 .57147 .45444 .5734 .45329 .57239 .45211 Mtetra
.923 .788 .694 r
.57239 .45211 .5734 .45329 .57528 .44908 .57428 .44814 Mtetra
.975 .687 .415 r
.57428 .44814 .57528 .44908 .5739 .24082 .57298 .24134 Mtetra
.998 .788 .494 r
.57298 .24134 .5739 .24082 .57558 .23162 .57464 .23083 Mtetra
.895 .85 .79 r
.57464 .23083 .57558 .23162 .57736 .22941 .57642 .2285 Mtetra
.662 .801 .949 r
.57642 .2285 .57736 .22941 .57918 .22885 .57824 .22784 Mtetra
.512 .718 .966 r
.57824 .22784 .57918 .22885 .581 .2288 .58006 .22769 Mtetra
.592 .73 .94 r
.58006 .22769 .581 .2288 .58282 .22852 .58188 .22731 Mtetra
.666 .742 .907 r
.58188 .22731 .58282 .22852 .58464 .22789 .5837 .22665 Mtetra
.674 .739 .899 r
.5837 .22665 .58464 .22789 .58646 .22718 .58552 .22595 Mtetra
.74 .761 .87 r
.58552 .22595 .58646 .22718 .58827 .22603 .58733 .22487 Mtetra
.745 .777 .879 r
.58733 .22487 .58827 .22603 .59008 .22484 .58914 .22379 Mtetra
.631 .761 .941 r
.58914 .22379 .59008 .22484 .5919 .22422 .59097 .22327 Mtetra
0 .046 .549 r
.59097 .22327 .5919 .22422 .59377 .22586 .59285 .22503 Mtetra
.974 .677 .391 r
.59285 .22503 .59377 .22586 .59603 .24365 .59919 .42163 Mtetra
.563 .326 .513 r
.59919 .42163 .59603 .24365 .60259 .4415 .60159 .44041 Mtetra
0 0 .51 r
.60159 .44041 .60259 .4415 .60462 .4437 .60362 .44252 Mtetra
.5 .694 .955 r
.60362 .44252 .60462 .4437 .60659 .44359 .6056 .44241 Mtetra
.756 .792 .882 r
.6056 .44241 .60659 .44359 .60854 .44234 .60755 .44119 Mtetra
.922 .799 .707 r
.60755 .44119 .60854 .44234 .61042 .43847 .60943 .43749 Mtetra
.976 .685 .401 r
.60943 .43749 .61042 .43847 .60686 .23189 .60602 .2341 Mtetra
.99 .778 .394 r
.60602 .2341 .60686 .23189 .6084 .22022 .60748 .21943 Mtetra
.917 .848 .76 r
.60748 .21943 .6084 .22022 .61018 .21764 .60926 .21671 Mtetra
.68 .807 .943 r
.60926 .21671 .61018 .21764 .61201 .217 .61109 .21598 Mtetra
.529 .726 .964 r
.61109 .21598 .61201 .217 .61386 .2169 .61294 .21578 Mtetra
.575 .724 .943 r
.61294 .21578 .61386 .2169 .61571 .21667 .61479 .21545 Mtetra
.665 .743 .908 r
.61479 .21545 .61571 .21667 .61755 .21603 .61663 .21479 Mtetra
.674 .739 .9 r
.61663 .21479 .61755 .21603 .61939 .21532 .61847 .21408 Mtetra
.732 .76 .875 r
.61847 .21408 .61939 .21532 .62122 .21422 .6203 .21305 Mtetra
.751 .779 .875 r
.6203 .21305 .62122 .21422 .62304 .21298 .62213 .21191 Mtetra
.654 .768 .933 r
.62213 .21191 .62304 .21298 .62488 .21227 .62397 .21129 Mtetra
0 .256 .741 r
.62397 .21129 .62488 .21227 .62679 .21341 .62588 .21256 Mtetra
.941 .573 .211 r
.62588 .21256 .62679 .21341 .62895 .22189 .62808 .2224 Mtetra
.974 .673 .378 r
.62808 .2224 .62895 .22189 .63803 .42913 .63706 .42814 Mtetra
.616 .124 0 r
.63706 .42814 .63803 .42913 .64013 .43178 .63916 .43072 Mtetra
.485 .714 .972 r
.63916 .43072 .64013 .43178 .64214 .43157 .64117 .43061 Mtetra
.765 .84 .908 r
.64117 .43061 .64214 .43157 .64411 .43037 .64313 .42938 Mtetra
.934 .822 .712 r
.64313 .42938 .64411 .43037 .64602 .42773 .64501 .42575 Mtetra
.976 .682 .389 r
.64501 .42575 .64602 .42773 .64782 .42197 .63937 .22208 Mtetra
.555 .324 .52 r
.63937 .22208 .64782 .42197 .64204 .2197 .64074 .20842 Mtetra
.576 .38 .58 r
.64074 .20842 .64204 .2197 .64384 .21738 .64257 .20719 Mtetra
.162 .094 .526 r
.64257 .20719 .64384 .21738 .65376 .41953 .64474 .21418 Mtetra
0 0 .372 r
.64474 .21418 .65376 .41953 .65598 .4245 .65494 .4215 Mtetra
0 .112 .644 r
.65494 .4215 .65598 .4245 .65806 .42585 .65708 .42445 Mtetra
.557 .681 .922 r
.65708 .42445 .65806 .42585 .66007 .42534 .6591 .42421 Mtetra
.687 .785 .925 r
.6591 .42421 .66007 .42534 .66206 .42447 .66109 .42338 Mtetra
.628 .773 .95 r
.66109 .42338 .66206 .42447 .66407 .42398 .6631 .42281 Mtetra
.477 .685 .958 r
.6631 .42281 .66407 .42398 .6661 .42407 .66513 .42276 Mtetra
.645 .738 .917 r
.66513 .42276 .6661 .42407 .66811 .42357 .66714 .42213 Mtetra
.86 .777 .769 r
.66714 .42213 .66811 .42357 .67004 .42121 .66906 .41961 Mtetra
.969 .733 .527 r
.66906 .41961 .67004 .42121 .67164 .41136 .67061 .40868 Mtetra
.977 .68 .379 r
.67061 .40868 .67164 .41136 .66404 .20219 .66313 .20078 Mtetra
.912 .77 .69 r
.66313 .20078 .66404 .20219 .66577 .19836 .66487 .1971 Mtetra
.72 .759 .883 r
.66487 .1971 .66577 .19836 .66763 .19737 .66672 .19614 Mtetra
.594 .712 .926 r
.66672 .19614 .66763 .19737 .66951 .197 .66861 .19576 Mtetra
.623 .725 .919 r
.66861 .19576 .66951 .197 .6714 .1965 .6705 .19526 Mtetra
.738 .767 .876 r
.6705 .19526 .6714 .1965 .67325 .19543 .67235 .19418 Mtetra
.647 .735 .913 r
.67235 .19418 .67325 .19543 .67513 .19483 .67423 .19359 Mtetra
.099 .423 .868 r
.67423 .19359 .67513 .19483 .67709 .19577 .67619 .19453 Mtetra
.918 .543 .122 r
.67619 .19453 .67709 .19577 .67946 .20475 .67856 .20352 Mtetra
.975 .67 .349 r
.67856 .20352 .67946 .20475 .6921 .41193 .69114 .41074 Mtetra
.611 .15 0 r
.69114 .41074 .6921 .41193 .69431 .41499 .69336 .41379 Mtetra
.417 .651 .955 r
.69336 .41379 .69431 .41499 .69638 .41512 .69543 .41392 Mtetra
.711 .785 .909 r
.69543 .41392 .69638 .41512 .69839 .41416 .69744 .41296 Mtetra
.888 .815 .77 r
.69744 .41296 .69839 .41416 .70031 .41149 .69936 .41028 Mtetra
.978 .755 .532 r
.69936 .41028 .70031 .41149 .70186 .40207 .70091 .4008 Mtetra
.977 .678 .362 r
.70091 .4008 .70186 .40207 .69228 .19243 .69139 .19116 Mtetra
.935 .785 .671 r
.69139 .19116 .69228 .19243 .69398 .18833 .69309 .18707 Mtetra
.726 .763 .882 r
.69309 .18707 .69398 .18833 .69585 .18731 .69496 .18606 Mtetra
.595 .712 .925 r
.69496 .18606 .69585 .18731 .69776 .18692 .69687 .18567 Mtetra
.562 .698 .932 r
.69687 .18567 .69776 .18692 .69967 .1866 .69879 .18541 Mtetra
.679 .758 .911 r
.69879 .18541 .69967 .1866 .70155 .18572 .70068 .18466 Mtetra
.668 .782 .934 r
.70068 .18466 .70155 .18572 .70345 .18505 .70257 .18396 Mtetra
.658 .773 .934 r
.70257 .18396 .70345 .18505 .70538 .18489 .70447 .1833 Mtetra
.652 .68 .864 r
.70447 .1833 .70538 .18489 .70738 .1859 .70637 .18265 Mtetra
.562 .486 .727 r
.70637 .18265 .70738 .1859 .70949 .18862 .7083 .18247 Mtetra
.457 .339 .631 r
.7083 .18247 .70949 .18862 .72368 .38637 .71032 .18366 Mtetra
.497 .281 .515 r
.71032 .18366 .72368 .38637 .72655 .39899 .71319 .19843 Mtetra
0 0 .399 r
.71319 .19843 .72655 .39899 .72882 .40184 .72777 .39892 Mtetra
0 .147 .667 r
.72777 .39892 .72882 .40184 .73098 .40295 .73005 .40179 Mtetra
.375 .636 .957 r
.73005 .40179 .73098 .40295 .73308 .40303 .73216 .40202 Mtetra
.681 .816 .948 r
.73216 .40202 .73308 .40303 .73513 .40226 .7342 .4012 Mtetra
.878 .843 .807 r
.7342 .4012 .73513 .40226 .73708 .40008 .73615 .39888 Mtetra
.979 .766 .546 r
.73615 .39888 .73708 .40008 .73863 .39186 .73771 .39066 Mtetra
.977 .675 .344 r
.73771 .39066 .73863 .39186 .72656 .18079 .72568 .17952 Mtetra
.95 .785 .643 r
.72568 .17952 .72656 .18079 .7282 .17613 .72733 .17486 Mtetra
.739 .768 .877 r
.72733 .17486 .7282 .17613 .73009 .17503 .72921 .17376 Mtetra
.607 .716 .922 r
.72921 .17376 .73009 .17503 .73202 .17459 .73115 .17332 Mtetra
.548 .689 .932 r
.73115 .17332 .73202 .17459 .73396 .17434 .7331 .17311 Mtetra
.678 .753 .908 r
.7331 .17311 .73396 .17434 .73587 .17344 .73501 .17235 Mtetra
.669 .779 .932 r
.73501 .17235 .73587 .17344 .73778 .17273 .73693 .17164 Mtetra
.654 .773 .936 r
.73693 .17164 .73778 .17273 .73973 .17246 .73885 .17099 Mtetra
.66 .703 .879 r
.73885 .17099 .73973 .17246 .74177 .17337 .74077 .1703 Mtetra
.571 .502 .739 r
.74077 .1703 .74177 .17337 .74392 .17581 .74273 .17004 Mtetra
.48 .362 .641 r
.74273 .17004 .74392 .17581 .74724 .19393 .74476 .17088 Mtetra
.352 .199 .529 r
.74476 .17088 .74724 .19393 .76356 .38661 .74743 .18009 Mtetra
0 0 .41 r
.74743 .18009 .76356 .38661 .76592 .38976 .76484 .38645 Mtetra
0 .124 .643 r
.76484 .38645 .76592 .38976 .76814 .391 .76722 .38979 Mtetra
.345 .608 .947 r
.76722 .38979 .76814 .391 .77028 .39115 .76938 .39013 Mtetra
.657 .807 .955 r
.76938 .39013 .77028 .39115 .77236 .39047 .77145 .3894 Mtetra
.856 .848 .835 r
.77145 .3894 .77236 .39047 .77434 .38859 .77343 .38737 Mtetra
.979 .777 .562 r
.77343 .38737 .77434 .38859 .77591 .38135 .775 .38013 Mtetra
.976 .67 .326 r
.775 .38013 .77591 .38135 .76128 .16914 .76042 .16784 Mtetra
.962 .781 .612 r
.76042 .16784 .76128 .16914 .76284 .16379 .76199 .1625 Mtetra
.756 .774 .868 r
.76199 .1625 .76284 .16379 .76474 .16257 .76388 .16128 Mtetra
.625 .722 .916 r
.76388 .16128 .76474 .16257 .76669 .16205 .76583 .16076 Mtetra
.547 .684 .929 r
.76583 .16076 .76669 .16205 .76867 .16184 .76781 .16054 Mtetra
.744 .77 .874 r
.76781 .16054 .76867 .16184 .77057 .16069 .76972 .1594 Mtetra
.676 .745 .903 r
.76972 .1594 .77057 .16069 .77251 .15992 .77166 .15864 Mtetra
.463 .643 .935 r
.77166 .15864 .77251 .15992 .77451 .15998 .77366 .15871 Mtetra
.768 .353 0 r
.77366 .15871 .77451 .15998 .77696 .16519 .77611 .16395 Mtetra
.971 .656 .295 r
.77611 .16395 .77696 .16519 .79694 .37652 .79604 .37533 Mtetra
.729 .293 0 r
.79604 .37533 .79694 .37652 .79949 .38121 .7986 .38 Mtetra
.303 .581 .939 r
.7986 .38 .79949 .38121 .80169 .38168 .8008 .38046 Mtetra
.648 .766 .935 r
.8008 .38046 .80169 .38168 .8038 .381 .8029 .37978 Mtetra
.827 .824 .845 r
.8029 .37978 .8038 .381 .8058 .37918 .80491 .37796 Mtetra
.908 .739 .66 r
.13492 .5899 .13612 .59084 .13835 .58522 .13715 .58427 Mtetra
.936 .686 .535 r
.13715 .58427 .13835 .58522 .16278 .38298 .16167 .38198 Mtetra
.91 .728 .644 r
.16167 .38198 .16278 .38298 .16497 .37678 .16387 .37577 Mtetra
.772 .762 .844 r
.16387 .37577 .16497 .37678 .1666 .37559 .16549 .37457 Mtetra
.631 .735 .923 r
.16549 .37457 .1666 .37559 .16814 .37516 .16704 .37414 Mtetra
.491 .685 .953 r
.16704 .37414 .16814 .37516 .16964 .37511 .16854 .37408 Mtetra
.666 .743 .908 r
.16854 .37408 .16964 .37511 .1712 .37455 .1701 .37351 Mtetra
.676 .744 .902 r
.1701 .37351 .1712 .37455 .17276 .37394 .17166 .3729 Mtetra
.68 .745 .9 r
.17166 .3729 .17276 .37394 .17433 .3733 .17323 .37227 Mtetra
.762 .76 .85 r
.17323 .37227 .17433 .3733 .17596 .37212 .17486 .37115 Mtetra
.715 .765 .892 r
.17486 .37115 .17596 .37212 .17756 .37127 .17644 .37035 Mtetra
.51 .718 .966 r
.17644 .37035 .17756 .37127 .17908 .37109 .17796 .37022 Mtetra
.916 .524 .237 r
.17796 .37022 .17908 .37109 .18019 .37469 .17906 .37394 Mtetra
.939 .683 .522 r
.17906 .37394 .18019 .37469 .1601 .57591 .1589 .57513 Mtetra
.931 .587 .358 r
.1589 .57513 .1601 .57591 .16103 .58218 .15985 .58117 Mtetra
0 .374 .818 r
.15985 .58117 .16103 .58218 .16255 .58304 .16138 .58193 Mtetra
.639 .734 .917 r
.16138 .58193 .16255 .58304 .16421 .58258 .16304 .58143 Mtetra
.792 .755 .819 r
.16304 .58143 .16421 .58258 .16599 .58095 .16481 .5799 Mtetra
.894 .746 .69 r
.16481 .5799 .16599 .58095 .16822 .57499 .16687 .57564 Mtetra
.941 .689 .528 r
.16687 .57564 .16822 .57499 .19106 .3719 .1892 .37809 Mtetra
.904 .832 .369 r
.1892 .37809 .19106 .3719 .19317 .36621 .19182 .36757 Mtetra
.792 .954 .623 r
.19182 .36757 .19317 .36621 .19482 .36487 .19359 .36513 Mtetra
.776 .992 .882 r
.19359 .36513 .19482 .36487 .19638 .36444 .19524 .36383 Mtetra
.703 .843 .95 r
.19524 .36383 .19638 .36444 .1979 .3644 .19683 .3631 Mtetra
.517 .64 .91 r
.19683 .3631 .1979 .3644 .19946 .36393 .19836 .36305 Mtetra
.184 .565 .935 r
.19836 .36305 .19946 .36393 .20104 .36337 .19984 .36342 Mtetra
.484 0 0 r
.19984 .36342 .20104 .36337 .20262 .3628 .2013 .36403 Mtetra
.352 0 0 r
.2013 .36403 .20262 .3628 .20419 .36224 .20283 .36391 Mtetra
.264 0 .023 r
.20283 .36391 .20419 .36224 .20577 .36168 .20441 .36338 Mtetra
.202 0 0 r
.20441 .36338 .20577 .36168 .20735 .36113 .206 .36269 Mtetra
.223 0 0 r
.206 .36269 .20735 .36113 .20893 .36056 .20759 .36211 Mtetra
.23 0 0 r
.20759 .36211 .20893 .36056 .21051 .35999 .20917 .36155 Mtetra
.231 0 0 r
.20917 .36155 .21051 .35999 .2121 .35942 .21075 .36099 Mtetra
.235 0 0 r
.21075 .36099 .2121 .35942 .21368 .35885 .21234 .36044 Mtetra
.239 0 0 r
.21234 .36044 .21368 .35885 .21527 .35827 .21392 .35988 Mtetra
.242 0 0 r
.21392 .35988 .21527 .35827 .21685 .3577 .21551 .35932 Mtetra
.302 0 .039 r
.21551 .35932 .21685 .3577 .21844 .35714 .21708 .35892 Mtetra
.302 0 .065 r
.21708 .35892 .21844 .35714 .22003 .35658 .21866 .35845 Mtetra
.227 0 .032 r
.21866 .35845 .22003 .35658 .22161 .35604 .22027 .35773 Mtetra
0 0 0 r
.22027 .35773 .22161 .35604 .2232 .35553 .22194 .35627 Mtetra
.709 .972 .744 r
.22194 .35627 .2232 .35553 .22478 .35503 .22363 .3547 Mtetra
.827 .902 .892 r
.22363 .3547 .22478 .35503 .22637 .35451 .2253 .35334 Mtetra
.714 .732 .865 r
.2253 .35334 .22637 .35451 .22796 .35392 .22692 .3525 Mtetra
.658 .676 .856 r
.22692 .3525 .22796 .35392 .22956 .35328 .22851 .35192 Mtetra
.637 .678 .872 r
.22851 .35192 .22956 .35328 .23116 .35263 .2301 .35144 Mtetra
.641 .709 .897 r
.2301 .35144 .23116 .35263 .23277 .35195 .23168 .35096 Mtetra
.644 .749 .926 r
.23168 .35096 .23277 .35195 .23437 .35131 .23327 .35046 Mtetra
.646 .781 .946 r
.23327 .35046 .23437 .35131 .23596 .35079 .23487 .34995 Mtetra
.741 .801 .9 r
.23487 .34995 .23596 .35079 .23756 .35028 .2365 .34903 Mtetra
.712 .72 .856 r
.2365 .34903 .23756 .35028 .23913 .35006 .23812 .34818 Mtetra
.608 .597 .814 r
.23812 .34818 .23913 .35006 .24063 .3505 .23971 .34781 Mtetra
.056 .18 .678 r
.23971 .34781 .24063 .3505 .24181 .35466 .2411 .3495 Mtetra
.852 .606 .066 r
.2411 .3495 .24181 .35466 .22551 .55621 .24191 .35791 Mtetra
0 0 .149 r
.24191 .35791 .22551 .55621 .22672 .56127 .22588 .55667 Mtetra
.153 .153 .605 r
.22588 .55667 .22672 .56127 .2283 .56215 .22732 .55916 Mtetra
.445 .425 .743 r
.22732 .55916 .2283 .56215 .23 .56175 .22893 .55969 Mtetra
.545 .561 .821 r
.22893 .55969 .23 .56175 .23174 .56083 .2306 .55962 Mtetra
.502 .669 .938 r
.2306 .55962 .23174 .56083 .23347 .56007 .23227 .55956 Mtetra
.493 .823 .999 r
.23227 .55956 .23347 .56007 .23521 .55918 .23396 .55926 Mtetra
.623 .953 .925 r
.23396 .55926 .23521 .55918 .23701 .55763 .2357 .55836 Mtetra
.927 .973 .74 r
.2357 .55836 .23701 .55763 .23908 .55289 .23761 .55556 Mtetra
.986 .88 .534 r
.23761 .55556 .23908 .55289 .25777 .35056 .23991 .54806 Mtetra
0 0 .137 r
.23991 .54806 .25777 .35056 .25993 .34358 .25853 .34641 Mtetra
.642 .778 .317 r
.25853 .34641 .25993 .34358 .26165 .34163 .26042 .34255 Mtetra
.579 .898 .635 r
.26042 .34255 .26165 .34163 .26327 .34108 .26211 .34104 Mtetra
.68 .957 .948 r
.26211 .34104 .26327 .34108 .26484 .341 .26375 .34015 Mtetra
.67 .789 .938 r
.26375 .34015 .26484 .341 .26643 .34078 .26537 .33955 Mtetra
.628 .698 .896 r
.26537 .33955 .26643 .34078 .26803 .34038 .26698 .33911 Mtetra
.598 .682 .9 r
.26698 .33911 .26803 .34038 .26964 .33995 .26858 .33879 Mtetra
.616 .709 .911 r
.26858 .33879 .26964 .33995 .27125 .33947 .27018 .33839 Mtetra
.64 .733 .916 r
.27018 .33839 .27125 .33947 .27286 .33894 .2718 .33791 Mtetra
.652 .745 .918 r
.2718 .33791 .27286 .33894 .27449 .33837 .27342 .33737 Mtetra
.668 .759 .919 r
.27342 .33737 .27449 .33837 .27611 .33774 .27504 .33677 Mtetra
.682 .768 .917 r
.27504 .33677 .27611 .33774 .27774 .33707 .27667 .33612 Mtetra
.69 .774 .915 r
.27667 .33612 .27774 .33707 .27938 .33636 .27831 .33543 Mtetra
.695 .778 .915 r
.27831 .33543 .27938 .33636 .28102 .33555 .27994 .33471 Mtetra
.699 .801 .928 r
.27994 .33471 .28102 .33555 .28267 .33471 .28158 .33398 Mtetra
.703 .825 .941 r
.28158 .33398 .28267 .33471 .28431 .33399 .28322 .33324 Mtetra
.709 .822 .935 r
.28322 .33324 .28431 .33399 .28592 .33363 .28486 .33247 Mtetra
.701 .736 .878 r
.28486 .33247 .28592 .33363 .28751 .33361 .28651 .3317 Mtetra
.668 .622 .794 r
.28651 .3317 .28751 .33361 .28909 .33368 .28815 .33094 Mtetra
.635 .544 .734 r
.28815 .33094 .28909 .33368 .29069 .33344 .28979 .33024 Mtetra
.619 .512 .71 r
.28979 .33024 .29069 .33344 .29233 .33282 .29143 .32958 Mtetra
.616 .508 .709 r
.29143 .32958 .29233 .33282 .29397 .33209 .29307 .32896 Mtetra
.616 .513 .714 r
.29307 .32896 .29397 .33209 .29562 .33141 .29471 .32834 Mtetra
.617 .517 .718 r
.29471 .32834 .29562 .33141 .29726 .33079 .29634 .32774 Mtetra
.616 .517 .719 r
.29634 .32774 .29726 .33079 .29889 .33019 .29798 .32714 Mtetra
.615 .517 .719 r
.29798 .32714 .29889 .33019 .30053 .3296 .29962 .32656 Mtetra
.614 .517 .72 r
.29962 .32656 .30053 .3296 .30217 .32902 .30126 .32598 Mtetra
.614 .516 .72 r
.30126 .32598 .30217 .32902 .30381 .32845 .3029 .32541 Mtetra
.613 .516 .72 r
.3029 .32541 .30381 .32845 .30545 .32788 .30454 .32484 Mtetra
.30454 .32484 .30545 .32788 .30709 .32731 .30618 .32427 Mtetra
.613 .516 .721 r
.30618 .32427 .30709 .32731 .30873 .32674 .30782 .32371 Mtetra
.613 .517 .721 r
.30782 .32371 .30873 .32674 .31038 .32618 .30946 .32315 Mtetra
.30946 .32315 .31038 .32618 .31202 .32561 .3111 .32258 Mtetra
.614 .517 .721 r
.3111 .32258 .31202 .32561 .31367 .32503 .31275 .322 Mtetra
.31275 .322 .31367 .32503 .31531 .32446 .31439 .32143 Mtetra
.615 .518 .721 r
.31439 .32143 .31531 .32446 .31696 .32388 .31604 .32085 Mtetra
.31604 .32085 .31696 .32388 .31861 .32329 .31769 .32026 Mtetra
.31769 .32026 .31861 .32329 .32026 .32271 .31934 .31967 Mtetra
.616 .518 .721 r
.31934 .31967 .32026 .32271 .32191 .32212 .32099 .31908 Mtetra
.32099 .31908 .32191 .32212 .32357 .32153 .32265 .31849 Mtetra
.616 .519 .721 r
.32265 .31849 .32357 .32153 .32522 .32093 .3243 .31789 Mtetra
.3243 .31789 .32522 .32093 .32688 .32033 .32595 .3173 Mtetra
.32595 .3173 .32688 .32033 .32853 .31974 .32761 .3167 Mtetra
.32761 .3167 .32853 .31974 .33019 .31914 .32927 .3161 Mtetra
.616 .518 .72 r
.32927 .3161 .33019 .31914 .33185 .31855 .33092 .3155 Mtetra
.33092 .3155 .33185 .31855 .33351 .31796 .33258 .3149 Mtetra
.33258 .3149 .33351 .31796 .33516 .31742 .33424 .3143 Mtetra
.615 .514 .717 r
.33424 .3143 .33516 .31742 .33682 .31692 .3359 .3137 Mtetra
.611 .507 .711 r
.3359 .3137 .33682 .31692 .33848 .3163 .33757 .31311 Mtetra
.608 .507 .714 r
.33757 .31311 .33848 .3163 .34017 .31534 .33923 .31256 Mtetra
.611 .53 .738 r
.33923 .31256 .34017 .31534 .34187 .31402 .34088 .31205 Mtetra
.629 .602 .804 r
.34088 .31205 .34187 .31402 .34357 .31277 .34254 .31154 Mtetra
.65 .712 .893 r
.34254 .31154 .34357 .31277 .34526 .31178 .34421 .31099 Mtetra
.661 .808 .954 r
.34421 .31099 .34526 .31178 .34693 .31113 .34587 .31039 Mtetra
.669 .824 .958 r
.34587 .31039 .34693 .31113 .3486 .31056 .34754 .30976 Mtetra
.695 .814 .939 r
.34754 .30976 .3486 .31056 .35026 .30999 .34922 .30903 Mtetra
.714 .784 .907 r
.34922 .30903 .35026 .30999 .35194 .30935 .3509 .30821 Mtetra
.688 .742 .892 r
.3509 .30821 .35194 .30935 .35361 .30871 .35258 .30749 Mtetra
.612 .703 .909 r
.35258 .30749 .35361 .30871 .35528 .30806 .35424 .3071 Mtetra
.374 .654 .966 r
.35424 .3071 .35528 .30806 .35696 .30742 .35587 .30725 Mtetra
.173 0 0 r
.35587 .30725 .35696 .30742 .35863 .30678 .3575 .30758 Mtetra
.302 0 0 r
.3575 .30758 .35863 .30678 .36032 .30601 .35915 .30753 Mtetra
.054 0 0 r
.35915 .30753 .36032 .30601 .36201 .30508 .36084 .30653 Mtetra
.216 0 0 r
.36084 .30653 .36201 .30508 .36368 .30453 .36252 .30594 Mtetra
.656 .233 .229 r
.36252 .30594 .36368 .30453 .3653 .30518 .3641 .30723 Mtetra
.955 .681 .478 r
.3641 .30723 .3653 .30518 .3667 .31007 .35561 .50686 Mtetra
.546 .313 .514 r
.35561 .50686 .3667 .31007 .35817 .51387 .35686 .51685 Mtetra
.681 .325 .363 r
.35686 .51685 .35817 .51387 .35973 .51799 .35852 .51907 Mtetra
.322 0 0 r
.35852 .51907 .35973 .51799 .3615 .51785 .36029 .51896 Mtetra
.087 0 0 r
.36029 .51896 .3615 .51785 .36331 .51703 .36209 .5183 Mtetra
.069 0 0 r
.36209 .5183 .36331 .51703 .36511 .5163 .3639 .5175 Mtetra
.161 0 0 r
.3639 .5175 .36511 .5163 .36687 .51647 .3657 .51694 Mtetra
0 0 0 r
.3657 .51694 .36687 .51647 .36864 .51657 .36751 .51624 Mtetra
.676 .924 .973 r
.36751 .51624 .36864 .51657 .37042 .51656 .36932 .51539 Mtetra
.733 .764 .878 r
.36932 .51539 .37042 .51656 .3722 .51641 .37115 .51436 Mtetra
.747 .66 .765 r
.37115 .51436 .3722 .51641 .37401 .51576 .373 .51277 Mtetra
.793 .628 .677 r
.373 .51277 .37401 .51576 .37587 .51392 .37492 .50947 Mtetra
.956 .686 .483 r
.37492 .50947 .37587 .51392 .37792 .50784 .38562 .30902 Mtetra
.553 .324 .522 r
.38562 .30902 .37792 .50784 .38865 .30259 .38781 .29722 Mtetra
.714 .522 .629 r
.38781 .29722 .38865 .30259 .39055 .29707 .38962 .29404 Mtetra
.651 .541 .717 r
.38962 .29404 .39055 .29707 .39227 .29605 .39133 .2931 Mtetra
.596 .513 .731 r
.39133 .2931 .39227 .29605 .39395 .2957 .39302 .29268 Mtetra
.57 .494 .73 r
.39302 .29268 .39395 .2957 .39564 .29536 .3947 .29246 Mtetra
.603 .52 .734 r
.3947 .29246 .39564 .29536 .39736 .29413 .39639 .29199 Mtetra
.615 .582 .793 r
.39639 .29199 .39736 .29413 .39909 .29293 .39808 .29154 Mtetra
.631 .682 .88 r
.39808 .29154 .39909 .29293 .4008 .29191 .39978 .29106 Mtetra
.643 .795 .955 r
.39978 .29106 .4008 .29191 .40251 .29126 .40148 .29051 Mtetra
.65 .821 .965 r
.40148 .29051 .40251 .29126 .40421 .29072 .40318 .28993 Mtetra
.667 .815 .954 r
.40318 .28993 .40421 .29072 .40591 .29022 .40489 .28929 Mtetra
.686 .787 .927 r
.40489 .28929 .40591 .29022 .40761 .2897 .40659 .28858 Mtetra
.687 .752 .901 r
.40659 .28858 .40761 .2897 .40931 .28916 .4083 .28787 Mtetra
.683 .717 .875 r
.4083 .28787 .40931 .28916 .41102 .2886 .41002 .28714 Mtetra
.682 .691 .852 r
.41002 .28714 .41102 .2886 .41272 .28799 .41173 .28639 Mtetra
.66 .663 .842 r
.41173 .28639 .41272 .28799 .41443 .28734 .41344 .28574 Mtetra
.617 .645 .855 r
.41344 .28574 .41443 .28734 .41615 .28667 .41514 .28531 Mtetra
.444 .604 .914 r
.41514 .28531 .41615 .28667 .41786 .28597 .41683 .28547 Mtetra
.014 .538 .857 r
.41683 .28547 .41786 .28597 .41958 .28526 .41851 .28583 Mtetra
.421 0 0 r
.41851 .28583 .41958 .28526 .42129 .28455 .42019 .28618 Mtetra
.289 0 .035 r
.42019 .28618 .42129 .28455 .42301 .28387 .4219 .28568 Mtetra
.236 0 .039 r
.4219 .28568 .42301 .28387 .42473 .28321 .42363 .28493 Mtetra
.168 0 0 r
.42363 .28493 .42473 .28321 .42644 .28252 .42535 .28403 Mtetra
0 0 0 r
.42535 .28403 .42644 .28252 .42817 .28151 .42709 .28281 Mtetra
.145 0 0 r
.42709 .28281 .42817 .28151 .42989 .28085 .42882 .28211 Mtetra
.519 .06 .103 r
.42882 .28211 .42989 .28085 .43159 .28094 .4305 .2826 Mtetra
.923 .606 .425 r
.4305 .2826 .43159 .28094 .43318 .28471 .43175 .29783 Mtetra
.946 .664 .471 r
.43175 .29783 .43318 .28471 .42897 .489 .42774 .49322 Mtetra
.691 .356 .402 r
.42774 .49322 .42897 .489 .43061 .49526 .42948 .49628 Mtetra
.32 0 0 r
.42948 .49628 .43061 .49526 .43244 .4954 .43131 .49619 Mtetra
0 0 0 r
.43131 .49619 .43244 .4954 .43429 .49465 .43316 .49549 Mtetra
.43316 .49549 .43429 .49465 .43615 .49345 .43502 .49452 Mtetra
.158 0 0 r
.43502 .49452 .43615 .49345 .438 .49271 .43686 .49401 Mtetra
.213 0 0 r
.43686 .49401 .438 .49271 .43985 .49204 .43871 .49349 Mtetra
.23 0 0 r
.43871 .49349 .43985 .49204 .44169 .49156 .44056 .49292 Mtetra
.163 0 0 r
.44056 .49292 .44169 .49156 .44352 .49166 .44241 .49223 Mtetra
0 0 0 r
.44241 .49223 .44352 .49166 .44536 .49177 .44427 .49151 Mtetra
.593 .917 .973 r
.44427 .49151 .44536 .49177 .4472 .49172 .44613 .49079 Mtetra
.617 .785 .962 r
.44613 .49079 .4472 .49172 .44905 .49116 .44798 .49029 Mtetra
.633 .803 .964 r
.44798 .49029 .44905 .49116 .45091 .49048 .44984 .48972 Mtetra
.673 .84 .963 r
.44984 .48972 .45091 .49048 .45277 .48975 .4517 .48898 Mtetra
.723 .85 .942 r
.4517 .48898 .45277 .48975 .45462 .48966 .45356 .48804 Mtetra
.76 .713 .808 r
.45356 .48804 .45462 .48966 .45647 .48924 .45544 .48658 Mtetra
.776 .637 .707 r
.45544 .48658 .45647 .48924 .45835 .48813 .45734 .48407 Mtetra
.902 .66 .563 r
.45734 .48407 .45835 .48813 .46029 .48334 .45946 .47083 Mtetra
.955 .676 .468 r
.45946 .47083 .46029 .48334 .46603 .27848 .46517 .27046 Mtetra
.691 .482 .599 r
.46517 .27046 .46603 .27848 .46793 .26955 .46698 .26645 Mtetra
.662 .546 .713 r
.46698 .26645 .46793 .26955 .4697 .26754 .46873 .26535 Mtetra
.614 .579 .791 r
.46873 .26535 .4697 .26754 .47145 .26642 .47047 .26488 Mtetra
.557 .63 .879 r
.47047 .26488 .47145 .26642 .4732 .26572 .47221 .26471 Mtetra
.693 .779 .917 r
.47221 .26471 .4732 .26572 .47495 .26507 .47396 .26396 Mtetra
.689 .757 .904 r
.47396 .26396 .47495 .26507 .4767 .26453 .47571 .26321 Mtetra
.654 .709 .887 r
.47571 .26321 .4767 .26453 .47844 .26403 .47746 .26262 Mtetra
.605 .672 .888 r
.47746 .26262 .47844 .26403 .4802 .26299 .47921 .26224 Mtetra
.348 .697 .983 r
.47921 .26224 .4802 .26299 .48195 .26218 .48095 .26231 Mtetra
.552 0 0 r
.48095 .26231 .48195 .26218 .4837 .26193 .48269 .26326 Mtetra
.895 .543 .369 r
.48269 .26326 .4837 .26193 .48541 .2646 .48433 .2712 Mtetra
.96 .673 .446 r
.48433 .2712 .48541 .2646 .48471 .46538 .48354 .4744 Mtetra
.641 .346 .455 r
.48354 .4744 .48471 .46538 .48644 .47668 .48536 .47803 Mtetra
.473 .007 .066 r
.48536 .47803 .48644 .47668 .4883 .47789 .48724 .47835 Mtetra
0 0 0 r
.48724 .47835 .4883 .47789 .49018 .47788 .48912 .47777 Mtetra
.694 .967 .934 r
.48912 .47777 .49018 .47788 .49206 .47739 .49101 .47667 Mtetra
.725 .865 .947 r
.49101 .47667 .49206 .47739 .49394 .47734 .4929 .4757 Mtetra
.751 .712 .815 r
.4929 .4757 .49394 .47734 .49583 .47695 .49479 .47433 Mtetra
.768 .637 .716 r
.49479 .47433 .49583 .47695 .49772 .47587 .4967 .47203 Mtetra
.878 .651 .591 r
.4967 .47203 .49772 .47587 .49964 .4718 .49865 .46327 Mtetra
.963 .68 .452 r
.49865 .46327 .49964 .4718 .50293 .2729 .50205 .25826 Mtetra
.64 .419 .567 r
.50205 .25826 .50293 .2729 .50481 .25711 .50385 .25367 Mtetra
.673 .54 .695 r
.50385 .25367 .50481 .25711 .50659 .25472 .50562 .2523 Mtetra
.615 .562 .772 r
.50562 .2523 .50659 .25472 .50836 .25358 .50739 .2518 Mtetra
.557 .597 .849 r
.50739 .2518 .50836 .25358 .51013 .25289 .50916 .25164 Mtetra
.654 .724 .9 r
.50916 .25164 .51013 .25289 .5119 .2522 .51093 .25105 Mtetra
.673 .748 .907 r
.51093 .25105 .5119 .2522 .51367 .25158 .5127 .25037 Mtetra
.647 .728 .908 r
.5127 .25037 .51367 .25158 .51545 .251 .51448 .2498 Mtetra
.622 .722 .918 r
.51448 .2498 .51545 .251 .51722 .24995 .51625 .24934 Mtetra
.389 .755 .992 r
.51625 .24934 .51722 .24995 .519 .24904 .51803 .24925 Mtetra
.475 0 0 r
.51803 .24925 .519 .24904 .52077 .24869 .5198 .24996 Mtetra
.878 .506 .336 r
.5198 .24996 .52077 .24869 .52255 .2509 .52158 .25621 Mtetra
.964 .674 .431 r
.52158 .25621 .52255 .2509 .52429 .44456 .52326 .46104 Mtetra
.604 .333 .48 r
.52326 .46104 .52429 .44456 .5262 .4635 .52517 .46506 Mtetra
.513 .065 .122 r
.52517 .46506 .5262 .4635 .52811 .46512 .52708 .46555 Mtetra
0 0 0 r
.52708 .46555 .52811 .46512 .53002 .46517 .52899 .46492 Mtetra
.731 .96 .942 r
.52899 .46492 .53002 .46517 .53193 .4647 .5309 .46376 Mtetra
.726 .823 .925 r
.5309 .46376 .53193 .4647 .53384 .46465 .53281 .46278 Mtetra
.719 .676 .807 r
.53281 .46278 .53384 .46465 .53576 .46438 .53473 .46158 Mtetra
.74 .615 .719 r
.53473 .46158 .53576 .46438 .53767 .46335 .53664 .45959 Mtetra
.85 .638 .615 r
.53664 .45959 .53767 .46335 .53957 .45904 .53853 .4532 Mtetra
.968 .683 .435 r
.53853 .4532 .53957 .45904 .54044 .25155 .53946 .2465 Mtetra
.793 .578 .61 r
.53946 .2465 .54044 .25155 .54219 .24219 .54123 .24099 Mtetra
.823 .779 .811 r
.54123 .24099 .54219 .24219 .54398 .24012 .54302 .23921 Mtetra
.671 .801 .944 r
.54302 .23921 .54398 .24012 .54577 .2395 .54481 .23853 Mtetra
.559 .748 .965 r
.54481 .23853 .54577 .2395 .54757 .23934 .54661 .23823 Mtetra
.715 .773 .898 r
.54661 .23823 .54757 .23934 .54936 .23859 .54841 .23734 Mtetra
.714 .747 .879 r
.54841 .23734 .54936 .23859 .55115 .23773 .5502 .23643 Mtetra
.579 .686 .914 r
.5502 .23643 .55115 .23773 .55296 .23738 .552 .23613 Mtetra
.645 .192 0 r
.552 .23613 .55296 .23738 .55478 .23934 .55383 .23887 Mtetra
.972 .679 .408 r
.55383 .23887 .55478 .23934 .55678 .25804 .55772 .44576 Mtetra
.542 .309 .511 r
.55772 .44576 .55678 .25804 .56073 .45217 .55974 .45354 Mtetra
.593 .134 .131 r
.55974 .45354 .56073 .45217 .56269 .45406 .56169 .45455 Mtetra
0 0 0 r
.56169 .45455 .56269 .45406 .56463 .45412 .56362 .4539 Mtetra
.72 .966 .938 r
.56362 .4539 .56463 .45412 .56657 .45362 .56555 .45273 Mtetra
.581 .792 .979 r
.56555 .45273 .56657 .45362 .56851 .45343 .5675 .4523 Mtetra
.535 .719 .957 r
.5675 .4523 .56851 .45343 .57045 .45312 .56944 .45208 Mtetra
.696 .797 .928 r
.56944 .45208 .57045 .45312 .57239 .45211 .57138 .45123 Mtetra
.934 .824 .712 r
.57138 .45123 .57239 .45211 .57428 .44814 .57328 .44757 Mtetra
.975 .687 .414 r
.57328 .44757 .57428 .44814 .57298 .24134 .5721 .24412 Mtetra
.985 .787 .386 r
.5721 .24412 .57298 .24134 .57464 .23083 .5737 .22998 Mtetra
.9 .837 .775 r
.5737 .22998 .57464 .23083 .57642 .2285 .57549 .22748 Mtetra
.682 .786 .929 r
.57549 .22748 .57642 .2285 .57824 .22784 .5773 .22675 Mtetra
.543 .716 .952 r
.5773 .22675 .57824 .22784 .58006 .22769 .57912 .22653 Mtetra
.623 .735 .928 r
.57912 .22653 .58006 .22769 .58188 .22731 .58094 .22605 Mtetra
.68 .736 .893 r
.58094 .22605 .58188 .22731 .5837 .22665 .58276 .22531 Mtetra
.658 .715 .89 r
.58276 .22531 .5837 .22665 .58552 .22595 .58458 .22468 Mtetra
.637 .719 .907 r
.58458 .22468 .58552 .22595 .58733 .22487 .5864 .22415 Mtetra
.504 .785 .996 r
.5864 .22415 .58733 .22487 .58914 .22379 .58823 .22389 Mtetra
.28 0 0 r
.58823 .22389 .58914 .22379 .59097 .22327 .59008 .22427 Mtetra
.813 .385 .228 r
.59008 .22427 .59097 .22327 .59285 .22503 .592 .22768 Mtetra
.971 .674 .398 r
.592 .22768 .59285 .22503 .59919 .42163 .5985 .4339 Mtetra
.662 .371 .468 r
.5985 .4339 .59919 .42163 .60159 .44041 .60061 .43981 Mtetra
.467 0 0 r
.60061 .43981 .60159 .44041 .60362 .44252 .60262 .44129 Mtetra
.516 .691 .947 r
.60262 .44129 .60362 .44252 .6056 .44241 .6046 .44115 Mtetra
.741 .773 .879 r
.6046 .44115 .6056 .44241 .60755 .44119 .60655 .44001 Mtetra
.916 .796 .714 r
.60655 .44001 .60755 .44119 .60943 .43749 .60844 .43645 Mtetra
.976 .685 .402 r
.60844 .43645 .60943 .43749 .60602 .2341 .60523 .23852 Mtetra
.967 .757 .32 r
.60523 .23852 .60602 .2341 .60748 .21943 .60656 .2185 Mtetra
.911 .826 .749 r
.60656 .2185 .60748 .21943 .60926 .21671 .60833 .21568 Mtetra
.695 .79 .923 r
.60833 .21568 .60926 .21671 .61109 .21598 .61017 .21489 Mtetra
.559 .723 .95 r
.61017 .21489 .61109 .21598 .61294 .21578 .61202 .21461 Mtetra
.606 .729 .932 r
.61202 .21461 .61294 .21578 .61479 .21545 .61386 .21419 Mtetra
.681 .738 .894 r
.61386 .21419 .61479 .21545 .61663 .21479 .6157 .21344 Mtetra
.661 .716 .89 r
.6157 .21344 .61663 .21479 .61847 .21408 .61754 .21278 Mtetra
.64 .718 .904 r
.61754 .21278 .61847 .21408 .6203 .21305 .61939 .21223 Mtetra
.545 .782 .986 r
.61939 .21223 .6203 .21305 .62213 .21191 .62124 .2119 Mtetra
.153 0 0 r
.62124 .2119 .62213 .21191 .62397 .21129 .62312 .21216 Mtetra
.772 .314 .16 r
.62312 .21216 .62397 .21129 .62588 .21256 .62507 .21476 Mtetra
.973 .672 .383 r
.62507 .21476 .62588 .21256 .62808 .2224 .63385 .42022 Mtetra
.54 .307 .511 r
.63385 .42022 .62808 .2224 .63706 .42814 .63611 .4278 Mtetra
.624 .065 0 r
.63611 .4278 .63706 .42814 .63916 .43072 .63818 .42964 Mtetra
.451 .692 .969 r
.63818 .42964 .63916 .43072 .64117 .43061 .64019 .42963 Mtetra
.738 .83 .921 r
.64019 .42963 .64117 .43061 .64313 .42938 .64217 .42855 Mtetra
.947 .838 .703 r
.64217 .42855 .64313 .42938 .64501 .42575 .64404 .42477 Mtetra
.977 .683 .386 r
.64404 .42477 .64501 .42575 .63937 .22208 .63823 .21498 Mtetra
.819 .574 .568 r
.63823 .21498 .63937 .22208 .64074 .20842 .63976 .20554 Mtetra
.714 .591 .716 r
.63976 .20554 .64074 .20842 .64257 .20719 .64158 .20389 Mtetra
.097 .18 .662 r
.64158 .20389 .64257 .20719 .64474 .21418 .64357 .20645 Mtetra
.978 .679 .348 r
.64357 .20645 .64474 .21418 .65494 .4215 .65359 .41099 Mtetra
.007 0 .482 r
.65359 .41099 .65494 .4215 .65708 .42445 .656 .42048 Mtetra
.414 .371 .702 r
.656 .42048 .65708 .42445 .6591 .42421 .65807 .42157 Mtetra
.511 .506 .786 r
.65807 .42157 .6591 .42421 .66109 .42338 .6601 .42172 Mtetra
.516 .617 .891 r
.6601 .42172 .66109 .42338 .6631 .42281 .66213 .42169 Mtetra
.474 .697 .966 r
.66213 .42169 .6631 .42281 .66513 .42276 .66416 .42163 Mtetra
.674 .782 .931 r
.66416 .42163 .66513 .42276 .66714 .42213 .66617 .42086 Mtetra
.881 .801 .766 r
.66617 .42086 .66714 .42213 .66906 .41961 .66809 .41818 Mtetra
.974 .735 .514 r
.66809 .41818 .66906 .41961 .67061 .40868 .6696 .40642 Mtetra
.977 .68 .378 r
.6696 .40642 .67061 .40868 .66313 .20078 .66222 .19945 Mtetra
.915 .778 .695 r
.66222 .19945 .66313 .20078 .66487 .1971 .66396 .19585 Mtetra
.718 .76 .885 r
.66396 .19585 .66487 .1971 .66672 .19614 .66582 .19489 Mtetra
.594 .712 .926 r
.66582 .19489 .66672 .19614 .66861 .19576 .66771 .19451 Mtetra
.624 .725 .919 r
.66771 .19451 .66861 .19576 .6705 .19526 .66959 .19401 Mtetra
.737 .767 .877 r
.66959 .19401 .6705 .19526 .67235 .19418 .67145 .19294 Mtetra
.647 .735 .913 r
.67145 .19294 .67235 .19418 .67423 .19359 .67333 .19234 Mtetra
.099 .423 .868 r
.67333 .19234 .67423 .19359 .67619 .19453 .67529 .19329 Mtetra
.918 .543 .122 r
.67529 .19329 .67619 .19453 .67856 .20352 .67766 .20227 Mtetra
.975 .67 .349 r
.67766 .20227 .67856 .20352 .69114 .41074 .69019 .40955 Mtetra
.61 .149 0 r
.69019 .40955 .69114 .41074 .69336 .41379 .6924 .4126 Mtetra
.416 .651 .955 r
.6924 .4126 .69336 .41379 .69543 .41392 .69447 .41273 Mtetra
.713 .787 .91 r
.69447 .41273 .69543 .41392 .69744 .41296 .69649 .41176 Mtetra
.892 .815 .765 r
.69649 .41176 .69744 .41296 .69936 .41028 .6984 .40901 Mtetra
.978 .748 .52 r
.6984 .40901 .69936 .41028 .70091 .4008 .6999 .39858 Mtetra
.977 .677 .364 r
.6999 .39858 .70091 .4008 .69139 .19116 .69047 .18946 Mtetra
.903 .745 .675 r
.69047 .18946 .69139 .19116 .69309 .18707 .69218 .18555 Mtetra
.7 .71 .856 r
.69218 .18555 .69309 .18707 .69496 .18606 .69406 .18463 Mtetra
.578 .67 .902 r
.69406 .18463 .69496 .18606 .69687 .18567 .69598 .18433 Mtetra
.538 .668 .921 r
.69598 .18433 .69687 .18567 .69879 .18541 .6979 .18417 Mtetra
.658 .743 .913 r
.6979 .18417 .69879 .18541 .70068 .18466 .6998 .18352 Mtetra
.67 .767 .923 r
.6998 .18352 .70068 .18466 .70257 .18396 .70169 .18281 Mtetra
.711 .78 .906 r
.70169 .18281 .70257 .18396 .70447 .1833 .70358 .1819 Mtetra
.757 .751 .847 r
.70358 .1819 .70447 .1833 .70637 .18265 .70544 .18063 Mtetra
.665 .632 .807 r
.70544 .18063 .70637 .18265 .7083 .18247 .70734 .17981 Mtetra
.468 .466 .773 r
.70734 .17981 .7083 .18247 .71032 .18366 .70931 .18024 Mtetra
0 0 .386 r
.70931 .18024 .71032 .18366 .71319 .19843 .71162 .18623 Mtetra
.974 .672 .296 r
.71162 .18623 .71319 .19843 .72777 .39892 .72677 .39669 Mtetra
0 0 .479 r
.72677 .39669 .72777 .39892 .73005 .40179 .72912 .40064 Mtetra
.345 .621 .954 r
.72912 .40064 .73005 .40179 .73216 .40202 .73123 .40094 Mtetra
.69 .805 .936 r
.73123 .40094 .73216 .40202 .7342 .4012 .73327 .40007 Mtetra
.882 .834 .794 r
.73327 .40007 .7342 .4012 .73615 .39888 .73522 .39764 Mtetra
.98 .76 .536 r
.73522 .39764 .73615 .39888 .73771 .39066 .73673 .38883 Mtetra
.977 .674 .346 r
.73673 .38883 .73771 .39066 .72568 .17952 .72477 .17778 Mtetra
.919 .746 .652 r
.72477 .17778 .72568 .17952 .72733 .17486 .72643 .17332 Mtetra
.712 .715 .851 r
.72643 .17332 .72733 .17486 .72921 .17376 .72833 .17231 Mtetra
.59 .674 .898 r
.72833 .17231 .72921 .17376 .73115 .17332 .73027 .17196 Mtetra
.526 .658 .919 r
.73027 .17196 .73115 .17332 .7331 .17311 .73222 .17184 Mtetra
.657 .739 .911 r
.73222 .17184 .7331 .17311 .73501 .17235 .73415 .17118 Mtetra
.668 .764 .922 r
.73415 .17118 .73501 .17235 .73693 .17164 .73606 .17047 Mtetra
.697 .776 .912 r
.73606 .17047 .73693 .17164 .73885 .17099 .73797 .16963 Mtetra
.765 .764 .852 r
.73797 .16963 .73885 .17099 .74077 .1703 .73985 .16832 Mtetra
.675 .644 .811 r
.73985 .16832 .74077 .1703 .74273 .17004 .74176 .16744 Mtetra
.52 .502 .776 r
.74176 .16744 .74273 .17004 .74476 .17088 .74375 .16755 Mtetra
0 0 .49 r
.74375 .16755 .74476 .17088 .74743 .18009 .74609 .17256 Mtetra
.972 .664 .291 r
.74609 .17256 .74743 .18009 .76484 .38645 .76383 .38389 Mtetra
0 0 .452 r
.76383 .38389 .76484 .38645 .76722 .38979 .76631 .3886 Mtetra
.304 .589 .943 r
.76631 .3886 .76722 .38979 .76938 .39013 .76847 .38903 Mtetra
.666 .796 .944 r
.76847 .38903 .76938 .39013 .77145 .3894 .77055 .38827 Mtetra
.862 .838 .821 r
.77055 .38827 .77145 .3894 .77343 .38737 .77252 .38613 Mtetra
.98 .772 .552 r
.77252 .38613 .77343 .38737 .775 .38013 .77406 .37845 Mtetra
.976 .67 .327 r
.77406 .37845 .775 .38013 .76042 .16784 .75951 .16604 Mtetra
.932 .744 .626 r
.75951 .16604 .76042 .16784 .76199 .1625 .7611 .16093 Mtetra
.728 .72 .843 r
.7611 .16093 .76199 .1625 .76388 .16128 .76301 .15979 Mtetra
.608 .68 .893 r
.76301 .15979 .76388 .16128 .76583 .16076 .76497 .15936 Mtetra
.529 .655 .916 r
.76497 .15936 .76583 .16076 .76781 .16054 .76696 .15923 Mtetra
.741 .767 .874 r
.76696 .15923 .76781 .16054 .76972 .1594 .76886 .15811 Mtetra
.674 .744 .904 r
.76886 .15811 .76972 .1594 .77166 .15864 .7708 .15736 Mtetra
.455 .639 .935 r
.7708 .15736 .77166 .15864 .77366 .15871 .77281 .15745 Mtetra
.794 .382 0 r
.77281 .15745 .77366 .15871 .77611 .16395 .77529 .16313 Mtetra
.971 .656 .296 r
.77529 .16313 .77611 .16395 .79604 .37533 .79519 .37468 Mtetra
.789 .321 0 r
.79519 .37468 .79604 .37533 .7986 .38 .79772 .37909 Mtetra
.259 .624 .96 r
.79772 .37909 .7986 .38 .8008 .38046 .79991 .37944 Mtetra
.664 .813 .955 r
.79991 .37944 .8008 .38046 .8029 .37978 .80201 .37867 Mtetra
.843 .844 .845 r
.80201 .37867 .8029 .37978 .80491 .37796 .80401 .37675 Mtetra
.909 .739 .66 r
.13373 .58897 .13492 .5899 .13715 .58427 .13596 .58333 Mtetra
.936 .686 .535 r
.13596 .58333 .13715 .58427 .16167 .38198 .16056 .38099 Mtetra
.91 .728 .643 r
.16056 .38099 .16167 .38198 .16387 .37577 .16276 .37476 Mtetra
.773 .762 .843 r
.16276 .37476 .16387 .37577 .16549 .37457 .16439 .37355 Mtetra
.633 .735 .922 r
.16439 .37355 .16549 .37457 .16704 .37414 .16593 .37311 Mtetra
.495 .686 .952 r
.16593 .37311 .16704 .37414 .16854 .37408 .16744 .37305 Mtetra
.667 .741 .906 r
.16744 .37305 .16854 .37408 .1701 .37351 .169 .37247 Mtetra
.676 .743 .901 r
.169 .37247 .1701 .37351 .17166 .3729 .17056 .37186 Mtetra
.68 .743 .898 r
.17056 .37186 .17166 .3729 .17323 .37227 .17213 .37122 Mtetra
.761 .756 .848 r
.17213 .37122 .17323 .37227 .17486 .37115 .17376 .37009 Mtetra
.713 .749 .88 r
.17376 .37009 .17486 .37115 .17644 .37035 .17535 .36929 Mtetra
.53 .694 .943 r
.17535 .36929 .17644 .37035 .17796 .37022 .17686 .36916 Mtetra
.918 .523 .204 r
.17686 .36916 .17796 .37022 .17906 .37394 .17797 .37282 Mtetra
.94 .683 .522 r
.17797 .37282 .17906 .37394 .1589 .57513 .15773 .57397 Mtetra
.943 .6 .34 r
.15773 .57397 .1589 .57513 .15985 .58117 .15867 .58013 Mtetra
.045 .455 .879 r
.15867 .58013 .15985 .58117 .16138 .58193 .16022 .58075 Mtetra
.65 .726 .904 r
.16022 .58075 .16138 .58193 .16304 .58143 .16188 .58021 Mtetra
.771 .743 .827 r
.16188 .58021 .16304 .58143 .16481 .5799 .16364 .57886 Mtetra
.843 .766 .777 r
.16364 .57886 .16481 .5799 .16687 .57564 .16548 .57664 Mtetra
.969 .926 .69 r
.16548 .57664 .16687 .57564 .1892 .37809 .16751 .57275 Mtetra
.484 .261 .499 r
.16751 .57275 .1892 .37809 .19182 .36757 .17098 .55499 Mtetra
0 0 .098 r
.17098 .55499 .19182 .36757 .19359 .36513 .19214 .36751 Mtetra
.795 .889 .47 r
.19214 .36751 .19359 .36513 .19524 .36383 .19404 .36378 Mtetra
.889 .922 .839 r
.19404 .36378 .19524 .36383 .19683 .3631 .19576 .3619 Mtetra
.125 .453 .884 r
.19576 .3619 .19683 .3631 .19836 .36305 .19721 .36253 Mtetra
.865 .425 .149 r
.19721 .36253 .19836 .36305 .19984 .36342 .19846 .36516 Mtetra
.9 .609 .484 r
.19846 .36516 .19984 .36342 .2013 .36403 .19856 .37909 Mtetra
.919 .658 .527 r
.19856 .37909 .2013 .36403 .20283 .36391 .1815 .56238 Mtetra
.526 .297 .51 r
.1815 .56238 .20283 .36391 .20441 .36338 .18314 .5622 Mtetra
.521 .292 .509 r
.18314 .5622 .20441 .36338 .206 .36269 .18501 .55969 Mtetra
.524 .295 .509 r
.18501 .55969 .206 .36269 .20759 .36211 .18671 .55887 Mtetra
.525 .296 .51 r
.18671 .55887 .20759 .36211 .20917 .36155 .18837 .55851 Mtetra
.18837 .55851 .20917 .36155 .21075 .36099 .19004 .55809 Mtetra
.19004 .55809 .21075 .36099 .21234 .36044 .1917 .55773 Mtetra
.1917 .55773 .21234 .36044 .21392 .35988 .19336 .55736 Mtetra
.19336 .55736 .21392 .35988 .21551 .35932 .19503 .55692 Mtetra
.529 .3 .511 r
.19503 .55692 .21551 .35932 .21708 .35892 .19652 .55837 Mtetra
.527 .297 .51 r
.19652 .55837 .21708 .35892 .21866 .35845 .19813 .55861 Mtetra
.521 .292 .509 r
.19813 .55861 .21866 .35845 .22027 .35773 .20001 .55609 Mtetra
0 0 .135 r
.20001 .55609 .22027 .35773 .22194 .35627 .22028 .36123 Mtetra
0 0 0 r
.22028 .36123 .22194 .35627 .22363 .3547 .22239 .35528 Mtetra
.954 .937 .733 r
.22239 .35528 .22363 .3547 .2253 .35334 .22422 .35227 Mtetra
.776 .758 .837 r
.22422 .35227 .2253 .35334 .22692 .3525 .22588 .351 Mtetra
.66 .665 .844 r
.22588 .351 .22692 .3525 .22851 .35192 .22747 .3504 Mtetra
.605 .641 .859 r
.22747 .3504 .22851 .35192 .2301 .35144 .22905 .35006 Mtetra
.612 .665 .877 r
.22905 .35006 .2301 .35144 .23168 .35096 .23062 .34969 Mtetra
.618 .688 .893 r
.23062 .34969 .23168 .35096 .23327 .35046 .2322 .3493 Mtetra
.626 .71 .906 r
.2322 .3493 .23327 .35046 .23487 .34995 .23379 .34888 Mtetra
.714 .751 .881 r
.23379 .34888 .23487 .34995 .2365 .34903 .23541 .34806 Mtetra
.724 .771 .891 r
.23541 .34806 .2365 .34903 .23812 .34818 .23704 .3472 Mtetra
.66 .758 .923 r
.23704 .3472 .23812 .34818 .23971 .34781 .23864 .34664 Mtetra
.24 .53 .919 r
.23864 .34664 .23971 .34781 .2411 .3495 .24015 .3471 Mtetra
0 .12 .657 r
.24015 .3471 .2411 .3495 .24191 .35791 .24154 .34888 Mtetra
.075 .012 .474 r
.24154 .34888 .24191 .35791 .22588 .55667 .2426 .3544 Mtetra
0 0 .164 r
.2426 .3544 .22588 .55667 .22732 .55916 .22669 .55219 Mtetra
.047 .021 .502 r
.22669 .55219 .22732 .55916 .22893 .55969 .22795 .55664 Mtetra
.11 .203 .681 r
.22795 .55664 .22893 .55969 .2306 .55962 .22946 .55841 Mtetra
.277 .558 .93 r
.22946 .55841 .2306 .55962 .23227 .55956 .23109 .55882 Mtetra
.569 .797 .985 r
.23109 .55882 .23227 .55956 .23396 .55926 .23279 .55846 Mtetra
.73 .82 .921 r
.23279 .55846 .23396 .55926 .2357 .55836 .23453 .55754 Mtetra
.831 .813 .832 r
.23453 .55754 .2357 .55836 .23761 .55556 .23635 .5558 Mtetra
.94 .924 .766 r
.23635 .5558 .23761 .55556 .23991 .54806 .23826 .55294 Mtetra
0 0 0 r
.23826 .55294 .23991 .54806 .25853 .34641 .24038 .54762 Mtetra
0 0 .163 r
.24038 .54762 .25853 .34641 .26042 .34255 .25866 .34966 Mtetra
0 0 .025 r
.25866 .34966 .26042 .34255 .26211 .34104 .26083 .34252 Mtetra
.833 .945 .586 r
.26083 .34252 .26211 .34104 .26375 .34015 .26264 .33958 Mtetra
.81 .858 .884 r
.26264 .33958 .26375 .34015 .26537 .33955 .26432 .33827 Mtetra
.644 .697 .884 r
.26432 .33827 .26537 .33955 .26698 .33911 .26593 .33776 Mtetra
.564 .655 .897 r
.26593 .33776 .26698 .33911 .26858 .33879 .26752 .33757 Mtetra
.591 .689 .91 r
.26752 .33757 .26858 .33879 .27018 .33839 .26912 .33727 Mtetra
.632 .721 .912 r
.26912 .33727 .27018 .33839 .2718 .33791 .27073 .33681 Mtetra
.642 .731 .913 r
.27073 .33681 .2718 .33791 .27342 .33737 .27235 .33632 Mtetra
.66 .744 .912 r
.27235 .33632 .27342 .33737 .27504 .33677 .27397 .33575 Mtetra
.676 .755 .91 r
.27397 .33575 .27504 .33677 .27667 .33612 .2756 .33511 Mtetra
.686 .761 .909 r
.2756 .33511 .27667 .33612 .27831 .33543 .27724 .33443 Mtetra
.691 .765 .908 r
.27724 .33443 .27831 .33543 .27994 .33471 .27887 .33373 Mtetra
.696 .769 .908 r
.27887 .33373 .27994 .33471 .28158 .33398 .28051 .33301 Mtetra
.703 .771 .905 r
.28051 .33301 .28158 .33398 .28322 .33324 .28215 .33225 Mtetra
.716 .771 .896 r
.28215 .33225 .28322 .33324 .28486 .33247 .2838 .33142 Mtetra
.72 .761 .885 r
.2838 .33142 .28486 .33247 .28651 .3317 .28545 .33056 Mtetra
.712 .744 .877 r
.28545 .33056 .28651 .3317 .28815 .33094 .2871 .32973 Mtetra
.692 .726 .876 r
.2871 .32973 .28815 .33094 .28979 .33024 .28875 .32899 Mtetra
.674 .715 .879 r
.28875 .32899 .28979 .33024 .29143 .32958 .29039 .32834 Mtetra
.667 .713 .883 r
.29039 .32834 .29143 .32958 .29307 .32896 .29202 .32773 Mtetra
.665 .715 .886 r
.29202 .32773 .29307 .32896 .29471 .32834 .29366 .32713 Mtetra
.664 .717 .888 r
.29366 .32713 .29471 .32834 .29634 .32774 .2953 .32653 Mtetra
.662 .717 .89 r
.2953 .32653 .29634 .32774 .29798 .32714 .29693 .32594 Mtetra
.66 .718 .891 r
.29693 .32594 .29798 .32714 .29962 .32656 .29857 .32536 Mtetra
.659 .718 .892 r
.29857 .32536 .29962 .32656 .30126 .32598 .30021 .32478 Mtetra
.657 .719 .894 r
.30021 .32478 .30126 .32598 .3029 .32541 .30185 .32422 Mtetra
.655 .719 .896 r
.30185 .32422 .3029 .32541 .30454 .32484 .30349 .32366 Mtetra
.654 .721 .898 r
.30349 .32366 .30454 .32484 .30618 .32427 .30513 .32311 Mtetra
.653 .723 .9 r
.30513 .32311 .30618 .32427 .30782 .32371 .30677 .32256 Mtetra
.655 .726 .902 r
.30677 .32256 .30782 .32371 .30946 .32315 .30841 .322 Mtetra
.656 .729 .903 r
.30841 .322 .30946 .32315 .3111 .32258 .31006 .32144 Mtetra
.657 .731 .904 r
.31006 .32144 .3111 .32258 .31275 .322 .3117 .32088 Mtetra
.658 .733 .904 r
.3117 .32088 .31275 .322 .31439 .32143 .31335 .3203 Mtetra
.66 .734 .905 r
.31335 .3203 .31439 .32143 .31604 .32085 .315 .31973 Mtetra
.661 .736 .905 r
.315 .31973 .31604 .32085 .31769 .32026 .31664 .31915 Mtetra
.662 .736 .905 r
.31664 .31915 .31769 .32026 .31934 .31967 .31829 .31856 Mtetra
.663 .737 .905 r
.31829 .31856 .31934 .31967 .32099 .31908 .31995 .31797 Mtetra
.664 .737 .905 r
.31995 .31797 .32099 .31908 .32265 .31849 .3216 .31737 Mtetra
.664 .737 .904 r
.3216 .31737 .32265 .31849 .3243 .31789 .32325 .31677 Mtetra
.665 .737 .904 r
.32325 .31677 .3243 .31789 .32595 .3173 .32491 .31617 Mtetra
.666 .737 .903 r
.32491 .31617 .32595 .3173 .32761 .3167 .32657 .31557 Mtetra
.666 .736 .902 r
.32657 .31557 .32761 .3167 .32927 .3161 .32822 .31496 Mtetra
.666 .735 .901 r
.32822 .31496 .32927 .3161 .33092 .3155 .32988 .31435 Mtetra
.666 .733 .9 r
.32988 .31435 .33092 .3155 .33258 .3149 .33154 .31374 Mtetra
.668 .732 .898 r
.33154 .31374 .33258 .3149 .33424 .3143 .33321 .31312 Mtetra
.668 .729 .895 r
.33321 .31312 .33424 .3143 .3359 .3137 .33487 .3125 Mtetra
.663 .723 .894 r
.33487 .3125 .3359 .3137 .33757 .31311 .33653 .3119 Mtetra
.649 .716 .897 r
.33653 .3119 .33757 .31311 .33923 .31256 .33819 .31136 Mtetra
.63 .712 .906 r
.33819 .31136 .33923 .31256 .34088 .31205 .33985 .31091 Mtetra
.629 .722 .914 r
.33985 .31091 .34088 .31205 .34254 .31154 .3415 .31045 Mtetra
.643 .738 .918 r
.3415 .31045 .34254 .31154 .34421 .31099 .34317 .30993 Mtetra
.667 .752 .913 r
.34317 .30993 .34421 .31099 .34587 .31039 .34483 .30932 Mtetra
.68 .753 .906 r
.34483 .30932 .34587 .31039 .34754 .30976 .34651 .30865 Mtetra
.715 .755 .884 r
.34651 .30865 .34754 .30976 .34922 .30903 .34819 .3078 Mtetra
.736 .738 .853 r
.34819 .3078 .34922 .30903 .3509 .30821 .34989 .30677 Mtetra
.683 .691 .851 r
.34989 .30677 .3509 .30821 .35258 .30749 .35157 .30603 Mtetra
.48 .6 .894 r
.35157 .30603 .35258 .30749 .35424 .3071 .3532 .30611 Mtetra
.647 .143 0 r
.3532 .30611 .35424 .3071 .35587 .30725 .35474 .308 Mtetra
.872 .503 .347 r
.35474 .308 .35587 .30725 .3575 .30758 .35612 .31292 Mtetra
.95 .675 .483 r
.35612 .31292 .3575 .30758 .35915 .30753 .34744 .50671 Mtetra
.525 .296 .51 r
.34744 .50671 .35915 .30753 .36084 .30653 .34922 .50605 Mtetra
.522 .293 .509 r
.34922 .50605 .36084 .30653 .36252 .30594 .3511 .50375 Mtetra
.536 .305 .512 r
.3511 .50375 .36252 .30594 .3641 .30723 .35259 .5088 Mtetra
.537 .306 .512 r
.35259 .5088 .3641 .30723 .35561 .50686 .35405 .5146 Mtetra
.622 .327 .448 r
.35405 .5146 .35561 .50686 .35686 .51685 .35569 .51715 Mtetra
.602 .061 0 r
.35569 .51715 .35686 .51685 .35852 .51907 .3574 .51819 Mtetra
.493 .743 .983 r
.3574 .51819 .35852 .51907 .36029 .51896 .35918 .51803 Mtetra
.623 .781 .957 r
.35918 .51803 .36029 .51896 .36209 .5183 .36097 .51752 Mtetra
.644 .821 .968 r
.36097 .51752 .36209 .5183 .3639 .5175 .36277 .51692 Mtetra
.574 .845 .996 r
.36277 .51692 .3639 .5175 .3657 .51694 .36457 .51644 Mtetra
.671 .891 .977 r
.36457 .51644 .3657 .51694 .36751 .51624 .36638 .51567 Mtetra
.81 .886 .899 r
.36638 .51567 .36751 .51624 .36932 .51539 .36822 .51427 Mtetra
.877 .778 .748 r
.36822 .51427 .36932 .51539 .37115 .51436 .37013 .51143 Mtetra
.848 .656 .643 r
.37013 .51143 .37115 .51436 .373 .51277 .37215 .50615 Mtetra
.954 .683 .486 r
.37215 .50615 .373 .51277 .37492 .50947 .38303 .30539 Mtetra
.544 .316 .52 r
.38303 .30539 .37492 .50947 .38562 .30902 .38504 .29777 Mtetra
.633 .424 .582 r
.38504 .29777 .38562 .30902 .38781 .29722 .38685 .29463 Mtetra
.737 .61 .717 r
.38685 .29463 .38781 .29722 .38962 .29404 .3886 .29282 Mtetra
.701 .734 .876 r
.3886 .29282 .38962 .29404 .39133 .2931 .39031 .29201 Mtetra
.628 .737 .926 r
.39031 .29201 .39133 .2931 .39302 .29268 .392 .29155 Mtetra
.586 .712 .93 r
.392 .29155 .39302 .29268 .3947 .29246 .39368 .29123 Mtetra
.616 .704 .908 r
.39368 .29123 .3947 .29246 .39639 .29199 .39537 .29082 Mtetra
.612 .713 .917 r
.39537 .29082 .39639 .29199 .39808 .29154 .39706 .29042 Mtetra
.621 .728 .923 r
.39706 .29042 .39808 .29154 .39978 .29106 .39876 .28998 Mtetra
.65 .745 .92 r
.39876 .28998 .39978 .29106 .40148 .29051 .40046 .28942 Mtetra
.666 .75 .913 r
.40046 .28942 .40148 .29051 .40318 .28993 .40216 .2888 Mtetra
.683 .749 .901 r
.40216 .2888 .40318 .28993 .40489 .28929 .40387 .2881 Mtetra
.702 .742 .883 r
.40387 .2881 .40489 .28929 .40659 .28858 .40559 .2873 Mtetra
.7 .724 .869 r
.40559 .2873 .40659 .28858 .4083 .28787 .4073 .28648 Mtetra
.696 .707 .856 r
.4073 .28648 .4083 .28787 .41002 .28714 .40902 .28566 Mtetra
.705 .696 .839 r
.40902 .28566 .41002 .28714 .41173 .28639 .41074 .28475 Mtetra
.658 .658 .839 r
.41074 .28475 .41173 .28639 .41344 .28574 .41245 .28411 Mtetra
.539 .605 .868 r
.41245 .28411 .41344 .28574 .41514 .28531 .41414 .28403 Mtetra
0 .033 .572 r
.41414 .28403 .41514 .28531 .41683 .28547 .41577 .28574 Mtetra
.879 .482 .272 r
.41577 .28574 .41683 .28547 .41851 .28583 .41731 .2901 Mtetra
.957 .677 .464 r
.41731 .2901 .41851 .28583 .42019 .28618 .41229 .48765 Mtetra
.529 .299 .51 r
.41229 .48765 .42019 .28618 .4219 .28568 .41404 .48935 Mtetra
.524 .295 .509 r
.41404 .48935 .4219 .28568 .42363 .28493 .41589 .488 Mtetra
.52 .291 .509 r
.41589 .488 .42363 .28493 .42535 .28403 .41782 .48459 Mtetra
.515 .288 .508 r
.41782 .48459 .42535 .28403 .42709 .28281 .4198 .4791 Mtetra
.521 .293 .509 r
.4198 .4791 .42709 .28281 .42882 .28211 .42169 .47656 Mtetra
.541 .308 .512 r
.42169 .47656 .42882 .28211 .4305 .2826 .42327 .48395 Mtetra
.54 .308 .512 r
.42327 .48395 .4305 .2826 .43175 .29783 .42487 .49116 Mtetra
.532 .301 .511 r
.42487 .49116 .43175 .29783 .42774 .49322 .42661 .49403 Mtetra
.657 .175 .095 r
.42661 .49403 .42774 .49322 .42948 .49628 .4284 .49537 Mtetra
.548 .765 .978 r
.4284 .49537 .42948 .49628 .43131 .49619 .43023 .49507 Mtetra
.663 .761 .923 r
.43023 .49507 .43131 .49619 .43316 .49549 .43208 .49441 Mtetra
.692 .776 .916 r
.43208 .49441 .43316 .49549 .43502 .49452 .43394 .49361 Mtetra
.587 .78 .972 r
.43394 .49361 .43502 .49452 .43686 .49401 .43578 .4932 Mtetra
.58 .8 .983 r
.43578 .4932 .43686 .49401 .43871 .49349 .43763 .49278 Mtetra
.589 .826 .989 r
.43763 .49278 .43871 .49349 .44056 .49292 .43947 .49229 Mtetra
.657 .865 .978 r
.43947 .49229 .44056 .49292 .44241 .49223 .44133 .49158 Mtetra
.675 .865 .971 r
.44133 .49158 .44241 .49223 .44427 .49151 .44319 .49082 Mtetra
.68 .857 .967 r
.44319 .49082 .44427 .49151 .44613 .49079 .44505 .49004 Mtetra
.542 .801 .993 r
.44505 .49004 .44613 .49079 .44798 .49029 .4469 .48969 Mtetra
.591 .853 .994 r
.4469 .48969 .44798 .49029 .44984 .48972 .44876 .48915 Mtetra
.72 .893 .959 r
.44876 .48915 .44984 .48972 .4517 .48898 .45062 .4882 Mtetra
.894 .837 .782 r
.45062 .4882 .4517 .48898 .45356 .48804 .45253 .48563 Mtetra
.861 .683 .659 r
.45253 .48563 .45356 .48804 .45544 .48658 .45447 .48102 Mtetra
.962 .684 .462 r
.45447 .48102 .45544 .48658 .45734 .48407 .46045 .282 Mtetra
.551 .321 .52 r
.46045 .282 .45734 .48407 .45946 .47083 .46242 .27068 Mtetra
.535 .309 .518 r
.46242 .27068 .45946 .47083 .46517 .27046 .46422 .26715 Mtetra
.726 .575 .685 r
.46422 .26715 .46517 .27046 .46698 .26645 .46599 .26505 Mtetra
.693 .71 .861 r
.46599 .26505 .46698 .26645 .46873 .26535 .46774 .26424 Mtetra
.613 .734 .932 r
.46774 .26424 .46873 .26535 .47047 .26488 .46948 .26381 Mtetra
.562 .722 .949 r
.46948 .26381 .47047 .26488 .47221 .26471 .47123 .26355 Mtetra
.73 .761 .877 r
.47123 .26355 .47221 .26471 .47396 .26396 .47298 .26257 Mtetra
.702 .715 .859 r
.47298 .26257 .47396 .26396 .47571 .26321 .47473 .26171 Mtetra
.631 .669 .868 r
.47473 .26171 .47571 .26321 .47746 .26262 .47648 .26121 Mtetra
.107 .398 .852 r
.47648 .26121 .47746 .26262 .47921 .26224 .47821 .26213 Mtetra
.815 .337 .059 r
.47821 .26213 .47921 .26224 .48095 .26231 .47992 .26478 Mtetra
.964 .678 .441 r
.47992 .26478 .48095 .26231 .48269 .26326 .47899 .45589 Mtetra
.559 .323 .514 r
.47899 .45589 .48269 .26326 .48433 .2712 .48062 .47316 Mtetra
.532 .301 .511 r
.48062 .47316 .48433 .2712 .48354 .4744 .48245 .47611 Mtetra
.624 .197 .212 r
.48245 .47611 .48354 .4744 .48536 .47803 .48431 .47733 Mtetra
.283 .684 .972 r
.48431 .47733 .48536 .47803 .48724 .47835 .48618 .47746 Mtetra
.615 .796 .969 r
.48618 .47746 .48724 .47835 .48912 .47777 .48806 .47694 Mtetra
.757 .846 .918 r
.48806 .47694 .48912 .47777 .49101 .47667 .48996 .47581 Mtetra
.881 .837 .798 r
.48996 .47581 .49101 .47667 .4929 .4757 .49186 .47346 Mtetra
.861 .693 .673 r
.49186 .47346 .4929 .4757 .49479 .47433 .49378 .4693 Mtetra
.903 .651 .548 r
.49378 .4693 .49479 .47433 .4967 .47203 .49581 .45326 Mtetra
.95 .667 .465 r
.49581 .45326 .4967 .47203 .49865 .46327 .4993 .25827 Mtetra
.535 .309 .518 r
.4993 .25827 .49865 .46327 .50205 .25826 .5011 .25436 Mtetra
.714 .55 .666 r
.5011 .25436 .50205 .25826 .50385 .25367 .50288 .25211 Mtetra
.705 .692 .835 r
.50288 .25211 .50385 .25367 .50562 .2523 .50465 .25116 Mtetra
.613 .73 .929 r
.50465 .25116 .50562 .2523 .50739 .2518 .50642 .25073 Mtetra
.541 .715 .953 r
.50642 .25073 .50739 .2518 .50916 .25164 .50819 .25052 Mtetra
.689 .759 .905 r
.50819 .25052 .50916 .25164 .51093 .25105 .50996 .24977 Mtetra
.686 .729 .883 r
.50996 .24977 .51093 .25105 .5127 .25037 .51173 .24901 Mtetra
.615 .689 .896 r
.51173 .24901 .5127 .25037 .51448 .2498 .51351 .24858 Mtetra
.117 .443 .879 r
.51351 .24858 .51448 .2498 .51625 .24934 .51528 .24937 Mtetra
.798 .313 .052 r
.51528 .24937 .51625 .24934 .51803 .24925 .51705 .25189 Mtetra
.967 .676 .428 r
.51705 .25189 .51803 .24925 .5198 .24996 .51848 .43122 Mtetra
.581 .34 .516 r
.51848 .43122 .5198 .24996 .52158 .25621 .52032 .46012 Mtetra
.532 .301 .511 r
.52032 .46012 .52158 .25621 .52326 .46104 .52222 .46322 Mtetra
.62 .215 .255 r
.52222 .46322 .52326 .46104 .52517 .46506 .52413 .4645 Mtetra
.267 .705 .963 r
.52413 .4645 .52517 .46506 .52708 .46555 .52604 .46455 Mtetra
.654 .791 .947 r
.52604 .46455 .52708 .46555 .52899 .46492 .52795 .4639 Mtetra
.769 .815 .889 r
.52795 .4639 .52899 .46492 .5309 .46376 .52987 .46264 Mtetra
.861 .805 .794 r
.52987 .46264 .5309 .46376 .53281 .46278 .53178 .46037 Mtetra
.848 .682 .676 r
.53178 .46037 .53281 .46278 .53473 .46158 .53368 .45647 Mtetra
.872 .631 .571 r
.53368 .45647 .53473 .46158 .53664 .45959 .53557 .44547 Mtetra
.959 .673 .448 r
.53557 .44547 .53664 .45959 .53853 .4532 .53671 .24606 Mtetra
.536 .309 .518 r
.53671 .24606 .53853 .4532 .53946 .2465 .53849 .2418 Mtetra
.698 .523 .646 r
.53849 .2418 .53946 .2465 .54123 .24099 .54027 .23939 Mtetra
.738 .703 .818 r
.54027 .23939 .54123 .24099 .54302 .23921 .54206 .23818 Mtetra
.665 .776 .932 r
.54206 .23818 .54302 .23921 .54481 .23853 .54386 .23753 Mtetra
.604 .76 .953 r
.54386 .23753 .54481 .23853 .54661 .23823 .54566 .2371 Mtetra
.728 .774 .889 r
.54566 .2371 .54661 .23823 .54841 .23734 .54745 .23614 Mtetra
.719 .758 .883 r
.54745 .23614 .54841 .23734 .5502 .23643 .54925 .2352 Mtetra
.58 .701 .925 r
.54925 .2352 .5502 .23643 .552 .23613 .55105 .23489 Mtetra
.659 .205 0 r
.55105 .23489 .552 .23613 .55383 .23887 .55288 .23768 Mtetra
.973 .68 .407 r
.55288 .23768 .55383 .23887 .55772 .44576 .55671 .44506 Mtetra
.929 .545 .206 r
.55671 .44506 .55772 .44576 .55974 .45354 .55872 .4526 Mtetra
0 .374 .816 r
.55872 .4526 .55974 .45354 .56169 .45455 .56067 .45355 Mtetra
.667 .798 .945 r
.56067 .45355 .56169 .45455 .56362 .4539 .56261 .45284 Mtetra
.762 .811 .891 r
.56261 .45284 .56362 .4539 .56555 .45273 .56454 .45162 Mtetra
.585 .744 .952 r
.56454 .45162 .56555 .45273 .5675 .4523 .56648 .45123 Mtetra
.494 .713 .969 r
.56648 .45123 .5675 .4523 .56944 .45208 .56843 .45111 Mtetra
.673 .806 .947 r
.56843 .45111 .56944 .45208 .57138 .45123 .57037 .45036 Mtetra
.931 .827 .721 r
.57037 .45036 .57138 .45123 .57328 .44757 .57227 .44686 Mtetra
.975 .688 .415 r
.57227 .44686 .57328 .44757 .5721 .24412 .57127 .25099 Mtetra
.927 .742 .259 r
.57127 .25099 .5721 .24412 .5737 .22998 .57276 .22891 Mtetra
.888 .803 .76 r
.57276 .22891 .5737 .22998 .57549 .22748 .57454 .22632 Mtetra
.685 .756 .905 r
.57454 .22632 .57549 .22748 .5773 .22675 .57636 .22557 Mtetra
.553 .699 .937 r
.57636 .22557 .5773 .22675 .57912 .22653 .57818 .22534 Mtetra
.65 .738 .914 r
.57818 .22534 .57912 .22653 .58094 .22605 .58 .22475 Mtetra
.697 .735 .881 r
.58 .22475 .58094 .22605 .58276 .22531 .58182 .22391 Mtetra
.635 .695 .888 r
.58182 .22391 .58276 .22531 .58458 .22468 .58364 .22339 Mtetra
.323 .556 .919 r
.58364 .22339 .58458 .22468 .5864 .22415 .58548 .22382 Mtetra
.697 .158 0 r
.58548 .22382 .5864 .22415 .58823 .22389 .58736 .22582 Mtetra
.869 .501 .348 r
.58736 .22582 .58823 .22389 .59008 .22427 .58935 .23284 Mtetra
.965 .666 .411 r
.58935 .23284 .59008 .22427 .592 .22768 .59556 .43402 Mtetra
.533 .302 .511 r
.59556 .43402 .592 .22768 .5985 .4339 .59762 .43789 Mtetra
.611 .261 .353 r
.59762 .43789 .5985 .4339 .60061 .43981 .59963 .43945 Mtetra
0 .425 .726 r
.59963 .43945 .60061 .43981 .60262 .44129 .60162 .44002 Mtetra
.536 .693 .94 r
.60162 .44002 .60262 .44129 .6046 .44115 .6036 .43982 Mtetra
.722 .757 .881 r
.6036 .43982 .6046 .44115 .60655 .44001 .60555 .43879 Mtetra
.911 .794 .719 r
.60555 .43879 .60655 .44001 .60844 .43645 .60745 .43533 Mtetra
.976 .685 .402 r
.60745 .43533 .60844 .43645 .60523 .23852 .60436 .23984 Mtetra
.992 .74 .418 r
.60436 .23984 .60523 .23852 .60656 .2185 .60563 .21732 Mtetra
.894 .793 .741 r
.60563 .21732 .60656 .2185 .60833 .21568 .60741 .21449 Mtetra
.694 .756 .899 r
.60741 .21449 .60833 .21568 .61017 .21489 .60924 .21368 Mtetra
.568 .704 .933 r
.60924 .21368 .61017 .21489 .61202 .21461 .61109 .2134 Mtetra
.631 .729 .919 r
.61109 .2134 .61202 .21461 .61386 .21419 .61293 .21288 Mtetra
.699 .738 .882 r
.61293 .21288 .61386 .21419 .6157 .21344 .61477 .21203 Mtetra
.643 .698 .886 r
.61477 .21203 .6157 .21344 .61754 .21278 .61661 .21145 Mtetra
.398 .592 .922 r
.61661 .21145 .61754 .21278 .61939 .21223 .61848 .21172 Mtetra
.593 .042 0 r
.61848 .21172 .61939 .21223 .62124 .2119 .62041 .21348 Mtetra
.852 .461 .304 r
.62041 .21348 .62124 .2119 .62312 .21216 .62245 .21889 Mtetra
.969 .667 .394 r
.62245 .21889 .62312 .21216 .62507 .21476 .63095 .42146 Mtetra
.534 .303 .511 r
.63095 .42146 .62507 .21476 .63385 .42022 .6331 .426 Mtetra
.601 .28 .397 r
.6331 .426 .63385 .42022 .63611 .4278 .63516 .42776 Mtetra
.366 0 0 r
.63516 .42776 .63611 .4278 .63818 .42964 .6372 .4285 Mtetra
.455 .681 .962 r
.6372 .4285 .63818 .42964 .64019 .42963 .63921 .4285 Mtetra
.698 .789 .921 r
.63921 .4285 .64019 .42963 .64217 .42855 .6412 .42763 Mtetra
.931 .834 .726 r
.6412 .42763 .64217 .42855 .64404 .42477 .64309 .42422 Mtetra
.977 .683 .386 r
.64309 .42422 .64404 .42477 .63823 .21498 .63742 .21657 Mtetra
.991 .789 .407 r
.63742 .21657 .63823 .21498 .63976 .20554 .63885 .20444 Mtetra
.878 .811 .779 r
.63885 .20444 .63976 .20554 .64158 .20389 .64064 .20208 Mtetra
.373 .496 .854 r
.64064 .20208 .64158 .20389 .64357 .20645 .64255 .20264 Mtetra
.158 .196 .652 r
.64255 .20264 .64357 .20645 .65359 .41099 .64454 .20526 Mtetra
.474 .263 .512 r
.64454 .20526 .65359 .41099 .656 .42048 .64743 .23009 Mtetra
0 0 .38 r
.64743 .23009 .656 .42048 .65807 .42157 .65694 .41652 Mtetra
.223 .209 .631 r
.65694 .41652 .65807 .42157 .6601 .42172 .65909 .41953 Mtetra
.269 .401 .812 r
.65909 .41953 .6601 .42172 .66213 .42169 .66117 .42064 Mtetra
.427 .686 .972 r
.66117 .42064 .66213 .42169 .66416 .42163 .6632 .42067 Mtetra
.692 .824 .946 r
.6632 .42067 .66416 .42163 .66617 .42086 .6652 .41981 Mtetra
.902 .831 .766 r
.6652 .41981 .66617 .42086 .66809 .41818 .66712 .41702 Mtetra
.979 .743 .509 r
.66712 .41702 .66809 .41818 .6696 .40642 .66864 .40532 Mtetra
.977 .681 .375 r
.66864 .40532 .6696 .40642 .66222 .19945 .66132 .19821 Mtetra
.922 .789 .696 r
.66132 .19821 .66222 .19945 .66396 .19585 .66306 .19461 Mtetra
.719 .761 .886 r
.66306 .19461 .66396 .19585 .66582 .19489 .66492 .19365 Mtetra
.594 .711 .925 r
.66492 .19365 .66582 .19489 .66771 .19451 .66681 .19327 Mtetra
.624 .724 .919 r
.66681 .19327 .66771 .19451 .66959 .19401 .66869 .19277 Mtetra
.737 .767 .877 r
.66869 .19277 .66959 .19401 .67145 .19294 .67055 .1917 Mtetra
.647 .735 .913 r
.67055 .1917 .67145 .19294 .67333 .19234 .67243 .1911 Mtetra
.099 .423 .868 r
.67243 .1911 .67333 .19234 .67529 .19329 .67439 .19204 Mtetra
.918 .543 .122 r
.67439 .19204 .67529 .19329 .67766 .20227 .67676 .20102 Mtetra
.975 .67 .349 r
.67676 .20102 .67766 .20227 .69019 .40955 .68923 .40835 Mtetra
.609 .149 0 r
.68923 .40835 .69019 .40955 .6924 .4126 .69145 .4114 Mtetra
.416 .65 .955 r
.69145 .4114 .6924 .4126 .69447 .41273 .69352 .41154 Mtetra
.715 .786 .908 r
.69352 .41154 .69447 .41273 .69649 .41176 .69553 .41055 Mtetra
.895 .813 .76 r
.69553 .41055 .69649 .41176 .6984 .40901 .69745 .40773 Mtetra
.98 .742 .506 r
.69745 .40773 .6984 .40901 .6999 .39858 .69889 .39616 Mtetra
.977 .677 .365 r
.69889 .39616 .6999 .39858 .69047 .18946 .68955 .18781 Mtetra
.902 .75 .683 r
.68955 .18781 .69047 .18946 .69218 .18555 .69128 .18405 Mtetra
.688 .709 .864 r
.69128 .18405 .69218 .18555 .69406 .18463 .69316 .1832 Mtetra
.557 .661 .906 r
.69316 .1832 .69406 .18463 .69598 .18433 .69508 .18299 Mtetra
.515 .655 .922 r
.69508 .18299 .69598 .18433 .6979 .18417 .69701 .18291 Mtetra
.65 .734 .911 r
.69701 .18291 .6979 .18417 .6998 .18352 .69891 .18229 Mtetra
.667 .748 .911 r
.69891 .18229 .6998 .18352 .70169 .18281 .70081 .18159 Mtetra
.714 .768 .895 r
.70081 .18159 .70169 .18281 .70358 .1819 .70269 .18066 Mtetra
.776 .783 .859 r
.70269 .18066 .70358 .1819 .70544 .18063 .70455 .17932 Mtetra
.7 .746 .887 r
.70455 .17932 .70544 .18063 .70734 .17981 .70644 .17844 Mtetra
.373 .572 .916 r
.70644 .17844 .70734 .17981 .70931 .18024 .70841 .17881 Mtetra
.818 .416 0 r
.70841 .17881 .70931 .18024 .71162 .18623 .71072 .18463 Mtetra
.975 .666 .33 r
.71072 .18463 .71162 .18623 .72677 .39669 .72583 .39545 Mtetra
.709 .265 0 r
.72583 .39545 .72677 .39669 .72912 .40064 .72818 .39949 Mtetra
.348 .622 .954 r
.72818 .39949 .72912 .40064 .73123 .40094 .7303 .39978 Mtetra
.695 .79 .924 r
.7303 .39978 .73123 .40094 .73327 .40007 .73234 .39889 Mtetra
.882 .824 .787 r
.73234 .39889 .73327 .40007 .73522 .39764 .73428 .39639 Mtetra
.981 .756 .524 r
.73428 .39639 .73522 .39764 .73673 .38883 .73576 .38691 Mtetra
.977 .674 .346 r
.73576 .38691 .73673 .38883 .72477 .17778 .72387 .1761 Mtetra
.918 .751 .658 r
.72387 .1761 .72477 .17778 .72643 .17332 .72554 .1718 Mtetra
.702 .714 .858 r
.72554 .1718 .72643 .17332 .72833 .17231 .72744 .17086 Mtetra
.572 .666 .902 r
.72744 .17086 .72833 .17231 .73027 .17196 .72939 .17058 Mtetra
.503 .645 .92 r
.72939 .17058 .73027 .17196 .73222 .17184 .73135 .17055 Mtetra
.648 .731 .91 r
.73135 .17055 .73222 .17184 .73415 .17118 .73327 .16993 Mtetra
.665 .746 .911 r
.73327 .16993 .73415 .17118 .73606 .17047 .7352 .16924 Mtetra
.699 .762 .901 r
.7352 .16924 .73606 .17047 .73797 .16963 .73711 .16837 Mtetra
.78 .786 .857 r
.73711 .16837 .73797 .16963 .73985 .16832 .73898 .167 Mtetra
.711 .751 .884 r
.73898 .167 .73985 .16832 .74176 .16744 .74089 .16605 Mtetra
.478 .63 .92 r
.74089 .16605 .74176 .16744 .74375 .16755 .74287 .16611 Mtetra
.736 .327 0 r
.74287 .16611 .74375 .16755 .74609 .17256 .7452 .17099 Mtetra
.973 .661 .311 r
.7452 .17099 .74609 .17256 .76383 .38389 .7629 .38261 Mtetra
.746 .316 0 r
.7629 .38261 .76383 .38389 .76631 .3886 .76539 .38743 Mtetra
.301 .59 .944 r
.76539 .38743 .76631 .3886 .76847 .38903 .76756 .38786 Mtetra
.671 .783 .933 r
.76756 .38786 .76847 .38903 .77055 .38827 .76963 .38707 Mtetra
.862 .828 .813 r
.76963 .38707 .77055 .38827 .77252 .38613 .7716 .38488 Mtetra
.981 .768 .541 r
.7716 .38488 .77252 .38613 .77406 .37845 .77311 .37673 Mtetra
.976 .67 .327 r
.77311 .37673 .77406 .37845 .75951 .16604 .75862 .1643 Mtetra
.932 .75 .632 r
.75862 .1643 .75951 .16604 .7611 .16093 .76022 .15938 Mtetra
.719 .72 .85 r
.76022 .15938 .7611 .16093 .76301 .15979 .76213 .15832 Mtetra
.591 .674 .898 r
.76213 .15832 .76301 .15979 .76497 .15936 .7641 .15796 Mtetra
.506 .644 .918 r
.7641 .15796 .76497 .15936 .76696 .15923 .7661 .15792 Mtetra
.737 .765 .875 r
.7661 .15792 .76696 .15923 .76886 .15811 .76801 .15681 Mtetra
.671 .743 .904 r
.76801 .15681 .76886 .15811 .7708 .15736 .76995 .15607 Mtetra
.446 .634 .935 r
.76995 .15607 .7708 .15736 .77281 .15745 .77196 .15619 Mtetra
.815 .408 0 r
.77196 .15619 .77281 .15745 .77529 .16313 .77448 .16234 Mtetra
.971 .656 .296 r
.77448 .16234 .77529 .16313 .79519 .37468 .79433 .37396 Mtetra
.767 .296 0 r
.79433 .37396 .79519 .37468 .79772 .37909 .79684 .37815 Mtetra
.311 .651 .97 r
.79684 .37815 .79772 .37909 .79991 .37944 .79903 .3784 Mtetra
.683 .818 .948 r
.79903 .3784 .79991 .37944 .80201 .37867 .80112 .37755 Mtetra
.85 .844 .838 r
.80112 .37755 .80201 .37867 .80401 .37675 .80311 .37555 Mtetra
.908 .74 .662 r
.13253 .58803 .13373 .58897 .13596 .58333 .13475 .58247 Mtetra
.936 .686 .534 r
.13475 .58247 .13596 .58333 .16056 .38099 .15944 .38008 Mtetra
.914 .731 .642 r
.15944 .38008 .16056 .38099 .16276 .37476 .16165 .37374 Mtetra
.774 .762 .842 r
.16165 .37374 .16276 .37476 .16439 .37355 .16328 .37252 Mtetra
.635 .735 .92 r
.16328 .37252 .16439 .37355 .16593 .37311 .16483 .37207 Mtetra
.501 .687 .95 r
.16483 .37207 .16593 .37311 .16744 .37305 .16633 .372 Mtetra
.669 .74 .903 r
.16633 .372 .16744 .37305 .169 .37247 .1679 .37141 Mtetra
.677 .74 .898 r
.1679 .37141 .169 .37247 .17056 .37186 .16946 .37079 Mtetra
.681 .74 .895 r
.16946 .37079 .17056 .37186 .17213 .37122 .17104 .37015 Mtetra
.759 .753 .846 r
.17104 .37015 .17213 .37122 .17376 .37009 .17266 .36903 Mtetra
.711 .747 .88 r
.17266 .36903 .17376 .37009 .17535 .36929 .17425 .36823 Mtetra
.53 .694 .943 r
.17425 .36823 .17535 .36929 .17686 .36916 .17577 .3681 Mtetra
.916 .519 .198 r
.17577 .3681 .17686 .36916 .17797 .37282 .17688 .37169 Mtetra
.94 .683 .522 r
.17688 .37169 .17797 .37282 .15773 .57397 .15657 .57277 Mtetra
.945 .603 .342 r
.15657 .57277 .15773 .57397 .15867 .58013 .1575 .57907 Mtetra
.16 .522 .918 r
.1575 .57907 .15867 .58013 .16022 .58075 .15905 .57955 Mtetra
.66 .724 .896 r
.15905 .57955 .16022 .58075 .16188 .58021 .16073 .57896 Mtetra
.75 .736 .84 r
.16073 .57896 .16188 .58021 .16364 .57886 .16246 .57779 Mtetra
.689 .756 .903 r
.16246 .57779 .16364 .57886 .16548 .57664 .16415 .57708 Mtetra
.603 .951 .832 r
.16415 .57708 .16548 .57664 .16751 .57275 .16588 .576 Mtetra
.036 0 .055 r
.16588 .576 .16751 .57275 .17098 .55499 .1677 .57399 Mtetra
0 0 .184 r
.1677 .57399 .17098 .55499 .19214 .36751 .17093 .55862 Mtetra
0 0 .087 r
.17093 .55862 .19214 .36751 .19404 .36378 .19276 .36456 Mtetra
.963 .93 .71 r
.19276 .36456 .19404 .36378 .19576 .3619 .19463 .36121 Mtetra
.668 .127 0 r
.19463 .36121 .19576 .3619 .19721 .36253 .196 .36264 Mtetra
.923 .62 .452 r
.196 .36264 .19721 .36253 .19846 .36516 .19642 .37332 Mtetra
.93 .67 .523 r
.19642 .37332 .19846 .36516 .19856 .37909 .17778 .5705 Mtetra
.528 .299 .51 r
.17778 .5705 .19856 .37909 .1815 .56238 .17928 .57162 Mtetra
.491 .217 .426 r
.17928 .57162 .1815 .56238 .18314 .5622 .18095 .57117 Mtetra
.459 .187 .413 r
.18095 .57117 .18314 .5622 .18501 .55969 .18268 .57018 Mtetra
.488 .221 .435 r
.18268 .57018 .18501 .55969 .18671 .55887 .18437 .56958 Mtetra
.493 .226 .438 r
.18437 .56958 .18671 .55887 .18837 .55851 .18605 .56908 Mtetra
.492 .224 .436 r
.18605 .56908 .18837 .55851 .19004 .55809 .18773 .56855 Mtetra
.492 .225 .436 r
.18773 .56855 .19004 .55809 .1917 .55773 .18941 .56805 Mtetra
.492 .223 .435 r
.18941 .56805 .1917 .55773 .19336 .55736 .19109 .56754 Mtetra
.491 .222 .433 r
.19109 .56754 .19336 .55736 .19503 .55692 .19278 .56702 Mtetra
.512 .24 .44 r
.19278 .56702 .19503 .55692 .19652 .55837 .19442 .56696 Mtetra
.495 .217 .422 r
.19442 .56696 .19652 .55837 .19813 .55861 .19609 .56664 Mtetra
.442 .166 .397 r
.19609 .56664 .19813 .55861 .20001 .55609 .19783 .56554 Mtetra
.089 0 .268 r
.19783 .56554 .20001 .55609 .22028 .36123 .2 .56 Mtetra
0 0 .108 r
.2 .56 .22028 .36123 .22239 .35528 .22099 .35752 Mtetra
.976 .903 .559 r
.22099 .35752 .22239 .35528 .22422 .35227 .22308 .35174 Mtetra
.851 .851 .842 r
.22308 .35174 .22422 .35227 .22588 .351 .22478 .35006 Mtetra
.673 .768 .921 r
.22478 .35006 .22588 .351 .22747 .3504 .22638 .34945 Mtetra
.552 .73 .958 r
.22638 .34945 .22747 .3504 .22905 .35006 .22794 .34922 Mtetra
.605 .773 .961 r
.22794 .34922 .22905 .35006 .23062 .34969 .22952 .34883 Mtetra
.636 .777 .948 r
.22952 .34883 .23062 .34969 .2322 .3493 .23111 .34835 Mtetra
.642 .759 .933 r
.23111 .34835 .2322 .3493 .23379 .34888 .23271 .34786 Mtetra
.683 .754 .906 r
.23271 .34786 .23379 .34888 .23541 .34806 .23431 .3472 Mtetra
.692 .791 .926 r
.23431 .3472 .23541 .34806 .23704 .3472 .23592 .34651 Mtetra
.663 .823 .96 r
.23592 .34651 .23704 .3472 .23864 .34664 .23753 .34592 Mtetra
.642 .81 .964 r
.23753 .34592 .23864 .34664 .24015 .3471 .23913 .3454 Mtetra
.576 .604 .844 r
.23913 .3454 .24015 .3471 .24154 .34888 .2407 .34518 Mtetra
.477 .4 .69 r
.2407 .34518 .24154 .34888 .2426 .3544 .24221 .34564 Mtetra
.219 .121 .524 r
.24221 .34564 .2426 .3544 .22669 .55219 .2434 .34977 Mtetra
0 0 .152 r
.2434 .34977 .22669 .55219 .22795 .55664 .22716 .55149 Mtetra
0 0 .349 r
.22716 .55149 .22795 .55664 .22946 .55841 .22837 .55658 Mtetra
.176 .381 .826 r
.22837 .55658 .22946 .55841 .23109 .55882 .22996 .5575 Mtetra
.612 .692 .9 r
.22996 .5575 .23109 .55882 .23279 .55846 .23166 .5571 Mtetra
.71 .717 .855 r
.23166 .5571 .23279 .55846 .23453 .55754 .2334 .55618 Mtetra
.688 .712 .866 r
.2334 .55618 .23453 .55754 .23635 .5558 .23514 .55541 Mtetra
.711 .905 .964 r
.23514 .55541 .23635 .5558 .23826 .55294 .23688 .55453 Mtetra
0 0 0 r
.23688 .55453 .23826 .55294 .24038 .54762 .23868 .55302 Mtetra
0 0 .082 r
.23868 .55302 .24038 .54762 .25866 .34966 .24073 .5486 Mtetra
0 0 .142 r
.24073 .5486 .25866 .34966 .26083 .34252 .2593 .34688 Mtetra
.881 .838 .373 r
.2593 .34688 .26083 .34252 .26264 .33958 .26153 .33906 Mtetra
.879 .847 .808 r
.26153 .33906 .26264 .33958 .26432 .33827 .26327 .337 Mtetra
.659 .705 .881 r
.26327 .337 .26432 .33827 .26593 .33776 .26489 .33643 Mtetra
.532 .643 .905 r
.26489 .33643 .26593 .33776 .26752 .33757 .26647 .33633 Mtetra
.568 .678 .913 r
.26647 .33633 .26752 .33757 .26912 .33727 .26806 .33611 Mtetra
.626 .714 .909 r
.26806 .33611 .26912 .33727 .27073 .33681 .26967 .33567 Mtetra
.633 .721 .91 r
.26967 .33567 .27073 .33681 .27235 .33632 .27128 .33521 Mtetra
.653 .733 .908 r
.27128 .33521 .27235 .33632 .27397 .33575 .27291 .33467 Mtetra
.671 .743 .905 r
.27291 .33467 .27397 .33575 .2756 .33511 .27453 .33405 Mtetra
.682 .75 .903 r
.27453 .33405 .2756 .33511 .27724 .33443 .27617 .33339 Mtetra
.689 .754 .901 r
.27617 .33339 .27724 .33443 .27887 .33373 .2778 .33269 Mtetra
.694 .757 .9 r
.2778 .33269 .27887 .33373 .28051 .33301 .27944 .33197 Mtetra
.698 .758 .899 r
.27944 .33197 .28051 .33301 .28215 .33225 .28109 .33123 Mtetra
.702 .763 .9 r
.28109 .33123 .28215 .33225 .2838 .33142 .28273 .33047 Mtetra
.704 .778 .909 r
.28273 .33047 .2838 .33142 .28545 .33056 .28437 .32971 Mtetra
.702 .798 .925 r
.28437 .32971 .28545 .33056 .2871 .32973 .28602 .32897 Mtetra
.689 .816 .944 r
.28602 .32897 .2871 .32973 .28875 .32899 .28766 .32828 Mtetra
.674 .825 .956 r
.28766 .32828 .28875 .32899 .29039 .32834 .2893 .32764 Mtetra
.666 .825 .96 r
.2893 .32764 .29039 .32834 .29202 .32773 .29093 .32703 Mtetra
.662 .824 .961 r
.29093 .32703 .29202 .32773 .29366 .32713 .29257 .32642 Mtetra
.659 .824 .962 r
.29257 .32642 .29366 .32713 .2953 .32653 .29421 .32583 Mtetra
.655 .824 .965 r
.29421 .32583 .2953 .32653 .29693 .32594 .29585 .32525 Mtetra
.651 .825 .966 r
.29585 .32525 .29693 .32594 .29857 .32536 .29749 .32467 Mtetra
.648 .826 .969 r
.29749 .32467 .29857 .32536 .30021 .32478 .29912 .32411 Mtetra
.644 .828 .971 r
.29912 .32411 .30021 .32478 .30185 .32422 .30076 .32355 Mtetra
.639 .83 .974 r
.30076 .32355 .30185 .32422 .30349 .32366 .3024 .32301 Mtetra
.635 .832 .976 r
.3024 .32301 .30349 .32366 .30513 .32311 .30404 .32247 Mtetra
.633 .835 .978 r
.30404 .32247 .30513 .32311 .30677 .32256 .30568 .32194 Mtetra
.633 .838 .979 r
.30568 .32194 .30677 .32256 .30841 .322 .30733 .3214 Mtetra
.633 .842 .98 r
.30733 .3214 .30841 .322 .31006 .32144 .30897 .32085 Mtetra
.634 .846 .981 r
.30897 .32085 .31006 .32144 .3117 .32088 .31061 .3203 Mtetra
.635 .85 .982 r
.31061 .3203 .3117 .32088 .31335 .3203 .31226 .31974 Mtetra
.637 .853 .982 r
.31226 .31974 .31335 .3203 .315 .31973 .31391 .31917 Mtetra
.638 .856 .982 r
.31391 .31917 .315 .31973 .31664 .31915 .31556 .3186 Mtetra
.64 .858 .982 r
.31556 .3186 .31664 .31915 .31829 .31856 .31721 .31801 Mtetra
.643 .859 .982 r
.31721 .31801 .31829 .31856 .31995 .31797 .31886 .31742 Mtetra
.645 .86 .981 r
.31886 .31742 .31995 .31797 .3216 .31737 .32052 .31682 Mtetra
.647 .86 .98 r
.32052 .31682 .3216 .31737 .32325 .31677 .32217 .31622 Mtetra
.65 .859 .979 r
.32217 .31622 .32325 .31677 .32491 .31617 .32383 .31561 Mtetra
.652 .858 .978 r
.32383 .31561 .32491 .31617 .32657 .31557 .32549 .31499 Mtetra
.654 .856 .977 r
.32549 .31499 .32657 .31557 .32822 .31496 .32715 .31437 Mtetra
.657 .854 .975 r
.32715 .31437 .32822 .31496 .32988 .31435 .32881 .31375 Mtetra
.659 .852 .974 r
.32881 .31375 .32988 .31435 .33154 .31374 .33047 .31313 Mtetra
.662 .848 .971 r
.33047 .31313 .33154 .31374 .33321 .31312 .33213 .31249 Mtetra
.665 .846 .969 r
.33213 .31249 .33321 .31312 .33487 .3125 .3338 .31185 Mtetra
.663 .842 .968 r
.3338 .31185 .33487 .3125 .33653 .3119 .33546 .31122 Mtetra
.657 .834 .968 r
.33546 .31122 .33653 .3119 .33819 .31136 .33713 .31062 Mtetra
.652 .816 .962 r
.33713 .31062 .33819 .31136 .33985 .31091 .33879 .31004 Mtetra
.658 .791 .945 r
.33879 .31004 .33985 .31091 .3415 .31045 .34046 .30946 Mtetra
.668 .766 .924 r
.34046 .30946 .3415 .31045 .34317 .30993 .34213 .30885 Mtetra
.678 .749 .904 r
.34213 .30885 .34317 .30993 .34483 .30932 .3438 .30818 Mtetra
.681 .74 .895 r
.3438 .30818 .34483 .30932 .34651 .30865 .34547 .3075 Mtetra
.714 .746 .878 r
.34547 .3075 .34651 .30865 .34819 .3078 .34716 .30664 Mtetra
.74 .752 .861 r
.34716 .30664 .34819 .3078 .34989 .30677 .34885 .30561 Mtetra
.664 .731 .9 r
.34885 .30561 .34989 .30677 .35157 .30603 .35052 .30501 Mtetra
.04 .439 .872 r
.35052 .30501 .35157 .30603 .3532 .30611 .35213 .3057 Mtetra
.918 .539 .279 r
.35213 .3057 .3532 .30611 .35474 .308 .35348 .3109 Mtetra
.953 .68 .481 r
.35348 .3109 .35474 .308 .35612 .31292 .3441 .51445 Mtetra
.533 .303 .511 r
.3441 .51445 .35612 .31292 .34744 .50671 .34566 .51822 Mtetra
.508 .241 .446 r
.34566 .51822 .34744 .50671 .34922 .50605 .34743 .51801 Mtetra
.484 .222 .441 r
.34743 .51801 .34922 .50605 .3511 .50375 .34923 .51713 Mtetra
.494 .236 .451 r
.34923 .51713 .3511 .50375 .35259 .5088 .35103 .51643 Mtetra
.519 .232 .418 r
.35103 .51643 .35259 .5088 .35405 .5146 .35278 .51662 Mtetra
.471 .06 .177 r
.35278 .51662 .35405 .5146 .35569 .51715 .35454 .51676 Mtetra
.279 .741 .95 r
.35454 .51676 .35569 .51715 .3574 .51819 .35631 .51669 Mtetra
.608 .67 .884 r
.35631 .51669 .3574 .51819 .35918 .51803 .3581 .51629 Mtetra
.63 .645 .847 r
.3581 .51629 .35918 .51803 .36097 .51752 .3599 .51578 Mtetra
.62 .64 .848 r
.3599 .51578 .36097 .51752 .36277 .51692 .36169 .51531 Mtetra
.577 .64 .876 r
.36169 .51531 .36277 .51692 .36457 .51644 .36348 .51505 Mtetra
.667 .709 .879 r
.36348 .51505 .36457 .51644 .36638 .51567 .36529 .51437 Mtetra
.81 .756 .802 r
.36529 .51437 .36638 .51567 .36822 .51427 .36715 .51254 Mtetra
.902 .718 .643 r
.36715 .51254 .36822 .51427 .37013 .51143 .3692 .50679 Mtetra
.956 .686 .484 r
.3692 .50679 .37013 .51143 .37215 .50615 .38046 .30164 Mtetra
.54 .313 .519 r
.38046 .30164 .37215 .50615 .38303 .30539 .3824 .29552 Mtetra
.602 .406 .588 r
.3824 .29552 .38303 .30539 .38504 .29777 .38415 .29379 Mtetra
.633 .495 .677 r
.38415 .29379 .38504 .29777 .38685 .29463 .38586 .29278 Mtetra
.657 .63 .811 r
.38586 .29278 .38685 .29463 .3886 .29282 .38756 .2921 Mtetra
.666 .83 .963 r
.38756 .2921 .3886 .29282 .39031 .29201 .38926 .29146 Mtetra
.606 .853 .991 r
.38926 .29146 .39031 .29201 .392 .29155 .39095 .29094 Mtetra
.594 .837 .99 r
.39095 .29094 .392 .29155 .39368 .29123 .39265 .29047 Mtetra
.629 .81 .97 r
.39265 .29047 .39368 .29123 .39537 .29082 .39434 .28995 Mtetra
.637 .789 .955 r
.39434 .28995 .39537 .29082 .39706 .29042 .39604 .28943 Mtetra
.648 .765 .934 r
.39604 .28943 .39706 .29042 .39876 .28998 .39774 .28888 Mtetra
.663 .747 .912 r
.39774 .28888 .39876 .28998 .40046 .28942 .39944 .28827 Mtetra
.67 .738 .901 r
.39944 .28827 .40046 .28942 .40216 .2888 .40115 .28762 Mtetra
.677 .736 .895 r
.40115 .28762 .40216 .2888 .40387 .2881 .40286 .28695 Mtetra
.686 .743 .895 r
.40286 .28695 .40387 .2881 .40559 .2873 .40457 .28622 Mtetra
.688 .761 .907 r
.40457 .28622 .40559 .2873 .4073 .28648 .40628 .2855 Mtetra
.699 .783 .916 r
.40628 .2855 .4073 .28648 .40902 .28566 .40799 .28473 Mtetra
.749 .804 .896 r
.40799 .28473 .40902 .28566 .41074 .28475 .40972 .28371 Mtetra
.671 .762 .919 r
.40972 .28371 .41074 .28475 .41245 .28411 .41143 .28307 Mtetra
.35 .624 .955 r
.41143 .28307 .41245 .28411 .41414 .28403 .41311 .2833 Mtetra
.897 .477 .137 r
.41311 .2833 .41414 .28403 .41577 .28574 .41466 .28739 Mtetra
.96 .681 .461 r
.41466 .28739 .41577 .28574 .41731 .2901 .40922 .49193 Mtetra
.536 .305 .511 r
.40922 .49193 .41731 .2901 .41229 .48765 .41084 .49741 Mtetra
.517 .242 .436 r
.41084 .49741 .41229 .48765 .41404 .48935 .41265 .4975 Mtetra
.469 .191 .408 r
.41265 .4975 .41404 .48935 .41589 .488 .41449 .49673 Mtetra
.452 .18 .409 r
.41449 .49673 .41589 .488 .41782 .48459 .41634 .49557 Mtetra
.486 .22 .436 r
.41634 .49557 .41782 .48459 .4198 .4791 .41819 .49483 Mtetra
.501 .247 .461 r
.41819 .49483 .4198 .4791 .42169 .47656 .42003 .49417 Mtetra
.509 .257 .468 r
.42003 .49417 .42169 .47656 .42327 .48395 .42186 .49373 Mtetra
.518 .243 .436 r
.42186 .49373 .42327 .48395 .42487 .49116 .42368 .49385 Mtetra
.483 .105 .247 r
.42368 .49385 .42487 .49116 .42661 .49403 .4255 .49396 Mtetra
.071 .632 .773 r
.4255 .49396 .42661 .49403 .4284 .49537 .42733 .49392 Mtetra
.629 .691 .889 r
.42733 .49392 .4284 .49537 .43023 .49507 .42917 .49342 Mtetra
.648 .668 .856 r
.42917 .49342 .43023 .49507 .43208 .49441 .43102 .4928 Mtetra
.655 .676 .858 r
.43102 .4928 .43208 .49441 .43394 .49361 .43287 .49214 Mtetra
.63 .687 .885 r
.43287 .49214 .43394 .49361 .43578 .4932 .43472 .49163 Mtetra
.629 .672 .872 r
.43472 .49163 .43578 .4932 .43763 .49278 .43657 .49112 Mtetra
.632 .661 .86 r
.43657 .49112 .43763 .49278 .43947 .49229 .43842 .49059 Mtetra
.646 .661 .85 r
.43842 .49059 .43947 .49229 .44133 .49158 .44027 .48997 Mtetra
.653 .676 .859 r
.44027 .48997 .44133 .49158 .44319 .49082 .44213 .48932 Mtetra
.656 .695 .874 r
.44213 .48932 .44319 .49082 .44505 .49004 .44398 .48867 Mtetra
.543 .669 .919 r
.44398 .48867 .44505 .49004 .4469 .48969 .44583 .4885 Mtetra
.628 .736 .926 r
.44583 .4885 .4469 .48969 .44876 .48915 .44769 .48799 Mtetra
.754 .778 .873 r
.44769 .48799 .44876 .48915 .45062 .4882 .44956 .48681 Mtetra
.913 .75 .666 r
.44956 .48681 .45062 .4882 .45253 .48563 .45151 .48206 Mtetra
.964 .687 .46 r
.45151 .48206 .45253 .48563 .45447 .48102 .45779 .27755 Mtetra
.547 .318 .52 r
.45779 .27755 .45447 .48102 .46045 .282 .45972 .26808 Mtetra
.589 .382 .569 r
.45972 .26808 .46045 .282 .46242 .27068 .4615 .26603 Mtetra
.63 .478 .658 r
.4615 .26603 .46242 .27068 .46422 .26715 .46325 .26487 Mtetra
.648 .589 .774 r
.46325 .26487 .46422 .26715 .46599 .26505 .465 .26414 Mtetra
.673 .794 .94 r
.465 .26414 .46599 .26505 .46774 .26424 .46674 .26347 Mtetra
.633 .817 .971 r
.46674 .26347 .46774 .26424 .46948 .26381 .46849 .26292 Mtetra
.626 .785 .958 r
.46849 .26292 .46948 .26381 .47123 .26355 .47024 .26242 Mtetra
.744 .77 .874 r
.47024 .26242 .47123 .26355 .47298 .26257 .47199 .26136 Mtetra
.699 .744 .886 r
.47199 .26136 .47298 .26257 .47473 .26171 .47375 .26056 Mtetra
.557 .702 .938 r
.47375 .26056 .47473 .26171 .47648 .26121 .47549 .26032 Mtetra
.768 .286 0 r
.47549 .26032 .47648 .26121 .47821 .26213 .47719 .26301 Mtetra
.966 .681 .439 r
.47719 .26301 .47821 .26213 .47992 .26478 .47595 .46378 Mtetra
.547 .313 .512 r
.47595 .46378 .47992 .26478 .47899 .45589 .47765 .47515 Mtetra
.546 .289 .478 r
.47765 .47515 .47899 .45589 .48062 .47316 .4795 .47642 Mtetra
.487 .13 .285 r
.4795 .47642 .48062 .47316 .48245 .47611 .48137 .4765 Mtetra
0 0 0 r
.48137 .4765 .48245 .47611 .48431 .47733 .48325 .47607 Mtetra
.509 .676 .94 r
.48325 .47607 .48431 .47733 .48618 .47746 .48513 .47598 Mtetra
.619 .686 .891 r
.48513 .47598 .48618 .47746 .48806 .47694 .48702 .47551 Mtetra
.738 .736 .849 r
.48702 .47551 .48806 .47694 .48996 .47581 .48891 .47434 Mtetra
.902 .751 .684 r
.48891 .47434 .48996 .47581 .49186 .47346 .49083 .47019 Mtetra
.967 .687 .447 r
.49083 .47019 .49186 .47346 .49378 .4693 .49467 .26989 Mtetra
.557 .326 .521 r
.49467 .26989 .49378 .4693 .49581 .45326 .49657 .25543 Mtetra
.532 .306 .518 r
.49657 .25543 .49581 .45326 .4993 .25827 .49836 .25301 Mtetra
.623 .462 .644 r
.49836 .25301 .4993 .25827 .5011 .25436 .50013 .25179 Mtetra
.641 .566 .754 r
.50013 .25179 .5011 .25436 .50288 .25211 .5019 .25105 Mtetra
.665 .765 .925 r
.5019 .25105 .50288 .25211 .50465 .25116 .50367 .25041 Mtetra
.621 .82 .977 r
.50367 .25041 .50465 .25116 .50642 .25073 .50544 .24988 Mtetra
.607 .792 .97 r
.50544 .24988 .50642 .25073 .50819 .25052 .50721 .24942 Mtetra
.729 .776 .89 r
.50721 .24942 .50819 .25052 .50996 .24977 .50899 .24846 Mtetra
.697 .728 .875 r
.50899 .24846 .50996 .24977 .51173 .24901 .51076 .24763 Mtetra
.577 .669 .902 r
.51076 .24763 .51173 .24901 .51351 .24858 .51254 .24736 Mtetra
.607 .145 0 r
.51254 .24736 .51351 .24858 .51528 .24937 .5143 .24977 Mtetra
.969 .68 .424 r
.5143 .24977 .51528 .24937 .51705 .25189 .51551 .44976 Mtetra
.549 .315 .512 r
.51551 .44976 .51705 .25189 .51848 .43122 .51737 .46221 Mtetra
.542 .295 .491 r
.51737 .46221 .51848 .43122 .52032 .46012 .51928 .46374 Mtetra
.492 .144 .305 r
.51928 .46374 .52032 .46012 .52222 .46322 .52118 .46382 Mtetra
.027 0 0 r
.52118 .46382 .52222 .46322 .52413 .4645 .52309 .46337 Mtetra
.541 .72 .956 r
.52309 .46337 .52413 .4645 .52604 .46455 .52501 .46313 Mtetra
.624 .7 .899 r
.52501 .46313 .52604 .46455 .52795 .4639 .52692 .46263 Mtetra
.744 .766 .871 r
.52692 .46263 .52795 .4639 .52987 .46264 .52883 .46147 Mtetra
.915 .785 .703 r
.52883 .46147 .52987 .46264 .53178 .46037 .53074 .45768 Mtetra
.953 .694 .508 r
.53074 .45768 .53178 .46037 .53368 .45647 .53261 .43689 Mtetra
.952 .665 .456 r
.53261 .43689 .53368 .45647 .53557 .44547 .53394 .24248 Mtetra
.533 .307 .518 r
.53394 .24248 .53557 .44547 .53671 .24606 .53573 .23977 Mtetra
.609 .438 .625 r
.53573 .23977 .53671 .24606 .53849 .2418 .53752 .23857 Mtetra
.622 .519 .715 r
.53752 .23857 .53849 .2418 .54027 .23939 .53931 .23784 Mtetra
.662 .679 .856 r
.53931 .23784 .54027 .23939 .54206 .23818 .54111 .23716 Mtetra
.66 .775 .934 r
.54111 .23716 .54206 .23818 .54386 .23753 .5429 .23654 Mtetra
.644 .774 .943 r
.5429 .23654 .54386 .23753 .54566 .2371 .5447 .23597 Mtetra
.737 .774 .883 r
.5447 .23597 .54566 .2371 .54745 .23614 .54649 .23494 Mtetra
.721 .76 .883 r
.54649 .23494 .54745 .23614 .54925 .2352 .54829 .234 Mtetra
.586 .709 .928 r
.54829 .234 .54925 .2352 .55105 .23489 .55009 .23366 Mtetra
.619 .162 0 r
.55009 .23366 .55105 .23489 .55288 .23768 .55192 .23625 Mtetra
.973 .681 .406 r
.55192 .23625 .55288 .23768 .55671 .44506 .55568 .44258 Mtetra
.895 .544 .065 r
.55568 .44258 .55671 .44506 .55872 .4526 .5577 .45103 Mtetra
.1 .382 .842 r
.5577 .45103 .55872 .4526 .56067 .45355 .55965 .45214 Mtetra
.641 .709 .897 r
.55965 .45214 .56067 .45355 .56261 .45284 .56159 .45155 Mtetra
.734 .763 .875 r
.56159 .45155 .56261 .45284 .56454 .45162 .56352 .45044 Mtetra
.594 .735 .942 r
.56352 .45044 .56454 .45162 .56648 .45123 .56546 .45003 Mtetra
.541 .708 .948 r
.56546 .45003 .56648 .45123 .56843 .45111 .56741 .44981 Mtetra
.693 .75 .895 r
.56741 .44981 .56843 .45111 .57037 .45036 .56935 .44896 Mtetra
.901 .769 .707 r
.56935 .44896 .57037 .45036 .57227 .44686 .57125 .44534 Mtetra
.974 .686 .416 r
.57125 .44534 .57227 .44686 .57127 .25099 .57022 .24359 Mtetra
.871 .611 .542 r
.57022 .24359 .57127 .25099 .57276 .22891 .57181 .22773 Mtetra
.878 .789 .758 r
.57181 .22773 .57276 .22891 .57454 .22632 .5736 .22517 Mtetra
.688 .762 .908 r
.5736 .22517 .57454 .22632 .57636 .22557 .57541 .22441 Mtetra
.559 .708 .94 r
.57541 .22441 .57636 .22557 .57818 .22534 .57724 .22415 Mtetra
.676 .749 .906 r
.57724 .22415 .57818 .22534 .58 .22475 .57906 .22344 Mtetra
.712 .74 .874 r
.57906 .22344 .58 .22475 .58182 .22391 .58087 .22252 Mtetra
.612 .686 .895 r
.58087 .22252 .58182 .22391 .58364 .22339 .5827 .22209 Mtetra
0 .189 .713 r
.5827 .22209 .58364 .22339 .58548 .22382 .58456 .22365 Mtetra
.941 .579 .279 r
.58456 .22365 .58548 .22382 .58736 .22582 .5866 .23367 Mtetra
.966 .667 .41 r
.5866 .23367 .58736 .22582 .58935 .23284 .59268 .43692 Mtetra
.53 .3 .51 r
.59268 .43692 .58935 .23284 .59556 .43402 .5947 .4393 Mtetra
.509 .193 .367 r
.5947 .4393 .59556 .43402 .59762 .43789 .59668 .43944 Mtetra
.297 0 .006 r
.59668 .43944 .59762 .43789 .59963 .43945 .59864 .439 Mtetra
.395 .802 .981 r
.59864 .439 .59963 .43945 .60162 .44002 .60062 .43875 Mtetra
.554 .702 .938 r
.60062 .43875 .60162 .44002 .6036 .43982 .60259 .43849 Mtetra
.704 .75 .888 r
.60259 .43849 .6036 .43982 .60555 .43879 .60455 .43756 Mtetra
.907 .794 .724 r
.60455 .43756 .60555 .43879 .60745 .43533 .60645 .43419 Mtetra
.976 .686 .402 r
.60645 .43419 .60745 .43533 .60436 .23984 .60361 .24598 Mtetra
.971 .74 .311 r
.60361 .24598 .60436 .23984 .60563 .21732 .6047 .21615 Mtetra
.896 .794 .74 r
.6047 .21615 .60563 .21732 .60741 .21449 .60648 .2133 Mtetra
.697 .759 .899 r
.60648 .2133 .60741 .21449 .60924 .21368 .60831 .21247 Mtetra
.572 .706 .933 r
.60831 .21247 .60924 .21368 .61109 .2134 .61016 .21218 Mtetra
.652 .737 .912 r
.61016 .21218 .61109 .2134 .61293 .21288 .612 .21157 Mtetra
.716 .744 .874 r
.612 .21157 .61293 .21288 .61477 .21203 .61383 .21062 Mtetra
.626 .692 .891 r
.61383 .21062 .61477 .21203 .61661 .21145 .61568 .21012 Mtetra
0 .336 .818 r
.61568 .21012 .61661 .21145 .61848 .21172 .61758 .21131 Mtetra
.923 .531 .192 r
.61758 .21131 .61848 .21172 .62041 .21348 .61968 .21854 Mtetra
.97 .669 .391 r
.61968 .21854 .62041 .21348 .62245 .21889 .6281 .42478 Mtetra
.531 .3 .51 r
.6281 .42478 .62245 .21889 .63095 .42146 .6302 .42774 Mtetra
.517 .213 .39 r
.6302 .42774 .63095 .42146 .6331 .426 .63222 .42796 Mtetra
.354 0 .104 r
.63222 .42796 .6331 .426 .63516 .42776 .63421 .42755 Mtetra
.315 .793 .913 r
.63421 .42755 .63516 .42776 .6372 .4285 .63621 .42723 Mtetra
.535 .695 .942 r
.63621 .42723 .6372 .4285 .63921 .4285 .63822 .42703 Mtetra
.691 .726 .877 r
.63822 .42703 .63921 .4285 .6412 .42763 .6402 .42615 Mtetra
.889 .772 .727 r
.6402 .42615 .6412 .42763 .64309 .42422 .64211 .42294 Mtetra
.977 .683 .387 r
.64211 .42294 .64309 .42422 .63742 .21657 .63667 .21998 Mtetra
.963 .763 .321 r
.63667 .21998 .63742 .21657 .63885 .20444 .63795 .20373 Mtetra
.936 .859 .739 r
.63795 .20373 .63885 .20444 .64064 .20208 .63972 .20072 Mtetra
.678 .724 .884 r
.63972 .20072 .64064 .20208 .64255 .20264 .64158 .19997 Mtetra
.497 .481 .769 r
.64158 .19997 .64255 .20264 .64454 .20526 .64348 .20022 Mtetra
.334 .276 .641 r
.64348 .20022 .64454 .20526 .64743 .23009 .64545 .20232 Mtetra
.97 .687 .274 r
.64545 .20232 .64743 .23009 .65694 .41652 .65533 .39968 Mtetra
0 0 .414 r
.65533 .39968 .65694 .41652 .65909 .41953 .65807 .41715 Mtetra
0 .151 .685 r
.65807 .41715 .65909 .41953 .66117 .42064 .6602 .41958 Mtetra
.393 .667 .969 r
.6602 .41958 .66117 .42064 .6632 .42067 .66224 .4197 Mtetra
.712 .827 .937 r
.66224 .4197 .6632 .42067 .6652 .41981 .66424 .41875 Mtetra
.906 .828 .758 r
.66424 .41875 .6652 .41981 .66712 .41702 .66615 .41585 Mtetra
.979 .743 .51 r
.66615 .41585 .66712 .41702 .66864 .40532 .66768 .40419 Mtetra
.977 .681 .375 r
.66768 .40419 .66864 .40532 .66132 .19821 .66041 .19697 Mtetra
.922 .789 .696 r
.66041 .19697 .66132 .19821 .66306 .19461 .66215 .19337 Mtetra
.719 .762 .886 r
.66215 .19337 .66306 .19461 .66492 .19365 .66401 .1924 Mtetra
.594 .712 .926 r
.66401 .1924 .66492 .19365 .66681 .19327 .6659 .19202 Mtetra
.623 .725 .919 r
.6659 .19202 .66681 .19327 .66869 .19277 .66779 .19152 Mtetra
.737 .768 .878 r
.66779 .19152 .66869 .19277 .67055 .1917 .66965 .19045 Mtetra
.647 .735 .913 r
.66965 .19045 .67055 .1917 .67243 .1911 .67153 .18985 Mtetra
.098 .423 .868 r
.67153 .18985 .67243 .1911 .67439 .19204 .67349 .19079 Mtetra
.918 .542 .121 r
.67349 .19079 .67439 .19204 .67676 .20102 .67586 .19976 Mtetra
.975 .67 .349 r
.67586 .19976 .67676 .20102 .68923 .40835 .68827 .40714 Mtetra
.608 .148 0 r
.68827 .40714 .68923 .40835 .69145 .4114 .69049 .41019 Mtetra
.423 .652 .954 r
.69049 .41019 .69145 .4114 .69352 .41154 .69256 .41031 Mtetra
.715 .781 .904 r
.69256 .41031 .69352 .41154 .69553 .41055 .69457 .40931 Mtetra
.891 .811 .763 r
.69457 .40931 .69553 .41055 .69745 .40773 .69649 .40654 Mtetra
.98 .749 .516 r
.69649 .40654 .69745 .40773 .69889 .39616 .69799 .39598 Mtetra
.978 .679 .36 r
.69799 .39598 .69889 .39616 .68955 .18781 .68868 .18695 Mtetra
.956 .83 .679 r
.68868 .18695 .68955 .18781 .69128 .18405 .6904 .18305 Mtetra
.721 .814 .923 r
.6904 .18305 .69128 .18405 .69316 .1832 .69228 .18211 Mtetra
.566 .733 .953 r
.69228 .18211 .69316 .1832 .69508 .18299 .69419 .18179 Mtetra
.529 .693 .943 r
.69419 .18179 .69508 .18299 .69701 .18291 .69612 .18162 Mtetra
.652 .731 .908 r
.69612 .18162 .69701 .18291 .69891 .18229 .69802 .18099 Mtetra
.66 .733 .904 r
.69802 .18099 .69891 .18229 .70081 .18159 .69992 .18033 Mtetra
.699 .754 .894 r
.69992 .18033 .70081 .18159 .70269 .18066 .70181 .17947 Mtetra
.764 .789 .873 r
.70181 .17947 .70269 .18066 .70455 .17932 .70368 .17823 Mtetra
.686 .785 .926 r
.70368 .17823 .70455 .17932 .70644 .17844 .70557 .17745 Mtetra
.227 .567 .939 r
.70557 .17745 .70644 .17844 .70841 .17881 .70755 .17793 Mtetra
.883 .473 .043 r
.70755 .17793 .70841 .17881 .71072 .18463 .7099 .18441 Mtetra
.974 .665 .334 r
.7099 .18441 .71072 .18463 .72583 .39545 .72492 .39455 Mtetra
.744 .272 0 r
.72492 .39455 .72583 .39545 .72818 .39949 .72724 .39831 Mtetra
.369 .63 .954 r
.72724 .39831 .72818 .39949 .7303 .39978 .72936 .39856 Mtetra
.696 .779 .916 r
.72936 .39856 .7303 .39978 .73234 .39889 .7314 .39766 Mtetra
.876 .817 .788 r
.7314 .39766 .73234 .39889 .73428 .39639 .73334 .3952 Mtetra
.981 .763 .534 r
.73334 .3952 .73428 .39639 .73576 .38691 .73487 .38639 Mtetra
.977 .675 .343 r
.73487 .38639 .73576 .38691 .72387 .1761 .72302 .17527 Mtetra
.971 .828 .645 r
.72302 .17527 .72387 .1761 .72554 .1718 .72468 .17079 Mtetra
.738 .822 .917 r
.72468 .17079 .72554 .1718 .72744 .17086 .72658 .16976 Mtetra
.583 .741 .952 r
.72658 .16976 .72744 .17086 .72939 .17058 .72852 .16938 Mtetra
.517 .687 .944 r
.72852 .16938 .72939 .17058 .73135 .17055 .73047 .16924 Mtetra
.651 .73 .907 r
.73047 .16924 .73135 .17055 .73327 .16993 .7324 .16861 Mtetra
.659 .731 .903 r
.7324 .16861 .73327 .16993 .7352 .16924 .73432 .16794 Mtetra
.685 .746 .898 r
.73432 .16794 .7352 .16924 .73711 .16837 .73624 .16714 Mtetra
.766 .787 .87 r
.73624 .16714 .73711 .16837 .73898 .167 .73812 .16588 Mtetra
.697 .786 .919 r
.73812 .16588 .73898 .167 .74089 .16605 .74004 .16503 Mtetra
.381 .655 .965 r
.74004 .16503 .74089 .16605 .74287 .16611 .74202 .16519 Mtetra
.833 .403 0 r
.74202 .16519 .74287 .16611 .7452 .17099 .7444 .17054 Mtetra
.973 .661 .314 r
.7444 .17054 .7452 .17099 .7629 .38261 .76201 .38178 Mtetra
.786 .327 0 r
.76201 .38178 .7629 .38261 .76539 .38743 .76447 .38624 Mtetra
.323 .601 .947 r
.76447 .38624 .76539 .38743 .76756 .38786 .76664 .38662 Mtetra
.674 .772 .924 r
.76664 .38662 .76756 .38786 .76963 .38707 .76871 .38583 Mtetra
.856 .819 .812 r
.76871 .38583 .76963 .38707 .7716 .38488 .77068 .38366 Mtetra
.981 .773 .551 r
.77068 .38366 .7716 .38488 .77311 .37673 .77223 .37598 Mtetra
.976 .67 .324 r
.77223 .37598 .77311 .37673 .75862 .1643 .75779 .1635 Mtetra
.982 .822 .608 r
.75779 .1635 .75862 .1643 .76022 .15938 .75939 .15837 Mtetra
.759 .831 .908 r
.75939 .15837 .76022 .15938 .76213 .15832 .76129 .15721 Mtetra
.604 .753 .949 r
.76129 .15721 .76213 .15832 .7641 .15796 .76325 .15675 Mtetra
.52 .689 .945 r
.76325 .15675 .7641 .15796 .7661 .15792 .76524 .15661 Mtetra
.736 .766 .876 r
.76524 .15661 .7661 .15792 .76801 .15681 .76715 .1555 Mtetra
.667 .74 .905 r
.76715 .1555 .76801 .15681 .76995 .15607 .76909 .15479 Mtetra
.445 .633 .935 r
.76909 .15479 .76995 .15607 .77196 .15619 .77111 .15491 Mtetra
.795 .385 0 r
.77111 .15491 .77196 .15619 .77448 .16234 .77359 .16066 Mtetra
.971 .657 .293 r
.77359 .16066 .77448 .16234 .79433 .37396 .79339 .37224 Mtetra
0 0 .373 r
.79339 .37224 .79433 .37396 .79684 .37815 .79592 .37662 Mtetra
.395 .577 .912 r
.79592 .37662 .79684 .37815 .79903 .3784 .79811 .37698 Mtetra
.663 .737 .905 r
.79811 .37698 .79903 .3784 .80112 .37755 .80021 .37623 Mtetra
.827 .808 .833 r
.80021 .37623 .80112 .37755 .80311 .37555 .80222 .37434 Mtetra
.904 .741 .668 r
.13133 .58706 .13253 .58803 .13475 .58247 .13352 .58183 Mtetra
.937 .687 .534 r
.13352 .58183 .13475 .58247 .15944 .38008 .15828 .37946 Mtetra
.925 .743 .636 r
.15828 .37946 .15944 .38008 .16165 .37374 .16054 .37273 Mtetra
.776 .762 .84 r
.16054 .37273 .16165 .37374 .16328 .37252 .16218 .37149 Mtetra
.639 .736 .918 r
.16218 .37149 .16328 .37252 .16483 .37207 .16373 .37103 Mtetra
.51 .689 .948 r
.16373 .37103 .16483 .37207 .16633 .372 .16523 .37093 Mtetra
.669 .737 .901 r
.16523 .37093 .16633 .372 .1679 .37141 .1668 .37035 Mtetra
.679 .739 .896 r
.1668 .37035 .1679 .37141 .16946 .37079 .16837 .36971 Mtetra
.685 .739 .892 r
.16837 .36971 .16946 .37079 .17104 .37015 .16994 .36905 Mtetra
.766 .748 .837 r
.16994 .36905 .17104 .37015 .17266 .36903 .17157 .36786 Mtetra
.718 .729 .859 r
.17157 .36786 .17266 .36903 .17425 .36823 .17317 .36699 Mtetra
.57 .671 .907 r
.17317 .36699 .17425 .36823 .17577 .3681 .1747 .36677 Mtetra
.905 .497 .118 r
.1747 .36677 .17577 .3681 .17688 .37169 .17583 .37012 Mtetra
.94 .684 .522 r
.17583 .37012 .17688 .37169 .15657 .57277 .15548 .57097 Mtetra
.959 .627 .331 r
.15548 .57097 .15657 .57277 .1575 .57907 .15633 .57795 Mtetra
.21 .541 .927 r
.15633 .57795 .1575 .57907 .15905 .57955 .15789 .5784 Mtetra
.668 .734 .899 r
.15789 .5784 .15905 .57955 .16073 .57896 .15956 .57777 Mtetra
.743 .744 .852 r
.15956 .57777 .16073 .57896 .16246 .57779 .16129 .57669 Mtetra
.521 .695 .948 r
.16129 .57669 .16246 .57779 .16415 .57708 .16292 .57656 Mtetra
.516 .826 1 r
.16292 .57656 .16415 .57708 .16588 .576 .16457 .57623 Mtetra
.625 .959 .893 r
.16457 .57623 .16588 .576 .1677 .57399 .16628 .57526 Mtetra
.985 .888 .644 r
.16628 .57526 .1677 .57399 .17093 .55862 .16845 .57 Mtetra
.954 .703 .52 r
.16845 .57 .17093 .55862 .19276 .36456 .19113 .36865 Mtetra
.81 .831 .359 r
.19113 .36865 .19276 .36456 .19463 .36121 .19329 .36253 Mtetra
.787 .419 .36 r
.19329 .36253 .19463 .36121 .196 .36264 .19451 .36542 Mtetra
.937 .678 .52 r
.19451 .36542 .196 .36264 .19642 .37332 .17532 .56621 Mtetra
.538 .307 .512 r
.17532 .56621 .19642 .37332 .17778 .5705 .17634 .572 Mtetra
.549 .117 .174 r
.17634 .572 .17778 .5705 .17928 .57162 .17791 .57256 Mtetra
.099 0 0 r
.17791 .57256 .17928 .57162 .18095 .57117 .17958 .57209 Mtetra
0 0 0 r
.17958 .57209 .18095 .57117 .18268 .57018 .18129 .57127 Mtetra
.131 0 0 r
.18129 .57127 .18268 .57018 .18437 .56958 .18297 .57077 Mtetra
.202 0 0 r
.18297 .57077 .18437 .56958 .18605 .56908 .18464 .57035 Mtetra
.215 0 0 r
.18464 .57035 .18605 .56908 .18773 .56855 .18632 .56991 Mtetra
.218 0 0 r
.18632 .56991 .18773 .56855 .18941 .56805 .188 .56944 Mtetra
.209 0 0 r
.188 .56944 .18941 .56805 .19109 .56754 .18968 .56893 Mtetra
.191 0 0 r
.18968 .56893 .19109 .56754 .19278 .56702 .19137 .56838 Mtetra
.297 0 0 r
.19137 .56838 .19278 .56702 .19442 .56696 .19304 .56809 Mtetra
.16 0 0 r
.19304 .56809 .19442 .56696 .19609 .56664 .19472 .56761 Mtetra
0 0 0 r
.19472 .56761 .19609 .56664 .19783 .56554 .19646 .5666 Mtetra
.951 .955 .692 r
.19646 .5666 .19783 .56554 .2 .56 .19844 .56313 Mtetra
.998 .824 .538 r
.19844 .56313 .2 .56 .22099 .35752 .20123 .55109 Mtetra
0 0 .107 r
.20123 .55109 .22099 .35752 .22308 .35174 .22171 .35368 Mtetra
0 0 0 r
.22171 .35368 .22308 .35174 .22478 .35006 .22346 .35147 Mtetra
.197 0 0 r
.22346 .35147 .22478 .35006 .22638 .34945 .22506 .3509 Mtetra
.362 0 .047 r
.22506 .3509 .22638 .34945 .22794 .34922 .22662 .35073 Mtetra
0 0 0 r
.22662 .35073 .22794 .34922 .22952 .34883 .22828 .34954 Mtetra
.69 .968 .748 r
.22828 .34954 .22952 .34883 .23111 .34835 .22996 .34804 Mtetra
.818 .91 .902 r
.22996 .34804 .23111 .34835 .23271 .34786 .23163 .34674 Mtetra
.704 .741 .879 r
.23163 .34674 .23271 .34786 .23431 .3472 .23325 .34596 Mtetra
.646 .702 .888 r
.23325 .34596 .23431 .3472 .23592 .34651 .23484 .34545 Mtetra
.625 .731 .923 r
.23484 .34545 .23592 .34651 .23753 .34592 .23643 .34502 Mtetra
.731 .789 .898 r
.23643 .34502 .23753 .34592 .23913 .3454 .23806 .34414 Mtetra
.712 .719 .855 r
.23806 .34414 .23913 .3454 .2407 .34518 .2397 .34328 Mtetra
.61 .595 .811 r
.2397 .34328 .2407 .34518 .24221 .34564 .24128 .34289 Mtetra
.081 .193 .682 r
.24128 .34289 .24221 .34564 .2434 .34977 .24269 .34456 Mtetra
.84 .598 .052 r
.24269 .34456 .2434 .34977 .22716 .55149 .24351 .35289 Mtetra
0 0 .149 r
.24351 .35289 .22716 .55149 .22837 .55658 .22753 .55198 Mtetra
.165 .162 .608 r
.22753 .55198 .22837 .55658 .22996 .5575 .22898 .55441 Mtetra
.468 .434 .737 r
.22898 .55441 .22996 .5575 .23166 .5571 .23061 .55483 Mtetra
.562 .549 .798 r
.23061 .55483 .23166 .5571 .2334 .55618 .23229 .55468 Mtetra
.486 .609 .899 r
.23229 .55468 .2334 .55618 .23514 .55541 .23395 .55473 Mtetra
.444 .766 .996 r
.23395 .55473 .23514 .55541 .23688 .55453 .23563 .55459 Mtetra
.598 .944 .926 r
.23563 .55459 .23688 .55453 .23868 .55302 .23738 .55376 Mtetra
.961 .937 .709 r
.23738 .55376 .23868 .55302 .24073 .5486 .23935 .55025 Mtetra
.95 .693 .511 r
.23935 .55025 .24073 .5486 .2593 .34688 .2575 .35449 Mtetra
.961 .819 .387 r
.2575 .35449 .2593 .34688 .26153 .33906 .26046 .33791 Mtetra
.848 .752 .757 r
.26046 .33791 .26153 .33906 .26327 .337 .26223 .33556 Mtetra
.646 .672 .861 r
.26223 .33556 .26327 .337 .26489 .33643 .26384 .33504 Mtetra
.49 .614 .902 r
.26384 .33504 .26489 .33643 .26647 .33633 .26541 .33507 Mtetra
.541 .662 .915 r
.26541 .33507 .26647 .33633 .26806 .33611 .267 .33494 Mtetra
.621 .71 .909 r
.267 .33494 .26806 .33611 .26967 .33567 .26861 .33452 Mtetra
.631 .717 .909 r
.26861 .33452 .26967 .33567 .27128 .33521 .27022 .33407 Mtetra
.649 .725 .904 r
.27022 .33407 .27128 .33521 .27291 .33467 .27184 .33354 Mtetra
.667 .733 .899 r
.27184 .33354 .27291 .33467 .27453 .33405 .27347 .33294 Mtetra
.682 .74 .895 r
.27347 .33294 .27453 .33405 .27617 .33339 .2751 .33227 Mtetra
.699 .743 .886 r
.2751 .33227 .27617 .33339 .2778 .33269 .27675 .33151 Mtetra
.707 .734 .873 r
.27675 .33151 .2778 .33269 .27944 .33197 .27839 .3307 Mtetra
.703 .718 .861 r
.27839 .3307 .27944 .33197 .28109 .33123 .28004 .32988 Mtetra
.69 .702 .857 r
.28004 .32988 .28109 .33123 .28273 .33047 .28169 .32913 Mtetra
.68 .7 .862 r
.28169 .32913 .28273 .33047 .28437 .32971 .28333 .32843 Mtetra
.677 .709 .873 r
.28333 .32843 .28437 .32971 .28602 .32897 .28497 .32776 Mtetra
.674 .721 .884 r
.28497 .32776 .28602 .32897 .28766 .32828 .2866 .32711 Mtetra
.672 .728 .892 r
.2866 .32711 .28766 .32828 .2893 .32764 .28824 .32648 Mtetra
.668 .729 .895 r
.28824 .32648 .2893 .32764 .29093 .32703 .28988 .32587 Mtetra
.665 .728 .896 r
.28988 .32587 .29093 .32703 .29257 .32642 .29152 .32527 Mtetra
.662 .728 .898 r
.29152 .32527 .29257 .32642 .29421 .32583 .29316 .32468 Mtetra
.659 .728 .9 r
.29316 .32468 .29421 .32583 .29585 .32525 .29479 .32411 Mtetra
.658 .73 .902 r
.29479 .32411 .29585 .32525 .29749 .32467 .29643 .32354 Mtetra
.655 .73 .905 r
.29643 .32354 .29749 .32467 .29912 .32411 .29807 .32298 Mtetra
.649 .73 .908 r
.29807 .32298 .29912 .32411 .30076 .32355 .29971 .32245 Mtetra
.636 .731 .917 r
.29971 .32245 .30076 .32355 .3024 .32301 .30134 .32197 Mtetra
.622 .74 .931 r
.30134 .32197 .3024 .32301 .30404 .32247 .30298 .32154 Mtetra
.615 .761 .949 r
.30298 .32154 .30404 .32247 .30568 .32194 .30461 .32112 Mtetra
.621 .789 .962 r
.30461 .32112 .30568 .32194 .30733 .3214 .30625 .32066 Mtetra
.632 .811 .968 r
.30625 .32066 .30733 .3214 .30897 .32085 .30789 .32015 Mtetra
.637 .82 .971 r
.30789 .32015 .30897 .32085 .31061 .3203 .30953 .31962 Mtetra
.64 .826 .972 r
.30953 .31962 .31061 .3203 .31226 .31974 .31118 .31907 Mtetra
.641 .83 .973 r
.31118 .31907 .31226 .31974 .31391 .31917 .31283 .31852 Mtetra
.644 .834 .974 r
.31283 .31852 .31391 .31917 .31556 .3186 .31448 .31795 Mtetra
.648 .838 .973 r
.31448 .31795 .31556 .3186 .31721 .31801 .31613 .31737 Mtetra
.652 .84 .973 r
.31613 .31737 .31721 .31801 .31886 .31742 .31778 .31678 Mtetra
.656 .841 .971 r
.31778 .31678 .31886 .31742 .32052 .31682 .31944 .31618 Mtetra
.659 .84 .97 r
.31944 .31618 .32052 .31682 .32217 .31622 .3211 .31556 Mtetra
.663 .839 .967 r
.3211 .31556 .32217 .31622 .32383 .31561 .32275 .31494 Mtetra
.666 .836 .965 r
.32275 .31494 .32383 .31561 .32549 .31499 .32441 .3143 Mtetra
.669 .833 .962 r
.32441 .3143 .32549 .31499 .32715 .31437 .32608 .31366 Mtetra
.671 .829 .959 r
.32608 .31366 .32715 .31437 .32881 .31375 .32774 .31302 Mtetra
.674 .824 .956 r
.32774 .31302 .32881 .31375 .33047 .31313 .3294 .31237 Mtetra
.675 .819 .952 r
.3294 .31237 .33047 .31313 .33213 .31249 .33107 .31172 Mtetra
.676 .815 .949 r
.33107 .31172 .33213 .31249 .3338 .31185 .33273 .31106 Mtetra
.682 .812 .945 r
.33273 .31106 .3338 .31185 .33546 .31122 .3344 .31039 Mtetra
.692 .805 .935 r
.3344 .31039 .33546 .31122 .33713 .31062 .33608 .30967 Mtetra
.702 .783 .915 r
.33608 .30967 .33713 .31062 .33879 .31004 .33775 .30891 Mtetra
.697 .746 .889 r
.33775 .30891 .33879 .31004 .34046 .30946 .33943 .30815 Mtetra
.693 .714 .865 r
.33943 .30815 .34046 .30946 .34213 .30885 .34111 .30738 Mtetra
.687 .688 .845 r
.34111 .30738 .34213 .30885 .3438 .30818 .34278 .3066 Mtetra
.661 .663 .841 r
.34278 .3066 .3438 .30818 .34547 .3075 .34446 .30596 Mtetra
.631 .657 .857 r
.34446 .30596 .34547 .3075 .34716 .30664 .34612 .30548 Mtetra
.561 .695 .93 r
.34612 .30548 .34716 .30664 .34885 .30561 .34777 .30526 Mtetra
0 .49 .774 r
.34777 .30526 .34885 .30561 .35052 .30501 .34939 .30561 Mtetra
.786 .351 .217 r
.34939 .30561 .35052 .30501 .35213 .3057 .3509 .30793 Mtetra
.954 .68 .481 r
.3509 .30793 .35213 .3057 .35348 .3109 .34145 .50943 Mtetra
.541 .309 .512 r
.34145 .50943 .35348 .3109 .3441 .51445 .34277 .51742 Mtetra
.661 .303 .353 r
.34277 .51742 .3441 .51445 .34566 .51822 .34443 .51932 Mtetra
.266 0 0 r
.34443 .51932 .34566 .51822 .34743 .51801 .3462 .51906 Mtetra
0 0 0 r
.3462 .51906 .34743 .51801 .34923 .51713 .348 .51827 Mtetra
.348 .51827 .34923 .51713 .35103 .51643 .34981 .51741 Mtetra
.122 0 0 r
.34981 .51741 .35103 .51643 .35278 .51662 .3516 .51691 Mtetra
.287 .781 .741 r
.3516 .51691 .35278 .51662 .35454 .51676 .3534 .51631 Mtetra
.704 .904 .967 r
.3534 .51631 .35454 .51676 .35631 .51669 .35521 .51542 Mtetra
.774 .756 .836 r
.35521 .51542 .35631 .51669 .3581 .51629 .35705 .51402 Mtetra
.735 .639 .752 r
.35705 .51402 .3581 .51629 .3599 .51578 .3589 .51244 Mtetra
.666 .546 .709 r
.3589 .51244 .3599 .51578 .36169 .51531 .36073 .51123 Mtetra
.555 .45 .69 r
.36073 .51123 .36169 .51531 .36348 .51505 .36251 .51109 Mtetra
.595 .48 .692 r
.36251 .51109 .36348 .51505 .36529 .51437 .36431 .51054 Mtetra
.72 .561 .674 r
.36431 .51054 .36529 .51437 .36715 .51254 .3662 .50821 Mtetra
.956 .686 .485 r
.3662 .50821 .36715 .51254 .3692 .50679 .37723 .3117 Mtetra
.561 .33 .522 r
.37723 .3117 .3692 .50679 .38046 .30164 .37964 .29592 Mtetra
.71 .515 .624 r
.37964 .29592 .38046 .30164 .3824 .29552 .38146 .29263 Mtetra
.646 .545 .726 r
.38146 .29263 .3824 .29552 .38415 .29379 .38317 .29176 Mtetra
.596 .583 .809 r
.38317 .29176 .38415 .29379 .38586 .29278 .38485 .29143 Mtetra
.553 .657 .905 r
.38485 .29143 .38586 .29278 .38756 .2921 .38653 .29126 Mtetra
.641 .796 .957 r
.38653 .29126 .38756 .2921 .38926 .29146 .38822 .29071 Mtetra
.644 .82 .968 r
.38822 .29071 .38926 .29146 .39095 .29094 .38992 .29015 Mtetra
.661 .813 .956 r
.38992 .29015 .39095 .29094 .39265 .29047 .39162 .28953 Mtetra
.683 .786 .928 r
.39162 .28953 .39265 .29047 .39434 .28995 .39332 .28884 Mtetra
.685 .751 .902 r
.39332 .28884 .39434 .28995 .39604 .28943 .39503 .28813 Mtetra
.682 .717 .875 r
.39503 .28813 .39604 .28943 .39774 .28888 .39673 .28741 Mtetra
.681 .69 .852 r
.39673 .28741 .39774 .28888 .39944 .28827 .39844 .28667 Mtetra
.659 .663 .843 r
.39844 .28667 .39944 .28827 .40115 .28762 .40015 .28602 Mtetra
.616 .645 .856 r
.40015 .28602 .40115 .28762 .40286 .28695 .40185 .28561 Mtetra
.454 .613 .917 r
.40185 .28561 .40286 .28695 .40457 .28622 .40353 .28573 Mtetra
.048 .565 .874 r
.40353 .28573 .40457 .28622 .40628 .2855 .4052 .28604 Mtetra
.341 0 0 r
.4052 .28604 .40628 .2855 .40799 .28473 .40688 .28621 Mtetra
.035 0 0 r
.40688 .28621 .40799 .28473 .40972 .28371 .40861 .28516 Mtetra
.174 0 0 r
.40861 .28516 .40972 .28371 .41143 .28307 .41032 .28446 Mtetra
.542 .096 .14 r
.41032 .28446 .41143 .28307 .41311 .2833 .412 .28503 Mtetra
.96 .68 .462 r
.412 .28503 .41311 .2833 .41466 .28739 .40675 .47893 Mtetra
.558 .322 .514 r
.40675 .47893 .41466 .28739 .40922 .49193 .40796 .49565 Mtetra
.692 .348 .389 r
.40796 .49565 .40922 .49193 .41084 .49741 .40968 .49846 Mtetra
.344 0 0 r
.40968 .49846 .41084 .49741 .41265 .4975 .41149 .49843 Mtetra
.054 0 0 r
.41149 .49843 .41265 .4975 .41449 .49673 .41333 .49781 Mtetra
0 0 0 r
.41333 .49781 .41449 .49673 .41634 .49557 .41518 .49694 Mtetra
.202 0 0 r
.41518 .49694 .41634 .49557 .41819 .49483 .41702 .49636 Mtetra
.22 0 0 r
.41702 .49636 .41819 .49483 .42003 .49417 .41886 .49573 Mtetra
.214 0 0 r
.41886 .49573 .42003 .49417 .42186 .49373 .4207 .49507 Mtetra
.144 0 0 r
.4207 .49507 .42186 .49373 .42368 .49385 .42255 .49436 Mtetra
0 0 0 r
.42255 .49436 .42368 .49385 .4255 .49396 .4244 .49363 Mtetra
.605 .909 .982 r
.4244 .49363 .4255 .49396 .42733 .49392 .42625 .49294 Mtetra
.625 .776 .953 r
.42625 .49294 .42733 .49392 .42917 .49342 .42809 .49242 Mtetra
.642 .779 .946 r
.42809 .49242 .42917 .49342 .43102 .4928 .42994 .49183 Mtetra
.684 .799 .936 r
.42994 .49183 .43102 .4928 .43287 .49214 .43179 .49108 Mtetra
.786 .799 .863 r
.43179 .49108 .43287 .49214 .43472 .49163 .43367 .48968 Mtetra
.755 .677 .775 r
.43367 .48968 .43472 .49163 .43657 .49112 .43554 .48806 Mtetra
.707 .583 .714 r
.43554 .48806 .43657 .49112 .43842 .49059 .43742 .48641 Mtetra
.612 .485 .684 r
.43742 .48641 .43842 .49059 .44027 .48997 .43928 .48562 Mtetra
.587 .465 .68 r
.43928 .48562 .44027 .48997 .44213 .48932 .44113 .48511 Mtetra
.577 .462 .686 r
.44113 .48511 .44213 .48932 .44398 .48867 .44298 .48472 Mtetra
.532 .442 .698 r
.44298 .48472 .44398 .48867 .44583 .4885 .44482 .48479 Mtetra
.589 .487 .706 r
.44482 .48479 .44583 .4885 .44769 .48799 .44668 .48433 Mtetra
.674 .54 .694 r
.44668 .48433 .44769 .48799 .44956 .48681 .44856 .48287 Mtetra
.886 .654 .582 r
.44856 .48287 .44956 .48681 .45151 .48206 .45064 .47256 Mtetra
.958 .68 .466 r
.45064 .47256 .45151 .48206 .45779 .27755 .45695 .26926 Mtetra
.696 .483 .596 r
.45695 .26926 .45779 .27755 .45972 .26808 .45877 .26492 Mtetra
.66 .543 .71 r
.45877 .26492 .45972 .26808 .4615 .26603 .46052 .26382 Mtetra
.616 .578 .789 r
.46052 .26382 .4615 .26603 .46325 .26487 .46227 .26333 Mtetra
.561 .633 .88 r
.46227 .26333 .46325 .26487 .465 .26414 .464 .26315 Mtetra
.698 .785 .919 r
.464 .26315 .465 .26414 .46674 .26347 .46575 .26237 Mtetra
.69 .762 .906 r
.46575 .26237 .46674 .26347 .46849 .26292 .4675 .26162 Mtetra
.656 .713 .89 r
.4675 .26162 .46849 .26292 .47024 .26242 .46925 .26102 Mtetra
.61 .678 .89 r
.46925 .26102 .47024 .26242 .47199 .26136 .471 .26062 Mtetra
.36 .706 .985 r
.471 .26062 .47199 .26136 .47375 .26056 .47274 .26067 Mtetra
.538 0 0 r
.47274 .26067 .47375 .26056 .47549 .26032 .47446 .26158 Mtetra
.897 .544 .368 r
.47446 .26158 .47549 .26032 .47719 .26301 .47608 .26949 Mtetra
.96 .673 .447 r
.47608 .26949 .47719 .26301 .47595 .46378 .47474 .47288 Mtetra
.64 .345 .455 r
.47474 .47288 .47595 .46378 .47765 .47515 .47656 .4765 Mtetra
.446 0 .047 r
.47656 .4765 .47765 .47515 .4795 .47642 .47843 .47671 Mtetra
.309 .794 .74 r
.47843 .47671 .4795 .47642 .48137 .4765 .48031 .47602 Mtetra
.769 .919 .938 r
.48031 .47602 .48137 .4765 .48325 .47607 .4822 .47482 Mtetra
.707 .754 .889 r
.4822 .47482 .48325 .47607 .48513 .47598 .48409 .47391 Mtetra
.718 .654 .785 r
.48409 .47391 .48513 .47598 .48702 .47551 .48598 .47263 Mtetra
.749 .615 .71 r
.48598 .47263 .48702 .47551 .48891 .47434 .48789 .47044 Mtetra
.878 .65 .589 r
.48789 .47044 .48891 .47434 .49083 .47019 .48986 .46145 Mtetra
.962 .68 .454 r
.48986 .46145 .49083 .47019 .49467 .26989 .49381 .25653 Mtetra
.648 .428 .571 r
.49381 .25653 .49467 .26989 .49657 .25543 .49562 .25199 Mtetra
.67 .538 .695 r
.49562 .25199 .49657 .25543 .49836 .25301 .49739 .25065 Mtetra
.614 .567 .777 r
.49739 .25065 .49836 .25301 .50013 .25179 .49916 .25016 Mtetra
.551 .615 .869 r
.49916 .25016 .50013 .25179 .5019 .25105 .50092 .25002 Mtetra
.627 .757 .941 r
.50092 .25002 .5019 .25105 .50367 .25041 .50269 .24952 Mtetra
.655 .799 .952 r
.50269 .24952 .50367 .25041 .50544 .24988 .50446 .24891 Mtetra
.666 .784 .937 r
.50446 .24891 .50544 .24988 .50721 .24942 .50624 .24826 Mtetra
.757 .772 .865 r
.50624 .24826 .50721 .24942 .50899 .24846 .50801 .2471 Mtetra
.715 .727 .86 r
.50801 .2471 .50899 .24846 .51076 .24763 .50979 .24615 Mtetra
.582 .655 .886 r
.50979 .24615 .51076 .24763 .51254 .24736 .51157 .24587 Mtetra
.705 .279 0 r
.51157 .24587 .51254 .24736 .5143 .24977 .51333 .24911 Mtetra
.97 .682 .423 r
.51333 .24911 .5143 .24977 .51551 .44976 .51445 .45661 Mtetra
.745 .428 .447 r
.51445 .45661 .51551 .44976 .51737 .46221 .51633 .46343 Mtetra
.535 .059 .073 r
.51633 .46343 .51737 .46221 .51928 .46374 .51823 .46409 Mtetra
.261 .756 .685 r
.51823 .46409 .51928 .46374 .52118 .46382 .52015 .46339 Mtetra
.758 .934 .943 r
.52015 .46339 .52118 .46382 .52309 .46337 .52206 .4622 Mtetra
.562 .722 .948 r
.52206 .4622 .52309 .46337 .52501 .46313 .52397 .46191 Mtetra
.568 .713 .94 r
.52397 .46191 .52501 .46313 .52692 .46263 .52588 .46161 Mtetra
.727 .807 .914 r
.52588 .46161 .52692 .46263 .52883 .46147 .5278 .46061 Mtetra
.946 .805 .672 r
.5278 .46061 .52883 .46147 .53074 .45768 .52971 .45608 Mtetra
.972 .688 .431 r
.52971 .45608 .53074 .45768 .53261 .43689 .5312 .24748 Mtetra
.545 .317 .519 r
.5312 .24748 .53261 .43689 .53394 .24248 .53297 .23907 Mtetra
.712 .565 .686 r
.53297 .23907 .53394 .24248 .53573 .23977 .53476 .23713 Mtetra
.617 .549 .755 r
.53476 .23713 .53573 .23977 .53752 .23857 .53655 .23657 Mtetra
.546 .567 .827 r
.53655 .23657 .53752 .23857 .53931 .23784 .53835 .23649 Mtetra
.609 .69 .9 r
.53835 .23649 .53931 .23784 .54111 .23716 .54015 .23608 Mtetra
.66 .761 .925 r
.54015 .23608 .54111 .23716 .5429 .23654 .54194 .23545 Mtetra
.67 .765 .922 r
.54194 .23545 .5429 .23654 .5447 .23597 .54374 .23478 Mtetra
.751 .77 .869 r
.54374 .23478 .5447 .23597 .54649 .23494 .54553 .23365 Mtetra
.731 .746 .864 r
.54553 .23365 .54649 .23494 .54829 .234 .54733 .23262 Mtetra
.615 .688 .895 r
.54733 .23262 .54829 .234 .55009 .23366 .54913 .23219 Mtetra
0 0 .518 r
.54913 .23219 .55009 .23366 .55192 .23625 .55096 .23451 Mtetra
.973 .681 .405 r
.55096 .23451 .55192 .23625 .55568 .44258 .55464 .43918 Mtetra
.885 .563 .06 r
.55464 .43918 .55568 .44258 .5577 .45103 .55667 .44954 Mtetra
0 .303 .798 r
.55667 .44954 .5577 .45103 .55965 .45214 .55863 .45088 Mtetra
.608 .725 .928 r
.55863 .45088 .55965 .45214 .56159 .45155 .56057 .45043 Mtetra
.741 .796 .897 r
.56057 .45043 .56159 .45155 .56352 .45044 .5625 .44933 Mtetra
.723 .792 .907 r
.5625 .44933 .56352 .45044 .56546 .45003 .56444 .44834 Mtetra
.716 .699 .832 r
.56444 .44834 .56546 .45003 .56741 .44981 .56637 .44723 Mtetra
.741 .63 .736 r
.56637 .44723 .56741 .44981 .56935 .44896 .5683 .44539 Mtetra
.839 .637 .63 r
.5683 .44539 .56935 .44896 .57125 .44534 .57018 .44005 Mtetra
.971 .682 .422 r
.57018 .44005 .57125 .44534 .57022 .24359 .56913 .2326 Mtetra
.706 .477 .574 r
.56913 .2326 .57022 .24359 .57181 .22773 .57086 .22616 Mtetra
.821 .734 .768 r
.57086 .22616 .57181 .22773 .5736 .22517 .57265 .22408 Mtetra
.685 .77 .916 r
.57265 .22408 .5736 .22517 .57541 .22441 .57447 .22333 Mtetra
.578 .734 .949 r
.57447 .22333 .57541 .22441 .57724 .22415 .57629 .22299 Mtetra
.698 .763 .902 r
.57629 .22299 .57724 .22415 .57906 .22344 .57811 .22218 Mtetra
.723 .751 .875 r
.57811 .22218 .57906 .22344 .58087 .22252 .57993 .2212 Mtetra
.602 .696 .909 r
.57993 .2212 .58087 .22252 .5827 .22209 .58175 .22081 Mtetra
0 0 .517 r
.58175 .22081 .5827 .22209 .58456 .22365 .58363 .22302 Mtetra
.974 .678 .394 r
.58363 .22302 .58456 .22365 .5866 .23367 .58957 .42887 Mtetra
.543 .31 .511 r
.58957 .42887 .5866 .23367 .59268 .43692 .59173 .4385 Mtetra
.636 .193 .181 r
.59173 .4385 .59268 .43692 .5947 .4393 .59373 .4399 Mtetra
0 0 0 r
.59373 .4399 .5947 .4393 .59668 .43944 .5957 .43931 Mtetra
.684 .969 .927 r
.5957 .43931 .59668 .43944 .59864 .439 .59765 .43817 Mtetra
.616 .821 .979 r
.59765 .43817 .59864 .439 .60062 .43875 .59962 .43759 Mtetra
.524 .712 .957 r
.59962 .43759 .60062 .43875 .60259 .43849 .60159 .43741 Mtetra
.679 .788 .932 r
.60159 .43741 .60259 .43849 .60455 .43756 .60356 .43663 Mtetra
.921 .832 .741 r
.60356 .43663 .60455 .43756 .60645 .43419 .60546 .43345 Mtetra
.982 .732 .479 r
.60546 .43345 .60645 .43419 .60361 .24598 .60702 .41637 Mtetra
0 0 .284 r
.60702 .41637 .60361 .24598 .6047 .21615 .60377 .21506 Mtetra
.905 .803 .736 r
.60377 .21506 .6047 .21615 .60648 .2133 .60555 .2121 Mtetra
.701 .759 .897 r
.60555 .2121 .60648 .2133 .60831 .21247 .60738 .21126 Mtetra
.574 .705 .931 r
.60738 .21126 .60831 .21247 .61016 .21218 .60923 .21095 Mtetra
.663 .741 .907 r
.60923 .21095 .61016 .21218 .612 .21157 .61107 .21029 Mtetra
.727 .753 .874 r
.61107 .21029 .612 .21157 .61383 .21062 .6129 .20928 Mtetra
.619 .702 .904 r
.6129 .20928 .61383 .21062 .61568 .21012 .61475 .20882 Mtetra
0 .157 .688 r
.61475 .20882 .61568 .21012 .61758 .21131 .61667 .21052 Mtetra
.975 .675 .378 r
.61667 .21052 .61758 .21131 .61968 .21854 .62477 .41237 Mtetra
.552 .316 .511 r
.62477 .41237 .61968 .21854 .6281 .42478 .62721 .42661 Mtetra
.677 .25 .227 r
.62721 .42661 .6281 .42478 .6302 .42774 .62928 .42851 Mtetra
.109 0 0 r
.62928 .42851 .6302 .42774 .63222 .42796 .63127 .42805 Mtetra
.605 .953 .857 r
.63127 .42805 .63222 .42796 .63421 .42755 .63324 .42689 Mtetra
.773 .902 .932 r
.63324 .42689 .63421 .42755 .63621 .42723 .63521 .42562 Mtetra
.727 .719 .843 r
.63521 .42562 .63621 .42723 .63822 .42703 .63719 .42445 Mtetra
.743 .634 .739 r
.63719 .42445 .63822 .42703 .6402 .42615 .63914 .42259 Mtetra
.828 .633 .639 r
.63914 .42259 .6402 .42615 .64211 .42294 .64098 .41784 Mtetra
.974 .679 .395 r
.64098 .41784 .64211 .42294 .63667 .21998 .6354 .20927 Mtetra
.719 .486 .571 r
.6354 .20927 .63667 .21998 .63795 .20373 .63703 .20231 Mtetra
.877 .767 .738 r
.63703 .20231 .63795 .20373 .63972 .20072 .63881 .19953 Mtetra
.77 .784 .864 r
.63881 .19953 .63972 .20072 .64158 .19997 .64065 .19825 Mtetra
.612 .64 .854 r
.64065 .19825 .64158 .19997 .64348 .20022 .64252 .19782 Mtetra
.273 .365 .775 r
.64252 .19782 .64348 .20022 .64545 .20232 .64445 .19902 Mtetra
.694 .399 0 r
.64445 .19902 .64545 .20232 .65533 .39968 .64664 .20644 Mtetra
0 0 .353 r
.64664 .20644 .65533 .39968 .65807 .41715 .65707 .41532 Mtetra
0 0 .492 r
.65707 .41532 .65807 .41715 .6602 .41958 .65923 .41849 Mtetra
.386 .658 .966 r
.65923 .41849 .6602 .41958 .66224 .4197 .66128 .41864 Mtetra
.721 .813 .922 r
.66128 .41864 .66224 .4197 .66424 .41875 .66327 .41764 Mtetra
.906 .822 .753 r
.66327 .41764 .66424 .41875 .66615 .41585 .66518 .41469 Mtetra
.979 .744 .511 r
.66518 .41469 .66615 .41585 .66768 .40419 .66671 .40308 Mtetra
.977 .681 .375 r
.66671 .40308 .66768 .40419 .66041 .19697 .6595 .19574 Mtetra
.923 .789 .696 r
.6595 .19574 .66041 .19697 .66215 .19337 .66125 .19212 Mtetra
.719 .762 .887 r
.66125 .19212 .66215 .19337 .66401 .1924 .66311 .19116 Mtetra
.594 .712 .926 r
.66311 .19116 .66401 .1924 .6659 .19202 .665 .19078 Mtetra
.623 .725 .92 r
.665 .19078 .6659 .19202 .66779 .19152 .66688 .19028 Mtetra
.737 .768 .878 r
.66688 .19028 .66779 .19152 .66965 .19045 .66875 .18921 Mtetra
.647 .735 .914 r
.66875 .18921 .66965 .19045 .67153 .18985 .67063 .18861 Mtetra
.098 .422 .868 r
.67063 .18861 .67153 .18985 .67349 .19079 .67259 .18955 Mtetra
.918 .543 .122 r
.67259 .18955 .67349 .19079 .67586 .19976 .67495 .19853 Mtetra
.975 .67 .349 r
.67495 .19853 .67586 .19976 .68827 .40714 .68732 .40595 Mtetra
.604 .143 0 r
.68732 .40595 .68827 .40714 .69049 .41019 .68953 .40896 Mtetra
.453 .664 .953 r
.68953 .40896 .69049 .41019 .69256 .41031 .6916 .409 Mtetra
.711 .766 .895 r
.6916 .409 .69256 .41031 .69457 .40931 .69361 .40801 Mtetra
.863 .801 .788 r
.69361 .40801 .69457 .40931 .69649 .40654 .69555 .40564 Mtetra
.976 .801 .601 r
.69555 .40564 .69649 .40654 .69799 .39598 .6973 .39958 Mtetra
.979 .682 .35 r
.6973 .39958 .69799 .39598 .68868 .18695 .68803 .1902 Mtetra
0 0 0 r
.68803 .1902 .68868 .18695 .6904 .18305 .68963 .18413 Mtetra
.68963 .18413 .6904 .18305 .69228 .18211 .69146 .18227 Mtetra
.56 .931 .804 r
.69146 .18227 .69228 .18211 .69419 .18179 .69333 .18113 Mtetra
.678 .879 .974 r
.69333 .18113 .69419 .18179 .69612 .18162 .69522 .18032 Mtetra
.672 .738 .9 r
.69522 .18032 .69612 .18162 .69802 .18099 .69712 .1796 Mtetra
.647 .71 .893 r
.69712 .1796 .69802 .18099 .69992 .18033 .69902 .17899 Mtetra
.674 .731 .893 r
.69902 .17899 .69992 .18033 .70181 .17947 .70092 .17825 Mtetra
.752 .78 .876 r
.70092 .17825 .70181 .17947 .70368 .17823 .7028 .17708 Mtetra
.669 .765 .922 r
.7028 .17708 .70368 .17823 .70557 .17745 .7047 .17637 Mtetra
.197 .526 .92 r
.7047 .17637 .70557 .17745 .70755 .17793 .70668 .17699 Mtetra
.903 .509 .087 r
.70668 .17699 .70755 .17793 .7099 .18441 .70911 .18475 Mtetra
.974 .665 .336 r
.70911 .18475 .7099 .18441 .72492 .39455 .72402 .39401 Mtetra
.759 .263 0 r
.72402 .39401 .72492 .39455 .72724 .39831 .72632 .39738 Mtetra
.391 .7 .983 r
.72632 .39738 .72724 .39831 .72936 .39856 .72842 .39743 Mtetra
.715 .804 .92 r
.72842 .39743 .72936 .39856 .7314 .39766 .73046 .39644 Mtetra
.861 .819 .806 r
.73046 .39644 .7314 .39766 .73334 .3952 .73242 .3942 Mtetra
.973 .806 .616 r
.73242 .3942 .73334 .3952 .73487 .38639 .73416 .38864 Mtetra
.978 .677 .335 r
.73416 .38864 .73487 .38639 .72302 .17527 .72248 .17918 Mtetra
0 0 .003 r
.72248 .17918 .72302 .17527 .72468 .17079 .72397 .17196 Mtetra
0 0 0 r
.72397 .17196 .72468 .17079 .72658 .16976 .7258 .16997 Mtetra
.543 .917 .764 r
.7258 .16997 .72658 .16976 .72852 .16938 .72768 .16877 Mtetra
.676 .893 .976 r
.72768 .16877 .72852 .16938 .73047 .16924 .72959 .16793 Mtetra
.675 .739 .899 r
.72959 .16793 .73047 .16924 .7324 .16861 .73151 .16719 Mtetra
.648 .708 .891 r
.73151 .16719 .7324 .16861 .73432 .16794 .73344 .16656 Mtetra
.658 .72 .894 r
.73344 .16656 .73432 .16794 .73624 .16714 .73537 .16589 Mtetra
.754 .779 .873 r
.73537 .16589 .73624 .16714 .73812 .16588 .73726 .16469 Mtetra
.68 .766 .916 r
.73726 .16469 .73812 .16588 .74004 .16503 .73918 .16392 Mtetra
.356 .62 .951 r
.73918 .16392 .74004 .16503 .74202 .16519 .74117 .1642 Mtetra
.855 .44 0 r
.74117 .1642 .74202 .16519 .7444 .17054 .74361 .17038 Mtetra
.973 .661 .315 r
.74361 .17038 .7444 .17054 .76201 .38178 .76115 .38132 Mtetra
.797 .317 0 r
.76115 .38132 .76201 .38178 .76447 .38624 .76358 .38533 Mtetra
.337 .673 .976 r
.76358 .38533 .76447 .38624 .76664 .38662 .76572 .3855 Mtetra
.695 .802 .931 r
.76572 .3855 .76664 .38662 .76871 .38583 .76779 .3846 Mtetra
.846 .821 .824 r
.76779 .3846 .76871 .38583 .77068 .38366 .76978 .38255 Mtetra
.968 .809 .63 r
.76978 .38255 .77068 .38366 .77223 .37598 .77152 .37741 Mtetra
.976 .672 .318 r
.77152 .37741 .77223 .37598 .75779 .1635 .75741 .16837 Mtetra
0 0 .075 r
.75741 .16837 .75779 .1635 .75939 .15837 .75872 .15963 Mtetra
0 0 0 r
.75872 .15963 .75939 .15837 .76129 .15721 .76055 .15749 Mtetra
.526 .9 .718 r
.76055 .15749 .76129 .15721 .76325 .15675 .76245 .1562 Mtetra
.679 .912 .975 r
.76245 .1562 .76325 .15675 .76524 .15661 .76438 .15532 Mtetra
.743 .772 .877 r
.76438 .15532 .76524 .15661 .76715 .1555 .76629 .15418 Mtetra
.66 .734 .904 r
.76629 .15418 .76715 .1555 .76909 .15479 .76823 .1535 Mtetra
.466 .644 .935 r
.76823 .1535 .76909 .15479 .77111 .15491 .77024 .15355 Mtetra
0 0 .42 r
.77024 .15355 .77111 .15491 .77359 .16066 .77253 .15694 Mtetra
.97 .657 .286 r
.77253 .15694 .77359 .16066 .79339 .37224 .79198 .36506 Mtetra
0 .005 .52 r
.79198 .36506 .79339 .37224 .79592 .37662 .79478 .37265 Mtetra
.367 .345 .703 r
.79478 .37265 .79592 .37662 .79811 .37698 .79707 .37417 Mtetra
.526 .506 .777 r
.79707 .37417 .79811 .37698 .80021 .37623 .79925 .37424 Mtetra
.703 .675 .82 r
.79925 .37424 .80021 .37623 .80222 .37434 .80132 .3731 Mtetra
.899 .743 .678 r
.13014 .58607 .13133 .58706 .13352 .58183 .13227 .58131 Mtetra
.937 .687 .534 r
.13227 .58131 .13352 .58183 .15828 .37946 .15709 .37911 Mtetra
.935 .75 .627 r
.15709 .37911 .15828 .37946 .16054 .37273 .15943 .37171 Mtetra
.778 .762 .839 r
.15943 .37171 .16054 .37273 .16218 .37149 .16107 .37046 Mtetra
.644 .736 .916 r
.16107 .37046 .16218 .37149 .16373 .37103 .16262 .36997 Mtetra
.521 .691 .945 r
.16262 .36997 .16373 .37103 .16523 .37093 .16413 .36985 Mtetra
.67 .735 .898 r
.16413 .36985 .16523 .37093 .1668 .37035 .1657 .36926 Mtetra
.681 .736 .892 r
.1657 .36926 .1668 .37035 .16837 .36971 .16727 .36862 Mtetra
.69 .736 .887 r
.16727 .36862 .16837 .36971 .16994 .36905 .16884 .36793 Mtetra
.772 .746 .829 r
.16884 .36793 .16994 .36905 .17157 .36786 .17049 .36667 Mtetra
.728 .729 .851 r
.17049 .36667 .17157 .36786 .17317 .36699 .17209 .36573 Mtetra
.591 .677 .9 r
.17209 .36573 .17317 .36699 .1747 .36677 .17363 .36545 Mtetra
.891 .473 .077 r
.17363 .36545 .1747 .36677 .17583 .37012 .17479 .36857 Mtetra
.94 .684 .522 r
.17479 .36857 .17583 .37012 .15548 .57097 .15441 .56894 Mtetra
.964 .642 .347 r
.15441 .56894 .15548 .57097 .15633 .57795 .15515 .57681 Mtetra
.204 .531 .922 r
.15515 .57681 .15633 .57795 .15789 .5784 .15671 .57728 Mtetra
.672 .742 .903 r
.15671 .57728 .15789 .5784 .15956 .57777 .15839 .57664 Mtetra
.748 .753 .857 r
.15839 .57664 .15956 .57777 .16129 .57669 .16012 .57553 Mtetra
.542 .695 .939 r
.16012 .57553 .16129 .57669 .16292 .57656 .16175 .57536 Mtetra
.572 .696 .926 r
.16175 .57536 .16292 .57656 .16457 .57623 .1634 .5751 Mtetra
.678 .742 .899 r
.1634 .5751 .16457 .57623 .16628 .57526 .16508 .57443 Mtetra
.881 .782 .748 r
.16508 .57443 .16628 .57526 .16845 .57 .167 .57154 Mtetra
.986 .898 .629 r
.167 .57154 .16845 .57 .19113 .36865 .16918 .56617 Mtetra
0 0 .135 r
.16918 .56617 .19113 .36865 .19329 .36253 .19043 .37833 Mtetra
.918 .658 .528 r
.19043 .37833 .19329 .36253 .19451 .36542 .17268 .56366 Mtetra
.537 .305 .512 r
.17268 .56366 .19451 .36542 .17532 .56621 .17375 .56898 Mtetra
.704 .358 .388 r
.17375 .56898 .17532 .56621 .17634 .572 .17512 .5714 Mtetra
.214 .661 .95 r
.17512 .5714 .17634 .572 .17791 .57256 .17673 .57155 Mtetra
.631 .754 .936 r
.17673 .57155 .17791 .57256 .17958 .57209 .1784 .57107 Mtetra
.681 .764 .914 r
.1784 .57107 .17958 .57209 .18129 .57127 .1801 .57039 Mtetra
.599 .773 .963 r
.1801 .57039 .18129 .57127 .18297 .57077 .18177 .56999 Mtetra
.564 .784 .982 r
.18177 .56999 .18297 .57077 .18464 .57035 .18343 .56966 Mtetra
.563 .804 .989 r
.18343 .56966 .18464 .57035 .18632 .56991 .1851 .5693 Mtetra
.587 .83 .99 r
.1851 .5693 .18632 .56991 .188 .56944 .18678 .56886 Mtetra
.609 .843 .988 r
.18678 .56886 .188 .56944 .18968 .56893 .18847 .56835 Mtetra
.632 .849 .983 r
.18847 .56835 .18968 .56893 .19137 .56838 .19016 .56778 Mtetra
.599 .837 .989 r
.19016 .56778 .19137 .56838 .19304 .56809 .19184 .56731 Mtetra
.659 .811 .956 r
.19184 .56731 .19304 .56809 .19472 .56761 .19354 .5667 Mtetra
.732 .795 .902 r
.19354 .5667 .19472 .56761 .19646 .5666 .19527 .56576 Mtetra
.857 .798 .792 r
.19527 .56576 .19646 .5666 .19844 .56313 .19712 .56356 Mtetra
.96 .895 .717 r
.19712 .56356 .19844 .56313 .20123 .55109 .19912 .55989 Mtetra
0 0 .145 r
.19912 .55989 .20123 .55109 .22171 .35368 .20143 .55288 Mtetra
.514 .286 .507 r
.20143 .55288 .22171 .35368 .22346 .35147 .20356 .54782 Mtetra
.527 .297 .509 r
.20356 .54782 .22346 .35147 .22506 .3509 .20511 .54872 Mtetra
.524 .294 .509 r
.20511 .54872 .22506 .3509 .22662 .35073 .20682 .54794 Mtetra
0 0 .139 r
.20682 .54794 .22662 .35073 .22828 .34954 .22663 .35449 Mtetra
0 0 0 r
.22663 .35449 .22828 .34954 .22996 .34804 .22872 .3487 Mtetra
.95 .948 .73 r
.22872 .3487 .22996 .34804 .23163 .34674 .23054 .34573 Mtetra
.769 .771 .854 r
.23054 .34573 .23163 .34674 .23325 .34596 .2322 .34456 Mtetra
.63 .671 .871 r
.2322 .34456 .23325 .34596 .23484 .34545 .23379 .34411 Mtetra
.572 .659 .896 r
.23379 .34411 .23484 .34545 .23643 .34502 .23536 .34389 Mtetra
.697 .738 .883 r
.23536 .34389 .23643 .34502 .23806 .34414 .23698 .34315 Mtetra
.725 .77 .889 r
.23698 .34315 .23806 .34414 .2397 .34328 .23861 .34229 Mtetra
.662 .756 .92 r
.23861 .34229 .2397 .34328 .24128 .34289 .24021 .34172 Mtetra
.247 .531 .919 r
.24021 .34172 .24128 .34289 .24269 .34456 .24173 .34216 Mtetra
0 .115 .655 r
.24173 .34216 .24269 .34456 .24351 .35289 .24313 .34396 Mtetra
.081 .017 .477 r
.24313 .34396 .24351 .35289 .22753 .55198 .24421 .34936 Mtetra
0 0 .166 r
.24421 .34936 .22753 .55198 .22898 .55441 .22839 .54685 Mtetra
.092 .046 .507 r
.22839 .54685 .22898 .55441 .23061 .55483 .22966 .55136 Mtetra
.176 .221 .67 r
.22966 .55136 .23061 .55483 .23229 .55468 .23117 .55315 Mtetra
.181 .438 .868 r
.23117 .55315 .23229 .55468 .23395 .55473 .23278 .55389 Mtetra
.435 .723 .986 r
.23278 .55389 .23395 .55473 .23563 .55459 .23445 .55384 Mtetra
.727 .832 .929 r
.23445 .55384 .23563 .55459 .23738 .55376 .2362 .55294 Mtetra
.904 .782 .716 r
.2362 .55294 .23738 .55376 .23935 .55025 .23818 .54933 Mtetra
.947 .689 .513 r
.23818 .54933 .23935 .55025 .2575 .35449 .25668 .35028 Mtetra
.883 .649 .58 r
.25668 .35028 .2575 .35449 .26046 .33791 .25942 .33646 Mtetra
.825 .718 .748 r
.25942 .33646 .26046 .33791 .26223 .33556 .26118 .33419 Mtetra
.632 .678 .875 r
.26118 .33419 .26223 .33556 .26384 .33504 .26279 .33373 Mtetra
.451 .612 .918 r
.26279 .33373 .26384 .33504 .26541 .33507 .26436 .33384 Mtetra
.522 .66 .923 r
.26436 .33384 .26541 .33507 .267 .33494 .26594 .33376 Mtetra
.619 .707 .909 r
.26594 .33376 .267 .33494 .26861 .33452 .26755 .33335 Mtetra
.633 .714 .905 r
.26755 .33335 .26861 .33452 .27022 .33407 .26916 .33289 Mtetra
.648 .718 .899 r
.26916 .33289 .27022 .33407 .27184 .33354 .27078 .33237 Mtetra
.665 .724 .893 r
.27078 .33237 .27184 .33354 .27347 .33294 .27241 .33177 Mtetra
.682 .73 .886 r
.27241 .33177 .27347 .33294 .2751 .33227 .27405 .33109 Mtetra
.706 .734 .873 r
.27405 .33109 .2751 .33227 .27675 .33151 .27569 .33028 Mtetra
.717 .728 .859 r
.27569 .33028 .27675 .33151 .27839 .3307 .27735 .32938 Mtetra
.712 .714 .85 r
.27735 .32938 .27839 .3307 .28004 .32988 .279 .3285 Mtetra
.694 .698 .85 r
.279 .3285 .28004 .32988 .28169 .32913 .28065 .32771 Mtetra
.678 .688 .852 r
.28065 .32771 .28169 .32913 .28333 .32843 .28229 .32701 Mtetra
.671 .685 .854 r
.28229 .32701 .28333 .32843 .28497 .32776 .28393 .32634 Mtetra
.667 .684 .856 r
.28393 .32634 .28497 .32776 .2866 .32711 .28557 .3257 Mtetra
.665 .684 .858 r
.28557 .3257 .2866 .32711 .28824 .32648 .28721 .32507 Mtetra
.661 .683 .86 r
.28721 .32507 .28824 .32648 .28988 .32587 .28884 .32446 Mtetra
.658 .683 .862 r
.28884 .32446 .28988 .32587 .29152 .32527 .29048 .32386 Mtetra
.656 .683 .864 r
.29048 .32386 .29152 .32527 .29316 .32468 .29212 .32328 Mtetra
.653 .683 .866 r
.29212 .32328 .29316 .32468 .29479 .32411 .29376 .32272 Mtetra
.652 .684 .868 r
.29376 .32272 .29479 .32411 .29643 .32354 .29539 .32216 Mtetra
.649 .684 .87 r
.29539 .32216 .29643 .32354 .29807 .32298 .29703 .32161 Mtetra
.641 .684 .874 r
.29703 .32161 .29807 .32298 .29971 .32245 .29867 .3211 Mtetra
.622 .68 .884 r
.29867 .3211 .29971 .32245 .30134 .32197 .3003 .32068 Mtetra
.6 .682 .899 r
.3003 .32068 .30134 .32197 .30298 .32154 .30193 .32035 Mtetra
.594 .698 .915 r
.30193 .32035 .30298 .32154 .30461 .32112 .30355 .32002 Mtetra
.608 .724 .927 r
.30355 .32002 .30461 .32112 .30625 .32066 .30519 .31964 Mtetra
.632 .748 .932 r
.30519 .31964 .30625 .32066 .30789 .32015 .30683 .31917 Mtetra
.641 .76 .934 r
.30683 .31917 .30789 .32015 .30953 .31962 .30847 .31867 Mtetra
.645 .766 .937 r
.30847 .31867 .30953 .31962 .31118 .31907 .31011 .31814 Mtetra
.647 .771 .939 r
.31011 .31814 .31118 .31907 .31283 .31852 .31176 .31761 Mtetra
.652 .777 .94 r
.31176 .31761 .31283 .31852 .31448 .31795 .31341 .31706 Mtetra
.658 .782 .94 r
.31341 .31706 .31448 .31795 .31613 .31737 .31506 .31648 Mtetra
.663 .785 .939 r
.31506 .31648 .31613 .31737 .31778 .31678 .31672 .31588 Mtetra
.668 .785 .936 r
.31672 .31588 .31778 .31678 .31944 .31618 .31837 .31527 Mtetra
.672 .784 .933 r
.31837 .31527 .31944 .31618 .3211 .31556 .32003 .31464 Mtetra
.676 .782 .93 r
.32003 .31464 .3211 .31556 .32275 .31494 .32169 .314 Mtetra
.678 .778 .926 r
.32169 .314 .32275 .31494 .32441 .3143 .32336 .31334 Mtetra
.68 .774 .922 r
.32336 .31334 .32441 .3143 .32608 .31366 .32502 .31268 Mtetra
.681 .769 .918 r
.32502 .31268 .32608 .31366 .32774 .31302 .32669 .31201 Mtetra
.683 .765 .913 r
.32669 .31201 .32774 .31302 .3294 .31237 .32835 .31133 Mtetra
.682 .759 .91 r
.32835 .31133 .3294 .31237 .33107 .31172 .33002 .31065 Mtetra
.682 .754 .906 r
.33002 .31065 .33107 .31172 .33273 .31106 .33169 .30997 Mtetra
.688 .751 .899 r
.33169 .30997 .33273 .31106 .3344 .31039 .33336 .30926 Mtetra
.702 .748 .887 r
.33336 .30926 .3344 .31039 .33608 .30967 .33504 .30847 Mtetra
.713 .738 .871 r
.33504 .30847 .33608 .30967 .33775 .30891 .33672 .30761 Mtetra
.706 .719 .859 r
.33672 .30761 .33775 .30891 .33943 .30815 .3384 .30676 Mtetra
.708 .706 .846 r
.3384 .30676 .33943 .30815 .34111 .30738 .34009 .30587 Mtetra
.702 .688 .833 r
.34009 .30587 .34111 .30738 .34278 .3066 .34177 .30498 Mtetra
.65 .653 .84 r
.34177 .30498 .34278 .3066 .34446 .30596 .34344 .30439 Mtetra
.477 .582 .881 r
.34344 .30439 .34446 .30596 .34612 .30548 .34507 .30451 Mtetra
.525 .012 0 r
.34507 .30451 .34612 .30548 .34777 .30526 .34662 .30604 Mtetra
.857 .48 .333 r
.34662 .30604 .34777 .30526 .34939 .30561 .34802 .31035 Mtetra
.95 .677 .484 r
.34802 .31035 .34939 .30561 .3509 .30793 .33849 .51019 Mtetra
.536 .305 .511 r
.33849 .51019 .3509 .30793 .34145 .50943 .33993 .51572 Mtetra
.616 .31 .428 r
.33993 .51572 .34145 .50943 .34277 .51742 .34158 .51775 Mtetra
.486 0 0 r
.34158 .51775 .34277 .51742 .34443 .51932 .3433 .51839 Mtetra
.582 .769 .968 r
.3433 .51839 .34443 .51932 .3462 .51906 .34508 .51801 Mtetra
.678 .774 .923 r
.34508 .51801 .3462 .51906 .348 .51827 .34689 .51731 Mtetra
.671 .788 .937 r
.34689 .51731 .348 .51827 .34981 .51741 .34869 .51663 Mtetra
.554 .792 .987 r
.34869 .51663 .34981 .51741 .3516 .51691 .35047 .51628 Mtetra
.635 .852 .982 r
.35047 .51628 .3516 .51691 .3534 .51631 .35227 .51567 Mtetra
.807 .87 .894 r
.35227 .51567 .3534 .51631 .35521 .51542 .35411 .51427 Mtetra
.887 .77 .727 r
.35411 .51427 .35521 .51542 .35705 .51402 .35604 .51103 Mtetra
.857 .658 .633 r
.35604 .51103 .35705 .51402 .3589 .51244 .35811 .50508 Mtetra
.952 .682 .49 r
.35811 .50508 .3589 .51244 .36073 .51123 .36947 .31165 Mtetra
.528 .303 .517 r
.36947 .31165 .36073 .51123 .36251 .51109 .37117 .31092 Mtetra
.514 .292 .514 r
.37117 .31092 .36251 .51109 .36431 .51054 .37259 .3162 Mtetra
.552 .322 .521 r
.37259 .3162 .36431 .51054 .3662 .50821 .3748 .30486 Mtetra
.544 .315 .519 r
.3748 .30486 .3662 .50821 .37723 .3117 .37685 .29697 Mtetra
.621 .405 .568 r
.37685 .29697 .37723 .3117 .37964 .29592 .37868 .2934 Mtetra
.754 .622 .714 r
.37868 .2934 .37964 .29592 .38146 .29263 .38044 .29138 Mtetra
.671 .722 .887 r
.38044 .29138 .38146 .29263 .38317 .29176 .38214 .29073 Mtetra
.581 .732 .946 r
.38214 .29073 .38317 .29176 .38485 .29143 .38382 .29041 Mtetra
.553 .725 .954 r
.38382 .29041 .38485 .29143 .38653 .29126 .3855 .29017 Mtetra
.647 .745 .921 r
.3855 .29017 .38653 .29126 .38822 .29071 .38719 .28963 Mtetra
.662 .75 .915 r
.38719 .28963 .38822 .29071 .38992 .29015 .38889 .28903 Mtetra
.68 .748 .903 r
.38889 .28903 .38992 .29015 .39162 .28953 .3906 .28834 Mtetra
.7 .741 .883 r
.3906 .28834 .39162 .28953 .39332 .28884 .39231 .28754 Mtetra
.698 .722 .868 r
.39231 .28754 .39332 .28884 .39503 .28813 .39402 .28673 Mtetra
.696 .706 .855 r
.39402 .28673 .39503 .28813 .39673 .28741 .39573 .28591 Mtetra
.702 .693 .838 r
.39573 .28591 .39673 .28741 .39844 .28667 .39745 .28502 Mtetra
.655 .655 .838 r
.39745 .28502 .39844 .28667 .40015 .28602 .39915 .28439 Mtetra
.528 .599 .869 r
.39915 .28439 .40015 .28602 .40185 .28561 .40084 .28435 Mtetra
0 .021 .557 r
.40084 .28435 .40185 .28561 .40353 .28573 .40245 .28606 Mtetra
.876 .479 .278 r
.40245 .28606 .40353 .28573 .4052 .28604 .40397 .29034 Mtetra
.956 .677 .467 r
.40397 .29034 .4052 .28604 .40688 .28621 .39814 .48671 Mtetra
.526 .296 .509 r
.39814 .48671 .40688 .28621 .40861 .28516 .39994 .48677 Mtetra
.522 .293 .508 r
.39994 .48677 .40861 .28516 .41032 .28446 .40181 .48486 Mtetra
.53 .299 .51 r
.40181 .48486 .41032 .28446 .412 .28503 .40353 .48704 Mtetra
.538 .306 .511 r
.40353 .48704 .412 .28503 .40675 .47893 .4051 .49354 Mtetra
.587 .318 .475 r
.4051 .49354 .40675 .47893 .40796 .49565 .40681 .4963 Mtetra
.651 .152 .053 r
.40681 .4963 .40796 .49565 .40968 .49846 .40858 .49758 Mtetra
.479 .74 .985 r
.40858 .49758 .40968 .49846 .41149 .49843 .4104 .49744 Mtetra
.617 .771 .954 r
.4104 .49744 .41149 .49843 .41333 .49781 .41224 .49695 Mtetra
.659 .811 .957 r
.41224 .49695 .41333 .49781 .41518 .49694 .41408 .49629 Mtetra
.607 .844 .989 r
.41408 .49629 .41518 .49694 .41702 .49636 .41592 .49574 Mtetra
.623 .857 .987 r
.41592 .49574 .41702 .49636 .41886 .49573 .41776 .49513 Mtetra
.641 .865 .983 r
.41776 .49513 .41886 .49573 .4207 .49507 .4196 .49446 Mtetra
.669 .872 .975 r
.4196 .49446 .4207 .49507 .42255 .49436 .42145 .49371 Mtetra
.679 .865 .97 r
.42145 .49371 .42255 .49436 .4244 .49363 .4233 .49293 Mtetra
.672 .852 .968 r
.4233 .49293 .4244 .49363 .42625 .49294 .42516 .49219 Mtetra
.551 .804 .992 r
.42516 .49219 .42625 .49294 .42809 .49242 .427 .49182 Mtetra
.602 .856 .992 r
.427 .49182 .42809 .49242 .42994 .49183 .42884 .49126 Mtetra
.737 .892 .95 r
.42884 .49126 .42994 .49183 .43179 .49108 .43071 .49024 Mtetra
.905 .819 .752 r
.43071 .49024 .43179 .49108 .43367 .48968 .43262 .48727 Mtetra
.871 .685 .648 r
.43262 .48727 .43367 .48968 .43554 .48806 .4346 .48211 Mtetra
.96 .684 .467 r
.4346 .48211 .43554 .48806 .43742 .48641 .44169 .28566 Mtetra
.539 .311 .518 r
.44169 .28566 .43742 .48641 .43928 .48562 .44357 .27994 Mtetra
.526 .301 .516 r
.44357 .27994 .43928 .48562 .44113 .48511 .44529 .27997 Mtetra
.518 .295 .515 r
.44529 .27997 .44113 .48511 .44298 .48472 .44693 .28376 Mtetra
0 0 .322 r
.44693 .28376 .44298 .48472 .44482 .48479 .44421 .4649 Mtetra
.484 .293 .545 r
.44421 .4649 .44482 .48479 .44668 .48433 .446 .46697 Mtetra
.947 .668 .478 r
.446 .46697 .44668 .48433 .44856 .48287 .45215 .28275 Mtetra
.553 .323 .52 r
.45215 .28275 .44856 .48287 .45064 .47256 .45417 .2702 Mtetra
.535 .309 .518 r
.45417 .2702 .45064 .47256 .45695 .26926 .45599 .26606 Mtetra
.753 .594 .68 r
.45599 .26606 .45695 .26926 .45877 .26492 .45778 .26355 Mtetra
.697 .715 .863 r
.45778 .26355 .45877 .26492 .46052 .26382 .45953 .26272 Mtetra
.617 .737 .932 r
.45953 .26272 .46052 .26382 .46227 .26333 .46127 .26228 Mtetra
.567 .726 .949 r
.46127 .26228 .46227 .26333 .464 .26315 .46301 .26199 Mtetra
.734 .763 .876 r
.46301 .26199 .464 .26315 .46575 .26237 .46476 .26099 Mtetra
.703 .716 .859 r
.46476 .26099 .46575 .26237 .4675 .26162 .46652 .26012 Mtetra
.631 .669 .868 r
.46652 .26012 .4675 .26162 .46925 .26102 .46826 .25962 Mtetra
.107 .399 .853 r
.46826 .25962 .46925 .26102 .471 .26062 .46999 .26053 Mtetra
.811 .331 .056 r
.46999 .26053 .471 .26062 .47274 .26067 .47168 .26311 Mtetra
.964 .678 .442 r
.47168 .26311 .47274 .26067 .47446 .26158 .47038 .44584 Mtetra
.575 .335 .515 r
.47038 .44584 .47446 .26158 .47608 .26949 .47182 .47154 Mtetra
.531 .3 .51 r
.47182 .47154 .47608 .26949 .47474 .47288 .47364 .47455 Mtetra
.622 .193 .206 r
.47364 .47455 .47474 .47288 .47656 .4765 .47549 .47576 Mtetra
.395 .737 .992 r
.47549 .47576 .47656 .4765 .47843 .47671 .47737 .47571 Mtetra
.67 .792 .94 r
.47737 .47571 .47843 .47671 .48031 .47602 .47925 .475 Mtetra
.78 .812 .878 r
.47925 .475 .48031 .47602 .4822 .47482 .48114 .47367 Mtetra
.865 .793 .779 r
.48114 .47367 .4822 .47482 .48409 .47391 .48305 .47124 Mtetra
.843 .667 .664 r
.48305 .47124 .48409 .47391 .48598 .47263 .48498 .46702 Mtetra
.916 .655 .529 r
.48498 .46702 .48598 .47263 .48789 .47044 .48712 .44466 Mtetra
.94 .657 .475 r
.48712 .44466 .48789 .47044 .48986 .46145 .49105 .25656 Mtetra
.535 .308 .517 r
.49105 .25656 .48986 .46145 .49381 .25653 .49286 .25269 Mtetra
.716 .553 .667 r
.49286 .25269 .49381 .25653 .49562 .25199 .49464 .25043 Mtetra
.702 .693 .838 r
.49464 .25043 .49562 .25199 .49739 .25065 .49641 .24952 Mtetra
.608 .728 .93 r
.49641 .24952 .49739 .25065 .49916 .25016 .49818 .2491 Mtetra
.535 .715 .955 r
.49818 .2491 .49916 .25016 .50092 .25002 .49994 .2489 Mtetra
.632 .743 .927 r
.49994 .2489 .50092 .25002 .50269 .24952 .50171 .24839 Mtetra
.664 .751 .915 r
.50171 .24839 .50269 .24952 .50446 .24891 .50349 .24775 Mtetra
.679 .751 .905 r
.50349 .24775 .50446 .24891 .50624 .24826 .50526 .24705 Mtetra
.767 .765 .851 r
.50526 .24705 .50624 .24826 .50801 .2471 .50704 .24579 Mtetra
.731 .739 .858 r
.50704 .24579 .50801 .2471 .50979 .24615 .50882 .24475 Mtetra
.6 .675 .894 r
.50882 .24475 .50979 .24615 .51157 .24587 .51059 .24439 Mtetra
.689 .261 0 r
.51059 .24439 .51157 .24587 .51333 .24911 .51236 .24752 Mtetra
.971 .683 .421 r
.51236 .24752 .51333 .24911 .51445 .45661 .51341 .45532 Mtetra
.927 .546 .163 r
.51341 .45532 .51445 .45661 .51633 .46343 .51529 .46246 Mtetra
.092 .5 .902 r
.51529 .46246 .51633 .46343 .51823 .46409 .51719 .4631 Mtetra
.678 .8 .94 r
.51719 .4631 .51823 .46409 .52015 .46339 .51911 .46235 Mtetra
.766 .81 .888 r
.51911 .46235 .52015 .46339 .52206 .4622 .52102 .4611 Mtetra
.533 .723 .961 r
.52102 .4611 .52206 .4622 .52397 .46191 .52293 .46088 Mtetra
.516 .731 .971 r
.52293 .46088 .52397 .46191 .52588 .46161 .52485 .46069 Mtetra
.708 .823 .936 r
.52485 .46069 .52588 .46161 .5278 .46061 .52676 .45979 Mtetra
.947 .81 .676 r
.52676 .45979 .5278 .46061 .52971 .45608 .52868 .45535 Mtetra
.973 .689 .429 r
.52868 .45535 .52971 .45608 .5312 .24748 .53023 .24653 Mtetra
.966 .751 .563 r
.53023 .24653 .5312 .24748 .53297 .23907 .53201 .23775 Mtetra
.826 .763 .792 r
.53201 .23775 .53297 .23907 .53476 .23713 .5338 .23583 Mtetra
.632 .708 .901 r
.5338 .23583 .53476 .23713 .53655 .23657 .53559 .23532 Mtetra
.49 .654 .933 r
.53559 .23532 .53655 .23657 .53835 .23649 .53739 .23531 Mtetra
.599 .719 .928 r
.53739 .23531 .53835 .23649 .54015 .23608 .53918 .23492 Mtetra
.664 .748 .913 r
.53918 .23492 .54015 .23608 .54194 .23545 .54098 .23427 Mtetra
.679 .749 .904 r
.54098 .23427 .54194 .23545 .54374 .23478 .54278 .23355 Mtetra
.76 .765 .857 r
.54278 .23355 .54374 .23478 .54553 .23365 .54457 .23235 Mtetra
.742 .747 .856 r
.54457 .23235 .54553 .23365 .54733 .23262 .54637 .23123 Mtetra
.631 .694 .89 r
.54637 .23123 .54733 .23262 .54913 .23219 .54817 .23073 Mtetra
0 0 .555 r
.54817 .23073 .54913 .23219 .55096 .23451 .55 .23291 Mtetra
.973 .681 .406 r
.55 .23291 .55096 .23451 .55464 .43918 .5536 .43625 Mtetra
.934 .603 .158 r
.5536 .43625 .55464 .43918 .55667 .44954 .55565 .44832 Mtetra
0 .196 .707 r
.55565 .44832 .55667 .44954 .55863 .45088 .55761 .44985 Mtetra
.569 .755 .966 r
.55761 .44985 .55863 .45088 .56057 .45043 .55955 .44949 Mtetra
.766 .835 .906 r
.55955 .44949 .56057 .45043 .5625 .44933 .56148 .44827 Mtetra
.858 .82 .811 r
.56148 .44827 .5625 .44933 .56444 .44834 .56341 .44614 Mtetra
.851 .698 .691 r
.56341 .44614 .56444 .44834 .56637 .44723 .56531 .44256 Mtetra
.858 .627 .588 r
.56531 .44256 .56637 .44723 .5683 .44539 .56715 .43413 Mtetra
.965 .675 .432 r
.56715 .43413 .5683 .44539 .57018 .44005 .56635 .23177 Mtetra
.536 .309 .517 r
.56635 .23177 .57018 .44005 .56913 .2326 .56811 .22696 Mtetra
.684 .498 .628 r
.56811 .22696 .56913 .2326 .57086 .22616 .5699 .22436 Mtetra
.742 .683 .794 r
.5699 .22436 .57086 .22616 .57265 .22408 .57171 .22302 Mtetra
.674 .774 .926 r
.57171 .22302 .57265 .22408 .57447 .22333 .57353 .22232 Mtetra
.61 .762 .952 r
.57353 .22232 .57447 .22333 .57629 .22299 .57535 .22186 Mtetra
.716 .774 .898 r
.57535 .22186 .57629 .22299 .57811 .22218 .57717 .22095 Mtetra
.728 .761 .878 r
.57717 .22095 .57811 .22218 .57993 .2212 .57898 .21995 Mtetra
.604 .711 .919 r
.57898 .21995 .57993 .2212 .58175 .22081 .58081 .21955 Mtetra
0 0 .498 r
.58081 .21955 .58175 .22081 .58363 .22302 .58269 .2218 Mtetra
.974 .678 .392 r
.58269 .2218 .58363 .22302 .58957 .42887 .58857 .42835 Mtetra
.937 .565 .237 r
.58857 .42835 .58957 .42887 .59173 .4385 .59073 .43756 Mtetra
0 .227 .7 r
.59073 .43756 .59173 .4385 .59373 .4399 .59273 .4389 Mtetra
.649 .796 .953 r
.59273 .4389 .59373 .4399 .5957 .43931 .59469 .43824 Mtetra
.757 .813 .897 r
.59469 .43824 .5957 .43931 .59765 .43817 .59665 .43704 Mtetra
.625 .761 .944 r
.59665 .43704 .59765 .43817 .59962 .43759 .59861 .43649 Mtetra
.483 .704 .967 r
.59861 .43649 .59962 .43759 .60159 .43741 .60059 .4364 Mtetra
.654 .797 .952 r
.60059 .4364 .60159 .43741 .60356 .43663 .60256 .43573 Mtetra
.918 .838 .75 r
.60256 .43573 .60356 .43663 .60546 .43345 .60447 .43268 Mtetra
.982 .742 .498 r
.60447 .43268 .60546 .43345 .60702 .41637 .60611 .4188 Mtetra
.978 .689 .394 r
.60611 .4188 .60702 .41637 .60377 .21506 .60284 .21397 Mtetra
.91 .803 .729 r
.60284 .21397 .60377 .21506 .60555 .2121 .60461 .2109 Mtetra
.705 .761 .895 r
.60461 .2109 .60555 .2121 .60738 .21126 .60645 .21004 Mtetra
.577 .706 .931 r
.60645 .21004 .60738 .21126 .60923 .21095 .6083 .20973 Mtetra
.667 .742 .906 r
.6083 .20973 .60923 .21095 .61107 .21029 .61014 .20905 Mtetra
.731 .761 .876 r
.61014 .20905 .61107 .21029 .6129 .20928 .61197 .20802 Mtetra
.62 .716 .915 r
.61197 .20802 .6129 .20928 .61475 .20882 .61382 .20754 Mtetra
0 .136 .669 r
.61382 .20754 .61475 .20882 .61667 .21052 .61574 .20929 Mtetra
.975 .676 .377 r
.61574 .20929 .61667 .21052 .62477 .41237 .62383 .41276 Mtetra
.942 .586 .304 r
.62383 .41276 .62477 .41237 .62721 .42661 .62623 .42569 Mtetra
0 .035 .524 r
.62623 .42569 .62721 .42661 .62928 .42851 .6283 .4276 Mtetra
.571 .788 .981 r
.6283 .4276 .62928 .42851 .63127 .42805 .63029 .42718 Mtetra
.778 .859 .91 r
.63029 .42718 .63127 .42805 .63324 .42689 .63226 .42588 Mtetra
.867 .839 .816 r
.63226 .42588 .63324 .42689 .63521 .42562 .6342 .4237 Mtetra
.871 .728 .701 r
.6342 .4237 .63521 .42562 .63719 .42445 .6361 .42019 Mtetra
.867 .637 .588 r
.6361 .42019 .63719 .42445 .63914 .42259 .63783 .41222 Mtetra
.97 .674 .405 r
.63783 .41222 .63914 .42259 .64098 .41784 .63259 .20809 Mtetra
.536 .309 .517 r
.63259 .20809 .64098 .41784 .6354 .20927 .63429 .20303 Mtetra
.678 .486 .619 r
.63429 .20303 .6354 .20927 .63703 .20231 .63608 .20028 Mtetra
.776 .679 .756 r
.63608 .20028 .63703 .20231 .63881 .19953 .63789 .19841 Mtetra
.773 .799 .874 r
.63789 .19841 .63881 .19953 .64065 .19825 .63973 .19715 Mtetra
.638 .758 .935 r
.63973 .19715 .64065 .19825 .64252 .19782 .6416 .19659 Mtetra
.015 .369 .837 r
.6416 .19659 .64252 .19782 .64445 .19902 .64353 .19767 Mtetra
.899 .513 .072 r
.64353 .19767 .64445 .19902 .64664 .20644 .64572 .20498 Mtetra
.976 .673 .363 r
.64572 .20498 .64664 .20644 .65707 .41532 .6561 .41419 Mtetra
.672 .204 0 r
.6561 .41419 .65707 .41532 .65923 .41849 .65826 .41738 Mtetra
.398 .659 .964 r
.65826 .41738 .65923 .41849 .66128 .41864 .6603 .41751 Mtetra
.723 .8 .912 r
.6603 .41751 .66128 .41864 .66327 .41764 .6623 .41649 Mtetra
.903 .816 .751 r
.6623 .41649 .66327 .41764 .66518 .41469 .66421 .41352 Mtetra
.979 .744 .511 r
.66421 .41352 .66518 .41469 .66671 .40308 .66575 .40199 Mtetra
.977 .681 .375 r
.66575 .40199 .66671 .40308 .6595 .19574 .65859 .1945 Mtetra
.923 .789 .695 r
.65859 .1945 .6595 .19574 .66125 .19212 .66034 .19088 Mtetra
.719 .762 .887 r
.66034 .19088 .66125 .19212 .66311 .19116 .6622 .18992 Mtetra
.594 .712 .926 r
.6622 .18992 .66311 .19116 .665 .19078 .66409 .18953 Mtetra
.623 .725 .92 r
.66409 .18953 .665 .19078 .66688 .19028 .66598 .18904 Mtetra
.737 .768 .878 r
.66598 .18904 .66688 .19028 .66875 .18921 .66784 .18796 Mtetra
.646 .735 .914 r
.66784 .18796 .66875 .18921 .67063 .18861 .66973 .18736 Mtetra
.096 .422 .868 r
.66973 .18736 .67063 .18861 .67259 .18955 .67169 .18831 Mtetra
.919 .543 .123 r
.67169 .18831 .67259 .18955 .67495 .19853 .67405 .19731 Mtetra
.975 .67 .349 r
.67405 .19731 .67495 .19853 .68732 .40595 .68636 .40476 Mtetra
.595 .132 0 r
.68636 .40476 .68732 .40595 .68953 .40896 .68857 .40771 Mtetra
.496 .683 .95 r
.68857 .40771 .68953 .40896 .6916 .409 .69063 .40763 Mtetra
.706 .753 .889 r
.69063 .40763 .6916 .409 .69361 .40801 .69265 .40666 Mtetra
.808 .786 .833 r
.69265 .40666 .69361 .40801 .69555 .40564 .69462 .40492 Mtetra
.92 .888 .784 r
.69462 .40492 .69555 .40564 .6973 .39958 .69655 .40224 Mtetra
0 0 0 r
.69655 .40224 .6973 .39958 .68803 .1902 .69837 .39757 Mtetra
0 0 .388 r
.69837 .39757 .68803 .1902 .68963 .18413 .68948 .19649 Mtetra
0 0 .326 r
.68948 .19649 .68963 .18413 .69146 .18227 .69077 .18469 Mtetra
0 0 0 r
.69077 .18469 .69146 .18227 .69333 .18113 .69251 .18103 Mtetra
.874 .99 .816 r
.69251 .18103 .69333 .18113 .69522 .18032 .69433 .17902 Mtetra
.701 .748 .888 r
.69433 .17902 .69522 .18032 .69712 .1796 .69622 .17814 Mtetra
.632 .692 .888 r
.69622 .17814 .69712 .1796 .69902 .17899 .69813 .1776 Mtetra
.647 .711 .895 r
.69813 .1776 .69902 .17899 .70092 .17825 .70003 .17699 Mtetra
.75 .774 .873 r
.70003 .17699 .70092 .17825 .7028 .17708 .70191 .17583 Mtetra
.664 .744 .909 r
.70191 .17583 .7028 .17708 .7047 .17637 .70381 .17514 Mtetra
.22 .506 .907 r
.70381 .17514 .7047 .17637 .70668 .17699 .7058 .17581 Mtetra
.909 .528 .097 r
.7058 .17581 .70668 .17699 .70911 .18475 .70829 .18465 Mtetra
.974 .665 .334 r
.70829 .18465 .70911 .18475 .72402 .39401 .72311 .39327 Mtetra
.709 .212 0 r
.72311 .39327 .72402 .39401 .72632 .39738 .7254 .39643 Mtetra
.486 .744 .985 r
.7254 .39643 .72632 .39738 .72842 .39743 .72749 .39625 Mtetra
.729 .798 .907 r
.72749 .39625 .72842 .39743 .73046 .39644 .72952 .39517 Mtetra
.824 .807 .835 r
.72952 .39517 .73046 .39644 .73242 .3942 .73151 .39333 Mtetra
.91 .872 .787 r
.73151 .39333 .73242 .3942 .73416 .38864 .73344 .3907 Mtetra
0 0 0 r
.73344 .3907 .73416 .38864 .72248 .17918 .73526 .38628 Mtetra
.029 0 .408 r
.73526 .38628 .72248 .17918 .72397 .17196 .72464 .19414 Mtetra
.001 0 .365 r
.72464 .19414 .72397 .17196 .7258 .16997 .72519 .1727 Mtetra
0 0 .011 r
.72519 .1727 .7258 .16997 .72768 .16877 .7269 .16881 Mtetra
.869 .995 .771 r
.7269 .16881 .72768 .16877 .72959 .16793 .72872 .16662 Mtetra
.708 .752 .887 r
.72872 .16662 .72959 .16793 .73151 .16719 .73062 .1657 Mtetra
.636 .691 .885 r
.73062 .1657 .73151 .16719 .73344 .16656 .73255 .16513 Mtetra
.627 .697 .895 r
.73255 .16513 .73344 .16656 .73537 .16589 .73449 .16461 Mtetra
.752 .773 .87 r
.73449 .16461 .73537 .16589 .73726 .16469 .73638 .16341 Mtetra
.676 .746 .904 r
.73638 .16341 .73726 .16469 .73918 .16392 .73831 .16266 Mtetra
.369 .594 .932 r
.73831 .16266 .73918 .16392 .74117 .1642 .74031 .16298 Mtetra
.856 .455 0 r
.74031 .16298 .74117 .1642 .74361 .17038 .74278 .16979 Mtetra
.973 .661 .314 r
.74278 .16979 .74361 .17038 .76115 .38132 .76027 .38061 Mtetra
.755 .274 0 r
.76027 .38061 .76115 .38132 .76358 .38533 .76268 .38439 Mtetra
.441 .725 .986 r
.76268 .38439 .76358 .38533 .76572 .3855 .76481 .38432 Mtetra
.715 .798 .917 r
.76481 .38432 .76572 .3855 .76779 .3846 .76687 .38331 Mtetra
.819 .809 .841 r
.76687 .38331 .76779 .3846 .76978 .38255 .76887 .38152 Mtetra
.897 .855 .792 r
.76887 .38152 .76978 .38255 .77152 .37741 .77082 .37898 Mtetra
.664 .77 .293 r
.77082 .37898 .77152 .37741 .75741 .16837 .77263 .37478 Mtetra
.5 .277 .507 r
.77263 .37478 .75741 .16837 .75872 .15963 .77363 .36013 Mtetra
.001 0 .404 r
.77363 .36013 .75872 .15963 .76055 .15749 .76003 .16055 Mtetra
0 0 .076 r
.76003 .16055 .76055 .15749 .76245 .1562 .76171 .15641 Mtetra
.846 .985 .704 r
.76171 .15641 .76245 .1562 .76438 .15532 .76352 .15405 Mtetra
.754 .779 .874 r
.76352 .15405 .76438 .15532 .76629 .15418 .76542 .15284 Mtetra
.65 .727 .905 r
.76542 .15284 .76629 .15418 .76823 .1535 .76738 .1522 Mtetra
.503 .664 .934 r
.76738 .1522 .76823 .1535 .77024 .15355 .76938 .15214 Mtetra
.159 .429 .866 r
.76938 .15214 .77024 .15355 .77253 .15694 .77147 .15313 Mtetra
.175 .214 .663 r
.77147 .15313 .77253 .15694 .79198 .36506 .77371 .15588 Mtetra
.034 0 .425 r
.77371 .15588 .79198 .36506 .79478 .37265 .7925 .35503 Mtetra
.135 .06 .5 r
.7925 .35503 .79478 .37265 .79707 .37417 .79583 .36898 Mtetra
.31 .27 .651 r
.79583 .36898 .79707 .37417 .79925 .37424 .79822 .37153 Mtetra
.487 .491 .787 r
.79822 .37153 .79925 .37424 .80132 .3731 .80041 .37184 Mtetra
.894 .745 .689 r
.12894 .58506 .13014 .58607 .13227 .58131 .13103 .58073 Mtetra
.937 .687 .534 r
.13103 .58073 .13227 .58131 .15709 .37911 .15589 .37882 Mtetra
.938 .747 .619 r
.15589 .37882 .15709 .37911 .15943 .37171 .15833 .37068 Mtetra
.779 .76 .836 r
.15833 .37068 .15943 .37171 .16107 .37046 .15997 .36941 Mtetra
.649 .735 .912 r
.15997 .36941 .16107 .37046 .16262 .36997 .16152 .3689 Mtetra
.533 .693 .942 r
.16152 .3689 .16262 .36997 .16413 .36985 .16303 .36876 Mtetra
.675 .733 .894 r
.16303 .36876 .16413 .36985 .1657 .36926 .1646 .36814 Mtetra
.682 .73 .887 r
.1646 .36814 .1657 .36926 .16727 .36862 .16617 .36749 Mtetra
.686 .729 .883 r
.16617 .36749 .16727 .36862 .16884 .36793 .16775 .36682 Mtetra
.761 .746 .838 r
.16775 .36682 .16884 .36793 .17049 .36667 .16938 .36565 Mtetra
.721 .758 .881 r
.16938 .36565 .17049 .36667 .17209 .36573 .17097 .36481 Mtetra
.546 .731 .961 r
.17097 .36481 .17209 .36573 .17363 .36545 .1725 .3646 Mtetra
.9 .486 .182 r
.1725 .3646 .17363 .36545 .17479 .36857 .17365 .36778 Mtetra
.939 .683 .522 r
.17365 .36778 .17479 .36857 .15441 .56894 .15321 .56808 Mtetra
.938 .613 .393 r
.15321 .56808 .15441 .56894 .15515 .57681 .15398 .57569 Mtetra
.205 .537 .925 r
.15398 .57569 .15515 .57681 .15671 .57728 .15554 .57614 Mtetra
.674 .74 .9 r
.15554 .57614 .15671 .57728 .15839 .57664 .15722 .57549 Mtetra
.75 .752 .854 r
.15722 .57549 .15839 .57664 .16012 .57553 .15895 .57436 Mtetra
.622 .719 .916 r
.15895 .57436 .16012 .57553 .16175 .57536 .16061 .57393 Mtetra
.613 .672 .882 r
.16061 .57393 .16175 .57536 .1634 .5751 .16227 .57354 Mtetra
.64 .662 .855 r
.16227 .57354 .1634 .5751 .16508 .57443 .16394 .57301 Mtetra
.744 .712 .822 r
.16394 .57301 .16508 .57443 .167 .57154 .16569 .57181 Mtetra
.778 .992 .884 r
.16569 .57181 .167 .57154 .16918 .56617 .16745 .57042 Mtetra
.328 .009 .263 r
.16745 .57042 .16918 .56617 .19043 .37833 .1692 .56919 Mtetra
.526 .296 .509 r
.1692 .56919 .19043 .37833 .17268 .56366 .1708 .56936 Mtetra
.54 .235 .4 r
.1708 .56936 .17268 .56366 .17375 .56898 .17237 .56986 Mtetra
.48 0 0 r
.17237 .56986 .17375 .56898 .17512 .5714 .17395 .57024 Mtetra
.567 .704 .934 r
.17395 .57024 .17512 .5714 .17673 .57155 .1756 .56999 Mtetra
.63 .659 .86 r
.1756 .56999 .17673 .57155 .1784 .57107 .17728 .56951 Mtetra
.645 .665 .855 r
.17728 .56951 .1784 .57107 .1801 .57039 .17896 .56896 Mtetra
.625 .677 .88 r
.17896 .56896 .1801 .57039 .18177 .56999 .18064 .56851 Mtetra
.619 .668 .875 r
.18064 .56851 .18177 .56999 .18343 .56966 .18231 .56809 Mtetra
.622 .656 .862 r
.18231 .56809 .18343 .56966 .1851 .5693 .18399 .56765 Mtetra
.629 .648 .85 r
.18399 .56765 .1851 .5693 .18678 .56886 .18567 .56718 Mtetra
.635 .645 .844 r
.18567 .56718 .18678 .56886 .18847 .56835 .18736 .56666 Mtetra
.64 .647 .841 r
.18736 .56666 .18847 .56835 .19016 .56778 .18905 .56612 Mtetra
.637 .649 .846 r
.18905 .56612 .19016 .56778 .19184 .56731 .19073 .5656 Mtetra
.645 .647 .837 r
.19073 .5656 .19184 .56731 .19354 .5667 .19243 .56503 Mtetra
.664 .658 .834 r
.19243 .56503 .19354 .5667 .19527 .56576 .19414 .56434 Mtetra
.726 .71 .836 r
.19414 .56434 .19527 .56576 .19712 .56356 .19588 .5633 Mtetra
.795 .925 .922 r
.19588 .5633 .19712 .56356 .19912 .55989 .19764 .56205 Mtetra
.062 0 0 r
.19764 .56205 .19912 .55989 .20143 .55288 .19941 .56076 Mtetra
.488 .206 .411 r
.19941 .56076 .20143 .55288 .20356 .54782 .20109 .5604 Mtetra
.506 .243 .451 r
.20109 .5604 .20356 .54782 .20511 .54872 .20276 .56012 Mtetra
.475 .212 .435 r
.20276 .56012 .20511 .54872 .20682 .54794 .2045 .55916 Mtetra
.206 0 .334 r
.2045 .55916 .20682 .54794 .22663 .35449 .20664 .55391 Mtetra
0 0 .114 r
.20664 .55391 .22663 .35449 .22872 .3487 .22729 .35126 Mtetra
.963 .9 .529 r
.22729 .35126 .22872 .3487 .23054 .34573 .2294 .34528 Mtetra
.858 .866 .845 r
.2294 .34528 .23054 .34573 .2322 .34456 .23111 .34357 Mtetra
.66 .756 .921 r
.23111 .34357 .2322 .34456 .23379 .34411 .23271 .34301 Mtetra
.549 .695 .936 r
.23271 .34301 .23379 .34411 .23536 .34389 .23428 .34282 Mtetra
.654 .738 .911 r
.23428 .34282 .23536 .34389 .23698 .34315 .23588 .34228 Mtetra
.694 .789 .923 r
.23588 .34228 .23698 .34315 .23861 .34229 .2375 .34158 Mtetra
.665 .821 .959 r
.2375 .34158 .23861 .34229 .24021 .34172 .2391 .34098 Mtetra
.641 .809 .964 r
.2391 .34098 .24021 .34172 .24173 .34216 .24071 .34046 Mtetra
.578 .605 .844 r
.24071 .34046 .24173 .34216 .24313 .34396 .24228 .34024 Mtetra
.482 .402 .69 r
.24228 .34024 .24313 .34396 .24421 .34936 .2438 .34067 Mtetra
.25 .145 .534 r
.2438 .34067 .24421 .34936 .22839 .54685 .24503 .34446 Mtetra
0 0 .153 r
.24503 .34446 .22839 .54685 .22966 .55136 .22887 .54612 Mtetra
0 0 .309 r
.22887 .54612 .22966 .55136 .23117 .55315 .23006 .55156 Mtetra
0 .201 .728 r
.23006 .55156 .23117 .55315 .23278 .55389 .23162 .55289 Mtetra
.5 .715 .968 r
.23162 .55289 .23278 .55389 .23445 .55384 .2333 .55277 Mtetra
.751 .772 .87 r
.2333 .55277 .23445 .55384 .2362 .55294 .23507 .55166 Mtetra
.881 .741 .703 r
.23507 .55166 .2362 .55294 .23818 .54933 .23706 .54792 Mtetra
.947 .688 .513 r
.23706 .54792 .23818 .54933 .25668 .35028 .25565 .34864 Mtetra
.926 .701 .578 r
.25565 .34864 .25668 .35028 .25942 .33646 .25833 .3356 Mtetra
.866 .789 .773 r
.25833 .3356 .25942 .33646 .26118 .33419 .26009 .33329 Mtetra
.656 .777 .937 r
.26009 .33329 .26118 .33419 .26279 .33373 .26171 .33274 Mtetra
.462 .685 .963 r
.26171 .33274 .26279 .33373 .26436 .33384 .26329 .33272 Mtetra
.542 .691 .936 r
.26329 .33272 .26436 .33384 .26594 .33376 .26488 .33255 Mtetra
.622 .705 .904 r
.26488 .33255 .26594 .33376 .26755 .33335 .26649 .33214 Mtetra
.631 .705 .9 r
.26649 .33214 .26755 .33335 .26916 .33289 .2681 .33168 Mtetra
.65 .713 .894 r
.2681 .33168 .26916 .33289 .27078 .33237 .26972 .33115 Mtetra
.667 .717 .886 r
.26972 .33115 .27078 .33237 .27241 .33177 .27135 .33054 Mtetra
.678 .718 .879 r
.27135 .33054 .27241 .33177 .27405 .33109 .27299 .32987 Mtetra
.689 .723 .876 r
.27299 .32987 .27405 .33109 .27569 .33028 .27463 .32915 Mtetra
.699 .742 .885 r
.27463 .32915 .27569 .33028 .27735 .32938 .27627 .32839 Mtetra
.704 .768 .902 r
.27627 .32839 .27735 .32938 .279 .3285 .27792 .32762 Mtetra
.7 .793 .922 r
.27792 .32762 .279 .3285 .28065 .32771 .27956 .32689 Mtetra
.693 .803 .933 r
.27956 .32689 .28065 .32771 .28229 .32701 .2812 .32618 Mtetra
.687 .802 .936 r
.2812 .32618 .28229 .32701 .28393 .32634 .28285 .3255 Mtetra
.68 .797 .937 r
.28285 .3255 .28393 .32634 .28557 .3257 .28449 .32484 Mtetra
.673 .793 .938 r
.28449 .32484 .28557 .3257 .28721 .32507 .28612 .32421 Mtetra
.668 .792 .941 r
.28612 .32421 .28721 .32507 .28884 .32446 .28776 .32361 Mtetra
.663 .791 .943 r
.28776 .32361 .28884 .32446 .29048 .32386 .2894 .32302 Mtetra
.658 .791 .945 r
.2894 .32302 .29048 .32386 .29212 .32328 .29104 .32244 Mtetra
.652 .791 .949 r
.29104 .32244 .29212 .32328 .29376 .32272 .29268 .32189 Mtetra
.646 .792 .952 r
.29268 .32189 .29376 .32272 .29539 .32216 .29431 .32135 Mtetra
.638 .796 .958 r
.29431 .32135 .29539 .32216 .29703 .32161 .29595 .32083 Mtetra
.629 .8 .965 r
.29595 .32083 .29703 .32161 .29867 .3211 .29759 .32034 Mtetra
.617 .801 .97 r
.29759 .32034 .29867 .3211 .3003 .32068 .29922 .31988 Mtetra
.61 .79 .968 r
.29922 .31988 .3003 .32068 .30193 .32035 .30086 .31945 Mtetra
.613 .769 .955 r
.30086 .31945 .30193 .32035 .30355 .32002 .30249 .31903 Mtetra
.62 .748 .938 r
.30249 .31903 .30355 .32002 .30519 .31964 .30413 .3186 Mtetra
.627 .74 .928 r
.30413 .3186 .30519 .31964 .30683 .31917 .30576 .31814 Mtetra
.631 .745 .93 r
.30576 .31814 .30683 .31917 .30847 .31867 .30741 .31767 Mtetra
.636 .755 .934 r
.30741 .31767 .30847 .31867 .31011 .31814 .30905 .31718 Mtetra
.642 .764 .937 r
.30905 .31718 .31011 .31814 .31176 .31761 .3107 .31667 Mtetra
.649 .77 .937 r
.3107 .31667 .31176 .31761 .31341 .31706 .31235 .31613 Mtetra
.657 .775 .936 r
.31235 .31613 .31341 .31706 .31506 .31648 .314 .31556 Mtetra
.665 .779 .934 r
.314 .31556 .31506 .31648 .31672 .31588 .31565 .31496 Mtetra
.671 .779 .93 r
.31565 .31496 .31672 .31588 .31837 .31527 .31731 .31433 Mtetra
.677 .778 .927 r
.31731 .31433 .31837 .31527 .32003 .31464 .31897 .31368 Mtetra
.681 .775 .922 r
.31897 .31368 .32003 .31464 .32169 .314 .32064 .31302 Mtetra
.684 .772 .918 r
.32064 .31302 .32169 .314 .32336 .31334 .3223 .31234 Mtetra
.685 .767 .913 r
.3223 .31234 .32336 .31334 .32502 .31268 .32397 .31165 Mtetra
.687 .762 .909 r
.32397 .31165 .32502 .31268 .32669 .31201 .32563 .31095 Mtetra
.688 .757 .905 r
.32563 .31095 .32669 .31201 .32835 .31133 .3273 .31025 Mtetra
.688 .752 .901 r
.3273 .31025 .32835 .31133 .33002 .31065 .32897 .30954 Mtetra
.688 .747 .896 r
.32897 .30954 .33002 .31065 .33169 .30997 .33064 .30882 Mtetra
.69 .741 .89 r
.33064 .30882 .33169 .30997 .33336 .30926 .33232 .30809 Mtetra
.694 .739 .886 r
.33232 .30809 .33336 .30926 .33504 .30847 .33399 .30734 Mtetra
.699 .747 .889 r
.33399 .30734 .33504 .30847 .33672 .30761 .33567 .30657 Mtetra
.699 .765 .903 r
.33567 .30657 .33672 .30761 .3384 .30676 .33735 .30581 Mtetra
.726 .789 .902 r
.33735 .30581 .3384 .30676 .34009 .30587 .33903 .30493 Mtetra
.743 .792 .892 r
.33903 .30493 .34009 .30587 .34177 .30498 .34073 .30394 Mtetra
.652 .752 .923 r
.34073 .30394 .34177 .30498 .34344 .30439 .34239 .30339 Mtetra
.01 .424 .861 r
.34239 .30339 .34344 .30439 .34507 .30451 .34399 .3041 Mtetra
.913 .528 .267 r
.34399 .3041 .34507 .30451 .34662 .30604 .34535 .30895 Mtetra
.952 .679 .482 r
.34535 .30895 .34662 .30604 .34802 .31035 .33543 .51262 Mtetra
.534 .302 .51 r
.33543 .51262 .34802 .31035 .33849 .51019 .33693 .51693 Mtetra
.54 .243 .411 r
.33693 .51693 .33849 .51019 .33993 .51572 .33866 .51751 Mtetra
.393 0 .099 r
.33866 .51751 .33993 .51572 .34158 .51775 .34043 .51736 Mtetra
.523 .863 .993 r
.34043 .51736 .34158 .51775 .3433 .51839 .34221 .5169 Mtetra
.63 .68 .879 r
.34221 .5169 .3433 .51839 .34508 .51801 .344 .5164 Mtetra
.651 .67 .856 r
.344 .5164 .34508 .51801 .34689 .51731 .34579 .51578 Mtetra
.629 .674 .874 r
.34579 .51578 .34689 .51731 .34869 .51663 .34759 .51528 Mtetra
.556 .675 .917 r
.34759 .51528 .34869 .51663 .35047 .51628 .34936 .51507 Mtetra
.661 .738 .907 r
.34936 .51507 .35047 .51628 .35227 .51567 .35116 .51443 Mtetra
.821 .766 .8 r
.35116 .51443 .35227 .51567 .35411 .51427 .35303 .51251 Mtetra
.907 .715 .632 r
.35303 .51251 .35411 .51427 .35604 .51103 .35513 .50613 Mtetra
.955 .685 .487 r
.35513 .50613 .35604 .51103 .35811 .50508 .36725 .30094 Mtetra
.537 .31 .518 r
.36725 .30094 .35811 .50508 .36947 .31165 .36917 .29585 Mtetra
.557 .353 .56 r
.36917 .29585 .36947 .31165 .37117 .31092 .37087 .29488 Mtetra
.54 .34 .558 r
.37087 .29488 .37117 .31092 .37259 .3162 .37255 .29456 Mtetra
.538 .33 .546 r
.37255 .29456 .37259 .3162 .3748 .30486 .37423 .29415 Mtetra
.582 .387 .582 r
.37423 .29415 .3748 .30486 .37685 .29697 .37596 .29285 Mtetra
.647 .501 .67 r
.37596 .29285 .37685 .29697 .37868 .2934 .37768 .29161 Mtetra
.704 .657 .801 r
.37768 .29161 .37868 .2934 .38044 .29138 .3794 .29061 Mtetra
.651 .814 .961 r
.3794 .29061 .38044 .29138 .38214 .29073 .38109 .29002 Mtetra
.609 .818 .98 r
.38109 .29002 .38214 .29073 .38382 .29041 .38278 .28955 Mtetra
.62 .784 .96 r
.38278 .28955 .38382 .29041 .3855 .29017 .38447 .28908 Mtetra
.66 .747 .914 r
.38447 .28908 .3855 .29017 .38719 .28963 .38617 .28848 Mtetra
.667 .739 .904 r
.38617 .28848 .38719 .28963 .38889 .28903 .38787 .28785 Mtetra
.675 .737 .897 r
.38787 .28785 .38889 .28903 .3906 .28834 .38958 .28719 Mtetra
.685 .743 .895 r
.38958 .28719 .3906 .28834 .39231 .28754 .39128 .28647 Mtetra
.688 .76 .906 r
.39128 .28647 .39231 .28754 .39402 .28673 .39299 .28575 Mtetra
.702 .781 .913 r
.39299 .28575 .39402 .28673 .39573 .28591 .3947 .28497 Mtetra
.746 .799 .895 r
.3947 .28497 .39573 .28591 .39745 .28502 .39642 .28396 Mtetra
.667 .757 .918 r
.39642 .28396 .39745 .28502 .39915 .28439 .39813 .28334 Mtetra
.31 .599 .948 r
.39813 .28334 .39915 .28439 .40084 .28435 .3998 .28364 Mtetra
.901 .486 .157 r
.3998 .28364 .40084 .28435 .40245 .28606 .40132 .28783 Mtetra
.959 .681 .464 r
.40132 .28783 .40245 .28606 .40397 .29034 .39499 .49235 Mtetra
.535 .304 .51 r
.39499 .49235 .40397 .29034 .39814 .48671 .39659 .49759 Mtetra
.512 .242 .442 r
.39659 .49759 .39814 .48671 .39994 .48677 .3984 .49755 Mtetra
.482 .215 .433 r
.3984 .49755 .39994 .48677 .40181 .48486 .40023 .49675 Mtetra
.482 .22 .44 r
.40023 .49675 .40181 .48486 .40353 .48704 .40208 .49586 Mtetra
.518 .237 .428 r
.40208 .49586 .40353 .48704 .4051 .49354 .40388 .49602 Mtetra
.481 .093 .226 r
.40388 .49602 .4051 .49354 .40681 .4963 .40569 .49615 Mtetra
.106 .656 .817 r
.40569 .49615 .40681 .4963 .40858 .49758 .40751 .49612 Mtetra
.61 .682 .893 r
.40751 .49612 .40858 .49758 .4104 .49744 .40934 .4957 Mtetra
.631 .65 .85 r
.40934 .4957 .4104 .49744 .41224 .49695 .41117 .49517 Mtetra
.641 .648 .842 r
.41117 .49517 .41224 .49695 .41408 .49629 .41301 .49457 Mtetra
.637 .655 .851 r
.41301 .49457 .41408 .49629 .41592 .49574 .41485 .49401 Mtetra
.641 .655 .848 r
.41485 .49401 .41592 .49574 .41776 .49513 .41669 .49342 Mtetra
.646 .659 .849 r
.41669 .49342 .41776 .49513 .4196 .49446 .41854 .4928 Mtetra
.653 .669 .853 r
.41854 .4928 .4196 .49446 .42145 .49371 .42038 .49215 Mtetra
.658 .685 .864 r
.42038 .49215 .42145 .49371 .4233 .49293 .42223 .49148 Mtetra
.654 .701 .88 r
.42223 .49148 .4233 .49293 .42516 .49219 .42408 .49085 Mtetra
.55 .677 .922 r
.42408 .49085 .42516 .49219 .427 .49182 .42592 .49064 Mtetra
.636 .742 .925 r
.42592 .49064 .427 .49182 .42884 .49126 .42777 .4901 Mtetra
.769 .78 .862 r
.42777 .4901 .42884 .49126 .43071 .49024 .42964 .4888 Mtetra
.914 .744 .657 r
.42964 .4888 .43071 .49024 .43262 .48727 .43162 .48372 Mtetra
.963 .687 .464 r
.43162 .48372 .43262 .48727 .4346 .48211 .43913 .2783 Mtetra
.543 .315 .519 r
.43913 .2783 .4346 .48211 .44169 .28566 .44107 .2702 Mtetra
.567 .362 .562 r
.44107 .2702 .44169 .28566 .44357 .27994 .44283 .26884 Mtetra
.552 .363 .578 r
.44283 .26884 .44357 .27994 .44529 .27997 .44456 .26833 Mtetra
.536 .349 .574 r
.44456 .26833 .44529 .27997 .44693 .28376 .44628 .26826 Mtetra
.544 .344 .56 r
.44628 .26826 .44693 .28376 .44421 .4649 .44802 .26779 Mtetra
.527 .302 .516 r
.44802 .26779 .44421 .4649 .446 .46697 .44976 .26724 Mtetra
.528 .302 .516 r
.44976 .26724 .446 .46697 .45215 .28275 .4515 .26652 Mtetra
.564 .358 .56 r
.4515 .26652 .45215 .28275 .45417 .2702 .45326 .26518 Mtetra
.634 .474 .648 r
.45326 .26518 .45417 .2702 .45599 .26606 .45502 .26385 Mtetra
.703 .622 .763 r
.45502 .26385 .45599 .26606 .45778 .26355 .45678 .26266 Mtetra
.68 .803 .94 r
.45678 .26266 .45778 .26355 .45953 .26272 .45852 .26196 Mtetra
.639 .821 .97 r
.45852 .26196 .45953 .26272 .46127 .26228 .46027 .26139 Mtetra
.632 .789 .957 r
.46027 .26139 .46127 .26228 .46301 .26199 .46201 .26086 Mtetra
.748 .771 .872 r
.46201 .26086 .46301 .26199 .46476 .26099 .46377 .25978 Mtetra
.7 .744 .886 r
.46377 .25978 .46476 .26099 .46652 .26012 .46552 .25896 Mtetra
.558 .703 .937 r
.46552 .25896 .46652 .26012 .46826 .25962 .46727 .25873 Mtetra
.773 .291 0 r
.46727 .25873 .46826 .25962 .46999 .26053 .46896 .26143 Mtetra
.966 .681 .441 r
.46896 .26143 .46999 .26053 .47168 .26311 .46718 .46198 Mtetra
.547 .313 .512 r
.46718 .46198 .47168 .26311 .47038 .44584 .46884 .47354 Mtetra
.54 .291 .488 r
.46884 .47354 .47038 .44584 .47182 .47154 .47069 .4748 Mtetra
.487 .129 .284 r
.47069 .4748 .47182 .47154 .47364 .47455 .47256 .47489 Mtetra
0 0 0 r
.47256 .47489 .47364 .47455 .47549 .47576 .47443 .47445 Mtetra
.53 .678 .932 r
.47443 .47445 .47549 .47576 .47737 .47571 .47631 .4743 Mtetra
.637 .705 .896 r
.47631 .4743 .47737 .47571 .47925 .475 .47819 .47375 Mtetra
.76 .769 .86 r
.47819 .47375 .47925 .475 .48114 .47367 .48009 .47248 Mtetra
.922 .772 .678 r
.48009 .47248 .48114 .47367 .48305 .47124 .48202 .46807 Mtetra
.967 .687 .449 r
.48202 .46807 .48305 .47124 .48498 .46702 .48644 .26458 Mtetra
.549 .319 .519 r
.48644 .26458 .48498 .46702 .48712 .44466 .48833 .25363 Mtetra
.531 .305 .517 r
.48833 .25363 .48712 .44466 .49105 .25656 .49012 .25132 Mtetra
.622 .462 .644 r
.49012 .25132 .49105 .25656 .49286 .25269 .49189 .25012 Mtetra
.641 .566 .754 r
.49189 .25012 .49286 .25269 .49464 .25043 .49366 .24938 Mtetra
.659 .765 .928 r
.49366 .24938 .49464 .25043 .49641 .24952 .49543 .24876 Mtetra
.611 .817 .979 r
.49543 .24876 .49641 .24952 .49818 .2491 .49719 .24826 Mtetra
.6 .793 .973 r
.49719 .24826 .49818 .2491 .49994 .2489 .49896 .24782 Mtetra
.656 .757 .924 r
.49896 .24782 .49994 .2489 .50171 .24839 .50074 .24721 Mtetra
.672 .743 .904 r
.50074 .24721 .50171 .24839 .50349 .24775 .50251 .24653 Mtetra
.678 .739 .897 r
.50251 .24653 .50349 .24775 .50526 .24705 .50428 .24582 Mtetra
.755 .761 .858 r
.50428 .24582 .50526 .24705 .50704 .24579 .50606 .24465 Mtetra
.724 .769 .889 r
.50606 .24465 .50704 .24579 .50882 .24475 .50784 .24371 Mtetra
.564 .733 .954 r
.50784 .24371 .50882 .24475 .51059 .24439 .50962 .24342 Mtetra
.788 .321 0 r
.50962 .24342 .51059 .24439 .51236 .24752 .51138 .24651 Mtetra
.971 .682 .422 r
.51138 .24651 .51236 .24752 .51341 .45532 .51237 .45363 Mtetra
.921 .547 .128 r
.51237 .45363 .51341 .45532 .51529 .46246 .51425 .46095 Mtetra
.229 .475 .885 r
.51425 .46095 .51529 .46246 .51719 .4631 .51615 .46169 Mtetra
.651 .712 .893 r
.51615 .46169 .51719 .4631 .51911 .46235 .51806 .46105 Mtetra
.737 .761 .872 r
.51806 .46105 .51911 .46235 .52102 .4611 .51998 .45994 Mtetra
.551 .717 .95 r
.51998 .45994 .52102 .4611 .52293 .46088 .52189 .45968 Mtetra
.561 .714 .943 r
.52189 .45968 .52293 .46088 .52485 .46069 .52381 .45939 Mtetra
.715 .755 .884 r
.52381 .45939 .52485 .46069 .52676 .45979 .52573 .45842 Mtetra
.916 .763 .677 r
.52573 .45842 .52676 .45979 .52868 .45535 .52764 .45403 Mtetra
.972 .688 .43 r
.52764 .45403 .52868 .45535 .53023 .24653 .52926 .24606 Mtetra
.979 .768 .549 r
.52926 .24606 .53023 .24653 .53201 .23775 .53104 .23693 Mtetra
.869 .845 .818 r
.53104 .23693 .53201 .23775 .5338 .23583 .53283 .23493 Mtetra
.651 .799 .954 r
.53283 .23493 .5338 .23583 .53559 .23532 .53463 .23432 Mtetra
.505 .717 .967 r
.53463 .23432 .53559 .23532 .53739 .23531 .53642 .23418 Mtetra
.62 .739 .931 r
.53642 .23418 .53739 .23531 .53918 .23492 .53822 .23371 Mtetra
.671 .741 .903 r
.53822 .23371 .53918 .23492 .54098 .23427 .54002 .23303 Mtetra
.677 .737 .896 r
.54002 .23303 .54098 .23427 .54278 .23355 .54182 .23231 Mtetra
.748 .76 .863 r
.54182 .23231 .54278 .23355 .54457 .23235 .54362 .23118 Mtetra
.734 .771 .882 r
.54362 .23118 .54457 .23235 .54637 .23123 .54541 .23017 Mtetra
.603 .746 .945 r
.54541 .23017 .54637 .23123 .54817 .23073 .54722 .22975 Mtetra
.632 .139 0 r
.54722 .22975 .54817 .23073 .55 .23291 .54904 .23205 Mtetra
.973 .68 .407 r
.54904 .23205 .55 .23291 .5536 .43625 .55259 .43647 Mtetra
.936 .58 .314 r
.55259 .43647 .5536 .43625 .55565 .44832 .55463 .44719 Mtetra
0 .152 .659 r
.55463 .44719 .55565 .44832 .55761 .44985 .55659 .44878 Mtetra
.545 .739 .965 r
.55659 .44878 .55761 .44985 .55955 .44949 .55853 .44851 Mtetra
.778 .829 .892 r
.55853 .44851 .55955 .44949 .56148 .44827 .56046 .4472 Mtetra
.917 .805 .721 r
.56046 .4472 .56148 .44827 .56341 .44614 .56237 .44373 Mtetra
.942 .703 .547 r
.56237 .44373 .56341 .44614 .56531 .44256 .56418 .43189 Mtetra
.966 .676 .432 r
.56418 .43189 .56531 .44256 .56715 .43413 .56354 .2279 Mtetra
.533 .306 .517 r
.56354 .2279 .56715 .43413 .56635 .23177 .56532 .22471 Mtetra
.605 .427 .614 r
.56532 .22471 .56635 .23177 .56811 .22696 .56713 .22341 Mtetra
.62 .506 .701 r
.56713 .22341 .56811 .22696 .5699 .22436 .56894 .22263 Mtetra
.656 .655 .837 r
.56894 .22263 .5699 .22436 .57171 .22302 .57076 .22195 Mtetra
.662 .769 .93 r
.57076 .22195 .57171 .22302 .57353 .22232 .57258 .2213 Mtetra
.645 .775 .942 r
.57258 .2213 .57353 .22232 .57535 .22186 .5744 .22072 Mtetra
.729 .776 .89 r
.5744 .22072 .57535 .22186 .57717 .22095 .57622 .21974 Mtetra
.73 .763 .879 r
.57622 .21974 .57717 .22095 .57898 .21995 .57804 .21873 Mtetra
.61 .719 .922 r
.57804 .21873 .57898 .21995 .58081 .21955 .57986 .2183 Mtetra
0 0 .538 r
.57986 .2183 .58081 .21955 .58269 .2218 .58174 .2204 Mtetra
.974 .679 .392 r
.58174 .2204 .58269 .2218 .58857 .42835 .58753 .4253 Mtetra
.897 .565 .076 r
.58753 .4253 .58857 .42835 .59073 .43756 .58971 .43597 Mtetra
0 .278 .782 r
.58971 .43597 .59073 .43756 .59273 .4389 .59172 .43745 Mtetra
.628 .703 .9 r
.59172 .43745 .59273 .4389 .59469 .43824 .59368 .43692 Mtetra
.729 .761 .878 r
.59368 .43692 .59469 .43824 .59665 .43704 .59564 .43583 Mtetra
.627 .746 .933 r
.59564 .43583 .59665 .43704 .59861 .43649 .59761 .43529 Mtetra
.528 .703 .95 r
.59761 .43529 .59861 .43649 .60059 .4364 .59959 .4351 Mtetra
.677 .747 .904 r
.59959 .4351 .60059 .4364 .60256 .43573 .60155 .43432 Mtetra
.888 .775 .731 r
.60155 .43432 .60256 .43573 .60447 .43268 .60347 .43116 Mtetra
.971 .72 .498 r
.60347 .43116 .60447 .43268 .60611 .4188 .60506 .41525 Mtetra
.974 .683 .405 r
.60506 .41525 .60611 .4188 .60284 .21397 .6019 .21272 Mtetra
.896 .783 .729 r
.6019 .21272 .60284 .21397 .60461 .2109 .60368 .20972 Mtetra
.707 .764 .897 r
.60368 .20972 .60461 .2109 .60645 .21004 .60551 .20885 Mtetra
.582 .714 .933 r
.60551 .20885 .60645 .21004 .6083 .20973 .60737 .20851 Mtetra
.67 .745 .907 r
.60737 .20851 .6083 .20973 .61014 .20905 .60921 .20781 Mtetra
.733 .763 .878 r
.60921 .20781 .61014 .20905 .61197 .20802 .61104 .20678 Mtetra
.624 .723 .918 r
.61104 .20678 .61197 .20802 .61382 .20754 .61289 .20629 Mtetra
0 .171 .697 r
.61289 .20629 .61382 .20754 .61574 .20929 .61481 .20792 Mtetra
.975 .676 .377 r
.61481 .20792 .61574 .20929 .62383 .41276 .6227 .40692 Mtetra
.853 .575 .039 r
.6227 .40692 .62383 .41276 .62623 .42569 .62523 .42407 Mtetra
0 .104 .654 r
.62523 .42407 .62623 .42569 .6283 .4276 .6273 .42621 Mtetra
.547 .679 .925 r
.6273 .42621 .6283 .4276 .63029 .42718 .62931 .426 Mtetra
.759 .797 .884 r
.62931 .426 .63029 .42718 .63226 .42588 .63128 .42475 Mtetra
.905 .814 .746 r
.63128 .42475 .63226 .42588 .6342 .4237 .63319 .42171 Mtetra
.949 .723 .563 r
.63319 .42171 .6342 .4237 .6361 .42019 .63489 .41261 Mtetra
.972 .677 .401 r
.63489 .41261 .6361 .42019 .63783 .41222 .62971 .20477 Mtetra
.534 .307 .517 r
.62971 .20477 .63783 .41222 .63259 .20809 .63145 .20076 Mtetra
.61 .428 .611 r
.63145 .20076 .63259 .20809 .63429 .20303 .63328 .19928 Mtetra
.628 .504 .693 r
.63328 .19928 .63429 .20303 .63608 .20028 .63513 .19835 Mtetra
.69 .651 .806 r
.63513 .19835 .63608 .20028 .63789 .19841 .63698 .19738 Mtetra
.752 .81 .898 r
.63698 .19738 .63789 .19841 .63973 .19715 .63883 .19628 Mtetra
.624 .805 .969 r
.63883 .19628 .63973 .19715 .6416 .19659 .6407 .19572 Mtetra
0 .296 .757 r
.6407 .19572 .6416 .19659 .64353 .19767 .64263 .19685 Mtetra
.928 .548 .17 r
.64263 .19685 .64353 .19767 .64572 .20498 .64486 .20538 Mtetra
.975 .672 .367 r
.64486 .20538 .64572 .20498 .6561 .41419 .65513 .41329 Mtetra
.69 .199 0 r
.65513 .41329 .6561 .41419 .65826 .41738 .65729 .41625 Mtetra
.413 .664 .964 r
.65729 .41625 .65826 .41738 .6603 .41751 .65933 .41635 Mtetra
.724 .794 .908 r
.65933 .41635 .6603 .41751 .6623 .41649 .66133 .41532 Mtetra
.902 .814 .751 r
.66133 .41532 .6623 .41649 .66421 .41352 .66324 .41236 Mtetra
.979 .744 .512 r
.66324 .41236 .66421 .41352 .66575 .40199 .66479 .40087 Mtetra
.977 .681 .375 r
.66479 .40087 .66575 .40199 .65859 .1945 .65768 .19327 Mtetra
.923 .789 .695 r
.65768 .19327 .65859 .1945 .66034 .19088 .65943 .18964 Mtetra
.719 .762 .886 r
.65943 .18964 .66034 .19088 .6622 .18992 .66129 .18867 Mtetra
.594 .712 .926 r
.66129 .18867 .6622 .18992 .66409 .18953 .66318 .18829 Mtetra
.622 .725 .92 r
.66318 .18829 .66409 .18953 .66598 .18904 .66507 .18779 Mtetra
.737 .768 .878 r
.66507 .18779 .66598 .18904 .66784 .18796 .66694 .18672 Mtetra
.646 .736 .915 r
.66694 .18672 .66784 .18796 .66973 .18736 .66882 .18612 Mtetra
.093 .421 .867 r
.66882 .18612 .66973 .18736 .67169 .18831 .67078 .18707 Mtetra
.919 .543 .124 r
.67078 .18707 .67169 .18831 .67405 .19731 .67315 .19609 Mtetra
.975 .67 .349 r
.67315 .19609 .67405 .19731 .68636 .40476 .6854 .40356 Mtetra
.582 .12 0 r
.6854 .40356 .68636 .40476 .68857 .40771 .6876 .40645 Mtetra
.533 .7 .947 r
.6876 .40645 .68857 .40771 .69063 .40763 .68966 .40625 Mtetra
.701 .75 .89 r
.68966 .40625 .69063 .40763 .69265 .40666 .69168 .40531 Mtetra
.733 .766 .879 r
.69168 .40531 .69265 .40666 .69462 .40492 .69369 .40417 Mtetra
.664 .865 .976 r
.69369 .40417 .69462 .40492 .69655 .40224 .69572 .40337 Mtetra
0 0 0 r
.69572 .40337 .69655 .40224 .69837 .39757 .69772 .40204 Mtetra
.167 0 .247 r
.69772 .40204 .69837 .39757 .68948 .19649 .69963 .39904 Mtetra
.492 .27 .506 r
.69963 .39904 .68948 .19649 .69077 .18469 .70072 .38096 Mtetra
0 0 .376 r
.70072 .38096 .69077 .18469 .69251 .18103 .69169 .18123 Mtetra
.961 .941 .644 r
.69169 .18123 .69251 .18103 .69433 .17902 .69343 .17771 Mtetra
.725 .756 .877 r
.69343 .17771 .69433 .17902 .69622 .17814 .69531 .17668 Mtetra
.618 .687 .892 r
.69531 .17668 .69622 .17814 .69813 .1776 .69723 .17621 Mtetra
.617 .698 .902 r
.69723 .17621 .69813 .1776 .70003 .17699 .69914 .17574 Mtetra
.746 .773 .875 r
.69914 .17574 .70003 .17699 .70191 .17583 .70102 .1746 Mtetra
.661 .748 .914 r
.70102 .1746 .70191 .17583 .70381 .17514 .70293 .17393 Mtetra
.22 .512 .911 r
.70293 .17393 .70381 .17514 .7058 .17581 .70491 .17458 Mtetra
.897 .511 .067 r
.70491 .17458 .7058 .17581 .70829 .18465 .70736 .18269 Mtetra
.975 .667 .329 r
.70736 .18269 .70829 .18465 .72311 .39327 .72214 .39165 Mtetra
0 0 .477 r
.72214 .39165 .72311 .39327 .7254 .39643 .72444 .3949 Mtetra
.549 .661 .91 r
.72444 .3949 .7254 .39643 .72749 .39625 .72652 .39469 Mtetra
.699 .725 .87 r
.72652 .39469 .72749 .39625 .72952 .39517 .72857 .39372 Mtetra
.749 .759 .861 r
.72857 .39372 .72952 .39517 .73151 .39333 .73059 .39243 Mtetra
.673 .84 .963 r
.73059 .39243 .73151 .39333 .73344 .3907 .73264 .39162 Mtetra
0 0 0 r
.73264 .39162 .73344 .3907 .73526 .38628 .73467 .39032 Mtetra
.182 0 .236 r
.73467 .39032 .73526 .38628 .72464 .19414 .7366 .38766 Mtetra
.501 .277 .507 r
.7366 .38766 .72464 .19414 .72519 .1727 .73787 .375 Mtetra
0 0 .388 r
.73787 .375 .72519 .1727 .7269 .16881 .72613 .16926 Mtetra
.946 .927 .57 r
.72613 .16926 .7269 .16881 .72872 .16662 .72784 .16531 Mtetra
.737 .764 .874 r
.72784 .16531 .72872 .16662 .73062 .1657 .72973 .16421 Mtetra
.626 .689 .889 r
.72973 .16421 .73062 .1657 .73255 .16513 .73167 .16369 Mtetra
.594 .681 .902 r
.73167 .16369 .73255 .16513 .73449 .16461 .73362 .16331 Mtetra
.747 .771 .872 r
.73362 .16331 .73449 .16461 .73638 .16341 .73551 .16215 Mtetra
.671 .749 .908 r
.73551 .16215 .73638 .16341 .73831 .16266 .73744 .16142 Mtetra
.367 .598 .935 r
.73744 .16142 .73831 .16266 .74031 .16298 .73944 .16174 Mtetra
.84 .436 0 r
.73944 .16174 .74031 .16298 .74278 .16979 .74188 .1681 Mtetra
.973 .661 .311 r
.74188 .1681 .74278 .16979 .76027 .38061 .75931 .37894 Mtetra
0 0 .404 r
.75931 .37894 .76027 .38061 .76268 .38439 .76173 .38285 Mtetra
.524 .648 .913 r
.76173 .38285 .76268 .38439 .76481 .38432 .76386 .38274 Mtetra
.689 .721 .874 r
.76386 .38274 .76481 .38432 .76687 .38331 .76593 .38183 Mtetra
.756 .76 .856 r
.76593 .38183 .76687 .38331 .76887 .38152 .76797 .38048 Mtetra
.67 .811 .95 r
.76797 .38048 .76887 .38152 .77082 .37898 .77005 .37969 Mtetra
0 0 0 r
.77005 .37969 .77082 .37898 .77263 .37478 .77209 .37843 Mtetra
.198 0 .222 r
.77209 .37843 .77263 .37478 .77363 .36013 .77406 .37609 Mtetra
.213 .035 .41 r
.77406 .37609 .77363 .36013 .76003 .16055 .7754 .36581 Mtetra
0 0 .4 r
.7754 .36581 .76003 .16055 .76171 .15641 .76101 .1572 Mtetra
.904 .891 .471 r
.76101 .1572 .76171 .15641 .76352 .15405 .76266 .15278 Mtetra
.764 .784 .869 r
.76266 .15278 .76352 .15405 .76542 .15284 .76456 .15151 Mtetra
.642 .724 .908 r
.76456 .15151 .76542 .15284 .76738 .1522 .76652 .1509 Mtetra
.538 .682 .931 r
.76652 .1509 .76738 .1522 .76938 .15214 .76851 .15072 Mtetra
.635 .706 .898 r
.76851 .15072 .76938 .15214 .77147 .15313 .77047 .15015 Mtetra
.554 .498 .748 r
.77047 .15015 .77147 .15313 .77371 .15588 .77247 .15002 Mtetra
.481 .361 .64 r
.77247 .15002 .77371 .15588 .7925 .35503 .77455 .15085 Mtetra
.013 0 .419 r
.77455 .15085 .7925 .35503 .79583 .36898 .79364 .35256 Mtetra
.03 0 .474 r
.79364 .35256 .79583 .36898 .79822 .37153 .79715 .36837 Mtetra
.191 .272 .718 r
.79715 .36837 .79822 .37153 .80041 .37184 .7995 .37056 Mtetra
.905 .771 .703 r
.12771 .58435 .12894 .58506 .13103 .58073 .12977 .58034 Mtetra
.937 .687 .534 r
.12977 .58034 .13103 .58073 .15589 .37882 .15466 .37882 Mtetra
.945 .75 .608 r
.15466 .37882 .15589 .37882 .15833 .37068 .15721 .36965 Mtetra
.782 .76 .833 r
.15721 .36965 .15833 .37068 .15997 .36941 .15886 .36834 Mtetra
.655 .733 .907 r
.15886 .36834 .15997 .36941 .16152 .3689 .16042 .36781 Mtetra
.547 .694 .936 r
.16042 .36781 .16152 .3689 .16303 .36876 .16193 .36764 Mtetra
.71 .736 .872 r
.16193 .36764 .16303 .36876 .1646 .36814 .16352 .36684 Mtetra
.694 .702 .853 r
.16352 .36684 .1646 .36814 .16617 .36749 .16511 .36608 Mtetra
.665 .677 .852 r
.16511 .36608 .16617 .36749 .16775 .36682 .16667 .36547 Mtetra
.63 .676 .875 r
.16667 .36547 .16775 .36682 .16938 .36565 .16823 .36503 Mtetra
.39 .741 .992 r
.16823 .36503 .16938 .36565 .17097 .36481 .16973 .36498 Mtetra
.536 0 0 r
.16973 .36498 .17097 .36481 .1725 .3646 .17116 .36565 Mtetra
.858 .522 .416 r
.17116 .36565 .1725 .3646 .17365 .36778 .1721 .37078 Mtetra
.934 .677 .524 r
.1721 .37078 .17365 .36778 .15321 .56808 .15167 .57026 Mtetra
.801 .467 .423 r
.15167 .57026 .15321 .56808 .15398 .57569 .15279 .57469 Mtetra
.314 .627 .961 r
.15279 .57469 .15398 .57569 .15554 .57614 .15437 .57492 Mtetra
.676 .725 .887 r
.15437 .57492 .15554 .57614 .15722 .57549 .15606 .57425 Mtetra
.738 .736 .849 r
.15606 .57425 .15722 .57549 .15895 .57436 .15779 .57318 Mtetra
.66 .728 .9 r
.15779 .57318 .15895 .57436 .16061 .57393 .15946 .57259 Mtetra
.635 .694 .887 r
.15946 .57259 .16061 .57393 .16227 .57354 .16113 .5721 Mtetra
.624 .675 .878 r
.16113 .5721 .16227 .57354 .16394 .57301 .16279 .57166 Mtetra
.603 .682 .897 r
.16279 .57166 .16394 .57301 .16569 .57181 .16445 .57131 Mtetra
.512 .828 1 r
.16445 .57131 .16569 .57181 .16745 .57042 .1661 .57098 Mtetra
.025 0 0 r
.1661 .57098 .16745 .57042 .1692 .56919 .16776 .57065 Mtetra
.272 0 0 r
.16776 .57065 .1692 .56919 .1708 .56936 .16942 .57026 Mtetra
.112 0 0 r
.16942 .57026 .1708 .56936 .17237 .56986 .17108 .56984 Mtetra
.397 .848 .911 r
.17108 .56984 .17237 .56986 .17395 .57024 .17275 .5694 Mtetra
.585 .778 .972 r
.17275 .5694 .17395 .57024 .1756 .56999 .17442 .56904 Mtetra
.617 .763 .949 r
.17442 .56904 .1756 .56999 .17728 .56951 .17609 .5686 Mtetra
.662 .782 .938 r
.17609 .5686 .17728 .56951 .17896 .56896 .17778 .56799 Mtetra
.764 .786 .871 r
.17778 .56799 .17896 .56896 .18064 .56851 .17953 .56683 Mtetra
.755 .686 .785 r
.17953 .56683 .18064 .56851 .18231 .56809 .18131 .56536 Mtetra
.713 .595 .722 r
.18131 .56536 .18231 .56809 .18399 .56765 .1831 .5638 Mtetra
.641 .509 .687 r
.1831 .5638 .18399 .56765 .18567 .56718 .18483 .56275 Mtetra
.594 .463 .671 r
.18483 .56275 .18567 .56718 .18736 .56666 .18653 .56216 Mtetra
.557 .436 .67 r
.18653 .56216 .18736 .56666 .18905 .56612 .18818 .56198 Mtetra
.49 .401 .682 r
.18818 .56198 .18905 .56612 .19073 .5656 .18978 .56239 Mtetra
.46 .421 .728 r
.18978 .56239 .19073 .5656 .19243 .56503 .19137 .56286 Mtetra
.455 .501 .817 r
.19137 .56286 .19243 .56503 .19414 .56434 .19298 .56317 Mtetra
.538 .691 .938 r
.19298 .56317 .19414 .56434 .19588 .5633 .19463 .563 Mtetra
.49 .86 .985 r
.19463 .563 .19588 .5633 .19764 .56205 .19632 .56259 Mtetra
0 0 0 r
.19632 .56259 .19764 .56205 .19941 .56076 .19801 .56206 Mtetra
.291 0 0 r
.19801 .56206 .19941 .56076 .20109 .5604 .19969 .56178 Mtetra
.236 0 0 r
.19969 .56178 .20109 .5604 .20276 .56012 .20138 .56134 Mtetra
0 0 0 r
.20138 .56134 .20276 .56012 .2045 .55916 .20312 .56036 Mtetra
.924 .969 .68 r
.20312 .56036 .2045 .55916 .20664 .55391 .20507 .55713 Mtetra
.997 .852 .529 r
.20507 .55713 .20664 .55391 .22729 .35126 .20766 .54716 Mtetra
0 0 .111 r
.20766 .54716 .22729 .35126 .2294 .34528 .22802 .34737 Mtetra
.72 .868 .455 r
.22802 .34737 .2294 .34528 .23111 .34357 .22986 .34422 Mtetra
.669 .963 .759 r
.22986 .34422 .23111 .34357 .23271 .34301 .23154 .34282 Mtetra
.705 .939 .961 r
.23154 .34282 .23271 .34301 .23428 .34282 .23317 .34196 Mtetra
.695 .79 .924 r
.23317 .34196 .23428 .34282 .23588 .34228 .23479 .34125 Mtetra
.669 .75 .912 r
.23479 .34125 .23588 .34228 .2375 .34158 .2364 .34065 Mtetra
.65 .767 .935 r
.2364 .34065 .2375 .34158 .2391 .34098 .238 .34013 Mtetra
.752 .8 .891 r
.238 .34013 .2391 .34098 .24071 .34046 .23965 .33913 Mtetra
.719 .711 .842 r
.23965 .33913 .24071 .34046 .24228 .34024 .24129 .3382 Mtetra
.598 .577 .8 r
.24129 .3382 .24228 .34024 .2438 .34067 .24288 .33786 Mtetra
0 0 .543 r
.24288 .33786 .2438 .34067 .24503 .34446 .24422 .34032 Mtetra
.951 .689 .502 r
.24422 .34032 .24503 .34446 .22887 .54612 .22803 .54154 Mtetra
.924 .642 .159 r
.22803 .54154 .22887 .54612 .23006 .55156 .2289 .55057 Mtetra
.53 .005 0 r
.2289 .55057 .23006 .55156 .23162 .55289 .23044 .55203 Mtetra
.559 .769 .977 r
.23044 .55203 .23162 .55289 .2333 .55277 .23214 .55172 Mtetra
.773 .78 .859 r
.23214 .55172 .2333 .55277 .23507 .55166 .23392 .55046 Mtetra
.87 .751 .73 r
.23392 .55046 .23507 .55166 .23706 .54792 .23586 .54736 Mtetra
.943 .748 .611 r
.23586 .54736 .23706 .54792 .25565 .34864 .23826 .53889 Mtetra
0 0 .108 r
.23826 .53889 .25565 .34864 .25833 .3356 .25698 .33773 Mtetra
.785 .888 .471 r
.25698 .33773 .25833 .3356 .26009 .33329 .25886 .33416 Mtetra
.556 .892 .646 r
.25886 .33416 .26009 .33329 .26171 .33274 .26055 .33274 Mtetra
.638 .953 .94 r
.26055 .33274 .26171 .33274 .26329 .33272 .26219 .33191 Mtetra
.667 .799 .946 r
.26219 .33191 .26329 .33272 .26488 .33255 .26382 .33131 Mtetra
.637 .702 .893 r
.26382 .33131 .26488 .33255 .26649 .33214 .26543 .33083 Mtetra
.616 .683 .891 r
.26543 .33083 .26649 .33214 .2681 .33168 .26704 .33043 Mtetra
.655 .708 .886 r
.26704 .33043 .2681 .33168 .26972 .33115 .26867 .32987 Mtetra
.677 .71 .873 r
.26867 .32987 .26972 .33115 .27135 .33054 .2703 .3292 Mtetra
.658 .694 .873 r
.2703 .3292 .27135 .33054 .27299 .32987 .27193 .32862 Mtetra
.556 .672 .915 r
.27193 .32862 .27299 .32987 .27463 .32915 .27353 .32844 Mtetra
.257 .653 .965 r
.27353 .32844 .27463 .32915 .27627 .32839 .2751 .32861 Mtetra
.322 0 0 r
.2751 .32861 .27627 .32839 .27792 .32762 .27666 .32889 Mtetra
.335 0 0 r
.27666 .32889 .27792 .32762 .27956 .32689 .27827 .32872 Mtetra
.233 0 .03 r
.27827 .32872 .27956 .32689 .2812 .32618 .27991 .32801 Mtetra
.176 0 0 r
.27991 .32801 .2812 .32618 .28285 .3255 .28157 .32716 Mtetra
.173 0 0 r
.28157 .32716 .28285 .3255 .28449 .32484 .28322 .32639 Mtetra
.197 0 0 r
.28322 .32639 .28449 .32484 .28612 .32421 .28486 .32574 Mtetra
.206 0 0 r
.28486 .32574 .28612 .32421 .28776 .32361 .2865 .32512 Mtetra
.219 0 0 r
.2865 .32512 .28776 .32361 .2894 .32302 .28814 .32454 Mtetra
.234 0 0 r
.28814 .32454 .2894 .32302 .29104 .32244 .28978 .32399 Mtetra
.251 0 0 r
.28978 .32399 .29104 .32244 .29268 .32189 .29142 .32347 Mtetra
.301 0 .028 r
.29142 .32347 .29268 .32189 .29431 .32135 .29305 .32307 Mtetra
.339 0 .075 r
.29305 .32307 .29431 .32135 .29595 .32083 .29467 .32273 Mtetra
.31 0 .085 r
.29467 .32273 .29595 .32083 .29759 .32034 .29631 .32222 Mtetra
.11 0 0 r
.29631 .32222 .29759 .32034 .29922 .31988 .29799 .32116 Mtetra
0 0 0 r
.29799 .32116 .29922 .31988 .30086 .31945 .2997 .31971 Mtetra
.751 .993 .866 r
.2997 .31971 .30086 .31945 .30249 .31903 .3014 .31839 Mtetra
.74 .853 .933 r
.3014 .31839 .30249 .31903 .30413 .3186 .30307 .31747 Mtetra
.645 .73 .911 r
.30307 .31747 .30413 .3186 .30576 .31814 .30471 .31696 Mtetra
.614 .708 .912 r
.30471 .31696 .30576 .31814 .30741 .31767 .30635 .31656 Mtetra
.618 .724 .922 r
.30635 .31656 .30741 .31767 .30905 .31718 .30799 .31614 Mtetra
.641 .747 .926 r
.30799 .31614 .30905 .31718 .3107 .31667 .30964 .31564 Mtetra
.647 .751 .925 r
.30964 .31564 .3107 .31667 .31235 .31613 .31129 .31511 Mtetra
.657 .756 .923 r
.31129 .31511 .31235 .31613 .314 .31556 .31294 .31454 Mtetra
.668 .759 .919 r
.31294 .31454 .314 .31556 .31565 .31496 .3146 .31393 Mtetra
.675 .759 .914 r
.3146 .31393 .31565 .31496 .31731 .31433 .31626 .31329 Mtetra
.68 .758 .91 r
.31626 .31329 .31731 .31433 .31897 .31368 .31792 .31262 Mtetra
.684 .755 .905 r
.31792 .31262 .31897 .31368 .32064 .31302 .31958 .31193 Mtetra
.687 .751 .9 r
.31958 .31193 .32064 .31302 .3223 .31234 .32125 .31123 Mtetra
.687 .747 .897 r
.32125 .31123 .3223 .31234 .32397 .31165 .32292 .31052 Mtetra
.687 .743 .894 r
.32292 .31052 .32397 .31165 .32563 .31095 .32459 .30981 Mtetra
.69 .742 .89 r
.32459 .30981 .32563 .31095 .3273 .31025 .32626 .30908 Mtetra
.706 .742 .879 r
.32626 .30908 .3273 .31025 .32897 .30954 .32794 .30826 Mtetra
.714 .726 .859 r
.32794 .30826 .32897 .30954 .33064 .30882 .32962 .30737 Mtetra
.686 .69 .848 r
.32962 .30737 .33064 .30882 .33232 .30809 .33129 .3066 Mtetra
.617 .657 .867 r
.33129 .3066 .33232 .30809 .33399 .30734 .33295 .30619 Mtetra
.435 .64 .943 r
.33295 .30619 .33399 .30734 .33567 .30657 .33457 .30629 Mtetra
0 .516 .768 r
.33457 .30629 .33567 .30657 .33735 .30581 .33619 .30656 Mtetra
.199 0 0 r
.33619 .30656 .33735 .30581 .33903 .30493 .33784 .30634 Mtetra
0 0 0 r
.33784 .30634 .33903 .30493 .34073 .30394 .33954 .30528 Mtetra
.176 0 0 r
.33954 .30528 .34073 .30394 .34239 .30339 .34121 .30467 Mtetra
.683 .258 .232 r
.34121 .30467 .34239 .30339 .34399 .3041 .34276 .30617 Mtetra
.953 .681 .482 r
.34276 .30617 .34399 .3041 .34535 .30895 .33284 .50668 Mtetra
.543 .31 .512 r
.33284 .50668 .34535 .30895 .33543 .51262 .33406 .5158 Mtetra
.663 .31 .364 r
.33406 .5158 .33543 .51262 .33693 .51693 .33571 .5178 Mtetra
.202 0 0 r
.33571 .5178 .33693 .51693 .33866 .51751 .33748 .51753 Mtetra
.557 .929 .919 r
.33748 .51753 .33866 .51751 .34043 .51736 .33928 .51674 Mtetra
.704 .868 .959 r
.33928 .51674 .34043 .51736 .34221 .5169 .34109 .51589 Mtetra
.619 .763 .948 r
.34109 .51589 .34221 .5169 .344 .5164 .34288 .51541 Mtetra
.649 .777 .942 r
.34288 .51541 .344 .5164 .34579 .51578 .34467 .51482 Mtetra
.686 .793 .931 r
.34467 .51482 .34579 .51578 .34759 .51528 .34648 .51407 Mtetra
.724 .755 .878 r
.34648 .51407 .34759 .51528 .34936 .51507 .3483 .51309 Mtetra
.75 .668 .77 r
.3483 .51309 .34936 .51507 .35116 .51443 .35015 .51152 Mtetra
.802 .636 .676 r
.35015 .51152 .35116 .51443 .35303 .51251 .35209 .50804 Mtetra
.955 .686 .487 r
.35209 .50804 .35303 .51251 .35513 .50613 .36423 .3061 Mtetra
.549 .319 .52 r
.36423 .3061 .35513 .50613 .36725 .30094 .36642 .29574 Mtetra
.712 .523 .633 r
.36642 .29574 .36725 .30094 .36917 .29585 .36823 .29272 Mtetra
.644 .533 .713 r
.36823 .29272 .36917 .29585 .37087 .29488 .36994 .29181 Mtetra
.592 .504 .724 r
.36994 .29181 .37087 .29488 .37255 .29456 .37162 .29141 Mtetra
.57 .487 .722 r
.37162 .29141 .37255 .29456 .37423 .29415 .37329 .29117 Mtetra
.602 .515 .729 r
.37329 .29117 .37423 .29415 .37596 .29285 .37498 .2907 Mtetra
.617 .581 .791 r
.37498 .2907 .37596 .29285 .37768 .29161 .37667 .29022 Mtetra
.643 .687 .877 r
.37667 .29022 .37768 .29161 .3794 .29061 .37836 .28969 Mtetra
.675 .788 .934 r
.37836 .28969 .3794 .29061 .38109 .29002 .38006 .28903 Mtetra
.683 .774 .92 r
.38006 .28903 .38109 .29002 .38278 .28955 .38176 .28834 Mtetra
.683 .733 .888 r
.38176 .28834 .38278 .28955 .38447 .28908 .38346 .28763 Mtetra
.678 .692 .856 r
.38346 .28763 .38447 .28908 .38617 .28848 .38516 .2869 Mtetra
.657 .665 .846 r
.38516 .2869 .38617 .28848 .38787 .28785 .38687 .28628 Mtetra
.612 .646 .86 r
.38687 .28628 .38787 .28785 .38958 .28719 .38856 .28588 Mtetra
.454 .62 .922 r
.38856 .28588 .38958 .28719 .39128 .28647 .39023 .28598 Mtetra
.062 .577 .878 r
.39023 .28598 .39128 .28647 .39299 .28575 .3919 .28627 Mtetra
.295 0 0 r
.3919 .28627 .39299 .28575 .3947 .28497 .39357 .28636 Mtetra
.002 0 0 r
.39357 .28636 .3947 .28497 .39642 .28396 .3953 .28532 Mtetra
.157 0 0 r
.3953 .28532 .39642 .28396 .39813 .28334 .39701 .28464 Mtetra
.566 .115 .14 r
.39701 .28464 .39813 .28334 .3998 .28364 .39866 .28535 Mtetra
.959 .681 .465 r
.39866 .28535 .3998 .28364 .40132 .28783 .39251 .48095 Mtetra
.554 .319 .513 r
.39251 .48095 .40132 .28783 .39499 .49235 .39371 .49603 Mtetra
.688 .344 .386 r
.39371 .49603 .39499 .49235 .39659 .49759 .39541 .49874 Mtetra
.352 0 0 r
.39541 .49874 .39659 .49759 .3984 .49755 .39722 .49869 Mtetra
.114 0 0 r
.39722 .49869 .3984 .49755 .40023 .49675 .39905 .49806 Mtetra
.049 0 0 r
.39905 .49806 .40023 .49675 .40208 .49586 .40089 .49717 Mtetra
.184 0 0 r
.40089 .49717 .40208 .49586 .40388 .49602 .40273 .49659 Mtetra
0 0 0 r
.40273 .49659 .40388 .49602 .40569 .49615 .40457 .49588 Mtetra
.675 .937 .966 r
.40457 .49588 .40569 .49615 .40751 .49612 .40642 .49498 Mtetra
.782 .783 .854 r
.40642 .49498 .40751 .49612 .40934 .4957 .40828 .49358 Mtetra
.742 .656 .765 r
.40828 .49358 .40934 .4957 .41117 .49517 .41015 .49201 Mtetra
.695 .571 .712 r
.41015 .49201 .41117 .49517 .41301 .49457 .41203 .49047 Mtetra
.613 .488 .686 r
.41203 .49047 .41301 .49457 .41485 .49401 .41387 .48969 Mtetra
.588 .466 .681 r
.41387 .48969 .41485 .49401 .41669 .49342 .41571 .48916 Mtetra
.58 .462 .683 r
.41571 .48916 .41669 .49342 .41854 .4928 .41755 .48874 Mtetra
.595 .478 .689 r
.41755 .48874 .41854 .4928 .42038 .49215 .41939 .48817 Mtetra
.596 .481 .693 r
.41939 .48817 .42038 .49215 .42223 .49148 .42124 .48759 Mtetra
.595 .483 .697 r
.42124 .48759 .42223 .49148 .42408 .49085 .42308 .48705 Mtetra
.537 .451 .705 r
.42308 .48705 .42408 .49085 .42592 .49064 .42491 .48707 Mtetra
.596 .496 .711 r
.42491 .48707 .42592 .49064 .42777 .4901 .42676 .48655 Mtetra
.689 .553 .695 r
.42676 .48655 .42777 .4901 .42964 .4888 .42864 .48491 Mtetra
.891 .657 .578 r
.42864 .48491 .42964 .4888 .43162 .48372 .43078 .47393 Mtetra
.956 .679 .471 r
.43078 .47393 .43162 .48372 .43913 .2783 .43829 .27123 Mtetra
.712 .503 .605 r
.43829 .27123 .43913 .2783 .44107 .2702 .44012 .26701 Mtetra
.661 .542 .709 r
.44012 .26701 .44107 .2702 .44283 .26884 .44187 .26589 Mtetra
.61 .524 .732 r
.44187 .26589 .44283 .26884 .44456 .26833 .44361 .26535 Mtetra
.572 .5 .735 r
.44361 .26535 .44456 .26833 .44628 .26826 .44533 .2651 Mtetra
.613 .515 .719 r
.44533 .2651 .44628 .26826 .44802 .26779 .44707 .26449 Mtetra
.608 .506 .712 r
.44707 .26449 .44802 .26779 .44976 .26724 .44881 .2639 Mtetra
.606 .502 .71 r
.44881 .2639 .44976 .26724 .4515 .26652 .45055 .26332 Mtetra
.603 .507 .718 r
.45055 .26332 .4515 .26652 .45326 .26518 .45229 .26279 Mtetra
.62 .566 .772 r
.45229 .26279 .45326 .26518 .45502 .26385 .45403 .26226 Mtetra
.644 .662 .853 r
.45403 .26226 .45502 .26385 .45678 .26266 .45578 .26168 Mtetra
.706 .791 .917 r
.45578 .26168 .45678 .26266 .45852 .26196 .45753 .26087 Mtetra
.695 .765 .906 r
.45753 .26087 .45852 .26196 .46027 .26139 .45928 .2601 Mtetra
.661 .717 .89 r
.45928 .2601 .46027 .26139 .46201 .26086 .46102 .25947 Mtetra
.616 .682 .89 r
.46102 .25947 .46201 .26086 .46377 .25978 .46277 .25905 Mtetra
.372 .715 .987 r
.46277 .25905 .46377 .25978 .46552 .25896 .46451 .25906 Mtetra
.526 0 0 r
.46451 .25906 .46552 .25896 .46727 .25873 .46623 .25994 Mtetra
.897 .545 .368 r
.46623 .25994 .46727 .25873 .46896 .26143 .46782 .2678 Mtetra
.959 .673 .449 r
.46782 .2678 .46896 .26143 .46718 .46198 .46593 .47132 Mtetra
.638 .344 .456 r
.46593 .47132 .46718 .46198 .46884 .47354 .46773 .47494 Mtetra
.416 0 .04 r
.46773 .47494 .46884 .47354 .47069 .4748 .4696 .47502 Mtetra
.383 .843 .796 r
.4696 .47502 .47069 .4748 .47256 .47489 .47148 .47428 Mtetra
.752 .891 .942 r
.47148 .47428 .47256 .47489 .47443 .47445 .47337 .47318 Mtetra
.507 .673 .939 r
.47337 .47318 .47443 .47445 .47631 .4743 .47525 .47309 Mtetra
.583 .719 .937 r
.47525 .47309 .47631 .4743 .47819 .47375 .47713 .47274 Mtetra
.75 .81 .901 r
.47713 .47274 .47819 .47375 .48009 .47248 .47903 .47162 Mtetra
.951 .786 .641 r
.47903 .47162 .48009 .47248 .48202 .46807 .48098 .46607 Mtetra
.968 .688 .447 r
.48098 .46607 .48202 .46807 .48644 .26458 .48553 .25693 Mtetra
.757 .531 .59 r
.48553 .25693 .48644 .26458 .48833 .25363 .48737 .25035 Mtetra
.687 .554 .699 r
.48737 .25035 .48833 .25363 .49012 .25132 .48915 .24885 Mtetra
.61 .556 .769 r
.48915 .24885 .49012 .25132 .49189 .25012 .49091 .24838 Mtetra
.53 .589 .858 r
.49091 .24838 .49189 .25012 .49366 .24938 .49267 .24833 Mtetra
.617 .751 .941 r
.49267 .24833 .49366 .24938 .49543 .24876 .49444 .24787 Mtetra
.646 .797 .955 r
.49444 .24787 .49543 .24876 .49719 .24826 .49621 .24729 Mtetra
.661 .783 .939 r
.49621 .24729 .49719 .24826 .49896 .24782 .49798 .24666 Mtetra
.703 .759 .896 r
.49798 .24666 .49896 .24782 .50074 .24721 .49976 .24584 Mtetra
.693 .717 .867 r
.49976 .24584 .50074 .24721 .50251 .24653 .50153 .24502 Mtetra
.664 .684 .859 r
.50153 .24502 .50251 .24653 .50428 .24582 .50331 .24434 Mtetra
.626 .674 .875 r
.50331 .24434 .50428 .24582 .50606 .24465 .50508 .24386 Mtetra
.439 .734 .99 r
.50508 .24386 .50606 .24465 .50784 .24371 .50686 .24378 Mtetra
.436 0 0 r
.50686 .24378 .50784 .24371 .50962 .24342 .50863 .24447 Mtetra
.87 .487 .313 r
.50863 .24447 .50962 .24342 .51138 .24651 .51038 .24987 Mtetra
.966 .676 .429 r
.51038 .24987 .51138 .24651 .51237 .45363 .51131 .45538 Mtetra
.815 .428 .32 r
.51131 .45538 .51237 .45363 .51425 .46095 .5132 .45978 Mtetra
.156 .499 .908 r
.5132 .45978 .51425 .46095 .51615 .46169 .51511 .46045 Mtetra
.604 .724 .93 r
.51511 .46045 .51615 .46169 .51806 .46105 .51702 .46001 Mtetra
.72 .802 .916 r
.51702 .46001 .51806 .46105 .51998 .45994 .51894 .45905 Mtetra
.711 .833 .94 r
.51894 .45905 .51998 .45994 .52189 .45968 .52085 .45815 Mtetra
.74 .726 .839 r
.52085 .45815 .52189 .45968 .52381 .45939 .52277 .45692 Mtetra
.76 .644 .734 r
.52277 .45692 .52381 .45939 .52573 .45842 .52469 .45489 Mtetra
.857 .647 .617 r
.52469 .45489 .52573 .45842 .52764 .45403 .5266 .44854 Mtetra
.968 .683 .436 r
.5266 .44854 .52764 .45403 .52926 .24606 .52829 .24138 Mtetra
.806 .591 .612 r
.52829 .24138 .52926 .24606 .53104 .23693 .53008 .23577 Mtetra
.824 .787 .817 r
.53008 .23577 .53104 .23693 .53283 .23493 .53187 .23402 Mtetra
.667 .803 .948 r
.53187 .23402 .53283 .23493 .53463 .23432 .53366 .23335 Mtetra
.561 .75 .966 r
.53366 .23335 .53463 .23432 .53642 .23418 .53546 .23305 Mtetra
.674 .757 .913 r
.53546 .23305 .53642 .23418 .53822 .23371 .53726 .23235 Mtetra
.696 .724 .871 r
.53726 .23235 .53822 .23371 .54002 .23303 .53905 .23151 Mtetra
.668 .689 .86 r
.53905 .23151 .54002 .23303 .54182 .23231 .54085 .23081 Mtetra
.634 .676 .872 r
.54085 .23081 .54182 .23231 .54362 .23118 .54266 .23028 Mtetra
.497 .737 .98 r
.54266 .23028 .54362 .23118 .54541 .23017 .54446 .23012 Mtetra
.312 0 0 r
.54446 .23012 .54541 .23017 .54722 .22975 .54627 .23066 Mtetra
.845 .434 .259 r
.54627 .23066 .54722 .22975 .54904 .23205 .54811 .2348 Mtetra
.969 .676 .414 r
.54811 .2348 .54904 .23205 .55259 .43647 .55162 .44119 Mtetra
.75 .41 .409 r
.55162 .44119 .55259 .43647 .55463 .44719 .5536 .4464 Mtetra
0 .198 .646 r
.5536 .4464 .55463 .44719 .55659 .44878 .55556 .44768 Mtetra
.51 .715 .964 r
.55556 .44768 .55659 .44878 .55853 .44851 .55751 .44752 Mtetra
.76 .826 .904 r
.55751 .44752 .55853 .44851 .56046 .4472 .55944 .44633 Mtetra
.943 .817 .691 r
.55944 .44633 .56046 .4472 .56237 .44373 .56135 .44225 Mtetra
.974 .687 .418 r
.56135 .44225 .56237 .44373 .56418 .43189 .56086 .23505 Mtetra
.549 .319 .518 r
.56086 .23505 .56418 .43189 .56354 .2279 .56256 .22424 Mtetra
.725 .565 .672 r
.56256 .22424 .56354 .2279 .56532 .22471 .56435 .22193 Mtetra
.621 .543 .745 r
.56435 .22193 .56532 .22471 .56713 .22341 .56617 .2213 Mtetra
.552 .559 .815 r
.56617 .2213 .56713 .22341 .56894 .22263 .56799 .22118 Mtetra
.592 .668 .892 r
.56799 .22118 .56894 .22263 .57076 .22195 .56981 .22084 Mtetra
.657 .758 .925 r
.56981 .22084 .57076 .22195 .57258 .2213 .57163 .22021 Mtetra
.668 .767 .924 r
.57163 .22021 .57258 .2213 .5744 .22072 .57346 .21954 Mtetra
.744 .773 .876 r
.57346 .21954 .5744 .22072 .57622 .21974 .57527 .21845 Mtetra
.74 .753 .863 r
.57527 .21845 .57622 .21974 .57804 .21873 .57709 .21736 Mtetra
.634 .7 .893 r
.57709 .21736 .57804 .21873 .57986 .2183 .57891 .21683 Mtetra
0 .115 .662 r
.57891 .21683 .57986 .2183 .58174 .2204 .58078 .2187 Mtetra
.975 .679 .391 r
.58078 .2187 .58174 .2204 .58753 .4253 .58644 .41985 Mtetra
.842 .564 .022 r
.58644 .41985 .58753 .4253 .58971 .43597 .58869 .43442 Mtetra
0 .196 .724 r
.58869 .43442 .58971 .43597 .59172 .43745 .5907 .43615 Mtetra
.59 .713 .929 r
.5907 .43615 .59172 .43745 .59368 .43692 .59268 .43577 Mtetra
.732 .792 .9 r
.59268 .43577 .59368 .43692 .59564 .43583 .59463 .43471 Mtetra
.729 .796 .905 r
.59463 .43471 .59564 .43583 .59761 .43529 .59659 .43366 Mtetra
.711 .71 .847 r
.59659 .43366 .59761 .43529 .59959 .4351 .59855 .43261 Mtetra
.738 .637 .747 r
.59855 .43261 .59959 .4351 .60155 .43432 .6005 .43089 Mtetra
.828 .636 .643 r
.6005 .43089 .60155 .43432 .60347 .43116 .60237 .42625 Mtetra
.973 .681 .408 r
.60237 .42625 .60347 .43116 .60506 .41525 .59928 .2185 Mtetra
.542 .313 .518 r
.59928 .2185 .60506 .41525 .6019 .21272 .60095 .21099 Mtetra
.831 .722 .744 r
.60095 .21099 .6019 .21272 .60368 .20972 .60275 .20858 Mtetra
.7 .77 .906 r
.60275 .20858 .60368 .20972 .60551 .20885 .60458 .20775 Mtetra
.599 .741 .944 r
.60458 .20775 .60551 .20885 .60737 .20851 .60643 .20733 Mtetra
.694 .762 .904 r
.60643 .20733 .60737 .20851 .60921 .20781 .60827 .20652 Mtetra
.743 .757 .864 r
.60827 .20652 .60921 .20781 .61104 .20678 .6101 .2054 Mtetra
.645 .707 .892 r
.6101 .2054 .61104 .20678 .61289 .20629 .61195 .20482 Mtetra
0 .268 .775 r
.61195 .20482 .61289 .20629 .61481 .20792 .61386 .20625 Mtetra
.954 .612 .23 r
.61386 .20625 .61481 .20792 .6227 .40692 .61615 .2203 Mtetra
0 0 .338 r
.61615 .2203 .6227 .40692 .62523 .42407 .62422 .42246 Mtetra
0 .029 .588 r
.62422 .42246 .62523 .42407 .6273 .42621 .6263 .42487 Mtetra
.501 .666 .936 r
.6263 .42487 .6273 .42621 .62931 .426 .62831 .4248 Mtetra
.752 .793 .887 r
.62831 .4248 .62931 .426 .63128 .42475 .63029 .4236 Mtetra
.921 .807 .717 r
.63029 .4236 .63128 .42475 .63319 .42171 .63219 .42008 Mtetra
.977 .683 .391 r
.63219 .42008 .63319 .42171 .63489 .41261 .62742 .21894 Mtetra
.563 .329 .519 r
.62742 .21894 .63489 .41261 .62971 .20477 .62869 .20092 Mtetra
.753 .576 .656 r
.62869 .20092 .62971 .20477 .63145 .20076 .63047 .19792 Mtetra
.64 .552 .74 r
.63047 .19792 .63145 .20076 .63328 .19928 .63233 .1971 Mtetra
.58 .57 .807 r
.63233 .1971 .63328 .19928 .63513 .19835 .6342 .19682 Mtetra
.629 .675 .875 r
.6342 .19682 .63513 .19835 .63698 .19738 .63607 .19629 Mtetra
.732 .794 .902 r
.63607 .19629 .63698 .19738 .63883 .19628 .63792 .19529 Mtetra
.625 .78 .955 r
.63792 .19529 .63883 .19628 .6407 .19572 .63979 .19476 Mtetra
0 .296 .771 r
.63979 .19476 .6407 .19572 .64263 .19685 .64173 .19594 Mtetra
.937 .567 .192 r
.64173 .19594 .64263 .19685 .64486 .20538 .64401 .20577 Mtetra
.975 .672 .367 r
.64401 .20577 .64486 .20538 .65513 .41329 .65416 .4123 Mtetra
.647 .159 0 r
.65416 .4123 .65513 .41329 .65729 .41625 .65631 .41511 Mtetra
.425 .668 .963 r
.65631 .41511 .65729 .41625 .65933 .41635 .65836 .41519 Mtetra
.725 .794 .907 r
.65836 .41519 .65933 .41635 .66133 .41532 .66035 .41415 Mtetra
.902 .814 .751 r
.66035 .41415 .66133 .41532 .66324 .41236 .66227 .41118 Mtetra
.979 .744 .512 r
.66227 .41118 .66324 .41236 .66479 .40087 .66382 .39968 Mtetra
.977 .681 .376 r
.66382 .39968 .66479 .40087 .65768 .19327 .65677 .19201 Mtetra
.922 .787 .695 r
.65677 .19201 .65768 .19327 .65943 .18964 .65852 .18838 Mtetra
.718 .76 .885 r
.65852 .18838 .65943 .18964 .66129 .18867 .66038 .18742 Mtetra
.592 .71 .926 r
.66038 .18742 .66129 .18867 .66318 .18829 .66228 .18704 Mtetra
.622 .724 .92 r
.66228 .18704 .66318 .18829 .66507 .18779 .66417 .18654 Mtetra
.737 .768 .878 r
.66417 .18654 .66507 .18779 .66694 .18672 .66603 .18547 Mtetra
.644 .734 .914 r
.66603 .18547 .66694 .18672 .66882 .18612 .66792 .18488 Mtetra
.065 .401 .856 r
.66792 .18488 .66882 .18612 .67078 .18707 .66988 .18589 Mtetra
.932 .565 .163 r
.66988 .18589 .67078 .18707 .67315 .19609 .67231 .19631 Mtetra
.975 .669 .353 r
.67231 .19631 .67315 .19609 .6854 .40356 .68446 .40278 Mtetra
.662 .154 0 r
.68446 .40278 .6854 .40356 .6876 .40645 .68665 .40549 Mtetra
.554 .775 .981 r
.68665 .40549 .6876 .40645 .68966 .40625 .6887 .40512 Mtetra
.722 .805 .916 r
.6887 .40512 .68966 .40625 .69168 .40531 .69072 .4041 Mtetra
.7 .781 .914 r
.69072 .4041 .69168 .40531 .69369 .40417 .69274 .40319 Mtetra
.457 .722 .982 r
.69274 .40319 .69369 .40417 .69572 .40337 .69481 .4031 Mtetra
.471 .876 .954 r
.69481 .4031 .69572 .40337 .69772 .40204 .69685 .40252 Mtetra
.71 .954 .675 r
.69685 .40252 .69772 .40204 .69963 .39904 .69882 .40043 Mtetra
.965 .83 .408 r
.69882 .40043 .69963 .39904 .70072 .38096 .70045 .39222 Mtetra
.979 .686 .327 r
.70045 .39222 .70072 .38096 .69169 .18123 .69085 .18088 Mtetra
.986 .865 .632 r
.69085 .18088 .69169 .18123 .69343 .17771 .69254 .17639 Mtetra
.735 .758 .871 r
.69254 .17639 .69343 .17771 .69531 .17668 .69441 .1753 Mtetra
.607 .695 .906 r
.69441 .1753 .69531 .17668 .69723 .17621 .69633 .17487 Mtetra
.591 .696 .915 r
.69633 .17487 .69723 .17621 .69914 .17574 .69825 .1745 Mtetra
.733 .772 .885 r
.69825 .1745 .69914 .17574 .70102 .1746 .70014 .17345 Mtetra
.661 .764 .926 r
.70014 .17345 .70102 .1746 .70293 .17393 .70204 .17278 Mtetra
.331 .595 .942 r
.70204 .17278 .70293 .17393 .70491 .17458 .70401 .17313 Mtetra
.694 .28 0 r
.70401 .17313 .70491 .17458 .70736 .18269 .70622 .1773 Mtetra
.975 .669 .318 r
.70622 .1773 .70736 .18269 .72214 .39165 .7209 .38569 Mtetra
.033 .062 .558 r
.7209 .38569 .72214 .39165 .72444 .3949 .72333 .39109 Mtetra
.459 .409 .715 r
.72333 .39109 .72444 .3949 .72652 .39469 .72548 .3918 Mtetra
.548 .512 .768 r
.72548 .3918 .72652 .39469 .72857 .39372 .72757 .39171 Mtetra
.583 .61 .845 r
.72757 .39171 .72857 .39372 .73059 .39243 .72966 .39138 Mtetra
.429 .692 .974 r
.72966 .39138 .73059 .39243 .73264 .39162 .73177 .3914 Mtetra
.447 .87 .937 r
.73177 .3914 .73264 .39162 .73467 .39032 .73384 .3908 Mtetra
.634 .924 .656 r
.73384 .3908 .73467 .39032 .7366 .38766 .73583 .38891 Mtetra
.958 .832 .404 r
.73583 .38891 .7366 .38766 .73787 .375 .73743 .38117 Mtetra
.977 .678 .322 r
.73743 .38117 .73787 .375 .72613 .16926 .7253 .16865 Mtetra
.985 .838 .616 r
.7253 .16865 .72613 .16926 .72784 .16531 .72694 .16374 Mtetra
.723 .716 .843 r
.72694 .16374 .72784 .16531 .72973 .16421 .72883 .16264 Mtetra
.603 .663 .881 r
.72883 .16264 .72973 .16421 .73167 .16369 .73078 .16223 Mtetra
.553 .656 .904 r
.73078 .16223 .73167 .16369 .73362 .16331 .73274 .16202 Mtetra
.729 .765 .881 r
.73274 .16202 .73362 .16331 .73551 .16215 .73464 .16097 Mtetra
.669 .764 .921 r
.73464 .16097 .73551 .16215 .73744 .16142 .73657 .16025 Mtetra
.433 .652 .951 r
.73657 .16025 .73744 .16142 .73944 .16174 .73856 .16035 Mtetra
.612 .192 0 r
.73856 .16035 .73944 .16174 .74188 .1681 .7408 .16397 Mtetra
.973 .663 .302 r
.7408 .16397 .74188 .1681 .75931 .37894 .75798 .37221 Mtetra
0 .022 .531 r
.75798 .37221 .75931 .37894 .76173 .38285 .76061 .37892 Mtetra
.448 .398 .71 r
.76061 .37892 .76173 .38285 .76386 .38274 .7628 .37976 Mtetra
.541 .503 .763 r
.7628 .37976 .76386 .38274 .76593 .38183 .76494 .37972 Mtetra
.593 .606 .835 r
.76494 .37972 .76593 .38183 .76797 .38048 .76705 .37933 Mtetra
.432 .675 .965 r
.76705 .37933 .76797 .38048 .77005 .37969 .7692 .37939 Mtetra
.443 .861 .952 r
.7692 .37939 .77005 .37969 .77209 .37843 .7713 .37885 Mtetra
.54 .891 .662 r
.7713 .37885 .77209 .37843 .77406 .37609 .77333 .37726 Mtetra
.937 .838 .395 r
.77333 .37726 .77406 .37609 .7754 .36581 .77494 .37036 Mtetra
.975 .672 .306 r
.77494 .37036 .7754 .36581 .76101 .1572 .76022 .15687 Mtetra
.997 .843 .562 r
.76022 .15687 .76101 .1572 .76266 .15278 .76178 .15121 Mtetra
.74 .727 .84 r
.76178 .15121 .76266 .15278 .76456 .15151 .76368 .14999 Mtetra
.62 .683 .888 r
.76368 .14999 .76456 .15151 .76652 .1509 .76565 .1495 Mtetra
.538 .661 .915 r
.76565 .1495 .76652 .1509 .76851 .15072 .76764 .14933 Mtetra
.749 .759 .861 r
.76764 .14933 .76851 .15072 .77047 .15015 .76955 .14812 Mtetra
.663 .636 .812 r
.76955 .14812 .77047 .15015 .77247 .15002 .77149 .1473 Mtetra
.538 .506 .768 r
.77149 .1473 .77247 .15002 .77455 .15085 .77351 .14729 Mtetra
0 0 .359 r
.77351 .14729 .77455 .15085 .79364 .35256 .77612 .15438 Mtetra
0 0 .404 r
.77612 .15438 .79364 .35256 .79715 .36837 .79617 .36625 Mtetra
0 .014 .588 r
.79617 .36625 .79715 .36837 .7995 .37056 .79862 .36959 Mtetra
.905 .775 .707 r
.12647 .58367 .12771 .58435 .12977 .58034 .12852 .57977 Mtetra
.937 .687 .534 r
.12852 .57977 .12977 .58034 .15466 .37882 .15346 .37855 Mtetra
.939 .737 .604 r
.15346 .37855 .15466 .37882 .15721 .36965 .1561 .36859 Mtetra
.785 .757 .828 r
.1561 .36859 .15721 .36965 .15886 .36834 .15775 .36725 Mtetra
.66 .731 .902 r
.15775 .36725 .15886 .36834 .16042 .36781 .15931 .3667 Mtetra
.559 .694 .931 r
.15931 .3667 .16042 .36781 .16193 .36764 .16083 .3665 Mtetra
.743 .739 .848 r
.16083 .3665 .16193 .36764 .16352 .36684 .16245 .36547 Mtetra
.707 .697 .838 r
.16245 .36547 .16352 .36684 .16511 .36608 .16404 .36462 Mtetra
.638 .661 .855 r
.16404 .36462 .16511 .36608 .16667 .36547 .1656 .36413 Mtetra
.02 .356 .83 r
.1656 .36413 .16667 .36547 .16823 .36503 .16701 .36496 Mtetra
.822 .378 .18 r
.16701 .36496 .16823 .36503 .16973 .36498 .16827 .36716 Mtetra
.854 .546 .466 r
.16827 .36716 .16973 .36498 .17116 .36565 .16892 .37482 Mtetra
.926 .668 .528 r
.16892 .37482 .17116 .36565 .1721 .37078 .14892 .56887 Mtetra
.532 .301 .51 r
.14892 .56887 .1721 .37078 .15167 .57026 .15013 .57243 Mtetra
.648 .272 .319 r
.15013 .57243 .15167 .57026 .15279 .57469 .15159 .5738 Mtetra
.515 .741 .977 r
.15159 .5738 .15279 .57469 .15437 .57492 .15322 .57362 Mtetra
.678 .713 .875 r
.15322 .57362 .15437 .57492 .15606 .57425 .1549 .57292 Mtetra
.714 .719 .853 r
.1549 .57292 .15606 .57425 .15779 .57318 .15662 .572 Mtetra
.657 .728 .901 r
.15662 .572 .15779 .57318 .15946 .57259 .15829 .57142 Mtetra
.63 .723 .914 r
.15829 .57142 .15946 .57259 .16113 .5721 .15996 .57095 Mtetra
.608 .719 .924 r
.15996 .57095 .16113 .5721 .16279 .57166 .16161 .57057 Mtetra
.554 .711 .945 r
.16161 .57057 .16279 .57166 .16445 .57131 .16326 .57034 Mtetra
.528 .73 .967 r
.16326 .57034 .16445 .57131 .1661 .57098 .16489 .57015 Mtetra
.52 .758 .983 r
.16489 .57015 .1661 .57098 .16776 .57065 .16654 .56994 Mtetra
.562 .799 .988 r
.16654 .56994 .16776 .57065 .16942 .57026 .1682 .56959 Mtetra
.584 .815 .987 r
.1682 .56959 .16942 .57026 .17108 .56984 .16986 .56918 Mtetra
.599 .821 .984 r
.16986 .56918 .17108 .56984 .17275 .5694 .17154 .56872 Mtetra
.496 .784 .996 r
.17154 .56872 .17275 .5694 .17442 .56904 .17318 .5685 Mtetra
.547 .834 .998 r
.17318 .5685 .17442 .56904 .17609 .5686 .17485 .56811 Mtetra
.697 .881 .966 r
.17485 .56811 .17609 .5686 .17778 .56799 .17656 .56733 Mtetra
.878 .815 .783 r
.17656 .56733 .17778 .56799 .17953 .56683 .17844 .5649 Mtetra
.859 .691 .673 r
.17844 .5649 .17953 .56683 .18131 .56536 .18052 .56046 Mtetra
.878 .644 .582 r
.18052 .56046 .18131 .56536 .1831 .5638 .18377 .54445 Mtetra
.919 .663 .534 r
.18377 .54445 .1831 .5638 .18483 .56275 .20404 .35954 Mtetra
.528 .303 .516 r
.20404 .35954 .18483 .56275 .18653 .56216 .2057 .35838 Mtetra
.517 .293 .513 r
.2057 .35838 .18653 .56216 .18818 .56198 .20687 .36202 Mtetra
0 0 .142 r
.20687 .36202 .18818 .56198 .18978 .56239 .18919 .55538 Mtetra
0 0 .475 r
.18919 .55538 .18978 .56239 .19137 .56286 .19037 .56007 Mtetra
0 .076 .623 r
.19037 .56007 .19137 .56286 .19298 .56317 .1918 .56216 Mtetra
.248 .59 .948 r
.1918 .56216 .19298 .56317 .19463 .563 .19341 .56249 Mtetra
.509 .828 1 r
.19341 .56249 .19463 .563 .19632 .56259 .19508 .56216 Mtetra
.628 .881 .988 r
.19508 .56216 .19632 .56259 .19801 .56206 .19679 .56155 Mtetra
.584 .853 .995 r
.19679 .56155 .19801 .56206 .19969 .56178 .19848 .56107 Mtetra
.651 .825 .967 r
.19848 .56107 .19969 .56178 .20138 .56134 .20019 .56047 Mtetra
.734 .806 .909 r
.20019 .56047 .20138 .56134 .20312 .56036 .20193 .55953 Mtetra
.843 .807 .816 r
.20193 .55953 .20312 .56036 .20507 .55713 .20376 .55762 Mtetra
.953 .925 .738 r
.20376 .55762 .20507 .55713 .20766 .54716 .20572 .55438 Mtetra
0 0 .03 r
.20572 .55438 .20766 .54716 .22802 .34737 .20801 .54759 Mtetra
0 0 .132 r
.20801 .54759 .22802 .34737 .22986 .34422 .22821 .34922 Mtetra
0 0 0 r
.22821 .34922 .22986 .34422 .23154 .34282 .23026 .34391 Mtetra
.88 .979 .683 r
.23026 .34391 .23154 .34282 .23317 .34196 .23205 .34128 Mtetra
.795 .836 .883 r
.23205 .34128 .23317 .34196 .23479 .34125 .23372 .34005 Mtetra
.669 .718 .885 r
.23372 .34005 .23479 .34125 .2364 .34065 .23533 .33943 Mtetra
.618 .699 .902 r
.23533 .33943 .2364 .34065 .238 .34013 .23692 .33904 Mtetra
.742 .755 .863 r
.23692 .33904 .238 .34013 .23965 .33913 .23857 .33803 Mtetra
.741 .753 .862 r
.23857 .33803 .23965 .33913 .24129 .3382 .24022 .33703 Mtetra
.614 .707 .911 r
.24022 .33703 .24129 .3382 .24288 .33786 .24181 .33664 Mtetra
.8 .341 0 r
.24181 .33664 .24288 .33786 .24422 .34032 .24315 .33912 Mtetra
.947 .685 .505 r
.24315 .33912 .24422 .34032 .22803 .54154 .22681 .54113 Mtetra
.933 .607 .398 r
.22681 .54113 .22803 .54154 .2289 .55057 .22771 .54987 Mtetra
.555 0 0 r
.22771 .54987 .2289 .55057 .23044 .55203 .22926 .55115 Mtetra
.619 .783 .96 r
.22926 .55115 .23044 .55203 .23214 .55172 .23098 .55068 Mtetra
.773 .78 .859 r
.23098 .55068 .23214 .55172 .23392 .55046 .23276 .54941 Mtetra
.831 .779 .803 r
.23276 .54941 .23392 .55046 .23586 .54736 .2346 .54748 Mtetra
.939 .906 .763 r
.2346 .54748 .23586 .54736 .23826 .53889 .23653 .54454 Mtetra
0 0 0 r
.23653 .54454 .23826 .53889 .25698 .33773 .23868 .53895 Mtetra
0 0 .158 r
.23868 .53895 .25698 .33773 .25886 .33416 .25713 .34079 Mtetra
0 0 .024 r
.25713 .34079 .25886 .33416 .26055 .33274 .25925 .33427 Mtetra
.809 .937 .572 r
.25925 .33427 .26055 .33274 .26219 .33191 .26107 .33138 Mtetra
.817 .869 .885 r
.26107 .33138 .26219 .33191 .26382 .33131 .26276 .33003 Mtetra
.658 .704 .881 r
.26276 .33003 .26382 .33131 .26543 .33083 .26438 .32946 Mtetra
.591 .664 .889 r
.26438 .32946 .26543 .33083 .26704 .33043 .26599 .32916 Mtetra
.663 .707 .88 r
.26599 .32916 .26704 .33043 .26867 .32987 .26762 .32856 Mtetra
.691 .709 .862 r
.26762 .32856 .26867 .32987 .2703 .3292 .26926 .32781 Mtetra
.627 .674 .875 r
.26926 .32781 .2703 .3292 .27193 .32862 .27087 .32737 Mtetra
.061 .401 .856 r
.27087 .32737 .27193 .32862 .27353 .32844 .2724 .32815 Mtetra
.864 .432 .181 r
.2724 .32815 .27353 .32844 .2751 .32861 .27375 .33109 Mtetra
.946 .679 .5 r
.27375 .33109 .2751 .32861 .27666 .32889 .2605 .51862 Mtetra
.549 .315 .513 r
.2605 .51862 .27666 .32889 .27827 .32872 .26125 .53045 Mtetra
.524 .294 .508 r
.26125 .53045 .27827 .32872 .27991 .32801 .26298 .53001 Mtetra
.52 .291 .507 r
.26298 .53001 .27991 .32801 .28157 .32716 .26484 .52785 Mtetra
.26484 .52785 .28157 .32716 .28322 .32639 .26669 .52582 Mtetra
.523 .293 .508 r
.26669 .52582 .28322 .32639 .28486 .32574 .26845 .52494 Mtetra
.26845 .52494 .28486 .32574 .2865 .32512 .2702 .52421 Mtetra
.524 .294 .508 r
.2702 .52421 .2865 .32512 .28814 .32454 .27194 .52374 Mtetra
.27194 .52374 .28814 .32454 .28978 .32399 .27365 .52352 Mtetra
.27365 .52352 .28978 .32399 .29142 .32347 .27536 .5234 Mtetra
.527 .296 .509 r
.27536 .5234 .29142 .32347 .29305 .32307 .27699 .52437 Mtetra
.526 .296 .509 r
.27699 .52437 .29305 .32307 .29467 .32273 .27863 .52523 Mtetra
.523 .293 .508 r
.27863 .52523 .29467 .32273 .29631 .32222 .2804 .52444 Mtetra
.487 .263 .5 r
.2804 .52444 .29631 .32222 .29799 .32116 .28336 .50713 Mtetra
0 0 .181 r
.28336 .50713 .29799 .32116 .2997 .31971 .29839 .32212 Mtetra
.766 .856 .413 r
.29839 .32212 .2997 .31971 .3014 .31839 .30028 .3181 Mtetra
.877 .906 .847 r
.30028 .3181 .3014 .31839 .30307 .31747 .30202 .31628 Mtetra
.672 .727 .891 r
.30202 .31628 .30307 .31747 .30471 .31696 .30367 .31565 Mtetra
.591 .676 .9 r
.30367 .31565 .30471 .31696 .30635 .31656 .3053 .31534 Mtetra
.593 .695 .913 r
.3053 .31534 .30635 .31656 .30799 .31614 .30693 .31502 Mtetra
.641 .73 .913 r
.30693 .31502 .30799 .31614 .30964 .31564 .30858 .31452 Mtetra
.647 .732 .911 r
.30858 .31452 .30964 .31564 .31129 .31511 .31023 .31399 Mtetra
.657 .736 .908 r
.31023 .31399 .31129 .31511 .31294 .31454 .31188 .31342 Mtetra
.669 .739 .903 r
.31188 .31342 .31294 .31454 .3146 .31393 .31354 .3128 Mtetra
.676 .739 .898 r
.31354 .3128 .3146 .31393 .31626 .31329 .3152 .31214 Mtetra
.682 .738 .893 r
.3152 .31214 .31626 .31329 .31792 .31262 .31687 .31145 Mtetra
.686 .735 .889 r
.31687 .31145 .31792 .31262 .31958 .31193 .31854 .31074 Mtetra
.688 .733 .885 r
.31854 .31074 .31958 .31193 .32125 .31123 .3202 .31002 Mtetra
.687 .729 .882 r
.3202 .31002 .32125 .31123 .32292 .31052 .32187 .3093 Mtetra
.686 .727 .881 r
.32187 .3093 .32292 .31052 .32459 .30981 .32354 .30858 Mtetra
.69 .727 .878 r
.32354 .30858 .32459 .30981 .32626 .30908 .32522 .30784 Mtetra
.722 .733 .86 r
.32522 .30784 .32626 .30908 .32794 .30826 .3269 .3069 Mtetra
.736 .719 .835 r
.3269 .3069 .32794 .30826 .32962 .30737 .3286 .30582 Mtetra
.683 .675 .837 r
.3286 .30582 .32962 .30737 .33129 .3066 .33027 .30505 Mtetra
.462 .577 .884 r
.33027 .30505 .33129 .3066 .33295 .30619 .33189 .3052 Mtetra
.689 .188 0 r
.33189 .3052 .33295 .30619 .33457 .30629 .3334 .30719 Mtetra
.873 .515 .368 r
.3334 .30719 .33457 .30629 .33619 .30656 .33471 .31258 Mtetra
.947 .674 .488 r
.33471 .31258 .33619 .30656 .33784 .30634 .32474 .50569 Mtetra
.522 .292 .508 r
.32474 .50569 .33784 .30634 .33954 .30528 .32656 .50428 Mtetra
.519 .29 .507 r
.32656 .50428 .33954 .30528 .34121 .30467 .32848 .50131 Mtetra
.538 .305 .511 r
.32848 .50131 .34121 .30467 .34276 .30617 .32985 .50776 Mtetra
.536 .304 .51 r
.32985 .50776 .34276 .30617 .33284 .50668 .33126 .51354 Mtetra
.629 .327 .439 r
.33126 .51354 .33284 .50668 .33406 .5158 .33287 .51604 Mtetra
.555 0 0 r
.33287 .51604 .33406 .5158 .33571 .5178 .33457 .51692 Mtetra
.577 .776 .974 r
.33457 .51692 .33571 .5178 .33748 .51753 .33635 .51654 Mtetra
.675 .784 .931 r
.33635 .51654 .33748 .51753 .33928 .51674 .33815 .51584 Mtetra
.664 .802 .949 r
.33815 .51584 .33928 .51674 .34109 .51589 .33995 .51519 Mtetra
.538 .804 .995 r
.33995 .51519 .34109 .51589 .34288 .51541 .34173 .51485 Mtetra
.627 .864 .987 r
.34173 .51485 .34288 .51541 .34467 .51482 .34353 .51423 Mtetra
.798 .881 .907 r
.34353 .51423 .34467 .51482 .34648 .51407 .34537 .51291 Mtetra
.873 .772 .747 r
.34537 .51291 .34648 .51407 .3483 .51309 .34728 .51008 Mtetra
.846 .653 .641 r
.34728 .51008 .3483 .51309 .35015 .51152 .34933 .5047 Mtetra
.952 .683 .49 r
.34933 .5047 .35015 .51152 .35209 .50804 .3616 .30367 Mtetra
.542 .313 .518 r
.3616 .30367 .35209 .50804 .36423 .3061 .36364 .29636 Mtetra
.645 .439 .589 r
.36364 .29636 .36423 .3061 .36642 .29574 .36546 .29325 Mtetra
.739 .617 .723 r
.36546 .29325 .36642 .29574 .36823 .29272 .36721 .29148 Mtetra
.697 .73 .876 r
.36721 .29148 .36823 .29272 .36994 .29181 .3689 .29069 Mtetra
.626 .73 .922 r
.3689 .29069 .36994 .29181 .37162 .29141 .37059 .29023 Mtetra
.59 .705 .923 r
.37059 .29023 .37162 .29141 .37329 .29117 .37227 .2899 Mtetra
.616 .698 .903 r
.37227 .2899 .37329 .29117 .37498 .2907 .37395 .28949 Mtetra
.618 .71 .911 r
.37395 .28949 .37498 .2907 .37667 .29022 .37564 .28906 Mtetra
.645 .73 .91 r
.37564 .28906 .37667 .29022 .37836 .28969 .37733 .28853 Mtetra
.694 .744 .89 r
.37733 .28853 .37836 .28969 .38006 .28903 .37903 .28777 Mtetra
.698 .727 .873 r
.37903 .28777 .38006 .28903 .38176 .28834 .38074 .28696 Mtetra
.698 .709 .857 r
.38074 .28696 .38176 .28834 .38346 .28763 .38245 .28613 Mtetra
.7 .692 .839 r
.38245 .28613 .38346 .28763 .38516 .2869 .38416 .28526 Mtetra
.652 .654 .839 r
.38416 .28526 .38516 .2869 .38687 .28628 .38586 .28465 Mtetra
.515 .593 .871 r
.38586 .28465 .38687 .28628 .38856 .28588 .38754 .28464 Mtetra
0 .005 .536 r
.38754 .28464 .38856 .28588 .39023 .28598 .38914 .28636 Mtetra
.873 .478 .284 r
.38914 .28636 .39023 .28598 .3919 .28627 .39063 .2906 Mtetra
.955 .677 .47 r
.39063 .2906 .3919 .28627 .39357 .28636 .384 .48599 Mtetra
.525 .295 .508 r
.384 .48599 .39357 .28636 .3953 .28532 .38579 .486 Mtetra
.52 .291 .507 r
.38579 .486 .3953 .28532 .39701 .28464 .38767 .48385 Mtetra
.531 .3 .509 r
.38767 .48385 .39701 .28464 .39866 .28535 .38933 .48716 Mtetra
.538 .305 .51 r
.38933 .48716 .39866 .28535 .39251 .48095 .39085 .49385 Mtetra
.594 .319 .47 r
.39085 .49385 .39251 .48095 .39371 .49603 .39255 .49662 Mtetra
.646 .142 .035 r
.39255 .49662 .39371 .49603 .39541 .49874 .3943 .49787 Mtetra
.47 .74 .987 r
.3943 .49787 .39541 .49874 .39722 .49869 .39612 .49774 Mtetra
.616 .78 .96 r
.39612 .49774 .39722 .49869 .39905 .49806 .39794 .49725 Mtetra
.66 .824 .962 r
.39794 .49725 .39905 .49806 .40089 .49717 .39978 .49658 Mtetra
.575 .845 .996 r
.39978 .49658 .40089 .49717 .40273 .49659 .40161 .49609 Mtetra
.66 .891 .98 r
.40161 .49609 .40273 .49659 .40457 .49588 .40346 .49533 Mtetra
.792 .897 .917 r
.40346 .49533 .40457 .49588 .40642 .49498 .40532 .49403 Mtetra
.898 .803 .746 r
.40532 .49403 .40642 .49498 .40828 .49358 .40724 .491 Mtetra
.863 .675 .647 r
.40724 .491 .40828 .49358 .41015 .49201 .40924 .48582 Mtetra
.958 .684 .474 r
.40924 .48582 .41015 .49201 .41203 .49047 .41769 .29299 Mtetra
.543 .315 .518 r
.41769 .29299 .41203 .49047 .41387 .48969 .41967 .28509 Mtetra
.525 .3 .515 r
.41967 .28509 .41387 .48969 .41571 .48916 .42137 .28544 Mtetra
.512 .29 .513 r
.42137 .28544 .41571 .48916 .41755 .48874 .42289 .29151 Mtetra
.525 .3 .516 r
.42289 .29151 .41755 .48874 .41939 .48817 .4246 .29171 Mtetra
.524 .299 .515 r
.4246 .29171 .41939 .48817 .42124 .48759 .42629 .29261 Mtetra
.508 .287 .513 r
.42629 .29261 .42124 .48759 .42308 .48705 .42778 .30001 Mtetra
0 0 .307 r
.42778 .30001 .42308 .48705 .42491 .48707 .42427 .47144 Mtetra
.523 .33 .56 r
.42427 .47144 .42491 .48707 .42676 .48655 .42608 .47174 Mtetra
.948 .671 .479 r
.42608 .47174 .42676 .48655 .42864 .48491 .43335 .28682 Mtetra
.557 .325 .52 r
.43335 .28682 .42864 .48491 .43078 .47393 .4355 .27241 Mtetra
.535 .308 .517 r
.4355 .27241 .43078 .47393 .43829 .27123 .43733 .26822 Mtetra
.761 .606 .686 r
.43733 .26822 .43829 .27123 .44012 .26701 .43912 .26571 Mtetra
.715 .731 .863 r
.43912 .26571 .44012 .26701 .44187 .26589 .44087 .26479 Mtetra
.649 .746 .921 r
.44087 .26479 .44187 .26589 .44361 .26535 .4426 .26423 Mtetra
.6 .725 .932 r
.4426 .26423 .44361 .26535 .44533 .2651 .44433 .26385 Mtetra
.662 .722 .893 r
.44433 .26385 .44533 .2651 .44707 .26449 .44607 .26322 Mtetra
.659 .718 .892 r
.44607 .26322 .44707 .26449 .44881 .2639 .44781 .2626 Mtetra
.653 .712 .891 r
.44781 .2626 .44881 .2639 .45055 .26332 .44955 .26202 Mtetra
.629 .701 .898 r
.44955 .26202 .45055 .26332 .45229 .26279 .45129 .26154 Mtetra
.63 .711 .905 r
.45129 .26154 .45229 .26279 .45403 .26226 .45303 .26105 Mtetra
.642 .726 .909 r
.45303 .26105 .45403 .26226 .45578 .26168 .45478 .26051 Mtetra
.74 .762 .871 r
.45478 .26051 .45578 .26168 .45753 .26087 .45653 .25947 Mtetra
.705 .714 .856 r
.45653 .25947 .45753 .26087 .45928 .2601 .45829 .25858 Mtetra
.634 .669 .866 r
.45829 .25858 .45928 .2601 .46102 .25947 .46003 .25807 Mtetra
.103 .397 .852 r
.46003 .25807 .46102 .25947 .46277 .25905 .46175 .25898 Mtetra
.81 .331 .063 r
.46175 .25898 .46277 .25905 .46451 .25906 .46344 .26154 Mtetra
.936 .629 .434 r
.46344 .26154 .46451 .25906 .46623 .25994 .46468 .28731 Mtetra
.928 .64 .476 r
.46468 .28731 .46623 .25994 .46782 .2678 .46301 .46994 Mtetra
.53 .299 .509 r
.46301 .46994 .46782 .2678 .46593 .47132 .46482 .47297 Mtetra
.624 .193 .204 r
.46482 .47297 .46593 .47132 .46773 .47494 .46666 .47419 Mtetra
.525 .795 .995 r
.46666 .47419 .46773 .47494 .4696 .47502 .46854 .47387 Mtetra
.691 .77 .912 r
.46854 .47387 .4696 .47502 .47148 .47428 .47042 .47306 Mtetra
.725 .767 .886 r
.47042 .47306 .47148 .47428 .47337 .47318 .47231 .47205 Mtetra
.447 .676 .962 r
.47231 .47205 .47337 .47318 .47525 .47309 .47419 .47208 Mtetra
.532 .74 .971 r
.47419 .47208 .47525 .47309 .47713 .47274 .47607 .47184 Mtetra
.734 .829 .923 r
.47607 .47184 .47713 .47274 .47903 .47162 .47796 .47083 Mtetra
.953 .791 .644 r
.47796 .47083 .47903 .47162 .48098 .46607 .47991 .46539 Mtetra
.97 .69 .445 r
.47991 .46539 .48098 .46607 .48553 .25693 .48454 .2558 Mtetra
.948 .751 .605 r
.48454 .2558 .48553 .25693 .48737 .25035 .48639 .24902 Mtetra
.783 .75 .823 r
.48639 .24902 .48737 .25035 .48915 .24885 .48816 .24756 Mtetra
.612 .7 .907 r
.48816 .24756 .48915 .24885 .49091 .24838 .48993 .24715 Mtetra
.471 .648 .936 r
.48993 .24715 .49091 .24838 .49267 .24833 .49169 .24717 Mtetra
.617 .729 .926 r
.49169 .24717 .49267 .24833 .49444 .24787 .49346 .24672 Mtetra
.657 .745 .915 r
.49346 .24672 .49444 .24787 .49621 .24729 .49523 .24612 Mtetra
.672 .745 .905 r
.49523 .24612 .49621 .24729 .49798 .24666 .497 .24544 Mtetra
.738 .756 .867 r
.497 .24544 .49798 .24666 .49976 .24584 .49878 .24439 Mtetra
.711 .712 .849 r
.49878 .24439 .49976 .24584 .50153 .24502 .50056 .24344 Mtetra
.645 .667 .857 r
.50056 .24344 .50153 .24502 .50331 .24434 .50233 .24285 Mtetra
.237 .467 .877 r
.50233 .24285 .50331 .24434 .50508 .24386 .5041 .24357 Mtetra
.772 .264 0 r
.5041 .24357 .50508 .24386 .50686 .24378 .50586 .24589 Mtetra
.897 .556 .393 r
.50586 .24589 .50686 .24378 .50863 .24447 .50758 .25621 Mtetra
.956 .664 .443 r
.50758 .25621 .50863 .24447 .51038 .24987 .50837 .45432 Mtetra
.531 .3 .509 r
.50837 .45432 .51038 .24987 .51131 .45538 .51026 .45765 Mtetra
.627 .227 .266 r
.51026 .45765 .51131 .45538 .5132 .45978 .51216 .45903 Mtetra
.156 .596 .933 r
.51216 .45903 .5132 .45978 .51511 .46045 .51407 .45939 Mtetra
.552 .742 .965 r
.51407 .45939 .51511 .46045 .51702 .46001 .51598 .4591 Mtetra
.708 .825 .938 r
.51598 .4591 .51702 .46001 .51894 .45905 .51789 .45821 Mtetra
.867 .849 .824 r
.51789 .45821 .51894 .45905 .52085 .45815 .51981 .45611 Mtetra
.863 .709 .69 r
.51981 .45611 .52085 .45815 .52277 .45692 .52173 .4524 Mtetra
.869 .636 .583 r
.52173 .4524 .52277 .45692 .52469 .45489 .52365 .44312 Mtetra
.962 .676 .446 r
.52365 .44312 .52469 .45489 .5266 .44854 .52552 .24125 Mtetra
.535 .308 .517 r
.52552 .24125 .5266 .44854 .52829 .24138 .52732 .23669 Mtetra
.702 .525 .646 r
.52732 .23669 .52829 .24138 .53008 .23577 .52911 .2342 Mtetra
.739 .707 .821 r
.52911 .2342 .53008 .23577 .53187 .23402 .5309 .23299 Mtetra
.664 .776 .932 r
.5309 .23299 .53187 .23402 .53366 .23335 .5327 .23234 Mtetra
.612 .761 .95 r
.5327 .23234 .53366 .23335 .53546 .23305 .53449 .23188 Mtetra
.722 .767 .888 r
.53449 .23188 .53546 .23305 .53726 .23235 .53629 .23094 Mtetra
.72 .724 .853 r
.53629 .23094 .53726 .23235 .53905 .23151 .53809 .22994 Mtetra
.657 .676 .857 r
.53809 .22994 .53905 .23151 .54085 .23081 .53989 .22929 Mtetra
.338 .522 .89 r
.53989 .22929 .54085 .23081 .54266 .23028 .5417 .22979 Mtetra
.695 .163 0 r
.5417 .22979 .54266 .23028 .54446 .23012 .54352 .23183 Mtetra
.877 .513 .352 r
.54352 .23183 .54446 .23012 .54627 .23066 .54537 .23902 Mtetra
.963 .668 .425 r
.54537 .23902 .54627 .23066 .54811 .2348 .54866 .44047 Mtetra
.532 .3 .509 r
.54866 .44047 .54811 .2348 .55162 .44119 .55063 .44429 Mtetra
.624 .252 .317 r
.55063 .44429 .55162 .44119 .5536 .4464 .55258 .44583 Mtetra
0 .429 .787 r
.55258 .44583 .5536 .4464 .55556 .44768 .55453 .4465 Mtetra
.496 .691 .955 r
.55453 .4465 .55556 .44768 .55751 .44752 .55648 .44641 Mtetra
.721 .792 .908 r
.55648 .44641 .55751 .44752 .55944 .44633 .55842 .44542 Mtetra
.938 .815 .698 r
.55842 .44542 .55944 .44633 .56135 .44225 .56033 .44148 Mtetra
.974 .687 .417 r
.56033 .44148 .56135 .44225 .56086 .23505 .55991 .23433 Mtetra
.978 .747 .521 r
.55991 .23433 .56086 .23505 .56256 .22424 .5616 .22289 Mtetra
.852 .766 .767 r
.5616 .22289 .56256 .22424 .56435 .22193 .5634 .22059 Mtetra
.644 .71 .895 r
.5634 .22059 .56435 .22193 .56617 .2213 .56521 .22002 Mtetra
.499 .656 .929 r
.56521 .22002 .56617 .2213 .56799 .22118 .56704 .21997 Mtetra
.574 .706 .932 r
.56704 .21997 .56799 .22118 .56981 .22084 .56886 .21967 Mtetra
.66 .748 .916 r
.56886 .21967 .56981 .22084 .57163 .22021 .57068 .21903 Mtetra
.676 .752 .908 r
.57068 .21903 .57163 .22021 .57346 .21954 .57251 .21832 Mtetra
.754 .768 .864 r
.57251 .21832 .57346 .21954 .57527 .21845 .57432 .21715 Mtetra
.751 .754 .854 r
.57432 .21715 .57527 .21845 .57709 .21736 .57614 .21597 Mtetra
.65 .704 .886 r
.57614 .21597 .57709 .21736 .57891 .21683 .57796 .21536 Mtetra
0 .156 .694 r
.57796 .21536 .57891 .21683 .58078 .2187 .57983 .2171 Mtetra
.975 .679 .391 r
.57983 .2171 .58078 .2187 .58644 .41985 .58531 .41203 Mtetra
.852 .595 .056 r
.58531 .41203 .58644 .41985 .58869 .43442 .58768 .43316 Mtetra
0 .082 .611 r
.58768 .43316 .58869 .43442 .5907 .43615 .5897 .43509 Mtetra
.543 .74 .967 r
.5897 .43509 .5907 .43615 .59268 .43577 .59167 .43481 Mtetra
.752 .834 .914 r
.59167 .43481 .59268 .43577 .59463 .43471 .59363 .43366 Mtetra
.852 .828 .823 r
.59363 .43366 .59463 .43471 .59659 .43366 .59557 .43163 Mtetra
.855 .713 .704 r
.59557 .43163 .59659 .43366 .59855 .43261 .59748 .42827 Mtetra
.85 .627 .6 r
.59748 .42827 .59855 .43261 .6005 .43089 .5993 .42112 Mtetra
.969 .676 .417 r
.5993 .42112 .6005 .43089 .60237 .42625 .59648 .2172 Mtetra
.537 .309 .517 r
.59648 .2172 .60237 .42625 .59928 .2185 .5982 .21176 Mtetra
.671 .476 .613 r
.5982 .21176 .59928 .2185 .60095 .21099 .59999 .20897 Mtetra
.745 .665 .772 r
.59999 .20897 .60095 .21099 .60275 .20858 .60181 .20747 Mtetra
.685 .772 .917 r
.60181 .20747 .60275 .20858 .60458 .20775 .60365 .20671 Mtetra
.628 .768 .947 r
.60365 .20671 .60458 .20775 .60643 .20733 .6055 .20618 Mtetra
.723 .777 .895 r
.6055 .20618 .60643 .20733 .60827 .20652 .60734 .20523 Mtetra
.755 .76 .856 r
.60734 .20523 .60827 .20652 .6101 .2054 .60917 .20401 Mtetra
.662 .712 .885 r
.60917 .20401 .6101 .2054 .61195 .20482 .61101 .20334 Mtetra
0 .306 .799 r
.61101 .20334 .61195 .20482 .61386 .20625 .61292 .20466 Mtetra
.941 .587 .186 r
.61292 .20466 .61386 .20625 .61615 .2203 .61512 .21567 Mtetra
.977 .679 .368 r
.61512 .21567 .61615 .2203 .62422 .42246 .62322 .42114 Mtetra
0 0 .481 r
.62322 .42114 .62422 .42246 .6263 .42487 .62531 .42369 Mtetra
.473 .683 .958 r
.62531 .42369 .6263 .42487 .62831 .4248 .62732 .42365 Mtetra
.752 .801 .892 r
.62732 .42365 .62831 .4248 .63029 .4236 .6293 .42246 Mtetra
.922 .807 .715 r
.6293 .42246 .63029 .4236 .63219 .42008 .6312 .41889 Mtetra
.977 .683 .39 r
.6312 .41889 .63219 .42008 .62742 .21894 .6264 .21504 Mtetra
.933 .671 .517 r
.6264 .21504 .62742 .21894 .62869 .20092 .62776 .19949 Mtetra
.883 .767 .729 r
.62776 .19949 .62869 .20092 .63047 .19792 .62954 .19656 Mtetra
.677 .724 .885 r
.62954 .19656 .63047 .19792 .63233 .1971 .6314 .19581 Mtetra
.547 .68 .926 r
.6314 .19581 .63233 .1971 .6342 .19682 .63328 .1956 Mtetra
.615 .727 .925 r
.63328 .1956 .6342 .19682 .63607 .19629 .63515 .19513 Mtetra
.73 .78 .892 r
.63515 .19513 .63607 .19629 .63792 .19529 .637 .19413 Mtetra
.633 .745 .928 r
.637 .19413 .63792 .19529 .63979 .19476 .63887 .19359 Mtetra
0 .324 .807 r
.63887 .19359 .63979 .19476 .64173 .19594 .64081 .19478 Mtetra
.937 .573 .183 r
.64081 .19478 .64173 .19594 .64401 .20577 .64311 .20511 Mtetra
.975 .673 .365 r
.64311 .20511 .64401 .20577 .65416 .4123 .65319 .41119 Mtetra
.607 .13 0 r
.65319 .41119 .65416 .4123 .65631 .41511 .65534 .41396 Mtetra
.431 .67 .962 r
.65534 .41396 .65631 .41511 .65836 .41519 .65738 .41402 Mtetra
.726 .795 .906 r
.65738 .41402 .65836 .41519 .66035 .41415 .65938 .41298 Mtetra
.902 .813 .75 r
.65938 .41298 .66035 .41415 .66227 .41118 .6613 .41 Mtetra
.979 .744 .512 r
.6613 .41 .66227 .41118 .66382 .39968 .66284 .39844 Mtetra
.977 .681 .376 r
.66284 .39844 .66382 .39968 .65677 .19201 .65586 .19074 Mtetra
.921 .786 .695 r
.65586 .19074 .65677 .19201 .65852 .18838 .65761 .18712 Mtetra
.717 .759 .885 r
.65761 .18712 .65852 .18838 .66038 .18742 .65947 .18616 Mtetra
.591 .709 .925 r
.65947 .18616 .66038 .18742 .66228 .18704 .66137 .18578 Mtetra
.62 .723 .92 r
.66137 .18578 .66228 .18704 .66417 .18654 .66326 .1853 Mtetra
.737 .768 .878 r
.66326 .1853 .66417 .18654 .66603 .18547 .66512 .18422 Mtetra
.641 .733 .916 r
.66512 .18422 .66603 .18547 .66792 .18488 .66701 .18364 Mtetra
.03 .378 .843 r
.66701 .18364 .66792 .18488 .66988 .18589 .66898 .18472 Mtetra
.944 .589 .203 r
.66898 .18472 .66988 .18589 .67231 .19631 .67152 .19752 Mtetra
.974 .668 .356 r
.67152 .19752 .67231 .19631 .68446 .40278 .68351 .40202 Mtetra
.637 .124 0 r
.68351 .40202 .68446 .40278 .68665 .40549 .6857 .40457 Mtetra
.583 .795 .98 r
.6857 .40457 .68665 .40549 .6887 .40512 .68775 .40409 Mtetra
.742 .829 .918 r
.68775 .40409 .6887 .40512 .69072 .4041 .68976 .40297 Mtetra
.711 .8 .92 r
.68976 .40297 .69072 .4041 .69274 .40319 .69178 .402 Mtetra
.467 .683 .96 r
.69178 .402 .69274 .40319 .69481 .4031 .69386 .40198 Mtetra
.609 .764 .954 r
.69386 .40198 .69481 .4031 .69685 .40252 .6959 .40147 Mtetra
.854 .843 .833 r
.6959 .40147 .69685 .40252 .69882 .40043 .69787 .39945 Mtetra
.982 .776 .552 r
.69787 .39945 .69882 .40043 .70045 .39222 .69952 .39145 Mtetra
.978 .678 .358 r
.69952 .39145 .70045 .39222 .69085 .18088 .68995 .17964 Mtetra
.947 .786 .649 r
.68995 .17964 .69085 .18088 .69254 .17639 .69164 .17507 Mtetra
.733 .757 .872 r
.69164 .17507 .69254 .17639 .69441 .1753 .69352 .17399 Mtetra
.601 .706 .918 r
.69352 .17399 .69441 .1753 .69633 .17487 .69544 .17358 Mtetra
.573 .697 .926 r
.69544 .17358 .69633 .17487 .69825 .1745 .69736 .17328 Mtetra
.709 .767 .897 r
.69736 .17328 .69825 .1745 .70014 .17345 .69925 .17236 Mtetra
.665 .778 .934 r
.69925 .17236 .70014 .17345 .70204 .17278 .70116 .17167 Mtetra
.514 .707 .958 r
.70116 .17167 .70204 .17278 .70401 .17313 .7031 .17151 Mtetra
.153 .39 .839 r
.7031 .17151 .70401 .17313 .70622 .1773 .70512 .17263 Mtetra
.198 .196 .631 r
.70512 .17263 .70622 .1773 .7209 .38569 .70726 .17568 Mtetra
0 0 .403 r
.70726 .17568 .7209 .38569 .72333 .39109 .7216 .37701 Mtetra
.188 .102 .52 r
.7216 .37701 .72333 .39109 .72548 .3918 .72427 .38642 Mtetra
.298 .255 .64 r
.72427 .38642 .72548 .3918 .72757 .39171 .72654 .38906 Mtetra
.33 .398 .782 r
.72654 .38906 .72757 .39171 .72966 .39138 .72872 .39018 Mtetra
.365 .624 .952 r
.72872 .39018 .72966 .39138 .73177 .3914 .73084 .39044 Mtetra
.614 .806 .973 r
.73084 .39044 .73177 .3914 .73384 .3908 .73292 .38986 Mtetra
.859 .868 .845 r
.73292 .38986 .73384 .3908 .73583 .38891 .7349 .38787 Mtetra
.984 .777 .546 r
.7349 .38787 .73583 .38891 .73743 .38117 .73649 .3799 Mtetra
.977 .674 .341 r
.73649 .3799 .73743 .38117 .7253 .16865 .72439 .16697 Mtetra
.93 .751 .638 r
.72439 .16697 .7253 .16865 .72694 .16374 .72604 .16215 Mtetra
.711 .71 .848 r
.72604 .16215 .72694 .16374 .72883 .16264 .72794 .16113 Mtetra
.581 .664 .895 r
.72794 .16113 .72883 .16264 .73078 .16223 .72989 .16082 Mtetra
.518 .648 .915 r
.72989 .16082 .73078 .16223 .73274 .16202 .73186 .16073 Mtetra
.7 .754 .894 r
.73186 .16073 .73274 .16202 .73464 .16097 .73378 .15985 Mtetra
.668 .775 .93 r
.73378 .15985 .73464 .16097 .73657 .16025 .73571 .15913 Mtetra
.551 .724 .955 r
.73571 .15913 .73657 .16025 .73856 .16035 .73767 .15886 Mtetra
.168 .422 .859 r
.73767 .15886 .73856 .16035 .7408 .16397 .73972 .15987 Mtetra
.197 .216 .654 r
.73972 .15987 .7408 .16397 .75798 .37221 .74191 .16261 Mtetra
.02 0 .416 r
.74191 .16261 .75798 .37221 .76061 .37892 .75846 .36106 Mtetra
.163 .077 .503 r
.75846 .36106 .76061 .37892 .7628 .37976 .76154 .37399 Mtetra
.297 .248 .632 r
.76154 .37399 .7628 .37976 .76494 .37972 .7639 .37689 Mtetra
.334 .386 .767 r
.7639 .37689 .76494 .37972 .76705 .37933 .76613 .37809 Mtetra
.349 .607 .945 r
.76613 .37809 .76705 .37933 .7692 .37939 .7683 .37843 Mtetra
.591 .797 .978 r
.7683 .37843 .7692 .37939 .7713 .37885 .77041 .37791 Mtetra
.827 .874 .879 r
.77041 .37791 .7713 .37885 .77333 .37726 .77242 .37623 Mtetra
.985 .79 .561 r
.77242 .37623 .77333 .37726 .77494 .37036 .77402 .36918 Mtetra
.975 .669 .322 r
.77402 .36918 .77494 .37036 .76022 .15687 .75932 .15518 Mtetra
.946 .753 .609 r
.75932 .15518 .76022 .15687 .76178 .15121 .76089 .14962 Mtetra
.727 .718 .842 r
.76089 .14962 .76178 .15121 .76368 .14999 .7628 .14848 Mtetra
.601 .674 .892 r
.7628 .14848 .76368 .14999 .76565 .1495 .76478 .14807 Mtetra
.517 .646 .915 r
.76478 .14807 .76565 .1495 .76764 .14933 .76678 .14799 Mtetra
.759 .77 .862 r
.76678 .14799 .76764 .14933 .76955 .14812 .76868 .14672 Mtetra
.696 .737 .883 r
.76868 .14672 .76955 .14812 .77149 .1473 .77062 .14584 Mtetra
.518 .64 .909 r
.77062 .14584 .77149 .1473 .77351 .14729 .77263 .14576 Mtetra
.82 .432 0 r
.77263 .14576 .77351 .14729 .77612 .15438 .77524 .15287 Mtetra
.97 .655 .291 r
.77524 .15287 .77612 .15438 .79617 .36625 .79529 .36529 Mtetra
.642 .167 0 r
.79529 .36529 .79617 .36625 .79862 .36959 .79774 .36865 Mtetra
.879 .731 .694 r
.1253 .58242 .12647 .58367 .12852 .57977 .12736 .57838 Mtetra
.936 .686 .535 r
.12736 .57838 .12852 .57977 .15346 .37855 .15245 .37659 Mtetra
.896 .687 .613 r
.15245 .37659 .15346 .37855 .1561 .36859 .155 .36751 Mtetra
.783 .752 .825 r
.155 .36751 .1561 .36859 .15775 .36725 .15665 .36616 Mtetra
.666 .731 .899 r
.15665 .36616 .15775 .36725 .15931 .3667 .15821 .36558 Mtetra
.564 .695 .929 r
.15821 .36558 .15931 .3667 .16083 .3665 .15973 .36537 Mtetra
.748 .742 .846 r
.15973 .36537 .16083 .3665 .16245 .36547 .16135 .36431 Mtetra
.705 .728 .868 r
.16135 .36431 .16245 .36547 .16404 .36462 .16294 .36352 Mtetra
.566 .7 .932 r
.16294 .36352 .16404 .36462 .1656 .36413 .16447 .36329 Mtetra
.857 .403 .061 r
.16447 .36329 .1656 .36413 .16701 .36496 .16569 .36574 Mtetra
.936 .68 .524 r
.16569 .36574 .16701 .36496 .16827 .36716 .14687 .54698 Mtetra
.579 .341 .52 r
.14687 .54698 .16827 .36716 .16892 .37482 .14565 .57215 Mtetra
.527 .297 .509 r
.14565 .57215 .16892 .37482 .14892 .56887 .14711 .57341 Mtetra
.496 .175 .352 r
.14711 .57341 .14892 .56887 .15013 .57243 .14872 .57343 Mtetra
.073 0 0 r
.14872 .57343 .15013 .57243 .15159 .5738 .15038 .5729 Mtetra
.659 .782 .94 r
.15038 .5729 .15159 .5738 .15322 .57362 .15206 .57231 Mtetra
.681 .713 .873 r
.15206 .57231 .15322 .57362 .1549 .57292 .15375 .5716 Mtetra
.688 .713 .867 r
.15375 .5716 .1549 .57292 .15662 .572 .15544 .57085 Mtetra
.647 .73 .909 r
.15544 .57085 .15662 .572 .15829 .57142 .15711 .57031 Mtetra
.623 .732 .925 r
.15711 .57031 .15829 .57142 .15996 .57095 .15878 .56987 Mtetra
.603 .731 .935 r
.15878 .56987 .15996 .57095 .16161 .57057 .16043 .56949 Mtetra
.574 .723 .944 r
.16043 .56949 .16161 .57057 .16326 .57034 .16208 .5692 Mtetra
.571 .709 .936 r
.16208 .5692 .16326 .57034 .16489 .57015 .16373 .56893 Mtetra
.579 .697 .923 r
.16373 .56893 .16489 .57015 .16654 .56994 .16538 .56865 Mtetra
.604 .694 .906 r
.16538 .56865 .16654 .56994 .1682 .56959 .16704 .56829 Mtetra
.616 .695 .9 r
.16704 .56829 .1682 .56959 .16986 .56918 .16871 .56788 Mtetra
.625 .699 .898 r
.16871 .56788 .16986 .56918 .17154 .56872 .17038 .56743 Mtetra
.515 .658 .925 r
.17038 .56743 .17154 .56872 .17318 .5685 .17201 .56736 Mtetra
.589 .716 .931 r
.17201 .56736 .17318 .5685 .17485 .56811 .17368 .56703 Mtetra
.729 .762 .879 r
.17368 .56703 .17485 .56811 .17656 .56733 .1754 .56607 Mtetra
.882 .736 .695 r
.1754 .56607 .17656 .56733 .17844 .5649 .17744 .56208 Mtetra
.939 .685 .526 r
.17744 .56208 .17844 .5649 .18052 .56046 .19921 .36496 Mtetra
.555 .325 .522 r
.19921 .36496 .18052 .56046 .18377 .54445 .20203 .35235 Mtetra
.531 .305 .517 r
.20203 .35235 .18377 .54445 .20404 .35954 .2038 .35003 Mtetra
.568 .381 .588 r
.2038 .35003 .20404 .35954 .2057 .35838 .20541 .34927 Mtetra
.515 .342 .584 r
.20541 .34927 .2057 .35838 .20687 .36202 .20691 .34963 Mtetra
.306 .164 .518 r
.20691 .34963 .20687 .36202 .18919 .55538 .208 .35409 Mtetra
0 0 .119 r
.208 .35409 .18919 .55538 .19037 .56007 .18952 .55567 Mtetra
0 0 .257 r
.18952 .55567 .19037 .56007 .1918 .56216 .19068 .56057 Mtetra
.214 .447 .868 r
.19068 .56057 .1918 .56216 .19341 .56249 .19225 .56126 Mtetra
.617 .71 .912 r
.19225 .56126 .19341 .56249 .19508 .56216 .19394 .56084 Mtetra
.699 .719 .865 r
.19394 .56084 .19508 .56216 .19679 .56155 .19566 .56001 Mtetra
.655 .674 .856 r
.19566 .56001 .19679 .56155 .19848 .56107 .19737 .5594 Mtetra
.647 .653 .843 r
.19737 .5594 .19848 .56107 .20019 .56047 .19907 .55882 Mtetra
.668 .663 .836 r
.19907 .55882 .20019 .56047 .20193 .55953 .20079 .55811 Mtetra
.675 .697 .863 r
.20079 .55811 .20193 .55953 .20376 .55762 .20251 .5574 Mtetra
.731 .937 .954 r
.20251 .5574 .20376 .55762 .20572 .55438 .20426 .5564 Mtetra
0 0 0 r
.20426 .5564 .20572 .55438 .20801 .54759 .20607 .55471 Mtetra
0 0 .138 r
.20607 .55471 .20801 .54759 .22821 .34922 .20823 .54927 Mtetra
0 0 .116 r
.20823 .54927 .22821 .34922 .23026 .34391 .22881 .34668 Mtetra
.95 .897 .508 r
.22881 .34668 .23026 .34391 .23205 .34128 .23093 .34064 Mtetra
.853 .83 .825 r
.23093 .34064 .23205 .34128 .23372 .34005 .23265 .33884 Mtetra
.674 .718 .882 r
.23265 .33884 .23372 .34005 .23533 .33943 .23426 .3382 Mtetra
.578 .681 .911 r
.23426 .3382 .23533 .33943 .23692 .33904 .23584 .33794 Mtetra
.719 .75 .877 r
.23584 .33794 .23692 .33904 .23857 .33803 .23748 .33708 Mtetra
.732 .779 .891 r
.23748 .33708 .23857 .33803 .24022 .33703 .23911 .33618 Mtetra
.568 .761 .969 r
.23911 .33618 .24022 .33703 .24181 .33664 .2407 .33588 Mtetra
.849 .388 .043 r
.2407 .33588 .24181 .33664 .24315 .33912 .24203 .33842 Mtetra
.947 .684 .505 r
.24203 .33842 .24315 .33912 .22681 .54113 .22564 .54016 Mtetra
.946 .617 .374 r
.22564 .54016 .22681 .54113 .22771 .54987 .22656 .5486 Mtetra
0 .193 .702 r
.22656 .5486 .22771 .54987 .22926 .55115 .22813 .54981 Mtetra
.628 .697 .894 r
.22813 .54981 .22926 .55115 .23098 .55068 .22984 .54934 Mtetra
.732 .728 .847 r
.22984 .54934 .23098 .55068 .23276 .54941 .23161 .54827 Mtetra
.708 .755 .889 r
.23161 .54827 .23276 .54941 .2346 .54748 .23336 .54742 Mtetra
.642 .948 .951 r
.23336 .54742 .2346 .54748 .23653 .54454 .23511 .54657 Mtetra
0 0 0 r
.23511 .54657 .23653 .54454 .23868 .53895 .23691 .54509 Mtetra
0 0 .158 r
.23691 .54509 .23868 .53895 .25713 .34079 .23896 .54072 Mtetra
0 0 .141 r
.23896 .54072 .25713 .34079 .25925 .33427 .2577 .33879 Mtetra
.867 .831 .358 r
.2577 .33879 .25925 .33427 .26107 .33138 .25994 .33092 Mtetra
.887 .854 .804 r
.25994 .33092 .26107 .33138 .26276 .33003 .2617 .32877 Mtetra
.676 .712 .876 r
.2617 .32877 .26276 .33003 .26438 .32946 .26333 .32811 Mtetra
.566 .658 .898 r
.26333 .32811 .26438 .32946 .26599 .32916 .26493 .32791 Mtetra
.67 .711 .879 r
.26493 .32791 .26599 .32916 .26762 .32856 .26656 .32727 Mtetra
.704 .716 .858 r
.26656 .32727 .26762 .32856 .26926 .32781 .26821 .32644 Mtetra
.597 .667 .888 r
.26821 .32644 .26926 .32781 .27087 .32737 .26982 .32612 Mtetra
.612 .137 0 r
.26982 .32612 .27087 .32737 .2724 .32815 .27125 .328 Mtetra
.949 .683 .498 r
.27125 .328 .2724 .32815 .27375 .33109 .25745 .52028 Mtetra
.558 .322 .515 r
.25745 .52028 .27375 .33109 .2605 .51862 .25786 .53637 Mtetra
.557 .298 .479 r
.25786 .53637 .2605 .51862 .26125 .53045 .25942 .53805 Mtetra
.482 .197 .404 r
.25942 .53805 .26125 .53045 .26298 .53001 .26115 .53763 Mtetra
.444 .163 .391 r
.26115 .53763 .26298 .53001 .26484 .52785 .26293 .53662 Mtetra
.462 .187 .41 r
.26293 .53662 .26484 .52785 .26669 .52582 .26469 .53573 Mtetra
.484 .213 .427 r
.26469 .53573 .26669 .52582 .26845 .52494 .26644 .53513 Mtetra
.486 .217 .43 r
.26644 .53513 .26845 .52494 .2702 .52421 .26819 .53455 Mtetra
.489 .219 .432 r
.26819 .53455 .2702 .52421 .27194 .52374 .26993 .53401 Mtetra
.49 .22 .432 r
.26993 .53401 .27194 .52374 .27365 .52352 .27168 .5335 Mtetra
.49 .218 .429 r
.27168 .5335 .27365 .52352 .27536 .5234 .27342 .533 Mtetra
.503 .228 .431 r
.27342 .533 .27536 .5234 .27699 .52437 .27514 .53281 Mtetra
.502 .221 .42 r
.27514 .53281 .27699 .52437 .27863 .52523 .27686 .53267 Mtetra
.461 .177 .395 r
.27686 .53267 .27863 .52523 .2804 .52444 .27863 .53194 Mtetra
.272 .012 .325 r
.27863 .53194 .2804 .52444 .28336 .50713 .28056 .52894 Mtetra
0 0 .162 r
.28056 .52894 .28336 .50713 .29839 .32212 .28378 .50813 Mtetra
0 0 .163 r
.28378 .50813 .29839 .32212 .30028 .3181 .29915 .31793 Mtetra
.933 .874 .756 r
.29915 .31793 .30028 .3181 .30202 .31628 .30096 .31508 Mtetra
.695 .73 .878 r
.30096 .31508 .30202 .31628 .30367 .31565 .30263 .31432 Mtetra
.569 .665 .902 r
.30263 .31432 .30367 .31565 .3053 .31534 .30425 .31409 Mtetra
.569 .679 .914 r
.30425 .31409 .3053 .31534 .30693 .31502 .30588 .31385 Mtetra
.643 .722 .906 r
.30588 .31385 .30693 .31502 .30858 .31452 .30753 .31334 Mtetra
.647 .722 .903 r
.30753 .31334 .30858 .31452 .31023 .31399 .30918 .31281 Mtetra
.658 .725 .898 r
.30918 .31281 .31023 .31399 .31188 .31342 .31083 .31223 Mtetra
.671 .727 .892 r
.31083 .31223 .31188 .31342 .31354 .3128 .31249 .31159 Mtetra
.678 .727 .887 r
.31249 .31159 .31354 .3128 .3152 .31214 .31416 .31092 Mtetra
.682 .726 .883 r
.31416 .31092 .3152 .31214 .31687 .31145 .31582 .31022 Mtetra
.685 .725 .88 r
.31582 .31022 .31687 .31145 .31854 .31074 .31749 .3095 Mtetra
.688 .724 .877 r
.31749 .3095 .31854 .31074 .3202 .31002 .31916 .30877 Mtetra
.689 .723 .876 r
.31916 .30877 .3202 .31002 .32187 .3093 .32083 .30804 Mtetra
.688 .721 .874 r
.32083 .30804 .32187 .3093 .32354 .30858 .3225 .3073 Mtetra
.687 .717 .872 r
.3225 .3073 .32354 .30858 .32522 .30784 .32418 .30656 Mtetra
.72 .727 .856 r
.32418 .30656 .32522 .30784 .3269 .3069 .32586 .30563 Mtetra
.738 .733 .846 r
.32586 .30563 .3269 .3069 .3286 .30582 .32756 .30457 Mtetra
.662 .715 .888 r
.32756 .30457 .3286 .30582 .33027 .30505 .32922 .30397 Mtetra
0 .364 .826 r
.32922 .30397 .33027 .30505 .33189 .3052 .3308 .30481 Mtetra
.924 .56 .312 r
.3308 .30481 .33189 .3052 .3334 .30719 .33207 .3107 Mtetra
.951 .679 .486 r
.33207 .3107 .3334 .30719 .33471 .31258 .32132 .5138 Mtetra
.531 .3 .509 r
.32132 .5138 .33471 .31258 .32474 .50569 .32286 .51706 Mtetra
.502 .235 .442 r
.32286 .51706 .32474 .50569 .32656 .50428 .32463 .51675 Mtetra
.481 .221 .442 r
.32463 .51675 .32656 .50428 .32848 .50131 .32644 .51583 Mtetra
.497 .24 .454 r
.32644 .51583 .32848 .50131 .32985 .50776 .32822 .51519 Mtetra
.52 .23 .414 r
.32822 .51519 .32985 .50776 .33126 .51354 .32996 .51542 Mtetra
.468 .046 .155 r
.32996 .51542 .33126 .51354 .33287 .51604 .33171 .51558 Mtetra
.342 .765 .975 r
.33171 .51558 .33287 .51604 .33457 .51692 .33347 .51546 Mtetra
.629 .685 .884 r
.33347 .51546 .33457 .51692 .33635 .51654 .33526 .51497 Mtetra
.649 .675 .861 r
.33526 .51497 .33635 .51654 .33815 .51584 .33705 .51436 Mtetra
.624 .679 .882 r
.33705 .51436 .33815 .51584 .33995 .51519 .33884 .51389 Mtetra
.553 .682 .925 r
.33884 .51389 .33995 .51519 .34173 .51485 .34062 .51368 Mtetra
.661 .746 .913 r
.34062 .51368 .34173 .51485 .34353 .51423 .34242 .51304 Mtetra
.823 .772 .805 r
.34242 .51304 .34353 .51423 .34537 .51291 .34428 .51114 Mtetra
.902 .715 .64 r
.34428 .51114 .34537 .51291 .34728 .51008 .34637 .50514 Mtetra
.954 .685 .488 r
.34637 .50514 .34728 .51008 .34933 .5047 .35904 .29992 Mtetra
.538 .31 .517 r
.35904 .29992 .34933 .5047 .3616 .30367 .361 .29422 Mtetra
.604 .409 .591 r
.361 .29422 .3616 .30367 .36364 .29636 .36274 .29249 Mtetra
.636 .501 .681 r
.36274 .29249 .36364 .29636 .36546 .29325 .36446 .29146 Mtetra
.664 .641 .817 r
.36446 .29146 .36546 .29325 .36721 .29148 .36615 .29075 Mtetra
.668 .83 .961 r
.36615 .29075 .36721 .29148 .3689 .29069 .36784 .29011 Mtetra
.613 .849 .988 r
.36784 .29011 .3689 .29069 .37059 .29023 .36953 .28958 Mtetra
.606 .831 .986 r
.36953 .28958 .37059 .29023 .37227 .2899 .37122 .28909 Mtetra
.636 .802 .963 r
.37122 .28909 .37227 .2899 .37395 .28949 .37291 .28856 Mtetra
.646 .779 .944 r
.37291 .28856 .37395 .28949 .37564 .28906 .3746 .28801 Mtetra
.662 .757 .921 r
.3746 .28801 .37564 .28906 .37733 .28853 .3763 .28741 Mtetra
.684 .75 .901 r
.3763 .28741 .37733 .28853 .37903 .28777 .378 .2867 Mtetra
.689 .762 .907 r
.378 .2867 .37903 .28777 .38074 .28696 .3797 .28598 Mtetra
.706 .782 .911 r
.3797 .28598 .38074 .28696 .38245 .28613 .38141 .28518 Mtetra
.743 .796 .895 r
.38141 .28518 .38245 .28613 .38416 .28526 .38313 .28419 Mtetra
.663 .753 .918 r
.38313 .28419 .38416 .28526 .38586 .28465 .38483 .28358 Mtetra
.268 .574 .94 r
.38483 .28358 .38586 .28465 .38754 .28464 .38649 .28396 Mtetra
.905 .494 .172 r
.38649 .28396 .38754 .28464 .38914 .28636 .38798 .28823 Mtetra
.958 .681 .468 r
.38798 .28823 .38914 .28636 .39063 .2906 .38077 .49273 Mtetra
.534 .302 .51 r
.38077 .49273 .39063 .2906 .384 .48599 .38235 .49778 Mtetra
.512 .244 .446 r
.38235 .49778 .384 .48599 .38579 .486 .38415 .49771 Mtetra
.484 .22 .438 r
.38415 .49771 .38579 .486 .38767 .48385 .38598 .49691 Mtetra
.487 .227 .446 r
.38598 .49691 .38767 .48385 .38933 .48716 .38782 .49606 Mtetra
.52 .238 .428 r
.38782 .49606 .38933 .48716 .39085 .49385 .38961 .49626 Mtetra
.484 .092 .221 r
.38961 .49626 .39085 .49385 .39255 .49662 .39141 .49643 Mtetra
.12 .663 .838 r
.39141 .49643 .39255 .49662 .3943 .49787 .39322 .49642 Mtetra
.604 .679 .895 r
.39322 .49642 .3943 .49787 .39612 .49774 .39504 .49602 Mtetra
.629 .651 .853 r
.39504 .49602 .39612 .49774 .39794 .49725 .39687 .4955 Mtetra
.634 .65 .848 r
.39687 .4955 .39794 .49725 .39978 .49658 .39871 .49494 Mtetra
.576 .64 .877 r
.39871 .49494 .39978 .49658 .40161 .49609 .40053 .49468 Mtetra
.658 .708 .884 r
.40053 .49468 .40161 .49609 .40346 .49533 .40237 .49403 Mtetra
.786 .76 .829 r
.40237 .49403 .40346 .49533 .40532 .49403 .40424 .4925 Mtetra
.91 .735 .652 r
.40424 .4925 .40532 .49403 .40724 .491 .40625 .4872 Mtetra
.961 .687 .471 r
.40625 .4872 .40724 .491 .40924 .48582 .41532 .2816 Mtetra
.541 .313 .518 r
.41532 .2816 .40924 .48582 .41769 .29299 .41728 .27427 Mtetra
.558 .349 .553 r
.41728 .27427 .41769 .29299 .41967 .28509 .41903 .27297 Mtetra
.549 .356 .572 r
.41903 .27297 .41967 .28509 .42137 .28544 .42075 .27249 Mtetra
.535 .343 .567 r
.42075 .27249 .42137 .28544 .42289 .29151 .42246 .27239 Mtetra
.543 .337 .551 r
.42246 .27239 .42289 .29151 .4246 .29171 .42419 .27178 Mtetra
.542 .335 .549 r
.42419 .27178 .4246 .29171 .42629 .29261 .42592 .27119 Mtetra
.541 .332 .547 r
.42592 .27119 .42629 .29261 .42778 .30001 .42765 .27062 Mtetra
.535 .322 .537 r
.42765 .27062 .42778 .30001 .42427 .47144 .42937 .27016 Mtetra
.527 .301 .515 r
.42937 .27016 .42427 .47144 .42608 .47174 .4311 .2696 Mtetra
.527 .301 .516 r
.4311 .2696 .42608 .47174 .43335 .28682 .43284 .26883 Mtetra
.561 .353 .555 r
.43284 .26883 .43335 .28682 .4355 .27241 .4346 .26745 Mtetra
.636 .476 .649 r
.4346 .26745 .4355 .27241 .43733 .26822 .43635 .2661 Mtetra
.708 .631 .769 r
.43635 .2661 .43733 .26822 .43912 .26571 .43811 .26492 Mtetra
.681 .824 .952 r
.43811 .26492 .43912 .26571 .44087 .26479 .43984 .26421 Mtetra
.625 .859 .987 r
.43984 .26421 .44087 .26479 .4426 .26423 .44158 .26363 Mtetra
.606 .848 .99 r
.44158 .26363 .4426 .26423 .44433 .26385 .44332 .2631 Mtetra
.656 .829 .967 r
.44332 .2631 .44433 .26385 .44607 .26322 .44506 .26247 Mtetra
.657 .83 .966 r
.44506 .26247 .44607 .26322 .44781 .2626 .4468 .26184 Mtetra
.658 .825 .964 r
.4468 .26184 .44781 .2626 .44955 .26202 .44854 .26121 Mtetra
.651 .814 .961 r
.44854 .26121 .44955 .26202 .45129 .26154 .45029 .26061 Mtetra
.657 .788 .944 r
.45029 .26061 .45129 .26154 .45303 .26105 .45203 .26 Mtetra
.664 .763 .924 r
.45203 .26 .45303 .26105 .45478 .26051 .45378 .25937 Mtetra
.752 .769 .867 r
.45378 .25937 .45478 .26051 .45653 .25947 .45553 .25825 Mtetra
.702 .743 .883 r
.45553 .25825 .45653 .25947 .45829 .25858 .45729 .25742 Mtetra
.559 .702 .936 r
.45729 .25742 .45829 .25858 .46003 .25807 .45903 .25718 Mtetra
.784 .305 0 r
.45903 .25718 .46003 .25807 .46175 .25898 .46071 .25994 Mtetra
.965 .681 .443 r
.46071 .25994 .46175 .25898 .46344 .26154 .45838 .46097 Mtetra
.545 .311 .511 r
.45838 .46097 .46344 .26154 .46468 .28731 .46001 .47202 Mtetra
.527 .296 .508 r
.46001 .47202 .46468 .28731 .46301 .46994 .46186 .47323 Mtetra
.486 .128 .284 r
.46186 .47323 .46301 .46994 .46482 .47297 .46372 .4733 Mtetra
0 0 0 r
.46372 .4733 .46482 .47297 .46666 .47419 .4656 .47287 Mtetra
.635 .719 .908 r
.4656 .47287 .46666 .47419 .46854 .47387 .46748 .47232 Mtetra
.66 .691 .869 r
.46748 .47232 .46854 .47387 .47042 .47306 .46936 .47163 Mtetra
.673 .715 .88 r
.46936 .47163 .47042 .47306 .47231 .47205 .47125 .47089 Mtetra
.472 .68 .956 r
.47125 .47089 .47231 .47205 .47419 .47208 .47312 .47086 Mtetra
.575 .716 .938 r
.47312 .47086 .47419 .47208 .47607 .47184 .47501 .47054 Mtetra
.732 .755 .871 r
.47501 .47054 .47607 .47184 .47796 .47083 .4769 .46946 Mtetra
.926 .753 .648 r
.4769 .46946 .47796 .47083 .47991 .46539 .47886 .46411 Mtetra
.969 .689 .446 r
.47886 .46411 .47991 .46539 .48454 .2558 .48354 .25512 Mtetra
.965 .774 .596 r
.48354 .25512 .48454 .2558 .48639 .24902 .4854 .24819 Mtetra
.825 .841 .86 r
.4854 .24819 .48639 .24902 .48816 .24756 .48717 .24665 Mtetra
.627 .786 .958 r
.48717 .24665 .48816 .24756 .48993 .24715 .48894 .24614 Mtetra
.486 .706 .967 r
.48894 .24614 .48993 .24715 .49169 .24717 .4907 .24605 Mtetra
.637 .742 .925 r
.4907 .24605 .49169 .24717 .49346 .24672 .49247 .24552 Mtetra
.665 .737 .904 r
.49247 .24552 .49346 .24672 .49523 .24612 .49425 .24487 Mtetra
.67 .732 .897 r
.49425 .24487 .49523 .24612 .497 .24544 .49602 .2442 Mtetra
.742 .755 .863 r
.49602 .2442 .497 .24544 .49878 .24439 .4978 .24311 Mtetra
.71 .74 .875 r
.4978 .24311 .49878 .24439 .50056 .24344 .49958 .24222 Mtetra
.588 .705 .924 r
.49958 .24222 .50056 .24344 .50233 .24285 .50135 .24188 Mtetra
.652 .157 0 r
.50135 .24188 .50233 .24285 .5041 .24357 .50311 .24413 Mtetra
.969 .68 .426 r
.50311 .24413 .5041 .24357 .50586 .24589 .50362 .43761 Mtetra
.561 .323 .512 r
.50362 .43761 .50586 .24589 .50758 .25621 .5054 .45697 Mtetra
.527 .297 .508 r
.5054 .45697 .50758 .25621 .50837 .45432 .50729 .45857 Mtetra
.498 .164 .332 r
.50729 .45857 .50837 .45432 .51026 .45765 .5092 .45867 Mtetra
.187 0 0 r
.5092 .45867 .51026 .45765 .51216 .45903 .51111 .45825 Mtetra
.42 .742 .993 r
.51111 .45825 .51216 .45903 .51407 .45939 .51302 .45816 Mtetra
.58 .717 .937 r
.51302 .45816 .51407 .45939 .51598 .4591 .51493 .45782 Mtetra
.72 .758 .882 r
.51493 .45782 .51598 .4591 .51789 .45821 .51685 .45681 Mtetra
.896 .765 .709 r
.51685 .45681 .51789 .45821 .51981 .45611 .51877 .45322 Mtetra
.934 .69 .545 r
.51877 .45322 .51981 .45611 .52173 .4524 .52071 .43966 Mtetra
.96 .675 .448 r
.52071 .43966 .52173 .4524 .52365 .44312 .52276 .23762 Mtetra
.531 .305 .516 r
.52276 .23762 .52365 .44312 .52552 .24125 .52455 .23475 Mtetra
.61 .436 .622 r
.52455 .23475 .52552 .24125 .52732 .23669 .52634 .23346 Mtetra
.629 .523 .715 r
.52634 .23346 .52732 .23669 .52911 .2342 .52814 .23266 Mtetra
.669 .686 .857 r
.52814 .23266 .52911 .2342 .5309 .23299 .52993 .23195 Mtetra
.664 .772 .93 r
.52993 .23195 .5309 .23299 .5327 .23234 .53173 .2313 Mtetra
.65 .768 .935 r
.53173 .2313 .5327 .23234 .53449 .23188 .53353 .23071 Mtetra
.735 .768 .879 r
.53353 .23071 .53449 .23188 .53629 .23094 .53533 .22968 Mtetra
.721 .749 .874 r
.53533 .22968 .53629 .23094 .53809 .22994 .53712 .22872 Mtetra
.614 .717 .919 r
.53712 .22872 .53809 .22994 .53989 .22929 .53893 .22828 Mtetra
0 .023 .532 r
.53893 .22828 .53989 .22929 .5417 .22979 .54074 .23006 Mtetra
.938 .586 .325 r
.54074 .23006 .5417 .22979 .54352 .23183 .54261 .24074 Mtetra
.962 .668 .426 r
.54261 .24074 .54352 .23183 .54537 .23902 .54572 .44331 Mtetra
.528 .297 .508 r
.54572 .44331 .54537 .23902 .54866 .44047 .54767 .44542 Mtetra
.509 .187 .357 r
.54767 .44542 .54866 .44047 .55063 .44429 .54962 .4456 Mtetra
.271 0 0 r
.54962 .4456 .55063 .44429 .55258 .44583 .55156 .44522 Mtetra
.356 .747 .986 r
.55156 .44522 .55258 .44583 .55453 .4465 .55351 .44515 Mtetra
.55 .684 .928 r
.55351 .44515 .55453 .4465 .55648 .44641 .55545 .44493 Mtetra
.703 .725 .867 r
.55545 .44493 .55648 .44641 .55842 .44542 .55739 .44398 Mtetra
.904 .764 .696 r
.55739 .44398 .55842 .44542 .56033 .44148 .5593 .44012 Mtetra
.974 .687 .418 r
.5593 .44012 .56033 .44148 .55991 .23433 .55896 .23415 Mtetra
.987 .758 .504 r
.55896 .23415 .55991 .23433 .5616 .22289 .56065 .22205 Mtetra
.894 .842 .786 r
.56065 .22205 .5616 .22289 .5634 .22059 .56245 .21967 Mtetra
.664 .804 .95 r
.56245 .21967 .5634 .22059 .56521 .22002 .56426 .21901 Mtetra
.509 .72 .968 r
.56426 .21901 .56521 .22002 .56704 .21997 .56609 .21885 Mtetra
.596 .733 .94 r
.56609 .21885 .56704 .21997 .56886 .21967 .56791 .21846 Mtetra
.668 .743 .907 r
.56791 .21846 .56886 .21967 .57068 .21903 .56973 .21778 Mtetra
.675 .738 .898 r
.56973 .21778 .57068 .21903 .57251 .21832 .57155 .21707 Mtetra
.742 .76 .867 r
.57155 .21707 .57251 .21832 .57432 .21715 .57337 .21597 Mtetra
.744 .773 .877 r
.57337 .21597 .57432 .21715 .57614 .21597 .57519 .21488 Mtetra
.629 .754 .937 r
.57519 .21488 .57614 .21597 .57796 .21536 .57702 .21436 Mtetra
0 .02 .529 r
.57702 .21436 .57796 .21536 .57983 .2171 .57889 .21621 Mtetra
.974 .678 .393 r
.57889 .21621 .57983 .2171 .58531 .41203 .58441 .41664 Mtetra
.885 .553 .415 r
.58441 .41664 .58531 .41203 .58768 .43316 .58667 .43204 Mtetra
0 .042 .558 r
.58667 .43204 .58768 .43316 .5897 .43509 .58869 .434 Mtetra
.515 .722 .967 r
.58869 .434 .5897 .43509 .59167 .43481 .59066 .43381 Mtetra
.762 .828 .903 r
.59066 .43381 .59167 .43481 .59363 .43366 .59262 .43259 Mtetra
.91 .815 .741 r
.59262 .43259 .59363 .43366 .59557 .43163 .59454 .42945 Mtetra
.941 .714 .566 r
.59454 .42945 .59557 .43163 .59748 .42827 .59632 .42008 Mtetra
.97 .678 .415 r
.59632 .42008 .59748 .42827 .5993 .42112 .59361 .21309 Mtetra
.533 .306 .516 r
.59361 .21309 .5993 .42112 .59648 .2172 .59538 .20936 Mtetra
.602 .418 .605 r
.59538 .20936 .59648 .2172 .5982 .21176 .5972 .20793 Mtetra
.622 .497 .69 r
.5972 .20793 .5982 .21176 .59999 .20897 .59904 .20706 Mtetra
.655 .636 .819 r
.59904 .20706 .59999 .20897 .60181 .20747 .60088 .20634 Mtetra
.671 .764 .92 r
.60088 .20634 .60181 .20747 .60365 .20671 .60272 .20565 Mtetra
.656 .772 .935 r
.60272 .20565 .60365 .20671 .6055 .20618 .60457 .20502 Mtetra
.727 .774 .891 r
.60457 .20502 .6055 .20618 .60734 .20523 .6064 .20403 Mtetra
.748 .776 .876 r
.6064 .20403 .60734 .20523 .60917 .20401 .60824 .20291 Mtetra
.646 .76 .932 r
.60824 .20291 .60917 .20401 .61101 .20334 .61009 .20232 Mtetra
0 .205 .703 r
.61009 .20232 .61101 .20334 .61292 .20466 .612 .20373 Mtetra
.952 .602 .253 r
.612 .20373 .61292 .20466 .61512 .21567 .61424 .2165 Mtetra
.974 .673 .381 r
.61424 .2165 .61512 .21567 .62322 .42114 .62223 .42 Mtetra
.552 .075 0 r
.62223 .42 .62322 .42114 .62531 .42369 .62432 .42246 Mtetra
.475 .676 .953 r
.62432 .42246 .62531 .42369 .62732 .42365 .62633 .42244 Mtetra
.744 .788 .888 r
.62633 .42244 .62732 .42365 .6293 .42246 .62831 .42128 Mtetra
.916 .805 .723 r
.62831 .42128 .6293 .42246 .6312 .41889 .63021 .41786 Mtetra
.981 .716 .451 r
.63021 .41786 .6312 .41889 .6264 .21504 .63145 .39436 Mtetra
0 0 .326 r
.63145 .39436 .6264 .21504 .62776 .19949 .62685 .19869 Mtetra
.932 .846 .735 r
.62685 .19869 .62776 .19949 .62954 .19656 .62863 .19562 Mtetra
.701 .816 .936 r
.62863 .19562 .62954 .19656 .6314 .19581 .63049 .19478 Mtetra
.553 .74 .963 r
.63049 .19478 .6314 .19581 .63328 .1956 .63236 .19449 Mtetra
.63 .754 .937 r
.63236 .19449 .63328 .1956 .63515 .19513 .63423 .19396 Mtetra
.732 .777 .889 r
.63423 .19396 .63515 .19513 .637 .19413 .63608 .19294 Mtetra
.632 .739 .925 r
.63608 .19294 .637 .19413 .63887 .19359 .63795 .1924 Mtetra
0 .317 .802 r
.63795 .1924 .63887 .19359 .64081 .19478 .63989 .19361 Mtetra
.941 .579 .194 r
.63989 .19361 .64081 .19478 .64311 .20511 .64221 .2045 Mtetra
.975 .673 .365 r
.64221 .2045 .64311 .20511 .65319 .41119 .65221 .41008 Mtetra
.595 .119 0 r
.65221 .41008 .65319 .41119 .65534 .41396 .65436 .4128 Mtetra
.438 .671 .961 r
.65436 .4128 .65534 .41396 .65738 .41402 .6564 .41285 Mtetra
.728 .794 .905 r
.6564 .41285 .65738 .41402 .65938 .41298 .6584 .41179 Mtetra
.902 .813 .75 r
.6584 .41179 .65938 .41298 .6613 .41 .66032 .40881 Mtetra
.979 .743 .511 r
.66032 .40881 .6613 .41 .66284 .39844 .66187 .39722 Mtetra
.977 .681 .376 r
.66187 .39722 .66284 .39844 .65586 .19074 .65494 .18948 Mtetra
.921 .787 .696 r
.65494 .18948 .65586 .19074 .65761 .18712 .65669 .18586 Mtetra
.717 .76 .886 r
.65669 .18586 .65761 .18712 .65947 .18616 .65856 .1849 Mtetra
.59 .709 .926 r
.65856 .1849 .65947 .18616 .66137 .18578 .66046 .18453 Mtetra
.617 .722 .921 r
.66046 .18453 .66137 .18578 .66326 .1853 .66235 .18405 Mtetra
.734 .769 .881 r
.66235 .18405 .66326 .1853 .66512 .18422 .66421 .183 Mtetra
.639 .737 .92 r
.66421 .183 .66512 .18422 .66701 .18364 .6661 .18243 Mtetra
.04 .39 .85 r
.6661 .18243 .66701 .18364 .66898 .18472 .66807 .18346 Mtetra
.934 .571 .168 r
.66807 .18346 .66898 .18472 .67152 .19752 .67052 .19445 Mtetra
.976 .672 .344 r
.67052 .19445 .67152 .19752 .68351 .40202 .68253 .40044 Mtetra
0 0 .558 r
.68253 .40044 .68351 .40202 .6857 .40457 .68473 .40311 Mtetra
.587 .69 .913 r
.68473 .40311 .6857 .40457 .68775 .40409 .68678 .40273 Mtetra
.717 .76 .887 r
.68678 .40273 .68775 .40409 .68976 .40297 .6888 .4017 Mtetra
.704 .772 .905 r
.6888 .4017 .68976 .40297 .69178 .402 .69082 .40076 Mtetra
.51 .694 .951 r
.69082 .40076 .69178 .402 .69386 .40198 .69289 .40062 Mtetra
.642 .733 .915 r
.69289 .40062 .69386 .40198 .6959 .40147 .69493 .39999 Mtetra
.836 .776 .795 r
.69493 .39999 .6959 .40147 .69787 .39945 .69689 .39784 Mtetra
.966 .745 .553 r
.69689 .39784 .69787 .39945 .69952 .39145 .6985 .38916 Mtetra
.977 .677 .361 r
.6985 .38916 .69952 .39145 .68995 .17964 .68904 .1781 Mtetra
.925 .761 .659 r
.68904 .1781 .68995 .17964 .69164 .17507 .69074 .17376 Mtetra
.729 .758 .876 r
.69074 .17376 .69164 .17507 .69352 .17399 .69262 .17271 Mtetra
.598 .711 .923 r
.69262 .17271 .69352 .17399 .69544 .17358 .69454 .17231 Mtetra
.561 .694 .93 r
.69454 .17231 .69544 .17358 .69736 .17328 .69647 .17204 Mtetra
.681 .755 .907 r
.69647 .17204 .69736 .17328 .69925 .17236 .69837 .17127 Mtetra
.669 .78 .932 r
.69837 .17127 .69925 .17236 .70116 .17167 .70028 .17056 Mtetra
.653 .769 .934 r
.70028 .17056 .70116 .17167 .7031 .17151 .70219 .16991 Mtetra
.641 .676 .868 r
.70219 .16991 .7031 .17151 .70512 .17263 .70411 .16931 Mtetra
.553 .478 .725 r
.70411 .16931 .70512 .17263 .70726 .17568 .70605 .16919 Mtetra
.454 .332 .624 r
.70605 .16919 .70726 .17568 .7216 .37701 .70809 .17044 Mtetra
.484 .27 .512 r
.70809 .17044 .7216 .37701 .72427 .38642 .71128 .19038 Mtetra
0 0 .396 r
.71128 .19038 .72427 .38642 .72654 .38906 .72549 .38607 Mtetra
.002 .153 .668 r
.72549 .38607 .72654 .38906 .72872 .39018 .72777 .38892 Mtetra
.361 .611 .945 r
.72777 .38892 .72872 .39018 .73084 .39044 .7299 .38923 Mtetra
.664 .771 .929 r
.7299 .38923 .73084 .39044 .73292 .38986 .73196 .38848 Mtetra
.849 .796 .799 r
.73196 .38848 .73292 .38986 .7349 .38787 .73393 .38626 Mtetra
.967 .75 .557 r
.73393 .38626 .7349 .38787 .73649 .3799 .73551 .37815 Mtetra
.977 .673 .343 r
.73551 .37815 .73649 .3799 .72439 .16697 .72352 .16585 Mtetra
.961 .799 .636 r
.72352 .16585 .72439 .16697 .72604 .16215 .72517 .16108 Mtetra
.744 .812 .906 r
.72517 .16108 .72604 .16215 .72794 .16113 .72707 .16 Mtetra
.591 .74 .947 r
.72707 .16 .72794 .16113 .72989 .16082 .72902 .15959 Mtetra
.525 .689 .943 r
.72902 .15959 .72989 .16082 .73186 .16073 .73098 .15943 Mtetra
.673 .743 .903 r
.73098 .15943 .73186 .16073 .73378 .15985 .73291 .15869 Mtetra
.665 .767 .926 r
.73291 .15869 .73378 .15985 .73571 .15913 .73484 .15799 Mtetra
.646 .762 .933 r
.73484 .15799 .73571 .15913 .73767 .15886 .73678 .15737 Mtetra
.643 .697 .884 r
.73678 .15737 .73767 .15886 .73972 .15987 .73872 .15676 Mtetra
.559 .493 .738 r
.73872 .15676 .73972 .15987 .74191 .16261 .74069 .15659 Mtetra
.473 .353 .635 r
.74069 .15659 .74191 .16261 .75846 .36106 .74275 .15752 Mtetra
.504 .285 .514 r
.74275 .15752 .75846 .36106 .76154 .37399 .74552 .16808 Mtetra
0 0 .407 r
.74552 .16808 .76154 .37399 .7639 .37689 .76282 .37356 Mtetra
.004 .134 .649 r
.76282 .37356 .7639 .37689 .76613 .37809 .7652 .37681 Mtetra
.331 .589 .938 r
.7652 .37681 .76613 .37809 .7683 .37843 .76738 .37722 Mtetra
.643 .767 .938 r
.76738 .37722 .7683 .37843 .77041 .37791 .76947 .37656 Mtetra
.827 .801 .826 r
.76947 .37656 .77041 .37791 .77242 .37623 .77148 .37463 Mtetra
.966 .759 .573 r
.77148 .37463 .77242 .37623 .77402 .36918 .77307 .36751 Mtetra
.975 .669 .323 r
.77307 .36751 .77402 .36918 .75932 .15518 .75847 .15405 Mtetra
.973 .794 .602 r
.75847 .15405 .75932 .15518 .76089 .14962 .76004 .14855 Mtetra
.765 .822 .897 r
.76004 .14855 .76089 .14962 .7628 .14848 .76195 .14733 Mtetra
.613 .75 .943 r
.76195 .14733 .7628 .14848 .76478 .14807 .76392 .14684 Mtetra
.524 .688 .943 r
.76392 .14684 .76478 .14807 .76678 .14799 .76591 .14668 Mtetra
.746 .771 .874 r
.76591 .14668 .76678 .14799 .76868 .14672 .76783 .14551 Mtetra
.68 .766 .916 r
.76783 .14551 .76868 .14672 .77062 .14584 .76978 .14473 Mtetra
.448 .676 .961 r
.76978 .14473 .77062 .14584 .77263 .14576 .7718 .14475 Mtetra
.868 .464 .004 r
.7718 .14475 .77263 .14576 .77524 .15287 .77443 .15209 Mtetra
.97 .655 .293 r
.77443 .15209 .77524 .15287 .79529 .36529 .79436 .36385 Mtetra
0 0 .482 r
.79436 .36385 .79529 .36529 .79774 .36865 .79681 .36711 Mtetra
.817 .624 .641 r
.12439 .57889 .1253 .58242 .12736 .57838 .12662 .57346 Mtetra
.932 .681 .536 r
.12662 .57346 .12736 .57838 .15245 .37659 .15173 .37214 Mtetra
.799 .595 .625 r
.15173 .37214 .15245 .37659 .155 .36751 .1539 .36634 Mtetra
.779 .739 .816 r
.1539 .36634 .155 .36751 .15665 .36616 .15555 .36497 Mtetra
.686 .719 .874 r
.15555 .36497 .15665 .36616 .15821 .36558 .15713 .36428 Mtetra
.585 .667 .896 r
.15713 .36428 .15821 .36558 .15973 .36537 .15866 .36402 Mtetra
.625 .675 .877 r
.15866 .36402 .15973 .36537 .16135 .36431 .1602 .36361 Mtetra
.39 .723 .989 r
.1602 .36361 .16135 .36431 .16294 .36352 .1617 .3636 Mtetra
.561 0 0 r
.1617 .3636 .16294 .36352 .16447 .36329 .16312 .36436 Mtetra
.871 .546 .434 r
.16312 .36436 .16447 .36329 .16569 .36574 .16392 .37052 Mtetra
.931 .674 .526 r
.16392 .37052 .16569 .36574 .14687 .54698 .14298 .56997 Mtetra
.588 .333 .498 r
.14298 .56997 .14687 .54698 .14565 .57215 .14414 .5739 Mtetra
.441 .014 .131 r
.14414 .5739 .14565 .57215 .14711 .57341 .14574 .57395 Mtetra
.39 .836 .725 r
.14574 .57395 .14711 .57341 .14872 .57343 .14744 .57312 Mtetra
.8 .912 .916 r
.14744 .57312 .14872 .57343 .15038 .5729 .14919 .57186 Mtetra
.703 .764 .899 r
.14919 .57186 .15038 .5729 .15206 .57231 .15089 .57107 Mtetra
.679 .723 .883 r
.15089 .57107 .15206 .57231 .15375 .5716 .15258 .57037 Mtetra
.665 .723 .892 r
.15258 .57037 .15375 .5716 .15544 .57085 .15426 .56975 Mtetra
.635 .739 .924 r
.15426 .56975 .15544 .57085 .15711 .57031 .15593 .56927 Mtetra
.609 .741 .939 r
.15593 .56927 .15711 .57031 .15878 .56987 .15758 .56886 Mtetra
.587 .743 .951 r
.15758 .56886 .15878 .56987 .16043 .56949 .15924 .56852 Mtetra
.511 .724 .969 r
.15924 .56852 .16043 .56949 .16208 .5692 .16087 .56837 Mtetra
.519 .759 .984 r
.16087 .56837 .16208 .5692 .16373 .56893 .16252 .56816 Mtetra
.591 .795 .977 r
.16252 .56816 .16373 .56893 .16538 .56865 .16418 .56776 Mtetra
.756 .799 .888 r
.16418 .56776 .16538 .56865 .16704 .56829 .16592 .56668 Mtetra
.753 .694 .795 r
.16592 .56668 .16704 .56829 .16871 .56788 .16769 .56529 Mtetra
.714 .603 .731 r
.16769 .56529 .16871 .56788 .17038 .56743 .16947 .5638 Mtetra
.561 .466 .703 r
.16947 .5638 .17038 .56743 .17201 .56736 .17111 .56361 Mtetra
.564 .463 .698 r
.17111 .56361 .17201 .56736 .17368 .56703 .17276 .5634 Mtetra
.644 .518 .695 r
.17276 .5634 .17368 .56703 .1754 .56607 .1745 .56237 Mtetra
.843 .635 .622 r
.1745 .56237 .1754 .56607 .17744 .56208 .17688 .55503 Mtetra
.935 .68 .528 r
.17688 .55503 .17744 .56208 .19921 .36496 .19915 .3538 Mtetra
.674 .458 .585 r
.19915 .3538 .19921 .36496 .20203 .35235 .20116 .34903 Mtetra
.704 .558 .686 r
.20116 .34903 .20203 .35235 .2038 .35003 .20287 .34728 Mtetra
.637 .543 .732 r
.20287 .34728 .2038 .35003 .20541 .34927 .20448 .34657 Mtetra
.524 .48 .75 r
.20448 .34657 .20541 .34927 .20691 .34963 .206 .34664 Mtetra
0 .041 .589 r
.206 .34664 .20691 .34963 .208 .35409 .20732 .34886 Mtetra
.981 .708 .324 r
.20732 .34886 .208 .35409 .18952 .55567 .2075 .36242 Mtetra
0 0 .118 r
.2075 .36242 .18952 .55567 .19068 .56057 .1898 .55647 Mtetra
.371 .322 .673 r
.1898 .55647 .19068 .56057 .19225 .56126 .19133 .55763 Mtetra
.6 .491 .701 r
.19133 .55763 .19225 .56126 .19394 .56084 .19303 .55709 Mtetra
.637 .51 .691 r
.19303 .55709 .19394 .56084 .19566 .56001 .19477 .55611 Mtetra
.538 .441 .693 r
.19477 .55611 .19566 .56001 .19737 .5594 .19641 .55612 Mtetra
.489 .437 .725 r
.19641 .55612 .19737 .5594 .19907 .55882 .19803 .55643 Mtetra
.493 .501 .794 r
.19803 .55643 .19907 .55882 .20079 .55811 .19966 .55662 Mtetra
.43 .584 .904 r
.19966 .55662 .20079 .55811 .20251 .5574 .20129 .55682 Mtetra
.449 .789 .998 r
.20129 .55682 .20251 .5574 .20426 .5564 .20296 .55662 Mtetra
.593 .948 .887 r
.20296 .55662 .20426 .5564 .20607 .55471 .2047 .55569 Mtetra
.972 .924 .678 r
.2047 .55569 .20607 .55471 .20823 .54927 .20674 .55162 Mtetra
.948 .693 .516 r
.20674 .55162 .20823 .54927 .22881 .34668 .2274 .34903 Mtetra
.998 .833 .552 r
.2274 .34903 .22881 .34668 .23093 .34064 .22985 .3395 Mtetra
.831 .753 .777 r
.22985 .3395 .23093 .34064 .23265 .33884 .23159 .33748 Mtetra
.655 .688 .869 r
.23159 .33748 .23265 .33884 .23426 .3382 .23319 .33691 Mtetra
.527 .651 .914 r
.23319 .33691 .23426 .3382 .23584 .33794 .23476 .33682 Mtetra
.682 .737 .893 r
.23476 .33682 .23584 .33794 .23748 .33708 .23638 .33615 Mtetra
.711 .782 .907 r
.23638 .33615 .23748 .33708 .23911 .33618 .23801 .33537 Mtetra
.565 .77 .975 r
.23801 .33537 .23911 .33618 .2407 .33588 .23959 .33507 Mtetra
.725 .209 0 r
.23959 .33507 .2407 .33588 .24203 .33842 .24099 .33685 Mtetra
.96 .65 .392 r
.24099 .33685 .24203 .33842 .22564 .54016 .24162 .34734 Mtetra
0 0 .133 r
.24162 .34734 .22564 .54016 .22656 .5486 .22566 .54455 Mtetra
.134 .163 .625 r
.22566 .54455 .22656 .5486 .22813 .54981 .22714 .54679 Mtetra
.481 .447 .743 r
.22714 .54679 .22813 .54981 .22984 .54934 .22878 .54712 Mtetra
.572 .56 .802 r
.22878 .54712 .22984 .54934 .23161 .54827 .23047 .54691 Mtetra
.485 .635 .92 r
.23047 .54691 .23161 .54827 .23336 .54742 .23215 .54693 Mtetra
.375 .773 .986 r
.23215 .54693 .23336 .54742 .23511 .54657 .23383 .5468 Mtetra
.504 .91 .861 r
.23383 .5468 .23511 .54657 .23691 .54509 .23558 .54599 Mtetra
.947 .959 .704 r
.23558 .54599 .23691 .54509 .23896 .54072 .23754 .54269 Mtetra
.981 .765 .539 r
.23754 .54269 .23896 .54072 .2577 .33879 .24069 .52543 Mtetra
0 0 .116 r
.24069 .52543 .2577 .33879 .25994 .33092 .25884 .33017 Mtetra
.886 .8 .759 r
.25884 .33017 .25994 .33092 .2617 .32877 .26063 .32757 Mtetra
.685 .725 .88 r
.26063 .32757 .2617 .32877 .26333 .32811 .26227 .32687 Mtetra
.548 .669 .917 r
.26227 .32687 .26333 .32811 .26493 .32791 .26386 .3267 Mtetra
.676 .723 .885 r
.26386 .3267 .26493 .32791 .26656 .32727 .2655 .32605 Mtetra
.714 .73 .863 r
.2655 .32605 .26656 .32727 .26821 .32644 .26715 .32518 Mtetra
.579 .679 .908 r
.26715 .32518 .26821 .32644 .26982 .32612 .26875 .32491 Mtetra
.793 .332 0 r
.26875 .32491 .26982 .32612 .27125 .328 .27013 .32743 Mtetra
.95 .684 .498 r
.27013 .32743 .27125 .328 .25745 .52028 .25543 .53013 Mtetra
.719 .432 .49 r
.25543 .53013 .25745 .52028 .25786 .53637 .25651 .5377 Mtetra
.662 .235 .222 r
.25651 .5377 .25786 .53637 .25942 .53805 .2581 .53905 Mtetra
.151 0 0 r
.2581 .53905 .25942 .53805 .26115 .53763 .25984 .53863 Mtetra
0 0 0 r
.25984 .53863 .26115 .53763 .26293 .53662 .26161 .5377 Mtetra
.26161 .5377 .26293 .53662 .26469 .53573 .26337 .53687 Mtetra
.109 0 0 r
.26337 .53687 .26469 .53573 .26644 .53513 .26512 .53628 Mtetra
.124 0 0 r
.26512 .53628 .26644 .53513 .26819 .53455 .26687 .53571 Mtetra
.166 0 0 r
.26687 .53571 .26819 .53455 .26993 .53401 .26861 .53522 Mtetra
.207 0 0 r
.26861 .53522 .26993 .53401 .27168 .5335 .27035 .53478 Mtetra
.225 0 0 r
.27035 .53478 .27168 .5335 .27342 .533 .27209 .53435 Mtetra
.322 0 0 r
.27209 .53435 .27342 .533 .27514 .53281 .27382 .53413 Mtetra
.318 0 0 r
.27382 .53413 .27514 .53281 .27686 .53267 .27555 .53392 Mtetra
.072 0 0 r
.27555 .53392 .27686 .53267 .27863 .53194 .27731 .53319 Mtetra
.794 .956 .629 r
.27731 .53319 .27863 .53194 .28056 .52894 .27922 .53058 Mtetra
.996 .837 .566 r
.27922 .53058 .28056 .52894 .28378 .50813 .28155 .52203 Mtetra
.968 .709 .488 r
.28155 .52203 .28378 .50813 .29915 .31793 .29804 .31746 Mtetra
.929 .815 .712 r
.29804 .31746 .29915 .31793 .30096 .31508 .29991 .31388 Mtetra
.708 .736 .873 r
.29991 .31388 .30096 .31508 .30263 .31432 .30158 .31305 Mtetra
.556 .671 .914 r
.30158 .31305 .30263 .31432 .30425 .31409 .3032 .31286 Mtetra
.558 .678 .919 r
.3032 .31286 .30425 .31409 .30588 .31385 .30483 .31266 Mtetra
.648 .718 .899 r
.30483 .31266 .30588 .31385 .30753 .31334 .30648 .31212 Mtetra
.651 .715 .895 r
.30648 .31212 .30753 .31334 .30918 .31281 .30813 .31157 Mtetra
.66 .715 .889 r
.30813 .31157 .30918 .31281 .31083 .31223 .30979 .31098 Mtetra
.671 .716 .883 r
.30979 .31098 .31083 .31223 .31249 .31159 .31145 .31033 Mtetra
.68 .718 .878 r
.31145 .31033 .31249 .31159 .31416 .31092 .31311 .30964 Mtetra
.691 .719 .87 r
.31311 .30964 .31416 .31092 .31582 .31022 .31478 .30889 Mtetra
.699 .712 .858 r
.31478 .30889 .31582 .31022 .31749 .3095 .31646 .30807 Mtetra
.695 .696 .847 r
.31646 .30807 .31749 .3095 .31916 .30877 .31813 .30726 Mtetra
.693 .684 .836 r
.31813 .30726 .31916 .30877 .32083 .30804 .31981 .30643 Mtetra
.687 .669 .827 r
.31981 .30643 .32083 .30804 .3225 .3073 .32149 .30562 Mtetra
.662 .651 .828 r
.32149 .30562 .3225 .3073 .32418 .30656 .32316 .30495 Mtetra
.636 .648 .845 r
.32316 .30495 .32418 .30656 .32586 .30563 .32481 .30443 Mtetra
.57 .692 .924 r
.32481 .30443 .32586 .30563 .32756 .30457 .32646 .30419 Mtetra
0 .494 .785 r
.32646 .30419 .32756 .30457 .32922 .30397 .32807 .30454 Mtetra
.805 .381 .239 r
.32807 .30454 .32922 .30397 .3308 .30481 .32954 .30714 Mtetra
.952 .68 .485 r
.32954 .30714 .3308 .30481 .33207 .3107 .31865 .50949 Mtetra
.538 .306 .51 r
.31865 .50949 .33207 .3107 .32132 .5138 .31996 .51653 Mtetra
.653 .286 .336 r
.31996 .51653 .32132 .5138 .32286 .51706 .3216 .51822 Mtetra
.254 0 0 r
.3216 .51822 .32286 .51706 .32463 .51675 .32337 .51791 Mtetra
.002 0 0 r
.32337 .51791 .32463 .51675 .32644 .51583 .32517 .51708 Mtetra
.024 0 0 r
.32517 .51708 .32644 .51583 .32822 .51519 .32697 .51623 Mtetra
.122 0 0 r
.32697 .51623 .32822 .51519 .32996 .51542 .32876 .51571 Mtetra
.314 .799 .759 r
.32876 .51571 .32996 .51542 .33171 .51558 .33055 .51508 Mtetra
.716 .896 .961 r
.33055 .51508 .33171 .51558 .33347 .51546 .33236 .51416 Mtetra
.771 .75 .834 r
.33236 .51416 .33347 .51546 .33526 .51497 .3342 .51277 Mtetra
.736 .645 .758 r
.3342 .51277 .33526 .51497 .33705 .51436 .33605 .51123 Mtetra
.662 .552 .72 r
.33605 .51123 .33705 .51436 .33884 .51389 .33787 .51012 Mtetra
.555 .461 .703 r
.33787 .51012 .33884 .51389 .34062 .51368 .33964 .50999 Mtetra
.602 .493 .703 r
.33964 .50999 .34062 .51368 .34242 .51304 .34144 .5094 Mtetra
.738 .578 .675 r
.34144 .5094 .34242 .51304 .34428 .51114 .34334 .50683 Mtetra
.954 .686 .489 r
.34334 .50683 .34428 .51114 .34637 .50514 .3559 .30699 Mtetra
.553 .323 .52 r
.3559 .30699 .34637 .50514 .35904 .29992 .35823 .2944 Mtetra
.708 .516 .628 r
.35823 .2944 .35904 .29992 .361 .29422 .36005 .29129 Mtetra
.642 .542 .725 r
.36005 .29129 .361 .29422 .36274 .29249 .36175 .29046 Mtetra
.593 .581 .808 r
.36175 .29046 .36274 .29249 .36446 .29146 .36343 .29013 Mtetra
.56 .664 .907 r
.36343 .29013 .36446 .29146 .36615 .29075 .3651 .28993 Mtetra
.646 .801 .958 r
.3651 .28993 .36615 .29075 .36784 .29011 .36679 .28937 Mtetra
.65 .823 .967 r
.36679 .28937 .36784 .29011 .36953 .28958 .36848 .28878 Mtetra
.674 .815 .951 r
.36848 .28878 .36953 .28958 .37122 .28909 .37018 .28812 Mtetra
.704 .784 .913 r
.37018 .28812 .37122 .28909 .37291 .28856 .37188 .28733 Mtetra
.682 .728 .885 r
.37188 .28733 .37291 .28856 .3746 .28801 .37358 .28662 Mtetra
.626 .681 .882 r
.37358 .28662 .3746 .28801 .3763 .28741 .37527 .28617 Mtetra
.459 .636 .931 r
.37527 .28617 .3763 .28741 .378 .2867 .37694 .28623 Mtetra
.084 .596 .887 r
.37694 .28623 .378 .2867 .3797 .28598 .3786 .28648 Mtetra
.24 0 0 r
.3786 .28648 .3797 .28598 .38141 .28518 .38027 .28648 Mtetra
0 0 0 r
.38027 .28648 .38141 .28518 .38313 .28419 .38199 .28544 Mtetra
.131 0 0 r
.38199 .28544 .38313 .28419 .38483 .28358 .3837 .28477 Mtetra
.585 .128 .135 r
.3837 .28477 .38483 .28358 .38649 .28396 .38534 .28559 Mtetra
.958 .681 .468 r
.38534 .28559 .38649 .28396 .38798 .28823 .37832 .48174 Mtetra
.553 .317 .512 r
.37832 .48174 .38798 .28823 .38077 .49273 .37946 .49637 Mtetra
.686 .34 .384 r
.37946 .49637 .38077 .49273 .38235 .49778 .38114 .49901 Mtetra
.355 0 0 r
.38114 .49901 .38235 .49778 .38415 .49771 .38295 .49894 Mtetra
.129 0 0 r
.38295 .49894 .38415 .49771 .38598 .49691 .38478 .49829 Mtetra
.075 0 0 r
.38478 .49829 .38598 .49691 .38782 .49606 .38662 .49742 Mtetra
.191 0 0 r
.38662 .49742 .38782 .49606 .38961 .49626 .38844 .49683 Mtetra
0 0 0 r
.38844 .49683 .38961 .49626 .39141 .49643 .39028 .49613 Mtetra
.68 .933 .968 r
.39028 .49613 .39141 .49643 .39322 .49642 .39212 .49523 Mtetra
.774 .775 .853 r
.39212 .49523 .39322 .49642 .39504 .49602 .39399 .49388 Mtetra
.736 .652 .766 r
.39399 .49388 .39504 .49602 .39687 .4955 .39585 .49236 Mtetra
.682 .565 .716 r
.39585 .49236 .39687 .4955 .39871 .49494 .39772 .491 Mtetra
.557 .457 .697 r
.39772 .491 .39871 .49494 .40053 .49468 .39954 .49083 Mtetra
.592 .483 .698 r
.39954 .49083 .40053 .49468 .40237 .49403 .40137 .49032 Mtetra
.692 .549 .687 r
.40137 .49032 .40237 .49403 .40424 .4925 .40325 .48856 Mtetra
.898 .66 .57 r
.40325 .48856 .40424 .4925 .40625 .4872 .40553 .47585 Mtetra
.952 .677 .479 r
.40553 .47585 .40625 .4872 .41532 .2816 .4145 .27496 Mtetra
.712 .507 .61 r
.4145 .27496 .41532 .2816 .41728 .27427 .41634 .27101 Mtetra
.655 .535 .706 r
.41634 .27101 .41728 .27427 .41903 .27297 .41808 .26994 Mtetra
.605 .516 .727 r
.41808 .26994 .41903 .27297 .42075 .27249 .4198 .26942 Mtetra
.574 .496 .729 r
.4198 .26942 .42075 .27249 .42246 .27239 .42152 .26915 Mtetra
.612 .51 .714 r
.42152 .26915 .42246 .27239 .42419 .27178 .42324 .26853 Mtetra
.61 .509 .714 r
.42324 .26853 .42419 .27178 .42592 .27119 .42497 .26793 Mtetra
.609 .507 .713 r
.42497 .26793 .42592 .27119 .42765 .27062 .4267 .26733 Mtetra
.61 .507 .712 r
.4267 .26733 .42765 .27062 .42937 .27016 .42843 .26673 Mtetra
.606 .498 .705 r
.42843 .26673 .42937 .27016 .4311 .2696 .43016 .26614 Mtetra
.603 .495 .704 r
.43016 .26614 .4311 .2696 .43284 .26883 .43189 .26557 Mtetra
.6 .502 .715 r
.43189 .26557 .43284 .26883 .4346 .26745 .43362 .26505 Mtetra
.615 .562 .772 r
.43362 .26505 .4346 .26745 .43635 .2661 .43536 .26455 Mtetra
.634 .663 .861 r
.43536 .26455 .43635 .2661 .43811 .26492 .43709 .26404 Mtetra
.647 .796 .954 r
.43709 .26404 .43811 .26492 .43984 .26421 .43883 .26346 Mtetra
.648 .827 .969 r
.43883 .26346 .43984 .26421 .44158 .26363 .44056 .26286 Mtetra
.656 .825 .964 r
.44056 .26286 .44158 .26363 .44332 .2631 .4423 .26223 Mtetra
.661 .803 .951 r
.4423 .26223 .44332 .2631 .44506 .26247 .44405 .26161 Mtetra
.668 .805 .949 r
.44405 .26161 .44506 .26247 .4468 .26184 .44579 .26095 Mtetra
.676 .803 .943 r
.44579 .26095 .4468 .26184 .44854 .26121 .44753 .26027 Mtetra
.717 .802 .917 r
.44753 .26027 .44854 .26121 .45029 .26061 .44928 .2594 Mtetra
.697 .744 .888 r
.44928 .2594 .45029 .26061 .45203 .26 .45103 .25861 Mtetra
.661 .7 .875 r
.45103 .25861 .45203 .26 .45378 .25937 .45278 .25797 Mtetra
.622 .683 .887 r
.45278 .25797 .45378 .25937 .45553 .25825 .45452 .25751 Mtetra
.382 .72 .988 r
.45452 .25751 .45553 .25825 .45729 .25742 .45626 .25751 Mtetra
.524 0 0 r
.45626 .25751 .45729 .25742 .45903 .25718 .45798 .25838 Mtetra
.901 .552 .373 r
.45798 .25838 .45903 .25718 .46071 .25994 .45954 .26669 Mtetra
.959 .673 .451 r
.45954 .26669 .46071 .25994 .45838 .46097 .4571 .46993 Mtetra
.639 .343 .453 r
.4571 .46993 .45838 .46097 .46001 .47202 .45889 .47348 Mtetra
.402 0 .041 r
.45889 .47348 .46001 .47202 .46186 .47323 .46076 .47349 Mtetra
.381 .84 .778 r
.46076 .47349 .46186 .47323 .46372 .4733 .46264 .47271 Mtetra
.756 .896 .94 r
.46264 .47271 .46372 .4733 .4656 .47287 .46453 .47159 Mtetra
.618 .72 .918 r
.46453 .47159 .4656 .47287 .46748 .47232 .46641 .47111 Mtetra
.614 .731 .93 r
.46641 .47111 .46748 .47232 .46936 .47163 .46829 .47064 Mtetra
.646 .787 .949 r
.46829 .47064 .46936 .47163 .47125 .47089 .47018 .47002 Mtetra
.69 .827 .948 r
.47018 .47002 .47125 .47089 .47312 .47086 .47207 .46922 Mtetra
.739 .708 .822 r
.47207 .46922 .47312 .47086 .47501 .47054 .47397 .46795 Mtetra
.761 .636 .722 r
.47397 .46795 .47501 .47054 .4769 .46946 .47588 .46578 Mtetra
.875 .652 .598 r
.47588 .46578 .4769 .46946 .47886 .46411 .47787 .45769 Mtetra
.964 .683 .453 r
.47787 .45769 .47886 .46411 .48354 .25512 .48258 .25195 Mtetra
.836 .64 .638 r
.48258 .25195 .48354 .25512 .4854 .24819 .48441 .24716 Mtetra
.796 .8 .855 r
.48441 .24716 .4854 .24819 .48717 .24665 .48618 .24575 Mtetra
.649 .795 .952 r
.48618 .24575 .48717 .24665 .48894 .24614 .48795 .24516 Mtetra
.551 .741 .964 r
.48795 .24516 .48894 .24614 .4907 .24605 .48972 .24489 Mtetra
.687 .753 .902 r
.48972 .24489 .4907 .24605 .49247 .24552 .49149 .24414 Mtetra
.687 .714 .869 r
.49149 .24414 .49247 .24552 .49425 .24487 .49327 .24335 Mtetra
.657 .681 .861 r
.49327 .24335 .49425 .24487 .49602 .2442 .49504 .24271 Mtetra
.625 .673 .876 r
.49504 .24271 .49602 .2442 .4978 .24311 .49681 .24224 Mtetra
.452 .721 .983 r
.49681 .24224 .4978 .24311 .49958 .24222 .49858 .24217 Mtetra
.422 0 0 r
.49858 .24217 .49958 .24222 .50135 .24188 .50035 .2429 Mtetra
.884 .509 .326 r
.50035 .2429 .50135 .24188 .50311 .24413 .50208 .24906 Mtetra
.964 .674 .434 r
.50208 .24906 .50311 .24413 .50362 .43761 .50245 .45458 Mtetra
.602 .331 .479 r
.50245 .45458 .50362 .43761 .5054 .45697 .50433 .45866 Mtetra
.519 .079 .143 r
.50433 .45866 .5054 .45697 .50729 .45857 .50623 .45917 Mtetra
0 0 0 r
.50623 .45917 .50729 .45857 .5092 .45867 .50814 .45862 Mtetra
.656 .965 .919 r
.50814 .45862 .5092 .45867 .51111 .45825 .51006 .45755 Mtetra
.715 .872 .955 r
.51006 .45755 .51111 .45825 .51302 .45816 .51197 .4566 Mtetra
.74 .722 .835 r
.51197 .4566 .51302 .45816 .51493 .45782 .51389 .45536 Mtetra
.763 .646 .733 r
.51389 .45536 .51493 .45782 .51685 .45681 .51581 .45328 Mtetra
.867 .652 .609 r
.51581 .45328 .51685 .45681 .51877 .45322 .51774 .44633 Mtetra
.967 .682 .44 r
.51774 .44633 .51877 .45322 .52071 .43966 .51999 .23896 Mtetra
.536 .309 .517 r
.51999 .23896 .52071 .43966 .52276 .23762 .52179 .23372 Mtetra
.677 .528 .676 r
.52179 .23372 .52276 .23762 .52455 .23475 .52358 .2321 Mtetra
.617 .548 .754 r
.52358 .2321 .52455 .23475 .52634 .23346 .52537 .23152 Mtetra
.564 .584 .832 r
.52537 .23152 .52634 .23346 .52814 .23266 .52717 .23133 Mtetra
.642 .709 .895 r
.52717 .23133 .52814 .23266 .52993 .23195 .52896 .23078 Mtetra
.675 .75 .908 r
.52896 .23078 .52993 .23195 .53173 .2313 .53076 .23008 Mtetra
.652 .733 .908 r
.53076 .23008 .53173 .2313 .53353 .23071 .53256 .22948 Mtetra
.637 .726 .912 r
.53256 .22948 .53353 .23071 .53533 .22968 .53436 .22894 Mtetra
.488 .776 .995 r
.53436 .22894 .53533 .22968 .53712 .22872 .53616 .22872 Mtetra
.316 0 0 r
.53616 .22872 .53712 .22872 .53893 .22828 .53797 .22923 Mtetra
.86 .46 .279 r
.53797 .22923 .53893 .22828 .54074 .23006 .5398 .23397 Mtetra
.968 .674 .418 r
.5398 .23397 .54074 .23006 .54261 .24074 .54274 .44062 Mtetra
.533 .301 .509 r
.54274 .44062 .54261 .24074 .54572 .44331 .54471 .4453 Mtetra
.554 .133 .198 r
.54471 .4453 .54572 .44331 .54767 .44542 .54665 .44604 Mtetra
0 0 0 r
.54665 .44604 .54767 .44542 .54962 .4456 .54859 .44546 Mtetra
.689 .968 .931 r
.54859 .44546 .54962 .4456 .55156 .44522 .55053 .44434 Mtetra
.722 .839 .937 r
.55053 .44434 .55156 .44522 .55351 .44515 .55247 .44336 Mtetra
.709 .686 .825 r
.55247 .44336 .55351 .44515 .55545 .44493 .55441 .44227 Mtetra
.735 .623 .734 r
.55441 .44227 .55545 .44493 .55739 .44398 .55634 .44047 Mtetra
.842 .641 .63 r
.55634 .44047 .55739 .44398 .5593 .44012 .55824 .43509 Mtetra
.971 .683 .424 r
.55824 .43509 .5593 .44012 .55896 .23415 .55794 .22721 Mtetra
.769 .542 .59 r
.55794 .22721 .55896 .23415 .56065 .22205 .55969 .22079 Mtetra
.84 .777 .791 r
.55969 .22079 .56065 .22205 .56245 .21967 .56149 .21875 Mtetra
.676 .806 .944 r
.56149 .21875 .56245 .21967 .56426 .21901 .56331 .21804 Mtetra
.557 .75 .967 r
.56331 .21804 .56426 .21901 .56609 .21885 .56514 .21773 Mtetra
.638 .751 .93 r
.56514 .21773 .56609 .21885 .56791 .21846 .56696 .21718 Mtetra
.682 .736 .892 r
.56696 .21718 .56791 .21846 .56973 .21778 .56878 .21643 Mtetra
.661 .715 .888 r
.56878 .21643 .56973 .21778 .57155 .21707 .5706 .21577 Mtetra
.646 .72 .902 r
.5706 .21577 .57155 .21707 .57337 .21597 .57243 .21519 Mtetra
.534 .789 .991 r
.57243 .21519 .57337 .21597 .57519 .21488 .57426 .21487 Mtetra
.205 0 0 r
.57426 .21487 .57519 .21488 .57702 .21436 .5761 .2152 Mtetra
.817 .383 .209 r
.5761 .2152 .57702 .21436 .57889 .21621 .578 .21857 Mtetra
.971 .674 .4 r
.578 .21857 .57889 .21621 .58441 .41664 .58358 .42536 Mtetra
.699 .39 .449 r
.58358 .42536 .58441 .41664 .58667 .43204 .58567 .43136 Mtetra
.458 0 0 r
.58567 .43136 .58667 .43204 .58869 .434 .58768 .43287 Mtetra
.481 .699 .965 r
.58768 .43287 .58869 .434 .59066 .43381 .58966 .43279 Mtetra
.742 .821 .913 r
.58966 .43279 .59066 .43381 .59262 .43259 .59162 .43169 Mtetra
.935 .828 .715 r
.59162 .43169 .59262 .43259 .59454 .42945 .59353 .42807 Mtetra
.976 .685 .404 r
.59353 .42807 .59454 .42945 .59632 .42008 .59112 .22585 Mtetra
.56 .327 .519 r
.59112 .22585 .59632 .42008 .59361 .21309 .59261 .20916 Mtetra
.737 .565 .659 r
.59261 .20916 .59361 .21309 .59538 .20936 .5944 .20643 Mtetra
.628 .54 .736 r
.5944 .20643 .59538 .20936 .5972 .20793 .59624 .2057 Mtetra
.565 .556 .803 r
.59624 .2057 .5972 .20793 .59904 .20706 .59809 .20551 Mtetra
.599 .657 .879 r
.59809 .20551 .59904 .20706 .60088 .20634 .59994 .20513 Mtetra
.675 .749 .907 r
.59994 .20513 .60088 .20634 .60272 .20565 .60178 .20441 Mtetra
.659 .738 .908 r
.60178 .20441 .60272 .20565 .60457 .20502 .60363 .20377 Mtetra
.644 .73 .911 r
.60363 .20377 .60457 .20502 .6064 .20403 .60548 .20319 Mtetra
.56 .785 .983 r
.60548 .20319 .6064 .20403 .60824 .20291 .60733 .20282 Mtetra
.092 0 0 r
.60733 .20282 .60824 .20291 .61009 .20232 .60921 .20304 Mtetra
.782 .319 .143 r
.60921 .20304 .61009 .20232 .612 .20373 .61115 .20574 Mtetra
.973 .672 .385 r
.61115 .20574 .612 .20373 .61424 .2165 .61904 .41219 Mtetra
.538 .304 .509 r
.61904 .41219 .61424 .2165 .62223 .42 .62126 .41945 Mtetra
.557 .001 0 r
.62126 .41945 .62223 .42 .62432 .42246 .62332 .42121 Mtetra
.491 .677 .948 r
.62332 .42121 .62432 .42246 .62633 .42244 .62533 .42114 Mtetra
.729 .77 .885 r
.62533 .42114 .62633 .42244 .62831 .42128 .62731 .42006 Mtetra
.908 .801 .731 r
.62731 .42006 .62831 .42128 .63021 .41786 .62922 .41679 Mtetra
.98 .729 .48 r
.62922 .41679 .63021 .41786 .63145 .39436 .63071 .4005 Mtetra
.981 .69 .373 r
.63071 .4005 .63145 .39436 .62685 .19869 .62594 .1978 Mtetra
.931 .832 .726 r
.62594 .1978 .62685 .19869 .62863 .19562 .62771 .19461 Mtetra
.715 .806 .922 r
.62771 .19461 .62863 .19562 .63049 .19478 .62957 .19371 Mtetra
.577 .741 .954 r
.62957 .19371 .63049 .19478 .63236 .19449 .63144 .19335 Mtetra
.642 .754 .93 r
.63144 .19335 .63236 .19449 .63423 .19396 .63331 .19277 Mtetra
.733 .776 .887 r
.63331 .19277 .63423 .19396 .63608 .19294 .63516 .19174 Mtetra
.632 .738 .924 r
.63516 .19174 .63608 .19294 .63795 .1924 .63703 .1912 Mtetra
0 .309 .797 r
.63703 .1912 .63795 .1924 .63989 .19361 .63897 .19244 Mtetra
.943 .585 .203 r
.63897 .19244 .63989 .19361 .64221 .2045 .64131 .20393 Mtetra
.975 .672 .365 r
.64131 .20393 .64221 .2045 .65221 .41008 .65123 .40895 Mtetra
.587 .111 0 r
.65123 .40895 .65221 .41008 .65436 .4128 .65338 .41164 Mtetra
.44 .674 .962 r
.65338 .41164 .65436 .4128 .6564 .41285 .65542 .41168 Mtetra
.73 .796 .904 r
.65542 .41168 .6564 .41285 .6584 .41179 .65742 .41061 Mtetra
.905 .812 .745 r
.65742 .41061 .6584 .41179 .66032 .40881 .65934 .40755 Mtetra
.979 .736 .499 r
.65934 .40755 .66032 .40881 .66187 .39722 .66084 .39453 Mtetra
.977 .68 .379 r
.66084 .39453 .66187 .39722 .65494 .18948 .65401 .18786 Mtetra
.893 .75 .696 r
.65401 .18786 .65494 .18948 .65669 .18586 .65577 .18437 Mtetra
.695 .714 .863 r
.65577 .18437 .65669 .18586 .65856 .1849 .65764 .1835 Mtetra
.573 .674 .908 r
.65764 .1835 .65856 .1849 .66046 .18453 .65954 .18321 Mtetra
.593 .699 .916 r
.65954 .18321 .66046 .18453 .66235 .18405 .66144 .18283 Mtetra
.721 .769 .891 r
.66144 .18283 .66235 .18405 .66421 .183 .66331 .18186 Mtetra
.643 .757 .932 r
.66331 .18186 .66421 .183 .6661 .18243 .6652 .18127 Mtetra
.203 .515 .914 r
.6652 .18127 .6661 .18243 .66807 .18346 .66715 .1819 Mtetra
.765 .362 0 r
.66715 .1819 .66807 .18346 .67052 .19445 .6693 .18677 Mtetra
.977 .675 .331 r
.6693 .18677 .67052 .19445 .68253 .40044 .68136 .39508 Mtetra
.068 .097 .582 r
.68136 .39508 .68253 .40044 .68473 .40311 .68364 .39952 Mtetra
.468 .424 .725 r
.68364 .39952 .68473 .40311 .68678 .40273 .68574 .40009 Mtetra
.56 .536 .785 r
.68574 .40009 .68678 .40273 .6888 .4017 .6878 .39991 Mtetra
.584 .637 .87 r
.6878 .39991 .6888 .4017 .69082 .40076 .68986 .39957 Mtetra
.505 .702 .958 r
.68986 .39957 .69082 .40076 .69289 .40062 .69193 .39943 Mtetra
.671 .775 .928 r
.69193 .39943 .69289 .40062 .69493 .39999 .69396 .39866 Mtetra
.862 .799 .788 r
.69396 .39866 .69493 .39999 .69689 .39784 .69592 .39628 Mtetra
.972 .741 .53 r
.69592 .39628 .69689 .39784 .6985 .38916 .69746 .38627 Mtetra
.977 .676 .363 r
.69746 .38627 .6985 .38916 .68904 .1781 .6881 .17625 Mtetra
.899 .734 .669 r
.6881 .17625 .68904 .1781 .69074 .17376 .68982 .17222 Mtetra
.703 .711 .855 r
.68982 .17222 .69074 .17376 .69262 .17271 .69171 .17127 Mtetra
.581 .673 .902 r
.69171 .17127 .69262 .17271 .69454 .17231 .69364 .17095 Mtetra
.538 .667 .92 r
.69364 .17095 .69454 .17231 .69647 .17204 .69557 .17078 Mtetra
.66 .741 .91 r
.69557 .17078 .69647 .17204 .69837 .17127 .69748 .17011 Mtetra
.67 .766 .922 r
.69748 .17011 .69837 .17127 .70028 .17056 .69939 .16939 Mtetra
.708 .779 .907 r
.69939 .16939 .70028 .17056 .70219 .16991 .70129 .16849 Mtetra
.756 .749 .846 r
.70129 .16849 .70219 .16991 .70411 .16931 .70316 .16721 Mtetra
.662 .624 .801 r
.70316 .16721 .70411 .16931 .70605 .16919 .70507 .16638 Mtetra
.478 .462 .762 r
.70507 .16638 .70605 .16919 .70809 .17044 .70705 .16676 Mtetra
0 0 .42 r
.70705 .16676 .70809 .17044 .71128 .19038 .70937 .17265 Mtetra
.97 .672 .273 r
.70937 .17265 .71128 .19038 .72549 .38607 .72447 .38366 Mtetra
0 0 .495 r
.72447 .38366 .72549 .38607 .72777 .38892 .72683 .38767 Mtetra
.388 .628 .949 r
.72683 .38767 .72777 .38892 .7299 .38923 .72895 .3879 Mtetra
.686 .759 .907 r
.72895 .3879 .7299 .38923 .73196 .38848 .73101 .38704 Mtetra
.837 .786 .802 r
.73101 .38704 .73196 .38848 .73393 .38626 .73299 .38492 Mtetra
.959 .783 .622 r
.73299 .38492 .73393 .38626 .73551 .37815 .73474 .37936 Mtetra
.977 .676 .335 r
.73474 .37936 .73551 .37815 .72352 .16585 .72295 .16933 Mtetra
0 0 0 r
.72295 .16933 .72352 .16585 .72517 .16108 .72444 .1621 Mtetra
.72444 .1621 .72517 .16108 .72707 .16 .72628 .16014 Mtetra
.574 .937 .804 r
.72628 .16014 .72707 .16 .72902 .15959 .72818 .15895 Mtetra
.674 .887 .976 r
.72818 .15895 .72902 .15959 .73098 .15943 .7301 .15812 Mtetra
.678 .743 .9 r
.7301 .15812 .73098 .15943 .73291 .15869 .73203 .15735 Mtetra
.655 .729 .904 r
.73203 .15735 .73291 .15869 .73484 .15799 .73396 .15669 Mtetra
.668 .742 .906 r
.73396 .15669 .73484 .15799 .73678 .15737 .73589 .15597 Mtetra
.759 .759 .853 r
.73589 .15597 .73678 .15737 .73872 .15676 .73779 .15469 Mtetra
.667 .633 .806 r
.73779 .15469 .73872 .15676 .74069 .15659 .73971 .15383 Mtetra
.517 .491 .766 r
.73971 .15383 .74069 .15659 .74275 .15752 .74171 .15395 Mtetra
0 0 .473 r
.74171 .15395 .74275 .15752 .74552 .16808 .7441 .15934 Mtetra
.971 .663 .283 r
.7441 .15934 .74552 .16808 .76282 .37356 .76182 .37137 Mtetra
0 0 .426 r
.76182 .37137 .76282 .37356 .7652 .37681 .7643 .37584 Mtetra
.318 .648 .969 r
.7643 .37584 .7652 .37681 .76738 .37722 .76646 .37608 Mtetra
.685 .798 .935 r
.76646 .37608 .76738 .37722 .76947 .37656 .76854 .37523 Mtetra
.836 .806 .822 r
.76854 .37523 .76947 .37656 .77148 .37463 .77054 .37323 Mtetra
.954 .787 .636 r
.77054 .37323 .77148 .37463 .77307 .36751 .7723 .36811 Mtetra
.975 .67 .317 r
.7723 .36811 .77307 .36751 .75847 .15405 .75806 .15856 Mtetra
0 0 .029 r
.75806 .15856 .75847 .15405 .76004 .14855 .75936 .14963 Mtetra
0 0 0 r
.75936 .14963 .76004 .14855 .76195 .14733 .7612 .1474 Mtetra
.655 .969 .821 r
.7612 .1474 .76195 .14733 .76392 .14684 .7631 .14605 Mtetra
.705 .867 .958 r
.7631 .14605 .76392 .14684 .76591 .14668 .76503 .14513 Mtetra
.718 .723 .854 r
.76503 .14513 .76591 .14668 .76783 .14551 .76696 .14407 Mtetra
.642 .707 .894 r
.76696 .14407 .76783 .14551 .76978 .14473 .76892 .14347 Mtetra
.441 .637 .939 r
.76892 .14347 .76978 .14473 .7718 .14475 .77095 .14358 Mtetra
.747 .319 0 r
.77095 .14358 .7718 .14475 .77443 .15209 .77336 .1483 Mtetra
.969 .656 .282 r
.77336 .1483 .77443 .15209 .79436 .36385 .79312 .3586 Mtetra
.086 .118 .598 r
.79312 .3586 .79436 .36385 .79681 .36711 .79567 .36315 Mtetra
.914 .661 .543 r
.12539 .55929 .12439 .57889 .12662 .57346 .14887 .37316 Mtetra
.537 .31 .517 r
.14887 .37316 .12662 .57346 .15173 .37214 .15096 .36809 Mtetra
.739 .561 .653 r
.15096 .36809 .15173 .37214 .1539 .36634 .15281 .36511 Mtetra
.773 .73 .813 r
.15281 .36511 .1539 .36634 .15555 .36497 .15446 .36377 Mtetra
.706 .722 .862 r
.15446 .36377 .15555 .36497 .15713 .36428 .15605 .36297 Mtetra
.589 .666 .892 r
.15605 .36297 .15713 .36428 .15866 .36402 .15758 .36269 Mtetra
0 .341 .821 r
.15758 .36269 .15866 .36402 .1602 .36361 .15898 .36354 Mtetra
.826 .387 .19 r
.15898 .36354 .1602 .36361 .1617 .3636 .16022 .36579 Mtetra
.863 .56 .474 r
.16022 .36579 .1617 .3636 .16312 .36436 .16073 .37451 Mtetra
.924 .666 .529 r
.16073 .37451 .16312 .36436 .16392 .37052 .14023 .56854 Mtetra
.531 .3 .509 r
.14023 .56854 .16392 .37052 .14298 .56997 .14145 .57194 Mtetra
.647 .262 .301 r
.14145 .57194 .14298 .56997 .14414 .5739 .1429 .57325 Mtetra
.571 .815 .991 r
.1429 .57325 .14414 .5739 .14574 .57395 .14456 .57287 Mtetra
.729 .761 .878 r
.14456 .57287 .14574 .57395 .14744 .57312 .14627 .57192 Mtetra
.76 .745 .839 r
.14627 .57192 .14744 .57312 .14919 .57186 .14802 .57068 Mtetra
.697 .739 .884 r
.14802 .57068 .14919 .57186 .15089 .57107 .14971 .5699 Mtetra
.669 .735 .9 r
.14971 .5699 .15089 .57107 .15258 .57037 .1514 .56927 Mtetra
.647 .74 .917 r
.1514 .56927 .15258 .57037 .15426 .56975 .15307 .56873 Mtetra
.618 .749 .939 r
.15307 .56873 .15426 .56975 .15593 .56927 .15473 .5683 Mtetra
.589 .751 .955 r
.15473 .5683 .15593 .56927 .15758 .56886 .15638 .56795 Mtetra
.561 .753 .967 r
.15638 .56795 .15758 .56886 .15924 .56852 .15803 .56766 Mtetra
.345 .674 .977 r
.15803 .56766 .15924 .56852 .16087 .56837 .15964 .56777 Mtetra
.392 .757 .993 r
.15964 .56777 .16087 .56837 .16252 .56816 .16127 .56768 Mtetra
.615 .867 .99 r
.16127 .56768 .16252 .56816 .16418 .56776 .16295 .56713 Mtetra
.88 .818 .784 r
.16295 .56713 .16418 .56776 .16592 .56668 .16483 .56469 Mtetra
.858 .688 .67 r
.16483 .56469 .16592 .56668 .16769 .56529 .16694 .56012 Mtetra
.935 .682 .529 r
.16694 .56012 .16769 .56529 .16947 .5638 .18817 .37398 Mtetra
.55 .321 .52 r
.18817 .37398 .16947 .5638 .17111 .56361 .19079 .36362 Mtetra
.52 .295 .513 r
.19079 .36362 .17111 .56361 .17276 .5634 .1921 .36576 Mtetra
.525 .3 .515 r
.1921 .36576 .17276 .5634 .1745 .56237 .19365 .3656 Mtetra
.551 .321 .52 r
.19365 .3656 .1745 .56237 .17688 .55503 .19632 .35463 Mtetra
.535 .308 .517 r
.19632 .35463 .17688 .55503 .19915 .3538 .1983 .35025 Mtetra
.741 .574 .667 r
.1983 .35025 .19915 .3538 .20116 .34903 .2001 .34763 Mtetra
.759 .709 .805 r
.2001 .34763 .20116 .34903 .20287 .34728 .20177 .34633 Mtetra
.687 .768 .913 r
.20177 .34633 .20287 .34728 .20448 .34657 .20337 .34566 Mtetra
.522 .729 .968 r
.20337 .34566 .20448 .34657 .206 .34664 .20492 .34549 Mtetra
0 .259 .752 r
.20492 .34549 .206 .34664 .20732 .34886 .20635 .34646 Mtetra
0 0 .461 r
.20635 .34646 .20732 .34886 .2075 .36242 .20765 .34891 Mtetra
.162 .049 .467 r
.20765 .34891 .2075 .36242 .1898 .55647 .2085 .35583 Mtetra
.473 .255 .502 r
.2085 .35583 .1898 .55647 .19133 .55763 .20806 .37581 Mtetra
.561 .33 .523 r
.20806 .37581 .19133 .55763 .19303 .55709 .21106 .36121 Mtetra
.527 .301 .515 r
.21106 .36121 .19303 .55709 .19477 .55611 .2127 .36026 Mtetra
0 0 .149 r
.2127 .36026 .19477 .55611 .19641 .55612 .19587 .54859 Mtetra
.06 .02 .494 r
.19587 .54859 .19641 .55612 .19803 .55643 .19707 .55318 Mtetra
.031 .135 .64 r
.19707 .55318 .19803 .55643 .19966 .55662 .19852 .55525 Mtetra
.099 .419 .866 r
.19852 .55525 .19966 .55662 .20129 .55682 .20009 .55601 Mtetra
.457 .741 .989 r
.20009 .55601 .20129 .55682 .20296 .55662 .20176 .5559 Mtetra
.746 .838 .921 r
.20176 .5559 .20296 .55662 .2047 .55569 .20351 .55491 Mtetra
.911 .774 .696 r
.20351 .55491 .2047 .55569 .20674 .55162 .20556 .55074 Mtetra
.945 .688 .518 r
.20556 .55074 .20674 .55162 .2274 .34903 .22637 .34725 Mtetra
.909 .698 .605 r
.22637 .34725 .2274 .34903 .22985 .3395 .22879 .33811 Mtetra
.81 .722 .768 r
.22879 .33811 .22985 .3395 .23159 .33748 .23052 .33617 Mtetra
.637 .689 .882 r
.23052 .33617 .23159 .33748 .23319 .33691 .23212 .33569 Mtetra
.481 .644 .929 r
.23212 .33569 .23319 .33691 .23476 .33682 .23368 .3357 Mtetra
.644 .727 .909 r
.23368 .3357 .23476 .33682 .23638 .33615 .23528 .3352 Mtetra
.693 .773 .913 r
.23528 .3352 .23638 .33615 .23801 .33537 .2369 .3345 Mtetra
.618 .772 .954 r
.2369 .3345 .23801 .33537 .23959 .33507 .2385 .33406 Mtetra
.128 .505 .909 r
.2385 .33406 .23959 .33507 .24099 .33685 .24002 .33457 Mtetra
0 .069 .628 r
.24002 .33457 .24099 .33685 .24162 .34734 .24141 .33644 Mtetra
.139 .046 .478 r
.24141 .33644 .24162 .34734 .22566 .54455 .24245 .34239 Mtetra
0 0 .163 r
.24245 .34239 .22566 .54455 .22714 .54679 .22654 .53935 Mtetra
.116 .065 .517 r
.22654 .53935 .22714 .54679 .22878 .54712 .22783 .54359 Mtetra
.193 .229 .671 r
.22783 .54359 .22878 .54712 .23047 .54691 .22935 .54533 Mtetra
.191 .437 .866 r
.22935 .54533 .23047 .54691 .23215 .54693 .23096 .54607 Mtetra
.42 .715 .985 r
.23096 .54607 .23215 .54693 .23383 .5468 .23264 .54605 Mtetra
.713 .833 .939 r
.23264 .54605 .23383 .5468 .23558 .54599 .2344 .54521 Mtetra
.9 .792 .732 r
.2344 .54521 .23558 .54599 .23754 .54269 .23636 .54192 Mtetra
.944 .719 .567 r
.23636 .54192 .23754 .54269 .24069 .52543 .23935 .52649 Mtetra
.95 .692 .51 r
.23935 .52649 .24069 .52543 .25884 .33017 .25776 .32906 Mtetra
.863 .757 .744 r
.25776 .32906 .25884 .33017 .26063 .32757 .25956 .32642 Mtetra
.687 .735 .887 r
.25956 .32642 .26063 .32757 .26227 .32687 .2612 .32571 Mtetra
.54 .685 .933 r
.2612 .32571 .26227 .32687 .26386 .3267 .26279 .32555 Mtetra
.678 .733 .892 r
.26279 .32555 .26386 .3267 .2655 .32605 .26443 .32489 Mtetra
.718 .743 .871 r
.26443 .32489 .2655 .32605 .26715 .32518 .26608 .32401 Mtetra
.576 .697 .924 r
.26608 .32401 .26715 .32518 .26875 .32491 .26768 .32375 Mtetra
.805 .344 0 r
.26768 .32375 .26875 .32491 .27013 .32743 .26906 .32629 Mtetra
.95 .685 .498 r
.26906 .32629 .27013 .32743 .25543 .53013 .25425 .52942 Mtetra
.938 .595 .353 r
.25425 .52942 .25543 .53013 .25651 .5377 .25534 .53686 Mtetra
.515 0 0 r
.25534 .53686 .25651 .5377 .2581 .53905 .25693 .5382 Mtetra
.599 .787 .97 r
.25693 .5382 .2581 .53905 .25984 .53863 .25867 .53777 Mtetra
.728 .815 .919 r
.25867 .53777 .25984 .53863 .26161 .5377 .26044 .53685 Mtetra
.71 .813 .929 r
.26044 .53685 .26161 .5377 .26337 .53687 .26221 .53601 Mtetra
.65 .8 .955 r
.26221 .53601 .26337 .53687 .26512 .53628 .26396 .53541 Mtetra
.639 .796 .958 r
.26396 .53541 .26512 .53628 .26687 .53571 .2657 .53486 Mtetra
.601 .788 .97 r
.2657 .53486 .26687 .53571 .26861 .53522 .26744 .53442 Mtetra
.561 .788 .984 r
.26744 .53442 .26861 .53522 .27035 .53478 .26918 .53408 Mtetra
.549 .804 .992 r
.26918 .53408 .27035 .53478 .27209 .53435 .27091 .53373 Mtetra
.446 .781 .998 r
.27091 .53373 .27209 .53435 .27382 .53413 .27263 .53355 Mtetra
.457 .794 .999 r
.27263 .53355 .27382 .53413 .27555 .53392 .27436 .53333 Mtetra
.677 .865 .971 r
.27436 .53333 .27555 .53392 .27731 .53319 .27613 .53259 Mtetra
.894 .838 .782 r
.27613 .53259 .27731 .53319 .27922 .53058 .27803 .53003 Mtetra
.948 .757 .611 r
.27803 .53003 .27922 .53058 .28155 .52203 .28033 .52202 Mtetra
.953 .691 .5 r
.28033 .52202 .28155 .52203 .29804 .31746 .29697 .31646 Mtetra
.902 .763 .698 r
.29697 .31646 .29804 .31746 .29991 .31388 .29885 .31271 Mtetra
.713 .742 .874 r
.29885 .31271 .29991 .31388 .30158 .31305 .30052 .31186 Mtetra
.554 .684 .926 r
.30052 .31186 .30158 .31305 .3032 .31286 .30215 .31166 Mtetra
.561 .686 .923 r
.30215 .31166 .3032 .31286 .30483 .31266 .30377 .31144 Mtetra
.655 .717 .894 r
.30377 .31144 .30483 .31266 .30648 .31212 .30543 .31087 Mtetra
.657 .713 .889 r
.30543 .31087 .30648 .31212 .30813 .31157 .30708 .31029 Mtetra
.663 .709 .882 r
.30708 .31029 .30813 .31157 .30979 .31098 .30874 .30968 Mtetra
.671 .709 .876 r
.30874 .30968 .30979 .31098 .31145 .31033 .3104 .30903 Mtetra
.681 .711 .871 r
.3104 .30903 .31145 .31033 .31311 .30964 .31207 .30833 Mtetra
.699 .715 .861 r
.31207 .30833 .31311 .30964 .31478 .30889 .31374 .30752 Mtetra
.711 .71 .848 r
.31374 .30752 .31478 .30889 .31646 .30807 .31542 .30662 Mtetra
.705 .696 .839 r
.31542 .30662 .31646 .30807 .31813 .30726 .3171 .30573 Mtetra
.707 .687 .828 r
.3171 .30573 .31813 .30726 .31981 .30643 .31879 .3048 Mtetra
.699 .672 .82 r
.31879 .3048 .31981 .30643 .32149 .30562 .32047 .3039 Mtetra
.647 .64 .829 r
.32047 .3039 .32149 .30562 .32316 .30495 .32214 .30332 Mtetra
.462 .565 .873 r
.32214 .30332 .32316 .30495 .32481 .30443 .32375 .30348 Mtetra
.575 .058 0 r
.32375 .30348 .32481 .30443 .32646 .30419 .32528 .30508 Mtetra
.86 .492 .352 r
.32528 .30508 .32646 .30419 .32807 .30454 .32661 .30973 Mtetra
.948 .676 .488 r
.32661 .30973 .32807 .30454 .32954 .30714 .3157 .50963 Mtetra
.534 .302 .509 r
.3157 .50963 .32954 .30714 .31865 .50949 .31712 .51477 Mtetra
.624 .306 .412 r
.31712 .51477 .31865 .50949 .31996 .51653 .31875 .51672 Mtetra
.434 0 0 r
.31875 .51672 .31996 .51653 .3216 .51822 .32046 .51729 Mtetra
.594 .772 .965 r
.32046 .51729 .3216 .51822 .32337 .51791 .32224 .51688 Mtetra
.684 .778 .922 r
.32224 .51688 .32337 .51791 .32517 .51708 .32403 .51614 Mtetra
.668 .793 .941 r
.32403 .51614 .32517 .51708 .32697 .51623 .32583 .51547 Mtetra
.561 .801 .989 r
.32583 .51547 .32697 .51623 .32876 .51571 .32761 .5151 Mtetra
.644 .859 .981 r
.32761 .5151 .32876 .51571 .33055 .51508 .3294 .51445 Mtetra
.818 .87 .885 r
.3294 .51445 .33055 .51508 .33236 .51416 .33124 .51297 Mtetra
.885 .764 .724 r
.33124 .51297 .33236 .51416 .3342 .51277 .33319 .50967 Mtetra
.854 .654 .631 r
.33319 .50967 .3342 .51277 .33605 .51123 .3353 .50363 Mtetra
.95 .682 .494 r
.3353 .50363 .33605 .51123 .33787 .51012 .34786 .3122 Mtetra
.524 .299 .515 r
.34786 .3122 .33787 .51012 .33964 .50999 .3495 .31261 Mtetra
0 0 .285 r
.3495 .31261 .33964 .50999 .34144 .5094 .34161 .48501 Mtetra
.928 .657 .506 r
.34161 .48501 .34144 .5094 .34334 .50683 .35333 .30338 Mtetra
.542 .313 .518 r
.35333 .30338 .34334 .50683 .3559 .30699 .35541 .29554 Mtetra
.642 .43 .58 r
.35541 .29554 .3559 .30699 .35823 .2944 .35726 .29199 Mtetra
.755 .629 .721 r
.35726 .29199 .35823 .2944 .36005 .29129 .35902 .29005 Mtetra
.668 .721 .889 r
.35902 .29005 .36005 .29129 .36175 .29046 .36071 .28941 Mtetra
.578 .729 .946 r
.36071 .28941 .36175 .29046 .36343 .29013 .36239 .2891 Mtetra
.562 .726 .951 r
.36239 .2891 .36343 .29013 .3651 .28993 .36406 .28884 Mtetra
.653 .746 .918 r
.36406 .28884 .3651 .28993 .36679 .28937 .36575 .28827 Mtetra
.667 .749 .912 r
.36575 .28827 .36679 .28937 .36848 .28878 .36744 .28765 Mtetra
.697 .75 .893 r
.36744 .28765 .36848 .28878 .37018 .28812 .36915 .28687 Mtetra
.733 .74 .857 r
.36915 .28687 .37018 .28812 .37188 .28733 .37086 .28586 Mtetra
.684 .69 .849 r
.37086 .28586 .37188 .28733 .37358 .28662 .37257 .28509 Mtetra
.536 .618 .881 r
.37257 .28509 .37358 .28662 .37527 .28617 .37424 .285 Mtetra
0 0 .517 r
.37424 .285 .37527 .28617 .37694 .28623 .37583 .28668 Mtetra
.868 .475 .29 r
.37583 .28668 .37694 .28623 .3786 .28648 .3773 .29083 Mtetra
.954 .677 .473 r
.3773 .29083 .3786 .28648 .38027 .28648 .36989 .4848 Mtetra
.523 .293 .507 r
.36989 .4848 .38027 .28648 .38199 .28544 .37169 .48441 Mtetra
.517 .288 .506 r
.37169 .48441 .38199 .28544 .3837 .28477 .37362 .48119 Mtetra
.535 .303 .509 r
.37362 .48119 .3837 .28477 .38534 .28559 .37515 .48681 Mtetra
.538 .305 .51 r
.37515 .48681 .38534 .28559 .37832 .48174 .37662 .49405 Mtetra
.599 .321 .468 r
.37662 .49405 .37832 .48174 .37946 .49637 .37828 .49689 Mtetra
.645 .134 .017 r
.37828 .49689 .37946 .49637 .38114 .49901 .38003 .49813 Mtetra
.471 .741 .987 r
.38003 .49813 .38114 .49901 .38295 .49894 .38184 .498 Mtetra
.617 .784 .961 r
.38184 .498 .38295 .49894 .38478 .49829 .38366 .4975 Mtetra
.656 .827 .966 r
.38366 .4975 .38478 .49829 .38662 .49742 .38549 .49684 Mtetra
.573 .849 .996 r
.38549 .49684 .38662 .49742 .38844 .49683 .38732 .49635 Mtetra
.661 .894 .98 r
.38732 .49635 .38844 .49683 .39028 .49613 .38915 .49559 Mtetra
.798 .896 .913 r
.38915 .49559 .39028 .49613 .39212 .49523 .39102 .49425 Mtetra
.895 .798 .746 r
.39102 .49425 .39212 .49523 .39399 .49388 .39295 .49124 Mtetra
.858 .672 .649 r
.39295 .49124 .39399 .49388 .39585 .49236 .39496 .48616 Mtetra
.885 .635 .556 r
.39496 .48616 .39585 .49236 .39772 .491 .39745 .46855 Mtetra
.933 .657 .495 r
.39745 .46855 .39772 .491 .39954 .49083 .40554 .30379 Mtetra
0 0 .306 r
.40554 .30379 .39954 .49083 .40137 .49032 .40099 .47017 Mtetra
.939 .664 .49 r
.40099 .47017 .40137 .49032 .40325 .48856 .40954 .28832 Mtetra
.551 .321 .519 r
.40954 .28832 .40325 .48856 .40553 .47585 .41169 .27615 Mtetra
.534 .307 .516 r
.41169 .27615 .40553 .47585 .4145 .27496 .41354 .2721 Mtetra
.76 .611 .693 r
.41354 .2721 .4145 .27496 .41634 .27101 .41533 .26971 Mtetra
.711 .728 .864 r
.41533 .26971 .41634 .27101 .41808 .26994 .41706 .26881 Mtetra
.646 .741 .919 r
.41706 .26881 .41808 .26994 .4198 .26942 .41879 .26827 Mtetra
.606 .721 .927 r
.41879 .26827 .4198 .26942 .42152 .26915 .42051 .26787 Mtetra
.661 .718 .891 r
.42051 .26787 .42152 .26915 .42324 .26853 .42223 .26725 Mtetra
.659 .717 .891 r
.42223 .26725 .42324 .26853 .42497 .26793 .42396 .26664 Mtetra
.658 .714 .889 r
.42396 .26664 .42497 .26793 .4267 .26733 .42569 .26603 Mtetra
.661 .713 .886 r
.42569 .26603 .4267 .26733 .42843 .26673 .42742 .2654 Mtetra
.656 .708 .885 r
.42742 .2654 .42843 .26673 .43016 .26614 .42916 .2648 Mtetra
.648 .702 .886 r
.42916 .2648 .43016 .26614 .43189 .26557 .43089 .26423 Mtetra
.62 .693 .896 r
.43089 .26423 .43189 .26557 .43362 .26505 .43262 .26379 Mtetra
.615 .703 .908 r
.43262 .26379 .43362 .26505 .43536 .26455 .43435 .26337 Mtetra
.618 .72 .919 r
.43435 .26337 .43536 .26455 .43709 .26404 .43608 .26293 Mtetra
.65 .746 .919 r
.43608 .26293 .43709 .26404 .43883 .26346 .43782 .26235 Mtetra
.662 .751 .916 r
.43782 .26235 .43883 .26346 .44056 .26286 .43956 .26173 Mtetra
.67 .75 .911 r
.43956 .26173 .44056 .26286 .4423 .26223 .4413 .26108 Mtetra
.666 .743 .908 r
.4413 .26108 .4423 .26223 .44405 .26161 .44304 .26044 Mtetra
.673 .743 .904 r
.44304 .26044 .44405 .26161 .44579 .26095 .44478 .25977 Mtetra
.681 .743 .898 r
.44478 .25977 .44579 .26095 .44753 .26027 .44653 .25905 Mtetra
.747 .756 .86 r
.44653 .25905 .44753 .26027 .44928 .2594 .44829 .25795 Mtetra
.704 .705 .848 r
.44829 .25795 .44928 .2594 .45103 .25861 .45004 .25705 Mtetra
.63 .661 .862 r
.45004 .25705 .45103 .25861 .45278 .25797 .45178 .25655 Mtetra
.094 .388 .847 r
.45178 .25655 .45278 .25797 .45452 .25751 .4535 .25748 Mtetra
.813 .338 .078 r
.4535 .25748 .45452 .25751 .45626 .25751 .45517 .26008 Mtetra
.963 .678 .446 r
.45517 .26008 .45626 .25751 .45798 .25838 .45275 .44903 Mtetra
.561 .324 .513 r
.45275 .44903 .45798 .25838 .45954 .26669 .45418 .46855 Mtetra
.53 .298 .508 r
.45418 .46855 .45954 .26669 .4571 .46993 .45597 .47154 Mtetra
.622 .188 .197 r
.45597 .47154 .4571 .46993 .45889 .47348 .45781 .47274 Mtetra
.542 .805 .994 r
.45781 .47274 .45889 .47348 .46076 .47349 .45969 .47237 Mtetra
.699 .778 .913 r
.45969 .47237 .46076 .47349 .46264 .47271 .46157 .47153 Mtetra
.731 .773 .887 r
.46157 .47153 .46264 .47271 .46453 .47159 .46346 .47048 Mtetra
.536 .722 .959 r
.46346 .47048 .46453 .47159 .46641 .47111 .46534 .47026 Mtetra
.54 .78 .987 r
.46534 .47026 .46641 .47111 .46829 .47064 .46722 .46993 Mtetra
.663 .855 .973 r
.46722 .46993 .46829 .47064 .47018 .47002 .46911 .4692 Mtetra
.879 .844 .806 r
.46911 .4692 .47018 .47002 .47207 .46922 .47102 .46692 Mtetra
.856 .689 .675 r
.47102 .46692 .47207 .46922 .47397 .46795 .47296 .46286 Mtetra
.889 .642 .56 r
.47296 .46286 .47397 .46795 .47588 .46578 .47505 .44924 Mtetra
.952 .67 .466 r
.47505 .44924 .47588 .46578 .47787 .45769 .47981 .25211 Mtetra
.534 .306 .516 r
.47981 .25211 .47787 .45769 .48258 .25195 .48163 .24809 Mtetra
.718 .554 .666 r
.48163 .24809 .48258 .25195 .48441 .24716 .48342 .24578 Mtetra
.73 .729 .85 r
.48342 .24578 .48441 .24716 .48618 .24575 .48519 .24473 Mtetra
.656 .771 .934 r
.48519 .24473 .48618 .24575 .48795 .24516 .48696 .24412 Mtetra
.609 .752 .946 r
.48696 .24412 .48795 .24516 .48972 .24489 .48873 .24369 Mtetra
.73 .758 .875 r
.48873 .24369 .48972 .24489 .49149 .24414 .49051 .24269 Mtetra
.707 .711 .851 r
.49051 .24269 .49149 .24414 .49327 .24335 .49228 .24177 Mtetra
.639 .664 .858 r
.49228 .24177 .49327 .24335 .49504 .24271 .49406 .24121 Mtetra
.236 .464 .876 r
.49406 .24121 .49504 .24271 .49681 .24224 .49582 .24193 Mtetra
.771 .262 0 r
.49582 .24193 .49681 .24224 .49858 .24217 .49757 .24424 Mtetra
.899 .56 .394 r
.49757 .24424 .49858 .24217 .50035 .2429 .49926 .25485 Mtetra
.955 .664 .445 r
.49926 .25485 .50035 .2429 .50208 .24906 .4995 .45331 Mtetra
.53 .299 .508 r
.4995 .45331 .50208 .24906 .50245 .45458 .50138 .45669 Mtetra
.63 .223 .252 r
.50138 .45669 .50245 .45458 .50433 .45866 .50327 .45808 Mtetra
.18 .648 .935 r
.50327 .45808 .50433 .45866 .50623 .45917 .50518 .45828 Mtetra
.601 .796 .974 r
.50518 .45828 .50623 .45917 .50814 .45862 .50709 .45779 Mtetra
.747 .849 .927 r
.50709 .45779 .50814 .45862 .51006 .45755 .50901 .4567 Mtetra
.872 .847 .817 r
.50901 .4567 .51006 .45755 .51197 .4566 .51093 .45453 Mtetra
.861 .706 .689 r
.51093 .45453 .51197 .4566 .51389 .45536 .51286 .4508 Mtetra
.87 .636 .582 r
.51286 .4508 .51389 .45536 .51581 .45328 .5148 .44125 Mtetra
.961 .676 .448 r
.5148 .44125 .51581 .45328 .51774 .44633 .51722 .239 Mtetra
.534 .307 .516 r
.51722 .239 .51774 .44633 .51999 .23896 .51902 .23446 Mtetra
.707 .532 .649 r
.51902 .23446 .51999 .23896 .52179 .23372 .52081 .23198 Mtetra
.715 .677 .812 r
.52081 .23198 .52179 .23372 .52358 .2321 .52261 .23089 Mtetra
.622 .724 .92 r
.52261 .23089 .52358 .2321 .52537 .23152 .5244 .23042 Mtetra
.546 .713 .949 r
.5244 .23042 .52537 .23152 .52717 .23133 .5262 .23019 Mtetra
.676 .756 .911 r
.5262 .23019 .52717 .23133 .52896 .23078 .52799 .22949 Mtetra
.69 .733 .884 r
.52799 .22949 .52896 .23078 .53076 .23008 .52979 .2287 Mtetra
.626 .694 .893 r
.52979 .2287 .53076 .23008 .53256 .22948 .53159 .22821 Mtetra
.242 .515 .909 r
.53159 .22821 .53256 .22948 .53436 .22894 .53339 .22879 Mtetra
.745 .224 0 r
.53339 .22879 .53436 .22894 .53616 .22872 .53521 .23091 Mtetra
.879 .526 .376 r
.53521 .23091 .53616 .22872 .53797 .22923 .53705 .23932 Mtetra
.96 .666 .43 r
.53705 .23932 .53797 .22923 .5398 .23397 .53978 .43972 Mtetra
.531 .299 .508 r
.53978 .43972 .5398 .23397 .54274 .44062 .54173 .4434 Mtetra
.625 .242 .297 r
.54173 .4434 .54274 .44062 .54471 .4453 .54368 .44489 Mtetra
.119 .636 .889 r
.54368 .44489 .54471 .4453 .54665 .44604 .54562 .44505 Mtetra
.642 .793 .955 r
.54562 .44505 .54665 .44604 .54859 .44546 .54756 .44443 Mtetra
.762 .818 .897 r
.54756 .44443 .54859 .44546 .55053 .44434 .5495 .44322 Mtetra
.852 .811 .809 r
.5495 .44322 .55053 .44434 .55247 .44336 .55143 .4411 Mtetra
.847 .693 .691 r
.55143 .4411 .55247 .44336 .55441 .44227 .55335 .43756 Mtetra
.85 .622 .592 r
.55335 .43756 .55441 .44227 .55634 .44047 .55522 .42957 Mtetra
.965 .676 .433 r
.55522 .42957 .55634 .44047 .55824 .43509 .55516 .22668 Mtetra
.535 .307 .516 r
.55516 .22668 .55824 .43509 .55794 .22721 .55693 .22167 Mtetra
.689 .502 .629 r
.55693 .22167 .55794 .22721 .55969 .22079 .55873 .21902 Mtetra
.743 .688 .798 r
.55873 .21902 .55969 .22079 .56149 .21875 .56054 .21768 Mtetra
.667 .772 .928 r
.56054 .21768 .56149 .21875 .56331 .21804 .56236 .21701 Mtetra
.6 .757 .953 r
.56236 .21701 .56331 .21804 .56514 .21773 .56418 .21659 Mtetra
.681 .761 .912 r
.56418 .21659 .56514 .21773 .56696 .21718 .566 .21585 Mtetra
.699 .734 .878 r
.566 .21585 .56696 .21718 .56878 .21643 .56782 .215 Mtetra
.638 .694 .885 r
.56782 .215 .56878 .21643 .5706 .21577 .56965 .21445 Mtetra
.339 .562 .919 r
.56965 .21445 .5706 .21577 .57243 .21519 .57149 .21485 Mtetra
.674 .129 0 r
.57149 .21485 .57243 .21519 .57426 .21487 .57336 .21673 Mtetra
.859 .485 .338 r
.57336 .21673 .57426 .21487 .5761 .2152 .5753 .22299 Mtetra
.966 .667 .411 r
.5753 .22299 .5761 .2152 .578 .21857 .58062 .42509 Mtetra
.531 .299 .508 r
.58062 .42509 .578 .21857 .58358 .42536 .58266 .42927 Mtetra
.619 .265 .349 r
.58266 .42927 .58358 .42536 .58567 .43136 .58467 .43096 Mtetra
0 .357 .684 r
.58467 .43096 .58567 .43136 .58768 .43287 .58666 .43168 Mtetra
.473 .681 .956 r
.58666 .43168 .58768 .43287 .58966 .43279 .58864 .43165 Mtetra
.703 .786 .916 r
.58864 .43165 .58966 .43279 .59162 .43169 .59061 .43075 Mtetra
.928 .825 .724 r
.59061 .43075 .59162 .43169 .59353 .42807 .59252 .42728 Mtetra
.976 .686 .403 r
.59252 .42728 .59353 .42807 .59112 .22585 .59023 .22777 Mtetra
.994 .754 .409 r
.59023 .22777 .59112 .22585 .59261 .20916 .59166 .20779 Mtetra
.875 .769 .742 r
.59166 .20779 .59261 .20916 .5944 .20643 .59345 .20505 Mtetra
.663 .714 .886 r
.59345 .20505 .5944 .20643 .59624 .2057 .59529 .20438 Mtetra
.524 .662 .923 r
.59529 .20438 .59624 .2057 .59809 .20551 .59715 .20426 Mtetra
.604 .714 .922 r
.59715 .20426 .59809 .20551 .59994 .20513 .599 .20385 Mtetra
.694 .742 .888 r
.599 .20385 .59994 .20513 .60178 .20441 .60084 .20302 Mtetra
.642 .703 .891 r
.60084 .20302 .60178 .20441 .60363 .20377 .60269 .20244 Mtetra
.399 .596 .925 r
.60269 .20244 .60363 .20377 .60548 .20319 .60456 .2027 Mtetra
.579 .023 0 r
.60456 .2027 .60548 .20319 .60733 .20282 .60647 .20438 Mtetra
.844 .449 .297 r
.60647 .20438 .60733 .20282 .60921 .20304 .60848 .20944 Mtetra
.969 .667 .395 r
.60848 .20944 .60921 .20304 .61115 .20574 .61608 .41257 Mtetra
.532 .3 .508 r
.61608 .41257 .61115 .20574 .61904 .41219 .61823 .41741 Mtetra
.609 .278 .383 r
.61823 .41741 .61904 .41219 .62126 .41945 .62029 .41925 Mtetra
.279 0 0 r
.62029 .41925 .62126 .41945 .62332 .42121 .62232 .41992 Mtetra
.516 .685 .943 r
.62232 .41992 .62332 .42121 .62533 .42114 .62433 .41978 Mtetra
.71 .754 .886 r
.62433 .41978 .62533 .42114 .62731 .42006 .62632 .4188 Mtetra
.901 .798 .737 r
.62632 .4188 .62731 .42006 .62922 .41679 .62823 .41565 Mtetra
.979 .73 .486 r
.62823 .41565 .62922 .41679 .63071 .4005 .62975 .40012 Mtetra
.977 .684 .387 r
.62975 .40012 .63071 .4005 .62594 .1978 .62501 .19663 Mtetra
.912 .797 .72 r
.62501 .19663 .62594 .1978 .62771 .19461 .62679 .19342 Mtetra
.71 .767 .897 r
.62679 .19342 .62771 .19461 .62957 .19371 .62864 .19251 Mtetra
.583 .718 .936 r
.62864 .19251 .62957 .19371 .63144 .19335 .63052 .19216 Mtetra
.643 .744 .922 r
.63052 .19216 .63144 .19335 .63331 .19277 .63239 .19158 Mtetra
.734 .776 .887 r
.63239 .19158 .63331 .19277 .63516 .19174 .63424 .19054 Mtetra
.632 .738 .925 r
.63424 .19054 .63516 .19174 .63703 .1912 .63611 .19001 Mtetra
0 .304 .794 r
.63611 .19001 .63703 .1912 .63897 .19244 .63805 .19126 Mtetra
.946 .591 .212 r
.63805 .19126 .63897 .19244 .64131 .20393 .64041 .20338 Mtetra
.975 .672 .365 r
.64041 .20338 .64131 .20393 .65123 .40895 .65026 .40783 Mtetra
.578 .103 0 r
.65026 .40783 .65123 .40895 .65338 .41164 .6524 .41048 Mtetra
.443 .675 .962 r
.6524 .41048 .65338 .41164 .65542 .41168 .65444 .41051 Mtetra
.733 .797 .903 r
.65444 .41051 .65542 .41168 .65742 .41061 .65644 .40942 Mtetra
.908 .811 .739 r
.65644 .40942 .65742 .41061 .65934 .40755 .65836 .40627 Mtetra
.98 .728 .481 r
.65836 .40627 .65934 .40755 .66084 .39453 .65976 .39095 Mtetra
.976 .679 .381 r
.65976 .39095 .66084 .39453 .65401 .18786 .65308 .18623 Mtetra
.888 .749 .702 r
.65308 .18623 .65401 .18786 .65577 .18437 .65484 .18287 Mtetra
.68 .706 .867 r
.65484 .18287 .65577 .18437 .65764 .1835 .65672 .18208 Mtetra
.551 .661 .909 r
.65672 .18208 .65764 .1835 .65954 .18321 .65862 .18188 Mtetra
.559 .681 .921 r
.65862 .18188 .65954 .18321 .66144 .18283 .66053 .18163 Mtetra
.696 .764 .904 r
.66053 .18163 .66144 .18283 .66331 .18186 .66241 .18079 Mtetra
.652 .775 .939 r
.66241 .18079 .66331 .18186 .6652 .18127 .6643 .18016 Mtetra
.466 .681 .959 r
.6643 .18016 .6652 .18127 .66715 .1819 .66622 .18014 Mtetra
.12 .345 .81 r
.66622 .18014 .66715 .1819 .6693 .18677 .6682 .18143 Mtetra
.179 .165 .604 r
.6682 .18143 .6693 .18677 .68136 .39508 .6703 .18498 Mtetra
0 0 .388 r
.6703 .18498 .68136 .39508 .68364 .39952 .68217 .38799 Mtetra
.204 .121 .534 r
.68217 .38799 .68364 .39952 .68574 .40009 .68459 .39521 Mtetra
.299 .267 .654 r
.68459 .39521 .68574 .40009 .6878 .39991 .68678 .39753 Mtetra
.344 .432 .808 r
.68678 .39753 .6878 .39991 .68986 .39957 .6889 .39843 Mtetra
.451 .686 .966 r
.6889 .39843 .68986 .39957 .69193 .39943 .69097 .39843 Mtetra
.688 .82 .946 r
.69097 .39843 .69193 .39943 .69396 .39866 .69301 .39757 Mtetra
.891 .835 .784 r
.69301 .39757 .69396 .39866 .69592 .39628 .69495 .395 Mtetra
.98 .745 .51 r
.69495 .395 .69592 .39628 .69746 .38627 .69644 .38391 Mtetra
.977 .677 .362 r
.69644 .38391 .69746 .38627 .6881 .17625 .68718 .17454 Mtetra
.903 .746 .678 r
.68718 .17454 .6881 .17625 .68982 .17222 .68891 .17067 Mtetra
.69 .705 .859 r
.68891 .17067 .68982 .17222 .69171 .17127 .6908 .1698 Mtetra
.561 .659 .902 r
.6908 .1698 .69171 .17127 .69364 .17095 .69273 .16956 Mtetra
.515 .651 .919 r
.69273 .16956 .69364 .17095 .69557 .17078 .69468 .16948 Mtetra
.65 .732 .909 r
.69468 .16948 .69557 .17078 .69748 .17011 .69659 .16885 Mtetra
.667 .747 .91 r
.69659 .16885 .69748 .17011 .69939 .16939 .6985 .16815 Mtetra
.712 .766 .895 r
.6985 .16815 .69939 .16939 .70129 .16849 .70039 .16722 Mtetra
.776 .781 .857 r
.70039 .16722 .70129 .16849 .70316 .16721 .70227 .16586 Mtetra
.702 .743 .884 r
.70227 .16586 .70316 .16721 .70507 .16638 .70417 .16496 Mtetra
.398 .58 .913 r
.70417 .16496 .70507 .16638 .70705 .16676 .70614 .16527 Mtetra
.798 .396 0 r
.70614 .16527 .70705 .16676 .70937 .17265 .70845 .17087 Mtetra
.974 .666 .327 r
.70845 .17087 .70937 .17265 .72447 .38366 .72352 .38232 Mtetra
.696 .26 0 r
.72352 .38232 .72447 .38366 .72683 .38767 .72588 .38644 Mtetra
.432 .656 .954 r
.72588 .38644 .72683 .38767 .72895 .3879 .728 .38653 Mtetra
.687 .752 .901 r
.728 .38653 .72895 .3879 .73101 .38704 .73006 .38566 Mtetra
.801 .787 .839 r
.73006 .38566 .73101 .38704 .73299 .38492 .73206 .38397 Mtetra
.907 .863 .785 r
.73206 .38397 .73299 .38492 .73474 .37936 .73401 .38132 Mtetra
0 0 0 r
.73401 .38132 .73474 .37936 .72295 .16933 .73582 .37673 Mtetra
0 0 .398 r
.73582 .37673 .72295 .16933 .72444 .1621 .72461 .1766 Mtetra
.006 0 .345 r
.72461 .1766 .72444 .1621 .72628 .16014 .72566 .16275 Mtetra
0 0 0 r
.72566 .16275 .72628 .16014 .72818 .15895 .72739 .15897 Mtetra
.867 .995 .775 r
.72739 .15897 .72818 .15895 .7301 .15812 .72922 .1568 Mtetra
.708 .753 .887 r
.72922 .1568 .7301 .15812 .73203 .15735 .73113 .15587 Mtetra
.642 .697 .886 r
.73113 .15587 .73203 .15735 .73396 .15669 .73307 .15527 Mtetra
.64 .706 .895 r
.73307 .15527 .73396 .15669 .73589 .15597 .73502 .15468 Mtetra
.775 .78 .857 r
.73502 .15468 .73589 .15597 .73779 .15469 .7369 .15331 Mtetra
.703 .742 .881 r
.7369 .15331 .73779 .15469 .73971 .15383 .73883 .15239 Mtetra
.47 .618 .914 r
.73883 .15239 .73971 .15383 .74171 .15395 .74082 .15248 Mtetra
.773 .371 0 r
.74082 .15248 .74171 .15395 .7441 .15934 .74322 .15801 Mtetra
.972 .66 .308 r
.74322 .15801 .7441 .15934 .76182 .37137 .76092 .37054 Mtetra
.778 .315 0 r
.76092 .37054 .76182 .37137 .7643 .37584 .76339 .37491 Mtetra
.402 .709 .985 r
.76339 .37491 .7643 .37584 .76646 .37608 .76554 .37492 Mtetra
.707 .802 .924 r
.76554 .37492 .76646 .37608 .76854 .37523 .76762 .37395 Mtetra
.82 .813 .844 r
.76762 .37395 .76854 .37523 .77054 .37323 .76963 .37216 Mtetra
.897 .852 .789 r
.76963 .37216 .77054 .37323 .7723 .36811 .77159 .36959 Mtetra
.714 .798 .324 r
.77159 .36959 .7723 .36811 .75806 .15856 .7734 .36524 Mtetra
.483 .263 .504 r
.7734 .36524 .75806 .15856 .75936 .14963 .77374 .34223 Mtetra
0 0 .402 r
.77374 .34223 .75936 .14963 .7612 .1474 .76063 .14992 Mtetra
0 0 0 r
.76063 .14992 .7612 .1474 .7631 .14605 .76232 .14591 Mtetra
.902 .984 .779 r
.76232 .14591 .7631 .14605 .76503 .14513 .76415 .14359 Mtetra
.717 .722 .854 r
.76415 .14359 .76503 .14513 .76696 .14407 .76608 .14253 Mtetra
.618 .679 .885 r
.76608 .14253 .76696 .14407 .76892 .14347 .76805 .14203 Mtetra
.471 .621 .916 r
.76805 .14203 .76892 .14347 .77095 .14358 .77007 .14211 Mtetra
0 .224 .745 r
.77007 .14211 .77095 .14358 .77336 .1483 .77224 .14391 Mtetra
.058 .114 .606 r
.77224 .14391 .77336 .1483 .79312 .3586 .7746 .1479 Mtetra
.048 0 .429 r
.7746 .1479 .79312 .3586 .79567 .36315 .79309 .34218 Mtetra
.528 .302 .515 r
.14679 .3676 .12539 .55929 .14887 .37316 .14842 .36645 Mtetra
.613 .435 .617 r
.14842 .36645 .14887 .37316 .15096 .36809 .15007 .36514 Mtetra
.681 .558 .708 r
.15007 .36514 .15096 .36809 .15281 .36511 .15171 .36389 Mtetra
.754 .729 .83 r
.15171 .36389 .15281 .36511 .15446 .36377 .15334 .36274 Mtetra
.704 .754 .891 r
.15334 .36274 .15446 .36377 .15605 .36297 .15492 .36199 Mtetra
.524 .712 .958 r
.15492 .36199 .15605 .36297 .15758 .36269 .15644 .36184 Mtetra
.864 .415 .08 r
.15644 .36184 .15758 .36269 .15898 .36354 .15765 .36437 Mtetra
.936 .68 .525 r
.15765 .36437 .15898 .36354 .16022 .36579 .13752 .55286 Mtetra
.563 .327 .516 r
.13752 .55286 .16022 .36579 .16073 .37451 .13704 .57097 Mtetra
.527 .296 .508 r
.13704 .57097 .16073 .37451 .14023 .56854 .13849 .57229 Mtetra
.5 .162 .324 r
.13849 .57229 .14023 .56854 .14145 .57194 .14008 .57241 Mtetra
0 0 0 r
.14008 .57241 .14145 .57194 .1429 .57325 .14174 .57197 Mtetra
.674 .715 .879 r
.14174 .57197 .1429 .57325 .14456 .57287 .14342 .57129 Mtetra
.695 .68 .831 r
.14342 .57129 .14456 .57287 .14627 .57192 .14513 .57043 Mtetra
.71 .695 .834 r
.14513 .57043 .14627 .57192 .14802 .57068 .14684 .56948 Mtetra
.677 .73 .89 r
.14684 .56948 .14802 .57068 .14971 .5699 .14853 .5688 Mtetra
.653 .742 .915 r
.14853 .5688 .14971 .5699 .1514 .56927 .1502 .56824 Mtetra
.629 .75 .935 r
.1502 .56824 .1514 .56927 .15307 .56873 .15187 .56777 Mtetra
.592 .753 .955 r
.15187 .56777 .15307 .56873 .15473 .5683 .15352 .56741 Mtetra
.567 .761 .97 r
.15352 .56741 .15473 .5683 .15638 .56795 .15517 .5671 Mtetra
.556 .767 .977 r
.15517 .5671 .15638 .56795 .15803 .56766 .15682 .5668 Mtetra
.322 .665 .974 r
.15682 .5668 .15803 .56766 .15964 .56777 .15843 .56694 Mtetra
.501 .753 .986 r
.15843 .56694 .15964 .56777 .16127 .56768 .16007 .56677 Mtetra
.72 .792 .908 r
.16007 .56677 .16127 .56768 .16295 .56713 .16178 .5659 Mtetra
.886 .735 .689 r
.16178 .5659 .16295 .56713 .16483 .56469 .16386 .56166 Mtetra
.938 .685 .528 r
.16386 .56166 .16483 .56469 .16694 .56012 .18665 .3623 Mtetra
.548 .319 .52 r
.18665 .3623 .16694 .56012 .18817 .37398 .18922 .35245 Mtetra
.561 .348 .549 r
.18922 .35245 .18817 .37398 .19079 .36362 .19092 .35084 Mtetra
.547 .352 .567 r
.19092 .35084 .19079 .36362 .1921 .36576 .19249 .35037 Mtetra
.534 .335 .556 r
.19249 .35037 .1921 .36576 .19365 .3656 .19403 .35024 Mtetra
.561 .356 .561 r
.19403 .35024 .19365 .3656 .19632 .35463 .19567 .34916 Mtetra
.626 .459 .636 r
.19567 .34916 .19632 .35463 .1983 .35025 .19733 .34789 Mtetra
.695 .598 .743 r
.19733 .34789 .1983 .35025 .2001 .34763 .19898 .34673 Mtetra
.721 .785 .903 r
.19898 .34673 .2001 .34763 .20177 .34633 .2006 .3459 Mtetra
.647 .88 .983 r
.2006 .3459 .20177 .34633 .20337 .34566 .2022 .34529 Mtetra
.551 .866 .995 r
.2022 .34529 .20337 .34566 .20492 .34549 .20377 .34485 Mtetra
.417 .754 .995 r
.20377 .34485 .20492 .34549 .20635 .34646 .20532 .34477 Mtetra
.484 .561 .858 r
.20532 .34477 .20635 .34646 .20765 .34891 .20684 .34488 Mtetra
.518 .415 .677 r
.20684 .34488 .20765 .34891 .2085 .35583 .20837 .34505 Mtetra
.563 .371 .579 r
.20837 .34505 .2085 .35583 .20806 .37581 .20998 .34429 Mtetra
.539 .323 .535 r
.20998 .34429 .20806 .37581 .21106 .36121 .21161 .34345 Mtetra
.535 .331 .551 r
.21161 .34345 .21106 .36121 .2127 .36026 .21317 .34323 Mtetra
.403 .227 .525 r
.21317 .34323 .2127 .36026 .19587 .54859 .21433 .3471 Mtetra
0 0 .124 r
.21433 .3471 .19587 .54859 .19707 .55318 .19624 .5486 Mtetra
0 0 .23 r
.19624 .5486 .19707 .55318 .19852 .55525 .19737 .55385 Mtetra
0 .225 .738 r
.19737 .55385 .19852 .55525 .20009 .55601 .19891 .55503 Mtetra
.527 .73 .967 r
.19891 .55503 .20009 .55601 .20176 .5559 .20058 .55483 Mtetra
.764 .773 .86 r
.20058 .55483 .20176 .5559 .20351 .55491 .20235 .55363 Mtetra
.888 .736 .687 r
.20235 .55363 .20351 .55491 .20556 .55074 .20442 .54935 Mtetra
.944 .688 .518 r
.20442 .54935 .20556 .55074 .22637 .34725 .22528 .34617 Mtetra
.926 .721 .606 r
.22528 .34617 .22637 .34725 .22879 .33811 .22768 .33725 Mtetra
.848 .793 .797 r
.22768 .33725 .22879 .33811 .23052 .33617 .22942 .33528 Mtetra
.654 .778 .939 r
.22942 .33528 .23052 .33617 .23212 .33569 .23102 .33473 Mtetra
.486 .705 .966 r
.23102 .33473 .23212 .33569 .23368 .3357 .23259 .33465 Mtetra
.623 .735 .927 r
.23259 .33465 .23368 .3357 .23528 .3352 .23418 .33423 Mtetra
.674 .765 .919 r
.23418 .33423 .23528 .3352 .2369 .3345 .2358 .3336 Mtetra
.652 .777 .94 r
.2358 .3336 .2369 .3345 .2385 .33406 .23741 .33306 Mtetra
.649 .752 .925 r
.23741 .33306 .2385 .33406 .24002 .33457 .23902 .33253 Mtetra
.585 .571 .804 r
.23902 .33253 .24002 .33457 .24141 .33644 .24061 .33226 Mtetra
.494 .395 .671 r
.24061 .33226 .24141 .33644 .24245 .34239 .24214 .33264 Mtetra
.292 .169 .535 r
.24214 .33264 .24245 .34239 .22654 .53935 .24337 .33637 Mtetra
0 0 .15 r
.24337 .33637 .22654 .53935 .22783 .54359 .22705 .53825 Mtetra
0 0 .313 r
.22705 .53825 .22783 .54359 .22935 .54533 .22824 .54372 Mtetra
0 .184 .716 r
.22824 .54372 .22935 .54533 .23096 .54607 .22979 .54509 Mtetra
.476 .711 .973 r
.22979 .54509 .23096 .54607 .23264 .54605 .23148 .54501 Mtetra
.743 .779 .882 r
.23148 .54501 .23264 .54605 .2344 .54521 .23325 .54397 Mtetra
.878 .746 .713 r
.23325 .54397 .2344 .54521 .23636 .54192 .23523 .54047 Mtetra
.939 .7 .55 r
.23523 .54047 .23636 .54192 .23935 .52649 .23893 .51689 Mtetra
.937 .677 .517 r
.23893 .51689 .23935 .52649 .25776 .32906 .2567 .32784 Mtetra
.852 .745 .745 r
.2567 .32784 .25776 .32906 .25956 .32642 .25849 .32529 Mtetra
.686 .74 .892 r
.25849 .32529 .25956 .32642 .2612 .32571 .26012 .3246 Mtetra
.539 .693 .939 r
.26012 .3246 .2612 .32571 .26279 .32555 .26172 .32443 Mtetra
.678 .739 .896 r
.26172 .32443 .26279 .32555 .26443 .32489 .26335 .32377 Mtetra
.719 .749 .876 r
.26335 .32377 .26443 .32489 .26608 .32401 .26501 .3229 Mtetra
.579 .708 .931 r
.26501 .3229 .26608 .32401 .26768 .32375 .26661 .32261 Mtetra
.785 .314 0 r
.26661 .32261 .26768 .32375 .26906 .32629 .268 .325 Mtetra
.951 .685 .497 r
.268 .325 .26906 .32629 .25425 .52942 .25318 .5273 Mtetra
.963 .63 .294 r
.25318 .5273 .25425 .52942 .25534 .53686 .25422 .53544 Mtetra
0 .146 .674 r
.25422 .53544 .25534 .53686 .25693 .5382 .2558 .53684 Mtetra
.617 .693 .898 r
.2558 .53684 .25693 .5382 .25867 .53777 .25753 .53641 Mtetra
.713 .723 .857 r
.25753 .53641 .25867 .53777 .26044 .53685 .25931 .53547 Mtetra
.697 .716 .864 r
.25931 .53547 .26044 .53685 .26221 .53601 .26108 .53463 Mtetra
.651 .701 .884 r
.26108 .53463 .26221 .53601 .26396 .53541 .26283 .53404 Mtetra
.645 .701 .887 r
.26283 .53404 .26396 .53541 .2657 .53486 .26457 .53348 Mtetra
.629 .695 .892 r
.26457 .53348 .2657 .53486 .26744 .53442 .26632 .533 Mtetra
.615 .682 .89 r
.26632 .533 .26744 .53442 .26918 .53408 .26806 .53258 Mtetra
.615 .67 .88 r
.26806 .53258 .26918 .53408 .27091 .53373 .2698 .53215 Mtetra
.563 .637 .882 r
.2698 .53215 .27091 .53373 .27263 .53355 .27152 .53195 Mtetra
.564 .634 .879 r
.27152 .53195 .27263 .53355 .27436 .53333 .27325 .53175 Mtetra
.672 .68 .849 r
.27325 .53175 .27436 .53333 .27613 .53259 .27502 .53102 Mtetra
.835 .722 .739 r
.27502 .53102 .27613 .53259 .27803 .53003 .27693 .52838 Mtetra
.919 .711 .605 r
.27693 .52838 .27803 .53003 .28033 .52202 .2793 .51947 Mtetra
.95 .688 .502 r
.2793 .51947 .28033 .52202 .29697 .31646 .29593 .31506 Mtetra
.875 .731 .699 r
.29593 .31506 .29697 .31646 .29885 .31271 .29779 .31156 Mtetra
.713 .745 .876 r
.29779 .31156 .29885 .31271 .30052 .31186 .29946 .31071 Mtetra
.564 .698 .931 r
.29946 .31071 .30052 .31186 .30215 .31166 .30109 .31047 Mtetra
.574 .694 .923 r
.30109 .31047 .30215 .31166 .30377 .31144 .30272 .3102 Mtetra
.66 .716 .89 r
.30272 .3102 .30377 .31144 .30543 .31087 .30438 .30961 Mtetra
.663 .712 .885 r
.30438 .30961 .30543 .31087 .30708 .31029 .30603 .309 Mtetra
.668 .71 .879 r
.30603 .309 .30708 .31029 .30874 .30968 .30769 .30837 Mtetra
.674 .707 .872 r
.30769 .30837 .30874 .30968 .3104 .30903 .30936 .30769 Mtetra
.679 .705 .867 r
.30936 .30769 .3104 .30903 .31207 .30833 .31102 .30699 Mtetra
.687 .709 .864 r
.31102 .30699 .31207 .30833 .31374 .30752 .31269 .30625 Mtetra
.696 .721 .869 r
.31269 .30625 .31374 .30752 .31542 .30662 .31437 .30546 Mtetra
.698 .743 .886 r
.31437 .30546 .31542 .30662 .3171 .30573 .31604 .30469 Mtetra
.728 .771 .887 r
.31604 .30469 .3171 .30573 .31879 .3048 .31773 .30378 Mtetra
.739 .775 .882 r
.31773 .30378 .31879 .3048 .32047 .3039 .31942 .3028 Mtetra
.646 .737 .916 r
.31942 .3028 .32047 .3039 .32214 .30332 .32108 .30227 Mtetra
0 .349 .812 r
.32108 .30227 .32214 .30332 .32375 .30348 .32265 .30313 Mtetra
.918 .546 .298 r
.32265 .30313 .32375 .30348 .32528 .30508 .32393 .30847 Mtetra
.95 .679 .487 r
.32393 .30847 .32528 .30508 .32661 .30973 .31262 .51195 Mtetra
.531 .3 .509 r
.31262 .51195 .32661 .30973 .3157 .50963 .31411 .51583 Mtetra
.538 .235 .401 r
.31411 .51583 .3157 .50963 .31712 .51477 .31582 .51638 Mtetra
.376 0 .058 r
.31582 .51638 .31712 .51477 .31875 .51672 .31758 .51624 Mtetra
.541 .852 .998 r
.31758 .51624 .31875 .51672 .32046 .51729 .31936 .51579 Mtetra
.633 .681 .877 r
.31936 .51579 .32046 .51729 .32224 .51688 .32114 .51528 Mtetra
.654 .673 .856 r
.32114 .51528 .32224 .51688 .32403 .51614 .32293 .51464 Mtetra
.626 .677 .878 r
.32293 .51464 .32403 .51614 .32583 .51547 .32471 .51415 Mtetra
.563 .682 .92 r
.32471 .51415 .32583 .51547 .32761 .5151 .32648 .51391 Mtetra
.669 .745 .907 r
.32648 .51391 .32761 .5151 .3294 .51445 .32828 .51323 Mtetra
.832 .768 .791 r
.32828 .51323 .3294 .51445 .33124 .51297 .33016 .51117 Mtetra
.906 .712 .629 r
.33016 .51117 .33124 .51297 .33319 .50967 .33231 .5045 Mtetra
.953 .685 .491 r
.33231 .5045 .33319 .50967 .3353 .50363 .34583 .29938 Mtetra
.535 .308 .516 r
.34583 .29938 .3353 .50363 .34786 .3122 .34775 .29464 Mtetra
.552 .345 .554 r
.34775 .29464 .34786 .3122 .3495 .31261 .34945 .29372 Mtetra
.536 .331 .55 r
.34945 .29372 .3495 .31261 .34161 .48501 .35112 .29341 Mtetra
.526 .3 .515 r
.35112 .29341 .34161 .48501 .35333 .30338 .3528 .29293 Mtetra
.585 .389 .583 r
.3528 .29293 .35333 .30338 .35541 .29554 .35453 .29156 Mtetra
.653 .508 .674 r
.35453 .29156 .35541 .29554 .35726 .29199 .35625 .29028 Mtetra
.708 .667 .808 r
.35625 .29028 .35726 .29199 .35902 .29005 .35796 .28927 Mtetra
.651 .814 .962 r
.35796 .28927 .35902 .29005 .36071 .28941 .35965 .28869 Mtetra
.61 .815 .979 r
.35965 .28869 .36071 .28941 .36239 .2891 .36133 .28822 Mtetra
.625 .781 .956 r
.36133 .28822 .36239 .2891 .36406 .28884 .36302 .28773 Mtetra
.665 .747 .911 r
.36302 .28773 .36406 .28884 .36575 .28827 .36471 .28711 Mtetra
.671 .738 .901 r
.36471 .28711 .36575 .28827 .36744 .28765 .36641 .28647 Mtetra
.698 .742 .885 r
.36641 .28647 .36744 .28765 .36915 .28687 .36811 .28568 Mtetra
.74 .75 .86 r
.36811 .28568 .36915 .28687 .37086 .28586 .36983 .28463 Mtetra
.673 .727 .89 r
.36983 .28463 .37086 .28586 .37257 .28509 .37153 .28397 Mtetra
.27 .563 .934 r
.37153 .28397 .37257 .28509 .37424 .285 .37318 .28436 Mtetra
.908 .502 .195 r
.37318 .28436 .37424 .285 .37583 .28668 .37464 .28875 Mtetra
.957 .681 .471 r
.37464 .28875 .37583 .28668 .3773 .29083 .36655 .49317 Mtetra
.533 .301 .509 r
.36655 .49317 .3773 .29083 .36989 .4848 .36811 .49796 Mtetra
.51 .247 .451 r
.36811 .49796 .36989 .4848 .37169 .48441 .36991 .49783 Mtetra
.487 .227 .446 r
.36991 .49783 .37169 .48441 .37362 .48119 .37174 .49698 Mtetra
.494 .239 .457 r
.37174 .49698 .37362 .48119 .37515 .48681 .37357 .49617 Mtetra
.522 .242 .432 r
.37357 .49617 .37515 .48681 .37662 .49405 .37535 .49643 Mtetra
.49 .096 .221 r
.37535 .49643 .37662 .49405 .37828 .49689 .37714 .49665 Mtetra
.131 .666 .858 r
.37714 .49665 .37828 .49689 .38003 .49813 .37894 .49666 Mtetra
.601 .675 .893 r
.37894 .49666 .38003 .49813 .38184 .498 .38076 .49628 Mtetra
.628 .65 .853 r
.38076 .49628 .38184 .498 .38366 .4975 .38258 .49576 Mtetra
.63 .649 .85 r
.38258 .49576 .38366 .4975 .38549 .49684 .38441 .49523 Mtetra
.577 .644 .88 r
.38441 .49523 .38549 .49684 .38732 .49635 .38622 .49496 Mtetra
.661 .712 .886 r
.38622 .49496 .38732 .49635 .38915 .49559 .38806 .4943 Mtetra
.794 .762 .824 r
.38806 .4943 .38915 .49559 .39102 .49425 .38993 .4927 Mtetra
.909 .733 .651 r
.38993 .4927 .39102 .49425 .39295 .49124 .39196 .48733 Mtetra
.96 .687 .474 r
.39196 .48733 .39295 .49124 .39496 .48616 .40191 .28175 Mtetra
.54 .311 .517 r
.40191 .28175 .39496 .48616 .39745 .46855 .40389 .27468 Mtetra
.527 .301 .515 r
.40389 .27468 .39745 .46855 .40554 .30379 .40563 .27353 Mtetra
.533 .32 .536 r
.40563 .27353 .40554 .30379 .40099 .47017 .40734 .27312 Mtetra
.525 .3 .515 r
.40734 .27312 .40099 .47017 .40954 .28832 .40905 .27281 Mtetra
.567 .361 .561 r
.40905 .27281 .40954 .28832 .41169 .27615 .4108 .27142 Mtetra
.64 .483 .654 r
.4108 .27142 .41169 .27615 .41354 .2721 .41255 .27007 Mtetra
.709 .639 .777 r
.41255 .27007 .41354 .2721 .41533 .26971 .4143 .26892 Mtetra
.68 .823 .952 r
.4143 .26892 .41533 .26971 .41706 .26881 .41603 .26822 Mtetra
.627 .855 .986 r
.41603 .26822 .41706 .26881 .41879 .26827 .41775 .26764 Mtetra
.612 .844 .987 r
.41775 .26764 .41879 .26827 .42051 .26787 .41948 .26711 Mtetra
.656 .825 .965 r
.41948 .26711 .42051 .26787 .42223 .26725 .4212 .26649 Mtetra
.657 .825 .964 r
.4212 .26649 .42223 .26725 .42396 .26664 .42294 .26587 Mtetra
.657 .823 .963 r
.42294 .26587 .42396 .26664 .42569 .26603 .42467 .26524 Mtetra
.658 .82 .961 r
.42467 .26524 .42569 .26603 .42742 .2654 .4264 .26462 Mtetra
.655 .819 .962 r
.4264 .26462 .42742 .2654 .42916 .2648 .42813 .264 Mtetra
.649 .815 .963 r
.42813 .264 .42916 .2648 .43089 .26423 .42987 .26341 Mtetra
.632 .803 .964 r
.42987 .26341 .43089 .26423 .43262 .26379 .4316 .26287 Mtetra
.635 .783 .952 r
.4316 .26287 .43262 .26379 .43435 .26337 .43333 .26234 Mtetra
.641 .762 .936 r
.43333 .26234 .43435 .26337 .43608 .26293 .43507 .2618 Mtetra
.658 .747 .915 r
.43507 .2618 .43608 .26293 .43782 .26235 .43681 .2612 Mtetra
.665 .742 .908 r
.43681 .2612 .43782 .26235 .43956 .26173 .43855 .26056 Mtetra
.669 .741 .904 r
.43855 .26056 .43956 .26173 .4413 .26108 .44029 .2599 Mtetra
.672 .742 .903 r
.44029 .2599 .4413 .26108 .44304 .26044 .44203 .25923 Mtetra
.675 .737 .897 r
.44203 .25923 .44304 .26044 .44478 .25977 .44378 .25854 Mtetra
.678 .735 .893 r
.44378 .25854 .44478 .25977 .44653 .25905 .44553 .25784 Mtetra
.753 .758 .857 r
.44553 .25784 .44653 .25905 .44829 .25795 .44729 .25669 Mtetra
.7 .737 .879 r
.44729 .25669 .44829 .25795 .45004 .25705 .44904 .25586 Mtetra
.553 .696 .935 r
.44904 .25586 .45004 .25705 .45178 .25655 .45077 .25564 Mtetra
.797 .324 0 r
.45077 .25564 .45178 .25655 .4535 .25748 .45244 .25851 Mtetra
.965 .681 .445 r
.45244 .25851 .4535 .25748 .45517 .26008 .44955 .46042 Mtetra
.543 .309 .51 r
.44955 .46042 .45517 .26008 .45275 .44903 .45117 .47061 Mtetra
.54 .286 .479 r
.45117 .47061 .45275 .44903 .45418 .46855 .45301 .47176 Mtetra
.484 .123 .277 r
.45301 .47176 .45418 .46855 .45597 .47154 .45487 .47185 Mtetra
0 0 0 r
.45487 .47185 .45597 .47154 .45781 .47274 .45674 .47142 Mtetra
.64 .721 .907 r
.45674 .47142 .45781 .47274 .45969 .47237 .45862 .47085 Mtetra
.666 .698 .87 r
.45862 .47085 .45969 .47237 .46157 .47153 .46051 .47013 Mtetra
.68 .723 .882 r
.46051 .47013 .46157 .47153 .46346 .47048 .46239 .46935 Mtetra
.505 .702 .958 r
.46239 .46935 .46346 .47048 .46534 .47026 .46427 .46922 Mtetra
.581 .755 .961 r
.46427 .46922 .46534 .47026 .46722 .46993 .46615 .46884 Mtetra
.731 .79 .9 r
.46615 .46884 .46722 .46993 .46911 .4692 .46804 .46781 Mtetra
.907 .757 .683 r
.46804 .46781 .46911 .4692 .47102 .46692 .46999 .46358 Mtetra
.967 .687 .451 r
.46999 .46358 .47102 .46692 .47296 .46286 .47512 .2622 Mtetra
.553 .322 .518 r
.47512 .2622 .47296 .46286 .47505 .44924 .47709 .2487 Mtetra
.53 .303 .515 r
.47709 .2487 .47505 .44924 .47981 .25211 .47888 .24638 Mtetra
.615 .449 .634 r
.47888 .24638 .47981 .25211 .48163 .24809 .48066 .24517 Mtetra
.633 .54 .732 r
.48066 .24517 .48163 .24809 .48342 .24578 .48243 .24441 Mtetra
.676 .712 .876 r
.48243 .24441 .48342 .24578 .48519 .24473 .4842 .24369 Mtetra
.661 .769 .929 r
.4842 .24369 .48519 .24473 .48696 .24412 .48597 .24306 Mtetra
.649 .76 .931 r
.48597 .24306 .48696 .24412 .48873 .24369 .48774 .24248 Mtetra
.74 .76 .869 r
.48774 .24248 .48873 .24369 .49051 .24269 .48952 .24142 Mtetra
.707 .739 .876 r
.48952 .24142 .49051 .24269 .49228 .24177 .4913 .24054 Mtetra
.584 .702 .924 r
.4913 .24054 .49228 .24177 .49406 .24121 .49307 .24022 Mtetra
.655 .162 0 r
.49307 .24022 .49406 .24121 .49582 .24193 .49482 .24249 Mtetra
.968 .68 .428 r
.49482 .24249 .49582 .24193 .49757 .24424 .49481 .43504 Mtetra
.562 .324 .512 r
.49481 .43504 .49757 .24424 .49926 .25485 .49652 .45539 Mtetra
.527 .296 .507 r
.49652 .45539 .49926 .25485 .4995 .45331 .49841 .45706 Mtetra
.503 .156 .311 r
.49841 .45706 .4995 .45331 .50138 .45669 .50031 .45726 Mtetra
.068 0 0 r
.50031 .45726 .50138 .45669 .50327 .45808 .50222 .45692 Mtetra
.504 .698 .956 r
.50222 .45692 .50327 .45808 .50518 .45828 .50413 .4568 Mtetra
.608 .685 .897 r
.50413 .4568 .50518 .45828 .50709 .45779 .50604 .45636 Mtetra
.728 .738 .859 r
.50604 .45636 .50709 .45779 .50901 .4567 .50796 .45526 Mtetra
.896 .76 .704 r
.50796 .45526 .50901 .4567 .51093 .45453 .50989 .45158 Mtetra
.934 .689 .542 r
.50989 .45158 .51093 .45453 .51286 .4508 .51186 .43735 Mtetra
.959 .674 .45 r
.51186 .43735 .51286 .4508 .5148 .44125 .51445 .23591 Mtetra
.531 .304 .515 r
.51445 .23591 .5148 .44125 .51722 .239 .51625 .23301 Mtetra
.621 .45 .629 r
.51625 .23301 .51722 .239 .51902 .23446 .51804 .23164 Mtetra
.646 .554 .737 r
.51804 .23164 .51902 .23446 .52081 .23198 .51984 .23078 Mtetra
.67 .743 .905 r
.51984 .23078 .52081 .23198 .52261 .23089 .52163 .2301 Mtetra
.625 .817 .974 r
.52163 .2301 .52261 .23089 .5244 .23042 .52343 .22955 Mtetra
.604 .793 .971 r
.52343 .22955 .5244 .23042 .5262 .23019 .52522 .22909 Mtetra
.721 .779 .898 r
.52522 .22909 .5262 .23019 .52799 .22949 .52702 .22816 Mtetra
.703 .733 .874 r
.52702 .22816 .52799 .22949 .52979 .2287 .52882 .22729 Mtetra
.596 .677 .897 r
.52882 .22729 .52979 .2287 .53159 .22821 .53062 .22694 Mtetra
0 .011 .552 r
.53062 .22694 .53159 .22821 .53339 .22879 .53243 .22891 Mtetra
.953 .622 .355 r
.53243 .22891 .53339 .22879 .53521 .23091 .53428 .24527 Mtetra
.955 .66 .437 r
.53428 .24527 .53521 .23091 .53705 .23932 .53682 .44202 Mtetra
.527 .296 .507 r
.53682 .44202 .53705 .23932 .53978 .43972 .53877 .44401 Mtetra
.508 .173 .334 r
.53877 .44401 .53978 .43972 .54173 .4434 .54071 .44423 Mtetra
.162 0 0 r
.54071 .44423 .54173 .4434 .54368 .44489 .54265 .44387 Mtetra
.533 .744 .973 r
.54265 .44387 .54368 .44489 .54562 .44505 .54459 .44361 Mtetra
.616 .697 .902 r
.54459 .44361 .54562 .44505 .54756 .44443 .54653 .44313 Mtetra
.735 .764 .876 r
.54653 .44313 .54756 .44443 .5495 .44322 .54847 .44202 Mtetra
.907 .792 .723 r
.54847 .44202 .5495 .44322 .55143 .4411 .55039 .43862 Mtetra
.941 .701 .548 r
.55039 .43862 .55143 .4411 .55335 .43756 .55224 .42665 Mtetra
.965 .676 .434 r
.55224 .42665 .55335 .43756 .55522 .42957 .55234 .22268 Mtetra
.531 .304 .515 r
.55234 .22268 .55522 .42957 .55516 .22668 .55414 .21949 Mtetra
.605 .425 .612 r
.55414 .21949 .55516 .22668 .55693 .22167 .55595 .21814 Mtetra
.624 .509 .702 r
.55595 .21814 .55693 .22167 .55873 .21902 .55776 .21732 Mtetra
.659 .661 .84 r
.55776 .21732 .55873 .21902 .56054 .21768 .55958 .21662 Mtetra
.658 .77 .932 r
.55958 .21662 .56054 .21768 .56236 .21701 .5614 .21599 Mtetra
.638 .771 .944 r
.5614 .21599 .56236 .21701 .56418 .21659 .56323 .21543 Mtetra
.716 .77 .895 r
.56323 .21543 .56418 .21659 .566 .21585 .56504 .21452 Mtetra
.713 .737 .87 r
.56504 .21452 .566 .21585 .56782 .215 .56686 .21358 Mtetra
.616 .685 .892 r
.56686 .21358 .56782 .215 .56965 .21445 .56869 .21313 Mtetra
0 .192 .716 r
.56869 .21313 .56965 .21445 .57149 .21485 .57055 .21468 Mtetra
.939 .573 .274 r
.57055 .21468 .57149 .21485 .57336 .21673 .57254 .2241 Mtetra
.966 .668 .411 r
.57254 .2241 .57336 .21673 .5753 .22299 .5777 .42818 Mtetra
.528 .297 .508 r
.5777 .42818 .5753 .22299 .58062 .42509 .57971 .43062 Mtetra
.513 .198 .371 r
.57971 .43062 .58062 .42509 .58266 .42927 .58169 .43085 Mtetra
.32 0 .016 r
.58169 .43085 .58266 .42927 .58467 .43096 .58367 .43049 Mtetra
.334 .767 .97 r
.58367 .43049 .58467 .43096 .58666 .43168 .58564 .43035 Mtetra
.535 .684 .934 r
.58564 .43035 .58666 .43168 .58864 .43165 .58762 .43017 Mtetra
.69 .723 .875 r
.58762 .43017 .58864 .43165 .59061 .43075 .58959 .42929 Mtetra
.893 .77 .718 r
.58959 .42929 .59061 .43075 .59252 .42728 .59151 .4259 Mtetra
.976 .707 .455 r
.59151 .4259 .59252 .42728 .59023 .22777 .59289 .39712 Mtetra
0 0 .295 r
.59289 .39712 .59023 .22777 .59166 .20779 .59072 .20693 Mtetra
.916 .838 .753 r
.59072 .20693 .59166 .20779 .59345 .20505 .59252 .20412 Mtetra
.687 .811 .941 r
.59252 .20412 .59345 .20505 .59529 .20438 .59436 .20335 Mtetra
.533 .73 .965 r
.59436 .20335 .59529 .20438 .59715 .20426 .59621 .20312 Mtetra
.644 .752 .928 r
.59621 .20312 .59715 .20426 .599 .20385 .59806 .20254 Mtetra
.714 .746 .877 r
.59806 .20254 .599 .20385 .60084 .20302 .59989 .2016 Mtetra
.625 .691 .892 r
.59989 .2016 .60084 .20302 .60269 .20244 .60175 .2011 Mtetra
0 .327 .812 r
.60175 .2011 .60269 .20244 .60456 .2027 .60364 .20231 Mtetra
.922 .53 .194 r
.60364 .20231 .60456 .2027 .60647 .20438 .6057 .20944 Mtetra
.97 .669 .393 r
.6057 .20944 .60647 .20438 .60848 .20944 .61321 .41596 Mtetra
.529 .297 .508 r
.61321 .41596 .60848 .20944 .61608 .41257 .6153 .41896 Mtetra
.519 .214 .389 r
.6153 .41896 .61608 .41257 .61823 .41741 .61731 .41926 Mtetra
.354 0 .08 r
.61731 .41926 .61823 .41741 .62029 .41925 .61931 .41892 Mtetra
.347 .797 .95 r
.61931 .41892 .62029 .41925 .62232 .41992 .62132 .41864 Mtetra
.541 .697 .941 r
.62132 .41864 .62232 .41992 .62433 .41978 .62333 .41842 Mtetra
.693 .746 .892 r
.62333 .41842 .62433 .41978 .62632 .4188 .62532 .41754 Mtetra
.896 .798 .744 r
.62532 .41754 .62632 .4188 .62823 .41565 .62724 .4145 Mtetra
.979 .732 .491 r
.62724 .4145 .62823 .41565 .62975 .40012 .62878 .39963 Mtetra
.977 .684 .387 r
.62878 .39963 .62975 .40012 .62501 .19663 .62408 .19546 Mtetra
.913 .798 .719 r
.62408 .19546 .62501 .19663 .62679 .19342 .62586 .19223 Mtetra
.711 .769 .898 r
.62586 .19223 .62679 .19342 .62864 .19251 .62772 .19132 Mtetra
.583 .719 .936 r
.62772 .19132 .62864 .19251 .63052 .19216 .62959 .19097 Mtetra
.643 .744 .922 r
.62959 .19097 .63052 .19216 .63239 .19158 .63146 .19039 Mtetra
.734 .776 .886 r
.63146 .19039 .63239 .19158 .63424 .19054 .63332 .18934 Mtetra
.632 .738 .924 r
.63332 .18934 .63424 .19054 .63611 .19001 .63519 .1888 Mtetra
0 .3 .791 r
.63519 .1888 .63611 .19001 .63805 .19126 .63713 .19007 Mtetra
.948 .595 .22 r
.63713 .19007 .63805 .19126 .64041 .20338 .63951 .20278 Mtetra
.975 .672 .365 r
.63951 .20278 .64041 .20338 .65026 .40783 .64927 .40668 Mtetra
.564 .091 0 r
.64927 .40668 .65026 .40783 .6524 .41048 .65142 .4093 Mtetra
.454 .676 .959 r
.65142 .4093 .6524 .41048 .65444 .41051 .65346 .40931 Mtetra
.733 .79 .898 r
.65346 .40931 .65444 .41051 .65644 .40942 .65546 .40821 Mtetra
.905 .809 .742 r
.65546 .40821 .65644 .40942 .65836 .40627 .65738 .40512 Mtetra
.981 .737 .494 r
.65738 .40512 .65836 .40627 .65976 .39095 .65887 .39179 Mtetra
.978 .683 .371 r
.65887 .39179 .65976 .39095 .65308 .18623 .65218 .18532 Mtetra
.94 .829 .707 r
.65218 .18532 .65308 .18623 .65484 .18287 .65394 .18184 Mtetra
.707 .803 .924 r
.65394 .18184 .65484 .18287 .65672 .18208 .65581 .18097 Mtetra
.557 .726 .953 r
.65581 .18097 .65672 .18208 .65862 .18188 .65771 .18068 Mtetra
.555 .706 .941 r
.65771 .18068 .65862 .18188 .66053 .18163 .65962 .18042 Mtetra
.672 .753 .912 r
.65962 .18042 .66053 .18163 .66241 .18079 .6615 .1797 Mtetra
.66 .773 .933 r
.6615 .1797 .66241 .18079 .6643 .18016 .66339 .17903 Mtetra
.647 .761 .932 r
.66339 .17903 .6643 .18016 .66622 .18014 .66528 .17842 Mtetra
.624 .649 .855 r
.66528 .17842 .66622 .18014 .6682 .18143 .66718 .17791 Mtetra
.539 .459 .714 r
.66718 .17791 .6682 .18143 .6703 .18498 .66911 .1779 Mtetra
.427 .305 .611 r
.66911 .1779 .6703 .18498 .68217 .38799 .67112 .17961 Mtetra
0 0 .386 r
.67112 .17961 .68217 .38799 .68459 .39521 .68308 .383 Mtetra
0 0 .458 r
.68308 .383 .68459 .39521 .68678 .39753 .68574 .3949 Mtetra
.014 .189 .7 r
.68574 .3949 .68678 .39753 .6889 .39843 .68794 .39728 Mtetra
.413 .662 .963 r
.68794 .39728 .6889 .39843 .69097 .39843 .69002 .39739 Mtetra
.705 .817 .935 r
.69002 .39739 .69097 .39843 .69301 .39757 .69205 .39645 Mtetra
.894 .83 .777 r
.69205 .39645 .69301 .39757 .69495 .395 .69399 .39379 Mtetra
.981 .752 .519 r
.69399 .39379 .69495 .395 .69644 .38391 .69553 .38352 Mtetra
.978 .678 .357 r
.69553 .38352 .69644 .38391 .68718 .17454 .6863 .17362 Mtetra
.955 .824 .675 r
.6863 .17362 .68718 .17454 .68891 .17067 .68802 .16962 Mtetra
.721 .806 .917 r
.68802 .16962 .68891 .17067 .6908 .1698 .68991 .16866 Mtetra
.569 .728 .949 r
.68991 .16866 .6908 .1698 .69273 .16956 .69184 .16833 Mtetra
.527 .688 .941 r
.69184 .16833 .69273 .16956 .69468 .16948 .69378 .16817 Mtetra
.651 .729 .906 r
.69378 .16817 .69468 .16948 .69659 .16885 .69569 .16753 Mtetra
.66 .731 .902 r
.69569 .16753 .69659 .16885 .6985 .16815 .6976 .16686 Mtetra
.697 .752 .894 r
.6976 .16686 .6985 .16815 .70039 .16722 .6995 .16599 Mtetra
.765 .786 .871 r
.6995 .16599 .70039 .16722 .70227 .16586 .70138 .16474 Mtetra
.689 .782 .922 r
.70138 .16474 .70227 .16586 .70417 .16496 .70329 .16393 Mtetra
.27 .588 .946 r
.70329 .16393 .70417 .16496 .70614 .16527 .70527 .16434 Mtetra
.87 .456 .014 r
.70527 .16434 .70614 .16527 .70845 .17087 .70761 .17048 Mtetra
.974 .665 .331 r
.70761 .17048 .70845 .17087 .72352 .38232 .72259 .38137 Mtetra
.74 .272 0 r
.72259 .38137 .72352 .38232 .72588 .38644 .72493 .3852 Mtetra
.487 .685 .954 r
.72493 .3852 .72588 .38644 .728 .38653 .72704 .38513 Mtetra
.687 .746 .896 r
.72704 .38513 .728 .38653 .73006 .38566 .7291 .38425 Mtetra
.744 .766 .871 r
.7291 .38425 .73006 .38566 .73206 .38397 .73114 .38301 Mtetra
.678 .83 .956 r
.73114 .38301 .73206 .38397 .73401 .38132 .7332 .38218 Mtetra
0 0 0 r
.7332 .38218 .73401 .38132 .73582 .37673 .73523 .38083 Mtetra
.179 0 .235 r
.73523 .38083 .73582 .37673 .72461 .1766 .73717 .37813 Mtetra
.499 .275 .505 r
.73717 .37813 .72461 .1766 .72566 .16275 .7384 .36471 Mtetra
0 0 .386 r
.7384 .36471 .72566 .16275 .72739 .15897 .72662 .15943 Mtetra
.944 .927 .569 r
.72662 .15943 .72739 .15897 .72922 .1568 .72834 .15549 Mtetra
.739 .765 .874 r
.72834 .15549 .72922 .1568 .73113 .15587 .73024 .15437 Mtetra
.631 .69 .886 r
.73024 .15437 .73113 .15587 .73307 .15527 .73218 .15382 Mtetra
.6 .684 .9 r
.73218 .15382 .73307 .15527 .73502 .15468 .73414 .1534 Mtetra
.76 .78 .87 r
.73414 .1534 .73502 .15468 .7369 .15331 .73604 .15216 Mtetra
.689 .779 .92 r
.73604 .15216 .7369 .15331 .73883 .15239 .73797 .15134 Mtetra
.377 .649 .963 r
.73797 .15134 .73883 .15239 .74082 .15248 .73997 .15152 Mtetra
.839 .415 0 r
.73997 .15152 .74082 .15248 .74322 .15801 .74237 .15719 Mtetra
.972 .66 .31 r
.74237 .15719 .74322 .15801 .76092 .37054 .75998 .36913 Mtetra
.672 .246 0 r
.75998 .36913 .76092 .37054 .76339 .37491 .76245 .37341 Mtetra
.507 .647 .92 r
.76245 .37341 .76339 .37491 .76554 .37492 .76459 .37335 Mtetra
.686 .722 .877 r
.76459 .37335 .76554 .37492 .76762 .37395 .76667 .37245 Mtetra
.758 .76 .854 r
.76667 .37245 .76762 .37395 .76963 .37216 .76872 .37107 Mtetra
.683 .807 .942 r
.76872 .37107 .76963 .37216 .77159 .36959 .77081 .37022 Mtetra
0 0 0 r
.77081 .37022 .77159 .36959 .7734 .36524 .77286 .36888 Mtetra
.178 0 .213 r
.77286 .36888 .7734 .36524 .77374 .34223 .77483 .36644 Mtetra
.298 .108 .446 r
.77483 .36644 .77374 .34223 .76063 .14992 .77605 .35464 Mtetra
0 0 .398 r
.77605 .35464 .76063 .14992 .76232 .14591 .76164 .14683 Mtetra
.862 .878 .441 r
.76164 .14683 .76232 .14591 .76415 .14359 .76331 .14256 Mtetra
.767 .834 .904 r
.76331 .14256 .76415 .14359 .76608 .14253 .76522 .14135 Mtetra
.628 .752 .936 r
.76522 .14135 .76608 .14253 .76805 .14203 .76719 .1408 Mtetra
.513 .683 .943 r
.76719 .1408 .76805 .14203 .77007 .14211 .7692 .14067 Mtetra
.5 .636 .914 r
.7692 .14067 .77007 .14211 .77224 .14391 .77122 .14065 Mtetra
.531 .47 .733 r
.77122 .14065 .77224 .14391 .7746 .1479 .77324 .1407 Mtetra
.542 .384 .616 r
.77324 .1407 .7746 .1479 .79309 .34218 .77526 .14058 Mtetra
.609 .49 .692 r
.14597 .36405 .14679 .3676 .14842 .36645 .14753 .36344 Mtetra
.61 .513 .719 r
.14753 .36344 .14842 .36645 .15007 .36514 .14909 .3629 Mtetra
.608 .561 .776 r
.14909 .3629 .15007 .36514 .15171 .36389 .15063 .3625 Mtetra
.615 .664 .874 r
.15063 .3625 .15171 .36389 .15334 .36274 .15217 .36212 Mtetra
.354 .726 .987 r
.15217 .36212 .15334 .36274 .15492 .36199 .15367 .36212 Mtetra
.561 .004 0 r
.15367 .36212 .15492 .36199 .15644 .36184 .15508 .36287 Mtetra
.874 .551 .436 r
.15508 .36287 .15644 .36184 .15765 .36437 .15585 .36921 Mtetra
.931 .674 .527 r
.15585 .36921 .15765 .36437 .13752 .55286 .13437 .56879 Mtetra
.609 .345 .491 r
.13437 .56879 .13752 .55286 .13704 .57097 .13553 .57267 Mtetra
.432 0 .117 r
.13553 .57267 .13704 .57097 .13849 .57229 .13713 .57269 Mtetra
.46 .885 .803 r
.13713 .57269 .13849 .57229 .14008 .57241 .13883 .57188 Mtetra
.796 .866 .901 r
.13883 .57188 .14008 .57241 .14174 .57197 .14058 .57062 Mtetra
.698 .712 .859 r
.14058 .57062 .14174 .57197 .14342 .57129 .14228 .5698 Mtetra
.683 .686 .847 r
.14228 .5698 .14342 .57129 .14513 .57043 .14397 .56904 Mtetra
.677 .7 .864 r
.14397 .56904 .14513 .57043 .14684 .56948 .14566 .56833 Mtetra
.657 .734 .906 r
.14566 .56833 .14684 .56948 .14853 .5688 .14734 .56775 Mtetra
.632 .746 .93 r
.14734 .56775 .14853 .5688 .1502 .56824 .149 .56727 Mtetra
.602 .754 .951 r
.149 .56727 .1502 .56824 .15187 .56777 .15066 .56688 Mtetra
.485 .731 .98 r
.15066 .56688 .15187 .56777 .15352 .56741 .15229 .56676 Mtetra
.46 .776 .998 r
.15229 .56676 .15352 .56741 .15517 .5671 .15392 .56658 Mtetra
.535 .835 .999 r
.15392 .56658 .15517 .5671 .15682 .5668 .15558 .56621 Mtetra
.653 .851 .976 r
.15558 .56621 .15682 .5668 .15843 .56694 .15727 .56559 Mtetra
.741 .722 .834 r
.15727 .56559 .15843 .56694 .16007 .56677 .15901 .56445 Mtetra
.766 .642 .724 r
.15901 .56445 .16007 .56677 .16178 .5659 .16086 .56233 Mtetra
.867 .651 .607 r
.16086 .56233 .16178 .5659 .16386 .56166 .16353 .5526 Mtetra
.931 .677 .531 r
.16353 .5526 .16386 .56166 .18665 .3623 .18638 .35341 Mtetra
.687 .477 .597 r
.18638 .35341 .18665 .3623 .18922 .35245 .18835 .34916 Mtetra
.676 .542 .694 r
.18835 .34916 .18922 .35245 .19092 .35084 .19002 .34784 Mtetra
.609 .514 .721 r
.19002 .34784 .19092 .35084 .19249 .35037 .1916 .34732 Mtetra
.564 .484 .723 r
.1916 .34732 .19249 .35037 .19403 .35024 .19314 .34714 Mtetra
.59 .497 .718 r
.19314 .34714 .19403 .35024 .19567 .34916 .19471 .34675 Mtetra
.61 .55 .762 r
.19471 .34675 .19567 .34916 .19733 .34789 .19629 .34631 Mtetra
.632 .645 .846 r
.19629 .34631 .19733 .34789 .19898 .34673 .19787 .34584 Mtetra
.668 .78 .933 r
.19787 .34584 .19898 .34673 .2006 .3459 .19946 .34525 Mtetra
.68 .834 .957 r
.19946 .34525 .2006 .3459 .2022 .34529 .20106 .34459 Mtetra
.687 .826 .95 r
.20106 .34459 .2022 .34529 .20377 .34485 .20266 .34392 Mtetra
.68 .772 .92 r
.20266 .34392 .20377 .34485 .20532 .34477 .20426 .34328 Mtetra
.663 .67 .846 r
.20426 .34328 .20532 .34477 .20684 .34488 .20586 .34265 Mtetra
.638 .579 .772 r
.20586 .34265 .20684 .34488 .20837 .34505 .20746 .34204 Mtetra
.656 .542 .713 r
.20746 .34204 .20837 .34505 .20998 .34429 .2091 .34105 Mtetra
.633 .518 .706 r
.2091 .34105 .20998 .34429 .21161 .34345 .21072 .34025 Mtetra
.565 .478 .715 r
.21072 .34025 .21161 .34345 .21317 .34323 .21228 .34006 Mtetra
0 0 .48 r
.21228 .34006 .21317 .34323 .21433 .3471 .21354 .3429 Mtetra
.949 .688 .509 r
.21354 .3429 .21433 .3471 .19624 .5486 .19531 .54501 Mtetra
.95 .643 .207 r
.19531 .54501 .19624 .5486 .19737 .55385 .19618 .55293 Mtetra
.457 0 0 r
.19618 .55293 .19737 .55385 .19891 .55503 .19772 .55416 Mtetra
.587 .776 .97 r
.19772 .55416 .19891 .55503 .20058 .55483 .19941 .55378 Mtetra
.783 .776 .847 r
.19941 .55378 .20058 .55483 .20235 .55363 .20119 .55241 Mtetra
.877 .746 .714 r
.20119 .55241 .20235 .55363 .20442 .54935 .20318 .54893 Mtetra
.946 .735 .586 r
.20318 .54893 .20442 .54935 .22528 .34617 .20596 .53707 Mtetra
0 0 .094 r
.20596 .53707 .22528 .34617 .22768 .33725 .22633 .33889 Mtetra
.812 .935 .567 r
.22633 .33889 .22768 .33725 .22942 .33528 .22817 .33593 Mtetra
.625 .947 .751 r
.22817 .33593 .22942 .33528 .23102 .33473 .22984 .33462 Mtetra
.664 .943 .961 r
.22984 .33462 .23102 .33473 .23259 .33465 .23148 .33382 Mtetra
.687 .796 .932 r
.23148 .33382 .23259 .33465 .23418 .33423 .2331 .33314 Mtetra
.667 .74 .905 r
.2331 .33314 .23418 .33423 .2358 .3336 .23471 .33254 Mtetra
.652 .742 .915 r
.23471 .33254 .2358 .3336 .23741 .33306 .23632 .332 Mtetra
.743 .762 .869 r
.23632 .332 .23741 .33306 .23902 .33253 .23797 .331 Mtetra
.712 .683 .82 r
.23797 .331 .23902 .33253 .24061 .33226 .23962 .33004 Mtetra
.602 .563 .782 r
.23962 .33004 .24061 .33226 .24214 .33264 .24122 .32966 Mtetra
0 .052 .597 r
.24122 .32966 .24214 .33264 .24337 .33637 .24259 .33191 Mtetra
.952 .689 .501 r
.24259 .33191 .24337 .33637 .22705 .53825 .22637 .53175 Mtetra
.854 .622 .083 r
.22637 .53175 .22705 .53825 .22824 .54372 .2271 .54236 Mtetra
0 0 .495 r
.2271 .54236 .22824 .54372 .22979 .54509 .22862 .54408 Mtetra
.505 .717 .967 r
.22862 .54408 .22979 .54509 .23148 .54501 .23031 .54395 Mtetra
.761 .777 .866 r
.23031 .54395 .23148 .54501 .23325 .54397 .2321 .54276 Mtetra
.884 .749 .708 r
.2321 .54276 .23325 .54397 .23523 .54047 .23409 .5391 Mtetra
.947 .689 .512 r
.23409 .5391 .23523 .54047 .23893 .51689 .25262 .3432 Mtetra
.567 .334 .523 r
.25262 .3432 .23893 .51689 .2567 .32784 .25562 .32665 Mtetra
.852 .75 .75 r
.25562 .32665 .2567 .32784 .25849 .32529 .25741 .32418 Mtetra
.684 .742 .895 r
.25741 .32418 .25849 .32529 .26012 .3246 .25905 .3235 Mtetra
.538 .696 .941 r
.25905 .3235 .26012 .3246 .26172 .32443 .26064 .32333 Mtetra
.678 .742 .899 r
.26064 .32333 .26172 .32443 .26335 .32377 .26228 .32267 Mtetra
.719 .752 .878 r
.26228 .32267 .26335 .32377 .26501 .3229 .26393 .3218 Mtetra
.577 .711 .934 r
.26393 .3218 .26501 .3229 .26661 .32261 .26554 .32152 Mtetra
.792 .321 0 r
.26554 .32152 .26661 .32261 .268 .325 .26693 .32392 Mtetra
.95 .685 .498 r
.26693 .32392 .268 .325 .25318 .5273 .25202 .52632 Mtetra
.946 .61 .355 r
.25202 .52632 .25318 .5273 .25422 .53544 .25306 .53443 Mtetra
.474 0 0 r
.25306 .53443 .25422 .53544 .2558 .53684 .25464 .53583 Mtetra
.608 .756 .949 r
.25464 .53583 .2558 .53684 .25753 .53641 .25637 .5354 Mtetra
.727 .786 .899 r
.25637 .5354 .25753 .53641 .25931 .53547 .25815 .53446 Mtetra
.696 .78 .916 r
.25815 .53446 .25931 .53547 .26108 .53463 .25991 .53368 Mtetra
.632 .777 .951 r
.25991 .53368 .26108 .53463 .26283 .53404 .26166 .53316 Mtetra
.658 .798 .95 r
.26166 .53316 .26283 .53404 .26457 .53348 .26341 .53254 Mtetra
.732 .799 .906 r
.26341 .53254 .26457 .53348 .26632 .533 .26519 .53158 Mtetra
.755 .726 .825 r
.26519 .53158 .26632 .533 .26806 .53258 .267 .53028 Mtetra
.718 .627 .755 r
.267 .53028 .26806 .53258 .2698 .53215 .26881 .52889 Mtetra
.622 .522 .719 r
.26881 .52889 .2698 .53215 .27152 .53195 .27058 .52818 Mtetra
.558 .461 .701 r
.27058 .52818 .27152 .53195 .27325 .53175 .2723 .52801 Mtetra
.609 .494 .698 r
.2723 .52801 .27325 .53175 .27502 .53102 .27407 .52735 Mtetra
.758 .588 .666 r
.27407 .52735 .27502 .53102 .27693 .52838 .27601 .52425 Mtetra
.948 .686 .504 r
.27601 .52425 .27693 .52838 .2793 .51947 .29229 .32699 Mtetra
.556 .325 .52 r
.29229 .32699 .2793 .51947 .29593 .31506 .29492 .31319 Mtetra
.823 .686 .713 r
.29492 .31319 .29593 .31506 .29779 .31156 .29673 .31044 Mtetra
.705 .75 .887 r
.29673 .31044 .29779 .31156 .29946 .31071 .2984 .30964 Mtetra
.589 .725 .938 r
.2984 .30964 .29946 .31071 .30109 .31047 .30003 .30931 Mtetra
.615 .716 .918 r
.30003 .30931 .30109 .31047 .30272 .3102 .30167 .30891 Mtetra
.682 .712 .872 r
.30167 .30891 .30272 .3102 .30438 .30961 .30333 .3082 Mtetra
.679 .694 .856 r
.30333 .3082 .30438 .30961 .30603 .309 .305 .30748 Mtetra
.681 .678 .841 r
.305 .30748 .30603 .309 .30769 .30837 .30667 .30673 Mtetra
.677 .662 .828 r
.30667 .30673 .30769 .30837 .30936 .30769 .30834 .30598 Mtetra
.655 .643 .826 r
.30834 .30598 .30936 .30769 .31102 .30699 .31 .30534 Mtetra
.594 .625 .852 r
.31 .30534 .31102 .30699 .31269 .30625 .31164 .30503 Mtetra
.439 .63 .935 r
.31164 .30503 .31269 .30625 .31437 .30546 .31326 .30513 Mtetra
0 .552 .811 r
.31326 .30513 .31437 .30546 .31604 .30469 .31486 .30537 Mtetra
.108 0 0 r
.31486 .30537 .31604 .30469 .31773 .30378 .31651 .30505 Mtetra
0 0 0 r
.31651 .30505 .31773 .30378 .31942 .3028 .31821 .30401 Mtetra
.158 0 0 r
.31821 .30401 .31942 .3028 .32108 .30227 .31987 .30345 Mtetra
.718 .297 .248 r
.31987 .30345 .32108 .30227 .32265 .30313 .32138 .30526 Mtetra
.952 .68 .486 r
.32138 .30526 .32265 .30313 .32393 .30847 .31 .50693 Mtetra
.539 .306 .51 r
.31 .50693 .32393 .30847 .31262 .51195 .31122 .51492 Mtetra
.654 .294 .349 r
.31122 .51492 .31262 .51195 .31411 .51583 .31285 .51671 Mtetra
.176 0 0 r
.31285 .51671 .31411 .51583 .31582 .51638 .31462 .51639 Mtetra
.581 .937 .928 r
.31462 .51639 .31582 .51638 .31758 .51624 .31642 .51557 Mtetra
.703 .858 .956 r
.31642 .51557 .31758 .51624 .31936 .51579 .31822 .51473 Mtetra
.626 .756 .94 r
.31822 .51473 .31936 .51579 .32114 .51528 .32001 .51424 Mtetra
.654 .769 .934 r
.32001 .51424 .32114 .51528 .32293 .51464 .3218 .51363 Mtetra
.685 .783 .925 r
.3218 .51363 .32293 .51464 .32471 .51415 .32359 .51289 Mtetra
.719 .745 .873 r
.32359 .51289 .32471 .51415 .32648 .51391 .32541 .51193 Mtetra
.748 .667 .771 r
.32541 .51193 .32648 .51391 .32828 .51323 .32726 .51036 Mtetra
.808 .64 .674 r
.32726 .51036 .32828 .51323 .33016 .51117 .32923 .50674 Mtetra
.953 .686 .491 r
.32923 .50674 .33016 .51117 .33231 .5045 .3428 .30396 Mtetra
.546 .316 .518 r
.3428 .30396 .33231 .5045 .34583 .29938 .34501 .2943 Mtetra
.71 .524 .635 r
.34501 .2943 .34583 .29938 .34775 .29464 .34682 .29141 Mtetra
.639 .526 .709 r
.34682 .29141 .34775 .29464 .34945 .29372 .34852 .29053 Mtetra
.587 .496 .718 r
.34852 .29053 .34945 .29372 .35112 .29341 .35019 .29014 Mtetra
.57 .482 .715 r
.35019 .29014 .35112 .29341 .3528 .29293 .35186 .28989 Mtetra
.601 .512 .726 r
.35186 .28989 .3528 .29293 .35453 .29156 .35354 .28941 Mtetra
.618 .582 .791 r
.35354 .28941 .35453 .29156 .35625 .29028 .35522 .28892 Mtetra
.646 .694 .88 r
.35522 .28892 .35625 .29028 .35796 .28927 .35691 .28838 Mtetra
.676 .793 .936 r
.35691 .28838 .35796 .28927 .35965 .28869 .3586 .28771 Mtetra
.684 .777 .922 r
.3586 .28771 .35965 .28869 .36133 .28822 .3603 .28702 Mtetra
.685 .735 .889 r
.3603 .28702 .36133 .28822 .36302 .28773 .36199 .2863 Mtetra
.681 .695 .856 r
.36199 .2863 .36302 .28773 .36471 .28711 .3637 .28556 Mtetra
.659 .669 .849 r
.3637 .28556 .36471 .28711 .36641 .28647 .36539 .28492 Mtetra
.633 .66 .859 r
.36539 .28492 .36641 .28647 .36811 .28568 .36708 .28442 Mtetra
.59 .691 .912 r
.36708 .28442 .36811 .28568 .36983 .28463 .36876 .2841 Mtetra
.155 .632 .925 r
.36876 .2841 .36983 .28463 .37153 .28397 .37042 .2843 Mtetra
.74 .254 .088 r
.37042 .2843 .37153 .28397 .37318 .28436 .372 .28605 Mtetra
.957 .681 .471 r
.372 .28605 .37318 .28436 .37464 .28875 .36396 .48575 Mtetra
.545 .311 .511 r
.36396 .48575 .37464 .28875 .36655 .49317 .36521 .4969 Mtetra
.668 .324 .381 r
.36521 .4969 .36655 .49317 .36811 .49796 .36689 .49923 Mtetra
.32 0 0 r
.36689 .49923 .36811 .49796 .36991 .49783 .36869 .49904 Mtetra
.066 0 0 r
.36869 .49904 .36991 .49783 .37174 .49698 .37052 .49828 Mtetra
.015 0 0 r
.37052 .49828 .37174 .49698 .37357 .49617 .37236 .49735 Mtetra
.173 0 0 r
.37236 .49735 .37357 .49617 .37535 .49643 .37418 .49684 Mtetra
0 0 0 r
.37418 .49684 .37535 .49643 .37714 .49665 .376 .49623 Mtetra
.673 .909 .976 r
.376 .49623 .37714 .49665 .37894 .49666 .37784 .49541 Mtetra
.766 .763 .85 r
.37784 .49541 .37894 .49666 .38076 .49628 .3797 .4941 Mtetra
.731 .646 .765 r
.3797 .4941 .38076 .49628 .38258 .49576 .38156 .49262 Mtetra
.676 .561 .718 r
.38156 .49262 .38258 .49576 .38441 .49523 .38342 .49133 Mtetra
.555 .457 .699 r
.38342 .49133 .38441 .49523 .38622 .49496 .38523 .49118 Mtetra
.594 .486 .701 r
.38523 .49118 .38622 .49496 .38806 .4943 .38706 .49066 Mtetra
.701 .557 .688 r
.38706 .49066 .38806 .4943 .38993 .4927 .38895 .48878 Mtetra
.902 .662 .567 r
.38895 .48878 .38993 .4927 .39196 .48733 .3913 .47527 Mtetra
.95 .676 .483 r
.3913 .47527 .39196 .48733 .40191 .28175 .4011 .27515 Mtetra
.71 .506 .611 r
.4011 .27515 .40191 .28175 .40389 .27468 .40295 .27132 Mtetra
.65 .528 .702 r
.40295 .27132 .40389 .27468 .40563 .27353 .40469 .27027 Mtetra
.597 .5 .715 r
.40469 .27027 .40563 .27353 .40734 .27312 .4064 .26979 Mtetra
.567 .478 .714 r
.4064 .26979 .40734 .27312 .40905 .27281 .40811 .26956 Mtetra
.6 .502 .715 r
.40811 .26956 .40905 .27281 .4108 .27142 .40983 .26905 Mtetra
.614 .564 .775 r
.40983 .26905 .4108 .27142 .41255 .27007 .41155 .26856 Mtetra
.633 .668 .866 r
.41155 .26856 .41255 .27007 .4143 .26892 .41327 .26806 Mtetra
.646 .798 .955 r
.41327 .26806 .4143 .26892 .41603 .26822 .41499 .26749 Mtetra
.65 .829 .969 r
.41499 .26749 .41603 .26822 .41775 .26764 .41672 .26688 Mtetra
.664 .825 .961 r
.41672 .26688 .41775 .26764 .41948 .26711 .41845 .26623 Mtetra
.683 .804 .939 r
.41845 .26623 .41948 .26711 .4212 .26649 .42018 .26552 Mtetra
.686 .786 .926 r
.42018 .26552 .4212 .26649 .42294 .26587 .42192 .2648 Mtetra
.683 .765 .914 r
.42192 .2648 .42294 .26587 .42467 .26524 .42365 .26409 Mtetra
.668 .744 .907 r
.42365 .26409 .42467 .26524 .4264 .26462 .42538 .26345 Mtetra
.663 .739 .906 r
.42538 .26345 .4264 .26462 .42813 .264 .42712 .26282 Mtetra
.661 .736 .905 r
.42712 .26282 .42813 .264 .42987 .26341 .42885 .2622 Mtetra
.66 .731 .902 r
.42885 .2622 .42987 .26341 .4316 .26287 .43059 .26158 Mtetra
.659 .716 .891 r
.43059 .26158 .4316 .26287 .43333 .26234 .43233 .26097 Mtetra
.658 .701 .878 r
.43233 .26097 .43333 .26234 .43507 .2618 .43407 .26035 Mtetra
.659 .689 .867 r
.43407 .26035 .43507 .2618 .43681 .2612 .43581 .25971 Mtetra
.66 .685 .862 r
.43581 .25971 .43681 .2612 .43855 .26056 .43755 .25907 Mtetra
.662 .684 .86 r
.43755 .25907 .43855 .26056 .44029 .2599 .43929 .25841 Mtetra
.682 .692 .853 r
.43929 .25841 .44029 .2599 .44203 .25923 .44104 .25764 Mtetra
.667 .672 .846 r
.44104 .25764 .44203 .25923 .44378 .25854 .44278 .25694 Mtetra
.64 .659 .853 r
.44278 .25694 .44378 .25854 .44553 .25784 .44453 .25638 Mtetra
.618 .673 .88 r
.44453 .25638 .44553 .25784 .44729 .25669 .44627 .25594 Mtetra
.384 .718 .988 r
.44627 .25594 .44729 .25669 .44904 .25586 .448 .25594 Mtetra
.525 0 0 r
.448 .25594 .44904 .25586 .45077 .25564 .44971 .25682 Mtetra
.906 .561 .378 r
.44971 .25682 .45077 .25564 .45244 .25851 .45124 .26572 Mtetra
.958 .672 .453 r
.45124 .26572 .45244 .25851 .44955 .46042 .44826 .46859 Mtetra
.645 .344 .446 r
.44826 .46859 .44955 .46042 .45117 .47061 .45004 .47208 Mtetra
.414 0 .049 r
.45004 .47208 .45117 .47061 .45301 .47176 .4519 .47213 Mtetra
.266 .76 .691 r
.4519 .47213 .45301 .47176 .45487 .47185 .45378 .47144 Mtetra
.726 .929 .958 r
.45378 .47144 .45487 .47185 .45674 .47142 .45567 .4704 Mtetra
.629 .776 .951 r
.45567 .4704 .45674 .47142 .45862 .47085 .45755 .46985 Mtetra
.639 .784 .951 r
.45755 .46985 .45862 .47085 .46051 .47013 .45943 .46926 Mtetra
.675 .823 .954 r
.45943 .46926 .46051 .47013 .46239 .46935 .46131 .46852 Mtetra
.698 .837 .949 r
.46131 .46852 .46239 .46935 .46427 .46922 .4632 .46767 Mtetra
.747 .723 .83 r
.4632 .46767 .46427 .46922 .46615 .46884 .4651 .46637 Mtetra
.771 .648 .726 r
.4651 .46637 .46615 .46884 .46804 .46781 .46702 .46415 Mtetra
.887 .658 .587 r
.46702 .46415 .46804 .46781 .46999 .46358 .46905 .45484 Mtetra
.961 .68 .457 r
.46905 .45484 .46999 .46358 .47512 .2622 .4743 .24962 Mtetra
.652 .433 .573 r
.4743 .24962 .47512 .2622 .47709 .2487 .47613 .24511 Mtetra
.662 .528 .69 r
.47613 .24511 .47709 .2487 .47888 .24638 .47791 .24383 Mtetra
.612 .551 .762 r
.47791 .24383 .47888 .24638 .48066 .24517 .47968 .24331 Mtetra
.563 .592 .84 r
.47968 .24331 .48066 .24517 .48243 .24441 .48144 .24313 Mtetra
.676 .727 .888 r
.48144 .24313 .48243 .24441 .4842 .24369 .48321 .24242 Mtetra
.686 .732 .886 r
.48321 .24242 .4842 .24369 .48597 .24306 .48498 .24166 Mtetra
.658 .7 .878 r
.48498 .24166 .48597 .24306 .48774 .24248 .48676 .24102 Mtetra
.626 .679 .88 r
.48676 .24102 .48774 .24248 .48952 .24142 .48853 .24054 Mtetra
.458 .725 .983 r
.48853 .24054 .48952 .24142 .4913 .24054 .4903 .24046 Mtetra
.399 0 0 r
.4903 .24046 .4913 .24054 .49307 .24022 .49206 .24116 Mtetra
.885 .51 .322 r
.49206 .24116 .49307 .24022 .49482 .24249 .49377 .24726 Mtetra
.964 .675 .436 r
.49377 .24726 .49482 .24249 .49481 .43504 .49358 .45299 Mtetra
.598 .329 .48 r
.49358 .45299 .49481 .43504 .49652 .45539 .49544 .45709 Mtetra
.501 .06 .133 r
.49544 .45709 .49652 .45539 .49841 .45706 .49734 .4575 Mtetra
0 0 0 r
.49734 .4575 .49841 .45706 .50031 .45726 .49925 .45686 Mtetra
.751 .937 .946 r
.49925 .45686 .50031 .45726 .50222 .45692 .50117 .45569 Mtetra
.703 .763 .898 r
.50117 .45569 .50222 .45692 .50413 .4568 .50308 .45479 Mtetra
.708 .66 .8 r
.50308 .45479 .50413 .4568 .50604 .45636 .505 .45364 Mtetra
.743 .622 .724 r
.505 .45364 .50604 .45636 .50796 .45526 .50692 .45166 Mtetra
.866 .65 .608 r
.50692 .45166 .50796 .45526 .50989 .45158 .50887 .4446 Mtetra
.966 .682 .442 r
.50887 .4446 .50989 .45158 .51186 .43735 .51167 .2372 Mtetra
.536 .307 .516 r
.51167 .2372 .51186 .43735 .51445 .23591 .51348 .23201 Mtetra
.674 .526 .676 r
.51348 .23201 .51445 .23591 .51625 .23301 .51528 .23043 Mtetra
.617 .553 .76 r
.51528 .23043 .51625 .23301 .51804 .23164 .51707 .22987 Mtetra
.56 .603 .853 r
.51707 .22987 .51804 .23164 .51984 .23078 .51886 .22969 Mtetra
.617 .746 .938 r
.51886 .22969 .51984 .23078 .52163 .2301 .52066 .22922 Mtetra
.654 .806 .956 r
.52066 .22922 .52163 .2301 .52343 .22955 .52245 .22859 Mtetra
.666 .791 .942 r
.52245 .22859 .52343 .22955 .52522 .22909 .52425 .22793 Mtetra
.752 .776 .873 r
.52425 .22793 .52522 .22909 .52702 .22816 .52605 .2268 Mtetra
.722 .733 .859 r
.52605 .2268 .52702 .22816 .52882 .22729 .52785 .2258 Mtetra
.599 .664 .884 r
.52785 .2258 .52882 .22729 .53062 .22694 .52965 .22543 Mtetra
0 0 .401 r
.52965 .22543 .53062 .22694 .53243 .22891 .53146 .22817 Mtetra
.972 .68 .412 r
.53146 .22817 .53243 .22891 .53428 .24527 .53383 .43554 Mtetra
.539 .305 .508 r
.53383 .43554 .53428 .24527 .53682 .44202 .53579 .44358 Mtetra
.585 .137 .153 r
.53579 .44358 .53682 .44202 .53877 .44401 .53773 .44455 Mtetra
0 0 0 r
.53773 .44455 .53877 .44401 .54071 .44423 .53967 .4439 Mtetra
.737 .952 .947 r
.53967 .4439 .54071 .44423 .54265 .44387 .54161 .44273 Mtetra
.591 .744 .949 r
.54161 .44273 .54265 .44387 .54459 .44361 .54355 .44232 Mtetra
.562 .701 .934 r
.54355 .44232 .54459 .44361 .54653 .44313 .5455 .44204 Mtetra
.713 .795 .916 r
.5455 .44204 .54653 .44313 .54847 .44202 .54744 .4411 Mtetra
.939 .812 .693 r
.54744 .4411 .54847 .44202 .55039 .43862 .54936 .43704 Mtetra
.973 .687 .42 r
.54936 .43704 .55039 .43862 .55224 .42665 .54962 .22904 Mtetra
.546 .316 .517 r
.54962 .22904 .55224 .42665 .55234 .22268 .55136 .21887 Mtetra
.717 .556 .67 r
.55136 .21887 .55234 .22268 .55414 .21949 .55316 .21662 Mtetra
.619 .537 .74 r
.55316 .21662 .55414 .21949 .55595 .21814 .55498 .21599 Mtetra
.553 .556 .812 r
.55498 .21599 .55595 .21814 .55776 .21732 .5568 .21586 Mtetra
.595 .67 .892 r
.5568 .21586 .55776 .21732 .55958 .21662 .55862 .2155 Mtetra
.655 .758 .925 r
.55862 .2155 .55958 .21662 .5614 .21599 .56045 .21488 Mtetra
.664 .763 .924 r
.56045 .21488 .5614 .21599 .56323 .21543 .56227 .21422 Mtetra
.741 .768 .875 r
.56227 .21422 .56323 .21543 .56504 .21452 .56409 .21314 Mtetra
.73 .737 .856 r
.56409 .21314 .56504 .21452 .56686 .21358 .56591 .21207 Mtetra
.621 .674 .88 r
.56591 .21207 .56686 .21358 .56869 .21313 .56773 .2116 Mtetra
0 .038 .597 r
.56773 .2116 .56869 .21313 .57055 .21468 .5696 .21373 Mtetra
.974 .678 .395 r
.5696 .21373 .57055 .21468 .57254 .2241 .57459 .41942 Mtetra
.543 .308 .509 r
.57459 .41942 .57254 .2241 .5777 .42818 .57673 .42993 Mtetra
.641 .208 .203 r
.57673 .42993 .5777 .42818 .57971 .43062 .57873 .43141 Mtetra
.082 0 0 r
.57873 .43141 .57971 .43062 .58169 .43085 .5807 .4309 Mtetra
.632 .963 .878 r
.5807 .4309 .58169 .43085 .58367 .43049 .58266 .42973 Mtetra
.739 .873 .942 r
.58266 .42973 .58367 .43049 .58564 .43035 .58462 .42866 Mtetra
.706 .699 .841 r
.58462 .42866 .58564 .43035 .58762 .43017 .58658 .42762 Mtetra
.732 .63 .745 r
.58658 .42762 .58762 .43017 .58959 .42929 .58853 .42592 Mtetra
.831 .64 .644 r
.58853 .42592 .58959 .42929 .59151 .4259 .59043 .42128 Mtetra
.973 .682 .41 r
.59043 .42128 .59151 .4259 .59289 .39712 .58808 .21314 Mtetra
.542 .312 .516 r
.58808 .21314 .59289 .39712 .59072 .20693 .58977 .20556 Mtetra
.856 .768 .764 r
.58977 .20556 .59072 .20693 .59252 .20412 .59158 .20318 Mtetra
.697 .813 .937 r
.59158 .20318 .59252 .20412 .59436 .20335 .59342 .20237 Mtetra
.575 .76 .966 r
.59342 .20237 .59436 .20335 .59621 .20312 .59527 .202 Mtetra
.68 .77 .919 r
.59527 .202 .59621 .20312 .59806 .20254 .59711 .20126 Mtetra
.727 .756 .875 r
.59711 .20126 .59806 .20254 .59989 .2016 .59895 .20025 Mtetra
.617 .701 .905 r
.59895 .20025 .59989 .2016 .60175 .2011 .6008 .19979 Mtetra
0 .128 .664 r
.6008 .19979 .60175 .2011 .60364 .20231 .60271 .20156 Mtetra
.975 .676 .381 r
.60271 .20156 .60364 .20231 .6057 .20944 .60994 .40483 Mtetra
.548 .311 .509 r
.60994 .40483 .6057 .20944 .61321 .41596 .61229 .418 Mtetra
.66 .241 .239 r
.61229 .418 .61321 .41596 .6153 .41896 .61435 .41978 Mtetra
.091 0 0 r
.61435 .41978 .6153 .41896 .61731 .41926 .61635 .41925 Mtetra
.618 .958 .891 r
.61635 .41925 .61731 .41926 .61931 .41892 .61833 .41814 Mtetra
.64 .848 .98 r
.61833 .41814 .61931 .41892 .62132 .41864 .62032 .41745 Mtetra
.517 .706 .956 r
.62032 .41745 .62132 .41864 .62333 .41842 .62233 .41728 Mtetra
.666 .779 .933 r
.62233 .41728 .62333 .41842 .62532 .41754 .62433 .41654 Mtetra
.907 .836 .764 r
.62433 .41654 .62532 .41754 .62724 .4145 .62626 .4137 Mtetra
.983 .748 .501 r
.62626 .4137 .62724 .4145 .62878 .39963 .62787 .40111 Mtetra
.978 .686 .383 r
.62787 .40111 .62878 .39963 .62408 .19546 .62316 .1944 Mtetra
.924 .808 .714 r
.62316 .1944 .62408 .19546 .62586 .19223 .62493 .19104 Mtetra
.713 .77 .897 r
.62493 .19104 .62586 .19223 .62772 .19132 .62679 .19012 Mtetra
.582 .716 .935 r
.62679 .19012 .62772 .19132 .62959 .19097 .62867 .18977 Mtetra
.643 .743 .921 r
.62867 .18977 .62959 .19097 .63146 .19039 .63054 .18919 Mtetra
.736 .775 .885 r
.63054 .18919 .63146 .19039 .63332 .18934 .63239 .18813 Mtetra
.631 .736 .923 r
.63239 .18813 .63332 .18934 .63519 .1888 .63427 .1876 Mtetra
0 .272 .772 r
.63427 .1876 .63519 .1888 .63713 .19007 .63621 .18894 Mtetra
.961 .624 .274 r
.63621 .18894 .63713 .19007 .63951 .20278 .63881 .20756 Mtetra
.971 .667 .378 r
.63881 .20756 .63951 .20278 .64927 .40668 .6483 .40588 Mtetra
.627 .111 0 r
.6483 .40588 .64927 .40668 .65142 .4093 .65044 .40831 Mtetra
.48 .733 .982 r
.65044 .40831 .65142 .4093 .65346 .40931 .65248 .40816 Mtetra
.745 .805 .9 r
.65248 .40816 .65346 .40931 .65546 .40821 .65448 .407 Mtetra
.886 .812 .77 r
.65448 .407 .65546 .40821 .65738 .40512 .65642 .40432 Mtetra
.981 .794 .579 r
.65642 .40432 .65738 .40512 .65887 .39179 .65818 .39739 Mtetra
.98 .687 .36 r
.65818 .39739 .65887 .39179 .65218 .18532 .65141 .18774 Mtetra
0 0 0 r
.65141 .18774 .65218 .18532 .65394 .18184 .65311 .18266 Mtetra
.65311 .18266 .65394 .18184 .65581 .18097 .65495 .18096 Mtetra
.604 .953 .882 r
.65495 .18096 .65581 .18097 .65771 .18068 .65682 .17992 Mtetra
.675 .855 .968 r
.65682 .17992 .65771 .18068 .65962 .18042 .6587 .17916 Mtetra
.672 .744 .905 r
.6587 .17916 .65962 .18042 .6615 .1797 .66059 .17843 Mtetra
.653 .737 .911 r
.66059 .17843 .6615 .1797 .66339 .17903 .66248 .1778 Mtetra
.7 .76 .898 r
.66248 .1778 .66339 .17903 .66528 .17842 .66436 .17693 Mtetra
.744 .734 .842 r
.66436 .17693 .66528 .17842 .66718 .17791 .66623 .17572 Mtetra
.646 .607 .796 r
.66623 .17572 .66718 .17791 .66911 .1779 .66812 .17499 Mtetra
.41 .413 .752 r
.66812 .17499 .66911 .1779 .67112 .17961 .67008 .17578 Mtetra
0 0 .225 r
.67008 .17578 .67112 .17961 .68308 .383 .67241 .18391 Mtetra
0 0 .368 r
.67241 .18391 .68308 .383 .68574 .3949 .68475 .39319 Mtetra
0 0 .489 r
.68475 .39319 .68574 .3949 .68794 .39728 .68698 .39634 Mtetra
.41 .709 .984 r
.68698 .39634 .68794 .39728 .69002 .39739 .68906 .39634 Mtetra
.727 .824 .925 r
.68906 .39634 .69002 .39739 .69205 .39645 .69109 .39529 Mtetra
.878 .826 .793 r
.69109 .39529 .69205 .39645 .69399 .39379 .69304 .39286 Mtetra
.977 .799 .597 r
.69304 .39286 .69399 .39379 .69553 .38352 .6948 .38665 Mtetra
.979 .681 .349 r
.6948 .38665 .69553 .38352 .6863 .17362 .68561 .17648 Mtetra
0 0 0 r
.68561 .17648 .6863 .17362 .68802 .16962 .68724 .17051 Mtetra
.68724 .17051 .68802 .16962 .68991 .16866 .68908 .1687 Mtetra
.593 .949 .856 r
.68908 .1687 .68991 .16866 .69184 .16833 .69097 .16761 Mtetra
.67 .865 .973 r
.69097 .16761 .69184 .16833 .69378 .16817 .69287 .16684 Mtetra
.67 .734 .898 r
.69287 .16684 .69378 .16817 .69569 .16753 .69478 .16611 Mtetra
.647 .708 .892 r
.69478 .16611 .69569 .16753 .6976 .16686 .6967 .16549 Mtetra
.672 .728 .892 r
.6967 .16549 .6976 .16686 .6995 .16599 .69861 .16475 Mtetra
.752 .779 .875 r
.69861 .16475 .6995 .16599 .70138 .16474 .70049 .16357 Mtetra
.671 .766 .922 r
.70049 .16357 .70138 .16474 .70329 .16393 .70241 .16284 Mtetra
.227 .548 .93 r
.70241 .16284 .70329 .16393 .70527 .16434 .7044 .16338 Mtetra
.893 .493 .064 r
.7044 .16338 .70527 .16434 .70761 .17048 .7068 .17066 Mtetra
.974 .664 .332 r
.7068 .17066 .70761 .17048 .72259 .38137 .72168 .3808 Mtetra
.759 .265 0 r
.72168 .3808 .72259 .38137 .72493 .3852 .724 .38424 Mtetra
.511 .759 .986 r
.724 .38424 .72493 .3852 .72704 .38513 .7261 .38398 Mtetra
.709 .802 .923 r
.7261 .38398 .72704 .38513 .7291 .38425 .72815 .38301 Mtetra
.726 .79 .903 r
.72815 .38301 .7291 .38425 .73114 .38301 .7302 .38193 Mtetra
.466 .709 .974 r
.7302 .38193 .73114 .38301 .7332 .38218 .73231 .38185 Mtetra
.466 .868 .962 r
.73231 .38185 .7332 .38218 .73523 .38083 .7344 .3813 Mtetra
.598 .913 .659 r
.7344 .3813 .73523 .38083 .73717 .37813 .73641 .37953 Mtetra
.944 .828 .385 r
.73641 .37953 .73717 .37813 .7384 .36471 .73802 .37182 Mtetra
.977 .678 .316 r
.73802 .37182 .7384 .36471 .72662 .15943 .72579 .1589 Mtetra
.989 .844 .608 r
.72579 .1589 .72662 .15943 .72834 .15549 .72743 .15391 Mtetra
.727 .72 .843 r
.72743 .15391 .72834 .15549 .73024 .15437 .72934 .15278 Mtetra
.609 .665 .879 r
.72934 .15278 .73024 .15437 .73218 .15382 .73129 .15233 Mtetra
.555 .656 .903 r
.73129 .15233 .73218 .15382 .73414 .1534 .73326 .15211 Mtetra
.731 .768 .882 r
.73326 .15211 .73414 .1534 .73604 .15216 .73517 .15105 Mtetra
.67 .781 .933 r
.73517 .15105 .73604 .15216 .73797 .15134 .73711 .15032 Mtetra
.416 .678 .97 r
.73711 .15032 .73797 .15134 .73997 .15152 .7391 .15038 Mtetra
.67 .222 0 r
.7391 .15038 .73997 .15152 .74237 .15719 .74136 .15397 Mtetra
.972 .661 .302 r
.74136 .15397 .74237 .15719 .75998 .36913 .75868 .36279 Mtetra
0 0 .518 r
.75868 .36279 .75998 .36913 .76245 .37341 .76133 .36964 Mtetra
.432 .396 .718 r
.76133 .36964 .76245 .37341 .76459 .37335 .76354 .37055 Mtetra
.532 .511 .779 r
.76354 .37055 .76459 .37335 .76667 .37245 .7657 .37056 Mtetra
.595 .635 .861 r
.7657 .37056 .76667 .37245 .76872 .37107 .76782 .37015 Mtetra
.459 .745 .99 r
.76782 .37015 .76872 .37107 .77081 .37022 .76996 .37 Mtetra
.457 .878 .929 r
.76996 .37 .77081 .37022 .77286 .36888 .77207 .36935 Mtetra
.469 .849 .628 r
.77207 .36935 .77286 .36888 .77483 .36644 .77411 .36787 Mtetra
.785 .821 .345 r
.77411 .36787 .77483 .36644 .77605 .35464 .77589 .36298 Mtetra
.973 .672 .291 r
.77589 .36298 .77605 .35464 .76164 .14683 .76145 .15407 Mtetra
0 0 .198 r
.76145 .15407 .76164 .14683 .76331 .14256 .76263 .14367 Mtetra
0 0 0 r
.76263 .14367 .76331 .14256 .76522 .14135 .76447 .14139 Mtetra
.674 .975 .827 r
.76447 .14139 .76522 .14135 .76719 .1408 .76637 .14 Mtetra
.718 .872 .954 r
.76637 .14 .76719 .1408 .7692 .14067 .76831 .13903 Mtetra
.692 .7 .853 r
.76831 .13903 .7692 .14067 .77122 .14065 .77025 .13812 Mtetra
.641 .58 .77 r
.77025 .13812 .77122 .14065 .77324 .1407 .77221 .13734 Mtetra
.611 .514 .719 r
.77221 .13734 .77324 .1407 .77526 .14058 .77418 .13666 Mtetra
.672 .656 .825 r
.14491 .36246 .14597 .36405 .14753 .36344 .14649 .36177 Mtetra
.633 .631 .83 r
.14649 .36177 .14753 .36344 .14909 .3629 .14804 .36129 Mtetra
.556 .605 .857 r
.14804 .36129 .14909 .3629 .15063 .3625 .14955 .36115 Mtetra
0 .295 .791 r
.14955 .36115 .15063 .3625 .15217 .36212 .15094 .36209 Mtetra
.826 .389 .198 r
.15094 .36209 .15217 .36212 .15367 .36212 .15217 .36434 Mtetra
.859 .554 .472 r
.15217 .36434 .15367 .36212 .15508 .36287 .15271 .37263 Mtetra
.924 .667 .53 r
.15271 .37263 .15508 .36287 .15585 .36921 .13164 .56719 Mtetra
.531 .299 .508 r
.13164 .56719 .15585 .36921 .13437 .56879 .13284 .57065 Mtetra
.652 .262 .294 r
.13284 .57065 .13437 .56879 .13553 .57267 .13429 .57198 Mtetra
.576 .809 .988 r
.13429 .57198 .13553 .57267 .13713 .57269 .13594 .5716 Mtetra
.727 .758 .877 r
.13594 .5716 .13713 .57269 .13883 .57188 .13765 .57065 Mtetra
.759 .742 .837 r
.13765 .57065 .13883 .57188 .14058 .57062 .1394 .56942 Mtetra
.704 .736 .876 r
.1394 .56942 .14058 .57062 .14228 .5698 .1411 .56859 Mtetra
.684 .731 .886 r
.1411 .56859 .14228 .5698 .14397 .56904 .14279 .56788 Mtetra
.666 .735 .901 r
.14279 .56788 .14397 .56904 .14566 .56833 .14447 .56725 Mtetra
.638 .744 .925 r
.14447 .56725 .14566 .56833 .14734 .56775 .14614 .56675 Mtetra
.606 .75 .946 r
.14614 .56675 .14734 .56775 .149 .56727 .14779 .56635 Mtetra
.57 .756 .966 r
.14779 .56635 .149 .56727 .15066 .56688 .14944 .56604 Mtetra
.304 .66 .972 r
.14944 .56604 .15066 .56688 .15229 .56676 .15104 .5662 Mtetra
.348 .745 .984 r
.15104 .5662 .15229 .56676 .15392 .56658 .15266 .56615 Mtetra
.597 .87 .993 r
.15266 .56615 .15392 .56658 .15558 .56621 .15434 .56562 Mtetra
.867 .831 .809 r
.15434 .56562 .15558 .56621 .15727 .56559 .15619 .56349 Mtetra
.843 .679 .679 r
.15619 .56349 .15727 .56559 .15901 .56445 .15825 .55943 Mtetra
.935 .682 .53 r
.15825 .55943 .15901 .56445 .16086 .56233 .18008 .37223 Mtetra
.568 .336 .524 r
.18008 .37223 .16086 .56233 .16353 .5526 .1836 .35365 Mtetra
.533 .306 .516 r
.1836 .35365 .16353 .5526 .18638 .35341 .18553 .34995 Mtetra
.723 .565 .675 r
.18553 .34995 .18638 .35341 .18835 .34916 .18728 .34777 Mtetra
.724 .701 .828 r
.18728 .34777 .18835 .34916 .19002 .34784 .18891 .34678 Mtetra
.65 .737 .913 r
.18891 .34678 .19002 .34784 .1916 .34732 .19049 .34625 Mtetra
.582 .716 .935 r
.19049 .34625 .1916 .34732 .19314 .34714 .19205 .34596 Mtetra
.604 .702 .913 r
.19205 .34596 .19314 .34714 .19471 .34675 .19362 .34562 Mtetra
.609 .711 .917 r
.19362 .34562 .19471 .34675 .19629 .34631 .19518 .34525 Mtetra
.621 .729 .924 r
.19518 .34525 .19629 .34631 .19787 .34584 .19676 .34483 Mtetra
.679 .756 .909 r
.19676 .34483 .19787 .34584 .19946 .34525 .19836 .34419 Mtetra
.699 .751 .892 r
.19836 .34419 .19946 .34525 .20106 .34459 .19997 .34345 Mtetra
.7 .735 .879 r
.19997 .34345 .20106 .34459 .20266 .34392 .20158 .34269 Mtetra
.68 .715 .876 r
.20158 .34269 .20266 .34392 .20426 .34328 .20318 .34202 Mtetra
.67 .708 .876 r
.20318 .34202 .20426 .34328 .20586 .34265 .20478 .3414 Mtetra
.665 .707 .878 r
.20478 .3414 .20586 .34265 .20746 .34204 .20638 .34079 Mtetra
.73 .726 .847 r
.20638 .34079 .20746 .34204 .2091 .34105 .20802 .33981 Mtetra
.702 .72 .863 r
.20802 .33981 .2091 .34105 .21072 .34025 .20964 .33901 Mtetra
.556 .672 .915 r
.20964 .33901 .21072 .34025 .21228 .34006 .2112 .33883 Mtetra
.867 .432 .025 r
.2112 .33883 .21228 .34006 .21354 .3429 .21245 .34175 Mtetra
.945 .684 .511 r
.21245 .34175 .21354 .3429 .19531 .54501 .19406 .54468 Mtetra
.926 .595 .392 r
.19406 .54468 .19531 .54501 .19618 .55293 .19497 .55227 Mtetra
.441 0 0 r
.19497 .55227 .19618 .55293 .19772 .55416 .19652 .55328 Mtetra
.64 .79 .954 r
.19652 .55328 .19772 .55416 .19941 .55378 .19823 .55274 Mtetra
.782 .78 .851 r
.19823 .55274 .19941 .55378 .20119 .55241 .20001 .5514 Mtetra
.84 .779 .793 r
.20001 .5514 .20119 .55241 .20318 .54893 .20187 .54932 Mtetra
.953 .913 .738 r
.20187 .54932 .20318 .54893 .20596 .53707 .20384 .54602 Mtetra
0 0 .135 r
.20384 .54602 .20596 .53707 .22633 .33889 .20618 .53878 Mtetra
0 0 .129 r
.20618 .53878 .22633 .33889 .22817 .33593 .22651 .34082 Mtetra
0 0 0 r
.22651 .34082 .22817 .33593 .22984 .33462 .22854 .33578 Mtetra
.858 .975 .668 r
.22854 .33578 .22984 .33462 .23148 .33382 .23034 .33318 Mtetra
.798 .847 .888 r
.23034 .33318 .23148 .33382 .2331 .33314 .23202 .33194 Mtetra
.671 .722 .887 r
.23202 .33194 .2331 .33314 .23471 .33254 .23363 .33132 Mtetra
.623 .701 .901 r
.23363 .33132 .23471 .33254 .23632 .332 .23523 .33089 Mtetra
.742 .753 .862 r
.23523 .33089 .23632 .332 .23797 .331 .23689 .32988 Mtetra
.745 .752 .858 r
.23689 .32988 .23797 .331 .23962 .33004 .23855 .32884 Mtetra
.629 .708 .903 r
.23855 .32884 .23962 .33004 .24122 .32966 .24015 .32839 Mtetra
.713 .243 0 r
.24015 .32839 .24122 .32966 .24259 .33191 .24152 .33053 Mtetra
.948 .685 .504 r
.24152 .33053 .24259 .33191 .22637 .53175 .22531 .52952 Mtetra
.968 .661 .38 r
.22531 .52952 .22637 .53175 .2271 .54236 .22593 .54131 Mtetra
.637 .123 0 r
.22593 .54131 .2271 .54236 .22862 .54408 .22745 .54308 Mtetra
.506 .719 .968 r
.22745 .54308 .22862 .54408 .23031 .54395 .22914 .54294 Mtetra
.766 .787 .87 r
.22914 .54294 .23031 .54395 .2321 .54276 .23093 .54173 Mtetra
.894 .764 .711 r
.23093 .54173 .2321 .54276 .23409 .5391 .23293 .53806 Mtetra
.948 .689 .512 r
.23293 .53806 .23409 .5391 .25262 .3432 .25158 .3416 Mtetra
.932 .7 .566 r
.25158 .3416 .25262 .3432 .25562 .32665 .25454 .32554 Mtetra
.857 .759 .753 r
.25454 .32554 .25562 .32665 .25741 .32418 .25633 .32308 Mtetra
.683 .744 .897 r
.25633 .32308 .25741 .32418 .25905 .3235 .25797 .3224 Mtetra
.535 .695 .942 r
.25797 .3224 .25905 .3235 .26064 .32333 .25956 .32224 Mtetra
.677 .745 .902 r
.25956 .32224 .26064 .32333 .26228 .32267 .2612 .32158 Mtetra
.719 .755 .881 r
.2612 .32158 .26228 .32267 .26393 .3218 .26285 .32072 Mtetra
.568 .712 .939 r
.26285 .32072 .26393 .3218 .26554 .32152 .26446 .32046 Mtetra
.82 .355 0 r
.26446 .32046 .26554 .32152 .26693 .32392 .26583 .32301 Mtetra
.95 .685 .498 r
.26583 .32301 .26693 .32392 .25202 .52632 .25078 .52631 Mtetra
.918 .579 .381 r
.25078 .52631 .25202 .52632 .25306 .53443 .25187 .53376 Mtetra
.578 .017 0 r
.25187 .53376 .25306 .53443 .25464 .53583 .25345 .53511 Mtetra
.581 .812 .987 r
.25345 .53511 .25464 .53583 .25637 .5354 .25519 .53469 Mtetra
.729 .846 .936 r
.25519 .53469 .25637 .5354 .25815 .53446 .25696 .53377 Mtetra
.667 .84 .966 r
.25696 .53377 .25815 .53446 .25991 .53368 .25872 .53309 Mtetra
.563 .834 .996 r
.25872 .53309 .25991 .53368 .26166 .53316 .26046 .53267 Mtetra
.663 .881 .979 r
.26046 .53267 .26166 .53316 .26341 .53254 .26222 .53195 Mtetra
.847 .861 .853 r
.26222 .53195 .26341 .53254 .26519 .53158 .26406 .5302 Mtetra
.87 .739 .716 r
.26406 .5302 .26519 .53158 .267 .53028 .26603 .52686 Mtetra
.838 .638 .633 r
.26603 .52686 .267 .53028 .26881 .52889 .26819 .52093 Mtetra
.778 .553 .593 r
.26819 .52093 .26881 .52889 .27058 .52818 .27054 .51251 Mtetra
.506 .314 .555 r
.27054 .51251 .27058 .52818 .2723 .52801 .27218 .51332 Mtetra
.499 .311 .557 r
.27218 .51332 .2723 .52801 .27407 .52735 .27382 .51429 Mtetra
.937 .673 .511 r
.27382 .51429 .27407 .52735 .27601 .52425 .28976 .32383 Mtetra
.545 .316 .518 r
.28976 .32383 .27601 .52425 .29229 .32699 .29205 .31472 Mtetra
.637 .424 .577 r
.29205 .31472 .29229 .32699 .29492 .31319 .29392 .31111 Mtetra
.758 .65 .742 r
.29392 .31111 .29492 .31319 .29673 .31044 .29566 .30935 Mtetra
.689 .751 .899 r
.29566 .30935 .29673 .31044 .2984 .30964 .29732 .30864 Mtetra
.626 .751 .937 r
.29732 .30864 .2984 .30964 .30003 .30931 .29897 .30818 Mtetra
.659 .735 .906 r
.29897 .30818 .30003 .30931 .30167 .30891 .30062 .3076 Mtetra
.701 .717 .861 r
.30062 .3076 .30167 .30891 .30333 .3082 .30229 .30678 Mtetra
.696 .698 .848 r
.30229 .30678 .30333 .3082 .305 .30748 .30397 .30596 Mtetra
.7 .685 .832 r
.30397 .30596 .305 .30748 .30667 .30673 .30564 .30508 Mtetra
.691 .665 .82 r
.30564 .30508 .30667 .30673 .30834 .30598 .30732 .30422 Mtetra
.64 .632 .827 r
.30732 .30422 .30834 .30598 .31 .30534 .30898 .30367 Mtetra
.398 .525 .869 r
.30898 .30367 .31 .30534 .31164 .30503 .31057 .30403 Mtetra
.72 .223 0 r
.31057 .30403 .31164 .30503 .31326 .30513 .31205 .3061 Mtetra
.873 .521 .378 r
.31205 .3061 .31326 .30513 .31486 .30537 .3133 .3117 Mtetra
.945 .674 .492 r
.3133 .3117 .31486 .30537 .31651 .30505 .30205 .50391 Mtetra
.52 .29 .506 r
.30205 .50391 .31651 .30505 .31821 .30401 .30389 .50238 Mtetra
.517 .288 .505 r
.30389 .50238 .31821 .30401 .31987 .30345 .3058 .49964 Mtetra
.538 .305 .509 r
.3058 .49964 .31987 .30345 .32138 .30526 .30704 .50712 Mtetra
.534 .302 .509 r
.30704 .50712 .32138 .30526 .31 .50693 .30842 .51263 Mtetra
.639 .326 .424 r
.30842 .51263 .31 .50693 .31122 .51492 .31001 .51504 Mtetra
.509 0 0 r
.31001 .51504 .31122 .51492 .31285 .51671 .31171 .51582 Mtetra
.587 .78 .972 r
.31171 .51582 .31285 .51671 .31462 .51639 .31348 .51542 Mtetra
.681 .788 .931 r
.31348 .51542 .31462 .51639 .31642 .51557 .31527 .5147 Mtetra
.66 .805 .952 r
.31527 .5147 .31642 .51557 .31822 .51473 .31707 .51405 Mtetra
.545 .811 .995 r
.31707 .51405 .31822 .51473 .32001 .51424 .31884 .51369 Mtetra
.635 .869 .986 r
.31884 .51369 .32001 .51424 .3218 .51363 .32063 .51304 Mtetra
.806 .88 .9 r
.32063 .51304 .3218 .51363 .32359 .51289 .32247 .51167 Mtetra
.868 .764 .745 r
.32247 .51167 .32359 .51289 .32541 .51193 .3244 .50883 Mtetra
.842 .649 .641 r
.3244 .50883 .32541 .51193 .32726 .51036 .32647 .50347 Mtetra
.95 .683 .494 r
.32647 .50347 .32726 .51036 .32923 .50674 .34012 .3024 Mtetra
.541 .312 .517 r
.34012 .3024 .32923 .50674 .3428 .30396 .3422 .29503 Mtetra
.654 .45 .594 r
.3422 .29503 .3428 .30396 .34501 .2943 .34403 .29191 Mtetra
.742 .624 .728 r
.34403 .29191 .34501 .2943 .34682 .29141 .34578 .29017 Mtetra
.695 .729 .877 r
.34578 .29017 .34682 .29141 .34852 .29053 .34748 .28939 Mtetra
.624 .726 .92 r
.34748 .28939 .34852 .29053 .35019 .29014 .34915 .28894 Mtetra
.591 .701 .919 r
.34915 .28894 .35019 .29014 .35186 .28989 .35082 .28861 Mtetra
.616 .696 .901 r
.35082 .28861 .35186 .28989 .35354 .28941 .3525 .28819 Mtetra
.619 .71 .91 r
.3525 .28819 .35354 .28941 .35522 .28892 .35418 .28776 Mtetra
.649 .731 .909 r
.35418 .28776 .35522 .28892 .35691 .28838 .35587 .28721 Mtetra
.696 .744 .889 r
.35587 .28721 .35691 .28838 .3586 .28771 .35757 .28644 Mtetra
.699 .726 .871 r
.35757 .28644 .3586 .28771 .3603 .28702 .35927 .28563 Mtetra
.7 .708 .854 r
.35927 .28563 .3603 .28702 .36199 .2863 .36097 .28478 Mtetra
.699 .69 .838 r
.36097 .28478 .36199 .2863 .3637 .28556 .36268 .28391 Mtetra
.652 .654 .839 r
.36268 .28391 .3637 .28556 .36539 .28492 .36438 .2833 Mtetra
.521 .598 .871 r
.36438 .2833 .36539 .28492 .36708 .28442 .36604 .28327 Mtetra
0 .159 .67 r
.36604 .28327 .36708 .28442 .36876 .2841 .36764 .28457 Mtetra
.847 .438 .264 r
.36764 .28457 .36876 .2841 .37042 .2843 .36914 .28805 Mtetra
.954 .678 .474 r
.36914 .28805 .37042 .2843 .372 .28605 .36092 .48768 Mtetra
.538 .304 .509 r
.36092 .48768 .372 .28605 .36396 .48575 .36234 .49512 Mtetra
.602 .313 .452 r
.36234 .49512 .36396 .48575 .36521 .4969 .36401 .49749 Mtetra
.564 .039 0 r
.36401 .49749 .36521 .4969 .36689 .49923 .36576 .49834 Mtetra
.559 .771 .977 r
.36576 .49834 .36689 .49923 .36869 .49904 .36757 .498 Mtetra
.672 .778 .929 r
.36757 .498 .36869 .49904 .37052 .49828 .3694 .4973 Mtetra
.685 .795 .933 r
.3694 .4973 .37052 .49828 .37236 .49735 .37123 .49655 Mtetra
.553 .791 .988 r
.37123 .49655 .37236 .49735 .37418 .49684 .37304 .4962 Mtetra
.623 .85 .986 r
.37304 .4962 .37418 .49684 .376 .49623 .37487 .4956 Mtetra
.778 .878 .919 r
.37487 .4956 .376 .49623 .37784 .49541 .37672 .49438 Mtetra
.89 .791 .745 r
.37672 .49438 .37784 .49541 .3797 .4941 .37866 .49138 Mtetra
.855 .667 .647 r
.37866 .49138 .3797 .4941 .38156 .49262 .38068 .48626 Mtetra
.875 .628 .562 r
.38068 .48626 .38156 .49262 .38342 .49133 .38318 .47025 Mtetra
.583 .367 .553 r
.38318 .47025 .38342 .49133 .38523 .49118 .38509 .46736 Mtetra
.416 .234 .524 r
.38509 .46736 .38523 .49118 .38706 .49066 .38667 .47263 Mtetra
.941 .667 .49 r
.38667 .47263 .38706 .49066 .38895 .48878 .39608 .2887 Mtetra
.551 .32 .518 r
.39608 .2887 .38895 .48878 .3913 .47527 .39828 .27638 Mtetra
.533 .306 .515 r
.39828 .27638 .3913 .47527 .4011 .27515 .40014 .27234 Mtetra
.76 .613 .696 r
.40014 .27234 .4011 .27515 .40295 .27132 .40193 .26999 Mtetra
.709 .724 .862 r
.40193 .26999 .40295 .27132 .40469 .27027 .40366 .2691 Mtetra
.641 .73 .913 r
.40366 .2691 .40469 .27027 .4064 .26979 .40538 .26857 Mtetra
.592 .703 .92 r
.40538 .26857 .4064 .26979 .40811 .26956 .40709 .26823 Mtetra
.619 .693 .897 r
.40709 .26823 .40811 .26956 .40983 .26905 .40881 .26779 Mtetra
.613 .703 .909 r
.40881 .26779 .40983 .26905 .41155 .26856 .41053 .26738 Mtetra
.618 .72 .919 r
.41053 .26738 .41155 .26856 .41327 .26806 .41225 .26694 Mtetra
.649 .743 .919 r
.41225 .26694 .41327 .26806 .41499 .26749 .41397 .26637 Mtetra
.665 .75 .914 r
.41397 .26637 .41499 .26749 .41672 .26688 .4157 .26574 Mtetra
.68 .751 .905 r
.4157 .26574 .41672 .26688 .41845 .26623 .41743 .26504 Mtetra
.7 .747 .888 r
.41743 .26504 .41845 .26623 .42018 .26552 .41917 .26424 Mtetra
.699 .729 .874 r
.41917 .26424 .42018 .26552 .42192 .2648 .42091 .26341 Mtetra
.69 .71 .863 r
.42091 .26341 .42192 .2648 .42365 .26409 .42264 .26262 Mtetra
.666 .688 .861 r
.42264 .26262 .42365 .26409 .42538 .26345 .42438 .26194 Mtetra
.659 .681 .86 r
.42438 .26194 .42538 .26345 .42712 .26282 .42611 .2613 Mtetra
.655 .678 .86 r
.42611 .2613 .42712 .26282 .42885 .2622 .42785 .26068 Mtetra
.656 .678 .859 r
.42785 .26068 .42885 .2622 .43059 .26158 .42959 .26006 Mtetra
.655 .677 .858 r
.42959 .26006 .43059 .26158 .43233 .26097 .43133 .25943 Mtetra
.656 .676 .857 r
.43133 .25943 .43233 .26097 .43407 .26035 .43306 .25881 Mtetra
.659 .676 .855 r
.43306 .25881 .43407 .26035 .43581 .25971 .43481 .25816 Mtetra
.659 .675 .854 r
.43481 .25816 .43581 .25971 .43755 .25907 .43655 .25751 Mtetra
.66 .674 .853 r
.43655 .25751 .43755 .25907 .43929 .25841 .43829 .25685 Mtetra
.7 .69 .837 r
.43829 .25685 .43929 .25841 .44104 .25764 .44004 .25595 Mtetra
.665 .659 .834 r
.44004 .25595 .44104 .25764 .44278 .25694 .44179 .25524 Mtetra
.595 .627 .853 r
.44179 .25524 .44278 .25694 .44453 .25638 .44353 .25491 Mtetra
.075 .366 .834 r
.44353 .25491 .44453 .25638 .44627 .25594 .44523 .25591 Mtetra
.817 .345 .086 r
.44523 .25591 .44627 .25594 .448 .25594 .4469 .25855 Mtetra
.963 .678 .448 r
.4469 .25855 .448 .25594 .44971 .25682 .4439 .44989 Mtetra
.556 .319 .511 r
.4439 .44989 .44971 .25682 .45124 .26572 .44533 .46712 Mtetra
.529 .297 .507 r
.44533 .46712 .45124 .26572 .44826 .46859 .44712 .4701 Mtetra
.627 .188 .186 r
.44712 .4701 .44826 .46859 .45004 .47208 .44895 .47134 Mtetra
.469 .774 .997 r
.44895 .47134 .45004 .47208 .4519 .47213 .45082 .47114 Mtetra
.656 .79 .946 r
.45082 .47114 .4519 .47213 .45378 .47144 .4527 .47048 Mtetra
.707 .811 .93 r
.4527 .47048 .45378 .47144 .45567 .4704 .45458 .46961 Mtetra
.552 .798 .99 r
.45458 .46961 .45567 .4704 .45755 .46985 .45646 .46923 Mtetra
.589 .851 .994 r
.45646 .46923 .45755 .46985 .45943 .46926 .45834 .46869 Mtetra
.712 .895 .963 r
.45834 .46869 .45943 .46926 .46131 .46852 .46023 .46775 Mtetra
.885 .85 .803 r
.46023 .46775 .46131 .46852 .4632 .46767 .46215 .4654 Mtetra
.858 .691 .675 r
.46215 .4654 .4632 .46767 .4651 .46637 .4641 .46131 Mtetra
.894 .646 .556 r
.4641 .46131 .4651 .46637 .46702 .46415 .46624 .44676 Mtetra
.951 .669 .468 r
.46624 .44676 .46702 .46415 .46905 .45484 .47153 .24988 Mtetra
.533 .305 .515 r
.47153 .24988 .46905 .45484 .4743 .24962 .47335 .24585 Mtetra
.721 .559 .669 r
.47335 .24585 .4743 .24962 .47613 .24511 .47515 .24355 Mtetra
.701 .692 .839 r
.47515 .24355 .47613 .24511 .47791 .24383 .47692 .24264 Mtetra
.616 .722 .922 r
.47692 .24264 .47791 .24383 .47968 .24331 .47868 .24219 Mtetra
.559 .713 .944 r
.47868 .24219 .47968 .24331 .48144 .24313 .48045 .24193 Mtetra
.721 .757 .881 r
.48045 .24193 .48144 .24313 .48321 .24242 .48222 .24099 Mtetra
.705 .714 .856 r
.48222 .24099 .48321 .24242 .48498 .24166 .484 .24009 Mtetra
.64 .668 .861 r
.484 .24009 .48498 .24166 .48676 .24102 .48577 .23953 Mtetra
.235 .466 .877 r
.48577 .23953 .48676 .24102 .48853 .24054 .48753 .24024 Mtetra
.764 .251 0 r
.48753 .24024 .48853 .24054 .4903 .24046 .48927 .24247 Mtetra
.89 .546 .389 r
.48927 .24247 .4903 .24046 .49206 .24116 .49094 .2518 Mtetra
.956 .666 .445 r
.49094 .2518 .49206 .24116 .49377 .24726 .49063 .45159 Mtetra
.53 .298 .507 r
.49063 .45159 .49377 .24726 .49358 .45299 .49249 .45508 Mtetra
.631 .221 .249 r
.49249 .45508 .49358 .45299 .49544 .45709 .49438 .45647 Mtetra
.296 .712 .973 r
.49438 .45647 .49544 .45709 .49734 .4575 .49628 .45651 Mtetra
.659 .794 .947 r
.49628 .45651 .49734 .4575 .49925 .45686 .49819 .45583 Mtetra
.773 .815 .886 r
.49819 .45583 .49925 .45686 .50117 .45569 .50011 .45454 Mtetra
.856 .8 .796 r
.50011 .45454 .50117 .45569 .50308 .45479 .50204 .4523 Mtetra
.839 .676 .68 r
.50204 .4523 .50308 .45479 .505 .45364 .50397 .44855 Mtetra
.863 .626 .579 r
.50397 .44855 .505 .45364 .50692 .45166 .50594 .43855 Mtetra
.959 .674 .451 r
.50594 .43855 .50692 .45166 .50887 .4446 .5089 .23726 Mtetra
.534 .306 .515 r
.5089 .23726 .50887 .4446 .51167 .2372 .51071 .23277 Mtetra
.709 .535 .651 r
.51071 .23277 .51167 .2372 .51348 .23201 .51251 .23029 Mtetra
.712 .678 .815 r
.51251 .23029 .51348 .23201 .51528 .23043 .5143 .22923 Mtetra
.616 .724 .922 r
.5143 .22923 .51528 .23043 .51707 .22987 .51609 .22877 Mtetra
.538 .713 .953 r
.51609 .22877 .51707 .22987 .51886 .22969 .51788 .22856 Mtetra
.623 .741 .932 r
.51788 .22856 .51886 .22969 .52066 .22922 .51968 .22808 Mtetra
.664 .753 .917 r
.51968 .22808 .52066 .22922 .52245 .22859 .52148 .22743 Mtetra
.679 .753 .907 r
.52148 .22743 .52245 .22859 .52425 .22793 .52328 .2267 Mtetra
.763 .767 .855 r
.52328 .2267 .52425 .22793 .52605 .2268 .52507 .22546 Mtetra
.738 .742 .855 r
.52507 .22546 .52605 .2268 .52785 .2258 .52687 .22437 Mtetra
.618 .682 .888 r
.52687 .22437 .52785 .2258 .52965 .22543 .52868 .22392 Mtetra
0 0 .43 r
.52868 .22392 .52965 .22543 .53146 .22817 .53048 .22655 Mtetra
.973 .681 .41 r
.53048 .22655 .53146 .22817 .53383 .43554 .53279 .43413 Mtetra
.936 .566 .183 r
.53279 .43413 .53383 .43554 .53579 .44358 .53475 .44261 Mtetra
0 .374 .818 r
.53475 .44261 .53579 .44358 .53773 .44455 .5367 .44356 Mtetra
.664 .802 .949 r
.5367 .44356 .53773 .44455 .53967 .4439 .53863 .44285 Mtetra
.764 .814 .893 r
.53863 .44285 .53967 .4439 .54161 .44273 .54057 .44161 Mtetra
.572 .74 .955 r
.54057 .44161 .54161 .44273 .54355 .44232 .54252 .44126 Mtetra
.503 .723 .971 r
.54252 .44126 .54355 .44232 .5455 .44204 .54446 .44109 Mtetra
.691 .819 .944 r
.54446 .44109 .5455 .44204 .54744 .4411 .5464 .44026 Mtetra
.942 .822 .697 r
.5464 .44026 .54744 .4411 .54936 .43704 .54833 .43629 Mtetra
.974 .688 .419 r
.54833 .43629 .54936 .43704 .54962 .22904 .54866 .22818 Mtetra
.974 .747 .533 r
.54866 .22818 .54962 .22904 .55136 .21887 .55039 .21749 Mtetra
.845 .762 .771 r
.55039 .21749 .55136 .21887 .55316 .21662 .5522 .21525 Mtetra
.642 .706 .893 r
.5522 .21525 .55316 .21662 .55498 .21599 .55402 .21469 Mtetra
.501 .653 .927 r
.55402 .21469 .55498 .21599 .5568 .21586 .55584 .21464 Mtetra
.58 .707 .929 r
.55584 .21464 .5568 .21586 .55862 .2155 .55766 .21431 Mtetra
.66 .746 .914 r
.55766 .21431 .55862 .2155 .56045 .21488 .55949 .21367 Mtetra
.674 .747 .905 r
.55949 .21367 .56045 .21488 .56227 .21422 .56131 .21296 Mtetra
.753 .763 .861 r
.56131 .21296 .56227 .21422 .56409 .21314 .56313 .21178 Mtetra
.745 .745 .852 r
.56313 .21178 .56409 .21314 .56591 .21207 .56495 .21062 Mtetra
.638 .69 .883 r
.56495 .21062 .56591 .21207 .56773 .2116 .56677 .21007 Mtetra
0 .061 .617 r
.56677 .21007 .56773 .2116 .5696 .21373 .56864 .21213 Mtetra
.974 .679 .394 r
.56864 .21213 .5696 .21373 .57459 .41942 .57357 .41775 Mtetra
.946 .593 .205 r
.57357 .41775 .57459 .41942 .57673 .42993 .57571 .42895 Mtetra
0 .137 .624 r
.57571 .42895 .57673 .42993 .57873 .43141 .57771 .43053 Mtetra
.591 .802 .98 r
.57771 .43053 .57873 .43141 .5807 .4309 .57968 .43004 Mtetra
.785 .86 .905 r
.57968 .43004 .5807 .4309 .58266 .42973 .58164 .4287 Mtetra
.86 .83 .817 r
.58164 .4287 .58266 .42973 .58462 .42866 .58358 .42658 Mtetra
.851 .709 .706 r
.58358 .42658 .58462 .42866 .58658 .42762 .58551 .42328 Mtetra
.843 .623 .605 r
.58551 .42328 .58658 .42762 .58853 .42592 .58736 .41657 Mtetra
.969 .677 .419 r
.58736 .41657 .58853 .42592 .59043 .42128 .58528 .21227 Mtetra
.536 .307 .515 r
.58528 .21227 .59043 .42128 .58808 .21314 .58702 .20647 Mtetra
.675 .479 .613 r
.58702 .20647 .58808 .21314 .58977 .20556 .58881 .2036 Mtetra
.749 .673 .777 r
.58881 .2036 .58977 .20556 .59158 .20318 .59064 .20209 Mtetra
.681 .775 .922 r
.59064 .20209 .59158 .20318 .59342 .20237 .59248 .20134 Mtetra
.611 .764 .953 r
.59248 .20134 .59342 .20237 .59527 .202 .59433 .20087 Mtetra
.701 .774 .908 r
.59433 .20087 .59527 .202 .59711 .20126 .59617 .20003 Mtetra
.733 .765 .878 r
.59617 .20003 .59711 .20126 .59895 .20025 .59801 .19898 Mtetra
.62 .718 .916 r
.59801 .19898 .59895 .20025 .6008 .19979 .59986 .1985 Mtetra
0 .107 .644 r
.59986 .1985 .6008 .19979 .60271 .20156 .60177 .20032 Mtetra
.975 .676 .38 r
.60177 .20032 .60271 .20156 .60994 .40483 .60898 .40503 Mtetra
.941 .582 .293 r
.60898 .40503 .60994 .40483 .61229 .418 .6113 .41709 Mtetra
0 .097 .579 r
.6113 .41709 .61229 .418 .61435 .41978 .61335 .41879 Mtetra
.631 .797 .962 r
.61335 .41879 .61435 .41978 .61635 .41925 .61535 .41818 Mtetra
.753 .817 .903 r
.61535 .41818 .61635 .41925 .61833 .41814 .61733 .417 Mtetra
.654 .773 .936 r
.61733 .417 .61833 .41814 .62032 .41745 .61932 .41632 Mtetra
.474 .697 .965 r
.61932 .41632 .62032 .41745 .62233 .41728 .62134 .41625 Mtetra
.637 .791 .957 r
.62134 .41625 .62233 .41728 .62433 .41654 .62334 .41563 Mtetra
.905 .849 .777 r
.62334 .41563 .62433 .41654 .62626 .4137 .62527 .41292 Mtetra
.984 .757 .516 r
.62527 .41292 .62626 .4137 .62787 .40111 .62695 .40194 Mtetra
.978 .685 .384 r
.62695 .40194 .62787 .40111 .62316 .1944 .62223 .19335 Mtetra
.929 .809 .706 r
.62223 .19335 .62316 .1944 .62493 .19104 .624 .18985 Mtetra
.716 .771 .896 r
.624 .18985 .62493 .19104 .62679 .19012 .62586 .18892 Mtetra
.581 .715 .935 r
.62586 .18892 .62679 .19012 .62867 .18977 .62774 .18857 Mtetra
.643 .743 .922 r
.62774 .18857 .62867 .18977 .63054 .18919 .62961 .18799 Mtetra
.737 .776 .884 r
.62961 .18799 .63054 .18919 .63239 .18813 .63146 .18692 Mtetra
.629 .736 .924 r
.63146 .18692 .63239 .18813 .63427 .1876 .63334 .1864 Mtetra
0 .24 .747 r
.63334 .1864 .63427 .1876 .63621 .18894 .63529 .18783 Mtetra
.975 .673 .364 r
.63529 .18783 .63621 .18894 .63881 .20756 .64465 .38779 Mtetra
.557 .318 .509 r
.64465 .38779 .63881 .20756 .6483 .40588 .64733 .40512 Mtetra
.589 .064 0 r
.64733 .40512 .6483 .40588 .65044 .40831 .64946 .40733 Mtetra
.552 .769 .978 r
.64946 .40733 .65044 .40831 .65248 .40816 .65149 .40697 Mtetra
.752 .799 .89 r
.65149 .40697 .65248 .40816 .65448 .407 .65349 .40575 Mtetra
.837 .806 .821 r
.65349 .40575 .65448 .407 .65642 .40432 .65546 .40377 Mtetra
.939 .9 .761 r
.65546 .40377 .65642 .40432 .65818 .39739 .65739 .40081 Mtetra
0 0 0 r
.65739 .40081 .65818 .39739 .65141 .18774 .65921 .39542 Mtetra
0 0 .367 r
.65921 .39542 .65141 .18774 .65311 .18266 .6526 .19096 Mtetra
0 0 .272 r
.6526 .19096 .65311 .18266 .65495 .18096 .65417 .18297 Mtetra
0 0 0 r
.65417 .18297 .65495 .18096 .65682 .17992 .65595 .17967 Mtetra
.864 .975 .856 r
.65595 .17967 .65682 .17992 .6587 .17916 .65778 .17785 Mtetra
.693 .744 .89 r
.65778 .17785 .6587 .17916 .66059 .17843 .65967 .17701 Mtetra
.634 .7 .893 r
.65967 .17701 .66059 .17843 .66248 .1778 .66156 .17645 Mtetra
.682 .734 .89 r
.66156 .17645 .66248 .1778 .66436 .17693 .66345 .17567 Mtetra
.769 .777 .859 r
.66345 .17567 .66436 .17693 .66623 .17572 .66531 .17437 Mtetra
.683 .733 .888 r
.66531 .17437 .66623 .17572 .66812 .17499 .6672 .17358 Mtetra
.221 .473 .885 r
.6672 .17358 .66812 .17499 .67008 .17578 .66916 .17434 Mtetra
.905 .528 .085 r
.66916 .17434 .67008 .17578 .67241 .18391 .67151 .18286 Mtetra
.975 .669 .347 r
.67151 .18286 .67241 .18391 .68475 .39319 .6838 .39238 Mtetra
.697 .201 0 r
.6838 .39238 .68475 .39319 .68698 .39634 .68603 .3954 Mtetra
.496 .753 .987 r
.68603 .3954 .68698 .39634 .68906 .39634 .6881 .39518 Mtetra
.739 .805 .904 r
.6881 .39518 .68906 .39634 .69109 .39529 .69012 .39405 Mtetra
.833 .81 .829 r
.69012 .39405 .69109 .39529 .69304 .39286 .6921 .39212 Mtetra
.926 .885 .772 r
.6921 .39212 .69304 .39286 .6948 .38665 .69404 .38929 Mtetra
0 0 0 r
.69404 .38929 .6948 .38665 .68561 .17648 .69586 .3843 Mtetra
0 0 .381 r
.69586 .3843 .68561 .17648 .68724 .17051 .68696 .18079 Mtetra
0 0 .307 r
.68696 .18079 .68724 .17051 .68908 .1687 .68838 .171 Mtetra
0 0 0 r
.68838 .171 .68908 .1687 .69097 .16761 .69013 .16749 Mtetra
.871 .99 .824 r
.69013 .16749 .69097 .16761 .69287 .16684 .69197 .1655 Mtetra
.699 .744 .886 r
.69197 .1655 .69287 .16684 .69478 .16611 .69387 .16462 Mtetra
.632 .69 .886 r
.69387 .16462 .69478 .16611 .6967 .16549 .69579 .16407 Mtetra
.643 .707 .893 r
.69579 .16407 .6967 .16549 .69861 .16475 .69771 .16346 Mtetra
.749 .772 .872 r
.69771 .16346 .69861 .16475 .70049 .16357 .6996 .16229 Mtetra
.666 .743 .908 r
.6996 .16229 .70049 .16357 .70241 .16284 .70151 .16159 Mtetra
.25 .524 .914 r
.70151 .16159 .70241 .16284 .7044 .16338 .70351 .16219 Mtetra
.9 .514 .074 r
.70351 .16219 .7044 .16338 .7068 .17066 .70597 .17048 Mtetra
.974 .665 .331 r
.70597 .17048 .7068 .17066 .72168 .3808 .72076 .38011 Mtetra
.722 .224 0 r
.72076 .38011 .72168 .3808 .724 .38424 .72307 .38334 Mtetra
.542 .786 .988 r
.72307 .38334 .724 .38424 .7261 .38398 .72516 .38296 Mtetra
.731 .834 .928 r
.72516 .38296 .7261 .38398 .72815 .38301 .72721 .38188 Mtetra
.742 .816 .91 r
.72721 .38188 .72815 .38301 .7302 .38193 .72926 .38073 Mtetra
.46 .68 .96 r
.72926 .38073 .7302 .38193 .73231 .38185 .73138 .38072 Mtetra
.596 .762 .958 r
.73138 .38072 .73231 .38185 .7344 .3813 .73347 .38024 Mtetra
.826 .847 .863 r
.73347 .38024 .7344 .3813 .73641 .37953 .73548 .3785 Mtetra
.985 .779 .545 r
.73548 .3785 .73641 .37953 .73802 .37182 .73707 .37056 Mtetra
.977 .673 .338 r
.73707 .37056 .73802 .37182 .72579 .1589 .72488 .15719 Mtetra
.931 .751 .636 r
.72488 .15719 .72579 .1589 .72743 .15391 .72653 .15229 Mtetra
.714 .709 .844 r
.72653 .15229 .72743 .15391 .72934 .15278 .72844 .15125 Mtetra
.588 .665 .892 r
.72844 .15125 .72934 .15278 .73129 .15233 .7304 .1509 Mtetra
.521 .647 .913 r
.7304 .1509 .73129 .15233 .73326 .15211 .73238 .1508 Mtetra
.7 .752 .892 r
.73238 .1508 .73326 .15211 .73517 .15105 .7343 .1499 Mtetra
.667 .773 .929 r
.7343 .1499 .73517 .15105 .73711 .15032 .73624 .14919 Mtetra
.55 .724 .955 r
.73624 .14919 .73711 .15032 .7391 .15038 .73821 .14891 Mtetra
.144 .411 .856 r
.73821 .14891 .7391 .15038 .74136 .15397 .74028 .14996 Mtetra
.156 .193 .649 r
.74028 .14996 .74136 .15397 .75868 .36279 .74249 .15288 Mtetra
.007 0 .411 r
.74249 .15288 .75868 .36279 .76133 .36964 .7594 .35483 Mtetra
.17 .089 .515 r
.7594 .35483 .76133 .36964 .76354 .37055 .76232 .36532 Mtetra
.28 .248 .644 r
.76232 .36532 .76354 .37055 .7657 .37056 .76468 .36808 Mtetra
.316 .407 .797 r
.76468 .36808 .7657 .37056 .76782 .37015 .76691 .36918 Mtetra
.45 .728 .986 r
.76691 .36918 .76782 .37015 .76996 .37 .76906 .36909 Mtetra
.641 .83 .973 r
.76906 .36909 .76996 .37 .77207 .36935 .77117 .36837 Mtetra
.777 .861 .912 r
.77117 .36837 .77207 .36935 .77411 .36787 .77322 .36702 Mtetra
.91 .889 .798 r
.77322 .36702 .77411 .36787 .77589 .36298 .77518 .36446 Mtetra
.711 .796 .321 r
.77518 .36446 .77589 .36298 .76145 .15407 .777 .3601 Mtetra
.49 .268 .504 r
.777 .3601 .76145 .15407 .76263 .14367 .77766 .34134 Mtetra
0 0 .402 r
.77766 .34134 .76263 .14367 .76447 .14139 .76391 .14396 Mtetra
0 0 0 r
.76391 .14396 .76447 .14139 .76637 .14 .7656 .13986 Mtetra
.911 .981 .767 r
.7656 .13986 .76637 .14 .76831 .13903 .76742 .13743 Mtetra
.737 .724 .839 r
.76742 .13743 .76831 .13903 .77025 .13812 .76934 .13622 Mtetra
.67 .656 .827 r
.76934 .13622 .77025 .13812 .77221 .13734 .77129 .13538 Mtetra
.633 .631 .83 r
.77129 .13538 .77221 .13734 .77418 .13666 .77327 .13477 Mtetra
.739 .834 .923 r
.14375 .3618 .14491 .36246 .14649 .36177 .14534 .36093 Mtetra
.667 .785 .936 r
.14534 .36093 .14649 .36177 .14804 .36129 .14691 .36035 Mtetra
.466 .698 .968 r
.14691 .36035 .14804 .36129 .14955 .36115 .14841 .36031 Mtetra
.87 .426 .098 r
.14841 .36031 .14955 .36115 .15094 .36209 .1496 .36289 Mtetra
.935 .68 .526 r
.1496 .36289 .15094 .36209 .15217 .36434 .129 .55124 Mtetra
.563 .327 .516 r
.129 .55124 .15217 .36434 .15271 .37263 .12844 .56958 Mtetra
.526 .295 .507 r
.12844 .56958 .15271 .37263 .13164 .56719 .12988 .57093 Mtetra
.503 .164 .324 r
.12988 .57093 .13164 .56719 .13284 .57065 .13147 .57109 Mtetra
0 0 0 r
.13147 .57109 .13284 .57065 .13429 .57198 .13312 .57067 Mtetra
.671 .71 .877 r
.13312 .57067 .13429 .57198 .13594 .5716 .1348 .57001 Mtetra
.695 .678 .83 r
.1348 .57001 .13594 .5716 .13765 .57065 .1365 .56914 Mtetra
.712 .692 .83 r
.1365 .56914 .13765 .57065 .1394 .56942 .13822 .56817 Mtetra
.688 .725 .878 r
.13822 .56817 .1394 .56942 .1411 .56859 .13991 .56743 Mtetra
.671 .735 .899 r
.13991 .56743 .1411 .56859 .14279 .56788 .1416 .56678 Mtetra
.65 .743 .918 r
.1416 .56678 .14279 .56788 .14447 .56725 .14327 .56623 Mtetra
.607 .746 .943 r
.14327 .56623 .14447 .56725 .14614 .56675 .14493 .56583 Mtetra
.576 .758 .964 r
.14493 .56583 .14614 .56675 .14779 .56635 .14658 .5655 Mtetra
.554 .767 .977 r
.14658 .5655 .14779 .56635 .14944 .56604 .14822 .56521 Mtetra
.277 .648 .967 r
.14822 .56521 .14944 .56604 .15104 .5662 .14982 .5654 Mtetra
.479 .751 .989 r
.14982 .5654 .15104 .5662 .15266 .56615 .15145 .56525 Mtetra
.717 .796 .914 r
.15145 .56525 .15266 .56615 .15434 .56562 .15316 .5644 Mtetra
.885 .737 .692 r
.15316 .5644 .15434 .56562 .15619 .56349 .15524 .56026 Mtetra
.937 .684 .529 r
.15524 .56026 .15619 .56349 .15825 .55943 .17847 .36157 Mtetra
.549 .319 .519 r
.17847 .36157 .15825 .55943 .18008 .37223 .18114 .35104 Mtetra
.573 .358 .551 r
.18114 .35104 .18008 .37223 .1836 .35365 .18291 .34878 Mtetra
.629 .471 .649 r
.18291 .34878 .1836 .35365 .18553 .34995 .18455 .34761 Mtetra
.651 .577 .758 r
.18455 .34761 .18553 .34995 .18728 .34777 .18616 .34687 Mtetra
.678 .778 .926 r
.18616 .34687 .18728 .34777 .18891 .34678 .18775 .34624 Mtetra
.622 .849 .986 r
.18775 .34624 .18891 .34678 .19049 .34625 .18933 .34573 Mtetra
.583 .841 .994 r
.18933 .34573 .19049 .34625 .19205 .34596 .1909 .3453 Mtetra
.615 .818 .978 r
.1909 .3453 .19205 .34596 .19362 .34562 .19248 .34484 Mtetra
.63 .795 .962 r
.19248 .34484 .19362 .34562 .19518 .34525 .19406 .34437 Mtetra
.643 .774 .943 r
.19406 .34437 .19518 .34525 .19676 .34483 .19564 .34386 Mtetra
.67 .762 .919 r
.19564 .34386 .19676 .34483 .19836 .34419 .19724 .34326 Mtetra
.682 .773 .92 r
.19724 .34326 .19836 .34419 .19997 .34345 .19884 .34261 Mtetra
.686 .794 .932 r
.19884 .34261 .19997 .34345 .20158 .34269 .20044 .34195 Mtetra
.678 .814 .948 r
.20044 .34195 .20158 .34269 .20318 .34202 .20204 .34131 Mtetra
.673 .82 .954 r
.20204 .34131 .20318 .34202 .20478 .3414 .20365 .34068 Mtetra
.669 .819 .955 r
.20365 .34068 .20478 .3414 .20638 .34079 .20525 .34007 Mtetra
.756 .827 .907 r
.20525 .34007 .20638 .34079 .20802 .33981 .20689 .33908 Mtetra
.718 .823 .93 r
.20689 .33908 .20802 .33981 .20964 .33901 .20851 .33828 Mtetra
.496 .764 .991 r
.20851 .33828 .20964 .33901 .2112 .33883 .21007 .3381 Mtetra
.882 .451 .144 r
.21007 .3381 .2112 .33883 .21245 .34175 .21132 .34107 Mtetra
.944 .683 .511 r
.21132 .34107 .21245 .34175 .19406 .54468 .19288 .54368 Mtetra
.943 .607 .361 r
.19288 .54368 .19406 .54468 .19497 .55227 .19381 .55103 Mtetra
0 .322 .801 r
.19381 .55103 .19497 .55227 .19652 .55328 .19537 .55196 Mtetra
.642 .705 .892 r
.19537 .55196 .19652 .55328 .19823 .55274 .19707 .55143 Mtetra
.741 .733 .844 r
.19707 .55143 .19823 .55274 .20001 .5514 .19884 .55031 Mtetra
.709 .763 .894 r
.19884 .55031 .20001 .5514 .20187 .54932 .20058 .54946 Mtetra
.639 .961 .913 r
.20058 .54946 .20187 .54932 .20384 .54602 .20233 .5485 Mtetra
0 0 0 r
.20233 .5485 .20384 .54602 .20618 .53878 .20414 .54683 Mtetra
.002 0 .207 r
.20414 .54683 .20618 .53878 .22651 .34082 .20631 .54151 Mtetra
0 0 .114 r
.20631 .54151 .22651 .34082 .22854 .33578 .22707 .33874 Mtetra
.938 .892 .489 r
.22707 .33874 .22854 .33578 .23034 .33318 .22921 .33258 Mtetra
.859 .838 .823 r
.22921 .33258 .23034 .33318 .23202 .33194 .23094 .33073 Mtetra
.678 .72 .881 r
.23094 .33073 .23202 .33194 .23363 .33132 .23256 .33006 Mtetra
.587 .683 .908 r
.23256 .33006 .23363 .33132 .23523 .33089 .23415 .32977 Mtetra
.722 .748 .873 r
.23415 .32977 .23523 .33089 .23689 .32988 .23579 .32889 Mtetra
.738 .774 .882 r
.23579 .32889 .23689 .32988 .23855 .32884 .23744 .32794 Mtetra
.595 .759 .957 r
.23744 .32794 .23855 .32884 .24015 .32839 .23904 .32757 Mtetra
.817 .338 0 r
.23904 .32757 .24015 .32839 .24152 .33053 .2404 .32986 Mtetra
.947 .684 .504 r
.2404 .32986 .24152 .33053 .22531 .52952 .22398 .53029 Mtetra
.909 .594 .436 r
.22398 .53029 .22531 .52952 .22593 .54131 .22475 .54037 Mtetra
.64 .113 0 r
.22475 .54037 .22593 .54131 .22745 .54308 .22628 .54205 Mtetra
.514 .718 .965 r
.22628 .54205 .22745 .54308 .22914 .54294 .22797 .5419 Mtetra
.765 .782 .867 r
.22797 .5419 .22914 .54294 .23093 .54173 .22976 .54069 Mtetra
.894 .763 .71 r
.22976 .54069 .23093 .54173 .23293 .53806 .23176 .537 Mtetra
.948 .689 .512 r
.23176 .537 .23293 .53806 .25158 .3416 .25052 .34012 Mtetra
.933 .702 .566 r
.25052 .34012 .25158 .3416 .25454 .32554 .25346 .32444 Mtetra
.857 .76 .754 r
.25346 .32444 .25454 .32554 .25633 .32308 .25525 .32199 Mtetra
.682 .746 .899 r
.25525 .32199 .25633 .32308 .25797 .3224 .25689 .32131 Mtetra
.53 .696 .945 r
.25689 .32131 .25797 .3224 .25956 .32224 .25848 .32116 Mtetra
.673 .747 .906 r
.25848 .32116 .25956 .32224 .2612 .32158 .26011 .32053 Mtetra
.717 .761 .887 r
.26011 .32053 .2612 .32158 .26285 .32072 .26177 .31968 Mtetra
.562 .72 .947 r
.26177 .31968 .26285 .32072 .26446 .32046 .26337 .31943 Mtetra
.818 .35 0 r
.26337 .31943 .26446 .32046 .26583 .32301 .26475 .32194 Mtetra
.95 .685 .498 r
.26475 .32194 .26583 .32301 .25078 .52631 .24965 .52486 Mtetra
.954 .613 .32 r
.24965 .52486 .25078 .52631 .25187 .53376 .25072 .53251 Mtetra
0 .123 .637 r
.25072 .53251 .25187 .53376 .25345 .53511 .25231 .53388 Mtetra
.611 .713 .918 r
.25231 .53388 .25345 .53511 .25519 .53469 .25404 .53346 Mtetra
.715 .745 .875 r
.25404 .53346 .25519 .53469 .25696 .53377 .25582 .53254 Mtetra
.654 .729 .904 r
.25582 .53254 .25696 .53377 .25872 .53309 .25757 .53195 Mtetra
.587 .722 .937 r
.25757 .53195 .25872 .53309 .26046 .53267 .2593 .53161 Mtetra
.7 .772 .907 r
.2593 .53161 .26046 .53267 .26222 .53195 .26107 .5308 Mtetra
.859 .767 .759 r
.26107 .5308 .26222 .53195 .26406 .5302 .26298 .52822 Mtetra
.901 .699 .621 r
.26298 .52822 .26406 .5302 .26603 .52686 .26527 .52069 Mtetra
.945 .683 .507 r
.26527 .52069 .26603 .52686 .26819 .52093 .28269 .31705 Mtetra
.532 .305 .515 r
.28269 .31705 .26819 .52093 .27054 .51251 .28457 .31335 Mtetra
.526 .299 .514 r
.28457 .31335 .27054 .51251 .27218 .51332 .28623 .3126 Mtetra
.524 .298 .514 r
.28623 .3126 .27218 .51332 .27382 .51429 .28785 .31242 Mtetra
.525 .299 .514 r
.28785 .31242 .27382 .51429 .28976 .32383 .28951 .31175 Mtetra
.576 .377 .574 r
.28951 .31175 .28976 .32383 .29205 .31472 .29121 .31042 Mtetra
.644 .494 .664 r
.29121 .31042 .29205 .31472 .29392 .31111 .29292 .30918 Mtetra
.689 .634 .789 r
.29292 .30918 .29392 .31111 .29566 .30935 .29459 .30824 Mtetra
.672 .743 .904 r
.29459 .30824 .29566 .30935 .29732 .30864 .29625 .3076 Mtetra
.656 .754 .922 r
.29625 .3076 .29732 .30864 .29897 .30818 .2979 .30703 Mtetra
.671 .736 .899 r
.2979 .30703 .29897 .30818 .30062 .3076 .29956 .3064 Mtetra
.69 .732 .882 r
.29956 .3064 .30062 .3076 .30229 .30678 .30123 .30566 Mtetra
.692 .748 .894 r
.30123 .30566 .30229 .30678 .30397 .30596 .3029 .30492 Mtetra
.725 .771 .889 r
.3029 .30492 .30397 .30596 .30564 .30508 .30458 .30403 Mtetra
.731 .769 .883 r
.30458 .30403 .30564 .30508 .30732 .30422 .30626 .30309 Mtetra
.636 .728 .914 r
.30626 .30309 .30732 .30422 .30898 .30367 .30791 .3026 Mtetra
0 .256 .742 r
.30791 .3026 .30898 .30367 .31057 .30403 .30946 .30363 Mtetra
.927 .57 .329 r
.30946 .30363 .31057 .30403 .31205 .3061 .31066 .30987 Mtetra
.949 .678 .49 r
.31066 .30987 .31205 .3061 .3133 .3117 .29851 .51284 Mtetra
.529 .297 .507 r
.29851 .51284 .3133 .3117 .30205 .50391 .30004 .51583 Mtetra
.501 .235 .442 r
.30004 .51583 .30205 .50391 .30389 .50238 .3018 .51551 Mtetra
.482 .222 .443 r
.3018 .51551 .30389 .50238 .3058 .49964 .3036 .51459 Mtetra
.499 .241 .455 r
.3036 .51459 .3058 .49964 .30704 .50712 .30538 .51405 Mtetra
.52 .225 .405 r
.30538 .51405 .30704 .50712 .30842 .51263 .30711 .51432 Mtetra
.463 .027 .124 r
.30711 .51432 .30842 .51263 .31001 .51504 .30884 .5145 Mtetra
.38 .77 .988 r
.30884 .5145 .31001 .51504 .31171 .51582 .31059 .51437 Mtetra
.631 .687 .885 r
.31059 .51437 .31171 .51582 .31348 .51542 .31237 .51387 Mtetra
.652 .68 .864 r
.31237 .51387 .31348 .51542 .31527 .5147 .31416 .51325 Mtetra
.621 .684 .888 r
.31416 .51325 .31527 .5147 .31707 .51405 .31594 .51279 Mtetra
.559 .693 .929 r
.31594 .51279 .31707 .51405 .31884 .51369 .31771 .51255 Mtetra
.669 .755 .914 r
.31771 .51255 .31884 .51369 .32063 .51304 .3195 .51187 Mtetra
.832 .774 .797 r
.3195 .51187 .32063 .51304 .32247 .51167 .32138 .50985 Mtetra
.9 .711 .638 r
.32138 .50985 .32247 .51167 .3244 .50883 .32351 .5037 Mtetra
.952 .685 .493 r
.32351 .5037 .3244 .50883 .32647 .50347 .33758 .29848 Mtetra
.536 .308 .516 r
.33758 .29848 .32647 .50347 .34012 .3024 .33956 .29299 Mtetra
.604 .409 .59 r
.33956 .29299 .34012 .3024 .3422 .29503 .34131 .29125 Mtetra
.64 .506 .683 r
.34131 .29125 .3422 .29503 .34403 .29191 .34302 .29019 Mtetra
.671 .652 .822 r
.34302 .29019 .34403 .29191 .34578 .29017 .34471 .28944 Mtetra
.668 .831 .961 r
.34471 .28944 .34578 .29017 .34748 .28939 .3464 .28879 Mtetra
.614 .847 .987 r
.3464 .28879 .34748 .28939 .34915 .28894 .34808 .28827 Mtetra
.608 .827 .984 r
.34808 .28827 .34915 .28894 .35082 .28861 .34976 .28779 Mtetra
.636 .799 .961 r
.34976 .28779 .35082 .28861 .3525 .28819 .35144 .28726 Mtetra
.646 .776 .943 r
.35144 .28726 .3525 .28819 .35418 .28776 .35313 .28671 Mtetra
.665 .757 .919 r
.35313 .28671 .35418 .28776 .35587 .28721 .35482 .28609 Mtetra
.687 .751 .9 r
.35482 .28609 .35587 .28721 .35757 .28644 .35652 .28537 Mtetra
.692 .761 .905 r
.35652 .28537 .35757 .28644 .35927 .28563 .35822 .28463 Mtetra
.712 .78 .906 r
.35822 .28463 .35927 .28563 .36097 .28478 .35992 .2838 Mtetra
.74 .789 .892 r
.35992 .2838 .36097 .28478 .36268 .28391 .36164 .28282 Mtetra
.66 .748 .916 r
.36164 .28282 .36268 .28391 .36438 .2833 .36333 .28222 Mtetra
.234 .552 .931 r
.36333 .28222 .36438 .2833 .36604 .28327 .36498 .28265 Mtetra
.898 .481 .169 r
.36498 .28265 .36604 .28327 .36764 .28457 .36644 .28663 Mtetra
.956 .681 .473 r
.36644 .28663 .36764 .28457 .36914 .28805 .35781 .49087 Mtetra
.534 .301 .508 r
.35781 .49087 .36914 .28805 .36092 .48768 .35932 .49649 Mtetra
.545 .259 .432 r
.35932 .49649 .36092 .48768 .36234 .49512 .36106 .49728 Mtetra
.441 .034 .171 r
.36106 .49728 .36234 .49512 .36401 .49749 .36285 .49726 Mtetra
.419 .844 .955 r
.36285 .49726 .36401 .49749 .36576 .49834 .36467 .49686 Mtetra
.625 .685 .887 r
.36467 .49686 .36576 .49834 .36757 .498 .36648 .49638 Mtetra
.65 .672 .859 r
.36648 .49638 .36757 .498 .3694 .4973 .36831 .49575 Mtetra
.641 .68 .871 r
.36831 .49575 .3694 .4973 .37123 .49655 .37013 .49518 Mtetra
.55 .672 .918 r
.37013 .49518 .37123 .49655 .37304 .4962 .37194 .49498 Mtetra
.648 .737 .915 r
.37194 .49498 .37304 .4962 .37487 .4956 .37376 .49439 Mtetra
.799 .773 .829 r
.37376 .49439 .37487 .4956 .37672 .49438 .37564 .49277 Mtetra
.908 .728 .648 r
.37564 .49277 .37672 .49438 .37866 .49138 .37769 .48722 Mtetra
.958 .687 .478 r
.37769 .48722 .37866 .49138 .38068 .48626 .38852 .2815 Mtetra
.538 .31 .516 r
.38852 .2815 .38068 .48626 .38318 .47025 .3905 .27496 Mtetra
.526 .3 .514 r
.3905 .27496 .38318 .47025 .38509 .46736 .39224 .27386 Mtetra
.525 .299 .514 r
.39224 .27386 .38509 .46736 .38667 .47263 .39394 .27348 Mtetra
.39394 .27348 .38667 .47263 .39608 .2887 .39565 .27314 Mtetra
.567 .361 .56 r
.39565 .27314 .39608 .2887 .39828 .27638 .3974 .27172 Mtetra
.643 .486 .655 r
.3974 .27172 .39828 .27638 .40014 .27234 .39915 .27035 Mtetra
.711 .643 .78 r
.39915 .27035 .40014 .27234 .40193 .26999 .40089 .26919 Mtetra
.682 .821 .95 r
.40089 .26919 .40193 .26999 .40366 .2691 .40262 .26848 Mtetra
.628 .85 .984 r
.40262 .26848 .40366 .2691 .40538 .26857 .40434 .26791 Mtetra
.607 .834 .986 r
.40434 .26791 .40538 .26857 .40709 .26823 .40606 .26741 Mtetra
.632 .803 .965 r
.40606 .26741 .40709 .26823 .40881 .26779 .40778 .26688 Mtetra
.635 .783 .952 r
.40778 .26688 .40881 .26779 .41053 .26738 .4095 .26635 Mtetra
.644 .761 .934 r
.4095 .26635 .41053 .26738 .41225 .26694 .41122 .2658 Mtetra
.66 .745 .913 r
.41122 .2658 .41225 .26694 .41397 .26637 .41295 .26519 Mtetra
.668 .738 .902 r
.41295 .26519 .41397 .26637 .4157 .26574 .41468 .26454 Mtetra
.674 .737 .897 r
.41468 .26454 .4157 .26574 .41743 .26504 .41641 .26386 Mtetra
.685 .744 .896 r
.41641 .26386 .41743 .26504 .41917 .26424 .41815 .26313 Mtetra
.688 .76 .907 r
.41815 .26313 .41917 .26424 .42091 .26341 .41988 .2624 Mtetra
.687 .777 .92 r
.41988 .2624 .42091 .26341 .42264 .26262 .42162 .26167 Mtetra
.674 .788 .935 r
.42162 .26167 .42264 .26262 .42438 .26194 .42336 .261 Mtetra
.669 .788 .938 r
.42336 .261 .42438 .26194 .42611 .2613 .42509 .26035 Mtetra
.666 .784 .937 r
.42509 .26035 .42611 .2613 .42785 .26068 .42683 .25971 Mtetra
.665 .78 .934 r
.42683 .25971 .42785 .26068 .42959 .26006 .42857 .25907 Mtetra
.665 .777 .933 r
.42857 .25907 .42959 .26006 .43133 .25943 .43031 .25843 Mtetra
.665 .775 .932 r
.43031 .25843 .43133 .25943 .43306 .25881 .43205 .2578 Mtetra
.67 .775 .929 r
.43205 .2578 .43306 .25881 .43481 .25816 .43379 .25714 Mtetra
.67 .773 .928 r
.43379 .25714 .43481 .25816 .43655 .25751 .43553 .25649 Mtetra
.669 .772 .927 r
.43553 .25649 .43655 .25751 .43829 .25685 .43728 .25583 Mtetra
.744 .791 .891 r
.43728 .25583 .43829 .25685 .44004 .25595 .43903 .25481 Mtetra
.682 .752 .904 r
.43903 .25481 .44004 .25595 .44179 .25524 .44078 .25409 Mtetra
.518 .687 .944 r
.44078 .25409 .44179 .25524 .44353 .25491 .44251 .25396 Mtetra
.803 .334 0 r
.44251 .25396 .44353 .25491 .44523 .25591 .44417 .2569 Mtetra
.964 .681 .446 r
.44417 .2569 .44523 .25591 .4469 .25855 .44071 .45914 Mtetra
.542 .307 .509 r
.44071 .45914 .4469 .25855 .4439 .44989 .44231 .46913 Mtetra
.541 .283 .474 r
.44231 .46913 .4439 .44989 .44533 .46712 .44414 .47028 Mtetra
.487 .123 .274 r
.44414 .47028 .44533 .46712 .44712 .4701 .446 .47039 Mtetra
0 0 0 r
.446 .47039 .44712 .4701 .44895 .47134 .44787 .47002 Mtetra
.616 .713 .914 r
.44787 .47002 .44895 .47134 .45082 .47114 .44975 .46955 Mtetra
.647 .682 .869 r
.44975 .46955 .45082 .47114 .4527 .47048 .45163 .46892 Mtetra
.663 .693 .867 r
.45163 .46892 .4527 .47048 .45458 .46961 .45351 .46821 Mtetra
.549 .672 .919 r
.45351 .46821 .45458 .46961 .45646 .46923 .45539 .46801 Mtetra
.62 .733 .928 r
.45539 .46801 .45646 .46923 .45834 .46869 .45727 .46752 Mtetra
.745 .78 .882 r
.45727 .46752 .45834 .46869 .46023 .46775 .45916 .46639 Mtetra
.909 .759 .683 r
.45916 .46639 .46023 .46775 .46215 .4654 .46112 .46212 Mtetra
.966 .687 .452 r
.46112 .46212 .46215 .4654 .4641 .46131 .46679 .26097 Mtetra
.554 .322 .518 r
.46679 .26097 .4641 .46131 .46624 .44676 .4688 .24707 Mtetra
.529 .302 .515 r
.4688 .24707 .46624 .44676 .47153 .24988 .4706 .24465 Mtetra
.628 .466 .643 r
.4706 .24465 .47153 .24988 .47335 .24585 .47238 .24334 Mtetra
.654 .577 .756 r
.47238 .24334 .47335 .24585 .47515 .24355 .47415 .2425 Mtetra
.675 .771 .923 r
.47415 .2425 .47515 .24355 .47692 .24264 .47592 .24181 Mtetra
.632 .808 .967 r
.47592 .24181 .47692 .24264 .47868 .24219 .47768 .24126 Mtetra
.621 .78 .957 r
.47768 .24126 .47868 .24219 .48045 .24193 .47945 .24076 Mtetra
.739 .767 .876 r
.47945 .24076 .48045 .24193 .48222 .24099 .48123 .23972 Mtetra
.705 .74 .878 r
.48123 .23972 .48222 .24099 .484 .24009 .48301 .23885 Mtetra
.584 .702 .923 r
.48301 .23885 .484 .24009 .48577 .23953 .48478 .23853 Mtetra
.656 .163 0 r
.48478 .23853 .48577 .23953 .48753 .24024 .48651 .2408 Mtetra
.958 .651 .407 r
.48651 .2408 .48753 .24024 .48927 .24247 .48792 .2716 Mtetra
.928 .636 .47 r
.48792 .2716 .48927 .24247 .49094 .2518 .48764 .45369 Mtetra
.526 .295 .507 r
.48764 .45369 .49094 .2518 .49063 .45159 .48952 .45538 Mtetra
.504 .158 .312 r
.48952 .45538 .49063 .45159 .49249 .45508 .49141 .4556 Mtetra
.045 0 0 r
.49141 .4556 .49249 .45508 .49438 .45647 .49332 .45526 Mtetra
.528 .7 .949 r
.49332 .45526 .49438 .45647 .49628 .45651 .49523 .45508 Mtetra
.628 .702 .899 r
.49523 .45508 .49628 .45651 .49819 .45583 .49714 .45455 Mtetra
.75 .767 .867 r
.49714 .45455 .49819 .45583 .50011 .45454 .49905 .45333 Mtetra
.915 .781 .699 r
.49905 .45333 .50011 .45454 .50204 .4523 .50099 .44943 Mtetra
.951 .691 .506 r
.50099 .44943 .50204 .4523 .50397 .44855 .50306 .42656 Mtetra
.948 .662 .463 r
.50306 .42656 .50397 .44855 .50594 .43855 .50613 .23406 Mtetra
.53 .303 .514 r
.50613 .23406 .50594 .43855 .5089 .23726 .50794 .23131 Mtetra
.62 .449 .63 r
.50794 .23131 .5089 .23726 .51071 .23277 .50973 .22995 Mtetra
.645 .554 .737 r
.50973 .22995 .51071 .23277 .51251 .23029 .51152 .2291 Mtetra
.664 .744 .909 r
.51152 .2291 .51251 .23029 .5143 .22923 .51332 .22845 Mtetra
.612 .816 .978 r
.51332 .22845 .5143 .22923 .51609 .22877 .51511 .22793 Mtetra
.594 .795 .976 r
.51511 .22793 .51609 .22877 .51788 .22856 .51691 .22749 Mtetra
.651 .763 .931 r
.51691 .22749 .51788 .22856 .51968 .22808 .5187 .22689 Mtetra
.673 .748 .907 r
.5187 .22689 .51968 .22808 .52148 .22743 .5205 .2262 Mtetra
.68 .742 .898 r
.5205 .2262 .52148 .22743 .52328 .2267 .5223 .22546 Mtetra
.753 .762 .86 r
.5223 .22546 .52328 .2267 .52507 .22546 .5241 .22429 Mtetra
.734 .769 .882 r
.5241 .22429 .52507 .22546 .52687 .22437 .5259 .22328 Mtetra
.595 .738 .944 r
.5259 .22328 .52687 .22437 .52868 .22392 .5277 .22288 Mtetra
.688 .207 0 r
.5277 .22288 .52868 .22392 .53048 .22655 .52951 .22547 Mtetra
.972 .681 .411 r
.52951 .22547 .53048 .22655 .53279 .43413 .53175 .43224 Mtetra
.931 .57 .153 r
.53175 .43224 .53279 .43413 .53475 .44261 .53371 .44107 Mtetra
.099 .391 .848 r
.53371 .44107 .53475 .44261 .5367 .44356 .53565 .44212 Mtetra
.641 .708 .896 r
.53565 .44212 .5367 .44356 .53863 .44285 .53759 .44152 Mtetra
.734 .759 .873 r
.53759 .44152 .53863 .44285 .54057 .44161 .53953 .4404 Mtetra
.58 .726 .943 r
.53953 .4404 .54057 .44161 .54252 .44126 .54148 .44004 Mtetra
.545 .709 .947 r
.54148 .44004 .54252 .44126 .54446 .44109 .54342 .4398 Mtetra
.701 .755 .894 r
.54342 .4398 .54446 .44109 .5464 .44026 .54537 .4389 Mtetra
.911 .772 .695 r
.54537 .4389 .5464 .44026 .54833 .43629 .54729 .43496 Mtetra
.974 .687 .42 r
.54729 .43496 .54833 .43629 .54866 .22818 .54769 .22798 Mtetra
.987 .763 .513 r
.54769 .22798 .54866 .22818 .55039 .21749 .54943 .21664 Mtetra
.889 .84 .791 r
.54943 .21664 .55039 .21749 .5522 .21525 .55124 .21432 Mtetra
.663 .8 .948 r
.55124 .21432 .5522 .21525 .55402 .21469 .55305 .21366 Mtetra
.511 .718 .965 r
.55305 .21366 .55402 .21469 .55584 .21464 .55488 .21349 Mtetra
.601 .732 .936 r
.55488 .21349 .55584 .21464 .55766 .21431 .5567 .21308 Mtetra
.668 .74 .904 r
.5567 .21308 .55766 .21431 .55949 .21367 .55853 .2124 Mtetra
.674 .735 .896 r
.55853 .2124 .55949 .21367 .56131 .21296 .56035 .21168 Mtetra
.742 .756 .865 r
.56035 .21168 .56131 .21296 .56313 .21178 .56217 .21057 Mtetra
.74 .768 .876 r
.56217 .21057 .56313 .21178 .56495 .21062 .56399 .2095 Mtetra
.62 .745 .936 r
.56399 .2095 .56495 .21062 .56677 .21007 .56582 .20902 Mtetra
0 0 .482 r
.56582 .20902 .56677 .21007 .56864 .21213 .56768 .21106 Mtetra
.974 .678 .395 r
.56768 .21106 .56864 .21213 .57357 .41775 .57254 .41563 Mtetra
.943 .597 .188 r
.57254 .41563 .57357 .41775 .57571 .42895 .57468 .42741 Mtetra
0 .181 .712 r
.57468 .42741 .57571 .42895 .57771 .43053 .57669 .42917 Mtetra
.568 .694 .926 r
.57669 .42917 .57771 .43053 .57968 .43004 .57866 .42887 Mtetra
.769 .798 .877 r
.57866 .42887 .57968 .43004 .58164 .4287 .58062 .42756 Mtetra
.907 .805 .736 r
.58062 .42756 .58164 .4287 .58358 .42658 .58255 .42436 Mtetra
.938 .713 .57 r
.58255 .42436 .58358 .42658 .58551 .42328 .58436 .41522 Mtetra
.97 .678 .417 r
.58436 .41522 .58551 .42328 .58736 .41657 .58241 .2079 Mtetra
.532 .304 .515 r
.58241 .2079 .58736 .41657 .58528 .21227 .58419 .20412 Mtetra
.601 .415 .601 r
.58419 .20412 .58528 .21227 .58702 .20647 .58601 .20264 Mtetra
.625 .499 .689 r
.58601 .20264 .58702 .20647 .58881 .2036 .58785 .20173 Mtetra
.659 .643 .824 r
.58785 .20173 .58881 .2036 .59064 .20209 .58969 .201 Mtetra
.665 .771 .929 r
.58969 .201 .59064 .20209 .59248 .20134 .59154 .20032 Mtetra
.644 .778 .945 r
.59154 .20032 .59248 .20134 .59433 .20087 .59338 .19973 Mtetra
.719 .778 .899 r
.59338 .19973 .59433 .20087 .59617 .20003 .59523 .19879 Mtetra
.735 .766 .878 r
.59523 .19879 .59617 .20003 .59801 .19898 .59706 .19774 Mtetra
.625 .725 .919 r
.59706 .19774 .59801 .19898 .59986 .1985 .59892 .19724 Mtetra
0 .146 .676 r
.59892 .19724 .59986 .1985 .60177 .20032 .60083 .19893 Mtetra
.975 .676 .379 r
.60083 .19893 .60177 .20032 .60898 .40503 .60788 .40019 Mtetra
.877 .581 .063 r
.60788 .40019 .60898 .40503 .6113 .41709 .61028 .41546 Mtetra
0 .18 .713 r
.61028 .41546 .6113 .41709 .61335 .41879 .61234 .41732 Mtetra
.615 .697 .903 r
.61234 .41732 .61335 .41879 .61535 .41818 .61434 .41683 Mtetra
.725 .759 .88 r
.61434 .41683 .61535 .41818 .61733 .417 .61632 .41575 Mtetra
.65 .752 .924 r
.61632 .41575 .61733 .417 .61932 .41632 .61832 .41509 Mtetra
.512 .697 .952 r
.61832 .41509 .61932 .41632 .62134 .41625 .62033 .41495 Mtetra
.661 .746 .913 r
.62033 .41495 .62134 .41625 .62334 .41563 .62233 .41424 Mtetra
.877 .784 .755 r
.62233 .41424 .62334 .41563 .62527 .41292 .62426 .41144 Mtetra
.97 .734 .524 r
.62426 .41144 .62527 .41292 .62695 .40194 .62592 .39981 Mtetra
.976 .682 .39 r
.62592 .39981 .62695 .40194 .62223 .19335 .6213 .1921 Mtetra
.914 .787 .707 r
.6213 .1921 .62223 .19335 .624 .18985 .62307 .18867 Mtetra
.716 .773 .897 r
.62307 .18867 .624 .18985 .62586 .18892 .62493 .18774 Mtetra
.581 .721 .939 r
.62493 .18774 .62586 .18892 .62774 .18857 .62681 .18739 Mtetra
.643 .746 .924 r
.62681 .18739 .62774 .18857 .62961 .18799 .62868 .1868 Mtetra
.737 .779 .886 r
.62868 .1868 .62961 .18799 .63146 .18692 .63054 .18574 Mtetra
.629 .741 .928 r
.63054 .18574 .63146 .18692 .63334 .1864 .63242 .18521 Mtetra
0 .256 .758 r
.63242 .18521 .63334 .1864 .63529 .18783 .63436 .18659 Mtetra
.975 .673 .364 r
.63436 .18659 .63529 .18783 .64465 .38779 .6434 .37937 Mtetra
.836 .581 .034 r
.6434 .37937 .64465 .38779 .64733 .40512 .64633 .40359 Mtetra
0 .073 .623 r
.64633 .40359 .64733 .40512 .64946 .40733 .64846 .40583 Mtetra
.589 .685 .907 r
.64846 .40583 .64946 .40733 .65149 .40697 .65049 .40545 Mtetra
.718 .735 .864 r
.65049 .40545 .65149 .40697 .65349 .40575 .6525 .40437 Mtetra
.741 .763 .871 r
.6525 .40437 .65349 .40575 .65546 .40377 .6545 .40317 Mtetra
.688 .903 .972 r
.6545 .40317 .65546 .40377 .65739 .40081 .65651 .40224 Mtetra
0 0 0 r
.65651 .40224 .65739 .40081 .65921 .39542 .6585 .40074 Mtetra
.164 0 .268 r
.6585 .40074 .65921 .39542 .6526 .19096 .66041 .39725 Mtetra
0 0 .365 r
.66041 .39725 .6526 .19096 .65417 .18297 .65372 .1926 Mtetra
0 0 .181 r
.65372 .1926 .65417 .18297 .65595 .17967 .65508 .17964 Mtetra
.958 .944 .707 r
.65508 .17964 .65595 .17967 .65778 .17785 .65687 .17652 Mtetra
.715 .749 .879 r
.65687 .17652 .65778 .17785 .65967 .17701 .65874 .17555 Mtetra
.615 .687 .894 r
.65874 .17555 .65967 .17701 .66156 .17645 .66064 .17509 Mtetra
.647 .716 .899 r
.66064 .17509 .66156 .17645 .66345 .17567 .66254 .17448 Mtetra
.757 .788 .878 r
.66254 .17448 .66345 .17567 .66531 .17437 .66441 .17329 Mtetra
.666 .78 .934 r
.66441 .17329 .66531 .17437 .6672 .17358 .6663 .17259 Mtetra
.027 .435 .868 r
.6663 .17259 .6672 .17358 .66916 .17434 .66827 .17344 Mtetra
.925 .544 .15 r
.66827 .17344 .66916 .17434 .67151 .18286 .67064 .18243 Mtetra
.975 .669 .348 r
.67064 .18243 .67151 .18286 .6838 .39238 .68282 .39099 Mtetra
0 0 .455 r
.68282 .39099 .6838 .39238 .68603 .3954 .68505 .39392 Mtetra
.56 .676 .916 r
.68505 .39392 .68603 .3954 .6881 .39518 .68711 .39365 Mtetra
.709 .732 .869 r
.68711 .39365 .6881 .39518 .69012 .39405 .68914 .39263 Mtetra
.748 .763 .865 r
.68914 .39263 .69012 .39405 .6921 .39212 .69116 .39136 Mtetra
.689 .874 .968 r
.69116 .39136 .6921 .39212 .69404 .38929 .6932 .39046 Mtetra
0 0 0 r
.6932 .39046 .69404 .38929 .69586 .3843 .69521 .38902 Mtetra
.173 0 .254 r
.69521 .38902 .69586 .3843 .68696 .18079 .69713 .38594 Mtetra
.48 .26 .502 r
.69713 .38594 .68696 .18079 .68838 .171 .69799 .36319 Mtetra
0 0 .372 r
.69799 .36319 .68838 .171 .69013 .16749 .68931 .16768 Mtetra
.959 .943 .646 r
.68931 .16768 .69013 .16749 .69197 .1655 .69107 .16416 Mtetra
.725 .755 .876 r
.69107 .16416 .69197 .1655 .69387 .16462 .69296 .16313 Mtetra
.619 .685 .89 r
.69296 .16313 .69387 .16462 .69579 .16407 .69488 .16264 Mtetra
.613 .693 .901 r
.69488 .16264 .69579 .16407 .69771 .16346 .69681 .16218 Mtetra
.744 .77 .874 r
.69681 .16218 .69771 .16346 .6996 .16229 .6987 .16104 Mtetra
.661 .746 .913 r
.6987 .16104 .6996 .16229 .70151 .16159 .70062 .16035 Mtetra
.245 .527 .916 r
.70062 .16035 .70151 .16159 .70351 .16219 .70262 .16095 Mtetra
.89 .501 .052 r
.70262 .16095 .70351 .16219 .70597 .17048 .70505 .16878 Mtetra
.974 .666 .327 r
.70505 .16878 .70597 .17048 .72076 .38011 .71979 .37856 Mtetra
0 0 .448 r
.71979 .37856 .72076 .38011 .72307 .38334 .72211 .38188 Mtetra
.563 .683 .92 r
.72211 .38188 .72307 .38334 .72516 .38296 .7242 .38159 Mtetra
.709 .762 .894 r
.7242 .38159 .72516 .38296 .72721 .38188 .72626 .38059 Mtetra
.731 .784 .895 r
.72626 .38059 .72721 .38188 .72926 .38073 .72831 .37948 Mtetra
.505 .693 .953 r
.72831 .37948 .72926 .38073 .73138 .38072 .73042 .37935 Mtetra
.633 .73 .918 r
.73042 .37935 .73138 .38072 .73347 .38024 .7325 .37874 Mtetra
.809 .774 .82 r
.7325 .37874 .73347 .38024 .73548 .3785 .73451 .3769 Mtetra
.969 .751 .555 r
.73451 .3769 .73548 .3785 .73707 .37056 .7361 .36877 Mtetra
.976 .673 .34 r
.7361 .36877 .73707 .37056 .72488 .15719 .724 .15601 Mtetra
.96 .795 .634 r
.724 .15601 .72488 .15719 .72653 .15229 .72566 .15119 Mtetra
.746 .807 .901 r
.72566 .15119 .72653 .15229 .72844 .15125 .72756 .15008 Mtetra
.596 .738 .943 r
.72756 .15008 .72844 .15125 .7304 .1509 .72952 .14965 Mtetra
.526 .687 .941 r
.72952 .14965 .7304 .1509 .73238 .1508 .73149 .14948 Mtetra
.673 .742 .903 r
.73149 .14948 .73238 .1508 .7343 .1499 .73343 .14873 Mtetra
.662 .766 .927 r
.73343 .14873 .7343 .1499 .73624 .14919 .73537 .14804 Mtetra
.637 .76 .937 r
.73537 .14804 .73624 .14919 .73821 .14891 .73732 .14745 Mtetra
.629 .697 .893 r
.73732 .14745 .73821 .14891 .74028 .14996 .73928 .1469 Mtetra
.547 .49 .744 r
.73928 .1469 .74028 .14996 .74249 .15288 .74127 .14682 Mtetra
.463 .345 .634 r
.74127 .14682 .74249 .15288 .7594 .35483 .74334 .14786 Mtetra
.494 .276 .512 r
.74334 .14786 .7594 .35483 .76232 .36532 .74646 .16286 Mtetra
0 0 .405 r
.74646 .16286 .76232 .36532 .76468 .36808 .76358 .36458 Mtetra
.069 .17 .663 r
.76358 .36458 .76468 .36808 .76691 .36918 .76596 .36762 Mtetra
.507 .639 .913 r
.76596 .36762 .76691 .36918 .76906 .36909 .76811 .36757 Mtetra
.663 .724 .894 r
.76811 .36757 .76906 .36909 .77117 .36837 .77021 .36681 Mtetra
.733 .743 .86 r
.77021 .36681 .77117 .36837 .77322 .36702 .77228 .36559 Mtetra
.692 .748 .895 r
.77228 .36559 .77322 .36702 .77518 .36446 .77437 .36467 Mtetra
.585 .935 .764 r
.77437 .36467 .77518 .36446 .777 .3601 .77642 .36323 Mtetra
.1 0 .153 r
.77642 .36323 .777 .3601 .77766 .34134 .77839 .3607 Mtetra
.232 .055 .423 r
.77839 .3607 .77766 .34134 .76391 .14396 .77962 .34901 Mtetra
0 0 .398 r
.77962 .34901 .76391 .14396 .7656 .13986 .76491 .14073 Mtetra
.877 .882 .449 r
.76491 .14073 .7656 .13986 .76742 .13743 .76658 .13638 Mtetra
.785 .834 .89 r
.76658 .13638 .76742 .13743 .76934 .13622 .76849 .13504 Mtetra
.672 .772 .925 r
.76849 .13504 .76934 .13622 .77129 .13538 .77045 .13429 Mtetra
.591 .755 .956 r
.77045 .13429 .77129 .13538 .77327 .13477 .77244 .13386 Mtetra
0 0 0 r
.14234 .3631 .14375 .3618 .14534 .36093 .14397 .36198 Mtetra
.14397 .36198 .14534 .36093 .14691 .36035 .14555 .36128 Mtetra
.392 0 0 r
.14555 .36128 .14691 .36035 .14841 .36031 .14703 .36138 Mtetra
.867 .54 .431 r
.14703 .36138 .14841 .36031 .1496 .36289 .14784 .36721 Mtetra
.931 .675 .528 r
.14784 .36721 .1496 .36289 .129 .55124 .12579 .56727 Mtetra
.613 .348 .492 r
.12579 .56727 .129 .55124 .12844 .56958 .12691 .57137 Mtetra
.431 .005 .127 r
.12691 .57137 .12844 .56958 .12988 .57093 .12851 .57138 Mtetra
.43 .866 .777 r
.12851 .57138 .12988 .57093 .13147 .57109 .1302 .57057 Mtetra
.795 .869 .903 r
.1302 .57057 .13147 .57109 .13312 .57067 .13195 .56932 Mtetra
.698 .712 .86 r
.13195 .56932 .13312 .57067 .1348 .57001 .13365 .5685 Mtetra
.686 .686 .845 r
.13365 .5685 .1348 .57001 .1365 .56914 .13535 .56772 Mtetra
.683 .697 .857 r
.13535 .56772 .1365 .56914 .13822 .56817 .13704 .56697 Mtetra
.67 .729 .894 r
.13704 .56697 .13822 .56817 .13991 .56743 .13872 .56632 Mtetra
.653 .742 .915 r
.13872 .56632 .13991 .56743 .1416 .56678 .14039 .56576 Mtetra
.631 .752 .935 r
.14039 .56576 .1416 .56678 .14327 .56623 .14206 .56528 Mtetra
.543 .74 .967 r
.14206 .56528 .14327 .56623 .14493 .56583 .1437 .56504 Mtetra
.534 .774 .986 r
.1437 .56504 .14493 .56583 .14658 .5655 .14534 .56478 Mtetra
.593 .807 .982 r
.14534 .56478 .14658 .5655 .14822 .56521 .147 .56436 Mtetra
.64 .79 .954 r
.147 .56436 .14822 .56521 .14982 .5654 .14868 .56382 Mtetra
.715 .687 .822 r
.14868 .56382 .14982 .5654 .15145 .56525 .15041 .5628 Mtetra
.753 .628 .722 r
.15041 .5628 .15145 .56525 .15316 .5644 .15225 .5608 Mtetra
.869 .651 .605 r
.15225 .5608 .15316 .5644 .15524 .56026 .15498 .55064 Mtetra
.93 .676 .532 r
.15498 .55064 .15524 .56026 .17847 .36157 .1783 .35189 Mtetra
.676 .465 .592 r
.1783 .35189 .17847 .36157 .18114 .35104 .18027 .34772 Mtetra
.666 .535 .695 r
.18027 .34772 .18114 .35104 .18291 .34878 .18193 .34651 Mtetra
.608 .56 .775 r
.18193 .34651 .18291 .34878 .18455 .34761 .18349 .3461 Mtetra
.534 .613 .878 r
.18349 .3461 .18455 .34761 .18616 .34687 .18503 .34602 Mtetra
.612 .773 .957 r
.18503 .34602 .18616 .34687 .18775 .34624 .1866 .34561 Mtetra
.633 .83 .976 r
.1866 .34561 .18775 .34624 .18933 .34573 .18818 .34509 Mtetra
.645 .832 .972 r
.18818 .34509 .18933 .34573 .1909 .3453 .18976 .34454 Mtetra
.693 .812 .939 r
.18976 .34454 .1909 .3453 .19248 .34484 .19137 .34385 Mtetra
.687 .762 .908 r
.19137 .34385 .19248 .34484 .19406 .34437 .19297 .34318 Mtetra
.656 .716 .893 r
.19297 .34318 .19406 .34437 .19564 .34386 .19456 .34263 Mtetra
.469 .636 .928 r
.19456 .34263 .19564 .34386 .19724 .34326 .19609 .34267 Mtetra
.075 .567 .895 r
.19609 .34267 .19724 .34326 .19884 .34261 .19759 .34297 Mtetra
.348 0 0 r
.19759 .34297 .19884 .34261 .20044 .34195 .1991 .34321 Mtetra
0 0 0 r
.1991 .34321 .20044 .34195 .20204 .34131 .20074 .34224 Mtetra
.556 .891 .641 r
.20074 .34224 .20204 .34131 .20365 .34068 .20242 .34082 Mtetra
.805 .983 .893 r
.20242 .34082 .20365 .34068 .20525 .34007 .2041 .33946 Mtetra
.789 .85 .897 r
.2041 .33946 .20525 .34007 .20689 .33908 .20576 .33829 Mtetra
.714 .81 .925 r
.20576 .33829 .20689 .33908 .20851 .33828 .20738 .33751 Mtetra
.511 .759 .986 r
.20738 .33751 .20851 .33828 .21007 .3381 .20894 .33731 Mtetra
.804 .316 0 r
.20894 .33731 .21007 .3381 .21132 .34107 .21027 .33942 Mtetra
.956 .67 .453 r
.21027 .33942 .21132 .34107 .19288 .54368 .21005 .35732 Mtetra
0 0 .108 r
.21005 .35732 .19288 .54368 .19381 .55103 .19289 .54725 Mtetra
.188 .211 .654 r
.19289 .54725 .19381 .55103 .19537 .55196 .19436 .54909 Mtetra
.495 .465 .753 r
.19436 .54909 .19537 .55196 .19707 .55143 .19599 .54932 Mtetra
.585 .578 .811 r
.19599 .54932 .19707 .55143 .19884 .55031 .19768 .54903 Mtetra
.464 .644 .935 r
.19768 .54903 .19884 .55031 .20058 .54946 .19933 .54908 Mtetra
.371 .792 .975 r
.19933 .54908 .20058 .54946 .20233 .5485 .20101 .54889 Mtetra
.493 .902 .809 r
.20101 .54889 .20233 .5485 .20414 .54683 .20275 .54799 Mtetra
.96 .945 .674 r
.20275 .54799 .20414 .54683 .20631 .54151 .20478 .54417 Mtetra
.949 .693 .515 r
.20478 .54417 .20631 .54151 .22707 .33874 .2254 .34369 Mtetra
.983 .845 .458 r
.2254 .34369 .22707 .33874 .22921 .33258 .22809 .33178 Mtetra
.865 .798 .782 r
.22809 .33178 .22921 .33258 .23094 .33073 .22985 .32956 Mtetra
.683 .73 .886 r
.22985 .32956 .23094 .33073 .23256 .33006 .23148 .32888 Mtetra
.559 .686 .924 r
.23148 .32888 .23256 .33006 .23415 .32977 .23306 .32867 Mtetra
.706 .747 .884 r
.23306 .32867 .23415 .32977 .23579 .32889 .23469 .32787 Mtetra
.724 .769 .888 r
.23469 .32787 .23579 .32889 .23744 .32794 .23634 .327 Mtetra
.57 .744 .959 r
.23634 .327 .23744 .32794 .23904 .32757 .23793 .32671 Mtetra
.831 .361 0 r
.23793 .32671 .23904 .32757 .2404 .32986 .23928 .32914 Mtetra
.947 .684 .504 r
.23928 .32914 .2404 .32986 .22398 .53029 .22271 .53036 Mtetra
.922 .599 .413 r
.22271 .53036 .22398 .53029 .22475 .54037 .22357 .53941 Mtetra
.611 .083 0 r
.22357 .53941 .22475 .54037 .22628 .54205 .2251 .54103 Mtetra
.519 .72 .964 r
.2251 .54103 .22628 .54205 .22797 .5419 .2268 .54086 Mtetra
.765 .783 .868 r
.2268 .54086 .22797 .5419 .22976 .54069 .22859 .53965 Mtetra
.894 .763 .71 r
.22859 .53965 .22976 .54069 .23176 .537 .23059 .53596 Mtetra
.948 .689 .512 r
.23059 .53596 .23176 .537 .25052 .34012 .24945 .33887 Mtetra
.936 .707 .566 r
.24945 .33887 .25052 .34012 .25346 .32444 .25238 .32335 Mtetra
.858 .761 .755 r
.25238 .32335 .25346 .32444 .25525 .32199 .25417 .3209 Mtetra
.68 .747 .902 r
.25417 .3209 .25525 .32199 .25689 .32131 .2558 .32024 Mtetra
.525 .697 .948 r
.2558 .32024 .25689 .32131 .25848 .32116 .25739 .32009 Mtetra
.657 .745 .915 r
.25739 .32009 .25848 .32116 .26011 .32053 .25902 .31953 Mtetra
.708 .771 .901 r
.25902 .31953 .26011 .32053 .26177 .31968 .26067 .31874 Mtetra
.571 .745 .959 r
.26067 .31874 .26177 .31968 .26337 .31943 .26228 .31844 Mtetra
.687 .181 0 r
.26228 .31844 .26337 .31943 .26475 .32194 .26372 .32028 Mtetra
.951 .685 .497 r
.26372 .32028 .26475 .32194 .24965 .52486 .24974 .5087 Mtetra
0 0 .059 r
.24974 .5087 .24965 .52486 .25072 .53251 .24977 .52894 Mtetra
.203 .236 .673 r
.24977 .52894 .25072 .53251 .25231 .53388 .25132 .53068 Mtetra
.59 .505 .727 r
.25132 .53068 .25231 .53388 .25404 .53346 .25305 .53027 Mtetra
.651 .542 .717 r
.25305 .53027 .25404 .53346 .25582 .53254 .25484 .52927 Mtetra
.605 .511 .721 r
.25484 .52927 .25582 .53254 .25757 .53195 .25658 .52872 Mtetra
.57 .492 .728 r
.25658 .52872 .25757 .53195 .2593 .53161 .25831 .52847 Mtetra
.644 .541 .722 r
.25831 .52847 .2593 .53161 .26107 .5308 .26008 .52756 Mtetra
.796 .621 .664 r
.26008 .52756 .26107 .5308 .26298 .52822 .26209 .5238 Mtetra
.947 .685 .507 r
.26209 .5238 .26298 .52822 .26527 .52069 .27962 .32094 Mtetra
.543 .314 .517 r
.27962 .32094 .26527 .52069 .28269 .31705 .28189 .3124 Mtetra
.702 .525 .646 r
.28189 .3124 .28269 .31705 .28457 .31335 .28368 .30995 Mtetra
.625 .508 .701 r
.28368 .30995 .28457 .31335 .28623 .3126 .28534 .30918 Mtetra
.575 .477 .706 r
.28534 .30918 .28623 .3126 .28785 .31242 .28697 .30888 Mtetra
.573 .471 .7 r
.28697 .30888 .28785 .31242 .28951 .31175 .28859 .30858 Mtetra
.598 .503 .717 r
.28859 .30858 .28951 .31175 .29121 .31042 .29023 .30811 Mtetra
.616 .565 .775 r
.29023 .30811 .29121 .31042 .29292 .30918 .29188 .30763 Mtetra
.659 .666 .846 r
.29188 .30763 .29292 .30918 .29459 .30824 .29353 .307 Mtetra
.691 .724 .876 r
.29353 .307 .29459 .30824 .29625 .3076 .2952 .30625 Mtetra
.672 .7 .868 r
.2952 .30625 .29625 .3076 .2979 .30703 .29686 .30558 Mtetra
.596 .656 .88 r
.29686 .30558 .2979 .30703 .29956 .3064 .2985 .30526 Mtetra
.429 .642 .946 r
.2985 .30526 .29956 .3064 .30123 .30566 .3001 .30535 Mtetra
0 .55 .801 r
.3001 .30535 .30123 .30566 .3029 .30492 .3017 .30558 Mtetra
.066 0 0 r
.3017 .30558 .3029 .30492 .30458 .30403 .30335 .30522 Mtetra
0 0 0 r
.30335 .30522 .30458 .30403 .30626 .30309 .30504 .3042 Mtetra
.152 0 0 r
.30504 .3042 .30626 .30309 .30791 .3026 .3067 .3037 Mtetra
.74 .323 .256 r
.3067 .3037 .30791 .3026 .30946 .30363 .30818 .30571 Mtetra
.951 .681 .489 r
.30818 .30571 .30946 .30363 .31066 .30987 .2959 .50794 Mtetra
.538 .304 .509 r
.2959 .50794 .31066 .30987 .29851 .51284 .29712 .51541 Mtetra
.659 .287 .329 r
.29712 .51541 .29851 .51284 .30004 .51583 .29874 .51713 Mtetra
.303 0 0 r
.29874 .51713 .30004 .51583 .3018 .51551 .3005 .51689 Mtetra
.11 0 0 r
.3005 .51689 .3018 .51551 .3036 .51459 .30229 .51614 Mtetra
.132 0 0 r
.30229 .51614 .3036 .51459 .30538 .51405 .30408 .51534 Mtetra
.15 0 0 r
.30408 .51534 .30538 .51405 .30711 .51432 .30587 .51474 Mtetra
.316 .794 .714 r
.30587 .51474 .30711 .51432 .30884 .5145 .30766 .51401 Mtetra
.735 .898 .952 r
.30766 .51401 .30884 .5145 .31059 .51437 .30947 .51302 Mtetra
.765 .741 .832 r
.30947 .51302 .31059 .51437 .31237 .51387 .31131 .51166 Mtetra
.729 .641 .761 r
.31131 .51166 .31237 .51387 .31416 .51325 .31315 .51019 Mtetra
.652 .55 .727 r
.31315 .51019 .31416 .51325 .31594 .51279 .31496 .50922 Mtetra
.558 .471 .712 r
.31496 .50922 .31594 .51279 .31771 .51255 .31672 .50905 Mtetra
.61 .506 .711 r
.31672 .50905 .31771 .51255 .3195 .51187 .31852 .5084 Mtetra
.754 .592 .676 r
.31852 .5084 .3195 .51187 .32138 .50985 .32044 .50561 Mtetra
.953 .686 .493 r
.32044 .50561 .32138 .50985 .32351 .5037 .33443 .30469 Mtetra
.55 .319 .518 r
.33443 .30469 .32351 .5037 .33758 .29848 .33679 .293 Mtetra
.704 .514 .629 r
.33679 .293 .33758 .29848 .33956 .29299 .33862 .29001 Mtetra
.639 .537 .723 r
.33862 .29001 .33956 .29299 .34131 .29125 .34031 .2892 Mtetra
.591 .578 .808 r
.34031 .2892 .34131 .29125 .34302 .29019 .34198 .28888 Mtetra
.567 .672 .91 r
.34198 .28888 .34302 .29019 .34471 .28944 .34364 .28865 Mtetra
.647 .808 .961 r
.34364 .28865 .34471 .28944 .3464 .28879 .34532 .28808 Mtetra
.65 .828 .969 r
.34532 .28808 .3464 .28879 .34808 .28827 .34701 .28749 Mtetra
.676 .819 .952 r
.34701 .28749 .34808 .28827 .34976 .28779 .3487 .28682 Mtetra
.703 .785 .915 r
.3487 .28682 .34976 .28779 .35144 .28726 .3504 .28604 Mtetra
.681 .73 .888 r
.3504 .28604 .35144 .28726 .35313 .28671 .3521 .28533 Mtetra
.624 .684 .886 r
.3521 .28533 .35313 .28671 .35482 .28609 .35378 .28489 Mtetra
.471 .65 .937 r
.35378 .28489 .35482 .28609 .35652 .28537 .35544 .2849 Mtetra
.141 .637 .912 r
.35544 .2849 .35652 .28537 .35822 .28463 .35709 .28507 Mtetra
.122 0 0 r
.35709 .28507 .35822 .28463 .35992 .2838 .35876 .28492 Mtetra
0 0 0 r
.35876 .28492 .35992 .2838 .36164 .28282 .36048 .28388 Mtetra
.072 0 0 r
.36048 .28388 .36164 .28282 .36333 .28222 .36218 .28324 Mtetra
.609 .142 .119 r
.36218 .28324 .36333 .28222 .36498 .28265 .3638 .28419 Mtetra
.957 .681 .472 r
.3638 .28419 .36498 .28265 .36644 .28663 .35542 .47987 Mtetra
.553 .317 .511 r
.35542 .47987 .36644 .28663 .35781 .49087 .35642 .49513 Mtetra
.666 .331 .396 r
.35642 .49513 .35781 .49087 .35932 .49649 .35808 .49764 Mtetra
.297 0 0 r
.35808 .49764 .35932 .49649 .36106 .49728 .35988 .49745 Mtetra
.463 .89 .855 r
.35988 .49745 .36106 .49728 .36285 .49726 .36171 .49668 Mtetra
.714 .883 .959 r
.36171 .49668 .36285 .49726 .36467 .49686 .36355 .49577 Mtetra
.62 .752 .94 r
.36355 .49577 .36467 .49686 .36648 .49638 .36537 .49528 Mtetra
.646 .76 .932 r
.36537 .49528 .36648 .49638 .36831 .49575 .36719 .4947 Mtetra
.678 .777 .926 r
.36719 .4947 .36831 .49575 .37013 .49518 .36902 .49397 Mtetra
.704 .757 .893 r
.36902 .49397 .37013 .49518 .37194 .49498 .37086 .4931 Mtetra
.741 .677 .789 r
.37086 .4931 .37194 .49498 .37376 .49439 .37272 .49169 Mtetra
.791 .641 .696 r
.37272 .49169 .37376 .49439 .37564 .49277 .37466 .4888 Mtetra
.927 .674 .535 r
.37466 .4888 .37564 .49277 .37769 .48722 .37751 .46536 Mtetra
.937 .662 .494 r
.37751 .46536 .37769 .48722 .38852 .2815 .38772 .27508 Mtetra
.703 .503 .614 r
.38772 .27508 .38852 .2815 .3905 .27496 .38957 .27155 Mtetra
.645 .523 .7 r
.38957 .27155 .3905 .27496 .39224 .27386 .3913 .27054 Mtetra
.593 .495 .712 r
.3913 .27054 .39224 .27386 .39394 .27348 .39301 .27009 Mtetra
.565 .474 .711 r
.39301 .27009 .39394 .27348 .39565 .27314 .39471 .26986 Mtetra
.599 .5 .714 r
.39471 .26986 .39565 .27314 .3974 .27172 .39642 .26936 Mtetra
.616 .565 .775 r
.39642 .26936 .3974 .27172 .39915 .27035 .39814 .26885 Mtetra
.641 .674 .866 r
.39814 .26885 .39915 .27035 .40089 .26919 .39985 .26831 Mtetra
.673 .8 .943 r
.39985 .26831 .40089 .26919 .40262 .26848 .40158 .26764 Mtetra
.68 .811 .945 r
.40158 .26764 .40262 .26848 .40434 .26791 .4033 .26694 Mtetra
.68 .784 .928 r
.4033 .26694 .40434 .26791 .40606 .26741 .40503 .26625 Mtetra
.666 .741 .906 r
.40503 .26625 .40606 .26741 .40778 .26688 .40676 .26561 Mtetra
.662 .72 .892 r
.40676 .26561 .40778 .26688 .4095 .26635 .40848 .26498 Mtetra
.662 .703 .878 r
.40848 .26498 .4095 .26635 .41122 .2658 .41021 .26435 Mtetra
.677 .695 .859 r
.41021 .26435 .41122 .2658 .41295 .26519 .41194 .26362 Mtetra
.66 .671 .849 r
.41194 .26362 .41295 .26519 .41468 .26454 .41367 .26296 Mtetra
.629 .656 .858 r
.41367 .26296 .41468 .26454 .41641 .26386 .4154 .26247 Mtetra
.49 .624 .91 r
.4154 .26247 .41641 .26386 .41815 .26313 .41711 .26249 Mtetra
.224 .652 .956 r
.41711 .26249 .41815 .26313 .41988 .2624 .41881 .26267 Mtetra
.258 0 0 r
.41881 .26267 .41988 .2624 .42162 .26167 .42052 .26285 Mtetra
.193 0 0 r
.42052 .26285 .42162 .26167 .42336 .261 .42225 .26236 Mtetra
.149 0 0 r
.42225 .26236 .42336 .261 .42509 .26035 .42399 .26166 Mtetra
.095 0 0 r
.42399 .26166 .42509 .26035 .42683 .25971 .42574 .26086 Mtetra
.117 0 0 r
.42574 .26086 .42683 .25971 .42857 .25907 .42748 .26022 Mtetra
.116 0 0 r
.42748 .26022 .42857 .25907 .43031 .25843 .42922 .25958 Mtetra
.112 0 0 r
.42922 .25958 .43031 .25843 .43205 .2578 .43096 .25893 Mtetra
.099 0 0 r
.43096 .25893 .43205 .2578 .43379 .25714 .43271 .25826 Mtetra
.097 0 0 r
.43271 .25826 .43379 .25714 .43553 .25649 .43445 .2576 Mtetra
.096 0 0 r
.43445 .2576 .43553 .25649 .43728 .25583 .4362 .25694 Mtetra
0 0 0 r
.4362 .25694 .43728 .25583 .43903 .25481 .43796 .25572 Mtetra
.43796 .25572 .43903 .25481 .44078 .25409 .43971 .25498 Mtetra
.384 0 0 r
.43971 .25498 .44078 .25409 .44251 .25396 .44144 .25512 Mtetra
.898 .547 .37 r
.44144 .25512 .44251 .25396 .44417 .2569 .44296 .26299 Mtetra
.959 .674 .453 r
.44296 .26299 .44417 .2569 .44071 .45914 .4394 .46693 Mtetra
.655 .351 .444 r
.4394 .46693 .44071 .45914 .44231 .46913 .44116 .47062 Mtetra
.431 0 .061 r
.44116 .47062 .44231 .46913 .44414 .47028 .44302 .47074 Mtetra
0 0 0 r
.44302 .47074 .44414 .47028 .446 .47039 .4449 .47009 Mtetra
.742 .948 .947 r
.4449 .47009 .446 .47039 .44787 .47002 .44679 .46894 Mtetra
.774 .802 .876 r
.44679 .46894 .44787 .47002 .44975 .46955 .44869 .46764 Mtetra
.748 .682 .788 r
.44869 .46764 .44975 .46955 .45163 .46892 .45059 .46614 Mtetra
.711 .601 .732 r
.45059 .46614 .45163 .46892 .45351 .46821 .45249 .46458 Mtetra
.564 .475 .713 r
.45249 .46458 .45351 .46821 .45539 .46801 .45436 .46435 Mtetra
.583 .486 .71 r
.45436 .46435 .45539 .46801 .45727 .46752 .45624 .46394 Mtetra
.659 .536 .703 r
.45624 .46394 .45727 .46752 .45916 .46639 .45814 .4627 Mtetra
.876 .653 .597 r
.45814 .4627 .45916 .46639 .46112 .46212 .46018 .45443 Mtetra
.962 .682 .457 r
.46018 .45443 .46112 .46212 .46679 .26097 .466 .24826 Mtetra
.657 .436 .572 r
.466 .24826 .46679 .26097 .4688 .24707 .46784 .24349 Mtetra
.663 .529 .691 r
.46784 .24349 .4688 .24707 .4706 .24465 .46962 .2422 Mtetra
.616 .561 .77 r
.46962 .2422 .4706 .24465 .47238 .24334 .47139 .24167 Mtetra
.565 .618 .864 r
.47139 .24167 .47238 .24334 .47415 .2425 .47315 .24146 Mtetra
.683 .777 .922 r
.47315 .24146 .47415 .2425 .47592 .24181 .47492 .24073 Mtetra
.689 .771 .914 r
.47492 .24073 .47592 .24181 .47768 .24126 .47669 .23998 Mtetra
.659 .722 .896 r
.47669 .23998 .47768 .24126 .47945 .24076 .47846 .23935 Mtetra
.63 .688 .886 r
.47846 .23935 .47945 .24076 .48123 .23972 .48023 .23885 Mtetra
.467 .731 .984 r
.48023 .23885 .48123 .23972 .48301 .23885 .482 .23874 Mtetra
.371 0 0 r
.482 .23874 .48301 .23885 .48478 .23853 .48376 .23941 Mtetra
.885 .507 .318 r
.48376 .23941 .48478 .23853 .48651 .2408 .48545 .24533 Mtetra
.964 .675 .437 r
.48545 .24533 .48651 .2408 .48792 .2716 .48469 .4513 Mtetra
.531 .298 .507 r
.48469 .4513 .48792 .2716 .48764 .45369 .48654 .45547 Mtetra
.483 .047 .135 r
.48654 .45547 .48764 .45369 .48952 .45538 .48844 .45578 Mtetra
.244 .742 .666 r
.48844 .45578 .48952 .45538 .49141 .4556 .49035 .45508 Mtetra
.741 .912 .951 r
.49035 .45508 .49141 .4556 .49332 .45526 .49226 .45399 Mtetra
.537 .692 .939 r
.49226 .45399 .49332 .45526 .49523 .45508 .49417 .45379 Mtetra
.575 .706 .932 r
.49417 .45379 .49523 .45508 .49714 .45455 .49608 .45347 Mtetra
.734 .8 .904 r
.49608 .45347 .49714 .45455 .49905 .45333 .49799 .45242 Mtetra
.946 .794 .661 r
.49799 .45242 .49905 .45333 .50099 .44943 .49994 .44753 Mtetra
.97 .688 .437 r
.49994 .44753 .50099 .44943 .50306 .42656 .50333 .23807 Mtetra
.541 .312 .516 r
.50333 .23807 .50306 .42656 .50613 .23406 .50517 .23041 Mtetra
.695 .547 .681 r
.50517 .23041 .50613 .23406 .50794 .23131 .50696 .22862 Mtetra
.613 .544 .754 r
.50696 .22862 .50794 .23131 .50973 .22995 .50875 .22808 Mtetra
.539 .58 .844 r
.50875 .22808 .50973 .22995 .51152 .2291 .51054 .228 Mtetra
.602 .738 .94 r
.51054 .228 .51152 .2291 .51332 .22845 .51234 .22758 Mtetra
.641 .805 .962 r
.51234 .22758 .51332 .22845 .51511 .22793 .51413 .227 Mtetra
.658 .794 .948 r
.51413 .227 .51511 .22793 .51691 .22749 .51593 .22636 Mtetra
.7 .768 .904 r
.51593 .22636 .51691 .22749 .5187 .22689 .51772 .22554 Mtetra
.697 .727 .873 r
.51772 .22554 .5187 .22689 .5205 .2262 .51952 .2247 Mtetra
.671 .694 .863 r
.51952 .2247 .5205 .2262 .5223 .22546 .52132 .22397 Mtetra
.644 .684 .873 r
.52132 .22397 .5223 .22546 .5241 .22429 .52312 .22339 Mtetra
.518 .75 .98 r
.52312 .22339 .5241 .22429 .5259 .22328 .52492 .22317 Mtetra
.257 0 0 r
.52492 .22317 .5259 .22328 .5277 .22288 .52673 .22365 Mtetra
.852 .44 .251 r
.52673 .22365 .5277 .22288 .52951 .22547 .52854 .22786 Mtetra
.969 .676 .418 r
.52854 .22786 .52951 .22547 .53175 .43224 .53072 .4347 Mtetra
.812 .44 .352 r
.53072 .4347 .53175 .43224 .53371 .44107 .53267 .43989 Mtetra
.035 .418 .863 r
.53267 .43989 .53371 .44107 .53565 .44212 .53461 .4408 Mtetra
.594 .71 .924 r
.53461 .4408 .53565 .44212 .53759 .44152 .53655 .4404 Mtetra
.712 .79 .912 r
.53655 .4404 .53759 .44152 .53953 .4404 .53849 .43946 Mtetra
.704 .822 .938 r
.53849 .43946 .53953 .4404 .54148 .44004 .54044 .43857 Mtetra
.726 .735 .857 r
.54044 .43857 .54148 .44004 .54342 .4398 .54238 .43745 Mtetra
.754 .653 .749 r
.54238 .43745 .54342 .4398 .54537 .4389 .54432 .4356 Mtetra
.851 .651 .632 r
.54432 .4356 .54537 .4389 .54729 .43496 .54623 .43016 Mtetra
.971 .683 .425 r
.54623 .43016 .54729 .43496 .54769 .22798 .54669 .22188 Mtetra
.788 .562 .594 r
.54669 .22188 .54769 .22798 .54943 .21664 .54847 .21542 Mtetra
.842 .784 .796 r
.54847 .21542 .54943 .21664 .55124 .21432 .55027 .2134 Mtetra
.677 .808 .945 r
.55027 .2134 .55124 .21432 .55305 .21366 .55209 .21268 Mtetra
.564 .753 .966 r
.55209 .21268 .55305 .21366 .55488 .21349 .55392 .21235 Mtetra
.657 .754 .921 r
.55392 .21235 .55488 .21349 .5567 .21308 .55574 .21172 Mtetra
.695 .727 .875 r
.55574 .21172 .5567 .21308 .55853 .2124 .55756 .21088 Mtetra
.67 .693 .863 r
.55756 .21088 .55853 .2124 .56035 .21168 .55938 .21015 Mtetra
.644 .68 .87 r
.55938 .21015 .56035 .21168 .56217 .21057 .56121 .20956 Mtetra
.549 .739 .964 r
.56121 .20956 .56217 .21057 .56399 .2095 .56304 .20928 Mtetra
0 .458 .708 r
.56304 .20928 .56399 .2095 .56582 .20902 .56488 .20966 Mtetra
.827 .387 .19 r
.56488 .20966 .56582 .20902 .56768 .21106 .56677 .21311 Mtetra
.971 .675 .402 r
.56677 .21311 .56768 .21106 .57254 .41563 .5716 .42034 Mtetra
.769 .426 .404 r
.5716 .42034 .57254 .41563 .57468 .42741 .57366 .42634 Mtetra
0 .192 .687 r
.57366 .42634 .57468 .42741 .57669 .42917 .57566 .42782 Mtetra
.513 .671 .935 r
.57566 .42782 .57669 .42917 .57866 .42887 .57764 .42771 Mtetra
.743 .796 .895 r
.57764 .42771 .57866 .42887 .58062 .42756 .5796 .42658 Mtetra
.932 .819 .711 r
.5796 .42658 .58062 .42756 .58255 .42436 .58152 .42289 Mtetra
.975 .685 .407 r
.58152 .42289 .58255 .42436 .58436 .41522 .57984 .21965 Mtetra
.557 .323 .517 r
.57984 .21965 .58436 .41522 .58241 .2079 .5814 .20377 Mtetra
.728 .554 .655 r
.5814 .20377 .58241 .2079 .58419 .20412 .5832 .20109 Mtetra
.624 .533 .731 r
.5832 .20109 .58419 .20412 .58601 .20264 .58504 .20037 Mtetra
.563 .552 .8 r
.58504 .20037 .58601 .20264 .58785 .20173 .5869 .20019 Mtetra
.585 .654 .884 r
.5869 .20019 .58785 .20173 .58969 .201 .58875 .19987 Mtetra
.657 .76 .925 r
.58875 .19987 .58969 .201 .59154 .20032 .59059 .19923 Mtetra
.667 .771 .927 r
.59059 .19923 .59154 .20032 .59338 .19973 .59244 .19854 Mtetra
.736 .775 .884 r
.59244 .19854 .59338 .19973 .59523 .19879 .59428 .1975 Mtetra
.744 .758 .864 r
.59428 .1975 .59523 .19879 .59706 .19774 .59612 .19636 Mtetra
.646 .709 .893 r
.59612 .19636 .59706 .19774 .59892 .19724 .59797 .19577 Mtetra
0 .245 .76 r
.59797 .19577 .59892 .19724 .60083 .19893 .59987 .19726 Mtetra
.959 .623 .255 r
.59987 .19726 .60083 .19893 .60788 .40019 .60215 .21316 Mtetra
0 0 .331 r
.60215 .21316 .60788 .40019 .61028 .41546 .60926 .41382 Mtetra
0 .105 .655 r
.60926 .41382 .61028 .41546 .61234 .41732 .61133 .41594 Mtetra
.574 .696 .924 r
.61133 .41594 .61234 .41732 .61434 .41683 .61333 .41561 Mtetra
.722 .783 .901 r
.61333 .41561 .61434 .41683 .61632 .41575 .61532 .41459 Mtetra
.728 .794 .904 r
.61532 .41459 .61632 .41575 .61832 .41509 .6173 .41353 Mtetra
.696 .717 .865 r
.6173 .41353 .61832 .41509 .62033 .41495 .61929 .41259 Mtetra
.731 .646 .764 r
.61929 .41259 .62033 .41495 .62233 .41424 .62127 .41103 Mtetra
.82 .641 .66 r
.62127 .41103 .62233 .41424 .62426 .41144 .62317 .40705 Mtetra
.975 .68 .396 r
.62317 .40705 .62426 .41144 .62592 .39981 .61875 .19985 Mtetra
.544 .313 .515 r
.61875 .19985 .62592 .39981 .6213 .1921 .62034 .19026 Mtetra
.845 .72 .725 r
.62034 .19026 .6213 .1921 .62307 .18867 .62214 .18752 Mtetra
.705 .776 .907 r
.62214 .18752 .62307 .18867 .62493 .18774 .624 .18665 Mtetra
.588 .743 .95 r
.624 .18665 .62493 .18774 .62681 .18739 .62588 .18626 Mtetra
.646 .758 .931 r
.62588 .18626 .62681 .18739 .62868 .1868 .62775 .18565 Mtetra
.73 .784 .896 r
.62775 .18565 .62868 .1868 .63054 .18574 .62961 .18464 Mtetra
.638 .763 .938 r
.62961 .18464 .63054 .18574 .63242 .18521 .63149 .18407 Mtetra
.061 .424 .869 r
.63149 .18407 .63242 .18521 .63436 .18659 .63342 .18496 Mtetra
.84 .449 0 r
.63342 .18496 .63436 .18659 .6434 .37937 .63554 .19092 Mtetra
0 0 .338 r
.63554 .19092 .6434 .37937 .64633 .40359 .64521 .39882 Mtetra
.103 .136 .61 r
.64521 .39882 .64633 .40359 .64846 .40583 .64739 .40242 Mtetra
.483 .441 .735 r
.64739 .40242 .64846 .40583 .65049 .40545 .64945 .40283 Mtetra
.57 .544 .786 r
.64945 .40283 .65049 .40545 .6525 .40437 .65149 .40257 Mtetra
.569 .629 .872 r
.65149 .40257 .6525 .40437 .6545 .40317 .65353 .40231 Mtetra
.428 .736 .991 r
.65353 .40231 .6545 .40317 .65651 .40224 .65558 .40222 Mtetra
.424 .869 .868 r
.65558 .40222 .65651 .40224 .6585 .40074 .6576 .40151 Mtetra
.71 .922 .584 r
.6576 .40151 .6585 .40074 .66041 .39725 .65955 .39903 Mtetra
.967 .817 .392 r
.65955 .39903 .66041 .39725 .65372 .1926 .66121 .38957 Mtetra
0 0 .343 r
.66121 .38957 .65372 .1926 .65508 .17964 .6542 .17918 Mtetra
.974 .867 .67 r
.6542 .17918 .65508 .17964 .65687 .17652 .65594 .1752 Mtetra
.725 .753 .875 r
.65594 .1752 .65687 .17652 .65874 .17555 .65782 .17417 Mtetra
.601 .693 .908 r
.65782 .17417 .65874 .17555 .66064 .17509 .65972 .17377 Mtetra
.613 .71 .914 r
.65972 .17377 .66064 .17509 .66254 .17448 .66163 .1733 Mtetra
.734 .784 .893 r
.66163 .1733 .66254 .17448 .66441 .17329 .6635 .17226 Mtetra
.65 .786 .947 r
.6635 .17226 .66441 .17329 .6663 .17259 .6654 .17162 Mtetra
.151 .527 .92 r
.6654 .17162 .6663 .17259 .66827 .17344 .66736 .17221 Mtetra
.813 .39 0 r
.66736 .17221 .66827 .17344 .67064 .18243 .66953 .17711 Mtetra
.976 .673 .335 r
.66953 .17711 .67064 .18243 .68282 .39099 .68167 .38598 Mtetra
.023 .076 .579 r
.68167 .38598 .68282 .39099 .68505 .39392 .68396 .39042 Mtetra
.47 .43 .731 r
.68396 .39042 .68505 .39392 .68711 .39365 .68607 .39095 Mtetra
.562 .534 .781 r
.68607 .39095 .68711 .39365 .68914 .39263 .68814 .39075 Mtetra
.582 .626 .861 r
.68814 .39075 .68914 .39263 .69116 .39136 .69021 .39042 Mtetra
.428 .718 .985 r
.69021 .39042 .69116 .39136 .6932 .39046 .69229 .39037 Mtetra
.422 .866 .891 r
.69229 .39037 .6932 .39046 .69521 .38902 .69434 .38971 Mtetra
.646 .906 .591 r
.69434 .38971 .69521 .38902 .69713 .38594 .69632 .38752 Mtetra
.958 .821 .388 r
.69632 .38752 .69713 .38594 .69799 .36319 .69794 .37887 Mtetra
.978 .687 .312 r
.69794 .37887 .69799 .36319 .68931 .16768 .68844 .16701 Mtetra
.975 .842 .648 r
.68844 .16701 .68931 .16768 .69107 .16416 .69015 .1626 Mtetra
.714 .715 .849 r
.69015 .1626 .69107 .16416 .69296 .16313 .69204 .16157 Mtetra
.594 .662 .885 r
.69204 .16157 .69296 .16313 .69488 .16264 .69398 .16119 Mtetra
.573 .67 .905 r
.69398 .16119 .69488 .16264 .69681 .16218 .69591 .1609 Mtetra
.728 .767 .884 r
.69591 .1609 .69681 .16218 .6987 .16104 .69781 .15986 Mtetra
.66 .761 .925 r
.69781 .15986 .6987 .16104 .70062 .16035 .69973 .15918 Mtetra
.338 .599 .943 r
.69973 .15918 .70062 .16035 .70262 .16095 .70171 .15952 Mtetra
.71 .294 0 r
.70171 .15952 .70262 .16095 .70505 .16878 .70393 .16381 Mtetra
.975 .668 .317 r
.70393 .16381 .70505 .16878 .71979 .37856 .71858 .37305 Mtetra
0 .042 .555 r
.71858 .37305 .71979 .37856 .72211 .38188 .72101 .37835 Mtetra
.448 .416 .73 r
.72101 .37835 .72211 .38188 .7242 .38159 .72317 .37905 Mtetra
.548 .54 .798 r
.72317 .37905 .7242 .38159 .72626 .38059 .72528 .37894 Mtetra
.603 .67 .887 r
.72528 .37894 .72626 .38059 .72831 .37948 .72737 .37848 Mtetra
.525 .759 .982 r
.72737 .37848 .72831 .37948 .73042 .37935 .72948 .37819 Mtetra
.676 .791 .935 r
.72948 .37819 .73042 .37935 .7325 .37874 .73155 .37738 Mtetra
.819 .796 .83 r
.73155 .37738 .7325 .37874 .73451 .3769 .73355 .37553 Mtetra
.96 .782 .616 r
.73355 .37553 .73451 .3769 .7361 .36877 .7353 .36982 Mtetra
.977 .675 .332 r
.7353 .36982 .7361 .36877 .724 .15601 .7234 .15905 Mtetra
0 0 0 r
.7234 .15905 .724 .15601 .72566 .15119 .72491 .15202 Mtetra
.72491 .15202 .72566 .15119 .72756 .15008 .72676 .15001 Mtetra
.679 .977 .884 r
.72676 .15001 .72756 .15008 .72952 .14965 .72866 .14877 Mtetra
.692 .841 .954 r
.72866 .14877 .72952 .14965 .73149 .14948 .73059 .14793 Mtetra
.659 .696 .873 r
.73059 .14793 .73149 .14948 .73343 .14873 .73253 .14723 Mtetra
.635 .693 .886 r
.73253 .14723 .73343 .14873 .73537 .14804 .73448 .14665 Mtetra
.642 .717 .902 r
.73448 .14665 .73537 .14804 .73732 .14745 .73643 .14605 Mtetra
.74 .754 .864 r
.73643 .14605 .73732 .14745 .73928 .1469 .73835 .14489 Mtetra
.665 .64 .815 r
.73835 .14489 .73928 .1469 .74127 .14682 .74028 .14407 Mtetra
.543 .508 .766 r
.74028 .14407 .74127 .14682 .74334 .14786 .74228 .144 Mtetra
.069 .14 .63 r
.74228 .144 .74334 .14786 .74646 .16286 .74452 .14734 Mtetra
.965 .663 .254 r
.74452 .14734 .74646 .16286 .76358 .36458 .76211 .35616 Mtetra
.041 .036 .523 r
.76211 .35616 .76358 .36458 .76596 .36762 .76484 .36386 Mtetra
.426 .392 .718 r
.76484 .36386 .76596 .36762 .76811 .36757 .76707 .3648 Mtetra
.529 .513 .782 r
.76707 .3648 .76811 .36757 .77021 .36681 .76923 .36482 Mtetra
.594 .624 .851 r
.76923 .36482 .77021 .36681 .77228 .36559 .77136 .36442 Mtetra
.472 .695 .965 r
.77136 .36442 .77228 .36559 .77437 .36467 .77352 .36435 Mtetra
.463 .87 .957 r
.77352 .36435 .77437 .36467 .77642 .36323 .77564 .36377 Mtetra
0 0 0 r
.77564 .36377 .77642 .36323 .77839 .3607 .7777 .36238 Mtetra
.727 .779 .286 r
.7777 .36238 .77839 .3607 .77962 .34901 .77947 .35738 Mtetra
.972 .671 .287 r
.77947 .35738 .77962 .34901 .76491 .14073 .76469 .14741 Mtetra
0 0 .178 r
.76469 .14741 .76491 .14073 .76658 .13638 .76591 .13745 Mtetra
0 0 0 r
.76591 .13745 .76658 .13638 .76849 .13504 .7678 .13587 Mtetra
.06 0 0 r
.7678 .13587 .76849 .13504 .77045 .13429 .76977 .13519 Mtetra
.256 0 0 r
.76977 .13519 .77045 .13429 .77244 .13386 .77178 .13497 Mtetra
.231 .009 .357 r
.13935 .37759 .14234 .3631 .14397 .36198 .14157 .37157 Mtetra
.428 .162 .406 r
.14157 .37157 .14397 .36198 .14555 .36128 .14325 .37008 Mtetra
.641 .358 .474 r
.14325 .37008 .14555 .36128 .14703 .36138 .14436 .37337 Mtetra
.92 .663 .532 r
.14436 .37337 .14703 .36138 .14784 .36721 .12313 .56506 Mtetra
.531 .299 .508 r
.12313 .56506 .14784 .36721 .12579 .56727 .12426 .56901 Mtetra
.691 .305 .312 r
.12426 .56901 .12579 .56727 .12691 .57137 .12566 .57072 Mtetra
.571 .817 .991 r
.12566 .57072 .12691 .57137 .12851 .57138 .1273 .57033 Mtetra
.728 .767 .885 r
.1273 .57033 .12851 .57138 .1302 .57057 .12901 .5694 Mtetra
.761 .75 .843 r
.12901 .5694 .1302 .57057 .13195 .56932 .13076 .56817 Mtetra
.709 .745 .88 r
.13076 .56817 .13195 .56932 .13365 .5685 .13246 .56732 Mtetra
.694 .738 .884 r
.13246 .56732 .13365 .5685 .13535 .56772 .13416 .56655 Mtetra
.681 .737 .894 r
.13416 .56655 .13535 .56772 .13704 .56697 .13585 .56585 Mtetra
.655 .741 .913 r
.13585 .56585 .13704 .56697 .13872 .56632 .13752 .56528 Mtetra
.632 .75 .933 r
.13752 .56528 .13872 .56632 .14039 .56576 .13918 .5648 Mtetra
.608 .76 .952 r
.13918 .5648 .14039 .56576 .14206 .56528 .14084 .56439 Mtetra
.434 .711 .982 r
.14084 .56439 .14206 .56528 .1437 .56504 .14246 .56436 Mtetra
.493 .783 .996 r
.14246 .56436 .1437 .56504 .14534 .56478 .1441 .56414 Mtetra
.672 .843 .965 r
.1441 .56414 .14534 .56478 .147 .56436 .14579 .56347 Mtetra
.852 .788 .789 r
.14579 .56347 .147 .56436 .14868 .56382 .14765 .56128 Mtetra
.828 .656 .669 r
.14765 .56128 .14868 .56382 .15041 .5628 .14973 .55709 Mtetra
.934 .681 .531 r
.14973 .55709 .15041 .5628 .15225 .5608 .1726 .36478 Mtetra
.554 .323 .52 r
.1726 .36478 .15225 .5608 .15498 .55064 .17553 .35207 Mtetra
.532 .305 .515 r
.17553 .35207 .15498 .55064 .1783 .35189 .17745 .34845 Mtetra
.722 .565 .677 r
.17745 .34845 .1783 .35189 .18027 .34772 .1792 .34631 Mtetra
.699 .693 .841 r
.1792 .34631 .18027 .34772 .18193 .34651 .18081 .34549 Mtetra
.593 .73 .939 r
.18081 .34549 .18193 .34651 .18349 .3461 .18237 .34517 Mtetra
.498 .715 .969 r
.18237 .34517 .18349 .3461 .18503 .34602 .18391 .34505 Mtetra
.62 .75 .939 r
.18391 .34505 .18503 .34602 .1866 .34561 .18548 .34463 Mtetra
.655 .757 .925 r
.18548 .34463 .1866 .34561 .18818 .34509 .18706 .34409 Mtetra
.67 .755 .914 r
.18706 .34409 .18818 .34509 .18976 .34454 .18866 .34349 Mtetra
.73 .757 .874 r
.18866 .34349 .18976 .34454 .19137 .34385 .19028 .34257 Mtetra
.703 .714 .857 r
.19028 .34257 .19137 .34385 .19297 .34318 .1919 .34176 Mtetra
.631 .669 .868 r
.1919 .34176 .19297 .34318 .19456 .34263 .19348 .3413 Mtetra
0 .085 .618 r
.19348 .3413 .19456 .34263 .19609 .34267 .19487 .34264 Mtetra
.877 .489 .298 r
.19487 .34264 .19609 .34267 .19759 .34297 .19603 .34624 Mtetra
.937 .677 .517 r
.19603 .34624 .19759 .34297 .1991 .34321 .17811 .53464 Mtetra
0 0 .122 r
.17811 .53464 .1991 .34321 .20074 .34224 .1988 .34927 Mtetra
0 0 0 r
.1988 .34927 .20074 .34224 .20242 .34082 .20106 .34227 Mtetra
.93 .956 .638 r
.20106 .34227 .20242 .34082 .2041 .33946 .20296 .33878 Mtetra
.828 .829 .848 r
.20296 .33878 .2041 .33946 .20576 .33829 .20465 .33724 Mtetra
.701 .755 .893 r
.20465 .33724 .20576 .33829 .20738 .33751 .20627 .33649 Mtetra
.554 .718 .949 r
.20627 .33649 .20738 .33751 .20894 .33731 .20784 .33626 Mtetra
0 .402 .849 r
.20784 .33626 .20894 .33731 .21027 .33942 .20931 .33696 Mtetra
0 .005 .578 r
.20931 .33696 .21027 .33942 .21005 .35732 .21065 .33904 Mtetra
.255 .108 .48 r
.21065 .33904 .21005 .35732 .19289 .54725 .21145 .34658 Mtetra
0 0 .137 r
.21145 .34658 .19289 .54725 .19436 .54909 .19375 .54227 Mtetra
.125 .078 .53 r
.19375 .54227 .19436 .54909 .19599 .54932 .19503 .54601 Mtetra
.198 .245 .686 r
.19503 .54601 .19599 .54932 .19768 .54903 .19653 .54759 Mtetra
.181 .458 .882 r
.19653 .54759 .19768 .54903 .19933 .54908 .19813 .54825 Mtetra
.446 .735 .989 r
.19813 .54825 .19933 .54908 .20101 .54889 .19979 .54817 Mtetra
.733 .84 .93 r
.19979 .54817 .20101 .54889 .20275 .54799 .20154 .54724 Mtetra
.908 .784 .713 r
.20154 .54724 .20275 .54799 .20478 .54417 .20357 .54348 Mtetra
.946 .689 .517 r
.20357 .54348 .20478 .54417 .2254 .34369 .22414 .34429 Mtetra
.964 .75 .566 r
.22414 .34429 .2254 .34369 .22809 .33178 .22699 .33071 Mtetra
.849 .762 .767 r
.22699 .33071 .22809 .33178 .22985 .32956 .22876 .32845 Mtetra
.683 .741 .895 r
.22876 .32845 .22985 .32956 .23148 .32888 .23039 .32778 Mtetra
.547 .698 .939 r
.23039 .32778 .23148 .32888 .23306 .32867 .23197 .32758 Mtetra
.705 .751 .888 r
.23197 .32758 .23306 .32867 .23469 .32787 .2336 .3268 Mtetra
.721 .756 .881 r
.2336 .3268 .23469 .32787 .23634 .327 .23525 .32593 Mtetra
.578 .717 .938 r
.23525 .32593 .23634 .327 .23793 .32671 .23684 .32564 Mtetra
.814 .347 0 r
.23684 .32564 .23793 .32671 .23928 .32914 .23818 .32808 Mtetra
.948 .684 .504 r
.23818 .32808 .23928 .32914 .22271 .53036 .22153 .52944 Mtetra
.945 .62 .383 r
.22153 .52944 .22271 .53036 .22357 .53941 .22239 .53839 Mtetra
.591 .068 0 r
.22239 .53839 .22357 .53941 .2251 .54103 .22393 .54001 Mtetra
.519 .721 .965 r
.22393 .54001 .2251 .54103 .2268 .54086 .22562 .53983 Mtetra
.766 .785 .869 r
.22562 .53983 .2268 .54086 .22859 .53965 .22741 .53863 Mtetra
.894 .764 .71 r
.22741 .53863 .22859 .53965 .23059 .53596 .22942 .53493 Mtetra
.948 .689 .512 r
.22942 .53493 .23059 .53596 .24945 .33887 .24835 .33783 Mtetra
.94 .711 .565 r
.24835 .33783 .24945 .33887 .25238 .32335 .25129 .32227 Mtetra
.858 .762 .756 r
.25129 .32227 .25238 .32335 .25417 .3209 .25308 .31982 Mtetra
.678 .748 .904 r
.25308 .31982 .25417 .3209 .2558 .32024 .25471 .31917 Mtetra
.519 .697 .95 r
.25471 .31917 .2558 .32024 .25739 .32009 .25631 .31904 Mtetra
.628 .739 .927 r
.25631 .31904 .25739 .32009 .25902 .31953 .25793 .31858 Mtetra
.69 .778 .919 r
.25793 .31858 .25902 .31953 .26067 .31874 .25957 .31788 Mtetra
.602 .775 .963 r
.25957 .31788 .26067 .31874 .26228 .31844 .26119 .31748 Mtetra
0 .363 .811 r
.26119 .31748 .26228 .31844 .26372 .32028 .26271 .31825 Mtetra
.654 .279 0 r
.26271 .31825 .26372 .32028 .24974 .5087 .26407 .32107 Mtetra
.473 .256 .502 r
.26407 .32107 .24974 .5087 .24977 .52894 .26415 .33939 Mtetra
0 0 .188 r
.26415 .33939 .24977 .52894 .25132 .53068 .2509 .52053 Mtetra
.546 .363 .585 r
.2509 .52053 .25132 .53068 .25305 .53027 .25263 .52021 Mtetra
.615 .417 .591 r
.25263 .52021 .25305 .53027 .25484 .52927 .2545 .51803 Mtetra
.554 .365 .579 r
.2545 .51803 .25484 .52927 .25658 .52872 .25624 .51743 Mtetra
.51 .33 .573 r
.25624 .51743 .25658 .52872 .25831 .52847 .2579 .51795 Mtetra
.6 .403 .587 r
.2579 .51795 .25831 .52847 .26008 .52756 .25975 .51614 Mtetra
.938 .676 .512 r
.25975 .51614 .26008 .52756 .26209 .5238 .27679 .3217 Mtetra
.541 .312 .517 r
.27679 .3217 .26209 .5238 .27962 .32094 .27901 .31387 Mtetra
.69 .489 .61 r
.27901 .31387 .27962 .32094 .28189 .3124 .28088 .31042 Mtetra
.759 .658 .75 r
.28088 .31042 .28189 .3124 .28368 .30995 .28261 .30872 Mtetra
.686 .725 .879 r
.28261 .30872 .28368 .30995 .28534 .30918 .28427 .308 Mtetra
.616 .712 .913 r
.28427 .308 .28534 .30918 .28697 .30888 .28591 .30759 Mtetra
.602 .686 .902 r
.28591 .30759 .28697 .30888 .28859 .30858 .28754 .30724 Mtetra
.617 .683 .889 r
.28754 .30724 .28859 .30858 .29023 .30811 .28918 .30683 Mtetra
.622 .696 .897 r
.28918 .30683 .29023 .30811 .29188 .30763 .29082 .3064 Mtetra
.689 .727 .879 r
.29082 .3064 .29188 .30763 .29353 .307 .29248 .30567 Mtetra
.72 .719 .848 r
.29248 .30567 .29353 .307 .2952 .30625 .29416 .30472 Mtetra
.669 .673 .845 r
.29416 .30472 .2952 .30625 .29686 .30558 .29582 .30403 Mtetra
.402 .547 .886 r
.29582 .30403 .29686 .30558 .2985 .30526 .29742 .30433 Mtetra
.736 .235 0 r
.29742 .30433 .2985 .30526 .3001 .30535 .29888 .30639 Mtetra
.869 .518 .381 r
.29888 .30639 .3001 .30535 .3017 .30558 .3001 .3119 Mtetra
.944 .674 .494 r
.3001 .3119 .3017 .30558 .30335 .30522 .28812 .50296 Mtetra
.518 .288 .505 r
.28812 .50296 .30335 .30522 .30504 .3042 .28999 .50089 Mtetra
.515 .285 .504 r
.28999 .50089 .30504 .3042 .3067 .3037 .29195 .4975 Mtetra
.543 .308 .51 r
.29195 .4975 .3067 .3037 .30818 .30571 .29299 .50739 Mtetra
.534 .301 .508 r
.29299 .50739 .30818 .30571 .2959 .50794 .29433 .51297 Mtetra
.651 .33 .415 r
.29433 .51297 .2959 .50794 .29712 .51541 .2959 .51541 Mtetra
.513 0 0 r
.2959 .51541 .29712 .51541 .29874 .51713 .29758 .51625 Mtetra
.52 .758 .983 r
.29758 .51625 .29874 .51713 .3005 .51689 .29934 .51602 Mtetra
.637 .8 .961 r
.29934 .51602 .3005 .51689 .30229 .51614 .30112 .51546 Mtetra
.638 .84 .978 r
.30112 .51546 .30229 .51614 .30408 .51534 .3029 .51485 Mtetra
.588 .868 .994 r
.3029 .51485 .30408 .51534 .30587 .51474 .30468 .51431 Mtetra
.69 .905 .972 r
.30468 .51431 .30587 .51474 .30766 .51401 .30649 .51346 Mtetra
.841 .879 .869 r
.30649 .51346 .30766 .51401 .30947 .51302 .30834 .5118 Mtetra
.881 .76 .724 r
.30834 .5118 .30947 .51302 .31131 .51166 .3103 .50851 Mtetra
.847 .649 .635 r
.3103 .50851 .31131 .51166 .31315 .51019 .31242 .50271 Mtetra
.845 .604 .573 r
.31242 .50271 .31315 .51019 .31496 .50922 .31508 .4883 Mtetra
.505 .305 .542 r
.31508 .4883 .31496 .50922 .31672 .50905 .31676 .48932 Mtetra
.468 .277 .538 r
.31676 .48932 .31672 .50905 .31852 .5084 .31835 .49176 Mtetra
.937 .669 .503 r
.31835 .49176 .31852 .5084 .32044 .50561 .33179 .30259 Mtetra
.542 .313 .516 r
.33179 .30259 .32044 .50561 .33443 .30469 .33395 .29425 Mtetra
.651 .44 .585 r
.33395 .29425 .33443 .30469 .33679 .293 .33581 .29066 Mtetra
.755 .634 .726 r
.33581 .29066 .33679 .293 .33862 .29001 .33757 .28877 Mtetra
.665 .72 .89 r
.33757 .28877 .33862 .29001 .34031 .2892 .33926 .28814 Mtetra
.575 .727 .946 r
.33926 .28814 .34031 .2892 .34198 .28888 .34092 .28785 Mtetra
.568 .727 .949 r
.34092 .28785 .34198 .28888 .34364 .28865 .34259 .28756 Mtetra
.655 .747 .918 r
.34259 .28756 .34364 .28865 .34532 .28808 .34427 .28699 Mtetra
.669 .75 .911 r
.34427 .28699 .34532 .28808 .34701 .28749 .34596 .28635 Mtetra
.702 .751 .89 r
.34596 .28635 .34701 .28749 .3487 .28682 .34766 .28556 Mtetra
.731 .737 .856 r
.34766 .28556 .3487 .28682 .3504 .28604 .34937 .28455 Mtetra
.682 .687 .849 r
.34937 .28455 .3504 .28604 .3521 .28533 .35107 .28379 Mtetra
.518 .609 .883 r
.35107 .28379 .3521 .28533 .35378 .28489 .35273 .28375 Mtetra
0 0 .499 r
.35273 .28375 .35378 .28489 .35544 .2849 .3543 .28541 Mtetra
.86 .466 .292 r
.3543 .28541 .35544 .2849 .35709 .28507 .35575 .28937 Mtetra
.952 .677 .477 r
.35575 .28937 .35709 .28507 .35876 .28492 .34725 .47823 Mtetra
.518 .288 .505 r
.34725 .47823 .35876 .28492 .36048 .28388 .34913 .47623 Mtetra
0 0 .266 r
.34913 .47623 .36048 .28388 .36218 .28324 .3601 .30168 Mtetra
.932 .654 .49 r
.3601 .30168 .36218 .28324 .3638 .28419 .35224 .48443 Mtetra
.539 .305 .509 r
.35224 .48443 .3638 .28419 .35542 .47987 .35359 .49271 Mtetra
.597 .321 .469 r
.35359 .49271 .35542 .47987 .35642 .49513 .35522 .49565 Mtetra
.627 .112 .001 r
.35522 .49565 .35642 .49513 .35808 .49764 .35695 .49679 Mtetra
.549 .779 .984 r
.35695 .49679 .35808 .49764 .35988 .49745 .35876 .49646 Mtetra
.669 .788 .938 r
.35876 .49646 .35988 .49745 .36171 .49668 .36058 .49577 Mtetra
.678 .807 .944 r
.36058 .49577 .36171 .49668 .36355 .49577 .36241 .49504 Mtetra
.534 .801 .995 r
.36241 .49504 .36355 .49577 .36537 .49528 .36422 .49471 Mtetra
.611 .861 .99 r
.36422 .49471 .36537 .49528 .36719 .4947 .36605 .49412 Mtetra
.77 .889 .93 r
.36605 .49412 .36719 .4947 .36902 .49397 .3679 .49295 Mtetra
.875 .796 .769 r
.3679 .49295 .36902 .49397 .37086 .4931 .36982 .49035 Mtetra
.843 .661 .657 r
.36982 .49035 .37086 .4931 .37272 .49169 .37183 .48575 Mtetra
.956 .684 .481 r
.37183 .48575 .37272 .49169 .37466 .4888 .38271 .28712 Mtetra
.548 .317 .517 r
.38271 .28712 .37466 .4888 .37751 .46536 .38492 .27579 Mtetra
.532 .304 .515 r
.38492 .27579 .37751 .46536 .38772 .27508 .38676 .27224 Mtetra
.74 .601 .703 r
.38676 .27224 .38772 .27508 .38957 .27155 .38854 .27023 Mtetra
.705 .724 .865 r
.38854 .27023 .38957 .27155 .3913 .27054 .39027 .26937 Mtetra
.634 .726 .914 r
.39027 .26937 .3913 .27054 .39301 .27009 .39198 .26887 Mtetra
.588 .701 .921 r
.39198 .26887 .39301 .27009 .39471 .26986 .39368 .26854 Mtetra
.618 .693 .898 r
.39368 .26854 .39471 .26986 .39642 .26936 .3954 .26811 Mtetra
.619 .708 .909 r
.3954 .26811 .39642 .26936 .39814 .26885 .39711 .26767 Mtetra
.639 .728 .913 r
.39711 .26767 .39814 .26885 .39985 .26831 .39883 .26715 Mtetra
.693 .75 .895 r
.39883 .26715 .39985 .26831 .40158 .26764 .40055 .26638 Mtetra
.699 .734 .878 r
.40055 .26638 .40158 .26764 .4033 .26694 .40228 .26557 Mtetra
.692 .712 .864 r
.40228 .26557 .4033 .26694 .40503 .26625 .40402 .26477 Mtetra
.666 .687 .86 r
.40402 .26477 .40503 .26625 .40676 .26561 .40574 .26409 Mtetra
.659 .679 .857 r
.40574 .26409 .40676 .26561 .40848 .26498 .40747 .26345 Mtetra
.661 .677 .854 r
.40747 .26345 .40848 .26498 .41021 .26435 .4092 .26279 Mtetra
.696 .688 .838 r
.4092 .26279 .41021 .26435 .41194 .26362 .41094 .26192 Mtetra
.657 .654 .835 r
.41094 .26192 .41194 .26362 .41367 .26296 .41267 .26126 Mtetra
.567 .612 .858 r
.41267 .26126 .41367 .26296 .4154 .26247 .41439 .26105 Mtetra
0 .164 .696 r
.41439 .26105 .4154 .26247 .41711 .26249 .41604 .26252 Mtetra
.86 .428 .188 r
.41604 .26252 .41711 .26249 .41881 .26267 .41764 .26598 Mtetra
.96 .678 .458 r
.41764 .26598 .41881 .26267 .42052 .26285 .41273 .45985 Mtetra
.532 .299 .507 r
.41273 .45985 .42052 .26285 .42225 .26236 .41439 .4647 Mtetra
.519 .289 .505 r
.41439 .4647 .42225 .26236 .42399 .26166 .41627 .46322 Mtetra
.511 .282 .504 r
.41627 .46322 .42399 .26166 .42574 .26086 .41829 .45755 Mtetra
.521 .29 .505 r
.41829 .45755 .42574 .26086 .42748 .26022 .42014 .4569 Mtetra
.42014 .4569 .42748 .26022 .42922 .25958 .422 .45612 Mtetra
.52 .29 .505 r
.422 .45612 .42922 .25958 .43096 .25893 .42386 .45521 Mtetra
.52 .289 .505 r
.42386 .45521 .43096 .25893 .43271 .25826 .42573 .45399 Mtetra
.42573 .45399 .43271 .25826 .43445 .2576 .42761 .45269 Mtetra
.42761 .45269 .43445 .2576 .4362 .25694 .42948 .45135 Mtetra
0 0 .29 r
.42948 .45135 .4362 .25694 .43796 .25572 .43654 .26879 Mtetra
.447 .195 .437 r
.43654 .26879 .43796 .25572 .43971 .25498 .43833 .2669 Mtetra
.949 .664 .463 r
.43833 .2669 .43971 .25498 .44144 .25512 .43503 .45041 Mtetra
.55 .314 .51 r
.43503 .45041 .44144 .25512 .44296 .26299 .43649 .46475 Mtetra
.529 .297 .507 r
.43649 .46475 .44296 .26299 .4394 .46693 .43825 .46824 Mtetra
.676 .233 .191 r
.43825 .46824 .4394 .46693 .44116 .47062 .44007 .46986 Mtetra
.348 .711 .985 r
.44007 .46986 .44116 .47062 .44302 .47074 .44193 .4699 Mtetra
.632 .815 .97 r
.44193 .4699 .44302 .47074 .4449 .47009 .44381 .4693 Mtetra
.769 .857 .916 r
.44381 .4693 .4449 .47009 .44679 .46894 .4457 .46811 Mtetra
.899 .831 .771 r
.4457 .46811 .44679 .46894 .44869 .46764 .44763 .46537 Mtetra
.869 .694 .663 r
.44763 .46537 .44869 .46764 .45059 .46614 .4496 .46082 Mtetra
.881 .636 .564 r
.4496 .46082 .45059 .46614 .45249 .46458 .45176 .44757 Mtetra
.948 .667 .473 r
.45176 .44757 .45249 .46458 .45436 .46435 .45741 .27367 Mtetra
0 0 .326 r
.45741 .27367 .45436 .46435 .45624 .46394 .45557 .44384 Mtetra
.601 .381 .555 r
.45557 .44384 .45624 .46394 .45814 .4627 .45751 .43993 Mtetra
.943 .661 .475 r
.45751 .43993 .45814 .4627 .46018 .45443 .4632 .24926 Mtetra
.533 .305 .515 r
.4632 .24926 .46018 .45443 .466 .24826 .46504 .24466 Mtetra
.746 .578 .667 r
.46504 .24466 .466 .24826 .46784 .24349 .46685 .24197 Mtetra
.707 .701 .841 r
.46685 .24197 .46784 .24349 .46962 .2422 .46862 .24102 Mtetra
.621 .728 .923 r
.46862 .24102 .46962 .2422 .47139 .24167 .47039 .24056 Mtetra
.565 .72 .945 r
.47039 .24056 .47139 .24167 .47315 .24146 .47215 .24027 Mtetra
.724 .76 .882 r
.47215 .24027 .47315 .24146 .47492 .24073 .47392 .23932 Mtetra
.705 .716 .858 r
.47392 .23932 .47492 .24073 .47669 .23998 .4757 .23842 Mtetra
.639 .669 .863 r
.4757 .23842 .47669 .23998 .47846 .23935 .47747 .23787 Mtetra
.233 .467 .879 r
.47747 .23787 .47846 .23935 .48023 .23885 .47922 .23857 Mtetra
.758 .243 0 r
.47922 .23857 .48023 .23885 .482 .23874 .48096 .24074 Mtetra
.882 .535 .385 r
.48096 .24074 .482 .23874 .48376 .23941 .48261 .24919 Mtetra
.957 .668 .445 r
.48261 .24919 .48376 .23941 .48545 .24533 .48174 .4498 Mtetra
.529 .297 .507 r
.48174 .4498 .48545 .24533 .48469 .4513 .48359 .45341 Mtetra
.634 .226 .252 r
.48359 .45341 .48469 .4513 .48654 .45547 .48547 .45484 Mtetra
.43 .783 .997 r
.48547 .45484 .48654 .45547 .48844 .45578 .48737 .45464 Mtetra
.685 .775 .919 r
.48737 .45464 .48844 .45578 .49035 .45508 .48928 .45385 Mtetra
.724 .769 .888 r
.48928 .45385 .49035 .45508 .49226 .45399 .4912 .45283 Mtetra
.485 .691 .959 r
.4912 .45283 .49226 .45399 .49417 .45379 .4931 .45275 Mtetra
.517 .731 .971 r
.4931 .45275 .49417 .45379 .49608 .45347 .49501 .45255 Mtetra
.715 .826 .934 r
.49501 .45255 .49608 .45347 .49799 .45242 .49693 .45161 Mtetra
.95 .804 .664 r
.49693 .45161 .49799 .45242 .49994 .44753 .49888 .44682 Mtetra
.972 .689 .435 r
.49888 .44682 .49994 .44753 .50333 .23807 .50234 .23696 Mtetra
.957 .749 .581 r
.50234 .23696 .50333 .23807 .50517 .23041 .50418 .22904 Mtetra
.808 .754 .802 r
.50418 .22904 .50517 .23041 .50696 .22862 .50598 .22729 Mtetra
.622 .701 .901 r
.50598 .22729 .50696 .22862 .50875 .22808 .50777 .22682 Mtetra
.477 .649 .934 r
.50777 .22682 .50875 .22808 .51054 .228 .50956 .22683 Mtetra
.597 .723 .932 r
.50956 .22683 .51054 .228 .51234 .22758 .51135 .22644 Mtetra
.654 .75 .92 r
.51135 .22644 .51234 .22758 .51413 .227 .51315 .22583 Mtetra
.671 .752 .911 r
.51315 .22583 .51413 .227 .51593 .22636 .51495 .22515 Mtetra
.736 .762 .874 r
.51495 .22515 .51593 .22636 .51772 .22554 .51674 .2241 Mtetra
.719 .721 .851 r
.51674 .2241 .51772 .22554 .51952 .2247 .51854 .2231 Mtetra
.657 .673 .854 r
.51854 .2231 .51952 .2247 .52132 .22397 .52034 .22243 Mtetra
.338 .521 .889 r
.52034 .22243 .52132 .22397 .52312 .22339 .52214 .22292 Mtetra
.689 .152 0 r
.52214 .22292 .52312 .22339 .52492 .22317 .52395 .22489 Mtetra
.869 .502 .349 r
.52395 .22489 .52492 .22317 .52673 .22365 .52575 .23153 Mtetra
.963 .669 .428 r
.52575 .23153 .52673 .22365 .52854 .22786 .52774 .4336 Mtetra
.53 .297 .507 r
.52774 .4336 .52854 .22786 .53072 .4347 .52968 .43763 Mtetra
.631 .252 .307 r
.52968 .43763 .53072 .4347 .53267 .43989 .53162 .43924 Mtetra
.047 .542 .884 r
.53162 .43924 .53267 .43989 .53461 .4408 .53357 .4397 Mtetra
.537 .731 .964 r
.53357 .4397 .53461 .4408 .53655 .4404 .53551 .43945 Mtetra
.695 .819 .942 r
.53551 .43945 .53655 .4404 .53849 .43946 .53745 .4386 Mtetra
.854 .855 .842 r
.53745 .4386 .53849 .43946 .54044 .43857 .53939 .43667 Mtetra
.863 .723 .705 r
.53939 .43667 .54044 .43857 .54238 .43745 .54132 .43325 Mtetra
.856 .633 .6 r
.54132 .43325 .54238 .43745 .54432 .4356 .54323 .42585 Mtetra
.966 .678 .433 r
.54323 .42585 .54432 .4356 .54623 .43016 .5439 .22171 Mtetra
.534 .306 .514 r
.5439 .22171 .54623 .43016 .54669 .22188 .54569 .21639 Mtetra
.693 .506 .63 r
.54569 .21639 .54669 .22188 .54847 .21542 .54749 .21367 Mtetra
.745 .692 .801 r
.54749 .21367 .54847 .21542 .55027 .2134 .54931 .21233 Mtetra
.67 .774 .928 r
.54931 .21233 .55027 .2134 .55209 .21268 .55113 .21164 Mtetra
.611 .76 .95 r
.55113 .21164 .55209 .21268 .55392 .21235 .55295 .21118 Mtetra
.709 .766 .897 r
.55295 .21118 .55392 .21235 .55574 .21172 .55477 .21029 Mtetra
.722 .727 .854 r
.55477 .21029 .55574 .21172 .55756 .21088 .55659 .20927 Mtetra
.662 .677 .854 r
.55659 .20927 .55756 .21088 .55938 .21015 .55842 .20857 Mtetra
.409 .555 .889 r
.55842 .20857 .55938 .21015 .56121 .20956 .56026 .20888 Mtetra
.574 .035 0 r
.56026 .20888 .56121 .20956 .56304 .20928 .56211 .21066 Mtetra
.861 .472 .306 r
.56211 .21066 .56304 .20928 .56488 .20966 .56402 .21616 Mtetra
.967 .669 .411 r
.56402 .21616 .56488 .20966 .56677 .21311 .56861 .41956 Mtetra
.531 .298 .507 r
.56861 .41956 .56677 .21311 .5716 .42034 .57065 .42411 Mtetra
.625 .267 .343 r
.57065 .42411 .5716 .42034 .57366 .42634 .57265 .42588 Mtetra
0 .371 .713 r
.57265 .42588 .57366 .42634 .57566 .42782 .57464 .42661 Mtetra
.479 .681 .954 r
.57464 .42661 .57566 .42782 .57764 .42771 .57662 .42656 Mtetra
.708 .787 .913 r
.57662 .42656 .57764 .42771 .5796 .42658 .57858 .42563 Mtetra
.93 .824 .72 r
.57858 .42563 .5796 .42658 .58152 .42289 .58051 .42209 Mtetra
.976 .686 .406 r
.58051 .42209 .58152 .42289 .57984 .21965 .57891 .22007 Mtetra
.991 .745 .453 r
.57891 .22007 .57984 .21965 .5814 .20377 .58045 .20236 Mtetra
.869 .765 .744 r
.58045 .20236 .5814 .20377 .5832 .20109 .58225 .19969 Mtetra
.658 .709 .886 r
.58225 .19969 .5832 .20109 .58504 .20037 .58409 .19904 Mtetra
.517 .658 .924 r
.58409 .19904 .58504 .20037 .5869 .20019 .58595 .19894 Mtetra
.561 .697 .932 r
.58595 .19894 .5869 .20019 .58875 .19987 .5878 .19868 Mtetra
.659 .749 .916 r
.5878 .19868 .58875 .19987 .59059 .19923 .58965 .19803 Mtetra
.675 .753 .909 r
.58965 .19803 .59059 .19923 .59244 .19854 .59149 .1973 Mtetra
.747 .769 .871 r
.59149 .1973 .59244 .19854 .59428 .1975 .59333 .19617 Mtetra
.756 .757 .853 r
.59333 .19617 .59428 .1975 .59612 .19636 .59517 .19494 Mtetra
.663 .708 .882 r
.59517 .19494 .59612 .19636 .59797 .19577 .59702 .19426 Mtetra
0 .289 .789 r
.59702 .19426 .59797 .19577 .59987 .19726 .59892 .19562 Mtetra
.946 .595 .201 r
.59892 .19562 .59987 .19726 .60215 .21316 .60108 .20727 Mtetra
.978 .681 .368 r
.60108 .20727 .60215 .21316 .60926 .41382 .60825 .41248 Mtetra
0 0 .529 r
.60825 .41248 .60926 .41382 .61133 .41594 .61032 .41482 Mtetra
.52 .723 .966 r
.61032 .41482 .61133 .41594 .61333 .41561 .61233 .41462 Mtetra
.739 .83 .921 r
.61233 .41462 .61333 .41561 .61532 .41459 .61432 .41353 Mtetra
.843 .832 .836 r
.61432 .41353 .61532 .41459 .6173 .41353 .61628 .4116 Mtetra
.854 .725 .72 r
.61628 .4116 .6173 .41353 .61929 .41259 .61821 .40852 Mtetra
.839 .626 .615 r
.61821 .40852 .61929 .41259 .62127 .41103 .62005 .40258 Mtetra
.971 .676 .404 r
.62005 .40258 .62127 .41103 .62317 .40705 .6159 .19784 Mtetra
.537 .307 .514 r
.6159 .19784 .62317 .40705 .61875 .19985 .61758 .19112 Mtetra
.651 .446 .592 r
.61758 .19112 .61875 .19985 .62034 .19026 .61938 .18805 Mtetra
.747 .652 .755 r
.61938 .18805 .62034 .19026 .62214 .18752 .62121 .1864 Mtetra
.682 .773 .92 r
.62121 .1864 .62214 .18752 .624 .18665 .62308 .18564 Mtetra
.606 .769 .958 r
.62308 .18564 .624 .18665 .62588 .18626 .62496 .18517 Mtetra
.652 .77 .936 r
.62496 .18517 .62588 .18626 .62775 .18565 .62683 .18454 Mtetra
.714 .786 .909 r
.62683 .18454 .62775 .18565 .62961 .18464 .62869 .18362 Mtetra
.657 .787 .944 r
.62869 .18362 .62961 .18464 .63149 .18407 .63057 .18297 Mtetra
.423 .661 .96 r
.63057 .18297 .63149 .18407 .63342 .18496 .63247 .18305 Mtetra
.079 .297 .78 r
.63247 .18305 .63342 .18496 .63554 .19092 .63442 .18453 Mtetra
.159 .129 .572 r
.63442 .18453 .63554 .19092 .64521 .39882 .63649 .18883 Mtetra
0 0 .373 r
.63649 .18883 .64521 .39882 .64739 .40242 .64608 .39258 Mtetra
.226 .145 .55 r
.64608 .39258 .64739 .40242 .64945 .40283 .64833 .39823 Mtetra
.305 .279 .664 r
.64833 .39823 .64945 .40283 .65149 .40257 .65046 .40031 Mtetra
.329 .435 .818 r
.65046 .40031 .65149 .40257 .65353 .40231 .65254 .4012 Mtetra
.401 .664 .966 r
.65254 .4012 .65353 .40231 .65558 .40222 .6546 .40131 Mtetra
.651 .825 .967 r
.6546 .40131 .65558 .40222 .6576 .40151 .65663 .4006 Mtetra
.896 .86 .797 r
.65663 .4006 .6576 .40151 .65955 .39903 .65858 .3981 Mtetra
.982 .768 .538 r
.65858 .3981 .65955 .39903 .66121 .38957 .66026 .38905 Mtetra
.978 .681 .371 r
.66026 .38905 .66121 .38957 .6542 .17918 .65328 .17795 Mtetra
.936 .789 .674 r
.65328 .17795 .6542 .17918 .65594 .1752 .65502 .17388 Mtetra
.723 .755 .878 r
.65502 .17388 .65594 .1752 .65782 .17417 .6569 .17288 Mtetra
.592 .705 .922 r
.6569 .17288 .65782 .17417 .65972 .17377 .65881 .17249 Mtetra
.592 .71 .926 r
.65881 .17249 .65972 .17377 .66163 .1733 .66071 .17211 Mtetra
.711 .774 .902 r
.66071 .17211 .66163 .1733 .6635 .17226 .6626 .17119 Mtetra
.659 .781 .939 r
.6626 .17119 .6635 .17226 .6654 .17162 .66449 .17052 Mtetra
.465 .685 .961 r
.66449 .17052 .6654 .17162 .66736 .17221 .66642 .17049 Mtetra
.081 .327 .804 r
.66642 .17049 .66736 .17221 .66953 .17711 .66842 .17185 Mtetra
.134 .136 .594 r
.66842 .17185 .66953 .17711 .68167 .38598 .67054 .17566 Mtetra
0 0 .385 r
.67054 .17566 .68167 .38598 .68396 .39042 .68252 .37958 Mtetra
.218 .134 .542 r
.68252 .37958 .68396 .39042 .68607 .39095 .68492 .38609 Mtetra
.306 .272 .656 r
.68492 .38609 .68607 .39095 .68814 .39075 .68711 .38833 Mtetra
.334 .423 .804 r
.68711 .38833 .68814 .39075 .69021 .39042 .68924 .38928 Mtetra
.379 .648 .962 r
.68924 .38928 .69021 .39042 .69229 .39037 .69134 .38946 Mtetra
.633 .822 .973 r
.69134 .38946 .69229 .39037 .69434 .38971 .69339 .3888 Mtetra
.883 .869 .819 r
.69339 .3888 .69434 .38971 .69632 .38752 .69537 .38653 Mtetra
.984 .769 .533 r
.69537 .38653 .69632 .38752 .69794 .37887 .69698 .37761 Mtetra
.977 .677 .356 r
.69698 .37761 .69794 .37887 .68844 .16701 .68751 .16533 Mtetra
.918 .751 .659 r
.68751 .16533 .68844 .16701 .69015 .1626 .68923 .16101 Mtetra
.699 .704 .851 r
.68923 .16101 .69015 .1626 .69204 .16157 .69113 .16006 Mtetra
.57 .659 .897 r
.69113 .16006 .69204 .16157 .69398 .16119 .69307 .15979 Mtetra
.534 .659 .916 r
.69307 .15979 .69398 .16119 .69591 .1609 .69501 .15964 Mtetra
.701 .759 .897 r
.69501 .15964 .69591 .1609 .69781 .15986 .69692 .15875 Mtetra
.661 .776 .934 r
.69692 .15875 .69781 .15986 .69973 .15918 .69884 .15807 Mtetra
.508 .705 .959 r
.69884 .15807 .69973 .15918 .70171 .15952 .70079 .15792 Mtetra
.102 .362 .827 r
.70079 .15792 .70171 .15952 .70393 .16381 .70283 .15915 Mtetra
.133 .153 .615 r
.70283 .15915 .70393 .16381 .71858 .37305 .70501 .16262 Mtetra
0 0 .397 r
.70501 .16262 .71858 .37305 .72101 .37835 .71943 .36681 Mtetra
.194 .116 .534 r
.71943 .36681 .72101 .37835 .72317 .37905 .722 .37431 Mtetra
.285 .263 .659 r
.722 .37431 .72317 .37905 .72528 .37894 .72427 .37671 Mtetra
.341 .448 .825 r
.72427 .37671 .72528 .37894 .72737 .37848 .72644 .37755 Mtetra
.537 .779 .987 r
.72644 .37755 .72737 .37848 .72948 .37819 .72854 .3772 Mtetra
.707 .835 .943 r
.72854 .3772 .72948 .37819 .73155 .37738 .73061 .37624 Mtetra
.811 .831 .866 r
.73061 .37624 .73155 .37738 .73355 .37553 .73263 .3746 Mtetra
.915 .865 .776 r
.73263 .3746 .73355 .37553 .7353 .36982 .73457 .37182 Mtetra
0 0 0 r
.73457 .37182 .7353 .36982 .7234 .15905 .73638 .36693 Mtetra
0 0 .392 r
.73638 .36693 .7234 .15905 .72491 .15202 .72482 .16256 Mtetra
0 0 .312 r
.72482 .16256 .72491 .15202 .72676 .15001 .7261 .15207 Mtetra
0 0 0 r
.7261 .15207 .72676 .15001 .72866 .14877 .72784 .14844 Mtetra
.895 .967 .825 r
.72784 .14844 .72866 .14877 .73059 .14793 .72969 .14634 Mtetra
.673 .696 .863 r
.72969 .14634 .73059 .14793 .73253 .14723 .73162 .14554 Mtetra
.606 .651 .868 r
.73162 .14554 .73253 .14723 .73448 .14665 .73358 .14511 Mtetra
.593 .666 .89 r
.73358 .14511 .73448 .14665 .73643 .14605 .73555 .14473 Mtetra
.733 .765 .878 r
.73555 .14473 .73643 .14605 .73835 .14489 .73747 .14364 Mtetra
.703 .767 .901 r
.73747 .14364 .73835 .14489 .74028 .14407 .7394 .14274 Mtetra
.601 .71 .92 r
.7394 .14274 .74028 .14407 .74228 .144 .74137 .14231 Mtetra
.202 .413 .845 r
.74137 .14231 .74228 .144 .74452 .14734 .74345 .14336 Mtetra
.147 .188 .648 r
.74345 .14336 .74452 .14734 .76211 .35616 .74567 .14632 Mtetra
.004 0 .41 r
.74567 .14632 .76211 .35616 .76484 .36386 .76291 .34925 Mtetra
.169 .088 .515 r
.76291 .34925 .76484 .36386 .76707 .3648 .76584 .35962 Mtetra
.279 .249 .645 r
.76584 .35962 .76707 .3648 .76923 .36482 .76821 .36235 Mtetra
.31 .405 .798 r
.76821 .36235 .76923 .36482 .77136 .36442 .77046 .36347 Mtetra
.377 .694 .982 r
.77046 .36347 .77136 .36442 .77352 .36435 .77263 .36354 Mtetra
.579 .831 .993 r
.77263 .36354 .77352 .36435 .77564 .36377 .77475 .363 Mtetra
.75 .897 .944 r
.77475 .363 .77564 .36377 .7777 .36238 .77683 .36179 Mtetra
.942 .918 .761 r
.77683 .36179 .7777 .36238 .77947 .35738 .77877 .35884 Mtetra
.778 .815 .336 r
.77877 .35884 .77947 .35738 .76469 .14741 .78054 .35391 Mtetra
.492 .269 .504 r
.78054 .35391 .76469 .14741 .76591 .13745 .78132 .33672 Mtetra
.025 0 .411 r
.78132 .33672 .76591 .13745 .7678 .13587 .76791 .14648 Mtetra
.485 .218 .433 r
.76791 .14648 .7678 .13587 .76977 .13519 .76989 .14577 Mtetra
.631 .331 .443 r
.76989 .14577 .76977 .13519 .77178 .13497 .77226 .14986 Mtetra
.52 .289 .505 r
.11474 .57074 .13935 .37759 .14157 .37157 .11643 .56995 Mtetra
.521 .29 .505 r
.11643 .56995 .14157 .37157 .14325 .37008 .11811 .56926 Mtetra
.11811 .56926 .14325 .37008 .14436 .37337 .11976 .56879 Mtetra
.523 .292 .506 r
.11976 .56879 .14436 .37337 .12313 .56506 .12132 .56911 Mtetra
.518 .185 .343 r
.12132 .56911 .12313 .56506 .12426 .56901 .12288 .56939 Mtetra
.236 0 0 r
.12288 .56939 .12426 .56901 .12566 .57072 .12447 .56946 Mtetra
.668 .718 .886 r
.12447 .56946 .12566 .57072 .1273 .57033 .12615 .56882 Mtetra
.697 .689 .839 r
.12615 .56882 .1273 .57033 .12901 .5694 .12785 .56796 Mtetra
.715 .704 .839 r
.12785 .56796 .12901 .5694 .13076 .56817 .12957 .567 Mtetra
.701 .742 .883 r
.12957 .567 .13076 .56817 .13246 .56732 .13127 .5662 Mtetra
.69 .748 .896 r
.13127 .5662 .13246 .56732 .13416 .56655 .13296 .56546 Mtetra
.674 .751 .908 r
.13296 .56546 .13416 .56655 .13585 .56585 .13464 .5648 Mtetra
.635 .748 .93 r
.13464 .5648 .13585 .56585 .13752 .56528 .13631 .56431 Mtetra
.608 .756 .949 r
.13631 .56431 .13752 .56528 .13918 .5648 .13797 .5639 Mtetra
.588 .766 .964 r
.13797 .5639 .13918 .5648 .14084 .56439 .13962 .56353 Mtetra
.317 .664 .974 r
.13962 .56353 .14084 .56439 .14246 .56436 .14122 .56367 Mtetra
.48 .778 .997 r
.14122 .56367 .14246 .56436 .1441 .56414 .14285 .56348 Mtetra
.733 .846 .933 r
.14285 .56348 .1441 .56414 .14579 .56347 .14457 .56256 Mtetra
.904 .756 .687 r
.14457 .56256 .14579 .56347 .14765 .56128 .14669 .5581 Mtetra
.937 .684 .53 r
.14669 .5581 .14765 .56128 .14973 .55709 .1706 .35796 Mtetra
.544 .314 .517 r
.1706 .35796 .14973 .55709 .1726 .36478 .17307 .3494 Mtetra
.587 .377 .564 r
.17307 .3494 .1726 .36478 .17553 .35207 .17483 .34726 Mtetra
.628 .471 .65 r
.17483 .34726 .17553 .35207 .17745 .34845 .17647 .34611 Mtetra
.648 .576 .76 r
.17647 .34611 .17745 .34845 .1792 .34631 .17807 .3454 Mtetra
.654 .77 .934 r
.17807 .3454 .1792 .34631 .18081 .34549 .17965 .34486 Mtetra
.589 .817 .986 r
.17965 .34486 .18081 .34549 .18237 .34517 .18122 .34445 Mtetra
.571 .794 .983 r
.18122 .34445 .18237 .34517 .18391 .34505 .18278 .34411 Mtetra
.646 .763 .934 r
.18278 .34411 .18391 .34505 .18548 .34463 .18436 .3436 Mtetra
.664 .749 .913 r
.18436 .3436 .18548 .34463 .18706 .34409 .18595 .34302 Mtetra
.67 .743 .905 r
.18595 .34302 .18706 .34409 .18866 .34349 .18755 .34242 Mtetra
.737 .757 .868 r
.18755 .34242 .18866 .34349 .19028 .34257 .18918 .34145 Mtetra
.703 .741 .881 r
.18918 .34145 .19028 .34257 .1919 .34176 .19079 .34068 Mtetra
.558 .706 .939 r
.19079 .34068 .1919 .34176 .19348 .3413 .19235 .34046 Mtetra
.895 .476 .164 r
.19235 .34046 .19348 .3413 .19487 .34264 .19355 .34366 Mtetra
.94 .681 .516 r
.19355 .34366 .19487 .34264 .19603 .34624 .17416 .54448 Mtetra
.536 .303 .509 r
.17416 .54448 .19603 .34624 .17811 .53464 .17511 .55116 Mtetra
.413 .169 .431 r
.17511 .55116 .17811 .53464 .1988 .34927 .17707 .54802 Mtetra
0 0 .087 r
.17707 .54802 .1988 .34927 .20106 .34227 .19944 .34622 Mtetra
.955 .872 .466 r
.19944 .34622 .20106 .34227 .20296 .33878 .20181 .33811 Mtetra
.858 .821 .811 r
.20181 .33811 .20296 .33878 .20465 .33724 .20355 .33619 Mtetra
.695 .752 .896 r
.20355 .33619 .20465 .33724 .20627 .33649 .20516 .33547 Mtetra
.565 .722 .947 r
.20516 .33547 .20627 .33649 .20784 .33626 .20673 .33521 Mtetra
.619 .734 .928 r
.20673 .33521 .20784 .33626 .20931 .33696 .20832 .33479 Mtetra
.569 .55 .793 r
.20832 .33479 .20931 .33696 .21065 .33904 .20988 .3346 Mtetra
.478 .375 .66 r
.20988 .3346 .21065 .33904 .21145 .34658 .21138 .33511 Mtetra
.277 .145 .515 r
.21138 .33511 .21145 .34658 .19375 .54227 .21249 .33958 Mtetra
0 0 .123 r
.21249 .33958 .19375 .54227 .19503 .54601 .19421 .54128 Mtetra
0 0 .313 r
.19421 .54128 .19503 .54601 .19653 .54759 .19539 .54612 Mtetra
0 .241 .753 r
.19539 .54612 .19653 .54759 .19813 .54825 .19694 .54729 Mtetra
.508 .727 .972 r
.19694 .54729 .19813 .54825 .19979 .54817 .19861 .54713 Mtetra
.757 .779 .872 r
.19861 .54713 .19979 .54817 .20154 .54724 .20038 .54599 Mtetra
.885 .741 .697 r
.20038 .54599 .20154 .54724 .20357 .54348 .20242 .54203 Mtetra
.945 .688 .517 r
.20242 .54203 .20357 .54348 .22414 .34429 .22326 .3409 Mtetra
.885 .659 .592 r
.22326 .3409 .22414 .34429 .22699 .33071 .2259 .32955 Mtetra
.839 .752 .767 r
.2259 .32955 .22699 .33071 .22876 .32845 .22767 .32736 Mtetra
.681 .744 .899 r
.22767 .32736 .22876 .32845 .23039 .32778 .22929 .32669 Mtetra
.545 .703 .943 r
.22929 .32669 .23039 .32778 .23197 .32758 .23087 .3265 Mtetra
.704 .752 .889 r
.23087 .3265 .23197 .32758 .2336 .3268 .23251 .32572 Mtetra
.72 .756 .881 r
.23251 .32572 .2336 .3268 .23525 .32593 .23415 .32486 Mtetra
.575 .717 .939 r
.23415 .32486 .23525 .32593 .23684 .32564 .23574 .32458 Mtetra
.817 .351 0 r
.23574 .32458 .23684 .32564 .23818 .32808 .23709 .32703 Mtetra
.948 .684 .504 r
.23709 .32703 .23818 .32808 .22153 .52944 .22035 .52852 Mtetra
.945 .619 .382 r
.22035 .52852 .22153 .52944 .22239 .53839 .22122 .53738 Mtetra
.587 .064 0 r
.22122 .53738 .22239 .53839 .22393 .54001 .22275 .53898 Mtetra
.521 .721 .964 r
.22275 .53898 .22393 .54001 .22562 .53983 .22445 .53881 Mtetra
.766 .785 .869 r
.22445 .53881 .22562 .53983 .22741 .53863 .22624 .5376 Mtetra
.894 .764 .71 r
.22624 .5376 .22741 .53863 .22942 .53493 .22825 .5339 Mtetra
.948 .689 .512 r
.22825 .5339 .22942 .53493 .24835 .33783 .24724 .33688 Mtetra
.941 .713 .564 r
.24724 .33688 .24835 .33783 .25129 .32227 .2502 .32119 Mtetra
.858 .763 .757 r
.2502 .32119 .25129 .32227 .25308 .31982 .25199 .31875 Mtetra
.675 .748 .906 r
.25199 .31875 .25308 .31982 .25471 .31917 .25363 .31811 Mtetra
.512 .695 .951 r
.25363 .31811 .25471 .31917 .25631 .31904 .25522 .31799 Mtetra
.593 .729 .938 r
.25522 .31799 .25631 .31904 .25793 .31858 .25683 .31765 Mtetra
.665 .775 .931 r
.25683 .31765 .25793 .31858 .25957 .31788 .25847 .31705 Mtetra
.637 .79 .955 r
.25847 .31705 .25957 .31788 .26119 .31748 .26009 .31654 Mtetra
.517 .724 .967 r
.26009 .31654 .26119 .31748 .26271 .31825 .26169 .31638 Mtetra
.479 .537 .839 r
.26169 .31638 .26271 .31825 .26407 .32107 .26327 .31653 Mtetra
.511 .398 .661 r
.26327 .31653 .26407 .32107 .26415 .33939 .26484 .31677 Mtetra
.53 .322 .541 r
.26484 .31677 .26415 .33939 .2509 .52053 .26644 .3166 Mtetra
.525 .298 .513 r
.26644 .3166 .2509 .52053 .25263 .52021 .26809 .31592 Mtetra
.26809 .31592 .25263 .52021 .2545 .51803 .26975 .3151 Mtetra
.26975 .3151 .2545 .51803 .25624 .51743 .2714 .31444 Mtetra
.524 .298 .513 r
.2714 .31444 .25624 .51743 .2579 .51795 .27304 .31391 Mtetra
.525 .298 .513 r
.27304 .31391 .2579 .51795 .25975 .51614 .2747 .31321 Mtetra
.526 .299 .513 r
.2747 .31321 .25975 .51614 .27679 .3217 .27639 .31196 Mtetra
.595 .4 .588 r
.27639 .31196 .27679 .3217 .27901 .31387 .27812 .31042 Mtetra
.675 .538 .69 r
.27812 .31042 .27901 .31387 .28088 .31042 .27983 .30903 Mtetra
.723 .711 .838 r
.27983 .30903 .28088 .31042 .28261 .30872 .28151 .30804 Mtetra
.67 .836 .963 r
.28151 .30804 .28261 .30872 .28427 .308 .28316 .3074 Mtetra
.624 .842 .983 r
.28316 .3074 .28427 .308 .28591 .30759 .2848 .30687 Mtetra
.629 .815 .972 r
.2848 .30687 .28591 .30759 .28754 .30724 .28645 .30635 Mtetra
.646 .783 .947 r
.28645 .30635 .28754 .30724 .28918 .30683 .2881 .30582 Mtetra
.651 .756 .927 r
.2881 .30582 .28918 .30683 .29082 .3064 .28975 .30527 Mtetra
.71 .749 .882 r
.28975 .30527 .29082 .3064 .29248 .30567 .29142 .30443 Mtetra
.727 .736 .858 r
.29142 .30443 .29248 .30567 .29416 .30472 .2931 .30347 Mtetra
.646 .71 .894 r
.2931 .30347 .29416 .30472 .29582 .30403 .29475 .30294 Mtetra
0 .228 .721 r
.29475 .30294 .29582 .30403 .29742 .30433 .29629 .30402 Mtetra
.926 .574 .344 r
.29629 .30402 .29742 .30433 .29888 .30639 .29743 .31049 Mtetra
.947 .678 .493 r
.29743 .31049 .29888 .30639 .3001 .3119 .28444 .51319 Mtetra
.528 .296 .507 r
.28444 .51319 .3001 .3119 .28812 .50296 .28597 .516 Mtetra
.501 .237 .447 r
.28597 .516 .28812 .50296 .28999 .50089 .28773 .51564 Mtetra
.485 .228 .449 r
.28773 .51564 .28999 .50089 .29195 .4975 .28952 .51471 Mtetra
.503 .249 .461 r
.28952 .51471 .29195 .4975 .29299 .50739 .29129 .51424 Mtetra
.523 .226 .404 r
.29129 .51424 .29299 .50739 .29433 .51297 .293 .51456 Mtetra
.469 .026 .112 r
.293 .51456 .29433 .51297 .2959 .51541 .29472 .51479 Mtetra
.368 .748 .989 r
.29472 .51479 .2959 .51541 .29758 .51625 .29647 .51473 Mtetra
.608 .667 .882 r
.29647 .51473 .29758 .51625 .29934 .51602 .29824 .51433 Mtetra
.633 .653 .852 r
.29824 .51433 .29934 .51602 .30112 .51546 .30001 .51379 Mtetra
.614 .65 .862 r
.30001 .51379 .30112 .51546 .3029 .51485 .30179 .51336 Mtetra
.594 .666 .89 r
.30179 .51336 .3029 .51485 .30468 .51431 .30355 .51301 Mtetra
.689 .733 .884 r
.30355 .51301 .30468 .51431 .30649 .51346 .30535 .51222 Mtetra
.839 .764 .779 r
.30535 .51222 .30649 .51346 .30834 .5118 .30725 .50999 Mtetra
.905 .711 .63 r
.30725 .50999 .30834 .5118 .3103 .50851 .30943 .50329 Mtetra
.951 .685 .495 r
.30943 .50329 .3103 .50851 .31242 .50271 .32436 .2982 Mtetra
.534 .305 .515 r
.32436 .2982 .31242 .50271 .31508 .4883 .32629 .29359 Mtetra
.525 .299 .513 r
.32629 .29359 .31508 .4883 .31676 .48932 .32799 .29269 Mtetra
.524 .297 .513 r
.32799 .29269 .31676 .48932 .31835 .49176 .32965 .2924 Mtetra
.525 .298 .513 r
.32965 .2924 .31835 .49176 .33179 .30259 .33133 .2918 Mtetra
.585 .388 .58 r
.33133 .2918 .33179 .30259 .33395 .29425 .33306 .29035 Mtetra
.659 .514 .676 r
.33306 .29035 .33395 .29425 .33581 .29066 .33479 .28901 Mtetra
.712 .676 .813 r
.33479 .28901 .33581 .29066 .33757 .28877 .3365 .28799 Mtetra
.65 .814 .962 r
.3365 .28799 .33757 .28877 .33926 .28814 .33818 .28741 Mtetra
.609 .812 .978 r
.33818 .28741 .33926 .28814 .34092 .28785 .33986 .28694 Mtetra
.627 .779 .954 r
.33986 .28694 .34092 .28785 .34259 .28756 .34153 .28645 Mtetra
.666 .747 .91 r
.34153 .28645 .34259 .28756 .34427 .28699 .34322 .28583 Mtetra
.672 .739 .9 r
.34322 .28583 .34427 .28699 .34596 .28635 .34491 .28517 Mtetra
.704 .744 .882 r
.34491 .28517 .34596 .28635 .34766 .28556 .34662 .28435 Mtetra
.739 .749 .86 r
.34662 .28435 .34766 .28556 .34937 .28455 .34833 .28331 Mtetra
.67 .724 .89 r
.34833 .28331 .34937 .28455 .35107 .28379 .35002 .28266 Mtetra
.211 .527 .92 r
.35002 .28266 .35107 .28379 .35273 .28375 .35165 .28315 Mtetra
.91 .509 .213 r
.35165 .28315 .35273 .28375 .3543 .28541 .35307 .28761 Mtetra
.955 .68 .476 r
.35307 .28761 .3543 .28541 .35575 .28937 .34355 .49197 Mtetra
.531 .298 .507 r
.34355 .49197 .35575 .28937 .34725 .47823 .34508 .49653 Mtetra
.512 .257 .466 r
.34508 .49653 .34725 .47823 .34913 .47623 .34687 .49634 Mtetra
.497 .247 .466 r
.34687 .49634 .34913 .47623 .3601 .30168 .3487 .49546 Mtetra
.521 .29 .505 r
.3487 .49546 .3601 .30168 .35224 .48443 .35052 .49473 Mtetra
.524 .248 .438 r
.35052 .49473 .35224 .48443 .35359 .49271 .35229 .49508 Mtetra
.497 .102 .221 r
.35229 .49508 .35359 .49271 .35522 .49565 .35406 .49536 Mtetra
.167 .686 .885 r
.35406 .49536 .35522 .49565 .35695 .49679 .35585 .49535 Mtetra
.621 .69 .894 r
.35585 .49535 .35695 .49679 .35876 .49646 .35766 .49488 Mtetra
.646 .678 .866 r
.35766 .49488 .35876 .49646 .36058 .49577 .35948 .49428 Mtetra
.635 .687 .881 r
.35948 .49428 .36058 .49577 .36241 .49504 .3613 .49374 Mtetra
.544 .682 .929 r
.3613 .49374 .36241 .49504 .36422 .49471 .36311 .49354 Mtetra
.647 .748 .923 r
.36311 .49354 .36422 .49471 .36605 .49412 .36493 .49296 Mtetra
.802 .781 .834 r
.36493 .49296 .36605 .49412 .3679 .49295 .36681 .49135 Mtetra
.903 .729 .656 r
.36681 .49135 .3679 .49295 .36982 .49035 .36885 .48613 Mtetra
.958 .686 .479 r
.36885 .48613 .36982 .49035 .37183 .48575 .38022 .28086 Mtetra
.54 .31 .516 r
.38022 .28086 .37183 .48575 .38271 .28712 .38225 .27339 Mtetra
.586 .379 .567 r
.38225 .27339 .38271 .28712 .38492 .27579 .38403 .27142 Mtetra
.636 .488 .665 r
.38403 .27142 .38492 .27579 .38676 .27224 .38577 .27024 Mtetra
.667 .622 .795 r
.38577 .27024 .38676 .27224 .38854 .27023 .38749 .26944 Mtetra
.678 .823 .953 r
.38749 .26944 .38854 .27023 .39027 .26937 .38921 .26876 Mtetra
.62 .848 .986 r
.38921 .26876 .39027 .26937 .39198 .26887 .39092 .26821 Mtetra
.602 .831 .987 r
.39092 .26821 .39198 .26887 .39368 .26854 .39264 .26772 Mtetra
.635 .803 .964 r
.39264 .26772 .39368 .26854 .3954 .26811 .39435 .26718 Mtetra
.644 .782 .947 r
.39435 .26718 .3954 .26811 .39711 .26767 .39607 .26662 Mtetra
.658 .761 .926 r
.39607 .26662 .39711 .26767 .39883 .26715 .39779 .26602 Mtetra
.684 .753 .904 r
.39779 .26602 .39883 .26715 .40055 .26638 .39952 .2653 Mtetra
.69 .764 .908 r
.39952 .2653 .40055 .26638 .40228 .26557 .40125 .26456 Mtetra
.69 .778 .918 r
.40125 .26456 .40228 .26557 .40402 .26477 .40298 .26382 Mtetra
.679 .788 .932 r
.40298 .26382 .40402 .26477 .40574 .26409 .40471 .26313 Mtetra
.674 .784 .932 r
.40471 .26313 .40574 .26409 .40747 .26345 .40644 .26246 Mtetra
.679 .78 .926 r
.40644 .26246 .40747 .26345 .4092 .26279 .40817 .26176 Mtetra
.74 .787 .89 r
.40817 .26176 .4092 .26279 .41094 .26192 .40991 .26076 Mtetra
.672 .744 .905 r
.40991 .26076 .41094 .26192 .41267 .26126 .41165 .26009 Mtetra
.445 .649 .946 r
.41165 .26009 .41267 .26126 .41439 .26105 .41335 .26016 Mtetra
.863 .419 .03 r
.41335 .26016 .41439 .26105 .41604 .26252 .41494 .26365 Mtetra
.962 .681 .455 r
.41494 .26365 .41604 .26252 .41764 .26598 .40949 .468 Mtetra
.536 .302 .508 r
.40949 .468 .41764 .26598 .41273 .45985 .41107 .47508 Mtetra
.52 .258 .459 r
.41107 .47508 .41273 .45985 .41439 .4647 .4129 .47527 Mtetra
.479 .21 .427 r
.4129 .47527 .41439 .4647 .41627 .46322 .41477 .47453 Mtetra
.464 .2 .428 r
.41477 .47453 .41627 .46322 .41829 .45755 .41664 .47334 Mtetra
.498 .241 .456 r
.41664 .47334 .41829 .45755 .42014 .4569 .4185 .47275 Mtetra
.4185 .47275 .42014 .4569 .422 .45612 .42037 .47214 Mtetra
.498 .242 .456 r
.42037 .47214 .422 .45612 .42386 .45521 .42223 .47153 Mtetra
.499 .243 .457 r
.42223 .47153 .42386 .45521 .42573 .45399 .42409 .47092 Mtetra
.5 .245 .459 r
.42409 .47092 .42573 .45399 .42761 .45269 .42596 .4703 Mtetra
.5 .247 .461 r
.42596 .4703 .42761 .45269 .42948 .45135 .42783 .46968 Mtetra
.498 .245 .462 r
.42783 .46968 .42948 .45135 .43654 .26879 .4297 .46891 Mtetra
.521 .29 .505 r
.4297 .46891 .43654 .26879 .43833 .2669 .43157 .46825 Mtetra
.43157 .46825 .43833 .2669 .43503 .45041 .43343 .46783 Mtetra
.523 .265 .465 r
.43343 .46783 .43503 .45041 .43649 .46475 .43528 .46815 Mtetra
.509 .151 .295 r
.43528 .46815 .43649 .46475 .43825 .46824 .43713 .46844 Mtetra
.16 0 0 r
.43713 .46844 .43825 .46824 .44007 .46986 .43899 .46853 Mtetra
.501 .662 .933 r
.43899 .46853 .44007 .46986 .44193 .4699 .44085 .46847 Mtetra
.631 .701 .896 r
.44085 .46847 .44193 .4699 .44381 .4693 .44273 .46794 Mtetra
.751 .75 .851 r
.44273 .46794 .44381 .4693 .4457 .46811 .44462 .46669 Mtetra
.911 .752 .672 r
.44462 .46669 .4457 .46811 .44763 .46537 .4466 .4621 Mtetra
.965 .687 .456 r
.4466 .4621 .44763 .46537 .4496 .46082 .45321 .25825 Mtetra
.547 .316 .516 r
.45321 .25825 .4496 .46082 .45176 .44757 .45521 .24727 Mtetra
.527 .3 .513 r
.45521 .24727 .45176 .44757 .45741 .27367 .45699 .24577 Mtetra
.534 .321 .537 r
.45699 .24577 .45741 .27367 .45557 .44384 .45875 .24525 Mtetra
.524 .297 .513 r
.45875 .24525 .45557 .44384 .45751 .43993 .4605 .24504 Mtetra
.526 .299 .514 r
.4605 .24504 .45751 .43993 .4632 .24926 .46228 .24366 Mtetra
.63 .461 .636 r
.46228 .24366 .4632 .24926 .46504 .24466 .46407 .24223 Mtetra
.701 .607 .748 r
.46407 .24223 .46504 .24466 .46685 .24197 .46584 .24096 Mtetra
.687 .784 .924 r
.46584 .24096 .46685 .24197 .46862 .24102 .46761 .24022 Mtetra
.637 .815 .968 r
.46761 .24022 .46862 .24102 .47039 .24056 .46938 .23965 Mtetra
.626 .787 .959 r
.46938 .23965 .47039 .24056 .47215 .24027 .47115 .23913 Mtetra
.743 .772 .877 r
.47115 .23913 .47215 .24027 .47392 .23932 .47293 .23807 Mtetra
.706 .743 .88 r
.47293 .23807 .47392 .23932 .4757 .23842 .4747 .2372 Mtetra
.583 .704 .926 r
.4747 .2372 .4757 .23842 .47747 .23787 .47647 .23688 Mtetra
.664 .171 0 r
.47647 .23688 .47747 .23787 .47922 .23857 .4782 .23915 Mtetra
.951 .634 .396 r
.4782 .23915 .47922 .23857 .48096 .24074 .47966 .25971 Mtetra
.944 .654 .458 r
.47966 .25971 .48096 .24074 .48261 .24919 .47873 .45203 Mtetra
.525 .294 .506 r
.47873 .45203 .48261 .24919 .48174 .4498 .48061 .45371 Mtetra
.505 .161 .317 r
.48061 .45371 .48174 .4498 .48359 .45341 .4825 .45394 Mtetra
.053 0 0 r
.4825 .45394 .48359 .45341 .48547 .45484 .4844 .45361 Mtetra
.629 .738 .927 r
.4844 .45361 .48547 .45484 .48737 .45464 .48631 .45307 Mtetra
.658 .692 .871 r
.48631 .45307 .48737 .45464 .48928 .45385 .48822 .45238 Mtetra
.673 .713 .879 r
.48822 .45238 .48928 .45385 .4912 .45283 .49013 .45161 Mtetra
.493 .684 .951 r
.49013 .45161 .4912 .45283 .4931 .45275 .49204 .45153 Mtetra
.556 .712 .944 r
.49204 .45153 .4931 .45275 .49501 .45255 .49395 .45126 Mtetra
.717 .758 .885 r
.49395 .45126 .49501 .45255 .49693 .45161 .49587 .45027 Mtetra
.922 .763 .667 r
.49587 .45027 .49693 .45161 .49888 .44682 .49782 .44556 Mtetra
.971 .689 .436 r
.49782 .44556 .49888 .44682 .50234 .23696 .50134 .23645 Mtetra
.976 .773 .566 r
.50134 .23645 .50234 .23696 .50418 .22904 .50319 .2282 Mtetra
.853 .843 .834 r
.50319 .2282 .50418 .22904 .50598 .22729 .50499 .22637 Mtetra
.636 .792 .957 r
.50499 .22637 .50598 .22729 .50777 .22682 .50678 .22582 Mtetra
.483 .709 .97 r
.50678 .22582 .50777 .22682 .50956 .22683 .50857 .22572 Mtetra
.617 .743 .936 r
.50857 .22572 .50956 .22683 .51135 .22644 .51037 .22525 Mtetra
.664 .744 .91 r
.51037 .22525 .51135 .22644 .51315 .22583 .51217 .2246 Mtetra
.671 .738 .901 r
.51217 .2246 .51315 .22583 .51495 .22515 .51396 .22391 Mtetra
.743 .76 .866 r
.51396 .22391 .51495 .22515 .51674 .2241 .51576 .22281 Mtetra
.721 .745 .871 r
.51576 .22281 .51674 .2241 .51854 .2231 .51756 .22183 Mtetra
.615 .712 .915 r
.51756 .22183 .51854 .2231 .52034 .22243 .51936 .22139 Mtetra
0 .001 .512 r
.51936 .22139 .52034 .22243 .52214 .22292 .52116 .22323 Mtetra
.937 .587 .332 r
.52116 .22323 .52214 .22292 .52395 .22489 .52296 .23404 Mtetra
.961 .668 .43 r
.52296 .23404 .52395 .22489 .52575 .23153 .52477 .4366 Mtetra
.526 .294 .506 r
.52477 .4366 .52575 .23153 .52774 .4336 .5267 .43868 Mtetra
.51 .188 .357 r
.5267 .43868 .52774 .4336 .52968 .43763 .52864 .4389 Mtetra
.27 0 0 r
.52864 .4389 .52968 .43763 .53162 .43924 .53058 .43856 Mtetra
.396 .755 .993 r
.53058 .43856 .53162 .43924 .53357 .4397 .53252 .43845 Mtetra
.564 .711 .941 r
.53252 .43845 .53357 .4397 .53551 .43945 .53447 .43815 Mtetra
.707 .757 .891 r
.53447 .43815 .53551 .43945 .53745 .4386 .53641 .43721 Mtetra
.889 .773 .728 r
.53641 .43721 .53745 .4386 .53939 .43667 .53834 .43398 Mtetra
.927 .695 .566 r
.53834 .43398 .53939 .43667 .54132 .43325 .54024 .42374 Mtetra
.966 .678 .434 r
.54024 .42374 .54132 .43325 .54323 .42585 .54109 .21769 Mtetra
.53 .302 .514 r
.54109 .21769 .54323 .42585 .5439 .22171 .54289 .21432 Mtetra
.606 .424 .609 r
.54289 .21432 .5439 .22171 .54569 .21639 .54471 .21288 Mtetra
.63 .514 .702 r
.54471 .21288 .54569 .21639 .54749 .21367 .54652 .21199 Mtetra
.667 .668 .842 r
.54652 .21199 .54749 .21367 .54931 .21233 .54834 .21125 Mtetra
.665 .77 .928 r
.54834 .21125 .54931 .21233 .55113 .21164 .55016 .21058 Mtetra
.648 .768 .936 r
.55016 .21058 .55113 .21164 .55295 .21118 .55199 .20998 Mtetra
.727 .768 .885 r
.55199 .20998 .55295 .21118 .55477 .21029 .55381 .20899 Mtetra
.726 .749 .871 r
.55381 .20899 .55477 .21029 .55659 .20927 .55563 .20798 Mtetra
.631 .717 .909 r
.55563 .20798 .55659 .20927 .55842 .20857 .55746 .20746 Mtetra
0 .189 .696 r
.55746 .20746 .55842 .20857 .56026 .20888 .55931 .20889 Mtetra
.925 .546 .26 r
.55931 .20889 .56026 .20888 .56211 .21066 .56124 .21658 Mtetra
.967 .67 .41 r
.56124 .21658 .56211 .21066 .56402 .21616 .56567 .42264 Mtetra
.527 .295 .506 r
.56567 .42264 .56402 .21616 .56861 .41956 .56768 .42531 Mtetra
.518 .204 .375 r
.56768 .42531 .56861 .41956 .57065 .42411 .56966 .42563 Mtetra
.326 0 .003 r
.56966 .42563 .57065 .42411 .57265 .42588 .57163 .42534 Mtetra
.333 .753 .976 r
.57163 .42534 .57265 .42588 .57464 .42661 .57361 .42525 Mtetra
.534 .679 .931 r
.57361 .42525 .57464 .42661 .57662 .42656 .57559 .42507 Mtetra
.691 .723 .874 r
.57559 .42507 .57662 .42656 .57858 .42563 .57756 .42418 Mtetra
.896 .77 .716 r
.57756 .42418 .57858 .42563 .58051 .42209 .57948 .42072 Mtetra
.975 .686 .407 r
.57948 .42072 .58051 .42209 .57891 .22007 .57805 .22448 Mtetra
.981 .756 .346 r
.57805 .22448 .57891 .22007 .58045 .20236 .5795 .20149 Mtetra
.912 .837 .758 r
.5795 .20149 .58045 .20236 .58225 .19969 .5813 .19874 Mtetra
.679 .806 .943 r
.5813 .19874 .58225 .19969 .58409 .19904 .58314 .198 Mtetra
.523 .725 .965 r
.58314 .198 .58409 .19904 .58595 .19894 .585 .1978 Mtetra
.581 .727 .943 r
.585 .1978 .58595 .19894 .5878 .19868 .58685 .19745 Mtetra
.668 .744 .907 r
.58685 .19745 .5878 .19868 .58965 .19803 .5887 .19676 Mtetra
.676 .74 .899 r
.5887 .19676 .58965 .19803 .59149 .1973 .59054 .19602 Mtetra
.737 .759 .87 r
.59054 .19602 .59149 .1973 .59333 .19617 .59238 .19494 Mtetra
.75 .772 .871 r
.59238 .19494 .59333 .19617 .59517 .19494 .59422 .19379 Mtetra
.649 .754 .926 r
.59422 .19379 .59517 .19494 .59702 .19426 .59607 .19318 Mtetra
0 .196 .699 r
.59607 .19318 .59702 .19426 .59892 .19562 .59798 .19463 Mtetra
.954 .607 .26 r
.59798 .19463 .59892 .19562 .60108 .20727 .60018 .208 Mtetra
.974 .674 .384 r
.60018 .208 .60108 .20727 .60825 .41248 .60724 .41132 Mtetra
0 0 .471 r
.60724 .41132 .60825 .41248 .61032 .41482 .60931 .41368 Mtetra
.487 .702 .964 r
.60931 .41368 .61032 .41482 .61233 .41462 .61133 .41358 Mtetra
.747 .823 .911 r
.61133 .41358 .61233 .41462 .61432 .41353 .61331 .41244 Mtetra
.901 .822 .76 r
.61331 .41244 .61432 .41353 .61628 .4116 .61525 .40956 Mtetra
.94 .724 .583 r
.61525 .40956 .61628 .4116 .61821 .40852 .61704 .40165 Mtetra
.973 .678 .401 r
.61704 .40165 .61821 .40852 .62005 .40258 .61296 .19282 Mtetra
.532 .304 .514 r
.61296 .19282 .62005 .40258 .6159 .19784 .61472 .18848 Mtetra
.594 .401 .59 r
.61472 .18848 .6159 .19784 .61758 .19112 .61656 .18692 Mtetra
.619 .485 .676 r
.61656 .18692 .61758 .19112 .61938 .18805 .61841 .18597 Mtetra
.647 .617 .806 r
.61841 .18597 .61938 .18805 .62121 .1864 .62028 .18527 Mtetra
.655 .763 .929 r
.62028 .18527 .62121 .1864 .62308 .18564 .62215 .18463 Mtetra
.63 .779 .953 r
.62215 .18463 .62308 .18564 .62496 .18517 .62403 .18407 Mtetra
.659 .772 .933 r
.62403 .18407 .62496 .18517 .62683 .18454 .6259 .18341 Mtetra
.693 .778 .917 r
.6259 .18341 .62683 .18454 .62869 .18362 .62777 .1826 Mtetra
.677 .795 .937 r
.62777 .1826 .62869 .18362 .63057 .18297 .62964 .18186 Mtetra
.659 .77 .931 r
.62964 .18186 .63057 .18297 .63247 .18305 .63152 .1812 Mtetra
.616 .628 .84 r
.63152 .1812 .63247 .18305 .63442 .18453 .6334 .18072 Mtetra
.529 .441 .7 r
.6334 .18072 .63442 .18453 .63649 .18883 .63531 .18079 Mtetra
.411 .283 .594 r
.63531 .18079 .63649 .18883 .64608 .39258 .63729 .18292 Mtetra
0 0 .37 r
.63729 .18292 .64608 .39258 .64833 .39823 .64703 .38877 Mtetra
0 0 .47 r
.64703 .38877 .64833 .39823 .65046 .40031 .64942 .39786 Mtetra
.019 .21 .719 r
.64942 .39786 .65046 .40031 .65254 .4012 .65156 .39999 Mtetra
.414 .653 .957 r
.65156 .39999 .65254 .4012 .6546 .40131 .65361 .40011 Mtetra
.695 .782 .918 r
.65361 .40011 .6546 .40131 .65663 .4006 .65563 .39922 Mtetra
.877 .792 .762 r
.65563 .39922 .65663 .4006 .65858 .3981 .65758 .3965 Mtetra
.967 .738 .539 r
.65758 .3965 .65858 .3981 .66026 .38905 .65922 .3866 Mtetra
.977 .679 .375 r
.65922 .3866 .66026 .38905 .65328 .17795 .65235 .17647 Mtetra
.916 .766 .681 r
.65235 .17647 .65328 .17795 .65502 .17388 .6541 .17258 Mtetra
.718 .756 .882 r
.6541 .17258 .65502 .17388 .6569 .17288 .65598 .1716 Mtetra
.588 .708 .926 r
.65598 .1716 .6569 .17288 .65881 .17249 .65789 .17123 Mtetra
.574 .704 .931 r
.65789 .17123 .65881 .17249 .66071 .17211 .6598 .17091 Mtetra
.683 .763 .912 r
.6598 .17091 .66071 .17211 .6626 .17119 .66169 .17014 Mtetra
.667 .786 .938 r
.66169 .17014 .6626 .17119 .66449 .17052 .66359 .16943 Mtetra
.646 .771 .94 r
.66359 .16943 .66449 .17052 .66642 .17049 .66549 .16882 Mtetra
.618 .654 .864 r
.66549 .16882 .66642 .17049 .66842 .17185 .6674 .16833 Mtetra
.532 .456 .716 r
.6674 .16833 .66842 .17185 .67054 .17566 .66933 .16837 Mtetra
.426 .302 .607 r
.66933 .16837 .67054 .17566 .68252 .37958 .67136 .17012 Mtetra
0 0 .384 r
.67136 .17012 .68252 .37958 .68492 .38609 .68343 .37443 Mtetra
0 0 .463 r
.68343 .37443 .68492 .38609 .68711 .38833 .68607 .38565 Mtetra
.014 .187 .698 r
.68607 .38565 .68711 .38833 .68924 .38928 .68827 .38806 Mtetra
.389 .637 .954 r
.68827 .38806 .68924 .38928 .69134 .38946 .69037 .38826 Mtetra
.681 .78 .925 r
.69037 .38826 .69134 .38946 .69339 .3888 .69242 .38743 Mtetra
.866 .797 .781 r
.69242 .38743 .69339 .3888 .69537 .38653 .69438 .38495 Mtetra
.97 .745 .544 r
.69438 .38495 .69537 .38653 .69698 .37761 .69599 .37584 Mtetra
.977 .677 .357 r
.69599 .37584 .69698 .37761 .68751 .16533 .68662 .16419 Mtetra
.949 .801 .662 r
.68662 .16419 .68751 .16533 .68923 .16101 .68833 .15991 Mtetra
.728 .801 .909 r
.68833 .15991 .68923 .16101 .69113 .16006 .69023 .15891 Mtetra
.576 .729 .947 r
.69023 .15891 .69113 .16006 .69307 .15979 .69217 .15855 Mtetra
.534 .692 .941 r
.69217 .15855 .69307 .15979 .69501 .15964 .69411 .15836 Mtetra
.673 .747 .906 r
.69411 .15836 .69501 .15964 .69692 .15875 .69603 .15762 Mtetra
.661 .77 .93 r
.69603 .15762 .69692 .15875 .69884 .15807 .69795 .15693 Mtetra
.639 .762 .937 r
.69795 .15693 .69884 .15807 .70079 .15792 .69988 .15634 Mtetra
.621 .672 .878 r
.69988 .15634 .70079 .15792 .70283 .15915 .70181 .15583 Mtetra
.537 .47 .728 r
.70181 .15583 .70283 .15915 .70501 .16262 .70378 .15583 Mtetra
.44 .319 .618 r
.70378 .15583 .70501 .16262 .71943 .36681 .70583 .15728 Mtetra
0 0 .397 r
.70583 .15728 .71943 .36681 .722 .37431 .72028 .36051 Mtetra
0 0 .465 r
.72028 .36051 .722 .37431 .72427 .37671 .7232 .37357 Mtetra
.098 .21 .693 r
.7232 .37357 .72427 .37671 .72644 .37755 .72548 .37607 Mtetra
.551 .674 .919 r
.72548 .37607 .72644 .37755 .72854 .3772 .72758 .37583 Mtetra
.696 .758 .9 r
.72758 .37583 .72854 .3772 .73061 .37624 .72965 .3749 Mtetra
.753 .784 .879 r
.72965 .3749 .73061 .37624 .73263 .3746 .7317 .37363 Mtetra
.699 .838 .95 r
.7317 .37363 .73263 .3746 .73457 .37182 .73377 .3727 Mtetra
0 0 0 r
.73377 .3727 .73457 .37182 .73638 .36693 .7358 .37124 Mtetra
.173 0 .24 r
.7358 .37124 .73638 .36693 .72482 .16256 .73774 .36838 Mtetra
.485 .264 .502 r
.73774 .36838 .72482 .16256 .7261 .15207 .73852 .34827 Mtetra
0 0 .384 r
.73852 .34827 .7261 .15207 .72784 .14844 .72708 .149 Mtetra
.915 .929 .554 r
.72708 .149 .72784 .14844 .72969 .14634 .72882 .14524 Mtetra
.734 .807 .91 r
.72882 .14524 .72969 .14634 .73162 .14554 .73074 .1442 Mtetra
.614 .711 .915 r
.73074 .1442 .73162 .14554 .73358 .14511 .73269 .14371 Mtetra
.565 .68 .917 r
.73269 .14371 .73358 .14511 .73555 .14473 .73467 .14344 Mtetra
.693 .756 .9 r
.73467 .14344 .73555 .14473 .73747 .14364 .73661 .14258 Mtetra
.683 .799 .936 r
.73661 .14258 .73747 .14364 .7394 .14274 .73855 .14179 Mtetra
.643 .808 .962 r
.73855 .14179 .7394 .14274 .74137 .14231 .7405 .14114 Mtetra
.604 .744 .944 r
.7405 .14114 .74137 .14231 .74345 .14336 .74247 .14068 Mtetra
.528 .505 .774 r
.74247 .14068 .74345 .14336 .74567 .14632 .74447 .14071 Mtetra
.446 .342 .643 r
.74447 .14071 .74567 .14632 .76291 .34925 .74657 .14187 Mtetra
.488 .271 .511 r
.74657 .14187 .76291 .34925 .76584 .35962 .74989 .15931 Mtetra
0 0 .405 r
.74989 .15931 .76584 .35962 .76821 .36235 .76711 .35889 Mtetra
.064 .169 .663 r
.76711 .35889 .76821 .36235 .77046 .36347 .76951 .36193 Mtetra
.483 .629 .917 r
.76951 .36193 .77046 .36347 .77263 .36354 .77168 .36196 Mtetra
.646 .706 .89 r
.77168 .36196 .77263 .36354 .77475 .363 .77379 .36128 Mtetra
.719 .718 .848 r
.77379 .36128 .77475 .363 .77683 .36179 .77587 .3601 Mtetra
.758 .738 .834 r
.77587 .3601 .77683 .36179 .77877 .35884 .77793 .35864 Mtetra
.798 .994 .87 r
.77793 .35864 .77877 .35884 .78054 .35391 .77996 .35691 Mtetra
.206 0 .171 r
.77996 .35691 .78054 .35391 .78132 .33672 .78199 .3551 Mtetra
.495 .243 .462 r
.78199 .3551 .78132 .33672 .76791 .14648 .78409 .35411 Mtetra
.521 .29 .505 r
.78409 .35411 .76791 .14648 .76989 .14577 .78621 .35337 Mtetra
.78621 .35337 .76989 .14577 .77226 .14986 .78834 .35277 Mtetra
.253 0 .023 r
.11317 .57264 .11474 .57074 .11643 .56995 .11484 .57204 Mtetra
.272 0 .062 r
.11484 .57204 .11643 .56995 .11811 .56926 .11651 .57142 Mtetra
.27 0 .069 r
.11651 .57142 .11811 .56926 .11976 .56879 .11819 .57076 Mtetra
.219 0 .011 r
.11819 .57076 .11976 .56879 .12132 .56911 .11987 .57004 Mtetra
0 0 0 r
.11987 .57004 .12132 .56911 .12288 .56939 .12156 .56928 Mtetra
.651 .937 .966 r
.12156 .56928 .12288 .56939 .12447 .56946 .12326 .56848 Mtetra
.715 .779 .902 r
.12326 .56848 .12447 .56946 .12615 .56882 .12496 .56763 Mtetra
.71 .741 .876 r
.12496 .56763 .12615 .56882 .12785 .56796 .12666 .56677 Mtetra
.707 .74 .877 r
.12666 .56677 .12785 .56796 .12957 .567 .12837 .56593 Mtetra
.699 .76 .899 r
.12837 .56593 .12957 .567 .13127 .5662 .13006 .56515 Mtetra
.685 .762 .91 r
.13006 .56515 .13127 .5662 .13296 .56546 .13175 .56445 Mtetra
.664 .764 .925 r
.13175 .56445 .13296 .56546 .13464 .5648 .13343 .56384 Mtetra
.621 .763 .947 r
.13343 .56384 .13464 .5648 .13631 .56431 .13509 .56339 Mtetra
.59 .763 .961 r
.13509 .56339 .13631 .56431 .13797 .5639 .13674 .56302 Mtetra
.566 .765 .972 r
.13674 .56302 .13797 .5639 .13962 .56353 .13839 .5627 Mtetra
.176 .591 .939 r
.13839 .5627 .13962 .56353 .14122 .56367 .13997 .56302 Mtetra
.419 .759 .995 r
.13997 .56302 .14122 .56367 .14285 .56348 .1416 .56291 Mtetra
.742 .866 .937 r
.1416 .56291 .14285 .56348 .14457 .56256 .14332 .56195 Mtetra
.926 .759 .655 r
.14332 .56195 .14457 .56256 .14669 .5581 .1456 .55604 Mtetra
.938 .686 .529 r
.1456 .55604 .14669 .5581 .1706 .35796 .17004 .35192 Mtetra
.764 .554 .613 r
.17004 .35192 .1706 .35796 .17307 .3494 .17219 .34622 Mtetra
.679 .548 .699 r
.17219 .34622 .17307 .3494 .17483 .34726 .17386 .3449 Mtetra
.603 .55 .768 r
.17386 .3449 .17483 .34726 .17647 .34611 .17542 .34451 Mtetra
.508 .587 .869 r
.17542 .34451 .17647 .34611 .17807 .3454 .17694 .34452 Mtetra
.602 .765 .957 r
.17694 .34452 .17807 .3454 .17965 .34486 .1785 .34414 Mtetra
.63 .81 .969 r
.1785 .34414 .17965 .34486 .18122 .34445 .18008 .34365 Mtetra
.649 .795 .952 r
.18008 .34365 .18122 .34445 .18278 .34411 .18166 .34312 Mtetra
.697 .763 .903 r
.18166 .34312 .18278 .34411 .18436 .3436 .18327 .3424 Mtetra
.688 .723 .876 r
.18327 .3424 .18436 .3436 .18595 .34302 .18487 .34169 Mtetra
.658 .692 .87 r
.18487 .34169 .18595 .34302 .18755 .34242 .18646 .34111 Mtetra
.621 .684 .888 r
.18646 .34111 .18755 .34242 .18918 .34145 .18804 .3407 Mtetra
.396 .715 .987 r
.18804 .3407 .18918 .34145 .19079 .34068 .18957 .3407 Mtetra
.564 0 0 r
.18957 .3407 .19079 .34068 .19235 .34046 .19101 .34152 Mtetra
.905 .603 .464 r
.19101 .34152 .19235 .34046 .19355 .34366 .19137 .3527 Mtetra
.93 .669 .521 r
.19137 .3527 .19355 .34366 .17416 .54448 .17228 .55009 Mtetra
.655 .347 .437 r
.17228 .55009 .17416 .54448 .17511 .55116 .17364 .55277 Mtetra
.797 .945 .596 r
.17364 .55277 .17511 .55116 .17707 .54802 .17558 .54992 Mtetra
.946 .692 .521 r
.17558 .54992 .17707 .54802 .19944 .34622 .19701 .35792 Mtetra
.923 .802 .333 r
.19701 .35792 .19944 .34622 .20181 .33811 .20068 .33723 Mtetra
.854 .786 .784 r
.20068 .33723 .20181 .33811 .20355 .33619 .20244 .33511 Mtetra
.688 .747 .897 r
.20244 .33511 .20355 .33619 .20516 .33547 .20405 .33442 Mtetra
.569 .718 .943 r
.20405 .33442 .20516 .33547 .20673 .33521 .20562 .33416 Mtetra
.738 .761 .872 r
.20562 .33416 .20673 .33521 .20832 .33479 .20727 .33319 Mtetra
.703 .671 .816 r
.20727 .33319 .20832 .33479 .20988 .3346 .2089 .33228 Mtetra
.587 .546 .776 r
.2089 .33228 .20988 .3346 .21138 .33511 .21048 .33198 Mtetra
0 0 .518 r
.21048 .33198 .21138 .33511 .21249 .33958 .21177 .33462 Mtetra
.95 .69 .507 r
.21177 .33462 .21249 .33958 .19421 .54128 .19343 .53612 Mtetra
.885 .625 .106 r
.19343 .53612 .19421 .54128 .19539 .54612 .19423 .54484 Mtetra
0 .058 .577 r
.19423 .54484 .19539 .54612 .19694 .54729 .19575 .54628 Mtetra
.54 .732 .963 r
.19575 .54628 .19694 .54729 .19861 .54713 .19743 .54606 Mtetra
.774 .775 .854 r
.19743 .54606 .19861 .54713 .20038 .54599 .19922 .54476 Mtetra
.889 .742 .692 r
.19922 .54476 .20038 .54599 .20242 .54203 .20128 .54063 Mtetra
.945 .688 .517 r
.20128 .54063 .20242 .54203 .22326 .3409 .22229 .33852 Mtetra
.899 .681 .598 r
.22229 .33852 .22326 .3409 .2259 .32955 .22481 .3284 Mtetra
.838 .754 .771 r
.22481 .3284 .2259 .32955 .22767 .32736 .22657 .32627 Mtetra
.679 .744 .9 r
.22657 .32627 .22767 .32736 .22929 .32669 .2282 .32561 Mtetra
.545 .703 .943 r
.2282 .32561 .22929 .32669 .23087 .3265 .22978 .32542 Mtetra
.703 .751 .89 r
.22978 .32542 .23087 .3265 .23251 .32572 .23141 .32464 Mtetra
.719 .755 .881 r
.23141 .32464 .23251 .32572 .23415 .32486 .23306 .32378 Mtetra
.574 .715 .938 r
.23306 .32378 .23415 .32486 .23574 .32458 .23465 .32351 Mtetra
.818 .352 0 r
.23465 .32351 .23574 .32458 .23709 .32703 .23599 .32598 Mtetra
.948 .684 .504 r
.23599 .32598 .23709 .32703 .22035 .52852 .21916 .52757 Mtetra
.945 .619 .379 r
.21916 .52757 .22035 .52852 .22122 .53738 .22004 .53636 Mtetra
.583 .061 0 r
.22004 .53636 .22122 .53738 .22275 .53898 .22157 .53795 Mtetra
.522 .721 .964 r
.22157 .53795 .22275 .53898 .22445 .53881 .22327 .53778 Mtetra
.766 .785 .868 r
.22327 .53778 .22445 .53881 .22624 .5376 .22506 .53656 Mtetra
.894 .764 .71 r
.22506 .53656 .22624 .5376 .22825 .5339 .22707 .53287 Mtetra
.948 .689 .512 r
.22707 .53287 .22825 .5339 .24724 .33688 .24614 .33594 Mtetra
.942 .713 .563 r
.24614 .33594 .24724 .33688 .2502 .32119 .24911 .32011 Mtetra
.858 .763 .757 r
.24911 .32011 .2502 .32119 .25199 .31875 .2509 .31767 Mtetra
.672 .747 .907 r
.2509 .31767 .25199 .31875 .25363 .31811 .25254 .31704 Mtetra
.507 .692 .952 r
.25254 .31704 .25363 .31811 .25522 .31799 .25413 .31694 Mtetra
.566 .719 .944 r
.25413 .31694 .25522 .31799 .25683 .31765 .25573 .31668 Mtetra
.646 .762 .933 r
.25573 .31668 .25683 .31765 .25847 .31705 .25736 .31615 Mtetra
.655 .78 .941 r
.25736 .31615 .25847 .31705 .26009 .31654 .259 .31559 Mtetra
.677 .774 .924 r
.259 .31559 .26009 .31654 .26169 .31638 .26064 .31494 Mtetra
.679 .688 .852 r
.26064 .31494 .26169 .31638 .26327 .31653 .26229 .31422 Mtetra
.65 .582 .765 r
.26229 .31422 .26327 .31653 .26484 .31677 .26394 .31349 Mtetra
.622 .511 .707 r
.26394 .31349 .26484 .31677 .26644 .3166 .26559 .31277 Mtetra
.609 .484 .684 r
.26559 .31277 .26644 .3166 .26809 .31592 .26724 .31208 Mtetra
.607 .482 .684 r
.26724 .31208 .26809 .31592 .26975 .3151 .26888 .31141 Mtetra
.608 .487 .69 r
.26888 .31141 .26975 .3151 .2714 .31444 .27053 .31075 Mtetra
.606 .486 .69 r
.27053 .31075 .2714 .31444 .27304 .31391 .27218 .31012 Mtetra
.602 .48 .686 r
.27218 .31012 .27304 .31391 .2747 .31321 .27382 .30951 Mtetra
.6 .482 .69 r
.27382 .30951 .2747 .31321 .27639 .31196 .27547 .30894 Mtetra
.608 .515 .724 r
.27547 .30894 .27639 .31196 .27812 .31042 .27711 .3084 Mtetra
.633 .599 .798 r
.27711 .3084 .27812 .31042 .27983 .30903 .27876 .30785 Mtetra
.667 .728 .895 r
.27876 .30785 .27983 .30903 .28151 .30804 .28041 .30723 Mtetra
.685 .809 .941 r
.28041 .30723 .28151 .30804 .28316 .3074 .28206 .30654 Mtetra
.689 .8 .934 r
.28206 .30654 .28316 .3074 .2848 .30687 .28372 .30584 Mtetra
.693 .765 .908 r
.28372 .30584 .2848 .30687 .28645 .30635 .28538 .30512 Mtetra
.683 .723 .88 r
.28538 .30512 .28645 .30635 .2881 .30582 .28705 .30441 Mtetra
.656 .687 .867 r
.28705 .30441 .2881 .30582 .28975 .30527 .2887 .30381 Mtetra
.633 .671 .869 r
.2887 .30381 .28975 .30527 .29142 .30443 .29035 .30333 Mtetra
.564 .709 .939 r
.29035 .30333 .29142 .30443 .2931 .30347 .29198 .30308 Mtetra
0 .494 .785 r
.29198 .30308 .2931 .30347 .29475 .30294 .29356 .30343 Mtetra
.823 .408 .256 r
.29356 .30343 .29475 .30294 .29629 .30402 .29497 .30629 Mtetra
.95 .68 .492 r
.29497 .30629 .29629 .30402 .29743 .31049 .28178 .50922 Mtetra
.535 .302 .508 r
.28178 .50922 .29743 .31049 .28444 .51319 .28302 .51585 Mtetra
.638 .267 .323 r
.28302 .51585 .28444 .51319 .28597 .516 .28465 .51734 Mtetra
.265 0 0 r
.28465 .51734 .28597 .516 .28773 .51564 .2864 .51699 Mtetra
.044 0 0 r
.2864 .51699 .28773 .51564 .28952 .51471 .2882 .51614 Mtetra
.09 0 0 r
.2882 .51614 .28952 .51471 .29129 .51424 .28999 .51533 Mtetra
.128 0 0 r
.28999 .51533 .29129 .51424 .293 .51456 .29176 .5148 Mtetra
.347 .823 .795 r
.29176 .5148 .293 .51456 .29472 .51479 .29354 .51418 Mtetra
.722 .871 .951 r
.29354 .51418 .29472 .51479 .29647 .51473 .29535 .51326 Mtetra
.752 .723 .825 r
.29535 .51326 .29647 .51473 .29824 .51433 .29718 .51196 Mtetra
.717 .624 .753 r
.29718 .51196 .29824 .51433 .30001 .51379 .29901 .51054 Mtetra
.64 .534 .719 r
.29901 .51054 .30001 .51379 .30179 .51336 .30082 .50965 Mtetra
.559 .465 .705 r
.30082 .50965 .30179 .51336 .30355 .51301 .30257 .50946 Mtetra
.613 .505 .707 r
.30257 .50946 .30355 .51301 .30535 .51222 .30437 .50877 Mtetra
.762 .597 .673 r
.30437 .50877 .30535 .51222 .30725 .50999 .30631 .5058 Mtetra
.952 .686 .495 r
.30631 .5058 .30725 .50999 .30943 .50329 .3212 .30402 Mtetra
.548 .317 .517 r
.3212 .30402 .30943 .50329 .32436 .2982 .32355 .29312 Mtetra
.71 .524 .635 r
.32355 .29312 .32436 .2982 .32629 .29359 .32538 .29021 Mtetra
.634 .516 .702 r
.32538 .29021 .32629 .29359 .32799 .29269 .32707 .28933 Mtetra
.584 .486 .709 r
.32707 .28933 .32799 .29269 .32965 .2924 .32873 .28896 Mtetra
.571 .475 .706 r
.32873 .28896 .32965 .2924 .33133 .2918 .33039 .28868 Mtetra
.601 .508 .721 r
.33039 .28868 .33133 .2918 .33306 .29035 .33207 .28818 Mtetra
.62 .582 .789 r
.33207 .28818 .33306 .29035 .33479 .28901 .33374 .28768 Mtetra
.65 .701 .884 r
.33374 .28768 .33479 .28901 .3365 .28799 .33543 .28712 Mtetra
.677 .797 .939 r
.33543 .28712 .3365 .28799 .33818 .28741 .33711 .28645 Mtetra
.684 .781 .924 r
.33711 .28645 .33818 .28741 .33986 .28694 .3388 .28575 Mtetra
.686 .737 .89 r
.3388 .28575 .33986 .28694 .34153 .28645 .3405 .28503 Mtetra
.681 .697 .858 r
.3405 .28503 .34153 .28645 .34322 .28583 .34219 .28429 Mtetra
.66 .672 .851 r
.34219 .28429 .34322 .28583 .34491 .28517 .34388 .28365 Mtetra
.638 .666 .861 r
.34388 .28365 .34491 .28517 .34662 .28435 .34557 .28313 Mtetra
.6 .702 .915 r
.34557 .28313 .34662 .28435 .34833 .28331 .34725 .28277 Mtetra
.186 .652 .937 r
.34725 .28277 .34833 .28331 .35002 .28266 .34889 .28293 Mtetra
.75 .266 .089 r
.34889 .28293 .35002 .28266 .35165 .28315 .35045 .28474 Mtetra
.956 .681 .475 r
.35045 .28474 .35165 .28315 .35307 .28761 .34099 .48473 Mtetra
.544 .309 .509 r
.34099 .48473 .35307 .28761 .34355 .49197 .34216 .49573 Mtetra
.662 .317 .379 r
.34216 .49573 .34355 .49197 .34508 .49653 .34382 .49796 Mtetra
.329 0 0 r
.34382 .49796 .34508 .49653 .34687 .49634 .34561 .49774 Mtetra
.103 0 0 r
.34561 .49774 .34687 .49634 .3487 .49546 .34744 .49695 Mtetra
.076 0 0 r
.34744 .49695 .3487 .49546 .35052 .49473 .34927 .49604 Mtetra
.198 0 0 r
.34927 .49604 .35052 .49473 .35229 .49508 .35108 .49552 Mtetra
0 0 0 r
.35108 .49552 .35229 .49508 .35406 .49536 .3529 .49491 Mtetra
.683 .904 .974 r
.3529 .49491 .35406 .49536 .35585 .49535 .35473 .49407 Mtetra
.762 .757 .848 r
.35473 .49407 .35585 .49535 .35766 .49488 .35659 .49278 Mtetra
.731 .653 .772 r
.35659 .49278 .35766 .49488 .35948 .49428 .35845 .49134 Mtetra
.672 .569 .731 r
.35845 .49134 .35948 .49428 .3613 .49374 .3603 .49018 Mtetra
.552 .469 .715 r
.3603 .49018 .3613 .49374 .36311 .49354 .3621 .49006 Mtetra
.597 .5 .715 r
.3621 .49006 .36311 .49354 .36493 .49296 .36393 .48953 Mtetra
.719 .574 .692 r
.36393 .48953 .36493 .49296 .36681 .49135 .36582 .48749 Mtetra
.907 .666 .563 r
.36582 .48749 .36681 .49135 .36885 .48613 .36832 .47282 Mtetra
.947 .675 .488 r
.36832 .47282 .36885 .48613 .38022 .28086 .37946 .27378 Mtetra
.696 .492 .607 r
.37946 .27378 .38022 .28086 .38225 .27339 .38131 .27012 Mtetra
.642 .527 .708 r
.38131 .27012 .38225 .27339 .38403 .27142 .38304 .26918 Mtetra
.598 .567 .79 r
.38304 .26918 .38403 .27142 .38577 .27024 .38474 .26881 Mtetra
.553 .647 .897 r
.38474 .26881 .38577 .27024 .38749 .26944 .38644 .26863 Mtetra
.646 .808 .961 r
.38644 .26863 .38749 .26944 .38921 .26876 .38816 .26805 Mtetra
.647 .835 .973 r
.38816 .26805 .38921 .26876 .39092 .26821 .38987 .26745 Mtetra
.667 .828 .961 r
.38987 .26745 .39092 .26821 .39264 .26772 .39159 .26679 Mtetra
.705 .799 .924 r
.39159 .26679 .39264 .26772 .39435 .26718 .39332 .26599 Mtetra
.686 .743 .895 r
.39332 .26599 .39435 .26718 .39607 .26662 .39505 .26526 Mtetra
.642 .697 .885 r
.39505 .26526 .39607 .26662 .39779 .26602 .39677 .26472 Mtetra
.492 .644 .924 r
.39677 .26472 .39779 .26602 .39952 .2653 .39847 .26471 Mtetra
.226 .665 .954 r
.39847 .26471 .39952 .2653 .40125 .26456 .40016 .26485 Mtetra
.217 0 0 r
.40016 .26485 .40125 .26456 .40298 .26382 .40186 .26495 Mtetra
.144 0 0 r
.40186 .26495 .40298 .26382 .40471 .26313 .40359 .26439 Mtetra
.096 0 0 r
.40359 .26439 .40471 .26313 .40644 .26246 .40532 .26364 Mtetra
.012 0 0 r
.40532 .26364 .40644 .26246 .40817 .26176 .40706 .26278 Mtetra
0 0 0 r
.40706 .26278 .40817 .26176 .40991 .26076 .40881 .26159 Mtetra
.40881 .26159 .40991 .26076 .41165 .26009 .41055 .26091 Mtetra
.468 0 0 r
.41055 .26091 .41165 .26009 .41335 .26016 .41224 .26132 Mtetra
.912 .577 .395 r
.41224 .26132 .41335 .26016 .41494 .26365 .41359 .27138 Mtetra
.954 .672 .464 r
.41359 .27138 .41494 .26365 .40949 .468 .40817 .4732 Mtetra
.68 .354 .416 r
.40817 .4732 .40949 .468 .41107 .47508 .40989 .47649 Mtetra
.375 0 .011 r
.40989 .47649 .41107 .47508 .4129 .47527 .41173 .47643 Mtetra
.089 0 0 r
.41173 .47643 .4129 .47527 .41477 .47453 .41359 .47574 Mtetra
0 0 0 r
.41359 .47574 .41477 .47453 .41664 .47334 .41546 .47476 Mtetra
.23 0 0 r
.41546 .47476 .41664 .47334 .4185 .47275 .41732 .47425 Mtetra
.244 0 0 r
.41732 .47425 .4185 .47275 .42037 .47214 .41918 .47373 Mtetra
.255 0 0 r
.41918 .47373 .42037 .47214 .42223 .47153 .42105 .4732 Mtetra
.253 0 0 r
.42105 .4732 .42223 .47153 .42409 .47092 .42291 .47262 Mtetra
.252 0 0 r
.42291 .47262 .42409 .47092 .42596 .4703 .42478 .47201 Mtetra
.25 0 0 r
.42478 .47201 .42596 .4703 .42783 .46968 .42665 .4714 Mtetra
.255 0 .002 r
.42665 .4714 .42783 .46968 .4297 .46891 .42852 .4708 Mtetra
.277 0 .043 r
.42852 .4708 .4297 .46891 .43157 .46825 .43039 .47019 Mtetra
.277 0 .05 r
.43039 .47019 .43157 .46825 .43343 .46783 .43226 .46955 Mtetra
.258 0 .005 r
.43226 .46955 .43343 .46783 .43528 .46815 .43414 .46896 Mtetra
0 0 0 r
.43414 .46896 .43528 .46815 .43713 .46844 .43602 .46828 Mtetra
.597 .933 .953 r
.43602 .46828 .43713 .46844 .43899 .46853 .4379 .46746 Mtetra
.698 .787 .92 r
.4379 .46746 .43899 .46853 .44085 .46847 .43978 .46662 Mtetra
.73 .682 .804 r
.43978 .46662 .44085 .46847 .44273 .46794 .44168 .46534 Mtetra
.763 .637 .721 r
.44168 .46534 .44273 .46794 .44462 .46669 .4436 .46314 Mtetra
.89 .662 .587 r
.4436 .46314 .44462 .46669 .4466 .4621 .44569 .45372 Mtetra
.96 .681 .462 r
.44569 .45372 .4466 .4621 .45321 .25825 .45241 .24817 Mtetra
.676 .459 .583 r
.45241 .24817 .45321 .25825 .45521 .24727 .45426 .24367 Mtetra
.661 .527 .69 r
.45426 .24367 .45521 .24727 .45699 .24577 .45603 .24239 Mtetra
.604 .501 .71 r
.45603 .24239 .45699 .24577 .45875 .24525 .45779 .24181 Mtetra
.566 .474 .71 r
.45779 .24181 .45875 .24525 .4605 .24504 .45955 .24157 Mtetra
.595 .492 .706 r
.45955 .24157 .4605 .24504 .46228 .24366 .46131 .24105 Mtetra
.614 .549 .758 r
.46131 .24105 .46228 .24366 .46407 .24223 .46307 .24051 Mtetra
.638 .647 .842 r
.46307 .24051 .46407 .24223 .46584 .24096 .46484 .23995 Mtetra
.696 .786 .92 r
.46484 .23995 .46584 .24096 .46761 .24022 .46661 .23916 Mtetra
.693 .777 .915 r
.46661 .23916 .46761 .24022 .46938 .23965 .46838 .23839 Mtetra
.664 .729 .898 r
.46838 .23839 .46938 .23965 .47115 .23913 .47015 .23774 Mtetra
.636 .695 .888 r
.47015 .23774 .47115 .23913 .47293 .23807 .47192 .23722 Mtetra
.474 .739 .986 r
.47192 .23722 .47293 .23807 .4747 .2372 .47368 .23708 Mtetra
.357 0 0 r
.47368 .23708 .4747 .2372 .47647 .23688 .47544 .23772 Mtetra
.886 .508 .317 r
.47544 .23772 .47647 .23688 .4782 .23915 .47711 .24364 Mtetra
.963 .675 .439 r
.47711 .24364 .4782 .23915 .47966 .25971 .47579 .44972 Mtetra
.53 .297 .506 r
.47579 .44972 .47966 .25971 .47873 .45203 .47762 .45389 Mtetra
.476 .046 .142 r
.47762 .45389 .47873 .45203 .48061 .45371 .47951 .45415 Mtetra
0 0 0 r
.47951 .45415 .48061 .45371 .4825 .45394 .48142 .45343 Mtetra
.744 .916 .95 r
.48142 .45343 .4825 .45394 .4844 .45361 .48334 .45232 Mtetra
.633 .73 .917 r
.48334 .45232 .4844 .45361 .48631 .45307 .48525 .45177 Mtetra
.613 .719 .921 r
.48525 .45177 .48631 .45307 .48822 .45238 .48716 .45129 Mtetra
.641 .772 .943 r
.48716 .45129 .48822 .45238 .49013 .45161 .48907 .45069 Mtetra
.667 .814 .954 r
.48907 .45069 .49013 .45161 .49204 .45153 .49098 .44997 Mtetra
.725 .718 .844 r
.49098 .44997 .49204 .45153 .49395 .45126 .4929 .44884 Mtetra
.755 .646 .741 r
.4929 .44884 .49395 .45126 .49587 .45027 .49483 .44692 Mtetra
.865 .655 .617 r
.49483 .44692 .49587 .45027 .49782 .44556 .4968 .44045 Mtetra
.967 .684 .441 r
.4968 .44045 .49782 .44556 .50134 .23645 .50037 .23272 Mtetra
.835 .626 .62 r
.50037 .23272 .50134 .23645 .50319 .2282 .5022 .22714 Mtetra
.822 .804 .834 r
.5022 .22714 .50319 .2282 .50499 .22637 .504 .22549 Mtetra
.655 .805 .955 r
.504 .22549 .50499 .22637 .50678 .22582 .5058 .22486 Mtetra
.538 .745 .971 r
.5058 .22486 .50678 .22582 .50857 .22572 .50759 .2246 Mtetra
.656 .757 .924 r
.50759 .2246 .50857 .22572 .51037 .22525 .50938 .22398 Mtetra
.677 .734 .894 r
.50938 .22398 .51037 .22525 .51217 .2246 .51118 .22326 Mtetra
.654 .714 .892 r
.51118 .22326 .51217 .2246 .51396 .22391 .51298 .22264 Mtetra
.65 .726 .904 r
.51298 .22264 .51396 .22391 .51576 .22281 .51478 .22204 Mtetra
.52 .784 .993 r
.51478 .22204 .51576 .22281 .51756 .22183 .51658 .22176 Mtetra
.248 0 0 r
.51658 .22176 .51756 .22183 .51936 .22139 .51838 .2222 Mtetra
.866 .465 .273 r
.51838 .2222 .51936 .22139 .52116 .22323 .52017 .22701 Mtetra
.967 .675 .422 r
.52017 .22701 .52116 .22323 .52296 .23404 .52179 .43408 Mtetra
.531 .297 .506 r
.52179 .43408 .52296 .23404 .52477 .4366 .52372 .43874 Mtetra
.543 .128 .205 r
.52372 .43874 .52477 .4366 .5267 .43868 .52565 .43941 Mtetra
0 0 0 r
.52565 .43941 .5267 .43868 .52864 .4389 .52759 .4388 Mtetra
.687 .97 .924 r
.52759 .4388 .52864 .4389 .53058 .43856 .52953 .43765 Mtetra
.712 .833 .94 r
.52953 .43765 .53058 .43856 .53252 .43845 .53148 .43672 Mtetra
.709 .694 .834 r
.53148 .43672 .53252 .43845 .53447 .43815 .53342 .43565 Mtetra
.744 .638 .743 r
.53342 .43565 .53447 .43815 .53641 .43721 .53536 .43384 Mtetra
.858 .652 .624 r
.53536 .43384 .53641 .43721 .53834 .43398 .53728 .42794 Mtetra
.969 .682 .429 r
.53728 .42794 .53834 .43398 .54024 .42374 .53831 .21922 Mtetra
.535 .306 .514 r
.53831 .21922 .54024 .42374 .54109 .21769 .5401 .2133 Mtetra
.679 .517 .659 r
.5401 .2133 .54109 .21769 .54289 .21432 .54191 .21142 Mtetra
.618 .535 .739 r
.54191 .21142 .54289 .21432 .54471 .21288 .54373 .21078 Mtetra
.569 .572 .816 r
.54373 .21078 .54471 .21288 .54652 .21199 .54555 .21056 Mtetra
.628 .69 .889 r
.54555 .21056 .54652 .21199 .54834 .21125 .54737 .21006 Mtetra
.673 .751 .909 r
.54737 .21006 .54834 .21125 .55016 .21058 .5492 .20935 Mtetra
.654 .736 .91 r
.5492 .20935 .55016 .21058 .55199 .20998 .55102 .20873 Mtetra
.647 .729 .909 r
.55102 .20873 .55199 .20998 .55381 .20899 .55285 .20814 Mtetra
.551 .778 .983 r
.55285 .20814 .55381 .20899 .55563 .20798 .55467 .2078 Mtetra
0 .472 .704 r
.55467 .2078 .55563 .20798 .55746 .20746 .55651 .20813 Mtetra
.839 .408 .208 r
.55651 .20813 .55746 .20746 .55931 .20889 .55839 .21188 Mtetra
.97 .674 .406 r
.55839 .21188 .55931 .20889 .56124 .21658 .56265 .41963 Mtetra
.532 .298 .506 r
.56265 .41963 .56124 .21658 .56567 .42264 .56469 .42511 Mtetra
.581 .181 .249 r
.56469 .42511 .56567 .42264 .56768 .42531 .56667 .42612 Mtetra
.076 0 0 r
.56667 .42612 .56768 .42531 .56966 .42563 .56864 .42559 Mtetra
.634 .961 .907 r
.56864 .42559 .56966 .42563 .57163 .42534 .57061 .4245 Mtetra
.719 .854 .946 r
.57061 .4245 .57163 .42534 .57361 .42525 .57257 .42352 Mtetra
.697 .693 .842 r
.57257 .42352 .57361 .42525 .57559 .42507 .57454 .42253 Mtetra
.729 .63 .749 r
.57454 .42253 .57559 .42507 .57756 .42418 .5765 .42089 Mtetra
.834 .644 .646 r
.5765 .42089 .57756 .42418 .57948 .42072 .57841 .41627 Mtetra
.973 .682 .412 r
.57841 .41627 .57948 .42072 .57805 .22448 .57682 .20787 Mtetra
.676 .44 .556 r
.57682 .20787 .57805 .22448 .5795 .20149 .57854 .20016 Mtetra
.858 .775 .768 r
.57854 .20016 .5795 .20149 .5813 .19874 .58035 .19781 Mtetra
.691 .812 .94 r
.58035 .19781 .5813 .19874 .58314 .198 .5822 .19702 Mtetra
.568 .756 .967 r
.5822 .19702 .58314 .198 .585 .1978 .58405 .19667 Mtetra
.626 .749 .935 r
.58405 .19667 .585 .1978 .58685 .19745 .5859 .19616 Mtetra
.684 .739 .893 r
.5859 .19616 .58685 .19745 .5887 .19676 .58774 .19538 Mtetra
.665 .718 .888 r
.58774 .19538 .5887 .19676 .59054 .19602 .58959 .19469 Mtetra
.657 .722 .897 r
.58959 .19469 .59054 .19602 .59238 .19494 .59144 .19404 Mtetra
.593 .787 .973 r
.59144 .19404 .59238 .19494 .59422 .19379 .5933 .19359 Mtetra
.023 .588 .793 r
.5933 .19359 .59422 .19379 .59607 .19318 .59517 .19373 Mtetra
.778 .303 .106 r
.59517 .19373 .59607 .19318 .59798 .19463 .5971 .19632 Mtetra
.973 .673 .387 r
.5971 .19632 .59798 .19463 .60018 .208 .60405 .403 Mtetra
.536 .302 .506 r
.60405 .403 .60018 .208 .60724 .41132 .60625 .41069 Mtetra
.556 .008 0 r
.60625 .41069 .60724 .41132 .60931 .41368 .60831 .41251 Mtetra
.455 .68 .962 r
.60831 .41251 .60931 .41368 .61133 .41358 .61032 .41251 Mtetra
.727 .813 .918 r
.61032 .41251 .61133 .41358 .61331 .41244 .61231 .41147 Mtetra
.925 .832 .734 r
.61231 .41147 .61331 .41244 .61525 .40956 .61424 .40816 Mtetra
.976 .72 .479 r
.61424 .40816 .61525 .40956 .61704 .40165 .61575 .39009 Mtetra
.969 .673 .41 r
.61575 .39009 .61704 .40165 .61296 .19282 .61192 .18835 Mtetra
.735 .551 .643 r
.61192 .18835 .61296 .19282 .61472 .18848 .61372 .18528 Mtetra
.625 .526 .722 r
.61372 .18528 .61472 .18848 .61656 .18692 .61558 .1845 Mtetra
.563 .541 .789 r
.61558 .1845 .61656 .18692 .61841 .18597 .61746 .18431 Mtetra
.559 .625 .874 r
.61746 .18431 .61841 .18597 .62028 .18527 .61935 .18411 Mtetra
.638 .749 .929 r
.61935 .18411 .62028 .18527 .62215 .18463 .62122 .18353 Mtetra
.647 .767 .936 r
.62122 .18353 .62215 .18463 .62403 .18407 .6231 .18292 Mtetra
.663 .762 .924 r
.6231 .18292 .62403 .18407 .6259 .18341 .62497 .18225 Mtetra
.679 .764 .915 r
.62497 .18225 .6259 .18341 .62777 .1826 .62684 .1815 Mtetra
.689 .78 .921 r
.62684 .1815 .62777 .1826 .62964 .18186 .62871 .1807 Mtetra
.739 .786 .89 r
.62871 .1807 .62964 .18186 .63152 .1812 .63057 .17964 Mtetra
.742 .721 .832 r
.63057 .17964 .63152 .1812 .6334 .18072 .63243 .17841 Mtetra
.64 .593 .785 r
.63243 .17841 .6334 .18072 .63531 .18079 .63431 .1777 Mtetra
.377 .38 .736 r
.63431 .1777 .63531 .18079 .63729 .18292 .63625 .1787 Mtetra
0 0 .189 r
.63625 .1787 .63729 .18292 .64703 .38877 .63849 .18753 Mtetra
0 0 .356 r
.63849 .18753 .64703 .38877 .64942 .39786 .6484 .39581 Mtetra
0 0 .566 r
.6484 .39581 .64942 .39786 .65156 .39999 .65057 .39877 Mtetra
.424 .655 .956 r
.65057 .39877 .65156 .39999 .65361 .40011 .65262 .39887 Mtetra
.72 .783 .902 r
.65262 .39887 .65361 .40011 .65563 .39922 .65464 .39784 Mtetra
.889 .791 .746 r
.65464 .39784 .65563 .39922 .65758 .3965 .65658 .39487 Mtetra
.971 .731 .515 r
.65658 .39487 .65758 .3965 .65922 .3866 .65814 .38297 Mtetra
.976 .678 .378 r
.65814 .38297 .65922 .3866 .65235 .17647 .6514 .17469 Mtetra
.888 .737 .688 r
.6514 .17469 .65235 .17647 .6541 .17258 .65317 .17107 Mtetra
.694 .712 .862 r
.65317 .17107 .6541 .17258 .65598 .1716 .65505 .17018 Mtetra
.571 .673 .908 r
.65505 .17018 .65598 .1716 .65789 .17123 .65697 .1699 Mtetra
.548 .678 .924 r
.65697 .1699 .65789 .17123 .6598 .17091 .65888 .16968 Mtetra
.66 .748 .915 r
.65888 .16968 .6598 .17091 .66169 .17014 .66078 .16901 Mtetra
.67 .772 .927 r
.66078 .16901 .66169 .17014 .66359 .16943 .66268 .16829 Mtetra
.717 .787 .907 r
.66268 .16829 .66359 .16943 .66549 .16882 .66456 .16735 Mtetra
.748 .74 .844 r
.66456 .16735 .66549 .16882 .6674 .16833 .66644 .16611 Mtetra
.648 .606 .794 r
.66644 .16611 .6674 .16833 .66933 .16837 .66834 .16536 Mtetra
.421 .415 .746 r
.66834 .16536 .66933 .16837 .67136 .17012 .67031 .1661 Mtetra
0 0 .255 r
.67031 .1661 .67136 .17012 .68343 .37443 .67264 .17412 Mtetra
0 0 .367 r
.67264 .17412 .68343 .37443 .68607 .38565 .68506 .38383 Mtetra
0 0 .5 r
.68506 .38383 .68607 .38565 .68827 .38806 .68731 .38705 Mtetra
.412 .696 .979 r
.68731 .38705 .68827 .38806 .69037 .38826 .6894 .38707 Mtetra
.719 .797 .913 r
.6894 .38707 .69037 .38826 .69242 .38743 .69144 .38605 Mtetra
.861 .796 .786 r
.69144 .38605 .69242 .38743 .69438 .38495 .69341 .38365 Mtetra
.964 .778 .605 r
.69341 .38365 .69438 .38495 .69599 .37584 .69517 .37746 Mtetra
.978 .679 .349 r
.69517 .37746 .69599 .37584 .68662 .16419 .68591 .16674 Mtetra
.695 .715 .193 r
.68591 .16674 .68662 .16419 .68833 .15991 .68754 .16068 Mtetra
0 0 0 r
.68754 .16068 .68833 .15991 .69023 .15891 .6894 .15889 Mtetra
.608 .955 .878 r
.6894 .15889 .69023 .15891 .69217 .15855 .69129 .15781 Mtetra
.665 .861 .974 r
.69129 .15781 .69217 .15855 .69411 .15836 .69321 .15705 Mtetra
.672 .742 .903 r
.69321 .15705 .69411 .15836 .69603 .15762 .69513 .15632 Mtetra
.652 .734 .91 r
.69513 .15632 .69603 .15762 .69795 .15693 .69705 .15567 Mtetra
.675 .752 .909 r
.69705 .15567 .69795 .15693 .69988 .15634 .69897 .15492 Mtetra
.742 .749 .858 r
.69897 .15492 .69988 .15634 .70181 .15583 .70087 .15375 Mtetra
.658 .626 .807 r
.70087 .15375 .70181 .15583 .70378 .15583 .70278 .15295 Mtetra
.508 .477 .758 r
.70278 .15295 .70378 .15583 .70583 .15728 .70476 .15312 Mtetra
.007 .084 .595 r
.70476 .15312 .70583 .15728 .72028 .36051 .70697 .157 Mtetra
0 0 .384 r
.70697 .157 .72028 .36051 .7232 .37357 .72189 .3665 Mtetra
.063 .064 .546 r
.72189 .3665 .7232 .37357 .72548 .37607 .72438 .37252 Mtetra
.44 .41 .73 r
.72438 .37252 .72548 .37607 .72758 .37583 .72655 .37329 Mtetra
.543 .538 .799 r
.72655 .37329 .72758 .37583 .72965 .3749 .72867 .3732 Mtetra
.597 .662 .883 r
.72867 .3732 .72965 .3749 .7317 .37363 .73077 .37277 Mtetra
.461 .76 .994 r
.73077 .37277 .7317 .37363 .73377 .3727 .73289 .37259 Mtetra
.445 .878 .898 r
.73289 .37259 .73377 .3727 .7358 .37124 .73498 .37188 Mtetra
.488 .839 .572 r
.73498 .37188 .7358 .37124 .73774 .36838 .737 .37017 Mtetra
.776 .797 .306 r
.737 .37017 .73774 .36838 .73852 .34827 .73877 .36472 Mtetra
.972 .68 .284 r
.73877 .36472 .73852 .34827 .72708 .149 .72661 .1538 Mtetra
0 0 .081 r
.72661 .1538 .72708 .149 .72882 .14524 .72807 .14604 Mtetra
.534 .822 .482 r
.72807 .14604 .72882 .14524 .73074 .1442 .72993 .14399 Mtetra
.719 .979 .914 r
.72993 .14399 .73074 .1442 .73269 .14371 .73183 .14274 Mtetra
.693 .822 .944 r
.73183 .14274 .73269 .14371 .73467 .14344 .73377 .14191 Mtetra
.662 .702 .876 r
.73377 .14191 .73467 .14344 .73661 .14258 .73572 .14118 Mtetra
.638 .714 .902 r
.73572 .14118 .73661 .14258 .73855 .14179 .73767 .14059 Mtetra
.638 .753 .931 r
.73767 .14059 .73855 .14179 .7405 .14114 .73963 .13999 Mtetra
.749 .803 .896 r
.73963 .13999 .7405 .14114 .74247 .14068 .74155 .13886 Mtetra
.668 .664 .836 r
.74155 .13886 .74247 .14068 .74447 .14071 .74349 .13805 Mtetra
.542 .514 .774 r
.74349 .13805 .74447 .14071 .74657 .14187 .7455 .13798 Mtetra
.026 .11 .615 r
.7455 .13798 .74657 .14187 .74989 .15931 .74778 .14161 Mtetra
.961 .661 .242 r
.74778 .14161 .74989 .15931 .76711 .35889 .76571 .35139 Mtetra
.048 .051 .538 r
.76571 .35139 .76711 .35889 .76951 .36193 .76839 .35816 Mtetra
.538 .463 .719 r
.76839 .35816 .76951 .36193 .77168 .36196 .77055 .35814 Mtetra
.616 .508 .708 r
.77055 .35814 .77168 .36196 .77379 .36128 .77265 .3573 Mtetra
.631 .511 .699 r
.77265 .3573 .77379 .36128 .77587 .3601 .77474 .35625 Mtetra
.507 .441 .716 r
.77474 .35625 .77587 .3601 .77793 .35864 .77693 .35652 Mtetra
.477 .545 .847 r
.77693 .35652 .77793 .35864 .77996 .35691 .77912 .35674 Mtetra
.092 .644 .816 r
.77912 .35674 .77996 .35691 .78199 .3551 .7813 .35674 Mtetra
.277 0 .007 r
.7813 .35674 .78199 .3551 .78409 .35411 .78344 .35616 Mtetra
.293 0 .085 r
.78344 .35616 .78409 .35411 .78621 .35337 .78556 .35541 Mtetra
.272 0 .077 r
.78556 .35541 .78621 .35337 .78834 .35277 .78767 .35457 Mtetra
.616 .881 .99 r
.11188 .57224 .11317 .57264 .11484 .57204 .11355 .57166 Mtetra
.629 .887 .987 r
.11355 .57166 .11484 .57204 .11651 .57142 .11522 .57104 Mtetra
.65 .893 .983 r
.11522 .57104 .11651 .57142 .11819 .57076 .1169 .57037 Mtetra
.693 .897 .97 r
.1169 .57037 .11819 .57076 .11987 .57004 .11859 .56958 Mtetra
.717 .885 .958 r
.11859 .56958 .11987 .57004 .12156 .56928 .12029 .56872 Mtetra
.732 .865 .944 r
.12029 .56872 .12156 .56928 .12326 .56848 .122 .56782 Mtetra
.742 .843 .926 r
.122 .56782 .12326 .56848 .12496 .56763 .12372 .56686 Mtetra
.741 .821 .914 r
.12372 .56686 .12496 .56763 .12666 .56677 .12543 .56591 Mtetra
.732 .802 .907 r
.12543 .56591 .12666 .56677 .12837 .56593 .12715 .56498 Mtetra
.702 .783 .914 r
.12715 .56498 .12837 .56593 .13006 .56515 .12884 .5642 Mtetra
.679 .778 .926 r
.12884 .5642 .13006 .56515 .13175 .56445 .13053 .56353 Mtetra
.651 .779 .942 r
.13053 .56353 .13175 .56445 .13343 .56384 .1322 .56297 Mtetra
.613 .779 .961 r
.1322 .56297 .13343 .56384 .13509 .56339 .13386 .56252 Mtetra
.579 .772 .971 r
.13386 .56252 .13509 .56339 .13674 .56302 .13552 .56217 Mtetra
.549 .766 .978 r
.13552 .56217 .13674 .56302 .13839 .5627 .13716 .56189 Mtetra
.085 .536 .905 r
.13716 .56189 .13839 .5627 .13997 .56302 .13873 .56231 Mtetra
.378 .727 .99 r
.13873 .56231 .13997 .56302 .1416 .56291 .14034 .56229 Mtetra
.724 .853 .943 r
.14034 .56229 .1416 .56291 .14332 .56195 .14206 .56141 Mtetra
.928 .766 .66 r
.14206 .56141 .14332 .56195 .1456 .55604 .14432 .55574 Mtetra
.94 .688 .528 r
.14432 .55574 .1456 .55604 .17004 .35192 .1689 .35098 Mtetra
.914 .736 .647 r
.1689 .35098 .17004 .35192 .17219 .34622 .17109 .34502 Mtetra
.77 .738 .824 r
.17109 .34502 .17219 .34622 .17386 .3449 .17275 .34373 Mtetra
.596 .7 .916 r
.17275 .34373 .17386 .3449 .17542 .34451 .17431 .34341 Mtetra
.415 .641 .949 r
.17431 .34341 .17542 .34451 .17694 .34452 .17582 .34352 Mtetra
.603 .736 .938 r
.17582 .34352 .17694 .34452 .1785 .34414 .17738 .34315 Mtetra
.647 .753 .926 r
.17738 .34315 .1785 .34414 .18008 .34365 .17896 .34264 Mtetra
.666 .752 .915 r
.17896 .34264 .18008 .34365 .18166 .34312 .18055 .34205 Mtetra
.736 .756 .869 r
.18055 .34205 .18166 .34312 .18327 .3424 .18218 .34109 Mtetra
.71 .712 .85 r
.18218 .34109 .18327 .3424 .18487 .34169 .1838 .34023 Mtetra
.639 .667 .861 r
.1838 .34023 .18487 .34169 .18646 .34111 .18538 .33973 Mtetra
.088 .396 .852 r
.18538 .33973 .18646 .34111 .18804 .3407 .18683 .34049 Mtetra
.837 .392 .166 r
.18683 .34049 .18804 .3407 .18957 .3407 .18811 .34288 Mtetra
.89 .595 .481 r
.18811 .34288 .18957 .3407 .19101 .34152 .18828 .35577 Mtetra
.923 .661 .524 r
.18828 .35577 .19101 .34152 .19137 .3527 .1695 .54851 Mtetra
.528 .296 .506 r
.1695 .54851 .19137 .3527 .17228 .55009 .17082 .55154 Mtetra
.57 .135 .175 r
.17082 .55154 .17228 .55009 .17364 .55277 .17239 .55226 Mtetra
.911 .812 .736 r
.17239 .55226 .17364 .55277 .17558 .54992 .17438 .54893 Mtetra
.943 .688 .523 r
.17438 .54893 .17558 .54992 .19701 .35792 .19637 .35223 Mtetra
.869 .632 .578 r
.19637 .35223 .19701 .35792 .20068 .33723 .19958 .3361 Mtetra
.834 .752 .773 r
.19958 .3361 .20068 .33723 .20244 .33511 .20134 .33402 Mtetra
.682 .742 .896 r
.20134 .33402 .20244 .33511 .20405 .33442 .20295 .33335 Mtetra
.563 .71 .94 r
.20295 .33335 .20405 .33442 .20562 .33416 .20452 .3331 Mtetra
.747 .762 .865 r
.20452 .3331 .20562 .33416 .20727 .33319 .20617 .33207 Mtetra
.739 .75 .861 r
.20617 .33207 .20727 .33319 .2089 .33228 .20781 .33107 Mtetra
.611 .7 .907 r
.20781 .33107 .2089 .33228 .21048 .33198 .2094 .33069 Mtetra
.808 .355 0 r
.2094 .33069 .21048 .33198 .21177 .33462 .2107 .33321 Mtetra
.946 .685 .51 r
.2107 .33321 .21177 .33462 .19343 .53612 .19232 .53433 Mtetra
.961 .644 .371 r
.19232 .53433 .19343 .53612 .19423 .54484 .19304 .5438 Mtetra
.544 .021 0 r
.19304 .5438 .19423 .54484 .19575 .54628 .19455 .54528 Mtetra
.542 .734 .964 r
.19455 .54528 .19575 .54628 .19743 .54606 .19624 .54505 Mtetra
.78 .787 .859 r
.19624 .54505 .19743 .54606 .19922 .54476 .19803 .54374 Mtetra
.9 .757 .695 r
.19803 .54374 .19922 .54476 .20128 .54063 .20009 .53959 Mtetra
.945 .688 .517 r
.20009 .53959 .20128 .54063 .22229 .33852 .22119 .33736 Mtetra
.928 .717 .597 r
.22119 .33736 .22229 .33852 .22481 .3284 .22371 .32731 Mtetra
.841 .76 .774 r
.22371 .32731 .22481 .3284 .22657 .32627 .22548 .32517 Mtetra
.678 .744 .9 r
.22548 .32517 .22657 .32627 .2282 .32561 .2271 .32452 Mtetra
.544 .701 .942 r
.2271 .32452 .2282 .32561 .22978 .32542 .22868 .32433 Mtetra
.702 .751 .889 r
.22868 .32433 .22978 .32542 .23141 .32464 .23032 .32356 Mtetra
.718 .755 .881 r
.23032 .32356 .23141 .32464 .23306 .32378 .23196 .3227 Mtetra
.573 .714 .937 r
.23196 .3227 .23306 .32378 .23465 .32351 .23355 .32242 Mtetra
.818 .353 0 r
.23355 .32242 .23465 .32351 .23599 .32598 .23489 .3249 Mtetra
.948 .684 .504 r
.23489 .3249 .23599 .32598 .21916 .52757 .21798 .52658 Mtetra
.946 .619 .377 r
.21798 .52658 .21916 .52757 .22004 .53636 .21886 .53533 Mtetra
.58 .058 0 r
.21886 .53533 .22004 .53636 .22157 .53795 .22039 .53692 Mtetra
.522 .721 .964 r
.22039 .53692 .22157 .53795 .22327 .53778 .22209 .53674 Mtetra
.766 .785 .868 r
.22209 .53674 .22327 .53778 .22506 .53656 .22388 .53553 Mtetra
.894 .764 .71 r
.22388 .53553 .22506 .53656 .22707 .53287 .2259 .53184 Mtetra
.948 .689 .512 r
.2259 .53184 .22707 .53287 .24614 .33594 .24503 .33497 Mtetra
.941 .712 .563 r
.24503 .33497 .24614 .33594 .24911 .32011 .24802 .31902 Mtetra
.857 .763 .757 r
.24802 .31902 .24911 .32011 .2509 .31767 .24981 .31659 Mtetra
.67 .746 .907 r
.24981 .31659 .2509 .31767 .25254 .31704 .25145 .31597 Mtetra
.501 .688 .951 r
.25145 .31597 .25254 .31704 .25413 .31694 .25304 .31588 Mtetra
.554 .713 .946 r
.25304 .31588 .25413 .31694 .25573 .31668 .25464 .31565 Mtetra
.636 .748 .929 r
.25464 .31565 .25573 .31668 .25736 .31615 .25627 .31516 Mtetra
.651 .76 .929 r
.25627 .31516 .25736 .31615 .259 .31559 .2579 .31461 Mtetra
.69 .774 .915 r
.2579 .31461 .259 .31559 .26064 .31494 .25955 .31391 Mtetra
.713 .767 .894 r
.25955 .31391 .26064 .31494 .26229 .31422 .26121 .31308 Mtetra
.711 .746 .879 r
.26121 .31308 .26229 .31422 .26394 .31349 .26287 .31224 Mtetra
.694 .724 .873 r
.26287 .31224 .26394 .31349 .26559 .31277 .26452 .31148 Mtetra
.678 .712 .873 r
.26452 .31148 .26559 .31277 .26724 .31208 .26617 .31079 Mtetra
.673 .71 .876 r
.26617 .31079 .26724 .31208 .26888 .31141 .26782 .31013 Mtetra
.673 .713 .878 r
.26782 .31013 .26888 .31141 .27053 .31075 .26947 .30947 Mtetra
.672 .711 .878 r
.26947 .30947 .27053 .31075 .27218 .31012 .27111 .30882 Mtetra
.665 .706 .878 r
.27111 .30882 .27218 .31012 .27382 .30951 .27276 .30819 Mtetra
.645 .697 .884 r
.27276 .30819 .27382 .30951 .27547 .30894 .2744 .30766 Mtetra
.63 .698 .895 r
.2744 .30766 .27547 .30894 .27711 .3084 .27604 .3072 Mtetra
.636 .715 .904 r
.27604 .3072 .27711 .3084 .27876 .30785 .27768 .30671 Mtetra
.675 .739 .899 r
.27768 .30671 .27876 .30785 .28041 .30723 .27933 .30606 Mtetra
.704 .741 .88 r
.27933 .30606 .28041 .30723 .28206 .30654 .281 .30525 Mtetra
.702 .72 .864 r
.281 .30525 .28206 .30654 .28372 .30584 .28267 .30443 Mtetra
.705 .703 .845 r
.28267 .30443 .28372 .30584 .28538 .30512 .28434 .30356 Mtetra
.689 .677 .833 r
.28434 .30356 .28538 .30512 .28705 .30441 .28601 .30274 Mtetra
.635 .642 .84 r
.28601 .30274 .28705 .30441 .2887 .30381 .28766 .30223 Mtetra
.421 .551 .881 r
.28766 .30223 .2887 .30381 .29035 .30333 .28925 .30249 Mtetra
.626 .096 0 r
.28925 .30249 .29035 .30333 .29198 .30308 .29075 .30407 Mtetra
.852 .487 .36 r
.29075 .30407 .29198 .30308 .29356 .30343 .29202 .30859 Mtetra
.946 .676 .495 r
.29202 .30859 .29356 .30343 .29497 .30629 .27887 .50858 Mtetra
.532 .299 .507 r
.27887 .50858 .29497 .30629 .28178 .50922 .2802 .51391 Mtetra
.634 .308 .401 r
.2802 .51391 .28178 .50922 .28302 .51585 .28179 .5159 Mtetra
.374 0 0 r
.28179 .5159 .28302 .51585 .28465 .51734 .28348 .51641 Mtetra
.599 .776 .964 r
.28348 .51641 .28465 .51734 .2864 .51699 .28525 .51598 Mtetra
.687 .784 .924 r
.28525 .51598 .2864 .51699 .2882 .51614 .28703 .51523 Mtetra
.656 .797 .95 r
.28703 .51523 .2882 .51614 .28999 .51533 .28881 .5146 Mtetra
.564 .809 .991 r
.28881 .5146 .28999 .51533 .29176 .5148 .29058 .51421 Mtetra
.651 .863 .98 r
.29058 .51421 .29176 .5148 .29354 .51418 .29236 .51354 Mtetra
.828 .863 .872 r
.29236 .51354 .29354 .51418 .29535 .51326 .29421 .51197 Mtetra
.875 .752 .724 r
.29421 .51197 .29535 .51326 .29718 .51196 .29618 .50872 Mtetra
.842 .645 .636 r
.29618 .50872 .29718 .51196 .29901 .51054 .29831 .50301 Mtetra
.817 .583 .584 r
.29831 .50301 .29901 .51054 .30082 .50965 .3008 .49191 Mtetra
.511 .314 .549 r
.3008 .49191 .30082 .50965 .30257 .50946 .30249 .49257 Mtetra
.497 .305 .549 r
.30249 .49257 .30257 .50946 .30437 .50877 .30415 .49367 Mtetra
.939 .671 .504 r
.30415 .49367 .30437 .50877 .30631 .5058 .31849 .30297 Mtetra
.542 .312 .516 r
.31849 .30297 .30631 .5058 .3212 .30402 .32069 .2945 Mtetra
.661 .452 .59 r
.32069 .2945 .3212 .30402 .32355 .29312 .32256 .29088 Mtetra
.762 .643 .73 r
.32256 .29088 .32355 .29312 .32538 .29021 .32432 .28895 Mtetra
.694 .727 .876 r
.32432 .28895 .32538 .29021 .32707 .28933 .32601 .28818 Mtetra
.624 .723 .918 r
.32601 .28818 .32707 .28933 .32873 .28896 .32768 .28773 Mtetra
.596 .699 .915 r
.32768 .28773 .32873 .28896 .33039 .28868 .32935 .28738 Mtetra
.618 .694 .898 r
.32935 .28738 .33039 .28868 .33207 .28818 .33102 .28696 Mtetra
.621 .709 .909 r
.33102 .28696 .33207 .28818 .33374 .28768 .33269 .28652 Mtetra
.654 .732 .907 r
.33269 .28652 .33374 .28768 .33543 .28712 .33437 .28595 Mtetra
.697 .744 .887 r
.33437 .28595 .33543 .28712 .33711 .28645 .33607 .28517 Mtetra
.7 .725 .87 r
.33607 .28517 .33711 .28645 .3388 .28575 .33777 .28435 Mtetra
.701 .707 .852 r
.33777 .28435 .3388 .28575 .3405 .28503 .33947 .28349 Mtetra
.697 .686 .836 r
.33947 .28349 .3405 .28503 .34219 .28429 .34117 .28262 Mtetra
.649 .651 .838 r
.34117 .28262 .34219 .28429 .34388 .28365 .34286 .28202 Mtetra
.511 .592 .872 r
.34286 .28202 .34388 .28365 .34557 .28313 .34451 .28202 Mtetra
0 .155 .659 r
.34451 .28202 .34557 .28313 .34725 .28277 .3461 .28329 Mtetra
.84 .431 .267 r
.3461 .28329 .34725 .28277 .34889 .28293 .34757 .28664 Mtetra
.953 .678 .478 r
.34757 .28664 .34889 .28293 .35045 .28474 .33797 .48587 Mtetra
.537 .303 .508 r
.33797 .48587 .35045 .28474 .34099 .48473 .3393 .49379 Mtetra
.605 .315 .449 r
.3393 .49379 .34099 .48473 .34216 .49573 .34094 .49624 Mtetra
.555 .02 0 r
.34094 .49624 .34216 .49573 .34382 .49796 .34268 .49706 Mtetra
.563 .773 .977 r
.34268 .49706 .34382 .49796 .34561 .49774 .34448 .49671 Mtetra
.675 .782 .93 r
.34448 .49671 .34561 .49774 .34744 .49695 .3463 .496 Mtetra
.679 .799 .939 r
.3463 .496 .34744 .49695 .34927 .49604 .34812 .49527 Mtetra
.551 .799 .991 r
.34812 .49527 .34927 .49604 .35108 .49552 .34993 .49491 Mtetra
.626 .858 .986 r
.34993 .49491 .35108 .49552 .3529 .49491 .35175 .49429 Mtetra
.791 .881 .912 r
.35175 .49429 .3529 .49491 .35473 .49407 .35361 .493 Mtetra
.888 .785 .741 r
.35361 .493 .35473 .49407 .35659 .49278 .35555 .48995 Mtetra
.852 .662 .645 r
.35555 .48995 .35659 .49278 .35845 .49134 .35761 .48476 Mtetra
.855 .613 .572 r
.35761 .48476 .35845 .49134 .3603 .49018 .36007 .47127 Mtetra
.528 .325 .55 r
.36007 .47127 .3603 .49018 .3621 .49006 .36186 .47127 Mtetra
.457 .271 .539 r
.36186 .47127 .3621 .49006 .36393 .48953 .36351 .47398 Mtetra
.943 .67 .492 r
.36351 .47398 .36393 .48953 .36582 .48749 .37428 .28843 Mtetra
.552 .32 .517 r
.37428 .28843 .36582 .48749 .36832 .47282 .37662 .27506 Mtetra
.532 .304 .514 r
.37662 .27506 .36832 .47282 .37946 .27378 .37849 .27102 Mtetra
.756 .614 .701 r
.37849 .27102 .37946 .27378 .38131 .27012 .38028 .2688 Mtetra
.674 .714 .879 r
.38028 .2688 .38131 .27012 .38304 .26918 .382 .2681 Mtetra
.582 .727 .943 r
.382 .2681 .38304 .26918 .38474 .26881 .3837 .26778 Mtetra
.543 .723 .957 r
.3837 .26778 .38474 .26881 .38644 .26863 .3854 .26755 Mtetra
.654 .753 .923 r
.3854 .26755 .38644 .26863 .38816 .26805 .38712 .26697 Mtetra
.669 .757 .916 r
.38712 .26697 .38816 .26805 .38987 .26745 .38884 .26632 Mtetra
.692 .755 .9 r
.38884 .26632 .38987 .26745 .39159 .26679 .39056 .26556 Mtetra
.738 .749 .861 r
.39056 .26556 .39159 .26679 .39332 .26599 .3923 .26451 Mtetra
.692 .696 .85 r
.3923 .26451 .39332 .26599 .39505 .26526 .39403 .26369 Mtetra
.582 .638 .872 r
.39403 .26369 .39505 .26526 .39677 .26472 .39574 .26341 Mtetra
0 .13 .661 r
.39574 .26341 .39677 .26472 .39847 .26471 .39738 .26489 Mtetra
.858 .436 .218 r
.39738 .26489 .39847 .26471 .40016 .26485 .39894 .26841 Mtetra
.958 .678 .463 r
.39894 .26841 .40016 .26485 .40186 .26495 .39289 .46127 Mtetra
.531 .298 .506 r
.39289 .46127 .40186 .26495 .40359 .26439 .39452 .46582 Mtetra
.517 .286 .504 r
.39452 .46582 .40359 .26439 .40532 .26364 .39644 .46343 Mtetra
0 0 .297 r
.39644 .46343 .40532 .26364 .40706 .26278 .40508 .28621 Mtetra
.162 0 .377 r
.40508 .28621 .40706 .26278 .40881 .26159 .40731 .27283 Mtetra
.461 .199 .43 r
.40731 .27283 .40881 .26159 .41055 .26091 .40908 .27159 Mtetra
.949 .666 .469 r
.40908 .27159 .41055 .26091 .41224 .26132 .40394 .45741 Mtetra
.548 .311 .509 r
.40394 .45741 .41224 .26132 .41359 .27138 .40528 .47071 Mtetra
.528 .296 .506 r
.40528 .47071 .41359 .27138 .40817 .4732 .40699 .47412 Mtetra
.675 .204 .127 r
.40699 .47412 .40817 .4732 .40989 .47649 .40878 .47562 Mtetra
.526 .77 .986 r
.40878 .47562 .40989 .47649 .41173 .47643 .41062 .47535 Mtetra
.659 .772 .933 r
.41062 .47535 .41173 .47643 .41359 .47574 .41249 .47469 Mtetra
.692 .788 .924 r
.41249 .47469 .41359 .47574 .41546 .47476 .41436 .47388 Mtetra
.581 .789 .978 r
.41436 .47388 .41546 .47476 .41732 .47425 .41621 .47346 Mtetra
.567 .805 .989 r
.41621 .47346 .41732 .47425 .41918 .47373 .41807 .47305 Mtetra
.561 .826 .995 r
.41807 .47305 .41918 .47373 .42105 .4732 .41993 .47261 Mtetra
.592 .857 .994 r
.41993 .47261 .42105 .4732 .42291 .47262 .4218 .47205 Mtetra
.601 .866 .993 r
.4218 .47205 .42291 .47262 .42478 .47201 .42367 .47146 Mtetra
.607 .87 .992 r
.42367 .47146 .42478 .47201 .42665 .4714 .42554 .47085 Mtetra
.593 .865 .994 r
.42554 .47085 .42665 .4714 .42852 .4708 .42741 .47027 Mtetra
.598 .872 .993 r
.42741 .47027 .42852 .4708 .43039 .47019 .42928 .46967 Mtetra
.611 .879 .991 r
.42928 .46967 .43039 .47019 .43226 .46955 .43116 .46903 Mtetra
.563 .861 .996 r
.43116 .46903 .43226 .46955 .43414 .46896 .43303 .46851 Mtetra
.631 .899 .986 r
.43303 .46851 .43414 .46896 .43602 .46828 .43491 .46778 Mtetra
.749 .913 .948 r
.43491 .46778 .43602 .46828 .4379 .46746 .4368 .46667 Mtetra
.885 .844 .799 r
.4368 .46667 .4379 .46746 .43978 .46662 .43873 .46429 Mtetra
.85 .685 .677 r
.43873 .46429 .43978 .46662 .44168 .46534 .44069 .46033 Mtetra
.876 .636 .572 r
.44069 .46033 .44168 .46534 .4436 .46314 .44285 .44855 Mtetra
.953 .673 .469 r
.44285 .44855 .4436 .46314 .44569 .45372 .4496 .24881 Mtetra
.532 .303 .514 r
.4496 .24881 .44569 .45372 .45241 .24817 .45145 .24458 Mtetra
.731 .57 .672 r
.45145 .24458 .45241 .24817 .45426 .24367 .45325 .24219 Mtetra
.722 .711 .84 r
.45325 .24219 .45426 .24367 .45603 .24239 .45503 .24115 Mtetra
.652 .728 .905 r
.45503 .24115 .45603 .24239 .45779 .24181 .45679 .24056 Mtetra
.594 .704 .919 r
.45679 .24056 .45779 .24181 .45955 .24157 .45854 .2402 Mtetra
.621 .692 .895 r
.45854 .2402 .45955 .24157 .46131 .24105 .46031 .23974 Mtetra
.624 .703 .902 r
.46031 .23974 .46131 .24105 .46307 .24051 .46207 .23927 Mtetra
.635 .72 .909 r
.46207 .23927 .46307 .24051 .46484 .23995 .46383 .23875 Mtetra
.731 .759 .875 r
.46383 .23875 .46484 .23995 .46661 .23916 .46561 .23774 Mtetra
.706 .716 .856 r
.46561 .23774 .46661 .23916 .46838 .23839 .46738 .23683 Mtetra
.641 .67 .862 r
.46738 .23683 .46838 .23839 .47015 .23774 .46915 .23627 Mtetra
.228 .466 .879 r
.46915 .23627 .47015 .23774 .47192 .23722 .4709 .23696 Mtetra
.758 .243 0 r
.4709 .23696 .47192 .23722 .47368 .23708 .47263 .23911 Mtetra
.879 .531 .386 r
.47263 .23911 .47368 .23708 .47544 .23772 .47426 .24736 Mtetra
.957 .668 .447 r
.47426 .24736 .47544 .23772 .47711 .24364 .47283 .44819 Mtetra
.528 .296 .506 r
.47283 .44819 .47711 .24364 .47579 .44972 .47467 .45183 Mtetra
.634 .226 .252 r
.47467 .45183 .47579 .44972 .47762 .45389 .47654 .45327 Mtetra
.446 .792 .998 r
.47654 .45327 .47762 .45389 .47951 .45415 .47844 .45304 Mtetra
.691 .781 .92 r
.47844 .45304 .47951 .45415 .48142 .45343 .48035 .45222 Mtetra
.728 .773 .888 r
.48035 .45222 .48142 .45343 .48334 .45232 .48227 .45117 Mtetra
.56 .728 .953 r
.48227 .45117 .48334 .45232 .48525 .45177 .48417 .45087 Mtetra
.532 .771 .985 r
.48417 .45087 .48525 .45177 .48716 .45129 .48608 .45057 Mtetra
.642 .849 .979 r
.48608 .45057 .48716 .45129 .48907 .45069 .488 .44989 Mtetra
.864 .858 .833 r
.488 .44989 .48907 .45069 .49098 .44997 .48993 .44786 Mtetra
.855 .703 .693 r
.48993 .44786 .49098 .44997 .4929 .44884 .49187 .44426 Mtetra
.858 .629 .591 r
.49187 .44426 .4929 .44884 .49483 .44692 .49386 .43574 Mtetra
.961 .677 .45 r
.49386 .43574 .49483 .44692 .4968 .44045 .49758 .23302 Mtetra
.533 .304 .514 r
.49758 .23302 .4968 .44045 .50037 .23272 .49941 .22821 Mtetra
.711 .534 .649 r
.49941 .22821 .50037 .23272 .5022 .22714 .50122 .22565 Mtetra
.74 .719 .832 r
.50122 .22565 .5022 .22714 .504 .22549 .50301 .22447 Mtetra
.656 .776 .937 r
.50301 .22447 .504 .22549 .5058 .22486 .50481 .22385 Mtetra
.59 .754 .956 r
.50481 .22385 .5058 .22486 .50759 .2246 .5066 .22345 Mtetra
.696 .763 .903 r
.5066 .22345 .50759 .2246 .50938 .22398 .5084 .22265 Mtetra
.691 .728 .879 r
.5084 .22265 .50938 .22398 .51118 .22326 .5102 .22184 Mtetra
.624 .688 .89 r
.5102 .22184 .51118 .22326 .51298 .22264 .512 .22136 Mtetra
.243 .516 .91 r
.512 .22136 .51298 .22264 .51478 .22204 .51379 .22193 Mtetra
.737 .213 0 r
.51379 .22193 .51478 .22204 .51658 .22176 .51559 .22395 Mtetra
.869 .513 .374 r
.51559 .22395 .51658 .22176 .51838 .2222 .51737 .2316 Mtetra
.961 .667 .432 r
.51737 .2316 .51838 .2222 .52017 .22701 .5188 .43293 Mtetra
.529 .296 .506 r
.5188 .43293 .52017 .22701 .52179 .43408 .52073 .43677 Mtetra
.63 .242 .29 r
.52073 .43677 .52179 .43408 .52372 .43874 .52267 .43831 Mtetra
.149 .653 .905 r
.52267 .43831 .52372 .43874 .52565 .43941 .5246 .43844 Mtetra
.649 .801 .956 r
.5246 .43844 .52565 .43941 .52759 .4388 .52654 .43778 Mtetra
.768 .821 .895 r
.52654 .43778 .52759 .4388 .52953 .43765 .52849 .43652 Mtetra
.85 .81 .81 r
.52849 .43652 .52953 .43765 .53148 .43672 .53043 .43441 Mtetra
.842 .689 .693 r
.53043 .43441 .53148 .43672 .53342 .43565 .53236 .43093 Mtetra
.848 .621 .594 r
.53236 .43093 .53342 .43565 .53536 .43384 .53429 .42307 Mtetra
.965 .676 .437 r
.53429 .42307 .53536 .43384 .53728 .42794 .53551 .21915 Mtetra
.533 .304 .514 r
.53551 .21915 .53728 .42794 .53831 .21922 .53732 .21405 Mtetra
.699 .515 .635 r
.53732 .21405 .53831 .21922 .5401 .2133 .53912 .21136 Mtetra
.721 .662 .791 r
.53912 .21136 .5401 .2133 .54191 .21142 .54094 .21013 Mtetra
.628 .716 .91 r
.54094 .21013 .54191 .21142 .54373 .21078 .54276 .20963 Mtetra
.549 .708 .945 r
.54276 .20963 .54373 .21078 .54555 .21056 .54458 .20939 Mtetra
.658 .749 .917 r
.54458 .20939 .54555 .21056 .54737 .21006 .5464 .20875 Mtetra
.69 .736 .886 r
.5464 .20875 .54737 .21006 .5492 .20935 .54823 .20794 Mtetra
.633 .697 .891 r
.54823 .20794 .5492 .20935 .55102 .20873 .55005 .20741 Mtetra
.335 .563 .921 r
.55005 .20741 .55102 .20873 .55285 .20814 .55189 .2078 Mtetra
.662 .111 0 r
.55189 .2078 .55285 .20814 .55467 .2078 .55374 .20959 Mtetra
.854 .476 .333 r
.55374 .20959 .55467 .2078 .55651 .20813 .55563 .21547 Mtetra
.966 .669 .414 r
.55563 .21547 .55651 .20813 .55839 .21188 .55965 .41872 Mtetra
.53 .296 .506 r
.55965 .41872 .55839 .21188 .56265 .41963 .56167 .42313 Mtetra
.627 .261 .331 r
.56167 .42313 .56265 .41963 .56469 .42511 .56367 .42486 Mtetra
0 .53 .769 r
.56367 .42486 .56469 .42511 .56667 .42612 .56564 .42514 Mtetra
.627 .795 .963 r
.56564 .42514 .56667 .42612 .56864 .42559 .56762 .42455 Mtetra
.754 .82 .904 r
.56762 .42455 .56864 .42559 .57061 .4245 .56958 .42337 Mtetra
.842 .815 .823 r
.56958 .42337 .57061 .4245 .57257 .42352 .57153 .42139 Mtetra
.845 .704 .707 r
.57153 .42139 .57257 .42352 .57454 .42253 .57347 .41816 Mtetra
.836 .619 .609 r
.57347 .41816 .57454 .42253 .5765 .42089 .57535 .41177 Mtetra
.969 .677 .42 r
.57535 .41177 .5765 .42089 .57841 .41627 .57401 .20724 Mtetra
.535 .306 .514 r
.57401 .20724 .57841 .41627 .57682 .20787 .57577 .20115 Mtetra
.677 .479 .611 r
.57577 .20115 .57682 .20787 .57854 .20016 .57757 .19821 Mtetra
.749 .675 .778 r
.57757 .19821 .57854 .20016 .58035 .19781 .5794 .1967 Mtetra
.677 .772 .922 r
.5794 .1967 .58035 .19781 .5822 .19702 .58124 .19597 Mtetra
.607 .759 .952 r
.58124 .19597 .5822 .19702 .58405 .19667 .58309 .19551 Mtetra
.67 .76 .918 r
.58309 .19551 .58405 .19667 .5859 .19616 .58494 .19481 Mtetra
.702 .737 .878 r
.58494 .19481 .5859 .19616 .58774 .19538 .58679 .19393 Mtetra
.648 .698 .882 r
.58679 .19393 .58774 .19538 .58959 .19469 .58864 .19331 Mtetra
.422 .601 .921 r
.58864 .19331 .58959 .19469 .59144 .19404 .59051 .19351 Mtetra
.525 0 0 r
.59051 .19351 .59144 .19404 .5933 .19359 .59241 .19503 Mtetra
.83 .424 .278 r
.59241 .19503 .5933 .19359 .59517 .19373 .59438 .19944 Mtetra
.969 .668 .396 r
.59438 .19944 .59517 .19373 .5971 .19632 .60106 .40288 Mtetra
.531 .298 .506 r
.60106 .40288 .5971 .19632 .60405 .403 .6032 .4084 Mtetra
.615 .284 .386 r
.6032 .4084 .60405 .403 .60625 .41069 .60526 .41044 Mtetra
.34 0 0 r
.60526 .41044 .60625 .41069 .60831 .41251 .60729 .41128 Mtetra
.45 .665 .954 r
.60729 .41128 .60831 .41251 .61032 .41251 .60931 .41132 Mtetra
.689 .778 .919 r
.60931 .41132 .61032 .41251 .61231 .41147 .61131 .41047 Mtetra
.918 .831 .744 r
.61131 .41047 .61231 .41147 .61424 .40816 .61324 .40732 Mtetra
.983 .731 .474 r
.61324 .40732 .61424 .40816 .61575 .39009 .61478 .39015 Mtetra
.978 .685 .389 r
.61478 .39015 .61575 .39009 .61192 .18835 .61098 .18688 Mtetra
.886 .764 .722 r
.61098 .18688 .61192 .18835 .61372 .18528 .61277 .18382 Mtetra
.664 .706 .879 r
.61277 .18382 .61372 .18528 .61558 .1845 .61464 .18312 Mtetra
.518 .652 .919 r
.61464 .18312 .61558 .1845 .61746 .18431 .61652 .18303 Mtetra
.521 .673 .933 r
.61652 .18303 .61746 .18431 .61935 .18411 .61841 .18289 Mtetra
.638 .74 .923 r
.61841 .18289 .61935 .18411 .62122 .18353 .62029 .18233 Mtetra
.652 .746 .919 r
.62029 .18233 .62122 .18353 .6231 .18292 .62216 .1817 Mtetra
.664 .748 .913 r
.62216 .1817 .6231 .18292 .62497 .18225 .62403 .18102 Mtetra
.676 .752 .908 r
.62403 .18102 .62497 .18225 .62684 .1815 .62591 .18027 Mtetra
.688 .758 .905 r
.62591 .18027 .62684 .1815 .62871 .1807 .62778 .17947 Mtetra
.745 .775 .877 r
.62778 .17947 .62871 .1807 .63057 .17964 .62964 .17835 Mtetra
.771 .772 .854 r
.62964 .17835 .63057 .17964 .63243 .17841 .6315 .17702 Mtetra
.683 .727 .883 r
.6315 .17702 .63243 .17841 .63431 .1777 .63337 .17622 Mtetra
.171 .432 .866 r
.63337 .17622 .63431 .1777 .63625 .1787 .63531 .17713 Mtetra
.9 .523 .072 r
.63531 .17713 .63625 .1787 .63849 .18753 .63751 .18506 Mtetra
.976 .674 .357 r
.63751 .18506 .63849 .18753 .6484 .39581 .6474 .39446 Mtetra
.601 .154 0 r
.6474 .39446 .6484 .39581 .65057 .39877 .64958 .39756 Mtetra
.42 .654 .956 r
.64958 .39756 .65057 .39877 .65262 .39887 .65163 .39766 Mtetra
.725 .79 .904 r
.65163 .39766 .65262 .39887 .65464 .39784 .65365 .39661 Mtetra
.904 .809 .744 r
.65365 .39661 .65464 .39784 .65658 .39487 .65558 .39353 Mtetra
.979 .731 .49 r
.65558 .39353 .65658 .39487 .65814 .38297 .65706 .37939 Mtetra
.976 .678 .378 r
.65706 .37939 .65814 .38297 .6514 .17469 .65046 .17296 Mtetra
.886 .741 .697 r
.65046 .17296 .6514 .17469 .65317 .17107 .65224 .16951 Mtetra
.677 .698 .862 r
.65224 .16951 .65317 .17107 .65505 .17018 .65412 .16871 Mtetra
.547 .653 .904 r
.65412 .16871 .65505 .17018 .65697 .1699 .65604 .16852 Mtetra
.523 .658 .921 r
.65604 .16852 .65697 .1699 .65888 .16968 .65796 .16841 Mtetra
.649 .735 .912 r
.65796 .16841 .65888 .16968 .66078 .16901 .65986 .16778 Mtetra
.666 .752 .914 r
.65986 .16778 .66078 .16901 .66268 .16829 .66176 .16708 Mtetra
.723 .775 .894 r
.66176 .16708 .66268 .16829 .66456 .16735 .66365 .16609 Mtetra
.774 .782 .859 r
.66365 .16609 .66456 .16735 .66644 .16611 .66552 .16475 Mtetra
.689 .736 .887 r
.66552 .16475 .66644 .16611 .66834 .16536 .66741 .16392 Mtetra
.251 .49 .891 r
.66741 .16392 .66834 .16536 .67031 .1661 .66938 .16462 Mtetra
.899 .52 .07 r
.66938 .16462 .67031 .1661 .67264 .17412 .67173 .17294 Mtetra
.975 .669 .344 r
.67173 .17294 .67264 .17412 .68506 .38383 .68411 .383 Mtetra
.7 .206 0 r
.68411 .383 .68506 .38383 .68731 .38705 .68635 .3861 Mtetra
.487 .749 .987 r
.68635 .3861 .68731 .38705 .6894 .38707 .68843 .3859 Mtetra
.736 .804 .906 r
.68843 .3859 .6894 .38707 .69144 .38605 .69047 .38478 Mtetra
.832 .809 .828 r
.69047 .38478 .69144 .38605 .69341 .38365 .69246 .38285 Mtetra
.926 .876 .767 r
.69246 .38285 .69341 .38365 .69517 .37746 .6944 .37995 Mtetra
0 0 0 r
.6944 .37995 .69517 .37746 .68591 .16674 .69622 .37478 Mtetra
0 0 .378 r
.69622 .37478 .68591 .16674 .68754 .16068 .68722 .17018 Mtetra
0 0 .297 r
.68722 .17018 .68754 .16068 .6894 .15889 .68869 .16113 Mtetra
0 0 0 r
.68869 .16113 .6894 .15889 .69129 .15781 .69045 .15769 Mtetra
.866 .991 .825 r
.69045 .15769 .69129 .15781 .69321 .15705 .6923 .15572 Mtetra
.697 .746 .89 r
.6923 .15572 .69321 .15705 .69513 .15632 .69421 .15485 Mtetra
.634 .697 .891 r
.69421 .15485 .69513 .15632 .69705 .15567 .69614 .15428 Mtetra
.643 .715 .9 r
.69614 .15428 .69705 .15567 .69897 .15492 .69807 .15367 Mtetra
.746 .78 .88 r
.69807 .15367 .69897 .15492 .70087 .15375 .69997 .15253 Mtetra
.705 .772 .904 r
.69997 .15253 .70087 .15375 .70278 .15295 .70188 .15163 Mtetra
.571 .695 .925 r
.70188 .15163 .70278 .15295 .70476 .15312 .70383 .15132 Mtetra
.174 .377 .823 r
.70383 .15132 .70476 .15312 .70697 .157 .70588 .1525 Mtetra
.13 .156 .62 r
.70588 .1525 .70697 .157 .72189 .3665 .70806 .15586 Mtetra
0 0 .396 r
.70806 .15586 .72189 .3665 .72438 .37252 .72276 .36057 Mtetra
.186 .108 .529 r
.72276 .36057 .72438 .37252 .72655 .37329 .72537 .36849 Mtetra
.283 .26 .656 r
.72537 .36849 .72655 .37329 .72867 .3732 .72765 .37092 Mtetra
.329 .436 .819 r
.72765 .37092 .72867 .3732 .73077 .37277 .72984 .37184 Mtetra
.466 .744 .989 r
.72984 .37184 .73077 .37277 .73289 .37259 .73196 .37168 Mtetra
.657 .837 .969 r
.73196 .37168 .73289 .37259 .73498 .37188 .73405 .37091 Mtetra
.795 .863 .9 r
.73405 .37091 .73498 .37188 .737 .37017 .73609 .36945 Mtetra
.927 .899 .779 r
.73609 .36945 .737 .37017 .73877 .36472 .73804 .36667 Mtetra
.677 .75 .254 r
.73804 .36667 .73877 .36472 .72661 .1538 .73984 .36174 Mtetra
0 0 .391 r
.73984 .36174 .72661 .1538 .72807 .14604 .728 .15663 Mtetra
0 0 .31 r
.728 .15663 .72807 .14604 .72993 .14399 .72927 .14601 Mtetra
0 0 0 r
.72927 .14601 .72993 .14399 .73183 .14274 .73101 .1424 Mtetra
.895 .967 .826 r
.73101 .1424 .73183 .14274 .73377 .14191 .73286 .1403 Mtetra
.675 .697 .862 r
.73286 .1403 .73377 .14191 .73572 .14118 .7348 .13949 Mtetra
.608 .652 .868 r
.7348 .13949 .73572 .14118 .73767 .14059 .73677 .13904 Mtetra
.589 .665 .891 r
.73677 .13904 .73767 .14059 .73963 .13999 .73875 .13868 Mtetra
.729 .766 .882 r
.73875 .13868 .73963 .13999 .74155 .13886 .74067 .13761 Mtetra
.699 .768 .905 r
.74067 .13761 .74155 .13886 .74349 .13805 .74261 .13673 Mtetra
.594 .709 .924 r
.74261 .13673 .74349 .13805 .7455 .13798 .74459 .13632 Mtetra
.059 .321 .803 r
.74459 .13632 .7455 .13798 .74778 .14161 .74671 .13776 Mtetra
.021 .108 .616 r
.74671 .13776 .74778 .14161 .76571 .35139 .749 .14139 Mtetra
.01 0 .412 r
.749 .14139 .76571 .35139 .76839 .35816 .76635 .34247 Mtetra
.515 .325 .561 r
.76635 .34247 .76839 .35816 .77055 .35814 .76855 .34303 Mtetra
.586 .376 .563 r
.76855 .34303 .77055 .35814 .77265 .3573 .77053 .34066 Mtetra
.474 .294 .556 r
.77053 .34066 .77265 .3573 .77474 .35625 .77286 .34289 Mtetra
.208 .12 .531 r
.77286 .34289 .77474 .35625 .77693 .35652 .77571 .35153 Mtetra
.226 .219 .641 r
.77571 .35153 .77693 .35652 .77912 .35674 .77813 .35462 Mtetra
.181 .36 .807 r
.77813 .35462 .77912 .35674 .7813 .35674 .78042 .35604 Mtetra
.484 .811 1 r
.78042 .35604 .7813 .35674 .78344 .35616 .78258 .35569 Mtetra
.587 .906 .981 r
.78258 .35569 .78344 .35616 .78556 .35541 .7847 .35492 Mtetra
.667 .932 .97 r
.7847 .35492 .78556 .35541 .78767 .35457 .7868 .35392 Mtetra
.655 .683 .865 r
.11072 .57079 .11188 .57224 .11355 .57166 .11238 .57019 Mtetra
.661 .683 .86 r
.11238 .57019 .11355 .57166 .11522 .57104 .11406 .56956 Mtetra
.668 .684 .856 r
.11406 .56956 .11522 .57104 .1169 .57037 .11574 .56889 Mtetra
.681 .688 .85 r
.11574 .56889 .1169 .57037 .11859 .56958 .11743 .56814 Mtetra
.689 .696 .851 r
.11743 .56814 .11859 .56958 .12029 .56872 .11912 .56734 Mtetra
.696 .708 .857 r
.11912 .56734 .12029 .56872 .122 .56782 .12082 .56652 Mtetra
.702 .722 .865 r
.12082 .56652 .122 .56782 .12372 .56686 .12252 .56568 Mtetra
.705 .742 .88 r
.12252 .56568 .12372 .56686 .12543 .56591 .12422 .56486 Mtetra
.704 .764 .899 r
.12422 .56486 .12543 .56591 .12715 .56498 .12592 .56406 Mtetra
.69 .786 .924 r
.12592 .56406 .12715 .56498 .12884 .5642 .12761 .56334 Mtetra
.671 .795 .941 r
.12761 .56334 .12884 .5642 .13053 .56353 .1293 .56269 Mtetra
.646 .796 .954 r
.1293 .56269 .13053 .56353 .1322 .56297 .13097 .56214 Mtetra
.601 .786 .97 r
.13097 .56214 .1322 .56297 .13386 .56252 .13263 .56172 Mtetra
.571 .783 .979 r
.13263 .56172 .13386 .56252 .13552 .56217 .13428 .56137 Mtetra
.553 .779 .983 r
.13428 .56137 .13552 .56217 .13716 .56189 .13593 .56107 Mtetra
.198 .606 .947 r
.13593 .56107 .13716 .56189 .13873 .56231 .13751 .56135 Mtetra
.494 .722 .973 r
.13751 .56135 .13873 .56231 .14034 .56229 .13914 .56122 Mtetra
.728 .767 .884 r
.13914 .56122 .14034 .56229 .14206 .56141 .14086 .56028 Mtetra
.904 .734 .661 r
.14086 .56028 .14206 .56141 .14432 .55574 .1431 .55478 Mtetra
.939 .687 .529 r
.1431 .55478 .14432 .55574 .1689 .35098 .16772 .35049 Mtetra
.932 .758 .643 r
.16772 .35049 .1689 .35098 .17109 .34502 .16993 .34431 Mtetra
.809 .822 .861 r
.16993 .34431 .17109 .34502 .17275 .34373 .1716 .34294 Mtetra
.605 .785 .967 r
.1716 .34294 .17275 .34373 .17431 .34341 .17317 .34253 Mtetra
.422 .698 .978 r
.17317 .34253 .17431 .34341 .17582 .34352 .17469 .34254 Mtetra
.624 .75 .937 r
.17469 .34254 .17582 .34352 .17738 .34315 .17626 .34211 Mtetra
.658 .744 .914 r
.17626 .34211 .17738 .34315 .17896 .34264 .17785 .34155 Mtetra
.666 .738 .904 r
.17785 .34155 .17896 .34264 .18055 .34205 .17944 .34096 Mtetra
.744 .753 .86 r
.17944 .34096 .18055 .34205 .18218 .34109 .18108 .33994 Mtetra
.711 .737 .872 r
.18108 .33994 .18218 .34109 .1838 .34023 .18269 .33912 Mtetra
.578 .706 .929 r
.18269 .33912 .1838 .34023 .18538 .33973 .18425 .33884 Mtetra
.831 .361 0 r
.18425 .33884 .18538 .33973 .18683 .34049 .18553 .34115 Mtetra
.94 .681 .516 r
.18553 .34115 .18683 .34049 .18811 .34288 .16652 .53353 Mtetra
.555 .319 .512 r
.16652 .53353 .18811 .34288 .18828 .35577 .16648 .54927 Mtetra
.526 .294 .506 r
.16648 .54927 .18828 .35577 .1695 .54851 .16788 .55147 Mtetra
.53 .166 .294 r
.16788 .55147 .1695 .54851 .17082 .55154 .16948 .5519 Mtetra
.396 .85 .789 r
.16948 .5519 .17082 .55154 .17239 .55226 .1712 .55118 Mtetra
.893 .752 .699 r
.1712 .55118 .17239 .55226 .17438 .54893 .17326 .54719 Mtetra
.942 .687 .523 r
.17326 .54719 .17438 .54893 .19637 .35223 .19585 .34547 Mtetra
.818 .589 .592 r
.19585 .34547 .19637 .35223 .19958 .3361 .19849 .33488 Mtetra
.823 .743 .776 r
.19849 .33488 .19958 .3361 .20134 .33402 .20023 .33291 Mtetra
.678 .74 .897 r
.20023 .33291 .20134 .33402 .20295 .33335 .20184 .33226 Mtetra
.555 .705 .94 r
.20184 .33226 .20295 .33335 .20452 .3331 .20341 .33204 Mtetra
.735 .76 .873 r
.20341 .33204 .20452 .3331 .20617 .33207 .20505 .33109 Mtetra
.733 .775 .887 r
.20505 .33109 .20617 .33207 .20781 .33107 .20669 .33018 Mtetra
.571 .753 .964 r
.20669 .33018 .20781 .33107 .2094 .33069 .20827 .32988 Mtetra
.863 .413 .073 r
.20827 .32988 .2094 .33069 .2107 .33321 .20955 .33255 Mtetra
.945 .683 .51 r
.20955 .33255 .2107 .33321 .19232 .53433 .19103 .5344 Mtetra
.918 .594 .414 r
.19103 .5344 .19232 .53433 .19304 .5438 .19184 .54285 Mtetra
.543 .009 0 r
.19184 .54285 .19304 .5438 .19455 .54528 .19336 .54426 Mtetra
.549 .732 .96 r
.19336 .54426 .19455 .54528 .19624 .54505 .19505 .54402 Mtetra
.778 .782 .856 r
.19505 .54402 .19624 .54505 .19803 .54374 .19684 .5427 Mtetra
.899 .756 .694 r
.19684 .5427 .19803 .54374 .20009 .53959 .19891 .53854 Mtetra
.945 .688 .517 r
.19891 .53854 .20009 .53959 .22119 .33736 .22009 .33618 Mtetra
.927 .716 .597 r
.22009 .33618 .22119 .33736 .22371 .32731 .22262 .32621 Mtetra
.841 .761 .774 r
.22262 .32621 .22371 .32731 .22548 .32517 .22438 .32408 Mtetra
.678 .744 .901 r
.22438 .32408 .22548 .32517 .2271 .32452 .226 .32343 Mtetra
.543 .701 .942 r
.226 .32343 .2271 .32452 .22868 .32433 .22758 .32324 Mtetra
.702 .751 .89 r
.22758 .32324 .22868 .32433 .23032 .32356 .22922 .32247 Mtetra
.718 .754 .881 r
.22922 .32247 .23032 .32356 .23196 .3227 .23087 .32161 Mtetra
.573 .713 .937 r
.23087 .32161 .23196 .3227 .23355 .32242 .23246 .32134 Mtetra
.818 .353 0 r
.23246 .32134 .23355 .32242 .23489 .3249 .2338 .32382 Mtetra
.948 .684 .504 r
.2338 .32382 .23489 .3249 .21798 .52658 .2168 .52557 Mtetra
.947 .619 .376 r
.2168 .52557 .21798 .52658 .21886 .53533 .21768 .5343 Mtetra
.578 .057 0 r
.21768 .5343 .21886 .53533 .22039 .53692 .21921 .53589 Mtetra
.523 .721 .964 r
.21921 .53589 .22039 .53692 .22209 .53674 .22091 .53571 Mtetra
.766 .784 .868 r
.22091 .53571 .22209 .53674 .22388 .53553 .2227 .5345 Mtetra
.894 .764 .71 r
.2227 .5345 .22388 .53553 .2259 .53184 .22472 .5308 Mtetra
.948 .689 .512 r
.22472 .5308 .2259 .53184 .24503 .33497 .24392 .33397 Mtetra
.941 .711 .563 r
.24392 .33397 .24503 .33497 .24802 .31902 .24693 .31794 Mtetra
.857 .763 .757 r
.24693 .31794 .24802 .31902 .24981 .31659 .24872 .3155 Mtetra
.669 .745 .907 r
.24872 .3155 .24981 .31659 .25145 .31597 .25036 .31488 Mtetra
.496 .685 .951 r
.25036 .31488 .25145 .31597 .25304 .31588 .25195 .31481 Mtetra
.549 .709 .946 r
.25195 .31481 .25304 .31588 .25464 .31565 .25355 .3146 Mtetra
.63 .741 .927 r
.25355 .3146 .25464 .31565 .25627 .31516 .25517 .31413 Mtetra
.641 .749 .927 r
.25517 .31413 .25627 .31516 .2579 .31461 .2568 .31362 Mtetra
.672 .765 .921 r
.2568 .31362 .2579 .31461 .25955 .31391 .25845 .31299 Mtetra
.695 .787 .922 r
.25845 .31299 .25955 .31391 .26121 .31308 .2601 .31227 Mtetra
.702 .81 .933 r
.2601 .31227 .26121 .31308 .26287 .31224 .26175 .31152 Mtetra
.693 .829 .948 r
.26175 .31152 .26287 .31224 .26452 .31148 .2634 .3108 Mtetra
.682 .837 .958 r
.2634 .3108 .26452 .31148 .26617 .31079 .26505 .31012 Mtetra
.679 .837 .96 r
.26505 .31012 .26617 .31079 .26782 .31013 .2667 .30944 Mtetra
.679 .835 .958 r
.2667 .30944 .26782 .31013 .26947 .30947 .26835 .30877 Mtetra
.679 .831 .957 r
.26835 .30877 .26947 .30947 .27111 .30882 .27 .3081 Mtetra
.675 .827 .956 r
.27 .3081 .27111 .30882 .27276 .30819 .27165 .30744 Mtetra
.663 .817 .957 r
.27165 .30744 .27276 .30819 .2744 .30766 .2733 .30683 Mtetra
.656 .797 .95 r
.2733 .30683 .2744 .30766 .27604 .3072 .27495 .30625 Mtetra
.663 .773 .931 r
.27495 .30625 .27604 .3072 .27768 .30671 .2766 .30565 Mtetra
.682 .756 .907 r
.2766 .30565 .27768 .30671 .27933 .30606 .27825 .30497 Mtetra
.697 .754 .896 r
.27825 .30497 .27933 .30606 .281 .30525 .27992 .30422 Mtetra
.698 .765 .903 r
.27992 .30422 .281 .30525 .28267 .30443 .28158 .30346 Mtetra
.731 .784 .895 r
.28158 .30346 .28267 .30443 .28434 .30356 .28326 .30255 Mtetra
.728 .776 .891 r
.28326 .30255 .28434 .30356 .28601 .30274 .28494 .30164 Mtetra
.628 .733 .923 r
.28494 .30164 .28601 .30274 .28766 .30223 .28658 .30118 Mtetra
0 .232 .717 r
.28658 .30118 .28766 .30223 .28925 .30249 .28811 .30223 Mtetra
.917 .553 .323 r
.28811 .30223 .28925 .30249 .29075 .30407 .28931 .30778 Mtetra
.947 .678 .494 r
.28931 .30778 .29075 .30407 .29202 .30859 .27572 .51115 Mtetra
.529 .296 .506 r
.27572 .51115 .29202 .30859 .27887 .50858 .27718 .51479 Mtetra
.539 .234 .399 r
.27718 .51479 .27887 .50858 .2802 .51391 .27886 .51539 Mtetra
.374 0 .029 r
.27886 .51539 .2802 .51391 .28179 .5159 .2806 .5153 Mtetra
.543 .828 .998 r
.2806 .5153 .28179 .5159 .28348 .51641 .28236 .51491 Mtetra
.632 .68 .877 r
.28236 .51491 .28348 .51641 .28525 .51598 .28413 .51439 Mtetra
.655 .676 .858 r
.28413 .51439 .28525 .51598 .28703 .51523 .28591 .51375 Mtetra
.616 .677 .885 r
.28591 .51375 .28703 .51523 .28881 .5146 .28768 .51331 Mtetra
.566 .69 .923 r
.28768 .51331 .28881 .5146 .29058 .51421 .28943 .51305 Mtetra
.677 .751 .907 r
.28943 .51305 .29058 .51421 .29236 .51354 .29122 .51233 Mtetra
.843 .767 .778 r
.29122 .51233 .29236 .51354 .29421 .51197 .29312 .51007 Mtetra
.903 .706 .627 r
.29312 .51007 .29421 .51197 .29618 .50872 .29534 .50316 Mtetra
.95 .684 .498 r
.29534 .50316 .29618 .50872 .29831 .50301 .31111 .29828 Mtetra
.532 .304 .514 r
.31111 .29828 .29831 .50301 .3008 .49191 .31304 .29392 Mtetra
.524 .297 .512 r
.31304 .29392 .3008 .49191 .30249 .49257 .31473 .29306 Mtetra
.523 .296 .512 r
.31473 .29306 .30249 .49257 .30415 .49367 .31639 .29279 Mtetra
.524 .297 .512 r
.31639 .29279 .30415 .49367 .31849 .30297 .31806 .29214 Mtetra
.586 .388 .58 r
.31806 .29214 .31849 .30297 .32069 .2945 .3198 .29066 Mtetra
.663 .519 .678 r
.3198 .29066 .32069 .2945 .32256 .29088 .32153 .28929 Mtetra
.719 .686 .817 r
.32153 .28929 .32256 .29088 .32432 .28895 .32323 .28824 Mtetra
.67 .833 .962 r
.32323 .28824 .32432 .28895 .32601 .28818 .32492 .28758 Mtetra
.619 .848 .986 r
.32492 .28758 .32601 .28818 .32768 .28773 .32659 .28705 Mtetra
.615 .827 .981 r
.32659 .28705 .32768 .28773 .32935 .28738 .32827 .28655 Mtetra
.638 .797 .959 r
.32827 .28655 .32935 .28738 .33102 .28696 .32995 .28601 Mtetra
.648 .775 .941 r
.32995 .28601 .33102 .28696 .33269 .28652 .33163 .28546 Mtetra
.668 .756 .917 r
.33163 .28546 .33269 .28652 .33437 .28595 .33331 .28483 Mtetra
.69 .752 .898 r
.33331 .28483 .33437 .28595 .33607 .28517 .33501 .28409 Mtetra
.695 .761 .903 r
.33501 .28409 .33607 .28517 .33777 .28435 .3367 .28333 Mtetra
.717 .778 .901 r
.3367 .28333 .33777 .28435 .33947 .28349 .33841 .28247 Mtetra
.737 .782 .889 r
.33841 .28247 .33947 .28349 .34117 .28262 .34012 .2815 Mtetra
.656 .741 .913 r
.34012 .2815 .34117 .28262 .34286 .28202 .3418 .28092 Mtetra
.179 .516 .916 r
.3418 .28092 .34286 .28202 .34451 .28202 .34343 .28144 Mtetra
.9 .487 .188 r
.34343 .28144 .34451 .28202 .3461 .28329 .34485 .28546 Mtetra
.955 .681 .477 r
.34485 .28546 .3461 .28329 .34757 .28664 .3348 .48964 Mtetra
.532 .299 .507 r
.3348 .48964 .34757 .28664 .33797 .48587 .33626 .49511 Mtetra
.544 .26 .434 r
.33626 .49511 .33797 .48587 .3393 .49379 .33799 .49593 Mtetra
.443 .033 .166 r
.33799 .49593 .3393 .49379 .34094 .49624 .33977 .49594 Mtetra
.429 .84 .97 r
.33977 .49594 .34094 .49624 .34268 .49706 .34157 .49557 Mtetra
.624 .682 .885 r
.34157 .49557 .34268 .49706 .34448 .49671 .34338 .49509 Mtetra
.65 .672 .858 r
.34338 .49509 .34448 .49671 .3463 .496 .34519 .49446 Mtetra
.635 .679 .874 r
.34519 .49446 .3463 .496 .34812 .49527 .34701 .49391 Mtetra
.55 .675 .921 r
.34701 .49391 .34812 .49527 .34993 .49491 .34881 .49371 Mtetra
.652 .742 .916 r
.34881 .49371 .34993 .49491 .35175 .49429 .35063 .49309 Mtetra
.811 .775 .819 r
.35063 .49309 .35175 .49429 .35361 .493 .35251 .49135 Mtetra
.907 .724 .643 r
.35251 .49135 .35361 .493 .35555 .48995 .3546 .48555 Mtetra
.957 .686 .482 r
.3546 .48555 .35555 .48995 .35761 .48476 .36687 .27969 Mtetra
.536 .307 .514 r
.36687 .27969 .35761 .48476 .36007 .47127 .36886 .27371 Mtetra
.525 .298 .513 r
.36886 .27371 .36007 .47127 .36186 .47127 .37059 .2727 Mtetra
.523 .296 .512 r
.37059 .2727 .36186 .47127 .36351 .47398 .37228 .27237 Mtetra
.37228 .27237 .36351 .47398 .37428 .28843 .37398 .27198 Mtetra
.565 .357 .557 r
.37398 .27198 .37428 .28843 .37662 .27506 .37574 .2705 Mtetra
.647 .491 .658 r
.37574 .2705 .37662 .27506 .37849 .27102 .37749 .2691 Mtetra
.711 .65 .787 r
.37749 .2691 .37849 .27102 .38028 .2688 .37923 .26798 Mtetra
.652 .81 .959 r
.37923 .26798 .38028 .2688 .382 .2681 .38094 .26738 Mtetra
.602 .817 .983 r
.38094 .26738 .382 .2681 .3837 .26778 .38265 .26691 Mtetra
.611 .787 .966 r
.38265 .26691 .3837 .26778 .3854 .26755 .38436 .26646 Mtetra
.667 .754 .916 r
.38436 .26646 .3854 .26755 .38712 .26697 .38608 .26582 Mtetra
.675 .746 .904 r
.38608 .26582 .38712 .26697 .38884 .26632 .3878 .26514 Mtetra
.694 .746 .892 r
.3878 .26514 .38884 .26632 .39056 .26556 .38953 .26437 Mtetra
.748 .758 .86 r
.38953 .26437 .39056 .26556 .3923 .26451 .39127 .26326 Mtetra
.686 .731 .884 r
.39127 .26326 .3923 .26451 .39403 .26369 .393 .26251 Mtetra
.427 .638 .944 r
.393 .26251 .39403 .26369 .39574 .26341 .39469 .26262 Mtetra
.883 .451 .095 r
.39469 .26262 .39574 .26341 .39738 .26489 .39624 .26637 Mtetra
.96 .681 .461 r
.39624 .26637 .39738 .26489 .39894 .26841 .38953 .47103 Mtetra
.533 .3 .507 r
.38953 .47103 .39894 .26841 .39289 .46127 .3911 .47719 Mtetra
.516 .256 .459 r
.3911 .47719 .39289 .46127 .39452 .46582 .39292 .47727 Mtetra
.479 .212 .431 r
.39292 .47727 .39452 .46582 .39644 .46343 .39478 .47646 Mtetra
.469 .209 .437 r
.39478 .47646 .39644 .46343 .40508 .28621 .39665 .47522 Mtetra
.52 .288 .504 r
.39665 .47522 .40508 .28621 .40731 .27283 .39851 .47443 Mtetra
.52 .289 .504 r
.39851 .47443 .40731 .27283 .40908 .27159 .40036 .47376 Mtetra
.521 .289 .504 r
.40036 .47376 .40908 .27159 .40394 .45741 .40221 .47339 Mtetra
.524 .262 .461 r
.40221 .47339 .40394 .45741 .40528 .47071 .40403 .47376 Mtetra
.509 .14 .275 r
.40403 .47376 .40528 .47071 .40699 .47412 .40585 .47408 Mtetra
.05 0 0 r
.40585 .47408 .40699 .47412 .40878 .47562 .40768 .47418 Mtetra
.621 .692 .895 r
.40768 .47418 .40878 .47562 .41062 .47535 .40954 .47369 Mtetra
.645 .671 .86 r
.40954 .47369 .41062 .47535 .41249 .47469 .4114 .47307 Mtetra
.654 .68 .862 r
.4114 .47307 .41249 .47469 .41436 .47388 .41327 .47241 Mtetra
.622 .689 .892 r
.41327 .47241 .41436 .47388 .41621 .47346 .41513 .47192 Mtetra
.619 .677 .883 r
.41513 .47192 .41621 .47346 .41807 .47305 .41699 .47144 Mtetra
.621 .669 .874 r
.41699 .47144 .41807 .47305 .41993 .47261 .41885 .47095 Mtetra
.634 .666 .864 r
.41885 .47095 .41993 .47261 .4218 .47205 .42072 .47039 Mtetra
.637 .668 .863 r
.42072 .47039 .4218 .47205 .42367 .47146 .42259 .46981 Mtetra
.64 .671 .864 r
.42259 .46981 .42367 .47146 .42554 .47085 .42446 .46922 Mtetra
.636 .672 .868 r
.42446 .46922 .42554 .47085 .42741 .47027 .42633 .46865 Mtetra
.64 .675 .867 r
.42633 .46865 .42741 .47027 .42928 .46967 .4282 .46806 Mtetra
.645 .678 .867 r
.4282 .46806 .42928 .46967 .43116 .46903 .43008 .46744 Mtetra
.578 .653 .888 r
.43008 .46744 .43116 .46903 .43303 .46851 .43194 .46715 Mtetra
.648 .719 .9 r
.43194 .46715 .43303 .46851 .43491 .46778 .43382 .46653 Mtetra
.756 .77 .864 r
.43382 .46653 .43491 .46778 .4368 .46667 .43572 .4653 Mtetra
.908 .757 .681 r
.43572 .4653 .4368 .46667 .43873 .46429 .43769 .46097 Mtetra
.965 .687 .458 r
.43769 .46097 .43873 .46429 .44069 .46033 .44473 .26178 Mtetra
.557 .323 .517 r
.44473 .26178 .44069 .46033 .44285 .44855 .44689 .24592 Mtetra
.528 .3 .513 r
.44689 .24592 .44285 .44855 .4496 .24881 .44869 .2435 Mtetra
.63 .466 .642 r
.44869 .2435 .4496 .24881 .45145 .24458 .45047 .24213 Mtetra
.662 .586 .76 r
.45047 .24213 .45145 .24458 .45325 .24219 .45224 .24124 Mtetra
.691 .797 .93 r
.45224 .24124 .45325 .24219 .45503 .24115 .454 .24048 Mtetra
.637 .845 .98 r
.454 .24048 .45503 .24115 .45679 .24056 .45577 .23987 Mtetra
.607 .833 .986 r
.45577 .23987 .45679 .24056 .45854 .2402 .45753 .23936 Mtetra
.64 .807 .963 r
.45753 .23936 .45854 .2402 .46031 .23974 .45929 .23878 Mtetra
.649 .784 .946 r
.45929 .23878 .46031 .23974 .46207 .23927 .46106 .23819 Mtetra
.657 .762 .927 r
.46106 .23819 .46207 .23927 .46383 .23875 .46283 .23758 Mtetra
.747 .769 .871 r
.46283 .23758 .46383 .23875 .46561 .23774 .46461 .23648 Mtetra
.707 .742 .879 r
.46461 .23648 .46561 .23774 .46738 .23683 .46638 .2356 Mtetra
.583 .703 .925 r
.46638 .2356 .46738 .23683 .46915 .23627 .46815 .23528 Mtetra
.681 .188 0 r
.46815 .23528 .46915 .23627 .4709 .23696 .46987 .2376 Mtetra
.967 .68 .434 r
.46987 .2376 .4709 .23696 .47263 .23911 .46842 .42184 Mtetra
.578 .335 .512 r
.46842 .42184 .47263 .23911 .47426 .24736 .46981 .45049 Mtetra
.524 .292 .505 r
.46981 .45049 .47426 .24736 .47283 .44819 .47168 .45213 Mtetra
.505 .161 .317 r
.47168 .45213 .47283 .44819 .47467 .45183 .47357 .45236 Mtetra
.052 0 0 r
.47357 .45236 .47467 .45183 .47654 .45327 .47547 .45204 Mtetra
.632 .74 .926 r
.47547 .45204 .47654 .45327 .47844 .45304 .47738 .45148 Mtetra
.663 .697 .872 r
.47738 .45148 .47844 .45304 .48035 .45222 .47929 .45077 Mtetra
.678 .718 .88 r
.47929 .45077 .48035 .45222 .48227 .45117 .4812 .44998 Mtetra
.52 .701 .952 r
.4812 .44998 .48227 .45117 .48417 .45087 .4831 .44981 Mtetra
.56 .746 .964 r
.4831 .44981 .48417 .45087 .48608 .45057 .48501 .44948 Mtetra
.711 .793 .915 r
.48501 .44948 .48608 .45057 .488 .44989 .48693 .44856 Mtetra
.902 .77 .706 r
.48693 .44856 .488 .44989 .48993 .44786 .48888 .44486 Mtetra
.933 .688 .544 r
.48888 .44486 .48993 .44786 .49187 .44426 .49094 .43066 Mtetra
.958 .674 .454 r
.49094 .43066 .49187 .44426 .49386 .43574 .49482 .22917 Mtetra
.528 .3 .513 r
.49482 .22917 .49386 .43574 .49758 .23302 .49664 .22636 Mtetra
.61 .434 .619 r
.49664 .22636 .49758 .23302 .49941 .22821 .49843 .22502 Mtetra
.633 .528 .717 r
.49843 .22502 .49941 .22821 .50122 .22565 .50023 .22418 Mtetra
.672 .699 .866 r
.50023 .22418 .50122 .22565 .50301 .22447 .50202 .22345 Mtetra
.655 .777 .938 r
.50202 .22345 .50301 .22447 .50481 .22385 .50382 .22283 Mtetra
.635 .771 .945 r
.50382 .22283 .50481 .22385 .5066 .22345 .50561 .22228 Mtetra
.728 .769 .885 r
.50561 .22228 .5066 .22345 .5084 .22265 .50741 .2213 Mtetra
.702 .73 .872 r
.50741 .2213 .5084 .22265 .5102 .22184 .50921 .22043 Mtetra
.591 .675 .898 r
.50921 .22043 .5102 .22184 .512 .22136 .51101 .22008 Mtetra
0 0 .515 r
.51101 .22008 .512 .22136 .51379 .22193 .5128 .22214 Mtetra
.955 .631 .37 r
.5128 .22214 .51379 .22193 .51559 .22395 .51454 .24123 Mtetra
.95 .655 .445 r
.51454 .24123 .51559 .22395 .51737 .2316 .51581 .43533 Mtetra
.525 .293 .505 r
.51581 .43533 .51737 .2316 .5188 .43293 .51774 .43729 Mtetra
.51 .174 .333 r
.51774 .43729 .5188 .43293 .52073 .43677 .51968 .43756 Mtetra
.167 0 0 r
.51968 .43756 .52073 .43677 .52267 .43831 .52161 .43725 Mtetra
.529 .737 .97 r
.52161 .43725 .52267 .43831 .5246 .43844 .52355 .43701 Mtetra
.624 .704 .903 r
.52355 .43701 .5246 .43844 .52654 .43778 .52549 .43649 Mtetra
.743 .768 .874 r
.52549 .43649 .52654 .43778 .52849 .43652 .52744 .43532 Mtetra
.908 .791 .719 r
.52744 .43532 .52849 .43652 .53043 .43441 .52938 .43183 Mtetra
.939 .699 .547 r
.52938 .43183 .53043 .43441 .53236 .43093 .5313 .41952 Mtetra
.964 .676 .438 r
.5313 .41952 .53236 .43093 .53429 .42307 .53271 .21568 Mtetra
.529 .301 .513 r
.53271 .21568 .53429 .42307 .53551 .21915 .53452 .21245 Mtetra
.616 .438 .618 r
.53452 .21245 .53551 .21915 .53732 .21405 .53633 .21095 Mtetra
.646 .541 .721 r
.53633 .21095 .53732 .21405 .53912 .21136 .53815 .21 Mtetra
.67 .718 .885 r
.53815 .21 .53912 .21136 .54094 .21013 .53997 .20929 Mtetra
.626 .809 .97 r
.53997 .20929 .54094 .21013 .54276 .20963 .54179 .20874 Mtetra
.599 .789 .971 r
.54179 .20874 .54276 .20963 .54458 .20939 .54361 .20828 Mtetra
.707 .778 .907 r
.54361 .20828 .54458 .20939 .5464 .20875 .54543 .20741 Mtetra
.706 .736 .875 r
.54543 .20741 .5464 .20875 .54823 .20794 .54725 .20651 Mtetra
.609 .682 .894 r
.54725 .20651 .54823 .20794 .55005 .20741 .54908 .20608 Mtetra
0 .166 .694 r
.54908 .20608 .55005 .20741 .55189 .2078 .55093 .20768 Mtetra
.937 .572 .28 r
.55093 .20768 .55189 .2078 .55374 .20959 .55285 .21691 Mtetra
.966 .669 .415 r
.55285 .21691 .55374 .20959 .55563 .21547 .55669 .42132 Mtetra
.526 .293 .505 r
.55669 .42132 .55563 .21547 .55965 .41872 .55869 .42383 Mtetra
.52 .196 .358 r
.55869 .42383 .55965 .41872 .56167 .42313 .56066 .4242 Mtetra
.262 0 0 r
.56066 .4242 .56167 .42313 .56367 .42486 .56264 .42395 Mtetra
.516 .767 .988 r
.56264 .42395 .56367 .42486 .56564 .42514 .56461 .42368 Mtetra
.609 .695 .905 r
.56461 .42368 .56564 .42514 .56762 .42455 .56658 .42322 Mtetra
.726 .761 .88 r
.56658 .42322 .56762 .42455 .56958 .42337 .56855 .42215 Mtetra
.896 .798 .744 r
.56855 .42215 .56958 .42337 .57153 .42139 .57049 .4191 Mtetra
.936 .71 .571 r
.57049 .4191 .57153 .42139 .57347 .41816 .57233 .4099 Mtetra
.969 .678 .419 r
.57233 .4099 .57347 .41816 .57535 .41177 .57114 .20259 Mtetra
.53 .302 .513 r
.57114 .20259 .57535 .41177 .57401 .20724 .57294 .19881 Mtetra
.6 .411 .598 r
.57294 .19881 .57401 .20724 .57577 .20115 .57477 .19729 Mtetra
.627 .5 .688 r
.57477 .19729 .57577 .20115 .57757 .19821 .5766 .19634 Mtetra
.661 .646 .824 r
.5766 .19634 .57757 .19821 .5794 .1967 .57845 .19559 Mtetra
.663 .768 .928 r
.57845 .19559 .5794 .1967 .58124 .19597 .58029 .19492 Mtetra
.641 .772 .943 r
.58029 .19492 .58124 .19597 .58309 .19551 .58214 .19434 Mtetra
.708 .77 .901 r
.58214 .19434 .58309 .19551 .58494 .19481 .58399 .19346 Mtetra
.719 .741 .869 r
.58399 .19346 .58494 .19481 .58679 .19393 .58583 .19247 Mtetra
.632 .691 .887 r
.58583 .19247 .58679 .19393 .58864 .19331 .58768 .19194 Mtetra
.01 .341 .821 r
.58768 .19194 .58864 .19331 .59051 .19351 .58957 .19309 Mtetra
.916 .516 .177 r
.58957 .19309 .59051 .19351 .59241 .19503 .59159 .19963 Mtetra
.97 .67 .394 r
.59159 .19963 .59241 .19503 .59438 .19944 .59816 .40678 Mtetra
.527 .294 .505 r
.59816 .40678 .59438 .19944 .60106 .40288 .60024 .40993 Mtetra
.522 .221 .397 r
.60024 .40993 .60106 .40288 .6032 .4084 .60226 .41033 Mtetra
.375 0 .095 r
.60226 .41033 .6032 .4084 .60526 .41044 .60427 .41008 Mtetra
.286 .757 .939 r
.60427 .41008 .60526 .41044 .60729 .41128 .60628 .40992 Mtetra
.518 .674 .935 r
.60628 .40992 .60729 .41128 .60931 .41132 .60829 .40979 Mtetra
.678 .717 .878 r
.60829 .40979 .60931 .41132 .61131 .41047 .61029 .40897 Mtetra
.882 .771 .734 r
.61029 .40897 .61131 .41047 .61324 .40732 .61222 .40588 Mtetra
.975 .723 .489 r
.61222 .40588 .61324 .40732 .61478 .39015 .61379 .3896 Mtetra
.977 .684 .39 r
.61379 .3896 .61478 .39015 .61098 .18688 .61004 .18594 Mtetra
.924 .827 .732 r
.61004 .18594 .61098 .18688 .61277 .18382 .61184 .18283 Mtetra
.686 .802 .937 r
.61184 .18283 .61277 .18382 .61464 .18312 .6137 .18205 Mtetra
.52 .718 .963 r
.6137 .18205 .61464 .18312 .61652 .18303 .61559 .18186 Mtetra
.536 .705 .948 r
.61559 .18186 .61652 .18303 .61841 .18289 .61747 .18165 Mtetra
.643 .736 .916 r
.61747 .18165 .61841 .18289 .62029 .18233 .61935 .18106 Mtetra
.652 .736 .911 r
.61935 .18106 .62029 .18233 .62216 .1817 .62122 .18043 Mtetra
.664 .74 .907 r
.62122 .18043 .62216 .1817 .62403 .18102 .6231 .17975 Mtetra
.677 .745 .902 r
.6231 .17975 .62403 .18102 .62591 .18027 .62497 .179 Mtetra
.685 .746 .898 r
.62497 .179 .62591 .18027 .62778 .17947 .62684 .17821 Mtetra
.735 .765 .877 r
.62684 .17821 .62778 .17947 .62964 .17835 .62871 .17713 Mtetra
.764 .783 .869 r
.62871 .17713 .62964 .17835 .6315 .17702 .63057 .17589 Mtetra
.672 .771 .924 r
.63057 .17589 .6315 .17702 .63337 .17622 .63245 .17517 Mtetra
0 .38 .837 r
.63245 .17517 .63337 .17622 .63531 .17713 .63439 .17616 Mtetra
.927 .549 .16 r
.63439 .17616 .63531 .17713 .63751 .18506 .63662 .18491 Mtetra
.975 .672 .363 r
.63662 .18491 .63751 .18506 .6474 .39446 .64642 .39335 Mtetra
.642 .167 0 r
.64642 .39335 .6474 .39446 .64958 .39756 .64858 .39631 Mtetra
.435 .656 .953 r
.64858 .39631 .64958 .39756 .65163 .39766 .65064 .39639 Mtetra
.724 .779 .896 r
.65064 .39639 .65163 .39766 .65365 .39661 .65266 .39533 Mtetra
.899 .803 .745 r
.65266 .39533 .65365 .39661 .65558 .39353 .65459 .39227 Mtetra
.98 .737 .496 r
.65459 .39227 .65558 .39353 .65706 .37939 .65612 .37915 Mtetra
.978 .681 .371 r
.65612 .37915 .65706 .37939 .65046 .17296 .64955 .17194 Mtetra
.936 .818 .704 r
.64955 .17194 .65046 .17296 .65224 .16951 .65132 .16841 Mtetra
.702 .79 .919 r
.65132 .16841 .65224 .16951 .65412 .16871 .65321 .16755 Mtetra
.55 .714 .948 r
.65321 .16755 .65412 .16871 .65604 .16852 .65512 .16729 Mtetra
.53 .689 .94 r
.65512 .16729 .65604 .16852 .65796 .16841 .65704 .16711 Mtetra
.648 .731 .91 r
.65704 .16711 .65796 .16841 .65986 .16778 .65894 .16649 Mtetra
.658 .736 .907 r
.65894 .16649 .65986 .16778 .66176 .16708 .66084 .16582 Mtetra
.708 .761 .894 r
.66084 .16582 .66176 .16708 .66365 .16609 .66273 .16491 Mtetra
.764 .793 .876 r
.66273 .16491 .66365 .16609 .66552 .16475 .66461 .16367 Mtetra
.676 .785 .932 r
.66461 .16367 .66552 .16475 .66741 .16392 .66651 .16292 Mtetra
.07 .464 .886 r
.66651 .16292 .66741 .16392 .66938 .16462 .66848 .1637 Mtetra
.921 .538 .139 r
.66848 .1637 .66938 .16462 .67173 .17294 .67085 .17248 Mtetra
.975 .668 .345 r
.67085 .17248 .67173 .17294 .68411 .383 .68313 .38162 Mtetra
0 0 .441 r
.68313 .38162 .68411 .383 .68635 .3861 .68537 .38462 Mtetra
.557 .676 .918 r
.68537 .38462 .68635 .3861 .68843 .3859 .68744 .38435 Mtetra
.708 .732 .869 r
.68744 .38435 .68843 .3859 .69047 .38478 .68948 .38332 Mtetra
.751 .761 .861 r
.68948 .38332 .69047 .38478 .69246 .38285 .69151 .38202 Mtetra
.704 .865 .958 r
.69151 .38202 .69246 .38285 .6944 .37995 .69356 .38106 Mtetra
0 0 0 r
.69356 .38106 .6944 .37995 .69622 .37478 .69558 .37956 Mtetra
.171 0 .253 r
.69558 .37956 .69622 .37478 .68722 .17018 .69751 .37644 Mtetra
.472 .253 .5 r
.69751 .37644 .68722 .17018 .68869 .16113 .69817 .35018 Mtetra
0 0 .369 r
.69817 .35018 .68869 .16113 .69045 .15769 .68963 .15791 Mtetra
.956 .944 .64 r
.68963 .15791 .69045 .15769 .6923 .15572 .69139 .15439 Mtetra
.723 .756 .878 r
.69139 .15439 .6923 .15572 .69421 .15485 .6933 .15336 Mtetra
.619 .687 .892 r
.6933 .15336 .69421 .15485 .69614 .15428 .69523 .15286 Mtetra
.595 .688 .907 r
.69523 .15286 .69614 .15428 .69807 .15367 .69717 .15247 Mtetra
.706 .775 .905 r
.69717 .15247 .69807 .15367 .69997 .15253 .69909 .15156 Mtetra
.691 .82 .944 r
.69909 .15156 .69997 .15253 .70188 .15163 .70101 .15074 Mtetra
.647 .822 .967 r
.70101 .15074 .70188 .15163 .70383 .15132 .70294 .15007 Mtetra
.604 .726 .931 r
.70294 .15007 .70383 .15132 .70588 .1525 .70488 .14962 Mtetra
.522 .487 .758 r
.70488 .14962 .70588 .1525 .70806 .15586 .70686 .1497 Mtetra
.426 .318 .628 r
.70686 .1497 .70806 .15586 .72276 .36057 .70893 .1512 Mtetra
0 0 .398 r
.70893 .1512 .72276 .36057 .72537 .36849 .72357 .35356 Mtetra
0 0 .46 r
.72357 .35356 .72537 .36849 .72765 .37092 .72658 .36771 Mtetra
.09 .201 .686 r
.72658 .36771 .72765 .37092 .72984 .37184 .72887 .37031 Mtetra
.527 .655 .916 r
.72887 .37031 .72984 .37184 .73196 .37168 .73099 .37017 Mtetra
.675 .728 .89 r
.73099 .37017 .73196 .37168 .73405 .37091 .73308 .36933 Mtetra
.734 .741 .857 r
.73308 .36933 .73405 .37091 .73609 .36945 .73513 .36811 Mtetra
.711 .772 .9 r
.73513 .36811 .73609 .36945 .73804 .36667 .7372 .36709 Mtetra
.544 .896 .673 r
.7372 .36709 .73804 .36667 .73984 .36174 .73924 .36552 Mtetra
.102 0 .19 r
.73924 .36552 .73984 .36174 .728 .15663 .74118 .36256 Mtetra
.482 .261 .501 r
.74118 .36256 .728 .15663 .72927 .14601 .74187 .34139 Mtetra
0 0 .384 r
.74187 .34139 .72927 .14601 .73101 .1424 .73026 .14297 Mtetra
.914 .928 .551 r
.73026 .14297 .73101 .1424 .73286 .1403 .73199 .13919 Mtetra
.734 .806 .908 r
.73199 .13919 .73286 .1403 .7348 .13949 .73392 .13814 Mtetra
.613 .711 .915 r
.73392 .13814 .7348 .13949 .73677 .13904 .73588 .13765 Mtetra
.559 .678 .919 r
.73588 .13765 .73677 .13904 .73875 .13868 .73787 .13739 Mtetra
.688 .757 .904 r
.73787 .13739 .73875 .13868 .74067 .13761 .73981 .13656 Mtetra
.677 .801 .941 r
.73981 .13656 .74067 .13761 .74261 .13673 .74176 .13579 Mtetra
.628 .807 .969 r
.74176 .13579 .74261 .13673 .74459 .13632 .74372 .13519 Mtetra
.463 .683 .961 r
.74372 .13519 .74459 .13632 .74671 .13776 .74573 .13517 Mtetra
.503 .496 .782 r
.74573 .13517 .74671 .13776 .749 .14139 .74776 .13534 Mtetra
.523 .386 .635 r
.74776 .13534 .749 .14139 .76635 .34247 .74979 .13552 Mtetra
.525 .298 .512 r
.74979 .13552 .76635 .34247 .76855 .34303 .75172 .13437 Mtetra
.524 .297 .512 r
.75172 .13437 .76855 .34303 .77053 .34066 .75367 .13354 Mtetra
.522 .296 .512 r
.75367 .13354 .77053 .34066 .77286 .34289 .75571 .13371 Mtetra
.492 .274 .51 r
.75571 .13371 .77286 .34289 .77571 .35153 .75894 .14905 Mtetra
0 0 .407 r
.75894 .14905 .77571 .35153 .77813 .35462 .77702 .35107 Mtetra
.054 .158 .656 r
.77702 .35107 .77813 .35462 .78042 .35604 .77946 .35425 Mtetra
.539 .623 .884 r
.77946 .35425 .78042 .35604 .78258 .35569 .78163 .35411 Mtetra
.666 .717 .886 r
.78163 .35411 .78258 .35569 .7847 .35492 .78374 .35331 Mtetra
.721 .736 .863 r
.78374 .35331 .7847 .35492 .7868 .35392 .78584 .35215 Mtetra
.612 .5 .702 r
.10981 .56723 .11072 .57079 .11238 .57019 .11148 .56658 Mtetra
.614 .5 .699 r
.11148 .56658 .11238 .57019 .11406 .56956 .11316 .56589 Mtetra
.617 .499 .697 r
.11316 .56589 .11406 .56956 .11574 .56889 .11485 .56517 Mtetra
.631 .506 .693 r
.11485 .56517 .11574 .56889 .11743 .56814 .11655 .56427 Mtetra
.622 .496 .688 r
.11655 .56427 .11743 .56814 .11912 .56734 .11825 .56344 Mtetra
.604 .483 .688 r
.11825 .56344 .11912 .56734 .12082 .56652 .11993 .5628 Mtetra
.525 .438 .7 r
.11993 .5628 .12082 .56652 .12252 .56568 .12152 .56289 Mtetra
.506 .475 .757 r
.12152 .56289 .12252 .56568 .12422 .56486 .1231 .56304 Mtetra
.506 .571 .855 r
.1231 .56304 .12422 .56486 .12592 .56406 .12471 .56307 Mtetra
.63 .761 .941 r
.12471 .56307 .12592 .56406 .12761 .56334 .12637 .56259 Mtetra
.66 .818 .959 r
.12637 .56259 .12761 .56334 .1293 .56269 .12805 .56197 Mtetra
.666 .825 .96 r
.12805 .56197 .1293 .56269 .13097 .56214 .12973 .56134 Mtetra
.561 .781 .981 r
.12973 .56134 .13097 .56214 .13263 .56172 .13138 .56101 Mtetra
.553 .8 .99 r
.13138 .56101 .13263 .56172 .13428 .56137 .13303 .56067 Mtetra
.605 .817 .982 r
.13303 .56067 .13428 .56137 .13593 .56107 .1347 .56021 Mtetra
.628 .789 .959 r
.1347 .56021 .13593 .56107 .13751 .56135 .13637 .55971 Mtetra
.702 .677 .823 r
.13637 .55971 .13751 .56135 .13914 .56122 .13809 .55877 Mtetra
.742 .624 .728 r
.13809 .55877 .13914 .56122 .14086 .56028 .13992 .55695 Mtetra
.859 .65 .619 r
.13992 .55695 .14086 .56028 .1431 .55478 .14245 .54887 Mtetra
.934 .681 .531 r
.14245 .54887 .1431 .55478 .16772 .35049 .16675 .34805 Mtetra
.84 .659 .657 r
.16675 .34805 .16772 .35049 .16993 .34431 .16879 .34347 Mtetra
.791 .8 .86 r
.16879 .34347 .16993 .34431 .1716 .34294 .17045 .34219 Mtetra
.631 .802 .965 r
.17045 .34219 .1716 .34294 .17317 .34253 .17203 .34171 Mtetra
.499 .741 .981 r
.17203 .34171 .17317 .34253 .17469 .34254 .17356 .34155 Mtetra
.663 .757 .92 r
.17356 .34155 .17469 .34254 .17626 .34211 .17515 .34098 Mtetra
.671 .732 .896 r
.17515 .34098 .17626 .34211 .17785 .34155 .17674 .34037 Mtetra
.646 .714 .897 r
.17674 .34037 .17785 .34155 .17944 .34096 .17833 .33985 Mtetra
.646 .729 .91 r
.17833 .33985 .17944 .34096 .18108 .33994 .17991 .33935 Mtetra
.45 .777 .998 r
.17991 .33935 .18108 .33994 .18269 .33912 .18145 .33918 Mtetra
.478 0 0 r
.18145 .33918 .18269 .33912 .18425 .33884 .18292 .33979 Mtetra
.876 .545 .42 r
.18292 .33979 .18425 .33884 .18553 .34115 .18379 .34591 Mtetra
.935 .675 .519 r
.18379 .34591 .18553 .34115 .16652 .53353 .16377 .54704 Mtetra
.622 .35 .484 r
.16377 .54704 .16652 .53353 .16648 .54927 .16498 .55105 Mtetra
.58 .168 .224 r
.16498 .55105 .16648 .54927 .16788 .55147 .16654 .55183 Mtetra
0 0 0 r
.16654 .55183 .16788 .55147 .16948 .5519 .16822 .55141 Mtetra
.815 .878 .891 r
.16822 .55141 .16948 .5519 .1712 .55118 .17001 .55001 Mtetra
.895 .741 .683 r
.17001 .55001 .1712 .55118 .17326 .54719 .17213 .54551 Mtetra
.942 .687 .523 r
.17213 .54551 .17326 .54719 .19585 .34547 .19494 .34239 Mtetra
.872 .658 .609 r
.19494 .34239 .19585 .34547 .19849 .33488 .19739 .33369 Mtetra
.82 .747 .783 r
.19739 .33369 .19849 .33488 .20023 .33291 .19913 .33181 Mtetra
.674 .739 .899 r
.19913 .33181 .20023 .33291 .20184 .33226 .20074 .33117 Mtetra
.547 .701 .941 r
.20074 .33117 .20184 .33226 .20341 .33204 .2023 .33098 Mtetra
.723 .757 .88 r
.2023 .33098 .20341 .33204 .20505 .33109 .20394 .3301 Mtetra
.718 .77 .893 r
.20394 .3301 .20505 .33109 .20669 .33018 .20557 .32926 Mtetra
.541 .739 .967 r
.20557 .32926 .20669 .33018 .20827 .32988 .20714 .32904 Mtetra
.874 .433 .098 r
.20714 .32904 .20827 .32988 .20955 .33255 .2084 .33188 Mtetra
.945 .683 .51 r
.2084 .33188 .20955 .33255 .19103 .5344 .18976 .53419 Mtetra
.923 .592 .396 r
.18976 .53419 .19103 .5344 .19184 .54285 .19065 .54188 Mtetra
.51 0 0 r
.19065 .54188 .19184 .54285 .19336 .54426 .19217 .54324 Mtetra
.553 .733 .959 r
.19217 .54324 .19336 .54426 .19505 .54402 .19386 .54298 Mtetra
.778 .782 .856 r
.19386 .54298 .19505 .54402 .19684 .5427 .19565 .54166 Mtetra
.899 .756 .694 r
.19565 .54166 .19684 .5427 .19891 .53854 .19772 .5375 Mtetra
.945 .688 .517 r
.19772 .5375 .19891 .53854 .22009 .33618 .219 .33504 Mtetra
.928 .717 .598 r
.219 .33504 .22009 .33618 .22262 .32621 .22152 .32512 Mtetra
.841 .761 .774 r
.22152 .32512 .22262 .32621 .22438 .32408 .22328 .32299 Mtetra
.678 .744 .901 r
.22328 .32299 .22438 .32408 .226 .32343 .22491 .32234 Mtetra
.543 .701 .943 r
.22491 .32234 .226 .32343 .22758 .32324 .22649 .32215 Mtetra
.702 .751 .89 r
.22649 .32215 .22758 .32324 .22922 .32247 .22812 .32138 Mtetra
.718 .754 .881 r
.22812 .32138 .22922 .32247 .23087 .32161 .22977 .32052 Mtetra
.573 .713 .937 r
.22977 .32052 .23087 .32161 .23246 .32134 .23136 .32025 Mtetra
.818 .353 0 r
.23136 .32025 .23246 .32134 .2338 .32382 .2327 .32273 Mtetra
.948 .684 .504 r
.2327 .32273 .2338 .32382 .2168 .52557 .21562 .52454 Mtetra
.947 .62 .375 r
.21562 .52454 .2168 .52557 .21768 .5343 .2165 .53326 Mtetra
.577 .056 0 r
.2165 .53326 .21768 .5343 .21921 .53589 .21803 .53485 Mtetra
.523 .721 .963 r
.21803 .53485 .21921 .53589 .22091 .53571 .21973 .53467 Mtetra
.766 .784 .868 r
.21973 .53467 .22091 .53571 .2227 .5345 .22152 .53346 Mtetra
.894 .764 .71 r
.22152 .53346 .2227 .5345 .22472 .5308 .22354 .52976 Mtetra
.948 .689 .512 r
.22354 .52976 .22472 .5308 .24392 .33397 .24282 .3329 Mtetra
.94 .71 .563 r
.24282 .3329 .24392 .33397 .24693 .31794 .24584 .31684 Mtetra
.857 .762 .757 r
.24584 .31684 .24693 .31794 .24872 .3155 .24763 .31441 Mtetra
.668 .744 .907 r
.24763 .31441 .24872 .3155 .25036 .31488 .24927 .31379 Mtetra
.493 .682 .95 r
.24927 .31379 .25036 .31488 .25195 .31481 .25086 .31373 Mtetra
.546 .706 .945 r
.25086 .31373 .25195 .31481 .25355 .3146 .25246 .31352 Mtetra
.626 .736 .926 r
.25246 .31352 .25355 .3146 .25517 .31413 .25408 .31307 Mtetra
.633 .742 .926 r
.25408 .31307 .25517 .31413 .2568 .31362 .25571 .3126 Mtetra
.653 .754 .924 r
.25571 .3126 .2568 .31362 .25845 .31299 .25734 .31204 Mtetra
.67 .774 .928 r
.25734 .31204 .25845 .31299 .2601 .31227 .25899 .31142 Mtetra
.679 .798 .938 r
.25899 .31142 .2601 .31227 .26175 .31152 .26063 .31076 Mtetra
.682 .819 .949 r
.26063 .31076 .26175 .31152 .2634 .3108 .26228 .31009 Mtetra
.683 .829 .954 r
.26228 .31009 .2634 .3108 .26505 .31012 .26393 .3094 Mtetra
.686 .83 .952 r
.26393 .3094 .26505 .31012 .2667 .30944 .26558 .30871 Mtetra
.685 .825 .95 r
.26558 .30871 .2667 .30944 .26835 .30877 .26724 .30801 Mtetra
.686 .821 .948 r
.26724 .30801 .26835 .30877 .27 .3081 .26889 .30732 Mtetra
.689 .817 .944 r
.26889 .30732 .27 .3081 .27165 .30744 .27055 .30662 Mtetra
.71 .811 .928 r
.27055 .30662 .27165 .30744 .2733 .30683 .27221 .30583 Mtetra
.712 .775 .901 r
.27221 .30583 .2733 .30683 .27495 .30625 .27388 .30501 Mtetra
.683 .724 .88 r
.27388 .30501 .27495 .30625 .2766 .30565 .27554 .3043 Mtetra
.602 .677 .893 r
.27554 .3043 .2766 .30565 .27825 .30497 .27717 .30395 Mtetra
.446 .678 .963 r
.27717 .30395 .27825 .30497 .27992 .30422 .27877 .30396 Mtetra
.05 .603 .823 r
.27877 .30396 .27992 .30422 .28158 .30346 .28037 .30408 Mtetra
0 0 0 r
.28037 .30408 .28158 .30346 .28326 .30255 .28201 .30359 Mtetra
.28201 .30359 .28326 .30255 .28494 .30164 .2837 .30259 Mtetra
.11 0 0 r
.2837 .30259 .28494 .30164 .28658 .30118 .28535 .30212 Mtetra
.756 .335 .25 r
.28535 .30212 .28658 .30118 .28811 .30223 .2868 .30424 Mtetra
.949 .681 .493 r
.2868 .30424 .28811 .30223 .28931 .30778 .27312 .50649 Mtetra
.537 .303 .508 r
.27312 .50649 .28931 .30778 .27572 .51115 .27426 .51417 Mtetra
.638 .278 .344 r
.27426 .51417 .27572 .51115 .27718 .51479 .27587 .51576 Mtetra
.178 0 0 r
.27587 .51576 .27718 .51479 .27886 .51539 .27762 .51541 Mtetra
.595 .942 .93 r
.27762 .51541 .27886 .51539 .2806 .5153 .27942 .51456 Mtetra
.694 .841 .954 r
.27942 .51456 .2806 .5153 .28236 .51491 .28121 .51378 Mtetra
.628 .743 .93 r
.28121 .51378 .28236 .51491 .28413 .51439 .28298 .51328 Mtetra
.655 .754 .923 r
.28298 .51328 .28413 .51439 .28591 .51375 .28476 .51267 Mtetra
.676 .767 .919 r
.28476 .51267 .28591 .51375 .28768 .51331 .28654 .51196 Mtetra
.707 .729 .867 r
.28654 .51196 .28768 .51331 .28943 .51305 .28834 .51105 Mtetra
.744 .664 .772 r
.28834 .51105 .28943 .51305 .29122 .51233 .29019 .50953 Mtetra
.817 .646 .671 r
.29019 .50953 .29122 .51233 .29312 .51007 .2922 .50569 Mtetra
.951 .686 .498 r
.2922 .50569 .29312 .51007 .29534 .50316 .30806 .30218 Mtetra
.543 .312 .516 r
.30806 .30218 .29534 .50316 .31111 .29828 .31032 .29315 Mtetra
.701 .517 .636 r
.31032 .29315 .31111 .29828 .31304 .29392 .31213 .29045 Mtetra
.629 .509 .698 r
.31213 .29045 .31304 .29392 .31473 .29306 .31382 .28962 Mtetra
.579 .479 .705 r
.31382 .28962 .31473 .29306 .31639 .29279 .31548 .28927 Mtetra
.57 .47 .702 r
.31548 .28927 .31639 .29279 .31806 .29214 .31713 .28899 Mtetra
.6 .506 .719 r
.31713 .28899 .31806 .29214 .3198 .29066 .3188 .28849 Mtetra
.619 .581 .79 r
.3188 .28849 .3198 .29066 .32153 .28929 .32047 .288 Mtetra
.642 .704 .892 r
.32047 .288 .32153 .28929 .32323 .28824 .32215 .28748 Mtetra
.649 .816 .963 r
.32215 .28748 .32323 .28824 .32492 .28758 .32383 .2869 Mtetra
.655 .836 .969 r
.32383 .2869 .32492 .28758 .32659 .28705 .32551 .28628 Mtetra
.683 .824 .951 r
.32551 .28628 .32659 .28705 .32827 .28655 .3272 .28558 Mtetra
.703 .786 .916 r
.3272 .28558 .32827 .28655 .32995 .28601 .32889 .2848 Mtetra
.681 .733 .89 r
.32889 .2848 .32995 .28601 .33163 .28546 .33058 .2841 Mtetra
.622 .687 .89 r
.33058 .2841 .33163 .28546 .33331 .28483 .33226 .28366 Mtetra
.481 .664 .943 r
.33226 .28366 .33331 .28483 .33501 .28409 .33391 .28363 Mtetra
.186 .669 .928 r
.33391 .28363 .33501 .28409 .3367 .28333 .33555 .28373 Mtetra
.006 0 0 r
.33555 .28373 .3367 .28333 .33841 .28247 .33722 .28346 Mtetra
0 0 0 r
.33722 .28346 .33841 .28247 .34012 .2815 .33894 .28241 Mtetra
.016 0 0 r
.33894 .28241 .34012 .2815 .3418 .28092 .34063 .28179 Mtetra
.638 .165 .113 r
.34063 .28179 .3418 .28092 .34343 .28144 .34222 .2829 Mtetra
.956 .681 .477 r
.34222 .2829 .34343 .28144 .34485 .28546 .33241 .47969 Mtetra
.55 .313 .509 r
.33241 .47969 .34485 .28546 .3348 .48964 .33335 .49398 Mtetra
.656 .321 .394 r
.33335 .49398 .3348 .48964 .33626 .49511 .33499 .49632 Mtetra
.259 0 0 r
.33499 .49632 .33626 .49511 .33799 .49593 .33679 .49601 Mtetra
.57 .937 .905 r
.33679 .49601 .33799 .49593 .33977 .49594 .33862 .49513 Mtetra
.725 .836 .933 r
.33862 .49513 .33977 .49594 .34157 .49557 .34045 .49419 Mtetra
.608 .694 .905 r
.34045 .49419 .34157 .49557 .34338 .49509 .34226 .49377 Mtetra
.626 .713 .909 r
.34226 .49377 .34338 .49509 .34519 .49446 .34407 .49328 Mtetra
.657 .747 .916 r
.34407 .49328 .34519 .49446 .34701 .49391 .34589 .49264 Mtetra
.695 .742 .888 r
.34589 .49264 .34701 .49391 .34881 .49371 .34772 .49181 Mtetra
.738 .675 .789 r
.34772 .49181 .34881 .49371 .35063 .49309 .34958 .49041 Mtetra
.798 .645 .693 r
.34958 .49041 .35063 .49309 .35251 .49135 .35153 .48738 Mtetra
.957 .687 .483 r
.35153 .48738 .35251 .49135 .3546 .48555 .36355 .29005 Mtetra
.559 .326 .518 r
.36355 .29005 .3546 .48555 .36687 .27969 .36608 .27356 Mtetra
.703 .506 .618 r
.36608 .27356 .36687 .27969 .36886 .27371 .36793 .27021 Mtetra
.638 .516 .697 r
.36793 .27021 .36886 .27371 .37059 .2727 .36966 .26925 Mtetra
.586 .485 .706 r
.36966 .26925 .37059 .2727 .37228 .27237 .37136 .26884 Mtetra
.562 .467 .704 r
.37136 .26884 .37228 .27237 .37398 .27198 .37305 .26862 Mtetra
.596 .495 .71 r
.37305 .26862 .37398 .27198 .37574 .2705 .37475 .26813 Mtetra
.612 .563 .775 r
.37475 .26813 .37574 .2705 .37749 .2691 .37646 .26764 Mtetra
.634 .677 .873 r
.37646 .26764 .37749 .2691 .37923 .26798 .37817 .26713 Mtetra
.644 .801 .958 r
.37817 .26713 .37923 .26798 .38094 .26738 .37988 .26657 Mtetra
.655 .811 .958 r
.37988 .26657 .38094 .26738 .38265 .26691 .3816 .26596 Mtetra
.677 .786 .931 r
.3816 .26596 .38265 .26691 .38436 .26646 .38332 .26528 Mtetra
.704 .749 .887 r
.38332 .26528 .38436 .26646 .38608 .26582 .38505 .26445 Mtetra
.685 .71 .868 r
.38505 .26445 .38608 .26582 .3878 .26514 .38678 .26368 Mtetra
.657 .687 .867 r
.38678 .26368 .3878 .26514 .38953 .26437 .3885 .26306 Mtetra
.623 .7 .9 r
.3885 .26306 .38953 .26437 .39127 .26326 .39021 .2626 Mtetra
.328 .711 .982 r
.39021 .2626 .39127 .26326 .393 .26251 .39191 .26264 Mtetra
.651 .109 0 r
.39191 .26264 .393 .26251 .39469 .26262 .39355 .26391 Mtetra
.96 .681 .461 r
.39355 .26391 .39469 .26262 .39624 .26637 .38744 .45001 Mtetra
.573 .332 .512 r
.38744 .45001 .39624 .26637 .38953 .47103 .38817 .47584 Mtetra
.668 .337 .405 r
.38817 .47584 .38953 .47103 .3911 .47719 .38988 .47865 Mtetra
.359 0 .011 r
.38988 .47865 .3911 .47719 .39292 .47727 .39171 .47852 Mtetra
.088 0 0 r
.39171 .47852 .39292 .47727 .39478 .47646 .39357 .47778 Mtetra
0 0 0 r
.39357 .47778 .39478 .47646 .39665 .47522 .39544 .47679 Mtetra
.244 0 0 r
.39544 .47679 .39665 .47522 .39851 .47443 .39729 .47625 Mtetra
.28 0 .03 r
.39729 .47625 .39851 .47443 .40036 .47376 .39914 .47569 Mtetra
.287 0 .052 r
.39914 .47569 .40036 .47376 .40221 .47339 .401 .47511 Mtetra
.225 0 0 r
.401 .47511 .40221 .47339 .40403 .47376 .40286 .47443 Mtetra
0 0 0 r
.40286 .47443 .40403 .47376 .40585 .47408 .40472 .47373 Mtetra
.599 .905 .984 r
.40472 .47373 .40585 .47408 .40768 .47418 .40658 .47304 Mtetra
.628 .752 .936 r
.40658 .47304 .40768 .47418 .40954 .47369 .40844 .47251 Mtetra
.642 .748 .926 r
.40844 .47251 .40954 .47369 .4114 .47307 .4103 .47193 Mtetra
.675 .765 .919 r
.4103 .47193 .4114 .47307 .41327 .47241 .41217 .4712 Mtetra
.76 .775 .865 r
.41217 .4712 .41327 .47241 .41513 .47192 .41405 .46995 Mtetra
.735 .671 .787 r
.41405 .46995 .41513 .47192 .41699 .47144 .41595 .46854 Mtetra
.693 .585 .73 r
.41595 .46854 .41699 .47144 .41885 .47095 .41784 .46715 Mtetra
.612 .498 .7 r
.41784 .46715 .41885 .47095 .42072 .47039 .41971 .46641 Mtetra
.59 .479 .695 r
.41971 .46641 .42072 .47039 .42259 .46981 .42158 .46587 Mtetra
.581 .475 .697 r
.42158 .46587 .42259 .46981 .42446 .46922 .42344 .46544 Mtetra
.595 .489 .703 r
.42344 .46544 .42446 .46922 .42633 .46865 .42531 .46488 Mtetra
.596 .49 .704 r
.42531 .46488 .42633 .46865 .4282 .46806 .42718 .46431 Mtetra
.598 .492 .704 r
.42718 .46431 .4282 .46806 .43008 .46744 .42906 .46373 Mtetra
.538 .456 .711 r
.42906 .46373 .43008 .46744 .43194 .46715 .43091 .46371 Mtetra
.593 .502 .721 r
.43091 .46371 .43194 .46715 .43382 .46653 .43279 .46322 Mtetra
.68 .558 .711 r
.43279 .46322 .43382 .46653 .43572 .4653 .43469 .46181 Mtetra
.879 .658 .6 r
.43469 .46181 .43572 .4653 .43769 .46097 .43677 .45369 Mtetra
.961 .682 .462 r
.43677 .45369 .43769 .46097 .44473 .26178 .44407 .24704 Mtetra
.643 .42 .565 r
.44407 .24704 .44473 .26178 .44689 .24592 .44594 .24221 Mtetra
.653 .519 .687 r
.44594 .24221 .44689 .24592 .44869 .2435 .44771 .24099 Mtetra
.612 .555 .766 r
.44771 .24099 .44869 .2435 .45047 .24213 .44947 .24047 Mtetra
.556 .616 .868 r
.44947 .24047 .45047 .24213 .45224 .24124 .45122 .2403 Mtetra
.643 .787 .95 r
.45122 .2403 .45224 .24124 .454 .24048 .45298 .23973 Mtetra
.649 .831 .97 r
.45298 .23973 .454 .24048 .45577 .23987 .45475 .23911 Mtetra
.66 .83 .965 r
.45475 .23911 .45577 .23987 .45753 .23936 .45651 .23845 Mtetra
.706 .811 .93 r
.45651 .23845 .45753 .23936 .45929 .23878 .45828 .23763 Mtetra
.694 .757 .9 r
.45828 .23763 .45929 .23878 .46106 .23819 .46006 .23684 Mtetra
.663 .711 .884 r
.46006 .23684 .46106 .23819 .46283 .23758 .46182 .23618 Mtetra
.641 .696 .885 r
.46182 .23618 .46283 .23758 .46461 .23648 .46359 .23563 Mtetra
.481 .743 .986 r
.46359 .23563 .46461 .23648 .46638 .2356 .46535 .23548 Mtetra
.352 0 0 r
.46535 .23548 .46638 .2356 .46815 .23528 .4671 .23611 Mtetra
.889 .515 .322 r
.4671 .23611 .46815 .23528 .46987 .2376 .46875 .24227 Mtetra
.963 .675 .441 r
.46875 .24227 .46987 .2376 .46842 .42184 .46687 .44832 Mtetra
.575 .317 .488 r
.46687 .44832 .46842 .42184 .46981 .45049 .46869 .45241 Mtetra
.468 .04 .144 r
.46869 .45241 .46981 .45049 .47168 .45213 .47058 .45261 Mtetra
0 0 0 r
.47058 .45261 .47168 .45213 .47357 .45236 .47248 .45187 Mtetra
.748 .92 .949 r
.47248 .45187 .47357 .45236 .47547 .45204 .4744 .45075 Mtetra
.635 .73 .917 r
.4744 .45075 .47547 .45204 .47738 .45148 .4763 .45018 Mtetra
.618 .722 .92 r
.4763 .45018 .47738 .45148 .47929 .45077 .47821 .44969 Mtetra
.646 .775 .942 r
.47821 .44969 .47929 .45077 .4812 .44998 .48012 .44906 Mtetra
.668 .816 .954 r
.48012 .44906 .4812 .44998 .4831 .44981 .48204 .44833 Mtetra
.731 .733 .852 r
.48204 .44833 .4831 .44981 .48501 .44948 .48396 .44719 Mtetra
.766 .66 .746 r
.48396 .44719 .48501 .44948 .48693 .44856 .48589 .44521 Mtetra
.876 .66 .608 r
.48589 .44521 .48693 .44856 .48888 .44486 .48788 .43802 Mtetra
.965 .682 .446 r
.48788 .43802 .48888 .44486 .49094 .43066 .49202 .23025 Mtetra
.533 .304 .513 r
.49202 .23025 .49094 .43066 .49482 .22917 .49386 .22509 Mtetra
.665 .515 .672 r
.49386 .22509 .49482 .22917 .49664 .22636 .49566 .22356 Mtetra
.609 .535 .746 r
.49566 .22356 .49664 .22636 .49843 .22502 .49745 .22302 Mtetra
.557 .575 .828 r
.49745 .22302 .49843 .22502 .50023 .22418 .49924 .22286 Mtetra
.625 .706 .904 r
.49924 .22286 .50023 .22418 .50202 .22345 .50103 .22237 Mtetra
.659 .766 .929 r
.50103 .22237 .50202 .22345 .50382 .22283 .50283 .22174 Mtetra
.667 .766 .924 r
.50283 .22174 .50382 .22283 .50561 .22228 .50462 .22107 Mtetra
.753 .768 .865 r
.50462 .22107 .50561 .22228 .50741 .2213 .50643 .21992 Mtetra
.719 .73 .859 r
.50643 .21992 .50741 .2213 .50921 .22043 .50823 .21893 Mtetra
.591 .661 .887 r
.50823 .21893 .50921 .22043 .51101 .22008 .51003 .21859 Mtetra
.649 .221 0 r
.51003 .21859 .51101 .22008 .5128 .22214 .51181 .22156 Mtetra
.971 .681 .416 r
.51181 .22156 .5128 .22214 .51454 .24123 .51284 .42971 Mtetra
.536 .301 .506 r
.51284 .42971 .51454 .24123 .51581 .43533 .51475 .43709 Mtetra
.564 .126 .167 r
.51475 .43709 .51581 .43533 .51774 .43729 .51668 .43792 Mtetra
0 0 0 r
.51668 .43792 .51774 .43729 .51968 .43756 .51862 .43725 Mtetra
.737 .954 .945 r
.51862 .43725 .51968 .43756 .52161 .43725 .52056 .43607 Mtetra
.584 .734 .947 r
.52056 .43607 .52161 .43725 .52355 .43701 .5225 .43569 Mtetra
.571 .702 .93 r
.5225 .43569 .52355 .43701 .52549 .43649 .52444 .43537 Mtetra
.721 .794 .909 r
.52444 .43537 .52549 .43649 .52744 .43532 .52639 .43438 Mtetra
.941 .806 .683 r
.52639 .43438 .52744 .43532 .52938 .43183 .52833 .43008 Mtetra
.973 .687 .425 r
.52833 .43008 .52938 .43183 .5313 .41952 .52992 .22098 Mtetra
.542 .311 .514 r
.52992 .22098 .5313 .41952 .53271 .21568 .53173 .21171 Mtetra
.706 .545 .667 r
.53173 .21171 .53271 .21568 .53452 .21245 .53354 .20957 Mtetra
.618 .537 .741 r
.53354 .20957 .53452 .21245 .53633 .21095 .53536 .20893 Mtetra
.554 .573 .828 r
.53536 .20893 .53633 .21095 .53815 .21 .53718 .20879 Mtetra
.598 .718 .929 r
.53718 .20879 .53815 .21 .53997 .20929 .539 .20839 Mtetra
.649 .805 .958 r
.539 .20839 .53997 .20929 .54179 .20874 .54082 .20777 Mtetra
.66 .793 .946 r
.54082 .20777 .54179 .20874 .54361 .20828 .54264 .20712 Mtetra
.743 .778 .882 r
.54264 .20712 .54361 .20828 .54543 .20741 .54446 .20604 Mtetra
.725 .737 .86 r
.54446 .20604 .54543 .20741 .54725 .20651 .54628 .205 Mtetra
.612 .672 .883 r
.54628 .205 .54725 .20651 .54908 .20608 .54811 .20457 Mtetra
0 0 .541 r
.54811 .20457 .54908 .20608 .55093 .20768 .54996 .20685 Mtetra
.973 .679 .4 r
.54996 .20685 .55093 .20768 .55285 .21691 .55363 .41346 Mtetra
.54 .304 .506 r
.55363 .41346 .55285 .21691 .55669 .42132 .55569 .42327 Mtetra
.618 .193 .213 r
.55569 .42327 .55669 .42132 .55869 .42383 .55767 .42457 Mtetra
.016 0 0 r
.55767 .42457 .55869 .42383 .56066 .4242 .55964 .42398 Mtetra
.702 .964 .941 r
.55964 .42398 .56066 .4242 .56264 .42395 .5616 .42285 Mtetra
.617 .766 .951 r
.5616 .42285 .56264 .42395 .56461 .42368 .56357 .42231 Mtetra
.556 .69 .929 r
.56357 .42231 .56461 .42368 .56658 .42322 .56555 .42205 Mtetra
.699 .783 .916 r
.56555 .42205 .56658 .42322 .56855 .42215 .56752 .42116 Mtetra
.929 .819 .716 r
.56752 .42116 .56855 .42215 .57049 .4191 .56945 .41755 Mtetra
.975 .686 .409 r
.56945 .41755 .57049 .4191 .57233 .4099 .56848 .21211 Mtetra
.551 .318 .515 r
.56848 .21211 .57233 .4099 .57114 .20259 .57013 .19829 Mtetra
.72 .545 .653 r
.57013 .19829 .57114 .20259 .57294 .19881 .57195 .19568 Mtetra
.621 .526 .726 r
.57195 .19568 .57294 .19881 .57477 .19729 .57379 .19497 Mtetra
.562 .548 .796 r
.57379 .19497 .57477 .19729 .5766 .19634 .57564 .19478 Mtetra
.588 .653 .882 r
.57564 .19478 .5766 .19634 .57845 .19559 .57749 .19444 Mtetra
.657 .757 .924 r
.57749 .19444 .57845 .19559 .58029 .19492 .57934 .1938 Mtetra
.666 .766 .924 r
.57934 .1938 .58029 .19492 .58214 .19434 .58119 .19312 Mtetra
.735 .769 .88 r
.58119 .19312 .58214 .19434 .58399 .19346 .58303 .19207 Mtetra
.737 .742 .856 r
.58303 .19207 .58399 .19346 .58583 .19247 .58487 .19095 Mtetra
.636 .683 .877 r
.58487 .19095 .58583 .19247 .58768 .19194 .58672 .19039 Mtetra
0 .196 .726 r
.58672 .19039 .58768 .19194 .58957 .19309 .58862 .19205 Mtetra
.975 .676 .383 r
.58862 .19205 .58957 .19309 .59159 .19963 .59484 .39178 Mtetra
.553 .314 .507 r
.59484 .39178 .59159 .19963 .59816 .40678 .59722 .40907 Mtetra
.662 .253 .26 r
.59722 .40907 .59816 .40678 .60024 .40993 .59927 .41096 Mtetra
.177 0 0 r
.59927 .41096 .60024 .40993 .60226 .41033 .60128 .4105 Mtetra
.562 .935 .827 r
.60128 .4105 .60226 .41033 .60427 .41008 .60326 .40935 Mtetra
.745 .887 .944 r
.60326 .40935 .60427 .41008 .60628 .40992 .60525 .40822 Mtetra
.695 .699 .85 r
.60525 .40822 .60628 .40992 .60829 .40979 .60724 .40726 Mtetra
.725 .631 .753 r
.60724 .40726 .60829 .40979 .61029 .40897 .60922 .40566 Mtetra
.824 .64 .653 r
.60922 .40566 .61029 .40897 .61222 .40588 .61113 .40143 Mtetra
.974 .68 .398 r
.61113 .40143 .61222 .40588 .61379 .3896 .60744 .19285 Mtetra
.54 .309 .514 r
.60744 .19285 .61379 .3896 .61004 .18594 .60909 .18443 Mtetra
.861 .757 .747 r
.60909 .18443 .61004 .18594 .61184 .18283 .6109 .18183 Mtetra
.693 .803 .934 r
.6109 .18183 .61184 .18283 .6137 .18205 .61277 .18102 Mtetra
.561 .746 .964 r
.61277 .18102 .6137 .18205 .61559 .18186 .61465 .1807 Mtetra
.572 .723 .944 r
.61465 .1807 .61559 .18186 .61747 .18165 .61653 .18037 Mtetra
.647 .731 .91 r
.61653 .18037 .61747 .18165 .61935 .18106 .61841 .17976 Mtetra
.653 .729 .905 r
.61841 .17976 .61935 .18106 .62122 .18043 .62028 .17912 Mtetra
.665 .733 .901 r
.62028 .17912 .62122 .18043 .6231 .17975 .62216 .17843 Mtetra
.677 .737 .896 r
.62216 .17843 .6231 .17975 .62497 .179 .62403 .17768 Mtetra
.682 .738 .893 r
.62403 .17768 .62497 .179 .62684 .17821 .62591 .1769 Mtetra
.724 .755 .877 r
.62591 .1769 .62684 .17821 .62871 .17713 .62777 .17588 Mtetra
.749 .772 .872 r
.62777 .17588 .62871 .17713 .63057 .17589 .62964 .17472 Mtetra
.655 .757 .925 r
.62964 .17472 .63057 .17589 .63245 .17517 .63152 .17408 Mtetra
0 .354 .822 r
.63152 .17408 .63245 .17517 .63439 .17616 .63346 .17515 Mtetra
.933 .561 .175 r
.63346 .17515 .63439 .17616 .63662 .18491 .63573 .18471 Mtetra
.975 .672 .363 r
.63573 .18471 .63662 .18491 .64642 .39335 .64542 .39219 Mtetra
.606 .133 0 r
.64542 .39219 .64642 .39335 .64858 .39631 .64759 .39502 Mtetra
.465 .664 .948 r
.64759 .39502 .64858 .39631 .65064 .39639 .64964 .39503 Mtetra
.718 .762 .887 r
.64964 .39503 .65064 .39639 .65266 .39533 .65166 .39398 Mtetra
.874 .796 .77 r
.65166 .39398 .65266 .39533 .65459 .39227 .65362 .39136 Mtetra
.979 .786 .575 r
.65362 .39136 .65459 .39227 .65612 .37915 .65539 .38416 Mtetra
.98 .686 .359 r
.65539 .38416 .65612 .37915 .64955 .17194 .64876 .17397 Mtetra
.725 .775 .281 r
.64876 .17397 .64955 .17194 .65132 .16841 .65048 .16904 Mtetra
.516 .858 .591 r
.65048 .16904 .65132 .16841 .65321 .16755 .65233 .16744 Mtetra
.605 .949 .917 r
.65233 .16744 .65321 .16755 .65512 .16729 .65422 .16649 Mtetra
.654 .84 .972 r
.65422 .16649 .65512 .16729 .65704 .16711 .65612 .16579 Mtetra
.662 .734 .903 r
.65612 .16579 .65704 .16711 .65894 .16649 .65802 .1651 Mtetra
.643 .713 .899 r
.65802 .1651 .65894 .16649 .66084 .16582 .65992 .1645 Mtetra
.678 .739 .897 r
.65992 .1645 .66084 .16582 .66273 .16491 .66182 .16373 Mtetra
.741 .788 .891 r
.66182 .16373 .66273 .16491 .66461 .16367 .6637 .16265 Mtetra
.659 .792 .946 r
.6637 .16265 .66461 .16367 .66651 .16292 .66561 .16196 Mtetra
.172 .545 .928 r
.66561 .16196 .66651 .16292 .66848 .1637 .66757 .1625 Mtetra
.819 .396 0 r
.66757 .1625 .66848 .1637 .67085 .17248 .66975 .16749 Mtetra
.976 .672 .333 r
.66975 .16749 .67085 .17248 .68313 .38162 .68198 .37681 Mtetra
.002 .067 .579 r
.68198 .37681 .68313 .38162 .68537 .38462 .68428 .3812 Mtetra
.475 .438 .737 r
.68428 .3812 .68537 .38462 .68744 .38435 .6864 .38166 Mtetra
.569 .54 .783 r
.6864 .38166 .68744 .38435 .68948 .38332 .68848 .3814 Mtetra
.592 .628 .857 r
.68848 .3814 .68948 .38332 .69151 .38202 .69055 .38101 Mtetra
.439 .714 .982 r
.69055 .38101 .69151 .38202 .69356 .38106 .69265 .38096 Mtetra
.421 .865 .892 r
.69265 .38096 .69356 .38106 .69558 .37956 .69471 .3803 Mtetra
.604 .882 .565 r
.69471 .3803 .69558 .37956 .69751 .37644 .6967 .37816 Mtetra
.945 .82 .373 r
.6967 .37816 .69751 .37644 .69817 .35018 .69834 .36967 Mtetra
.975 .687 .297 r
.69834 .36967 .69817 .35018 .68963 .15791 .68876 .15733 Mtetra
.98 .849 .64 r
.68876 .15733 .68963 .15791 .69139 .15439 .69047 .15283 Mtetra
.715 .717 .851 r
.69047 .15283 .69139 .15439 .6933 .15336 .69238 .15179 Mtetra
.593 .661 .886 r
.69238 .15179 .6933 .15336 .69523 .15286 .69432 .15141 Mtetra
.543 .657 .91 r
.69432 .15141 .69523 .15286 .69717 .15247 .69627 .15123 Mtetra
.662 .752 .916 r
.69627 .15123 .69717 .15247 .69909 .15156 .6982 .15053 Mtetra
.669 .798 .944 r
.6982 .15053 .69909 .15156 .70101 .15074 .70013 .1498 Mtetra
.699 .829 .945 r
.70013 .1498 .70101 .15074 .70294 .15007 .70205 .14894 Mtetra
.76 .806 .89 r
.70205 .14894 .70294 .15007 .70488 .14962 .70395 .14774 Mtetra
.668 .655 .828 r
.70395 .14774 .70488 .14962 .70686 .1497 .70587 .14692 Mtetra
.514 .488 .766 r
.70587 .14692 .70686 .1497 .70893 .1512 .70785 .14705 Mtetra
.018 .092 .6 r
.70785 .14705 .70893 .1512 .72357 .35356 .71007 .15084 Mtetra
0 0 .383 r
.71007 .15084 .72357 .35356 .72658 .36771 .72525 .36049 Mtetra
.057 .059 .542 r
.72525 .36049 .72658 .36771 .72887 .37031 .72777 .36669 Mtetra
.454 .416 .727 r
.72777 .36669 .72887 .37031 .73099 .37017 .72994 .36736 Mtetra
.557 .526 .777 r
.72994 .36736 .73099 .37017 .73308 .36933 .73207 .36718 Mtetra
.606 .611 .83 r
.73207 .36718 .73308 .36933 .73513 .36811 .73417 .36669 Mtetra
.509 .666 .933 r
.73417 .36669 .73513 .36811 .7372 .36709 .7363 .36659 Mtetra
.549 .88 .99 r
.7363 .36659 .7372 .36709 .73924 .36552 .7384 .36596 Mtetra
.549 .896 .666 r
.7384 .36596 .73924 .36552 .74118 .36256 .74044 .36435 Mtetra
.773 .795 .303 r
.74044 .36435 .74118 .36256 .74187 .34139 .74221 .3589 Mtetra
.971 .679 .277 r
.74221 .3589 .74187 .34139 .73026 .14297 .72978 .14766 Mtetra
0 0 .073 r
.72978 .14766 .73026 .14297 .73199 .13919 .73125 .13993 Mtetra
.555 .843 .511 r
.73125 .13993 .73199 .13919 .73392 .13814 .73311 .1379 Mtetra
.714 .976 .92 r
.73311 .1379 .73392 .13814 .73588 .13765 .73502 .13669 Mtetra
.684 .821 .949 r
.73502 .13669 .73588 .13765 .73787 .13739 .73697 .13588 Mtetra
.657 .704 .881 r
.73697 .13588 .73787 .13739 .73981 .13656 .73892 .13518 Mtetra
.632 .716 .907 r
.73892 .13518 .73981 .13656 .74176 .13579 .74089 .13462 Mtetra
.624 .752 .938 r
.74089 .13462 .74176 .13579 .74372 .13519 .74286 .13407 Mtetra
.675 .785 .932 r
.74286 .13407 .74372 .13519 .74573 .13517 .74481 .13331 Mtetra
.663 .658 .834 r
.74481 .13331 .74573 .13517 .74776 .13534 .74677 .13251 Mtetra
.636 .557 .749 r
.74677 .13251 .74776 .13534 .74979 .13552 .74872 .1317 Mtetra
.639 .512 .692 r
.74872 .1317 .74979 .13552 .75172 .13437 .75065 .13058 Mtetra
.611 .496 .698 r
.75065 .13058 .75172 .13437 .75367 .13354 .75261 .12981 Mtetra
.544 .457 .708 r
.75261 .12981 .75367 .13354 .75571 .13371 .75462 .12974 Mtetra
.043 .119 .618 r
.75462 .12974 .75571 .13371 .75894 .14905 .75693 .13335 Mtetra
.961 .659 .242 r
.75693 .13335 .75894 .14905 .77702 .35107 .77559 .34344 Mtetra
.049 .052 .538 r
.77559 .34344 .77702 .35107 .77946 .35425 .77832 .35033 Mtetra
.526 .45 .713 r
.77832 .35033 .77946 .35425 .78163 .35411 .78051 .35042 Mtetra
.621 .517 .715 r
.78051 .35042 .78163 .35411 .78374 .35331 .78262 .34956 Mtetra
.662 .539 .704 r
.78262 .34956 .78374 .35331 .78584 .35215 .78469 .34817 Mtetra
.597 .388 .568 r
.11031 .55223 .10981 .56723 .11148 .56658 .1122 .54971 Mtetra
.632 .414 .568 r
.1122 .54971 .11148 .56658 .11316 .56589 .11436 .54502 Mtetra
.91 .658 .543 r
.11436 .54502 .11316 .56589 .11485 .56517 .1367 .37413 Mtetra
.548 .317 .518 r
.1367 .37413 .11485 .56517 .11655 .56427 .13945 .36391 Mtetra
.528 .3 .513 r
.13945 .36391 .11655 .56427 .11825 .56344 .14123 .36162 Mtetra
.519 .293 .511 r
.14123 .36162 .11825 .56344 .11993 .5628 .14261 .36268 Mtetra
0 0 .088 r
.14261 .36268 .11993 .5628 .12152 .56289 .12108 .5554 Mtetra
.001 0 .465 r
.12108 .5554 .12152 .56289 .1231 .56304 .12212 .56006 Mtetra
0 .1 .631 r
.12212 .56006 .1231 .56304 .12471 .56307 .12349 .56203 Mtetra
.494 .702 .962 r
.12349 .56203 .12471 .56307 .12637 .56259 .12511 .56193 Mtetra
.646 .834 .973 r
.12511 .56193 .12637 .56259 .12805 .56197 .12679 .56134 Mtetra
.706 .849 .951 r
.12679 .56134 .12805 .56197 .12973 .56134 .12849 .56054 Mtetra
.487 .757 .99 r
.12849 .56054 .12973 .56134 .13138 .56101 .13012 .56037 Mtetra
.534 .809 .996 r
.13012 .56037 .13138 .56101 .13303 .56067 .13177 .56005 Mtetra
.688 .85 .96 r
.13177 .56005 .13303 .56067 .1347 .56021 .13347 .55932 Mtetra
.849 .789 .793 r
.13347 .55932 .1347 .56021 .13637 .55971 .13533 .55718 Mtetra
.82 .654 .676 r
.13533 .55718 .13637 .55971 .13809 .55877 .13739 .55333 Mtetra
.861 .631 .588 r
.13739 .55333 .13809 .55877 .13992 .55695 .14064 .53904 Mtetra
.919 .665 .537 r
.14064 .53904 .13992 .55695 .14245 .54887 .16394 .34844 Mtetra
.531 .303 .514 r
.16394 .34844 .14245 .54887 .16675 .34805 .16591 .34452 Mtetra
.725 .565 .673 r
.16591 .34452 .16675 .34805 .16879 .34347 .16768 .34227 Mtetra
.728 .733 .854 r
.16768 .34227 .16879 .34347 .17045 .34219 .16931 .34132 Mtetra
.639 .777 .947 r
.16931 .34132 .17045 .34219 .17203 .34171 .17088 .34083 Mtetra
.569 .755 .965 r
.17088 .34083 .17203 .34171 .17356 .34155 .17244 .34053 Mtetra
.702 .76 .897 r
.17244 .34053 .17356 .34155 .17515 .34098 .17405 .33978 Mtetra
.683 .723 .88 r
.17405 .33978 .17515 .34098 .17674 .34037 .17565 .3391 Mtetra
.607 .687 .899 r
.17565 .3391 .17674 .34037 .17833 .33985 .17721 .33874 Mtetra
0 .382 .839 r
.17721 .33874 .17833 .33985 .17991 .33935 .17866 .33948 Mtetra
.809 .368 .197 r
.17866 .33948 .17991 .33935 .18145 .33918 .17995 .34167 Mtetra
.864 .56 .472 r
.17995 .34167 .18145 .33918 .18292 .33979 .18046 .35106 Mtetra
.926 .665 .523 r
.18046 .35106 .18292 .33979 .18379 .34591 .16099 .54556 Mtetra
.528 .296 .506 r
.16099 .54556 .18379 .34591 .16377 .54704 .16224 .54906 Mtetra
.656 .271 .302 r
.16224 .54906 .16377 .54704 .16498 .55105 .16373 .55052 Mtetra
.047 .568 .869 r
.16373 .55052 .16498 .55105 .16654 .55183 .16533 .55081 Mtetra
.636 .759 .937 r
.16533 .55081 .16654 .55183 .16822 .55141 .16703 .55029 Mtetra
.781 .766 .84 r
.16703 .55029 .16822 .55141 .17001 .55001 .16882 .54891 Mtetra
.899 .745 .682 r
.16882 .54891 .17001 .55001 .17213 .54551 .17094 .54434 Mtetra
.942 .688 .523 r
.17094 .54434 .17213 .54551 .19494 .34239 .19387 .34093 Mtetra
.912 .708 .614 r
.19387 .34093 .19494 .34239 .19739 .33369 .19629 .33257 Mtetra
.822 .755 .789 r
.19629 .33257 .19739 .33369 .19913 .33181 .19802 .3307 Mtetra
.671 .739 .901 r
.19802 .3307 .19913 .33181 .20074 .33117 .19963 .33008 Mtetra
.542 .7 .942 r
.19963 .33008 .20074 .33117 .2023 .33098 .20119 .3299 Mtetra
.721 .755 .879 r
.20119 .3299 .2023 .33098 .20394 .3301 .20283 .32903 Mtetra
.715 .755 .884 r
.20283 .32903 .20394 .3301 .20557 .32926 .20446 .32819 Mtetra
.555 .709 .943 r
.20446 .32819 .20557 .32926 .20714 .32904 .20603 .32797 Mtetra
.869 .428 .049 r
.20603 .32797 .20714 .32904 .2084 .33188 .20729 .33083 Mtetra
.945 .684 .51 r
.20729 .33083 .2084 .33188 .18976 .53419 .18856 .53324 Mtetra
.942 .609 .368 r
.18856 .53324 .18976 .53419 .19065 .54188 .18945 .54087 Mtetra
.488 0 0 r
.18945 .54087 .19065 .54188 .19217 .54324 .19098 .54222 Mtetra
.554 .735 .96 r
.19098 .54222 .19217 .54324 .19386 .54298 .19266 .54196 Mtetra
.779 .784 .857 r
.19266 .54196 .19386 .54298 .19565 .54166 .19446 .54064 Mtetra
.9 .757 .694 r
.19446 .54064 .19565 .54166 .19772 .5375 .19653 .53647 Mtetra
.945 .688 .517 r
.19653 .53647 .19772 .5375 .219 .33504 .21789 .33393 Mtetra
.929 .718 .598 r
.21789 .33393 .219 .33504 .22152 .32512 .22041 .32402 Mtetra
.841 .761 .775 r
.22041 .32402 .22152 .32512 .22328 .32299 .22218 .3219 Mtetra
.678 .745 .901 r
.22218 .3219 .22328 .32299 .22491 .32234 .22381 .32125 Mtetra
.543 .701 .943 r
.22381 .32125 .22491 .32234 .22649 .32215 .22539 .32106 Mtetra
.701 .751 .89 r
.22539 .32106 .22649 .32215 .22812 .32138 .22702 .32029 Mtetra
.717 .754 .881 r
.22702 .32029 .22812 .32138 .22977 .32052 .22867 .31943 Mtetra
.573 .712 .937 r
.22867 .31943 .22977 .32052 .23136 .32025 .23026 .31916 Mtetra
.818 .353 0 r
.23026 .31916 .23136 .32025 .2327 .32273 .2316 .32164 Mtetra
.948 .684 .504 r
.2316 .32164 .2327 .32273 .21562 .52454 .21444 .5235 Mtetra
.947 .62 .375 r
.21444 .5235 .21562 .52454 .2165 .53326 .21531 .53223 Mtetra
.576 .055 0 r
.21531 .53223 .2165 .53326 .21803 .53485 .21685 .53382 Mtetra
.523 .721 .963 r
.21685 .53382 .21803 .53485 .21973 .53467 .21855 .53363 Mtetra
.766 .784 .868 r
.21855 .53363 .21973 .53467 .22152 .53346 .22034 .53242 Mtetra
.894 .764 .71 r
.22034 .53242 .22152 .53346 .22354 .52976 .22236 .52872 Mtetra
.948 .689 .512 r
.22236 .52872 .22354 .52976 .24282 .3329 .24173 .33173 Mtetra
.938 .708 .564 r
.24173 .33173 .24282 .3329 .24584 .31684 .24474 .31574 Mtetra
.856 .761 .757 r
.24474 .31574 .24584 .31684 .24763 .31441 .24654 .31331 Mtetra
.667 .742 .906 r
.24654 .31331 .24763 .31441 .24927 .31379 .24818 .3127 Mtetra
.492 .68 .949 r
.24818 .3127 .24927 .31379 .25086 .31373 .24976 .31263 Mtetra
.544 .702 .943 r
.24976 .31263 .25086 .31373 .25246 .31352 .25136 .31244 Mtetra
.623 .732 .925 r
.25136 .31244 .25246 .31352 .25408 .31307 .25299 .312 Mtetra
.63 .737 .925 r
.25299 .312 .25408 .31307 .25571 .3126 .25462 .31153 Mtetra
.65 .746 .919 r
.25462 .31153 .25571 .3126 .25734 .31204 .25625 .31099 Mtetra
.669 .753 .913 r
.25625 .31099 .25734 .31204 .25899 .31142 .25789 .31037 Mtetra
.678 .756 .91 r
.25789 .31037 .25899 .31142 .26063 .31076 .25954 .30971 Mtetra
.683 .757 .908 r
.25954 .30971 .26063 .31076 .26228 .31009 .26119 .30903 Mtetra
.686 .757 .906 r
.26119 .30903 .26228 .31009 .26393 .3094 .26284 .30833 Mtetra
.689 .756 .903 r
.26284 .30833 .26393 .3094 .26558 .30871 .2645 .30762 Mtetra
.688 .753 .901 r
.2645 .30762 .26558 .30871 .26724 .30801 .26615 .30691 Mtetra
.689 .749 .898 r
.26615 .30691 .26724 .30801 .26889 .30732 .26781 .3062 Mtetra
.693 .746 .892 r
.26781 .3062 .26889 .30732 .27055 .30662 .26947 .30546 Mtetra
.73 .748 .867 r
.26947 .30546 .27055 .30662 .27221 .30583 .27115 .3045 Mtetra
.729 .721 .843 r
.27115 .3045 .27221 .30583 .27388 .30501 .27283 .30348 Mtetra
.672 .675 .845 r
.27283 .30348 .27388 .30501 .27554 .3043 .27449 .30279 Mtetra
.377 .541 .891 r
.27449 .30279 .27554 .3043 .27717 .30395 .27606 .30313 Mtetra
.747 .239 0 r
.27606 .30313 .27717 .30395 .27877 .30396 .27751 .30511 Mtetra
.857 .502 .38 r
.27751 .30511 .27877 .30396 .28037 .30408 .27872 .31015 Mtetra
.943 .674 .498 r
.27872 .31015 .28037 .30408 .28201 .30359 .26591 .49487 Mtetra
0 0 .223 r
.26591 .49487 .28201 .30359 .2837 .30259 .28098 .32268 Mtetra
.361 .133 .427 r
.28098 .32268 .2837 .30259 .28535 .30212 .28303 .31709 Mtetra
.931 .66 .504 r
.28303 .31709 .28535 .30212 .2868 .30424 .27023 .50552 Mtetra
.533 .3 .507 r
.27023 .50552 .2868 .30424 .27312 .50649 .27148 .51168 Mtetra
.651 .331 .418 r
.27148 .51168 .27312 .50649 .27426 .51417 .27302 .51419 Mtetra
.461 0 0 r
.27302 .51419 .27426 .51417 .27587 .51576 .27469 .51489 Mtetra
.593 .785 .972 r
.27469 .51489 .27587 .51576 .27762 .51541 .27646 .51446 Mtetra
.685 .795 .933 r
.27646 .51446 .27762 .51541 .27942 .51456 .27824 .51372 Mtetra
.647 .808 .961 r
.27824 .51372 .27942 .51456 .28121 .51378 .28002 .51312 Mtetra
.546 .818 .996 r
.28002 .51312 .28121 .51378 .28298 .51328 .28178 .51274 Mtetra
.642 .873 .984 r
.28178 .51274 .28298 .51328 .28476 .51267 .28356 .51208 Mtetra
.814 .876 .891 r
.28356 .51208 .28476 .51267 .28654 .51196 .2854 .51064 Mtetra
.859 .751 .742 r
.2854 .51064 .28654 .51196 .28834 .51105 .28734 .50782 Mtetra
.835 .642 .641 r
.28734 .50782 .28834 .51105 .29019 .50953 .28946 .50253 Mtetra
.948 .682 .5 r
.28946 .50253 .29019 .50953 .2922 .50569 .30532 .30151 Mtetra
.539 .309 .515 r
.30532 .30151 .2922 .50569 .30806 .30218 .30748 .29401 Mtetra
.664 .461 .6 r
.30748 .29401 .30806 .30218 .31032 .29315 .30933 .29087 Mtetra
.743 .631 .736 r
.30933 .29087 .31032 .29315 .31213 .29045 .31108 .28918 Mtetra
.688 .723 .876 r
.31108 .28918 .31213 .29045 .31382 .28962 .31276 .28844 Mtetra
.615 .716 .917 r
.31276 .28844 .31382 .28962 .31548 .28927 .31442 .28802 Mtetra
.592 .694 .913 r
.31442 .28802 .31548 .28927 .31713 .28899 .31608 .28769 Mtetra
.616 .693 .899 r
.31608 .28769 .31713 .28899 .3188 .28849 .31774 .28727 Mtetra
.614 .707 .911 r
.31774 .28727 .3188 .28849 .32047 .288 .31941 .28686 Mtetra
.63 .729 .918 r
.31941 .28686 .32047 .288 .32215 .28748 .32108 .28638 Mtetra
.658 .747 .916 r
.32108 .28638 .32215 .28748 .32383 .2869 .32276 .28579 Mtetra
.673 .749 .908 r
.32276 .28579 .32383 .2869 .32551 .28628 .32445 .28514 Mtetra
.708 .751 .886 r
.32445 .28514 .32551 .28628 .3272 .28558 .32614 .2843 Mtetra
.73 .734 .854 r
.32614 .2843 .3272 .28558 .32889 .2848 .32785 .2833 Mtetra
.68 .684 .848 r
.32785 .2833 .32889 .2848 .33058 .2841 .32955 .28255 Mtetra
.498 .599 .885 r
.32955 .28255 .33058 .2841 .33226 .28366 .33119 .28257 Mtetra
.537 .04 0 r
.33119 .28257 .33226 .28366 .33391 .28363 .33274 .28423 Mtetra
.854 .463 .301 r
.33274 .28423 .33391 .28363 .33555 .28373 .33415 .28812 Mtetra
.876 .573 .47 r
.33415 .28812 .33555 .28373 .33722 .28346 .33487 .30353 Mtetra
.388 .157 .437 r
.33487 .30353 .33722 .28346 .33894 .28241 .33683 .29864 Mtetra
.376 .14 .424 r
.33683 .29864 .33894 .28241 .34063 .28179 .33875 .2944 Mtetra
.94 .664 .488 r
.33875 .2944 .34063 .28179 .34222 .2829 .32929 .48244 Mtetra
.539 .304 .507 r
.32929 .48244 .34222 .2829 .33241 .47969 .33052 .49147 Mtetra
.603 .323 .465 r
.33052 .49147 .33241 .47969 .33335 .49398 .33212 .49443 Mtetra
.596 .066 0 r
.33212 .49443 .33335 .49398 .33499 .49632 .33384 .49543 Mtetra
.627 .797 .964 r
.33384 .49543 .33499 .49632 .33679 .49601 .33565 .49489 Mtetra
.713 .772 .899 r
.33565 .49489 .33679 .49601 .33862 .49513 .33749 .49398 Mtetra
.691 .763 .906 r
.33749 .49398 .33862 .49513 .34045 .49419 .33931 .49319 Mtetra
.506 .728 .973 r
.33931 .49319 .34045 .49419 .34226 .49377 .3411 .49302 Mtetra
.567 .807 .989 r
.3411 .49302 .34226 .49377 .34407 .49328 .34291 .49261 Mtetra
.751 .869 .934 r
.34291 .49261 .34407 .49328 .34589 .49264 .34476 .49154 Mtetra
.868 .786 .767 r
.34476 .49154 .34589 .49264 .34772 .49181 .34668 .48895 Mtetra
.839 .656 .654 r
.34668 .48895 .34772 .49181 .34958 .49041 .34872 .48429 Mtetra
.954 .684 .485 r
.34872 .48429 .34958 .49041 .35153 .48738 .36103 .2847 Mtetra
.545 .314 .515 r
.36103 .2847 .35153 .48738 .36355 .29005 .36326 .27433 Mtetra
.612 .395 .562 r
.36326 .27433 .36355 .29005 .36608 .27356 .36512 .27084 Mtetra
.741 .608 .71 r
.36512 .27084 .36608 .27356 .36793 .27021 .36689 .26889 Mtetra
.699 .722 .867 r
.36689 .26889 .36793 .27021 .36966 .26925 .36861 .26806 Mtetra
.625 .721 .915 r
.36861 .26806 .36966 .26925 .37136 .26884 .37032 .2676 Mtetra
.582 .695 .92 r
.37032 .2676 .37136 .26884 .37305 .26862 .37201 .26729 Mtetra
.614 .691 .898 r
.37201 .26729 .37305 .26862 .37475 .26813 .37372 .26687 Mtetra
.61 .704 .91 r
.37372 .26687 .37475 .26813 .37646 .26764 .37542 .26646 Mtetra
.62 .723 .92 r
.37542 .26646 .37646 .26764 .37817 .26713 .37713 .26601 Mtetra
.651 .745 .918 r
.37713 .26601 .37817 .26713 .37988 .26657 .37884 .26544 Mtetra
.668 .749 .911 r
.37884 .26544 .37988 .26657 .3816 .26596 .38056 .2648 Mtetra
.695 .75 .894 r
.38056 .2648 .3816 .26596 .38332 .26528 .38229 .26402 Mtetra
.74 .745 .856 r
.38229 .26402 .38332 .26528 .38505 .26445 .38403 .26295 Mtetra
.694 .695 .846 r
.38403 .26295 .38505 .26445 .38678 .26368 .38576 .2621 Mtetra
.591 .641 .869 r
.38576 .2621 .38678 .26368 .3885 .26306 .38747 .26178 Mtetra
0 .299 .792 r
.38747 .26178 .3885 .26306 .39021 .2626 .38912 .26286 Mtetra
.831 .392 .189 r
.38912 .26286 .39021 .2626 .39191 .26264 .39069 .2658 Mtetra
.958 .679 .464 r
.39069 .2658 .39191 .26264 .39355 .26391 .38389 .46374 Mtetra
.541 .306 .507 r
.38389 .46374 .39355 .26391 .38744 .45001 .38527 .47403 Mtetra
.561 .304 .484 r
.38527 .47403 .38744 .45001 .38817 .47584 .38698 .47674 Mtetra
.607 .119 .068 r
.38698 .47674 .38817 .47584 .38988 .47865 .38876 .47779 Mtetra
.545 .778 .985 r
.38876 .47779 .38988 .47865 .39171 .47852 .3906 .47746 Mtetra
.669 .78 .932 r
.3906 .47746 .39171 .47852 .39357 .47778 .39245 .47676 Mtetra
.695 .795 .927 r
.39245 .47676 .39357 .47778 .39544 .47679 .39432 .47595 Mtetra
.58 .796 .982 r
.39432 .47595 .39544 .47679 .39729 .47625 .39616 .47552 Mtetra
.569 .818 .992 r
.39616 .47552 .39729 .47625 .39914 .47569 .39801 .47508 Mtetra
.578 .846 .995 r
.39801 .47508 .39914 .47569 .401 .47511 .39987 .47457 Mtetra
.648 .884 .983 r
.39987 .47457 .401 .47511 .40286 .47443 .40173 .47384 Mtetra
.67 .88 .976 r
.40173 .47384 .40286 .47443 .40472 .47373 .40359 .47306 Mtetra
.671 .863 .973 r
.40359 .47306 .40472 .47373 .40658 .47304 .40546 .4723 Mtetra
.548 .808 .994 r
.40546 .4723 .40658 .47304 .40844 .47251 .40731 .47192 Mtetra
.595 .858 .993 r
.40731 .47192 .40844 .47251 .4103 .47193 .40918 .47136 Mtetra
.728 .894 .955 r
.40918 .47136 .4103 .47193 .41217 .4712 .41105 .47036 Mtetra
.899 .826 .766 r
.41105 .47036 .41217 .4712 .41405 .46995 .41299 .46757 Mtetra
.861 .686 .662 r
.41299 .46757 .41405 .46995 .41595 .46854 .41499 .46302 Mtetra
.865 .625 .574 r
.41499 .46302 .41595 .46854 .41784 .46715 .41722 .45125 Mtetra
.948 .67 .478 r
.41722 .45125 .41784 .46715 .41971 .46641 .42503 .26662 Mtetra
.509 .285 .51 r
.42503 .26662 .41971 .46641 .42158 .46587 .4266 .27198 Mtetra
0 0 .299 r
.4266 .27198 .42158 .46587 .42344 .46544 .4228 .44978 Mtetra
.53 .333 .558 r
.4228 .44978 .42344 .46544 .42531 .46488 .42464 .44972 Mtetra
.53 .335 .56 r
.42464 .44972 .42531 .46488 .42718 .46431 .42649 .44964 Mtetra
.534 .339 .562 r
.42649 .44964 .42718 .46431 .42906 .46373 .42835 .44945 Mtetra
.443 .271 .552 r
.42835 .44945 .42906 .46373 .43091 .46371 .43013 .45196 Mtetra
.531 .346 .575 r
.43013 .45196 .43091 .46371 .43279 .46322 .43198 .45191 Mtetra
.658 .443 .581 r
.43198 .45191 .43279 .46322 .43469 .46181 .43396 .44766 Mtetra
.953 .673 .47 r
.43396 .44766 .43469 .46181 .43677 .45369 .44124 .2484 Mtetra
.533 .304 .513 r
.44124 .2484 .43677 .45369 .44407 .24704 .44312 .24347 Mtetra
.75 .581 .666 r
.44312 .24347 .44407 .24704 .44594 .24221 .44493 .24071 Mtetra
.7 .701 .848 r
.44493 .24071 .44594 .24221 .44771 .24099 .4467 .23981 Mtetra
.612 .725 .926 r
.4467 .23981 .44771 .24099 .44947 .24047 .44846 .23938 Mtetra
.542 .713 .951 r
.44846 .23938 .44947 .24047 .45122 .2403 .45021 .23916 Mtetra
.646 .744 .921 r
.45021 .23916 .45122 .2403 .45298 .23973 .45197 .23859 Mtetra
.665 .752 .915 r
.45197 .23859 .45298 .23973 .45475 .23911 .45374 .23794 Mtetra
.678 .751 .906 r
.45374 .23794 .45475 .23911 .45651 .23845 .4555 .23723 Mtetra
.74 .759 .868 r
.4555 .23723 .45651 .23845 .45828 .23763 .45728 .23616 Mtetra
.706 .709 .851 r
.45728 .23616 .45828 .23763 .46006 .23684 .45906 .23524 Mtetra
.637 .664 .859 r
.45906 .23524 .46006 .23684 .46182 .23618 .46082 .23469 Mtetra
.22 .46 .876 r
.46082 .23469 .46182 .23618 .46359 .23563 .46257 .23541 Mtetra
.764 .251 0 r
.46257 .23541 .46359 .23563 .46535 .23548 .46428 .23757 Mtetra
.881 .536 .391 r
.46428 .23757 .46535 .23548 .4671 .23611 .46588 .24619 Mtetra
.956 .668 .449 r
.46588 .24619 .4671 .23611 .46875 .24227 .46391 .44678 Mtetra
.528 .295 .505 r
.46391 .44678 .46875 .24227 .46687 .44832 .46573 .45037 Mtetra
.633 .222 .246 r
.46573 .45037 .46687 .44832 .46869 .45241 .4676 .45179 Mtetra
.459 .8 .999 r
.4676 .45179 .46869 .45241 .47058 .45261 .4695 .45153 Mtetra
.695 .788 .922 r
.4695 .45153 .47058 .45261 .47248 .45187 .47141 .45068 Mtetra
.733 .779 .889 r
.47141 .45068 .47248 .45187 .4744 .45075 .47332 .44962 Mtetra
.561 .732 .956 r
.47332 .44962 .4744 .45075 .4763 .45018 .47523 .44931 Mtetra
.538 .778 .987 r
.47523 .44931 .4763 .45018 .47821 .44969 .47713 .44898 Mtetra
.648 .855 .979 r
.47713 .44898 .47821 .44969 .48012 .44906 .47904 .44828 Mtetra
.867 .86 .832 r
.47904 .44828 .48012 .44906 .48204 .44833 .48098 .44623 Mtetra
.856 .703 .692 r
.48098 .44623 .48204 .44833 .48396 .44719 .48293 .44259 Mtetra
.864 .632 .586 r
.48293 .44259 .48396 .44719 .48589 .44521 .48495 .4335 Mtetra
.96 .676 .452 r
.48495 .4335 .48589 .44521 .48788 .43802 .48922 .23055 Mtetra
.532 .303 .513 r
.48922 .23055 .48788 .43802 .49202 .23025 .49106 .22588 Mtetra
.713 .539 .652 r
.49106 .22588 .49202 .23025 .49386 .22509 .49287 .22336 Mtetra
.708 .678 .819 r
.49287 .22336 .49386 .22509 .49566 .22356 .49466 .22233 Mtetra
.61 .717 .921 r
.49466 .22233 .49566 .22356 .49745 .22302 .49645 .2219 Mtetra
.53 .705 .951 r
.49645 .2219 .49745 .22302 .49924 .22286 .49824 .22171 Mtetra
.625 .739 .929 r
.49824 .22171 .49924 .22286 .50103 .22237 .50004 .22121 Mtetra
.666 .752 .915 r
.50004 .22121 .50103 .22237 .50283 .22174 .50184 .22055 Mtetra
.68 .751 .905 r
.50184 .22055 .50283 .22174 .50462 .22107 .50363 .21982 Mtetra
.765 .764 .851 r
.50363 .21982 .50462 .22107 .50643 .21992 .50544 .21855 Mtetra
.735 .738 .854 r
.50544 .21855 .50643 .21992 .50823 .21893 .50724 .21746 Mtetra
.61 .675 .887 r
.50724 .21746 .50823 .21893 .51003 .21859 .50904 .21704 Mtetra
.611 .191 0 r
.50904 .21704 .51003 .21859 .51181 .22156 .51083 .21991 Mtetra
.972 .682 .415 r
.51083 .21991 .51181 .22156 .51284 .42971 .51179 .42845 Mtetra
.931 .554 .178 r
.51179 .42845 .51284 .42971 .51475 .43709 .51369 .43615 Mtetra
0 .428 .85 r
.51369 .43615 .51475 .43709 .51668 .43792 .51562 .43696 Mtetra
.671 .81 .95 r
.51562 .43696 .51668 .43792 .51862 .43725 .51756 .43621 Mtetra
.767 .818 .893 r
.51756 .43621 .51862 .43725 .52056 .43607 .5195 .43495 Mtetra
.559 .736 .958 r
.5195 .43495 .52056 .43607 .5225 .43569 .52145 .43463 Mtetra
.511 .729 .972 r
.52145 .43463 .5225 .43569 .52444 .43537 .52339 .43444 Mtetra
.7 .825 .942 r
.52339 .43444 .52444 .43537 .52639 .43438 .52533 .43356 Mtetra
.946 .819 .687 r
.52533 .43356 .52639 .43438 .52833 .43008 .52728 .42935 Mtetra
.974 .688 .423 r
.52728 .42935 .52833 .43008 .52992 .22098 .52894 .21997 Mtetra
.968 .747 .549 r
.52894 .21997 .52992 .22098 .53173 .21171 .53075 .2103 Mtetra
.835 .757 .777 r
.53075 .2103 .53173 .21171 .53354 .20957 .53256 .20818 Mtetra
.64 .703 .892 r
.53256 .20818 .53354 .20957 .53536 .20893 .53438 .20762 Mtetra
.501 .654 .928 r
.53438 .20762 .53536 .20893 .53718 .20879 .5362 .20757 Mtetra
.587 .712 .93 r
.5362 .20757 .53718 .20879 .539 .20839 .53802 .20721 Mtetra
.659 .749 .916 r
.53802 .20721 .539 .20839 .54082 .20777 .53984 .20657 Mtetra
.673 .75 .909 r
.53984 .20657 .54082 .20777 .54264 .20712 .54167 .20586 Mtetra
.754 .766 .862 r
.54167 .20586 .54264 .20712 .54446 .20604 .54349 .20468 Mtetra
.742 .745 .854 r
.54349 .20468 .54446 .20604 .54628 .205 .54531 .20354 Mtetra
.631 .687 .884 r
.54531 .20354 .54628 .205 .54811 .20457 .54714 .20301 Mtetra
0 .012 .574 r
.54714 .20301 .54811 .20457 .54996 .20685 .54899 .20521 Mtetra
.974 .68 .399 r
.54899 .20521 .54996 .20685 .55363 .41346 .55259 .41186 Mtetra
.944 .587 .202 r
.55259 .41186 .55363 .41346 .55569 .42327 .55465 .4223 Mtetra
0 .238 .71 r
.55465 .4223 .55569 .42327 .55767 .42457 .55663 .4236 Mtetra
.647 .804 .958 r
.55663 .4236 .55767 .42457 .55964 .42398 .5586 .42293 Mtetra
.76 .819 .899 r
.5586 .42293 .55964 .42398 .5616 .42285 .56057 .42171 Mtetra
.606 .756 .95 r
.56057 .42171 .5616 .42285 .56357 .42231 .56254 .42122 Mtetra
.493 .715 .97 r
.56254 .42122 .56357 .42231 .56555 .42205 .56452 .42108 Mtetra
.674 .815 .95 r
.56452 .42108 .56555 .42205 .56752 .42116 .56649 .42031 Mtetra
.935 .835 .721 r
.56649 .42031 .56752 .42116 .56945 .41755 .56843 .41677 Mtetra
.976 .686 .408 r
.56843 .41677 .56945 .41755 .56848 .21211 .56753 .21183 Mtetra
.986 .744 .482 r
.56753 .21183 .56848 .21211 .57013 .19829 .56917 .19685 Mtetra
.863 .762 .748 r
.56917 .19685 .57013 .19829 .57195 .19568 .57098 .19426 Mtetra
.655 .705 .884 r
.57098 .19426 .57195 .19568 .57379 .19497 .57283 .19362 Mtetra
.516 .656 .922 r
.57283 .19362 .57379 .19497 .57564 .19478 .57468 .19352 Mtetra
.567 .698 .929 r
.57468 .19352 .57564 .19478 .57749 .19444 .57653 .19323 Mtetra
.661 .747 .913 r
.57653 .19323 .57749 .19444 .57934 .1938 .57838 .19257 Mtetra
.676 .749 .906 r
.57838 .19257 .57934 .1938 .58119 .19312 .58023 .19184 Mtetra
.747 .763 .865 r
.58023 .19184 .58119 .19312 .58303 .19207 .58207 .19069 Mtetra
.752 .748 .849 r
.58207 .19069 .58303 .19207 .58487 .19095 .58391 .18946 Mtetra
.654 .696 .876 r
.58391 .18946 .58487 .19095 .58672 .19039 .58576 .18881 Mtetra
0 .224 .746 r
.58576 .18881 .58672 .19039 .58862 .19205 .58766 .1904 Mtetra
.975 .677 .381 r
.58766 .1904 .58862 .19205 .59484 .39178 .59372 .38586 Mtetra
.922 .63 .149 r
.59372 .38586 .59484 .39178 .59722 .40907 .59621 .40806 Mtetra
0 .021 .52 r
.59621 .40806 .59722 .40907 .59927 .41096 .59826 .41004 Mtetra
.575 .793 .982 r
.59826 .41004 .59927 .41096 .60128 .4105 .60027 .40959 Mtetra
.781 .856 .906 r
.60027 .40959 .60128 .4105 .60326 .40935 .60225 .40825 Mtetra
.857 .827 .817 r
.60225 .40825 .60326 .40935 .60525 .40822 .60421 .40613 Mtetra
.85 .711 .709 r
.60421 .40613 .60525 .40822 .60724 .40726 .60615 .40289 Mtetra
.84 .622 .606 r
.60615 .40289 .60724 .40726 .60922 .40566 .608 .39641 Mtetra
.97 .675 .407 r
.608 .39641 .60922 .40566 .61113 .40143 .60459 .19124 Mtetra
.534 .304 .513 r
.60459 .19124 .61113 .40143 .60744 .19285 .60631 .18517 Mtetra
.661 .46 .601 r
.60631 .18517 .60744 .19285 .60909 .18443 .60812 .18221 Mtetra
.741 .65 .758 r
.60812 .18221 .60909 .18443 .6109 .18183 .60996 .18062 Mtetra
.671 .753 .912 r
.60996 .18062 .6109 .18183 .61277 .18102 .61183 .1799 Mtetra
.595 .742 .946 r
.61183 .1799 .61277 .18102 .61465 .1807 .61371 .17949 Mtetra
.604 .726 .931 r
.61371 .17949 .61465 .1807 .61653 .18037 .61559 .17905 Mtetra
.65 .725 .904 r
.61559 .17905 .61653 .18037 .61841 .17976 .61746 .17843 Mtetra
.655 .726 .901 r
.61746 .17843 .61841 .17976 .62028 .17912 .61934 .17778 Mtetra
.665 .727 .896 r
.61934 .17778 .62028 .17912 .62216 .17843 .62122 .17708 Mtetra
.675 .73 .891 r
.62122 .17708 .62216 .17843 .62403 .17768 .62309 .17633 Mtetra
.68 .733 .891 r
.62309 .17633 .62403 .17768 .62591 .1769 .62497 .17556 Mtetra
.721 .749 .874 r
.62497 .17556 .62591 .1769 .62777 .17588 .62683 .17455 Mtetra
.744 .758 .864 r
.62683 .17455 .62777 .17588 .62964 .17472 .6287 .1734 Mtetra
.654 .728 .903 r
.6287 .1734 .62964 .17472 .63152 .17408 .63058 .17276 Mtetra
.049 .38 .845 r
.63058 .17276 .63152 .17408 .63346 .17515 .63253 .17382 Mtetra
.924 .553 .139 r
.63253 .17382 .63346 .17515 .63573 .18471 .63477 .18297 Mtetra
.976 .673 .359 r
.63477 .18297 .63573 .18471 .64542 .39219 .64443 .39088 Mtetra
0 0 .435 r
.64443 .39088 .64542 .39219 .64759 .39502 .64659 .39369 Mtetra
.503 .675 .942 r
.64659 .39369 .64759 .39502 .64964 .39503 .64864 .39359 Mtetra
.709 .746 .881 r
.64864 .39359 .64964 .39503 .65166 .39398 .65066 .39259 Mtetra
.816 .783 .822 r
.65066 .39259 .65166 .39398 .65362 .39136 .65265 .39072 Mtetra
.939 .889 .755 r
.65265 .39072 .65362 .39136 .65539 .38416 .65459 .38766 Mtetra
0 0 0 r
.65459 .38766 .65539 .38416 .64876 .17397 .65641 .38181 Mtetra
0 0 .362 r
.65641 .38181 .64876 .17397 .65048 .16904 .64991 .17633 Mtetra
0 0 .254 r
.64991 .17633 .65048 .16904 .65233 .16744 .65154 .16937 Mtetra
0 0 0 r
.65154 .16937 .65233 .16744 .65422 .16649 .65334 .16624 Mtetra
.854 .978 .863 r
.65334 .16624 .65422 .16649 .65612 .16579 .65519 .16446 Mtetra
.687 .741 .892 r
.65519 .16446 .65612 .16579 .65802 .1651 .65708 .16364 Mtetra
.624 .693 .893 r
.65708 .16364 .65802 .1651 .65992 .1645 .65899 .16313 Mtetra
.64 .715 .902 r
.65899 .16313 .65992 .1645 .66182 .16373 .6609 .16254 Mtetra
.718 .778 .899 r
.6609 .16254 .66182 .16373 .6637 .16265 .66279 .16157 Mtetra
.669 .785 .936 r
.66279 .16157 .6637 .16265 .66561 .16196 .6647 .16085 Mtetra
.477 .691 .961 r
.6647 .16085 .66561 .16196 .66757 .1625 .66663 .16079 Mtetra
.061 .317 .8 r
.66663 .16079 .66757 .1625 .66975 .16749 .66864 .16218 Mtetra
.111 .119 .587 r
.66864 .16218 .66975 .16749 .68198 .37681 .67078 .16618 Mtetra
0 0 .383 r
.67078 .16618 .68198 .37681 .68428 .3812 .68285 .37064 Mtetra
.229 .143 .546 r
.68285 .37064 .68428 .3812 .6864 .38166 .68524 .37675 Mtetra
.316 .278 .656 r
.68524 .37675 .6864 .38166 .68848 .3814 .68744 .3789 Mtetra
.346 .424 .799 r
.68744 .3789 .68848 .3814 .69055 .38101 .68958 .37983 Mtetra
.381 .64 .958 r
.68958 .37983 .69055 .38101 .69265 .38096 .69169 .38002 Mtetra
.627 .816 .973 r
.69169 .38002 .69265 .38096 .69471 .3803 .69376 .37938 Mtetra
.878 .871 .826 r
.69376 .37938 .69471 .3803 .6967 .37816 .69574 .37717 Mtetra
.984 .771 .535 r
.69574 .37717 .6967 .37816 .69834 .36967 .69737 .36841 Mtetra
.977 .676 .353 r
.69737 .36841 .69834 .36967 .68876 .15733 .68783 .15562 Mtetra
.919 .75 .656 r
.68783 .15562 .68876 .15733 .69047 .15283 .68955 .1512 Mtetra
.698 .701 .849 r
.68955 .1512 .69047 .15283 .69238 .15179 .69146 .15025 Mtetra
.567 .655 .895 r
.69146 .15025 .69238 .15179 .69432 .15141 .69341 .14999 Mtetra
.507 .643 .917 r
.69341 .14999 .69432 .15141 .69627 .15123 .69537 .14993 Mtetra
.648 .734 .912 r
.69537 .14993 .69627 .15123 .6982 .15053 .6973 .14929 Mtetra
.665 .753 .916 r
.6973 .14929 .6982 .15053 .70013 .1498 .69923 .14859 Mtetra
.697 .77 .908 r
.69923 .14859 .70013 .1498 .70205 .14894 .70115 .14773 Mtetra
.753 .789 .882 r
.70115 .14773 .70205 .14894 .70395 .14774 .70305 .14655 Mtetra
.712 .78 .905 r
.70305 .14655 .70395 .14774 .70587 .14692 .70497 .14561 Mtetra
.581 .703 .926 r
.70497 .14561 .70587 .14692 .70785 .14705 .70692 .14526 Mtetra
.172 .38 .826 r
.70692 .14526 .70785 .14705 .71007 .15084 .70898 .14643 Mtetra
.132 .161 .625 r
.70898 .14643 .71007 .15084 .72525 .36049 .71116 .14971 Mtetra
0 0 .397 r
.71116 .14971 .72525 .36049 .72777 .36669 .72607 .35368 Mtetra
.2 .113 .527 r
.72607 .35368 .72777 .36669 .72994 .36736 .72873 .362 Mtetra
.312 .265 .644 r
.72873 .362 .72994 .36736 .73207 .36718 .73102 .36444 Mtetra
.362 .414 .781 r
.73102 .36444 .73207 .36718 .73417 .36669 .73322 .36541 Mtetra
.45 .661 .952 r
.73322 .36541 .73417 .36669 .7363 .36659 .73536 .36545 Mtetra
.618 .774 .955 r
.73536 .36545 .7363 .36659 .7384 .36596 .73746 .36487 Mtetra
.765 .834 .905 r
.73746 .36487 .7384 .36596 .74044 .36435 .73952 .36358 Mtetra
.924 .893 .78 r
.73952 .36358 .74044 .36435 .74221 .3589 .74148 .3608 Mtetra
.695 .759 .263 r
.74148 .3608 .74221 .3589 .72978 .14766 .74328 .35579 Mtetra
0 0 .39 r
.74328 .35579 .72978 .14766 .73125 .13993 .73114 .14982 Mtetra
0 0 .305 r
.73114 .14982 .73125 .13993 .73311 .1379 .73245 .13991 Mtetra
0 0 0 r
.73245 .13991 .73311 .1379 .73502 .13669 .73421 .13636 Mtetra
.892 .971 .827 r
.73421 .13636 .73502 .13669 .73697 .13588 .73606 .13427 Mtetra
.672 .696 .864 r
.73606 .13427 .73697 .13588 .73892 .13518 .73801 .13348 Mtetra
.603 .649 .869 r
.73801 .13348 .73892 .13518 .74089 .13462 .73999 .13305 Mtetra
.576 .658 .892 r
.73999 .13305 .74089 .13462 .74286 .13407 .74197 .13274 Mtetra
.683 .748 .9 r
.74197 .13274 .74286 .13407 .74481 .13331 .74393 .13193 Mtetra
.692 .742 .89 r
.74393 .13193 .74481 .13331 .74677 .13251 .74587 .13106 Mtetra
.691 .729 .88 r
.74587 .13106 .74677 .13251 .74872 .1317 .74782 .13019 Mtetra
.708 .726 .864 r
.74782 .13019 .74872 .1317 .75065 .13058 .74977 .1292 Mtetra
.67 .732 .896 r
.74977 .1292 .75065 .13058 .75261 .12981 .75173 .12844 Mtetra
.569 .688 .921 r
.75173 .12844 .75261 .12981 .75462 .12974 .75372 .12813 Mtetra
.02 .303 .795 r
.75372 .12813 .75462 .12974 .75693 .13335 .75587 .12964 Mtetra
0 .08 .604 r
.75587 .12964 .75693 .13335 .77559 .34344 .75819 .13346 Mtetra
.007 0 .412 r
.75819 .13346 .77559 .34344 .77832 .35033 .77639 .33648 Mtetra
.456 .29 .565 r
.77639 .33648 .77832 .35033 .78051 .35042 .77875 .33888 Mtetra
.583 .386 .58 r
.77875 .33888 .78051 .35042 .78262 .34956 .7808 .33722 Mtetra
.665 .439 .568 r
.7808 .33722 .78262 .34956 .78469 .34817 .78255 .33206 Mtetra
.523 .296 .512 r
.13324 .35528 .11031 .55223 .1122 .54971 .13482 .35455 Mtetra
.13482 .35455 .1122 .54971 .11436 .54502 .13641 .35383 Mtetra
.13641 .35383 .11436 .54502 .1367 .37413 .13799 .35312 Mtetra
.552 .34 .546 r
.13799 .35312 .1367 .37413 .13945 .36391 .13964 .35191 Mtetra
.559 .362 .571 r
.13964 .35191 .13945 .36391 .14123 .36162 .14124 .35111 Mtetra
.532 .346 .575 r
.14124 .35111 .14123 .36162 .14261 .36268 .14275 .35104 Mtetra
.262 .129 .504 r
.14275 .35104 .14261 .36268 .12108 .5554 .14371 .35555 Mtetra
0 0 .059 r
.14371 .35555 .12108 .5554 .12212 .56006 .12126 .55605 Mtetra
.717 .463 0 r
.12126 .55605 .12212 .56006 .12349 .56203 .12228 .56099 Mtetra
.285 .607 .954 r
.12228 .56099 .12349 .56203 .12511 .56193 .12385 .56126 Mtetra
.639 .832 .974 r
.12385 .56126 .12511 .56193 .12679 .56134 .12553 .56069 Mtetra
.739 .849 .932 r
.12553 .56069 .12679 .56134 .12849 .56054 .12725 .55975 Mtetra
.411 .725 .989 r
.12725 .55975 .12849 .56054 .13012 .56037 .12886 .55971 Mtetra
.535 .805 .995 r
.12886 .55971 .13012 .56037 .13177 .56005 .13051 .5594 Mtetra
.748 .848 .925 r
.13051 .5594 .13177 .56005 .13347 .55932 .13224 .55841 Mtetra
.902 .757 .691 r
.13224 .55841 .13347 .55932 .13533 .55718 .13436 .55406 Mtetra
.936 .684 .531 r
.13436 .55406 .13533 .55718 .13739 .55333 .15894 .35472 Mtetra
.545 .315 .517 r
.15894 .35472 .13739 .55333 .14064 .53904 .16157 .34505 Mtetra
.527 .299 .513 r
.16157 .34505 .14064 .53904 .16394 .34844 .16333 .34292 Mtetra
.616 .45 .635 r
.16333 .34292 .16394 .34844 .16591 .34452 .16497 .34178 Mtetra
.635 .543 .734 r
.16497 .34178 .16591 .34452 .16768 .34227 .16657 .34108 Mtetra
.671 .72 .886 r
.16657 .34108 .16768 .34227 .16931 .34132 .16816 .34046 Mtetra
.644 .779 .946 r
.16816 .34046 .16931 .34132 .17088 .34083 .16974 .33995 Mtetra
.625 .771 .95 r
.16974 .33995 .17088 .34083 .17244 .34053 .17132 .3395 Mtetra
.732 .761 .877 r
.17132 .3395 .17244 .34053 .17405 .33978 .17294 .33858 Mtetra
.694 .724 .873 r
.17294 .33858 .17405 .33978 .17565 .3391 .17455 .33783 Mtetra
.561 .67 .911 r
.17455 .33783 .17565 .3391 .17721 .33874 .1761 .33763 Mtetra
.826 .364 0 r
.1761 .33763 .17721 .33874 .17866 .33948 .17736 .34003 Mtetra
.94 .681 .517 r
.17736 .34003 .17866 .33948 .17995 .34167 .15771 .53366 Mtetra
.551 .315 .511 r
.15771 .53366 .17995 .34167 .18046 .35106 .15781 .54768 Mtetra
.524 .292 .505 r
.15781 .54768 .18046 .35106 .16099 .54556 .15926 .54935 Mtetra
.517 .176 .328 r
.15926 .54935 .16099 .54556 .16224 .54906 .16087 .54966 Mtetra
.108 0 0 r
.16087 .54966 .16224 .54906 .16373 .55052 .16253 .54943 Mtetra
.481 .689 .959 r
.16253 .54943 .16373 .55052 .16533 .55081 .16417 .54937 Mtetra
.618 .678 .884 r
.16417 .54937 .16533 .55081 .16703 .55029 .16586 .54893 Mtetra
.745 .727 .835 r
.16586 .54893 .16703 .55029 .16882 .54891 .16763 .54775 Mtetra
.896 .742 .682 r
.16763 .54775 .16882 .54891 .17094 .54434 .16975 .54321 Mtetra
.942 .688 .523 r
.16975 .54321 .17094 .54434 .19387 .34093 .19278 .33965 Mtetra
.917 .715 .615 r
.19278 .33965 .19387 .34093 .19629 .33257 .19518 .33145 Mtetra
.822 .757 .791 r
.19518 .33145 .19629 .33257 .19802 .3307 .19691 .3296 Mtetra
.669 .739 .903 r
.19691 .3296 .19802 .3307 .19963 .33008 .19852 .32899 Mtetra
.538 .698 .943 r
.19852 .32899 .19963 .33008 .20119 .3299 .20008 .32882 Mtetra
.719 .754 .88 r
.20008 .32882 .20119 .3299 .20283 .32903 .20172 .32796 Mtetra
.714 .755 .885 r
.20172 .32796 .20283 .32903 .20446 .32819 .20335 .32713 Mtetra
.552 .709 .944 r
.20335 .32713 .20446 .32819 .20603 .32797 .20492 .32691 Mtetra
.871 .43 .053 r
.20492 .32691 .20603 .32797 .20729 .33083 .20618 .32978 Mtetra
.945 .684 .51 r
.20618 .32978 .20729 .33083 .18856 .53324 .18736 .53229 Mtetra
.942 .608 .366 r
.18736 .53229 .18856 .53324 .18945 .54087 .18826 .53985 Mtetra
.482 0 0 r
.18826 .53985 .18945 .54087 .19098 .54222 .18978 .5412 Mtetra
.555 .735 .959 r
.18978 .5412 .19098 .54222 .19266 .54196 .19147 .54093 Mtetra
.779 .784 .857 r
.19147 .54093 .19266 .54196 .19446 .54064 .19326 .53961 Mtetra
.9 .757 .694 r
.19326 .53961 .19446 .54064 .19653 .53647 .19534 .53543 Mtetra
.945 .688 .517 r
.19534 .53543 .19653 .53647 .21789 .33393 .21678 .33283 Mtetra
.929 .719 .598 r
.21678 .33283 .21789 .33393 .22041 .32402 .21931 .32293 Mtetra
.841 .762 .775 r
.21931 .32293 .22041 .32402 .22218 .3219 .22108 .32081 Mtetra
.677 .745 .902 r
.22108 .32081 .22218 .3219 .22381 .32125 .2227 .32015 Mtetra
.542 .701 .943 r
.2227 .32015 .22381 .32125 .22539 .32106 .22429 .31996 Mtetra
.701 .751 .89 r
.22429 .31996 .22539 .32106 .22702 .32029 .22592 .31919 Mtetra
.717 .754 .881 r
.22592 .31919 .22702 .32029 .22867 .31943 .22757 .31833 Mtetra
.573 .712 .937 r
.22757 .31833 .22867 .31943 .23026 .31916 .22916 .31806 Mtetra
.818 .353 0 r
.22916 .31806 .23026 .31916 .2316 .32164 .2305 .32054 Mtetra
.948 .684 .504 r
.2305 .32054 .2316 .32164 .21444 .5235 .21326 .52245 Mtetra
.947 .62 .375 r
.21326 .52245 .21444 .5235 .21531 .53223 .21413 .53118 Mtetra
.576 .055 0 r
.21413 .53118 .21531 .53223 .21685 .53382 .21566 .53278 Mtetra
.523 .721 .963 r
.21566 .53278 .21685 .53382 .21855 .53363 .21736 .53259 Mtetra
.766 .784 .868 r
.21736 .53259 .21855 .53363 .22034 .53242 .21916 .53138 Mtetra
.894 .764 .71 r
.21916 .53138 .22034 .53242 .22236 .52872 .22118 .52767 Mtetra
.948 .689 .512 r
.22118 .52767 .22236 .52872 .24173 .33173 .24064 .33046 Mtetra
.937 .707 .565 r
.24064 .33046 .24173 .33173 .24474 .31574 .24365 .31463 Mtetra
.856 .761 .757 r
.24365 .31463 .24474 .31574 .24654 .31331 .24545 .3122 Mtetra
.667 .741 .906 r
.24545 .3122 .24654 .31331 .24818 .3127 .24708 .31159 Mtetra
.493 .679 .948 r
.24708 .31159 .24818 .3127 .24976 .31263 .24867 .31153 Mtetra
.544 .7 .941 r
.24867 .31153 .24976 .31263 .25136 .31244 .25027 .31133 Mtetra
.622 .728 .923 r
.25027 .31133 .25136 .31244 .25299 .312 .2519 .3109 Mtetra
.629 .731 .921 r
.2519 .3109 .25299 .312 .25462 .31153 .25353 .31043 Mtetra
.649 .738 .915 r
.25353 .31043 .25462 .31153 .25625 .31099 .25516 .3099 Mtetra
.667 .745 .909 r
.25516 .3099 .25625 .31099 .25789 .31037 .2568 .30928 Mtetra
.677 .749 .905 r
.2568 .30928 .25789 .31037 .25954 .30971 .25845 .30863 Mtetra
.683 .751 .903 r
.25845 .30863 .25954 .30971 .26119 .30903 .2601 .30794 Mtetra
.688 .751 .9 r
.2601 .30794 .26119 .30903 .26284 .30833 .26175 .30723 Mtetra
.691 .75 .897 r
.26175 .30723 .26284 .30833 .2645 .30762 .26341 .3065 Mtetra
.693 .747 .893 r
.26341 .3065 .2645 .30762 .26615 .30691 .26507 .30577 Mtetra
.693 .742 .889 r
.26507 .30577 .26615 .30691 .26781 .3062 .26673 .30502 Mtetra
.692 .737 .885 r
.26673 .30502 .26781 .3062 .26947 .30546 .26839 .30428 Mtetra
.735 .746 .861 r
.26839 .30428 .26947 .30546 .27115 .3045 .27007 .30328 Mtetra
.735 .74 .855 r
.27007 .30328 .27115 .3045 .27283 .30348 .27175 .30226 Mtetra
.648 .715 .897 r
.27175 .30226 .27283 .30348 .27449 .30279 .2734 .30172 Mtetra
0 .154 .649 r
.2734 .30172 .27449 .30279 .27606 .30313 .27491 .3029 Mtetra
.924 .577 .359 r
.27491 .3029 .27606 .30313 .27751 .30511 .27598 .30961 Mtetra
.945 .677 .497 r
.27598 .30961 .27751 .30511 .27872 .31015 .26161 .51202 Mtetra
.526 .293 .505 r
.26161 .51202 .27872 .31015 .26591 .49487 .26313 .51459 Mtetra
.505 .253 .466 r
.26313 .51459 .26591 .49487 .28098 .32268 .26488 .51418 Mtetra
.518 .287 .503 r
.26488 .51418 .28098 .32268 .28303 .31709 .26668 .51321 Mtetra
.52 .288 .503 r
.26668 .51321 .28303 .31709 .27023 .50552 .26843 .51285 Mtetra
.526 .232 .41 r
.26843 .51285 .27023 .50552 .27148 .51168 .27012 .51326 Mtetra
.478 .033 .114 r
.27012 .51326 .27148 .51168 .27302 .51419 .27182 .51354 Mtetra
.403 .76 .994 r
.27182 .51354 .27302 .51419 .27469 .51489 .27356 .51343 Mtetra
.628 .686 .885 r
.27356 .51343 .27469 .51489 .27646 .51446 .27533 .51293 Mtetra
.652 .683 .867 r
.27533 .51293 .27646 .51446 .27824 .51372 .27711 .51231 Mtetra
.609 .687 .898 r
.27711 .51231 .27824 .51372 .28002 .51312 .27887 .5119 Mtetra
.562 .703 .935 r
.27887 .5119 .28002 .51312 .28178 .51274 .28062 .51164 Mtetra
.678 .764 .916 r
.28062 .51164 .28178 .51274 .28356 .51208 .28241 .51092 Mtetra
.844 .774 .784 r
.28241 .51092 .28356 .51208 .2854 .51064 .28431 .5087 Mtetra
.897 .705 .635 r
.28431 .5087 .2854 .51064 .28734 .50782 .28651 .50228 Mtetra
.949 .684 .499 r
.28651 .50228 .28734 .50782 .28946 .50253 .30284 .29721 Mtetra
.533 .304 .513 r
.30284 .29721 .28946 .50253 .30532 .30151 .30483 .2921 Mtetra
.604 .408 .59 r
.30483 .2921 .30532 .30151 .30748 .29401 .30659 .29033 Mtetra
.645 .512 .687 r
.30659 .29033 .30748 .29401 .30933 .29087 .30829 .28924 Mtetra
.679 .667 .831 r
.30829 .28924 .30933 .29087 .31108 .28918 .30998 .28846 Mtetra
.664 .83 .963 r
.30998 .28846 .31108 .28918 .31276 .28844 .31166 .28783 Mtetra
.607 .841 .988 r
.31166 .28783 .31276 .28844 .31442 .28802 .31332 .28733 Mtetra
.604 .821 .983 r
.31332 .28733 .31442 .28802 .31608 .28769 .31499 .28686 Mtetra
.631 .796 .962 r
.31499 .28686 .31608 .28769 .31774 .28727 .31666 .28635 Mtetra
.638 .777 .948 r
.31666 .28635 .31774 .28727 .31941 .28686 .31834 .28583 Mtetra
.653 .759 .927 r
.31834 .28583 .31941 .28686 .32108 .28638 .32002 .28526 Mtetra
.669 .745 .907 r
.32002 .28526 .32108 .28638 .32276 .28579 .3217 .28462 Mtetra
.675 .737 .897 r
.3217 .28462 .32276 .28579 .32445 .28514 .32339 .28395 Mtetra
.711 .744 .878 r
.32339 .28395 .32445 .28514 .32614 .2843 .32509 .28309 Mtetra
.738 .747 .859 r
.32509 .28309 .32614 .2843 .32785 .2833 .3268 .28205 Mtetra
.666 .721 .89 r
.3268 .28205 .32785 .2833 .32955 .28255 .32848 .28141 Mtetra
.132 .478 .897 r
.32848 .28141 .32955 .28255 .33119 .28257 .33009 .28202 Mtetra
.914 .521 .24 r
.33009 .28202 .33119 .28257 .33274 .28423 .33145 .28669 Mtetra
.954 .68 .48 r
.33145 .28669 .33274 .28423 .33415 .28812 .32051 .49101 Mtetra
.529 .296 .505 r
.32051 .49101 .33415 .28812 .33487 .30353 .32202 .49518 Mtetra
.52 .288 .503 r
.32202 .49518 .33487 .30353 .33683 .29864 .3238 .49492 Mtetra
.518 .287 .503 r
.3238 .49492 .33683 .29864 .33875 .2944 .32563 .49398 Mtetra
.519 .288 .503 r
.32563 .49398 .33875 .2944 .32929 .48244 .32744 .49333 Mtetra
.526 .25 .44 r
.32744 .49333 .32929 .48244 .33052 .49147 .32919 .49375 Mtetra
.499 .098 .211 r
.32919 .49375 .33052 .49147 .33212 .49443 .33094 .49406 Mtetra
.249 .728 .934 r
.33094 .49406 .33212 .49443 .33384 .49543 .33273 .494 Mtetra
.646 .701 .886 r
.33273 .494 .33384 .49543 .33565 .49489 .33454 .49341 Mtetra
.67 .702 .871 r
.33454 .49341 .33565 .49489 .33749 .49398 .33636 .49268 Mtetra
.639 .721 .907 r
.33636 .49268 .33749 .49398 .33931 .49319 .33817 .49213 Mtetra
.487 .708 .968 r
.33817 .49213 .33931 .49319 .3411 .49302 .33996 .49202 Mtetra
.622 .774 .953 r
.33996 .49202 .3411 .49302 .34291 .49261 .34178 .49151 Mtetra
.81 .791 .834 r
.34178 .49151 .34291 .49261 .34476 .49154 .34366 .48985 Mtetra
.901 .723 .651 r
.34366 .48985 .34476 .49154 .34668 .48895 .34574 .4844 Mtetra
.956 .686 .484 r
.34574 .4844 .34668 .48895 .34872 .48429 .35855 .2788 Mtetra
.537 .307 .514 r
.35855 .2788 .34872 .48429 .36103 .2847 .36059 .27203 Mtetra
.589 .384 .571 r
.36059 .27203 .36103 .2847 .36326 .27433 .36237 .27009 Mtetra
.638 .493 .668 r
.36237 .27009 .36326 .27433 .36512 .27084 .36411 .26891 Mtetra
.67 .632 .802 r
.36411 .26891 .36512 .27084 .36689 .26889 .36583 .26811 Mtetra
.67 .823 .957 r
.36583 .26811 .36689 .26889 .36861 .26806 .36754 .26745 Mtetra
.608 .844 .988 r
.36754 .26745 .36861 .26806 .37032 .2676 .36925 .26693 Mtetra
.591 .826 .989 r
.36925 .26693 .37032 .2676 .37201 .26729 .37095 .26647 Mtetra
.625 .801 .967 r
.37095 .26647 .37201 .26729 .37372 .26687 .37266 .26596 Mtetra
.632 .783 .954 r
.37266 .26596 .37372 .26687 .37542 .26646 .37437 .26544 Mtetra
.646 .763 .934 r
.37437 .26544 .37542 .26646 .37713 .26601 .37608 .26489 Mtetra
.666 .748 .911 r
.37608 .26489 .37713 .26601 .37884 .26544 .3778 .26425 Mtetra
.673 .738 .899 r
.3778 .26425 .37884 .26544 .38056 .2648 .37952 .26358 Mtetra
.694 .74 .886 r
.37952 .26358 .38056 .2648 .38229 .26402 .38125 .26279 Mtetra
.748 .752 .856 r
.38125 .26279 .38229 .26402 .38403 .26295 .38299 .26167 Mtetra
.687 .728 .881 r
.38299 .26167 .38403 .26295 .38576 .2621 .38472 .26092 Mtetra
.426 .637 .944 r
.38472 .26092 .38576 .2621 .38747 .26178 .38641 .26103 Mtetra
.873 .432 .076 r
.38641 .26103 .38747 .26178 .38912 .26286 .38795 .26452 Mtetra
.96 .681 .463 r
.38795 .26452 .38912 .26286 .39069 .2658 .3807 .46874 Mtetra
.534 .3 .506 r
.3807 .46874 .39069 .2658 .38389 .46374 .38222 .47567 Mtetra
.543 .268 .449 r
.38222 .47567 .38389 .46374 .38527 .47403 .384 .47662 Mtetra
.468 .08 .221 r
.384 .47662 .38527 .47403 .38698 .47674 .38582 .4767 Mtetra
.291 .787 .865 r
.38582 .4767 .38698 .47674 .38876 .47779 .38766 .47634 Mtetra
.627 .694 .893 r
.38766 .47634 .38876 .47779 .3906 .47746 .38951 .47583 Mtetra
.652 .676 .86 r
.38951 .47583 .3906 .47746 .39245 .47676 .39136 .47517 Mtetra
.659 .685 .864 r
.39136 .47517 .39245 .47676 .39432 .47595 .39322 .47448 Mtetra
.624 .691 .893 r
.39322 .47448 .39432 .47595 .39616 .47552 .39507 .47399 Mtetra
.623 .68 .884 r
.39507 .47399 .39616 .47552 .39801 .47508 .39692 .47349 Mtetra
.629 .674 .874 r
.39692 .47349 .39801 .47508 .39987 .47457 .39877 .47296 Mtetra
.65 .68 .865 r
.39877 .47296 .39987 .47457 .40173 .47384 .40063 .47232 Mtetra
.658 .695 .873 r
.40063 .47232 .40173 .47384 .40359 .47306 .4025 .47164 Mtetra
.655 .711 .888 r
.4025 .47164 .40359 .47306 .40546 .4723 .40436 .47099 Mtetra
.546 .686 .931 r
.40436 .47099 .40546 .4723 .40731 .47192 .40621 .47078 Mtetra
.632 .753 .935 r
.40621 .47078 .40731 .47192 .40918 .47136 .40807 .47023 Mtetra
.767 .791 .872 r
.40807 .47023 .40918 .47136 .41105 .47036 .40996 .46896 Mtetra
.913 .75 .665 r
.40996 .46896 .41105 .47036 .41299 .46757 .41197 .46412 Mtetra
.963 .687 .464 r
.41197 .46412 .41299 .46757 .41499 .46302 .42074 .25927 Mtetra
.542 .311 .514 r
.42074 .25927 .41499 .46302 .41722 .45125 .42279 .24974 Mtetra
.525 .297 .512 r
.42279 .24974 .41722 .45125 .42503 .26662 .42456 .24833 Mtetra
.538 .333 .549 r
.42456 .24833 .42503 .26662 .4266 .27198 .42631 .24781 Mtetra
.526 .316 .538 r
.42631 .24781 .4266 .27198 .4228 .44978 .42804 .24777 Mtetra
.523 .296 .511 r
.42804 .24777 .4228 .44978 .42464 .44972 .42979 .24717 Mtetra
.42979 .24717 .42464 .44972 .42649 .44964 .43154 .24658 Mtetra
.43154 .24658 .42649 .44964 .42835 .44945 .4333 .246 Mtetra
.523 .295 .511 r
.4333 .246 .42835 .44945 .43013 .45196 .43505 .24556 Mtetra
.523 .296 .511 r
.43505 .24556 .43013 .45196 .43198 .45191 .4368 .245 Mtetra
.4368 .245 .43198 .45191 .43396 .44766 .43856 .24418 Mtetra
.525 .297 .512 r
.43856 .24418 .43396 .44766 .44124 .2484 .44035 .2426 Mtetra
.631 .459 .631 r
.44035 .2426 .44124 .2484 .44312 .24347 .44213 .24106 Mtetra
.708 .613 .748 r
.44213 .24106 .44312 .24347 .44493 .24071 .44391 .23974 Mtetra
.679 .79 .933 r
.44391 .23974 .44493 .24071 .4467 .23981 .44567 .23903 Mtetra
.622 .815 .975 r
.44567 .23903 .4467 .23981 .44846 .23938 .44743 .2385 Mtetra
.607 .788 .968 r
.44743 .2385 .44846 .23938 .45021 .23916 .44919 .23803 Mtetra
.662 .753 .918 r
.44919 .23803 .45021 .23916 .45197 .23859 .45096 .2374 Mtetra
.671 .744 .905 r
.45096 .2374 .45197 .23859 .45374 .23794 .45272 .23672 Mtetra
.677 .74 .898 r
.45272 .23672 .45374 .23794 .4555 .23723 .45449 .23601 Mtetra
.75 .761 .862 r
.45449 .23601 .4555 .23723 .45728 .23616 .45627 .23488 Mtetra
.706 .738 .876 r
.45627 .23488 .45728 .23616 .45906 .23524 .45805 .234 Mtetra
.578 .699 .925 r
.45805 .234 .45906 .23524 .46082 .23469 .45981 .23369 Mtetra
.701 .211 0 r
.45981 .23369 .46082 .23469 .46257 .23541 .46152 .2361 Mtetra
.967 .681 .436 r
.46152 .2361 .46257 .23541 .46428 .23757 .45936 .43087 Mtetra
.556 .317 .509 r
.45936 .43087 .46428 .23757 .46588 .24619 .46088 .44904 Mtetra
.524 .291 .504 r
.46088 .44904 .46588 .24619 .46391 .44678 .46273 .45063 Mtetra
.505 .157 .311 r
.46273 .45063 .46391 .44678 .46573 .45037 .46462 .45087 Mtetra
.044 0 0 r
.46462 .45087 .46573 .45037 .4676 .45179 .46652 .45056 Mtetra
.634 .741 .925 r
.46652 .45056 .4676 .45179 .4695 .45153 .46842 .44999 Mtetra
.667 .702 .873 r
.46842 .44999 .4695 .45153 .47141 .45068 .47033 .44926 Mtetra
.683 .724 .881 r
.47033 .44926 .47141 .45068 .47332 .44962 .47224 .44844 Mtetra
.521 .706 .955 r
.47224 .44844 .47332 .44962 .47523 .44931 .47415 .44827 Mtetra
.565 .753 .966 r
.47415 .44827 .47523 .44931 .47713 .44898 .47605 .44792 Mtetra
.717 .798 .915 r
.47605 .44792 .47713 .44898 .47904 .44828 .47797 .44696 Mtetra
.904 .771 .704 r
.47797 .44696 .47904 .44828 .48098 .44623 .47993 .4432 Mtetra
.935 .687 .539 r
.47993 .4432 .48098 .44623 .48293 .44259 .48204 .42793 Mtetra
.957 .672 .457 r
.48204 .42793 .48293 .44259 .48495 .4335 .48646 .22739 Mtetra
.528 .299 .512 r
.48646 .22739 .48495 .4335 .48922 .23055 .48828 .22454 Mtetra
.623 .45 .628 r
.48828 .22454 .48922 .23055 .49106 .22588 .49008 .22311 Mtetra
.652 .561 .74 r
.49008 .22311 .49106 .22588 .49287 .22336 .49187 .22219 Mtetra
.667 .75 .913 r
.49187 .22219 .49287 .22336 .49466 .22233 .49366 .22153 Mtetra
.61 .81 .977 r
.49366 .22153 .49466 .22233 .49645 .2219 .49546 .22102 Mtetra
.59 .786 .974 r
.49546 .22102 .49645 .2219 .49824 .22171 .49725 .2206 Mtetra
.652 .756 .926 r
.49725 .2206 .49824 .22171 .50004 .22121 .49905 .21999 Mtetra
.673 .743 .903 r
.49905 .21999 .50004 .22121 .50184 .22055 .50084 .21929 Mtetra
.68 .739 .895 r
.50084 .21929 .50184 .22055 .50363 .21982 .50264 .21855 Mtetra
.756 .76 .856 r
.50264 .21855 .50363 .21982 .50544 .21855 .50445 .21735 Mtetra
.732 .766 .88 r
.50445 .21735 .50544 .21855 .50724 .21746 .50625 .21634 Mtetra
.588 .731 .942 r
.50625 .21634 .50724 .21746 .50904 .21704 .50805 .21597 Mtetra
.728 .255 0 r
.50805 .21597 .50904 .21704 .51083 .21991 .50984 .21878 Mtetra
.972 .681 .415 r
.50984 .21878 .51083 .21991 .51179 .42845 .51073 .42664 Mtetra
.925 .557 .138 r
.51073 .42664 .51179 .42845 .51369 .43615 .51263 .43464 Mtetra
.151 .432 .869 r
.51263 .43464 .51369 .43615 .51562 .43696 .51457 .43554 Mtetra
.649 .716 .897 r
.51457 .43554 .51562 .43696 .51756 .43621 .51651 .43489 Mtetra
.739 .764 .873 r
.51651 .43489 .51756 .43621 .5195 .43495 .51845 .43375 Mtetra
.568 .724 .947 r
.51845 .43375 .5195 .43495 .52145 .43463 .52039 .43342 Mtetra
.547 .713 .949 r
.52039 .43342 .52145 .43463 .52339 .43444 .52233 .43316 Mtetra
.706 .762 .895 r
.52233 .43316 .52339 .43444 .52533 .43356 .52428 .43223 Mtetra
.917 .773 .688 r
.52428 .43223 .52533 .43356 .52728 .42935 .52622 .42809 Mtetra
.973 .688 .424 r
.52622 .42809 .52728 .42935 .52894 .21997 .52796 .21971 Mtetra
.985 .768 .528 r
.52796 .21971 .52894 .21997 .53075 .2103 .52977 .20943 Mtetra
.88 .84 .801 r
.52977 .20943 .53075 .2103 .53256 .20818 .53158 .20723 Mtetra
.658 .796 .949 r
.53158 .20723 .53256 .20818 .53438 .20762 .5334 .20659 Mtetra
.507 .717 .966 r
.5334 .20659 .53438 .20762 .5362 .20757 .53522 .20643 Mtetra
.606 .737 .938 r
.53522 .20643 .5362 .20757 .53802 .20721 .53704 .20599 Mtetra
.667 .744 .908 r
.53704 .20599 .53802 .20721 .53984 .20657 .53887 .20531 Mtetra
.674 .739 .9 r
.53887 .20531 .53984 .20657 .54167 .20586 .54069 .20459 Mtetra
.745 .76 .865 r
.54069 .20459 .54167 .20586 .54349 .20468 .54251 .20346 Mtetra
.739 .768 .877 r
.54251 .20346 .54349 .20468 .54531 .20354 .54434 .20239 Mtetra
.616 .74 .935 r
.54434 .20239 .54531 .20354 .54714 .20301 .54616 .20192 Mtetra
.551 .071 0 r
.54616 .20192 .54714 .20301 .54899 .20521 .54801 .20407 Mtetra
.974 .679 .4 r
.54801 .20407 .54899 .20521 .55259 .41186 .55155 .40963 Mtetra
.939 .593 .175 r
.55155 .40963 .55259 .41186 .55465 .4223 .55361 .42075 Mtetra
0 .292 .791 r
.55361 .42075 .55465 .4223 .55663 .4236 .55559 .42214 Mtetra
.629 .705 .9 r
.55559 .42214 .55663 .4236 .5586 .42293 .55756 .42158 Mtetra
.73 .759 .876 r
.55756 .42158 .5586 .42293 .56057 .42171 .55953 .42047 Mtetra
.607 .736 .936 r
.55953 .42047 .56057 .42171 .56254 .42122 .5615 .42 Mtetra
.529 .704 .951 r
.5615 .42 .56254 .42122 .56452 .42108 .56348 .41979 Mtetra
.686 .756 .905 r
.56348 .41979 .56452 .42108 .56649 .42031 .56545 .41896 Mtetra
.904 .782 .716 r
.56545 .41896 .56649 .42031 .56843 .41677 .56739 .41546 Mtetra
.975 .686 .409 r
.56739 .41546 .56843 .41677 .56753 .21183 .5666 .21382 Mtetra
.995 .764 .416 r
.5666 .21382 .56753 .21183 .56917 .19685 .56821 .19598 Mtetra
.908 .837 .764 r
.56821 .19598 .56917 .19685 .57098 .19426 .57003 .1933 Mtetra
.677 .803 .942 r
.57003 .1933 .57098 .19426 .57283 .19362 .57187 .19256 Mtetra
.524 .723 .964 r
.57187 .19256 .57283 .19362 .57468 .19352 .57372 .19236 Mtetra
.588 .728 .94 r
.57372 .19236 .57468 .19352 .57653 .19323 .57557 .19198 Mtetra
.67 .743 .905 r
.57557 .19198 .57653 .19323 .57838 .19257 .57742 .19128 Mtetra
.677 .738 .896 r
.57742 .19128 .57838 .19257 .58023 .19184 .57927 .19053 Mtetra
.739 .756 .867 r
.57927 .19053 .58023 .19184 .58207 .19069 .58111 .18943 Mtetra
.748 .767 .868 r
.58111 .18943 .58207 .19069 .58391 .18946 .58295 .18828 Mtetra
.646 .747 .923 r
.58295 .18828 .58391 .18946 .58576 .18881 .58481 .18768 Mtetra
0 .163 .677 r
.58481 .18768 .58576 .18881 .58766 .1904 .58671 .18923 Mtetra
.963 .631 .294 r
.58671 .18923 .58766 .1904 .59372 .38586 .58897 .20759 Mtetra
0 0 .309 r
.58897 .20759 .59372 .38586 .59621 .40806 .59518 .40642 Mtetra
0 .084 .637 r
.59518 .40642 .59621 .40806 .59826 .41004 .59724 .40859 Mtetra
.557 .677 .919 r
.59724 .40859 .59826 .41004 .60027 .40959 .59924 .40833 Mtetra
.764 .788 .872 r
.59924 .40833 .60027 .40959 .60225 .40825 .60123 .40701 Mtetra
.901 .801 .739 r
.60123 .40701 .60225 .40825 .60421 .40613 .60317 .40387 Mtetra
.941 .714 .566 r
.60317 .40387 .60421 .40613 .60615 .40289 .60496 .39469 Mtetra
.971 .677 .406 r
.60496 .39469 .60615 .40289 .608 .39641 .60167 .18664 Mtetra
.53 .301 .512 r
.60167 .18664 .608 .39641 .60459 .19124 .60345 .18265 Mtetra
.599 .409 .596 r
.60345 .18265 .60459 .19124 .60631 .18517 .60529 .18109 Mtetra
.623 .491 .681 r
.60529 .18109 .60631 .18517 .60812 .18221 .60715 .18012 Mtetra
.649 .618 .806 r
.60715 .18012 .60812 .18221 .60996 .18062 .60902 .1794 Mtetra
.65 .745 .919 r
.60902 .1794 .60996 .18062 .61183 .1799 .61089 .17878 Mtetra
.624 .753 .939 r
.61089 .17878 .61183 .1799 .61371 .17949 .61277 .17826 Mtetra
.632 .735 .922 r
.61277 .17826 .61371 .17949 .61559 .17905 .61464 .17771 Mtetra
.652 .723 .901 r
.61464 .17771 .61559 .17905 .61746 .17843 .61652 .17708 Mtetra
.658 .723 .897 r
.61652 .17708 .61746 .17843 .61934 .17778 .6184 .17642 Mtetra
.666 .724 .893 r
.6184 .17642 .61934 .17778 .62122 .17708 .62027 .17571 Mtetra
.674 .727 .889 r
.62027 .17571 .62122 .17708 .62309 .17633 .62215 .17497 Mtetra
.677 .729 .889 r
.62215 .17497 .62309 .17633 .62497 .17556 .62403 .1742 Mtetra
.718 .746 .873 r
.62403 .1742 .62497 .17556 .62683 .17455 .6259 .17321 Mtetra
.741 .756 .865 r
.6259 .17321 .62683 .17455 .6287 .1734 .62776 .17208 Mtetra
.651 .726 .904 r
.62776 .17208 .6287 .1734 .63058 .17276 .62965 .17144 Mtetra
.054 .385 .847 r
.62965 .17144 .63058 .17276 .63253 .17382 .63159 .17249 Mtetra
.92 .546 .128 r
.63159 .17249 .63253 .17382 .63477 .18297 .63382 .18126 Mtetra
.976 .673 .359 r
.63382 .18126 .63477 .18297 .64443 .39088 .64343 .38955 Mtetra
0 0 .445 r
.64343 .38955 .64443 .39088 .64659 .39369 .64559 .39234 Mtetra
.535 .688 .937 r
.64559 .39234 .64659 .39369 .64864 .39359 .64764 .39213 Mtetra
.7 .74 .883 r
.64764 .39213 .64864 .39359 .65066 .39259 .64966 .39118 Mtetra
.73 .759 .876 r
.64966 .39118 .65066 .39259 .65265 .39072 .65168 .39004 Mtetra
.695 .891 .969 r
.65168 .39004 .65265 .39072 .65459 .38766 .6537 .3891 Mtetra
0 0 0 r
.6537 .3891 .65459 .38766 .65641 .38181 .65571 .38756 Mtetra
.184 0 .283 r
.65571 .38756 .65641 .38181 .64991 .17633 .65763 .38402 Mtetra
0 0 .362 r
.65763 .38402 .64991 .17633 .65154 .16937 .65105 .17852 Mtetra
0 0 .173 r
.65105 .17852 .65154 .16937 .65334 .16624 .65247 .16625 Mtetra
.956 .949 .703 r
.65247 .16625 .65334 .16624 .65519 .16446 .65426 .16313 Mtetra
.71 .749 .883 r
.65426 .16313 .65519 .16446 .65708 .16364 .65615 .16219 Mtetra
.607 .685 .898 r
.65615 .16219 .65708 .16364 .65899 .16313 .65807 .16175 Mtetra
.599 .696 .911 r
.65807 .16175 .65899 .16313 .6609 .16254 .65998 .16134 Mtetra
.692 .769 .91 r
.65998 .16134 .6609 .16254 .66279 .16157 .66188 .16051 Mtetra
.677 .791 .935 r
.66188 .16051 .66279 .16157 .6647 .16085 .66379 .15976 Mtetra
.651 .774 .938 r
.66379 .15976 .6647 .16085 .66663 .16079 .6657 .15911 Mtetra
.616 .656 .866 r
.6657 .15911 .66663 .16079 .66864 .16218 .66761 .15863 Mtetra
.53 .454 .714 r
.66761 .15863 .66864 .16218 .67078 .16618 .66956 .15867 Mtetra
.43 .302 .604 r
.66956 .15867 .67078 .16618 .68285 .37064 .67159 .16038 Mtetra
0 0 .383 r
.67159 .16038 .68285 .37064 .68524 .37675 .68371 .36447 Mtetra
0 0 .461 r
.68371 .36447 .68524 .37675 .68744 .3789 .68638 .37611 Mtetra
.024 .185 .694 r
.68638 .37611 .68744 .3789 .68958 .37983 .6886 .37857 Mtetra
.382 .627 .95 r
.6886 .37857 .68958 .37983 .69169 .38002 .69072 .37879 Mtetra
.675 .775 .926 r
.69072 .37879 .69169 .38002 .69376 .37938 .69278 .37799 Mtetra
.862 .796 .785 r
.69278 .37799 .69376 .37938 .69574 .37717 .69475 .37556 Mtetra
.969 .746 .544 r
.69475 .37556 .69574 .37717 .69737 .36841 .69637 .36654 Mtetra
.977 .676 .355 r
.69637 .36654 .69737 .36841 .68783 .15562 .68692 .15441 Mtetra
.948 .795 .659 r
.68692 .15441 .68783 .15562 .68955 .1512 .68865 .15006 Mtetra
.725 .794 .906 r
.68865 .15006 .68955 .1512 .69146 .15025 .69056 .14906 Mtetra
.57 .721 .944 r
.69056 .14906 .69146 .15025 .69341 .14999 .6925 .14873 Mtetra
.512 .679 .941 r
.6925 .14873 .69341 .14999 .69537 .14993 .69446 .1486 Mtetra
.644 .729 .91 r
.69446 .1486 .69537 .14993 .6973 .14929 .69639 .14799 Mtetra
.655 .736 .91 r
.69639 .14799 .6973 .14929 .69923 .14859 .69833 .14732 Mtetra
.676 .753 .909 r
.69833 .14732 .69923 .14859 .70115 .14773 .70025 .14656 Mtetra
.715 .787 .909 r
.70025 .14656 .70115 .14773 .70305 .14655 .70217 .14561 Mtetra
.701 .831 .945 r
.70217 .14561 .70305 .14655 .70497 .14561 .70409 .14474 Mtetra
.658 .83 .966 r
.70409 .14474 .70497 .14561 .70692 .14526 .70603 .14402 Mtetra
.607 .731 .933 r
.70603 .14402 .70692 .14526 .70898 .14643 .70798 .14356 Mtetra
.527 .49 .759 r
.70798 .14356 .70898 .14643 .71116 .14971 .70996 .1436 Mtetra
.438 .327 .63 r
.70996 .1436 .71116 .14971 .72607 .35368 .71203 .14492 Mtetra
.484 .267 .508 r
.71203 .14492 .72607 .35368 .72873 .362 .71518 .16322 Mtetra
0 0 .392 r
.71518 .16322 .72873 .362 .73102 .36444 .72994 .36121 Mtetra
.04 .166 .669 r
.72994 .36121 .73102 .36444 .73322 .36541 .73226 .36407 Mtetra
.475 .664 .945 r
.73226 .36407 .73322 .36541 .73536 .36545 .7344 .36405 Mtetra
.657 .741 .912 r
.7344 .36405 .73536 .36545 .73746 .36487 .73649 .36333 Mtetra
.724 .743 .867 r
.73649 .36333 .73746 .36487 .73952 .36358 .73856 .36218 Mtetra
.708 .761 .894 r
.73856 .36218 .73952 .36358 .74148 .3608 .74064 .36117 Mtetra
.574 .916 .701 r
.74064 .36117 .74148 .3608 .74328 .35579 .74268 .35958 Mtetra
.104 0 .191 r
.74268 .35958 .74328 .35579 .73114 .14982 .74463 .35663 Mtetra
.48 .259 .5 r
.74463 .35663 .73114 .14982 .73245 .13991 .74525 .33476 Mtetra
0 0 .385 r
.74525 .33476 .73245 .13991 .73421 .13636 .73345 .13696 Mtetra
.907 .925 .541 r
.73345 .13696 .73421 .13636 .73606 .13427 .73519 .13316 Mtetra
.731 .806 .911 r
.73519 .13316 .73606 .13427 .73801 .13348 .73712 .13212 Mtetra
.607 .708 .916 r
.73712 .13212 .73801 .13348 .73999 .13305 .7391 .13166 Mtetra
.544 .671 .921 r
.7391 .13166 .73999 .13305 .74197 .13274 .74109 .13145 Mtetra
.663 .747 .912 r
.74109 .13145 .74197 .13274 .74393 .13193 .74305 .13074 Mtetra
.67 .769 .925 r
.74305 .13074 .74393 .13193 .74587 .13106 .74501 .12999 Mtetra
.673 .797 .941 r
.74501 .12999 .74587 .13106 .74782 .13019 .74697 .12924 Mtetra
.686 .827 .951 r
.74697 .12924 .74782 .13019 .74977 .1292 .74893 .12841 Mtetra
.655 .856 .977 r
.74893 .12841 .74977 .1292 .75173 .12844 .75089 .12767 Mtetra
.6 .838 .989 r
.75089 .12767 .75173 .12844 .75372 .12813 .75287 .1271 Mtetra
.433 .691 .973 r
.75287 .1271 .75372 .12813 .75587 .12964 .75489 .12711 Mtetra
.496 .498 .789 r
.75489 .12711 .75587 .12964 .75819 .13346 .75694 .12731 Mtetra
.519 .382 .633 r
.75694 .12731 .75819 .13346 .77639 .33648 .75898 .12753 Mtetra
.523 .296 .511 r
.75898 .12753 .77639 .33648 .77875 .33888 .76096 .12691 Mtetra
.76096 .12691 .77875 .33888 .7808 .33722 .76292 .12601 Mtetra
.524 .296 .511 r
.76292 .12601 .7808 .33722 .78255 .33206 .76488 .12498 Mtetra
.615 .497 .695 r
.1324 .3518 .13324 .35528 .13482 .35455 .13398 .35112 Mtetra
.616 .499 .697 r
.13398 .35112 .13482 .35455 .13641 .35383 .13556 .35045 Mtetra
.617 .502 .699 r
.13556 .35045 .13641 .35383 .13799 .35312 .13714 .34977 Mtetra
.658 .529 .695 r
.13714 .34977 .13799 .35312 .13964 .35191 .13877 .34865 Mtetra
.631 .515 .704 r
.13877 .34865 .13964 .35191 .14124 .35111 .14037 .34786 Mtetra
.56 .471 .712 r
.14037 .34786 .14124 .35111 .14275 .35104 .14189 .34769 Mtetra
0 0 .388 r
.14189 .34769 .14275 .35104 .14371 .35555 .14302 .35083 Mtetra
.943 .688 .522 r
.14302 .35083 .14371 .35555 .12126 .55605 .12044 .55174 Mtetra
.95 .665 .217 r
.12044 .55174 .12126 .55605 .12228 .56099 .12105 .56002 Mtetra
.093 .509 .904 r
.12105 .56002 .12228 .56099 .12385 .56126 .1226 .56051 Mtetra
.64 .815 .967 r
.1226 .56051 .12385 .56126 .12553 .56069 .12428 .55996 Mtetra
.75 .831 .914 r
.12428 .55996 .12553 .56069 .12725 .55975 .12601 .55895 Mtetra
.318 .678 .977 r
.12601 .55895 .12725 .55975 .12886 .55971 .1276 .55906 Mtetra
.495 .791 .998 r
.1276 .55906 .12886 .55971 .13051 .5594 .12925 .55882 Mtetra
.76 .863 .925 r
.12925 .55882 .13051 .5594 .13224 .55841 .13098 .55777 Mtetra
.924 .758 .657 r
.13098 .55777 .13224 .55841 .13436 .55406 .13328 .55192 Mtetra
.938 .685 .53 r
.13328 .55192 .13436 .55406 .15894 .35472 .15852 .34748 Mtetra
.746 .531 .604 r
.15852 .34748 .15894 .35472 .16157 .34505 .16071 .34164 Mtetra
.67 .535 .69 r
.16071 .34164 .16157 .34505 .16333 .34292 .16238 .34034 Mtetra
.598 .532 .752 r
.16238 .34034 .16333 .34292 .16497 .34178 .16394 .33994 Mtetra
.517 .559 .838 r
.16394 .33994 .16497 .34178 .16657 .34108 .16546 .33996 Mtetra
.624 .72 .916 r
.16546 .33996 .16657 .34108 .16816 .34046 .16703 .33953 Mtetra
.651 .768 .935 r
.16703 .33953 .16816 .34046 .16974 .33995 .16861 .339 Mtetra
.662 .766 .928 r
.16861 .339 .16974 .33995 .17132 .3395 .17019 .33843 Mtetra
.755 .759 .856 r
.17019 .33843 .17132 .3395 .17294 .33858 .17184 .33733 Mtetra
.711 .723 .859 r
.17184 .33733 .17294 .33858 .17455 .33783 .17346 .33648 Mtetra
.56 .655 .899 r
.17346 .33648 .17455 .33783 .1761 .33763 .17501 .33629 Mtetra
.908 .502 .127 r
.17501 .33629 .1761 .33763 .17736 .34003 .17615 .33979 Mtetra
.941 .682 .517 r
.17615 .33979 .17736 .34003 .15771 .53366 .15535 .54316 Mtetra
.701 .415 .488 r
.15535 .54316 .15771 .53366 .15781 .54768 .1563 .54941 Mtetra
.546 .125 .193 r
.1563 .54941 .15781 .54768 .15926 .54935 .15787 .54998 Mtetra
0 0 0 r
.15787 .54998 .15926 .54935 .16087 .54966 .15958 .54934 Mtetra
.765 .919 .94 r
.15958 .54934 .16087 .54966 .16253 .54943 .16134 .54824 Mtetra
.564 .703 .934 r
.16134 .54824 .16253 .54943 .16417 .54937 .16301 .54798 Mtetra
.595 .679 .9 r
.16301 .54798 .16417 .54937 .16586 .54893 .16468 .54765 Mtetra
.727 .733 .856 r
.16468 .54765 .16586 .54893 .16763 .54775 .16644 .54663 Mtetra
.898 .745 .683 r
.16644 .54663 .16763 .54775 .16975 .54321 .16856 .54212 Mtetra
.942 .688 .523 r
.16856 .54212 .16975 .54321 .19278 .33965 .19167 .33846 Mtetra
.919 .719 .616 r
.19167 .33846 .19278 .33965 .19518 .33145 .19407 .33034 Mtetra
.822 .758 .792 r
.19407 .33034 .19518 .33145 .19691 .3296 .1958 .32851 Mtetra
.667 .74 .904 r
.1958 .32851 .19691 .3296 .19852 .32899 .19741 .32791 Mtetra
.536 .698 .944 r
.19741 .32791 .19852 .32899 .20008 .32882 .19897 .32774 Mtetra
.718 .754 .88 r
.19897 .32774 .20008 .32882 .20172 .32796 .20061 .32688 Mtetra
.713 .754 .885 r
.20061 .32688 .20172 .32796 .20335 .32713 .20224 .32605 Mtetra
.551 .707 .943 r
.20224 .32605 .20335 .32713 .20492 .32691 .20381 .32584 Mtetra
.871 .432 .054 r
.20381 .32584 .20492 .32691 .20618 .32978 .20507 .32872 Mtetra
.945 .684 .51 r
.20507 .32872 .20618 .32978 .18736 .53229 .18616 .53131 Mtetra
.943 .608 .364 r
.18616 .53131 .18736 .53229 .18826 .53985 .18706 .53883 Mtetra
.478 0 0 r
.18706 .53883 .18826 .53985 .18978 .5412 .18858 .54017 Mtetra
.556 .735 .959 r
.18858 .54017 .18978 .5412 .19147 .54093 .19027 .5399 Mtetra
.78 .784 .856 r
.19027 .5399 .19147 .54093 .19326 .53961 .19207 .53858 Mtetra
.9 .757 .694 r
.19207 .53858 .19326 .53961 .19534 .53543 .19414 .5344 Mtetra
.945 .688 .517 r
.19414 .5344 .19534 .53543 .21678 .33283 .21568 .33173 Mtetra
.929 .719 .598 r
.21568 .33173 .21678 .33283 .21931 .32293 .21821 .32184 Mtetra
.841 .762 .775 r
.21821 .32184 .21931 .32293 .22108 .32081 .21998 .31971 Mtetra
.678 .745 .902 r
.21998 .31971 .22108 .32081 .2227 .32015 .2216 .31906 Mtetra
.543 .701 .943 r
.2216 .31906 .2227 .32015 .22429 .31996 .22318 .31887 Mtetra
.701 .75 .89 r
.22318 .31887 .22429 .31996 .22592 .31919 .22482 .3181 Mtetra
.717 .754 .881 r
.22482 .3181 .22592 .31919 .22757 .31833 .22647 .31724 Mtetra
.573 .712 .937 r
.22647 .31724 .22757 .31833 .22916 .31806 .22806 .31696 Mtetra
.817 .352 0 r
.22806 .31696 .22916 .31806 .2305 .32054 .2294 .31944 Mtetra
.948 .684 .504 r
.2294 .31944 .2305 .32054 .21326 .52245 .21208 .52138 Mtetra
.948 .621 .375 r
.21208 .52138 .21326 .52245 .21413 .53118 .21294 .53014 Mtetra
.575 .055 0 r
.21294 .53014 .21413 .53118 .21566 .53278 .21448 .53173 Mtetra
.524 .72 .963 r
.21448 .53173 .21566 .53278 .21736 .53259 .21618 .53155 Mtetra
.766 .784 .868 r
.21618 .53155 .21736 .53259 .21916 .53138 .21797 .53033 Mtetra
.894 .763 .71 r
.21797 .53033 .21916 .53138 .22118 .52767 .22 .52662 Mtetra
.948 .689 .512 r
.22 .52662 .22118 .52767 .24064 .33046 .23956 .32909 Mtetra
.935 .705 .566 r
.23956 .32909 .24064 .33046 .24365 .31463 .24255 .31352 Mtetra
.855 .76 .757 r
.24255 .31352 .24365 .31463 .24545 .3122 .24435 .31109 Mtetra
.667 .74 .904 r
.24435 .31109 .24545 .3122 .24708 .31159 .24599 .31047 Mtetra
.496 .678 .947 r
.24599 .31047 .24708 .31159 .24867 .31153 .24758 .3104 Mtetra
.547 .698 .939 r
.24758 .3104 .24867 .31153 .25027 .31133 .24918 .3102 Mtetra
.624 .725 .919 r
.24918 .3102 .25027 .31133 .2519 .3109 .25081 .30976 Mtetra
.631 .726 .916 r
.25081 .30976 .2519 .3109 .25353 .31043 .25244 .30929 Mtetra
.65 .73 .908 r
.25244 .30929 .25353 .31043 .25516 .3099 .25407 .30875 Mtetra
.667 .734 .9 r
.25407 .30875 .25516 .3099 .2568 .30928 .25572 .30813 Mtetra
.676 .736 .895 r
.25572 .30813 .2568 .30928 .25845 .30863 .25736 .30747 Mtetra
.682 .737 .892 r
.25736 .30747 .25845 .30863 .2601 .30794 .25902 .30678 Mtetra
.687 .738 .889 r
.25902 .30678 .2601 .30794 .26175 .30723 .26067 .30606 Mtetra
.692 .738 .886 r
.26067 .30606 .26175 .30723 .26341 .3065 .26233 .30532 Mtetra
.711 .74 .874 r
.26233 .30532 .26341 .3065 .26507 .30577 .264 .30447 Mtetra
.711 .721 .858 r
.264 .30447 .26507 .30577 .26673 .30502 .26567 .30359 Mtetra
.684 .693 .852 r
.26567 .30359 .26673 .30502 .26839 .30428 .26733 .30284 Mtetra
.66 .684 .862 r
.26733 .30284 .26839 .30428 .27007 .30328 .26898 .30222 Mtetra
.587 .728 .941 r
.26898 .30222 .27007 .30328 .27175 .30226 .27061 .30189 Mtetra
0 .513 .791 r
.27061 .30189 .27175 .30226 .2734 .30172 .27219 .3022 Mtetra
.832 .424 .271 r
.27219 .3022 .2734 .30172 .27491 .3029 .27355 .30523 Mtetra
.948 .68 .495 r
.27355 .30523 .27491 .3029 .27598 .30961 .25893 .50843 Mtetra
.533 .299 .506 r
.25893 .50843 .27598 .30961 .26161 .51202 .26014 .51477 Mtetra
.624 .255 .322 r
.26014 .51477 .26161 .51202 .26313 .51459 .26176 .51613 Mtetra
.279 0 0 r
.26176 .51613 .26313 .51459 .26488 .51418 .26351 .51573 Mtetra
.086 0 0 r
.26351 .51573 .26488 .51418 .26668 .51321 .2653 .51486 Mtetra
.146 0 0 r
.2653 .51486 .26668 .51321 .26843 .51285 .26709 .51406 Mtetra
.151 0 0 r
.26709 .51406 .26843 .51285 .27012 .51326 .26885 .51352 Mtetra
.347 .822 .79 r
.26885 .51352 .27012 .51326 .27182 .51354 .27063 .51289 Mtetra
.726 .863 .946 r
.27063 .51289 .27182 .51354 .27356 .51343 .27243 .51196 Mtetra
.749 .722 .827 r
.27243 .51196 .27356 .51343 .27533 .51293 .27425 .51069 Mtetra
.719 .634 .762 r
.27425 .51069 .27533 .51293 .27711 .51231 .27609 .50931 Mtetra
.635 .543 .734 r
.27609 .50931 .27711 .51231 .27887 .5119 .27788 .50853 Mtetra
.558 .479 .723 r
.27788 .50853 .27887 .5119 .28062 .51164 .27963 .50835 Mtetra
.619 .52 .72 r
.27963 .50835 .28062 .51164 .28241 .51092 .28141 .50766 Mtetra
.777 .611 .674 r
.28141 .50766 .28241 .51092 .28431 .5087 .28338 .50448 Mtetra
.951 .686 .499 r
.28338 .50448 .28431 .5087 .28651 .50228 .29971 .30196 Mtetra
.545 .314 .515 r
.29971 .30196 .28651 .50228 .30284 .29721 .30207 .29177 Mtetra
.695 .509 .631 r
.30207 .29177 .30284 .29721 .30483 .2921 .3039 .28903 Mtetra
.632 .528 .719 r
.3039 .28903 .30483 .2921 .30659 .29033 .30558 .28826 Mtetra
.584 .573 .807 r
.30558 .28826 .30659 .29033 .30829 .28924 .30723 .28797 Mtetra
.572 .683 .915 r
.30723 .28797 .30829 .28924 .30998 .28846 .30888 .28771 Mtetra
.64 .817 .968 r
.30888 .28771 .30998 .28846 .31166 .28783 .31055 .28716 Mtetra
.642 .836 .975 r
.31055 .28716 .31166 .28783 .31332 .28733 .31223 .28658 Mtetra
.663 .823 .96 r
.31223 .28658 .31332 .28733 .31499 .28686 .31391 .28595 Mtetra
.682 .792 .932 r
.31391 .28595 .31499 .28686 .31666 .28635 .31559 .28526 Mtetra
.684 .756 .906 r
.31559 .28526 .31666 .28635 .31834 .28583 .31728 .28456 Mtetra
.685 .723 .879 r
.31728 .28456 .31834 .28583 .32002 .28526 .31897 .28383 Mtetra
.681 .696 .857 r
.31897 .28383 .32002 .28526 .3217 .28462 .32066 .28308 Mtetra
.66 .673 .852 r
.32066 .28308 .3217 .28462 .32339 .28395 .32234 .28244 Mtetra
.642 .671 .862 r
.32234 .28244 .32339 .28395 .32509 .28309 .32402 .28189 Mtetra
.606 .711 .919 r
.32402 .28189 .32509 .28309 .3268 .28205 .3257 .28151 Mtetra
.192 .657 .939 r
.3257 .28151 .3268 .28205 .32848 .28141 .32733 .28165 Mtetra
.768 .292 .111 r
.32733 .28165 .32848 .28141 .33009 .28202 .32886 .28362 Mtetra
.954 .681 .48 r
.32886 .28362 .33009 .28202 .33145 .28669 .31792 .48479 Mtetra
.54 .305 .507 r
.31792 .48479 .33145 .28669 .32051 .49101 .31907 .49472 Mtetra
.653 .307 .373 r
.31907 .49472 .32051 .49101 .32202 .49518 .32071 .49678 Mtetra
.328 0 .017 r
.32071 .49678 .32202 .49518 .3238 .49492 .3225 .4965 Mtetra
.122 0 0 r
.3225 .4965 .3238 .49492 .32563 .49398 .32432 .49566 Mtetra
.103 0 0 r
.32432 .49566 .32563 .49398 .32744 .49333 .32615 .49471 Mtetra
.168 0 0 r
.32615 .49471 .32744 .49333 .32919 .49375 .32796 .49409 Mtetra
.272 .769 .72 r
.32796 .49409 .32919 .49375 .33094 .49406 .32978 .49348 Mtetra
.609 .859 .991 r
.32978 .49348 .33094 .49406 .33273 .494 .33159 .4929 Mtetra
.624 .752 .939 r
.33159 .4929 .33273 .494 .33454 .49341 .3334 .49239 Mtetra
.643 .777 .944 r
.3334 .49239 .33454 .49341 .33636 .49268 .33521 .49181 Mtetra
.667 .812 .953 r
.33521 .49181 .33636 .49268 .33817 .49213 .33703 .49112 Mtetra
.698 .792 .923 r
.33703 .49112 .33817 .49213 .33996 .49202 .33886 .4903 Mtetra
.745 .696 .805 r
.33886 .4903 .33996 .49202 .34178 .49151 .34073 .48894 Mtetra
.802 .652 .696 r
.34073 .48894 .34178 .49151 .34366 .48985 .34268 .48592 Mtetra
.956 .687 .484 r
.34268 .48592 .34366 .48985 .34574 .4844 .35518 .28948 Mtetra
.561 .327 .518 r
.35518 .28948 .34574 .4844 .35855 .2788 .3578 .27203 Mtetra
.69 .49 .611 r
.3578 .27203 .35855 .2788 .36059 .27203 .35966 .26873 Mtetra
.636 .522 .707 r
.35966 .26873 .36059 .27203 .36237 .27009 .36138 .26784 Mtetra
.591 .562 .791 r
.36138 .26784 .36237 .27009 .36411 .26891 .36307 .2675 Mtetra
.549 .65 .901 r
.36307 .2675 .36411 .26891 .36583 .26811 .36476 .26733 Mtetra
.635 .813 .968 r
.36476 .26733 .36583 .26811 .36754 .26745 .36647 .26678 Mtetra
.634 .84 .979 r
.36647 .26678 .36754 .26745 .36925 .26693 .36818 .26621 Mtetra
.653 .832 .969 r
.36818 .26621 .36925 .26693 .37095 .26647 .36989 .26559 Mtetra
.678 .802 .941 r
.36989 .26559 .37095 .26647 .37266 .26596 .37161 .2649 Mtetra
.683 .767 .915 r
.37161 .2649 .37266 .26596 .37437 .26544 .37333 .2642 Mtetra
.683 .731 .887 r
.37333 .2642 .37437 .26544 .37608 .26489 .37505 .26347 Mtetra
.684 .703 .862 r
.37505 .26347 .37608 .26489 .3778 .26425 .37677 .2627 Mtetra
.664 .677 .852 r
.37677 .2627 .3778 .26425 .37952 .26358 .3785 .26203 Mtetra
.642 .668 .86 r
.3785 .26203 .37952 .26358 .38125 .26279 .38021 .26147 Mtetra
.623 .697 .898 r
.38021 .26147 .38125 .26279 .38299 .26167 .38193 .26101 Mtetra
.335 .715 .984 r
.38193 .26101 .38299 .26167 .38472 .26092 .38362 .26103 Mtetra
.654 .113 0 r
.38362 .26103 .38472 .26092 .38641 .26103 .38526 .26232 Mtetra
.96 .681 .462 r
.38526 .26232 .38641 .26103 .38795 .26452 .37856 .44999 Mtetra
.569 .328 .511 r
.37856 .44999 .38795 .26452 .3807 .46874 .37929 .47432 Mtetra
.653 .331 .416 r
.37929 .47432 .3807 .46874 .38222 .47567 .38099 .47709 Mtetra
.349 0 0 r
.38099 .47709 .38222 .47567 .384 .47662 .38282 .47694 Mtetra
.364 .828 .761 r
.38282 .47694 .384 .47662 .38582 .4767 .38468 .47618 Mtetra
.73 .902 .956 r
.38468 .47618 .38582 .4767 .38766 .47634 .38654 .47517 Mtetra
.632 .746 .931 r
.38654 .47517 .38766 .47634 .38951 .47583 .38839 .47463 Mtetra
.65 .748 .921 r
.38839 .47463 .38951 .47583 .39136 .47517 .39025 .47402 Mtetra
.687 .766 .912 r
.39025 .47402 .39136 .47517 .39322 .47448 .39211 .47323 Mtetra
.759 .766 .859 r
.39211 .47323 .39322 .47448 .39507 .47399 .39399 .47197 Mtetra
.733 .665 .783 r
.39399 .47197 .39507 .47399 .39692 .47349 .39588 .47057 Mtetra
.689 .581 .729 r
.39588 .47057 .39692 .47349 .39877 .47296 .39776 .46921 Mtetra
.611 .499 .702 r
.39776 .46921 .39877 .47296 .40063 .47232 .39963 .46849 Mtetra
.591 .484 .701 r
.39963 .46849 .40063 .47232 .4025 .47164 .40148 .46796 Mtetra
.581 .484 .709 r
.40148 .46796 .4025 .47164 .40436 .47099 .40334 .46755 Mtetra
.534 .465 .725 r
.40334 .46755 .40436 .47099 .40621 .47078 .40518 .46756 Mtetra
.598 .515 .731 r
.40518 .46756 .40621 .47078 .40807 .47023 .40704 .46705 Mtetra
.698 .574 .712 r
.40704 .46705 .40807 .47023 .40996 .46896 .40894 .46546 Mtetra
.89 .663 .588 r
.40894 .46546 .40996 .46896 .41197 .46412 .41111 .45588 Mtetra
.958 .681 .469 r
.41111 .45588 .41197 .46412 .42074 .25927 .41997 .25053 Mtetra
.692 .477 .591 r
.41997 .25053 .42074 .25927 .42279 .24974 .42184 .24608 Mtetra
.649 .518 .69 r
.42184 .24608 .42279 .24974 .42456 .24833 .42361 .24493 Mtetra
.601 .498 .709 r
.42361 .24493 .42456 .24833 .42631 .24781 .42536 .24437 Mtetra
.566 .475 .71 r
.42536 .24437 .42631 .24781 .42804 .24777 .42709 .24412 Mtetra
.603 .49 .697 r
.42709 .24412 .42804 .24777 .42979 .24717 .42884 .2435 Mtetra
.602 .488 .696 r
.42884 .2435 .42979 .24717 .43154 .24658 .4306 .24288 Mtetra
.601 .486 .695 r
.4306 .24288 .43154 .24658 .4333 .246 .43235 .24227 Mtetra
.602 .486 .694 r
.43235 .24227 .4333 .246 .43505 .24556 .4341 .24165 Mtetra
.598 .478 .687 r
.4341 .24165 .43505 .24556 .4368 .245 .43586 .24104 Mtetra
.596 .475 .685 r
.43586 .24104 .4368 .245 .43856 .24418 .43762 .24044 Mtetra
.594 .481 .694 r
.43762 .24044 .43856 .24418 .44035 .2426 .43937 .23989 Mtetra
.613 .541 .75 r
.43937 .23989 .44035 .2426 .44213 .24106 .44113 .23934 Mtetra
.639 .647 .841 r
.44113 .23934 .44213 .24106 .44391 .23974 .44289 .23876 Mtetra
.673 .788 .935 r
.44289 .23876 .44391 .23974 .44567 .23903 .44465 .23808 Mtetra
.681 .795 .936 r
.44465 .23808 .44567 .23903 .44743 .2385 .44642 .23737 Mtetra
.682 .758 .909 r
.44642 .23737 .44743 .2385 .44919 .23803 .44818 .23664 Mtetra
.685 .713 .87 r
.44818 .23664 .44919 .23803 .45096 .2374 .44995 .23586 Mtetra
.669 .685 .856 r
.44995 .23586 .45096 .2374 .45272 .23672 .45172 .23515 Mtetra
.644 .67 .86 r
.45172 .23515 .45272 .23672 .45449 .23601 .45349 .23456 Mtetra
.638 .687 .879 r
.45349 .23456 .45449 .23601 .45627 .23488 .45525 .23402 Mtetra
.482 .743 .986 r
.45525 .23402 .45627 .23488 .45805 .234 .45701 .23387 Mtetra
.353 0 0 r
.45701 .23387 .45805 .234 .45981 .23369 .45876 .23451 Mtetra
.894 .523 .328 r
.45876 .23451 .45981 .23369 .46152 .2361 .46038 .24096 Mtetra
.962 .675 .443 r
.46038 .24096 .46152 .2361 .45936 .43087 .45793 .44697 Mtetra
.602 .328 .474 r
.45793 .44697 .45936 .43087 .46088 .44904 .45973 .45097 Mtetra
.472 .045 .146 r
.45973 .45097 .46088 .44904 .46273 .45063 .46162 .45121 Mtetra
0 0 0 r
.46162 .45121 .46273 .45063 .46462 .45087 .46352 .45055 Mtetra
.711 .943 .958 r
.46352 .45055 .46462 .45087 .46652 .45056 .46544 .4495 Mtetra
.642 .777 .945 r
.46544 .4495 .46652 .45056 .46842 .44999 .46734 .44888 Mtetra
.64 .767 .94 r
.46734 .44888 .46842 .44999 .47033 .44926 .46925 .44829 Mtetra
.669 .805 .948 r
.46925 .44829 .47033 .44926 .47224 .44844 .47116 .44756 Mtetra
.674 .824 .955 r
.47116 .44756 .47224 .44844 .47415 .44827 .47307 .4468 Mtetra
.732 .735 .853 r
.47307 .4468 .47415 .44827 .47605 .44792 .47499 .44565 Mtetra
.767 .663 .747 r
.47499 .44565 .47605 .44792 .47797 .44696 .47693 .44367 Mtetra
.879 .663 .606 r
.47693 .44367 .47797 .44696 .47993 .4432 .47894 .43632 Mtetra
.965 .682 .447 r
.47894 .43632 .47993 .4432 .48204 .42793 .48365 .22845 Mtetra
.533 .303 .513 r
.48365 .22845 .48204 .42793 .48646 .22739 .4855 .22334 Mtetra
.664 .516 .673 r
.4855 .22334 .48646 .22739 .48828 .22454 .4873 .22185 Mtetra
.611 .543 .754 r
.4873 .22185 .48828 .22454 .49008 .22311 .48909 .2213 Mtetra
.554 .598 .852 r
.48909 .2213 .49008 .22311 .49187 .22219 .49087 .22114 Mtetra
.615 .755 .945 r
.49087 .22114 .49187 .22219 .49366 .22153 .49266 .22067 Mtetra
.643 .809 .963 r
.49266 .22067 .49366 .22153 .49546 .22102 .49446 .22007 Mtetra
.659 .793 .946 r
.49446 .22007 .49546 .22102 .49725 .2206 .49625 .21943 Mtetra
.698 .761 .901 r
.49625 .21943 .49725 .2206 .49905 .21999 .49805 .21861 Mtetra
.693 .722 .872 r
.49805 .21861 .49905 .21999 .50084 .21929 .49985 .21778 Mtetra
.669 .692 .863 r
.49985 .21778 .50084 .21929 .50264 .21855 .50165 .21707 Mtetra
.651 .689 .873 r
.50165 .21707 .50264 .21855 .50445 .21735 .50345 .21645 Mtetra
.536 .759 .979 r
.50345 .21645 .50445 .21735 .50625 .21634 .50525 .21618 Mtetra
.205 0 0 r
.50525 .21618 .50625 .21634 .50805 .21597 .50705 .21661 Mtetra
.861 .45 .248 r
.50705 .21661 .50805 .21597 .50984 .21878 .50883 .22098 Mtetra
.969 .677 .421 r
.50883 .22098 .50984 .21878 .51073 .42664 .50966 .42832 Mtetra
.835 .449 .318 r
.50966 .42832 .51073 .42664 .51263 .43464 .51157 .43339 Mtetra
.103 .453 .884 r
.51157 .43339 .51263 .43464 .51457 .43554 .51351 .4342 Mtetra
.604 .713 .921 r
.51351 .4342 .51457 .43554 .51651 .43489 .51545 .43375 Mtetra
.717 .789 .908 r
.51545 .43375 .51651 .43489 .51845 .43375 .51739 .43278 Mtetra
.693 .816 .941 r
.51739 .43278 .51845 .43375 .52039 .43342 .51933 .43194 Mtetra
.718 .732 .862 r
.51933 .43194 .52039 .43342 .52233 .43316 .52128 .43088 Mtetra
.753 .658 .756 r
.52128 .43088 .52233 .43316 .52428 .43223 .52322 .42908 Mtetra
.858 .659 .632 r
.52322 .42908 .52428 .43223 .52622 .42809 .52517 .42359 Mtetra
.97 .684 .429 r
.52517 .42359 .52622 .42809 .52796 .21971 .52697 .21478 Mtetra
.819 .596 .6 r
.52697 .21478 .52796 .21971 .52977 .20943 .52879 .2083 Mtetra
.844 .798 .806 r
.52879 .2083 .52977 .20943 .53158 .20723 .5306 .20633 Mtetra
.674 .812 .949 r
.5306 .20633 .53158 .20723 .5334 .20659 .53242 .20561 Mtetra
.56 .755 .969 r
.53242 .20561 .5334 .20659 .53522 .20643 .53424 .20529 Mtetra
.659 .758 .923 r
.53424 .20529 .53522 .20643 .53704 .20599 .53607 .20464 Mtetra
.693 .731 .879 r
.53607 .20464 .53704 .20599 .53887 .20531 .53789 .20381 Mtetra
.669 .698 .868 r
.53789 .20381 .53887 .20531 .54069 .20459 .53971 .20309 Mtetra
.652 .69 .873 r
.53971 .20309 .54069 .20459 .54251 .20346 .54154 .20246 Mtetra
.568 .752 .964 r
.54154 .20246 .54251 .20346 .54434 .20239 .54337 .20212 Mtetra
0 .52 .773 r
.54337 .20212 .54434 .20239 .54616 .20192 .5452 .20242 Mtetra
.829 .384 .171 r
.5452 .20242 .54616 .20192 .54801 .20407 .54706 .2058 Mtetra
.971 .676 .405 r
.54706 .2058 .54801 .20407 .55155 .40963 .55055 .41339 Mtetra
.797 .443 .386 r
.55055 .41339 .55155 .40963 .55361 .42075 .55257 .41957 Mtetra
0 .322 .799 r
.55257 .41957 .55361 .42075 .55559 .42214 .55455 .42075 Mtetra
.583 .697 .921 r
.55455 .42075 .55559 .42214 .55756 .42158 .55652 .42039 Mtetra
.705 .78 .91 r
.55652 .42039 .55756 .42158 .55953 .42047 .55849 .41946 Mtetra
.699 .814 .936 r
.55849 .41946 .55953 .42047 .5615 .42 .56046 .41858 Mtetra
.711 .743 .877 r
.56046 .41858 .5615 .42 .56348 .41979 .56243 .41758 Mtetra
.748 .664 .768 r
.56243 .41758 .56348 .41979 .56545 .41896 .56439 .4159 Mtetra
.845 .657 .649 r
.56439 .4159 .56545 .41896 .56739 .41546 .56632 .41125 Mtetra
.973 .683 .413 r
.56632 .41125 .56739 .41546 .5666 .21382 .5655 .20254 Mtetra
.728 .49 .567 r
.5655 .20254 .5666 .21382 .56821 .19598 .56725 .19471 Mtetra
.862 .784 .773 r
.56725 .19471 .56821 .19598 .57003 .1933 .56907 .19237 Mtetra
.691 .817 .943 r
.56907 .19237 .57003 .1933 .57187 .19256 .57091 .19158 Mtetra
.572 .76 .967 r
.57091 .19158 .57187 .19256 .57372 .19236 .57276 .19122 Mtetra
.644 .754 .929 r
.57276 .19122 .57372 .19236 .57557 .19198 .57461 .19062 Mtetra
.698 .734 .879 r
.57461 .19062 .57557 .19198 .57742 .19128 .57646 .18976 Mtetra
.676 .7 .865 r
.57646 .18976 .57742 .19128 .57927 .19053 .5783 .18899 Mtetra
.659 .689 .867 r
.5783 .18899 .57927 .19053 .58111 .18943 .58016 .18831 Mtetra
.602 .743 .943 r
.58016 .18831 .58111 .18943 .58295 .18828 .58201 .18787 Mtetra
.135 .645 .899 r
.58201 .18787 .58295 .18828 .58481 .18768 .58388 .18801 Mtetra
.778 .289 .06 r
.58388 .18801 .58481 .18768 .58671 .18923 .5858 .19054 Mtetra
.973 .674 .388 r
.5858 .19054 .58671 .18923 .58897 .20759 .59198 .39705 Mtetra
.536 .301 .505 r
.59198 .39705 .58897 .20759 .59518 .40642 .59416 .40529 Mtetra
0 .112 .623 r
.59416 .40529 .59518 .40642 .59724 .40859 .59621 .40706 Mtetra
.53 .651 .912 r
.59621 .40706 .59724 .40859 .59924 .40833 .59822 .40692 Mtetra
.746 .759 .863 r
.59822 .40692 .59924 .40833 .60123 .40701 .60021 .40568 Mtetra
.918 .786 .699 r
.60021 .40568 .60123 .40701 .60317 .40387 .60213 .40181 Mtetra
.976 .683 .396 r
.60213 .40181 .60317 .40387 .60496 .39469 .59901 .19271 Mtetra
.544 .312 .513 r
.59901 .19271 .60496 .39469 .60167 .18664 .60063 .18195 Mtetra
.714 .533 .643 r
.60063 .18195 .60167 .18664 .60345 .18265 .60244 .17922 Mtetra
.62 .512 .71 r
.60244 .17922 .60345 .18265 .60529 .18109 .60431 .17844 Mtetra
.57 .527 .768 r
.60431 .17844 .60529 .18109 .60715 .18012 .60619 .17819 Mtetra
.576 .598 .838 r
.60619 .17819 .60715 .18012 .60902 .1794 .60807 .17791 Mtetra
.639 .691 .882 r
.60807 .17791 .60902 .1794 .61089 .17878 .60994 .17733 Mtetra
.643 .699 .887 r
.60994 .17733 .61089 .17878 .61277 .17826 .61181 .17673 Mtetra
.646 .689 .875 r
.61181 .17673 .61277 .17826 .61464 .17771 .61369 .17611 Mtetra
.65 .679 .864 r
.61369 .17611 .61464 .17771 .61652 .17708 .61557 .17546 Mtetra
.654 .679 .861 r
.61557 .17546 .61652 .17708 .6184 .17642 .61744 .17479 Mtetra
.66 .68 .858 r
.61744 .17479 .6184 .17642 .62027 .17571 .61932 .17409 Mtetra
.665 .682 .856 r
.61932 .17409 .62027 .17571 .62215 .17497 .6212 .17335 Mtetra
.668 .685 .857 r
.6212 .17335 .62215 .17497 .62403 .1742 .62307 .1726 Mtetra
.703 .701 .845 r
.62307 .1726 .62403 .1742 .6259 .17321 .62495 .17163 Mtetra
.724 .713 .84 r
.62495 .17163 .6259 .17321 .62776 .17208 .62681 .17052 Mtetra
.646 .685 .873 r
.62681 .17052 .62776 .17208 .62965 .17144 .6287 .1699 Mtetra
.151 .407 .852 r
.6287 .1699 .62965 .17144 .63159 .17249 .63064 .17089 Mtetra
.896 .518 .063 r
.63064 .17089 .63159 .17249 .63382 .18126 .63283 .17865 Mtetra
.976 .674 .357 r
.63283 .17865 .63382 .18126 .64343 .38955 .64242 .38809 Mtetra
0 0 .453 r
.64242 .38809 .64343 .38955 .64559 .39234 .64458 .391 Mtetra
.549 .697 .937 r
.64458 .391 .64559 .39234 .64764 .39213 .64663 .39074 Mtetra
.696 .75 .893 r
.64663 .39074 .64764 .39213 .64966 .39118 .64866 .38982 Mtetra
.659 .741 .911 r
.64866 .38982 .64966 .39118 .65168 .39004 .65069 .3891 Mtetra
.434 .723 .986 r
.65069 .3891 .65168 .39004 .6537 .3891 .65276 .38903 Mtetra
.396 .852 .882 r
.65276 .38903 .6537 .3891 .65571 .38756 .6548 .38841 Mtetra
.636 .885 .546 r
.6548 .38841 .65571 .38756 .65763 .38402 .65677 .38607 Mtetra
.945 .815 .367 r
.65677 .38607 .65763 .38402 .65105 .17852 .65846 .37693 Mtetra
0 0 .34 r
.65846 .37693 .65105 .17852 .65247 .16625 .65158 .16589 Mtetra
.979 .876 .66 r
.65158 .16589 .65247 .16625 .65426 .16313 .65334 .1618 Mtetra
.721 .755 .879 r
.65334 .1618 .65426 .16313 .65615 .16219 .65522 .16079 Mtetra
.593 .691 .91 r
.65522 .16079 .65615 .16219 .65807 .16175 .65714 .16041 Mtetra
.568 .689 .922 r
.65714 .16041 .65807 .16175 .65998 .16134 .65906 .16011 Mtetra
.673 .757 .914 r
.65906 .16011 .65998 .16134 .66188 .16051 .66097 .15938 Mtetra
.68 .778 .924 r
.66097 .15938 .66188 .16051 .66379 .15976 .66287 .15861 Mtetra
.722 .789 .905 r
.66287 .15861 .66379 .15976 .6657 .15911 .66477 .15763 Mtetra
.752 .741 .842 r
.66477 .15763 .6657 .15911 .66761 .15863 .66665 .15635 Mtetra
.651 .605 .789 r
.66665 .15635 .66761 .15863 .66956 .15867 .66855 .15556 Mtetra
.446 .425 .741 r
.66855 .15556 .66956 .15867 .67159 .16038 .67053 .15616 Mtetra
0 0 .367 r
.67053 .15616 .67159 .16038 .68371 .36447 .67281 .16297 Mtetra
0 0 .365 r
.67281 .16297 .68371 .36447 .68638 .37611 .68535 .37374 Mtetra
0 0 .533 r
.68535 .37374 .68638 .37611 .6886 .37857 .68763 .37729 Mtetra
.413 .641 .95 r
.68763 .37729 .6886 .37857 .69072 .37879 .68973 .37744 Mtetra
.698 .761 .9 r
.68973 .37744 .69072 .37879 .69278 .37799 .69179 .3765 Mtetra
.849 .782 .786 r
.69179 .3765 .69278 .37799 .69475 .37556 .69377 .37417 Mtetra
.962 .773 .602 r
.69377 .37417 .69475 .37556 .69637 .36654 .69554 .36787 Mtetra
.978 .678 .347 r
.69554 .36787 .69637 .36654 .68692 .15441 .6862 .15664 Mtetra
.755 .759 .248 r
.6862 .15664 .68692 .15441 .68865 .15006 .68784 .15069 Mtetra
.535 .859 .574 r
.68784 .15069 .68865 .15006 .69056 .14906 .68971 .14897 Mtetra
.61 .953 .904 r
.68971 .14897 .69056 .14906 .6925 .14873 .69162 .14795 Mtetra
.646 .849 .978 r
.69162 .14795 .6925 .14873 .69446 .1486 .69355 .14726 Mtetra
.66 .732 .903 r
.69355 .14726 .69446 .1486 .69639 .14799 .69548 .14657 Mtetra
.641 .71 .898 r
.69548 .14657 .69639 .14799 .69833 .14732 .69742 .14597 Mtetra
.642 .723 .907 r
.69742 .14597 .69833 .14732 .70025 .14656 .69936 .14536 Mtetra
.675 .765 .919 r
.69936 .14536 .70025 .14656 .70217 .14561 .70129 .1446 Mtetra
.683 .809 .943 r
.70129 .1446 .70217 .14561 .70409 .14474 .70321 .14381 Mtetra
.712 .837 .942 r
.70321 .14381 .70409 .14474 .70603 .14402 .70514 .14289 Mtetra
.777 .811 .88 r
.70514 .14289 .70603 .14402 .70798 .14356 .70704 .14157 Mtetra
.669 .645 .817 r
.70704 .14157 .70798 .14356 .70996 .1436 .70897 .14072 Mtetra
.496 .471 .759 r
.70897 .14072 .70996 .1436 .71203 .14492 .71096 .14096 Mtetra
0 0 .463 r
.71096 .14096 .71203 .14492 .71518 .16322 .71331 .14662 Mtetra
.968 .669 .268 r
.71331 .14662 .71518 .16322 .72994 .36121 .72891 .35886 Mtetra
0 0 .472 r
.72891 .35886 .72994 .36121 .73226 .36407 .73132 .36301 Mtetra
.492 .731 .978 r
.73132 .36301 .73226 .36407 .7344 .36405 .73345 .36283 Mtetra
.701 .789 .919 r
.73345 .36283 .7344 .36405 .73649 .36333 .73553 .36188 Mtetra
.733 .762 .876 r
.73553 .36188 .73649 .36333 .73856 .36218 .7376 .3607 Mtetra
.531 .668 .925 r
.7376 .3607 .73856 .36218 .74064 .36117 .73973 .36053 Mtetra
.556 .856 .997 r
.73973 .36053 .74064 .36117 .74268 .35958 .74185 .35996 Mtetra
.529 .895 .692 r
.74185 .35996 .74268 .35958 .74463 .35663 .7439 .35848 Mtetra
.753 .782 .287 r
.7439 .35848 .74463 .35663 .74525 .33476 .74567 .35304 Mtetra
.969 .677 .271 r
.74567 .35304 .74525 .33476 .73345 .13696 .73299 .1417 Mtetra
0 0 .075 r
.73299 .1417 .73345 .13696 .73519 .13316 .73445 .13388 Mtetra
.548 .842 .515 r
.73445 .13388 .73519 .13316 .73712 .13212 .73631 .13189 Mtetra
.698 .973 .922 r
.73631 .13189 .73712 .13212 .7391 .13166 .73824 .13072 Mtetra
.671 .823 .957 r
.73824 .13072 .7391 .13166 .74109 .13145 .74019 .12996 Mtetra
.652 .706 .887 r
.74019 .12996 .74109 .13145 .74305 .13074 .74216 .12928 Mtetra
.625 .701 .9 r
.74216 .12928 .74305 .13074 .74501 .12999 .74413 .12875 Mtetra
.612 .734 .932 r
.74413 .12875 .74501 .12999 .74697 .12924 .74611 .12825 Mtetra
.647 .806 .959 r
.74611 .12825 .74697 .12924 .74893 .12841 .74808 .12759 Mtetra
.651 .844 .974 r
.74808 .12759 .74893 .12841 .75089 .12767 .75005 .12687 Mtetra
.662 .854 .973 r
.75005 .12687 .75089 .12767 .75287 .1271 .75202 .12611 Mtetra
.686 .82 .947 r
.75202 .12611 .75287 .1271 .75489 .12711 .75398 .12529 Mtetra
.673 .669 .838 r
.75398 .12529 .75489 .12711 .75694 .12731 .75594 .12444 Mtetra
.639 .558 .746 r
.75594 .12444 .75694 .12731 .75898 .12753 .7579 .12359 Mtetra
.612 .491 .691 r
.7579 .12359 .75898 .12753 .76096 .12691 .75986 .12276 Mtetra
.608 .482 .684 r
.75986 .12276 .76096 .12691 .76292 .12601 .76183 .12194 Mtetra
.609 .486 .687 r
.76183 .12194 .76292 .12601 .76488 .12498 .7638 .12112 Mtetra
.68 .71 .871 r
.13129 .35055 .1324 .3518 .13398 .35112 .13287 .34988 Mtetra
.682 .712 .871 r
.13287 .34988 .13398 .35112 .13556 .35045 .13445 .3492 Mtetra
.685 .712 .869 r
.13445 .3492 .13556 .35045 .13714 .34977 .13603 .3485 Mtetra
.756 .724 .823 r
.13603 .3485 .13714 .34977 .13877 .34865 .13768 .3473 Mtetra
.708 .702 .843 r
.13768 .3473 .13877 .34865 .14037 .34786 .13928 .34643 Mtetra
.578 .647 .882 r
.13928 .34643 .14037 .34786 .14189 .34769 .14081 .34619 Mtetra
.874 .455 .025 r
.14081 .34619 .14189 .34769 .14302 .35083 .14195 .34918 Mtetra
.939 .684 .524 r
.14195 .34918 .14302 .35083 .12044 .55174 .11933 .54982 Mtetra
.961 .651 .392 r
.11933 .54982 .12044 .55174 .12105 .56002 .11981 .55914 Mtetra
.017 .479 .874 r
.11981 .55914 .12105 .56002 .1226 .56051 .12136 .55967 Mtetra
.642 .795 .956 r
.12136 .55967 .1226 .56051 .12428 .55996 .12303 .55913 Mtetra
.745 .811 .904 r
.12303 .55913 .12428 .55996 .12601 .55895 .12476 .55813 Mtetra
.25 .637 .962 r
.12476 .55813 .12601 .55895 .1276 .55906 .12635 .55834 Mtetra
.457 .762 .995 r
.12635 .55834 .1276 .55906 .12925 .55882 .12798 .55819 Mtetra
.742 .854 .932 r
.12798 .55819 .12925 .55882 .13098 .55777 .12971 .55723 Mtetra
.927 .766 .662 r
.12971 .55723 .13098 .55777 .13328 .55192 .13198 .55158 Mtetra
.94 .688 .529 r
.13198 .55158 .13328 .55192 .15852 .34748 .15738 .34649 Mtetra
.913 .732 .645 r
.15738 .34649 .15852 .34748 .16071 .34164 .1596 .3404 Mtetra
.765 .732 .823 r
.1596 .3404 .16071 .34164 .16238 .34034 .16127 .33913 Mtetra
.594 .694 .912 r
.16127 .33913 .16238 .34034 .16394 .33994 .16282 .33882 Mtetra
.415 .636 .946 r
.16282 .33882 .16394 .33994 .16546 .33996 .16433 .33893 Mtetra
.616 .737 .932 r
.16433 .33893 .16546 .33996 .16703 .33953 .16589 .33852 Mtetra
.658 .752 .919 r
.16589 .33852 .16703 .33953 .16861 .339 .16748 .33796 Mtetra
.675 .751 .908 r
.16748 .33796 .16861 .339 .17019 .33843 .16907 .33733 Mtetra
.769 .756 .841 r
.16907 .33733 .17019 .33843 .17184 .33733 .17074 .33611 Mtetra
.728 .73 .852 r
.17074 .33611 .17184 .33733 .17346 .33648 .17237 .33516 Mtetra
.587 .669 .896 r
.17237 .33516 .17346 .33648 .17501 .33629 .17393 .33487 Mtetra
.898 .489 .091 r
.17393 .33487 .17501 .33629 .17615 .33979 .17508 .33825 Mtetra
.943 .684 .516 r
.17508 .33825 .17615 .33979 .15535 .54316 .15415 .54207 Mtetra
.942 .6 .345 r
.15415 .54207 .15535 .54316 .1563 .54941 .15507 .54859 Mtetra
0 .475 .862 r
.15507 .54859 .1563 .54941 .15787 .54998 .15665 .54912 Mtetra
.689 .803 .936 r
.15665 .54912 .15787 .54998 .15958 .54934 .15837 .54839 Mtetra
.772 .794 .871 r
.15837 .54839 .15958 .54934 .16134 .54824 .16014 .54717 Mtetra
.564 .728 .951 r
.16014 .54717 .16134 .54824 .16301 .54798 .16181 .54689 Mtetra
.581 .729 .944 r
.16181 .54689 .16301 .54798 .16468 .54765 .16348 .54657 Mtetra
.733 .77 .882 r
.16348 .54657 .16468 .54765 .16644 .54663 .16523 .54558 Mtetra
.901 .749 .684 r
.16523 .54558 .16644 .54663 .16856 .54212 .16736 .54106 Mtetra
.942 .688 .523 r
.16736 .54106 .16856 .54212 .19167 .33846 .19056 .3373 Mtetra
.92 .72 .617 r
.19056 .3373 .19167 .33846 .19407 .33034 .19295 .32925 Mtetra
.823 .76 .793 r
.19295 .32925 .19407 .33034 .1958 .32851 .19469 .32742 Mtetra
.667 .741 .906 r
.19469 .32742 .1958 .32851 .19741 .32791 .1963 .32682 Mtetra
.535 .698 .944 r
.1963 .32682 .19741 .32791 .19897 .32774 .19786 .32665 Mtetra
.718 .754 .881 r
.19786 .32665 .19897 .32774 .20061 .32688 .19949 .32579 Mtetra
.712 .753 .884 r
.19949 .32579 .20061 .32688 .20224 .32605 .20113 .32497 Mtetra
.551 .706 .942 r
.20113 .32497 .20224 .32605 .20381 .32584 .2027 .32476 Mtetra
.871 .431 .052 r
.2027 .32476 .20381 .32584 .20507 .32872 .20395 .32764 Mtetra
.945 .684 .51 r
.20395 .32764 .20507 .32872 .18616 .53131 .18496 .53029 Mtetra
.944 .609 .362 r
.18496 .53029 .18616 .53131 .18706 .53883 .18586 .5378 Mtetra
.475 0 0 r
.18586 .5378 .18706 .53883 .18858 .54017 .18739 .53914 Mtetra
.556 .734 .959 r
.18739 .53914 .18858 .54017 .19027 .5399 .18908 .53887 Mtetra
.78 .784 .856 r
.18908 .53887 .19027 .5399 .19207 .53858 .19087 .53754 Mtetra
.9 .757 .694 r
.19087 .53754 .19207 .53858 .19414 .5344 .19295 .53336 Mtetra
.945 .688 .517 r
.19295 .53336 .19414 .5344 .21568 .33173 .21457 .33063 Mtetra
.929 .719 .598 r
.21457 .33063 .21568 .33173 .21821 .32184 .2171 .32074 Mtetra
.841 .762 .775 r
.2171 .32074 .21821 .32184 .21998 .31971 .21887 .31862 Mtetra
.678 .745 .902 r
.21887 .31862 .21998 .31971 .2216 .31906 .2205 .31796 Mtetra
.543 .701 .943 r
.2205 .31796 .2216 .31906 .22318 .31887 .22208 .31777 Mtetra
.701 .75 .89 r
.22208 .31777 .22318 .31887 .22482 .3181 .22372 .317 Mtetra
.717 .754 .881 r
.22372 .317 .22482 .3181 .22647 .31724 .22537 .31614 Mtetra
.573 .712 .936 r
.22537 .31614 .22647 .31724 .22806 .31696 .22696 .31586 Mtetra
.817 .351 0 r
.22696 .31586 .22806 .31696 .2294 .31944 .2283 .31834 Mtetra
.948 .684 .504 r
.2283 .31834 .2294 .31944 .21208 .52138 .2109 .52031 Mtetra
.948 .621 .375 r
.2109 .52031 .21208 .52138 .21294 .53014 .21176 .52909 Mtetra
.575 .055 0 r
.21176 .52909 .21294 .53014 .21448 .53173 .21329 .53069 Mtetra
.524 .72 .963 r
.21329 .53069 .21448 .53173 .21618 .53155 .21499 .5305 Mtetra
.766 .783 .867 r
.21499 .5305 .21618 .53155 .21797 .53033 .21679 .52928 Mtetra
.894 .763 .71 r
.21679 .52928 .21797 .53033 .22 .52662 .21881 .52556 Mtetra
.948 .689 .512 r
.21881 .52556 .22 .52662 .23956 .32909 .23849 .32763 Mtetra
.933 .703 .568 r
.23849 .32763 .23956 .32909 .24255 .31352 .24146 .31239 Mtetra
.855 .759 .756 r
.24146 .31239 .24255 .31352 .24435 .31109 .24326 .30996 Mtetra
.668 .739 .903 r
.24326 .30996 .24435 .31109 .24599 .31047 .2449 .30934 Mtetra
.501 .678 .945 r
.2449 .30934 .24599 .31047 .24758 .3104 .24649 .30926 Mtetra
.553 .697 .936 r
.24649 .30926 .24758 .3104 .24918 .3102 .24809 .30905 Mtetra
.629 .722 .914 r
.24809 .30905 .24918 .3102 .25081 .30976 .24972 .30859 Mtetra
.636 .721 .909 r
.24972 .30859 .25081 .30976 .25244 .30929 .25135 .3081 Mtetra
.654 .724 .9 r
.25135 .3081 .25244 .30929 .25407 .30875 .25299 .30754 Mtetra
.669 .725 .891 r
.25299 .30754 .25407 .30875 .25572 .30813 .25463 .30691 Mtetra
.678 .724 .885 r
.25463 .30691 .25572 .30813 .25736 .30747 .25628 .30623 Mtetra
.681 .723 .881 r
.25628 .30623 .25736 .30747 .25902 .30678 .25794 .30553 Mtetra
.685 .723 .879 r
.25794 .30553 .25902 .30678 .26067 .30606 .25959 .30482 Mtetra
.692 .725 .876 r
.25959 .30482 .26067 .30606 .26233 .30532 .26125 .30406 Mtetra
.732 .734 .853 r
.26125 .30406 .26233 .30532 .264 .30447 .26293 .30306 Mtetra
.73 .711 .832 r
.26293 .30306 .264 .30447 .26567 .30359 .26462 .30201 Mtetra
.674 .669 .837 r
.26462 .30201 .26567 .30359 .26733 .30284 .26628 .30128 Mtetra
.447 .572 .887 r
.26628 .30128 .26733 .30284 .26898 .30222 .26786 .30146 Mtetra
.65 .113 0 r
.26786 .30146 .26898 .30222 .27061 .30189 .26934 .30302 Mtetra
.849 .489 .371 r
.26934 .30302 .27061 .30189 .27219 .3022 .27057 .30763 Mtetra
.944 .675 .498 r
.27057 .30763 .27219 .3022 .27355 .30523 .25603 .50761 Mtetra
.531 .297 .505 r
.25603 .50761 .27355 .30523 .25893 .50843 .25733 .51281 Mtetra
.637 .306 .394 r
.25733 .51281 .25893 .50843 .26014 .51477 .25889 .51478 Mtetra
.329 0 0 r
.25889 .51478 .26014 .51477 .26176 .51613 .26057 .51523 Mtetra
.606 .785 .966 r
.26057 .51523 .26176 .51613 .26351 .51573 .26233 .51477 Mtetra
.692 .793 .927 r
.26233 .51477 .26351 .51573 .2653 .51486 .26412 .514 Mtetra
.651 .806 .957 r
.26412 .514 .2653 .51486 .26709 .51406 .26589 .51339 Mtetra
.564 .821 .994 r
.26589 .51339 .26709 .51406 .26885 .51352 .26765 .51297 Mtetra
.656 .872 .98 r
.26765 .51297 .26885 .51352 .27063 .51289 .26943 .51227 Mtetra
.837 .864 .865 r
.26943 .51227 .27063 .51289 .27243 .51196 .27128 .51062 Mtetra
.873 .747 .721 r
.27128 .51062 .27243 .51196 .27425 .51069 .27326 .50733 Mtetra
.839 .641 .634 r
.27326 .50733 .27425 .51069 .27609 .50931 .27543 .50153 Mtetra
.795 .565 .589 r
.27543 .50153 .27609 .50931 .27788 .50853 .27786 .49213 Mtetra
.499 .306 .55 r
.27786 .49213 .27788 .50853 .27963 .50835 .27952 .49309 Mtetra
.504 .313 .554 r
.27952 .49309 .27963 .50835 .28141 .50766 .28119 .49382 Mtetra
.939 .673 .507 r
.28119 .49382 .28141 .50766 .28338 .50448 .29695 .3016 Mtetra
.54 .31 .514 r
.29695 .3016 .28338 .50448 .29971 .30196 .29919 .29312 Mtetra
.668 .46 .594 r
.29919 .29312 .29971 .30196 .30207 .29177 .30108 .28955 Mtetra
.753 .64 .736 r
.30108 .28955 .30207 .29177 .3039 .28903 .30283 .28777 Mtetra
.656 .716 .892 r
.30283 .28777 .3039 .28903 .30558 .28826 .3045 .28718 Mtetra
.563 .719 .946 r
.3045 .28718 .30558 .28826 .30723 .28797 .30615 .28692 Mtetra
.57 .726 .947 r
.30615 .28692 .30723 .28797 .30888 .28771 .30781 .28663 Mtetra
.65 .747 .92 r
.30781 .28663 .30888 .28771 .31055 .28716 .30948 .28607 Mtetra
.666 .751 .914 r
.30948 .28607 .31055 .28716 .31223 .28658 .31116 .28545 Mtetra
.686 .748 .899 r
.31116 .28545 .31223 .28658 .31391 .28595 .31284 .28473 Mtetra
.701 .737 .879 r
.31284 .28473 .31391 .28595 .31559 .28526 .31454 .28392 Mtetra
.697 .715 .863 r
.31454 .28392 .31559 .28526 .31728 .28456 .31623 .28311 Mtetra
.699 .699 .846 r
.31623 .28311 .31728 .28456 .31897 .28383 .31793 .28225 Mtetra
.694 .68 .832 r
.31793 .28225 .31897 .28383 .32066 .28308 .31963 .28139 Mtetra
.646 .646 .836 r
.31963 .28139 .32066 .28308 .32234 .28244 .32131 .2808 Mtetra
.497 .584 .873 r
.32131 .2808 .32234 .28244 .32402 .28189 .32295 .28084 Mtetra
0 .124 .621 r
.32295 .28084 .32402 .28189 .3257 .28151 .32452 .28212 Mtetra
.838 .435 .282 r
.32452 .28212 .3257 .28151 .32733 .28165 .32595 .28552 Mtetra
.951 .678 .483 r
.32595 .28552 .32733 .28165 .32886 .28362 .31493 .48509 Mtetra
.535 .301 .506 r
.31493 .48509 .32886 .28362 .31792 .48479 .31621 .49274 Mtetra
.612 .315 .44 r
.31621 .49274 .31792 .48479 .31907 .49472 .31783 .49514 Mtetra
.531 0 0 r
.31783 .49514 .31907 .49472 .32071 .49678 .31955 .4959 Mtetra
.577 .784 .977 r
.31955 .4959 .32071 .49678 .3225 .4965 .32135 .49551 Mtetra
.685 .791 .931 r
.32135 .49551 .3225 .4965 .32432 .49566 .32316 .49475 Mtetra
.699 .811 .935 r
.32316 .49475 .32432 .49566 .32615 .49471 .32499 .49394 Mtetra
.637 .825 .973 r
.32499 .49394 .32615 .49471 .32796 .49409 .3268 .49334 Mtetra
.634 .829 .975 r
.3268 .49334 .32796 .49409 .32978 .49348 .32861 .49274 Mtetra
.602 .824 .985 r
.32861 .49274 .32978 .49348 .33159 .4929 .33042 .49223 Mtetra
.531 .814 .998 r
.33042 .49223 .33159 .4929 .3334 .49239 .33222 .49188 Mtetra
.61 .873 .991 r
.33222 .49188 .3334 .49239 .33521 .49181 .33404 .49127 Mtetra
.781 .896 .925 r
.33404 .49127 .33521 .49181 .33703 .49112 .33589 .49004 Mtetra
.87 .788 .767 r
.33589 .49004 .33703 .49112 .33886 .4903 .33783 .48744 Mtetra
.837 .655 .656 r
.33783 .48744 .33886 .4903 .34073 .48894 .33987 .48284 Mtetra
.954 .684 .486 r
.33987 .48284 .34073 .48894 .34268 .48592 .35269 .28381 Mtetra
.546 .314 .515 r
.35269 .28381 .34268 .48592 .35518 .28948 .35497 .27279 Mtetra
.607 .389 .559 r
.35497 .27279 .35518 .28948 .3578 .27203 .35684 .26929 Mtetra
.736 .604 .71 r
.35684 .26929 .3578 .27203 .35966 .26873 .35861 .2674 Mtetra
.666 .711 .881 r
.35861 .2674 .35966 .26873 .36138 .26784 .36032 .26675 Mtetra
.568 .719 .944 r
.36032 .26675 .36138 .26784 .36307 .2675 .36201 .26646 Mtetra
.534 .718 .957 r
.36201 .26646 .36307 .2675 .36476 .26733 .3637 .26626 Mtetra
.645 .752 .927 r
.3637 .26626 .36476 .26733 .36647 .26678 .36541 .26571 Mtetra
.662 .758 .921 r
.36541 .26571 .36647 .26678 .36818 .26621 .36713 .26509 Mtetra
.681 .755 .907 r
.36713 .26509 .36818 .26621 .36989 .26559 .36884 .26439 Mtetra
.7 .745 .886 r
.36884 .26439 .36989 .26559 .37161 .2649 .37057 .26358 Mtetra
.698 .723 .869 r
.37057 .26358 .37161 .2649 .37333 .2642 .3723 .26275 Mtetra
.696 .703 .853 r
.3723 .26275 .37333 .2642 .37505 .26347 .37402 .26191 Mtetra
.701 .69 .836 r
.37402 .26191 .37505 .26347 .37677 .2627 .37576 .261 Mtetra
.657 .653 .835 r
.37576 .261 .37677 .2627 .3785 .26203 .37748 .26034 Mtetra
.552 .608 .863 r
.37748 .26034 .3785 .26203 .38021 .26147 .37918 .26019 Mtetra
0 .277 .775 r
.37918 .26019 .38021 .26147 .38193 .26101 .38082 .26131 Mtetra
.832 .396 .199 r
.38082 .26131 .38193 .26101 .38362 .26103 .38237 .26429 Mtetra
.957 .678 .466 r
.38237 .26429 .38362 .26103 .38526 .26232 .37503 .4625 Mtetra
.54 .304 .507 r
.37503 .4625 .38526 .26232 .37856 .44999 .37639 .47257 Mtetra
.563 .304 .482 r
.37639 .47257 .37856 .44999 .37929 .47432 .37808 .47527 Mtetra
.603 .118 .075 r
.37808 .47527 .37929 .47432 .38099 .47709 .37986 .47629 Mtetra
.531 .788 .992 r
.37986 .47629 .38099 .47709 .38282 .47694 .38169 .47598 Mtetra
.671 .798 .943 r
.38169 .47598 .38282 .47694 .38468 .47618 .38355 .47527 Mtetra
.7 .816 .937 r
.38355 .47527 .38468 .47618 .38654 .47517 .38541 .47442 Mtetra
.548 .806 .993 r
.38541 .47442 .38654 .47517 .38839 .47463 .38725 .47405 Mtetra
.61 .862 .991 r
.38725 .47405 .38839 .47463 .39025 .47402 .38911 .47345 Mtetra
.753 .896 .942 r
.38911 .47345 .39025 .47402 .39211 .47323 .39098 .47234 Mtetra
.897 .816 .76 r
.39098 .47234 .39211 .47323 .39399 .47197 .39293 .46949 Mtetra
.859 .68 .658 r
.39293 .46949 .39399 .47197 .39588 .47057 .39495 .46481 Mtetra
.862 .622 .574 r
.39495 .46481 .39588 .47057 .39776 .46921 .39725 .45274 Mtetra
.946 .669 .483 r
.39725 .45274 .39776 .46921 .39963 .46849 .40614 .26885 Mtetra
.497 .275 .507 r
.40614 .26885 .39963 .46849 .40148 .46796 .40749 .2788 Mtetra
0 0 .289 r
.40749 .2788 .40148 .46796 .40334 .46755 .40276 .45226 Mtetra
.424 .253 .544 r
.40276 .45226 .40334 .46755 .40518 .46756 .40447 .45539 Mtetra
.529 .342 .572 r
.40447 .45539 .40518 .46756 .40704 .46705 .40631 .45539 Mtetra
.69 .466 .578 r
.40631 .45539 .40704 .46705 .40894 .46546 .40836 .44948 Mtetra
.949 .671 .478 r
.40836 .44948 .40894 .46546 .41111 .45588 .41712 .25201 Mtetra
.531 .302 .512 r
.41712 .25201 .41111 .45588 .41997 .25053 .41901 .24734 Mtetra
.761 .6 .678 r
.41901 .24734 .41997 .25053 .42184 .24608 .42082 .24467 Mtetra
.714 .717 .852 r
.42082 .24467 .42184 .24608 .42361 .24493 .42258 .24371 Mtetra
.649 .73 .908 r
.42258 .24371 .42361 .24493 .42536 .24437 .42433 .24314 Mtetra
.6 .708 .919 r
.42433 .24314 .42536 .24437 .42709 .24412 .42607 .24275 Mtetra
.659 .706 .882 r
.42607 .24275 .42709 .24412 .42884 .2435 .42783 .24212 Mtetra
.658 .705 .881 r
.42783 .24212 .42884 .2435 .4306 .24288 .42958 .24149 Mtetra
.657 .702 .88 r
.42958 .24149 .4306 .24288 .43235 .24227 .43133 .24086 Mtetra
.66 .7 .876 r
.43133 .24086 .43235 .24227 .4341 .24165 .43309 .24021 Mtetra
.657 .695 .874 r
.43309 .24021 .4341 .24165 .43586 .24104 .43485 .23958 Mtetra
.65 .69 .874 r
.43485 .23958 .43586 .24104 .43762 .24044 .4366 .23898 Mtetra
.622 .678 .883 r
.4366 .23898 .43762 .24044 .43937 .23989 .43836 .23852 Mtetra
.621 .692 .895 r
.43836 .23852 .43937 .23989 .44113 .23934 .44011 .23806 Mtetra
.633 .713 .905 r
.44011 .23806 .44113 .23934 .44289 .23876 .44187 .23754 Mtetra
.689 .744 .893 r
.44187 .23754 .44289 .23876 .44465 .23808 .44364 .23677 Mtetra
.698 .732 .876 r
.44364 .23677 .44465 .23808 .44642 .23737 .44541 .23594 Mtetra
.694 .711 .861 r
.44541 .23594 .44642 .23737 .44818 .23664 .44718 .2351 Mtetra
.705 .698 .841 r
.44718 .2351 .44818 .23664 .44995 .23586 .44895 .23416 Mtetra
.668 .662 .835 r
.44895 .23416 .44995 .23586 .45172 .23515 .45072 .23341 Mtetra
.602 .629 .85 r
.45072 .23341 .45172 .23515 .45349 .23456 .45248 .23303 Mtetra
.2 .439 .866 r
.45248 .23303 .45349 .23456 .45525 .23402 .45422 .23381 Mtetra
.77 .261 0 r
.45422 .23381 .45525 .23402 .45701 .23387 .45592 .23601 Mtetra
.883 .54 .395 r
.45592 .23601 .45701 .23387 .45876 .23451 .45749 .24494 Mtetra
.955 .667 .451 r
.45749 .24494 .45876 .23451 .46038 .24096 .45497 .44533 Mtetra
.527 .293 .504 r
.45497 .44533 .46038 .24096 .45793 .44697 .45678 .4489 Mtetra
.639 .222 .236 r
.45678 .4489 .45793 .44697 .45973 .45097 .45864 .45035 Mtetra
.378 .76 .99 r
.45864 .45035 .45973 .45097 .46162 .45121 .46053 .45024 Mtetra
.649 .799 .954 r
.46053 .45024 .46162 .45121 .46352 .45055 .46244 .44959 Mtetra
.707 .818 .934 r
.46244 .44959 .46352 .45055 .46544 .4495 .46435 .4487 Mtetra
.568 .807 .989 r
.46435 .4487 .46544 .4495 .46734 .44888 .46625 .44826 Mtetra
.579 .851 .995 r
.46625 .44826 .46734 .44888 .46925 .44829 .46816 .44773 Mtetra
.695 .898 .97 r
.46816 .44773 .46925 .44829 .47116 .44756 .47007 .44682 Mtetra
.874 .866 .827 r
.47007 .44682 .47116 .44756 .47307 .4468 .47201 .44469 Mtetra
.855 .703 .693 r
.47201 .44469 .47307 .4468 .47499 .44565 .47397 .44106 Mtetra
.861 .631 .589 r
.47397 .44106 .47499 .44565 .47693 .44367 .47601 .43222 Mtetra
.96 .677 .454 r
.47601 .43222 .47693 .44367 .47894 .43632 .48084 .22891 Mtetra
.531 .302 .512 r
.48084 .22891 .47894 .43632 .48365 .22845 .48269 .22418 Mtetra
.717 .543 .654 r
.48269 .22418 .48365 .22845 .4855 .22334 .4845 .22164 Mtetra
.709 .682 .822 r
.4845 .22164 .4855 .22334 .4873 .22185 .4863 .22062 Mtetra
.611 .718 .921 r
.4863 .22062 .4873 .22185 .48909 .2213 .48809 .22018 Mtetra
.529 .706 .952 r
.48809 .22018 .48909 .2213 .49087 .22114 .48987 .21999 Mtetra
.621 .739 .931 r
.48987 .21999 .49087 .22114 .49266 .22067 .49167 .21951 Mtetra
.658 .75 .918 r
.49167 .21951 .49266 .22067 .49446 .22007 .49346 .21888 Mtetra
.674 .749 .907 r
.49346 .21888 .49446 .22007 .49625 .21943 .49526 .21818 Mtetra
.735 .757 .87 r
.49526 .21818 .49625 .21943 .49805 .21861 .49706 .21713 Mtetra
.713 .713 .848 r
.49706 .21713 .49805 .21861 .49985 .21778 .49886 .21614 Mtetra
.651 .667 .852 r
.49886 .21614 .49985 .21778 .50165 .21707 .50066 .2155 Mtetra
.333 .515 .886 r
.50066 .2155 .50165 .21707 .50345 .21645 .50245 .216 Mtetra
.687 .148 0 r
.50245 .216 .50345 .21645 .50525 .21618 .50424 .21792 Mtetra
.863 .495 .349 r
.50424 .21792 .50525 .21618 .50705 .21661 .506 .22427 Mtetra
.962 .67 .431 r
.506 .22427 .50705 .21661 .50883 .22098 .50667 .42687 Mtetra
.528 .294 .504 r
.50667 .42687 .50883 .22098 .50966 .42832 .50858 .43104 Mtetra
.638 .25 .294 r
.50858 .43104 .50966 .42832 .51157 .43339 .51051 .4327 Mtetra
.084 .561 .903 r
.51051 .4327 .51157 .43339 .51351 .4342 .51244 .43312 Mtetra
.547 .741 .966 r
.51244 .43312 .51351 .4342 .51545 .43375 .51439 .43283 Mtetra
.702 .827 .942 r
.51439 .43283 .51545 .43375 .51739 .43278 .51633 .43194 Mtetra
.854 .859 .845 r
.51633 .43194 .51739 .43278 .51933 .43194 .51828 .43002 Mtetra
.858 .721 .71 r
.51828 .43002 .51933 .43194 .52128 .43088 .52023 .42671 Mtetra
.848 .63 .606 r
.52023 .42671 .52128 .43088 .52322 .42908 .52218 .41985 Mtetra
.966 .678 .436 r
.52218 .41985 .52322 .42908 .52517 .42359 .52417 .21513 Mtetra
.533 .303 .512 r
.52417 .21513 .52517 .42359 .52697 .21478 .52599 .20943 Mtetra
.7 .513 .631 r
.52599 .20943 .52697 .21478 .52879 .2083 .5278 .20661 Mtetra
.749 .702 .807 r
.5278 .20661 .52879 .2083 .5306 .20633 .52962 .20527 Mtetra
.669 .776 .93 r
.52962 .20527 .5306 .20633 .53242 .20561 .53144 .20458 Mtetra
.61 .761 .952 r
.53144 .20458 .53242 .20561 .53424 .20529 .53326 .20411 Mtetra
.712 .768 .896 r
.53326 .20411 .53424 .20529 .53607 .20464 .53509 .20321 Mtetra
.72 .726 .855 r
.53509 .20321 .53607 .20464 .53789 .20381 .53691 .20219 Mtetra
.661 .676 .854 r
.53691 .20219 .53789 .20381 .53971 .20309 .53873 .2015 Mtetra
.409 .555 .889 r
.53873 .2015 .53971 .20309 .54154 .20246 .54056 .2018 Mtetra
.556 .011 0 r
.54056 .2018 .54154 .20246 .54337 .20212 .54241 .20347 Mtetra
.849 .455 .298 r
.54241 .20347 .54337 .20212 .5452 .20242 .54427 .20841 Mtetra
.967 .671 .414 r
.54427 .20841 .5452 .20242 .54706 .2058 .54754 .41219 Mtetra
.529 .295 .504 r
.54754 .41219 .54706 .2058 .55055 .41339 .54954 .41718 Mtetra
.631 .272 .343 r
.54954 .41718 .55055 .41339 .55257 .41957 .55153 .41906 Mtetra
0 .463 .797 r
.55153 .41906 .55257 .41957 .55455 .42075 .55351 .41962 Mtetra
.522 .723 .965 r
.55351 .41962 .55455 .42075 .55652 .42039 .55548 .41941 Mtetra
.682 .816 .947 r
.55548 .41941 .55652 .42039 .55849 .41946 .55745 .4186 Mtetra
.838 .863 .862 r
.55745 .4186 .55849 .41946 .56046 .41858 .55942 .41683 Mtetra
.864 .74 .725 r
.55942 .41683 .56046 .41858 .56243 .41758 .56136 .41372 Mtetra
.846 .635 .617 r
.56136 .41372 .56243 .41758 .56439 .4159 .56327 .40769 Mtetra
.969 .678 .421 r
.56327 .40769 .56439 .4159 .56632 .41125 .56269 .20248 Mtetra
.535 .305 .512 r
.56269 .20248 .56632 .41125 .5655 .20254 .56446 .19583 Mtetra
.68 .482 .611 r
.56446 .19583 .5655 .20254 .56725 .19471 .56627 .1928 Mtetra
.753 .681 .781 r
.56627 .1928 .56725 .19471 .56907 .19237 .5681 .19128 Mtetra
.678 .776 .924 r
.5681 .19128 .56907 .19237 .57091 .19158 .56995 .19054 Mtetra
.615 .765 .951 r
.56995 .19054 .57091 .19158 .57276 .19122 .5718 .19004 Mtetra
.7 .769 .905 r
.5718 .19004 .57276 .19122 .57461 .19062 .57365 .1892 Mtetra
.728 .734 .855 r
.57365 .1892 .57461 .19062 .57646 .18976 .57549 .18813 Mtetra
.673 .682 .851 r
.57549 .18813 .57646 .18976 .5783 .18899 .57734 .18735 Mtetra
.48 .588 .885 r
.57734 .18735 .5783 .18899 .58016 .18831 .5792 .18744 Mtetra
0 .164 .64 r
.5792 .18744 .58016 .18831 .58201 .18787 .58109 .18883 Mtetra
.828 .401 .225 r
.58109 .18883 .58201 .18787 .58388 .18801 .58304 .19266 Mtetra
.97 .67 .396 r
.58304 .19266 .58388 .18801 .5858 .19054 .58896 .39625 Mtetra
.532 .297 .504 r
.58896 .39625 .5858 .19054 .59198 .39705 .5911 .40281 Mtetra
.615 .287 .391 r
.5911 .40281 .59198 .39705 .59416 .40529 .59315 .40495 Mtetra
.252 0 0 r
.59315 .40495 .59416 .40529 .59621 .40706 .59518 .40568 Mtetra
.539 .682 .931 r
.59518 .40568 .59621 .40706 .59822 .40692 .59719 .40547 Mtetra
.736 .75 .864 r
.59719 .40547 .59822 .40692 .60021 .40568 .59918 .40429 Mtetra
.92 .779 .689 r
.59918 .40429 .60021 .40568 .60213 .40181 .6011 .40021 Mtetra
.976 .684 .395 r
.6011 .40021 .60213 .40181 .59901 .19271 .59799 .18876 Mtetra
.887 .649 .573 r
.59799 .18876 .59901 .19271 .60063 .18195 .59966 .18001 Mtetra
.829 .707 .729 r
.59966 .18001 .60063 .18195 .60244 .17922 .60148 .17743 Mtetra
.656 .655 .838 r
.60148 .17743 .60244 .17922 .60431 .17844 .60335 .17672 Mtetra
.558 .617 .868 r
.60335 .17672 .60431 .17844 .60619 .17819 .60523 .17652 Mtetra
.568 .63 .873 r
.60523 .17652 .60619 .17819 .60807 .17791 .60711 .17626 Mtetra
.639 .668 .862 r
.60711 .17626 .60807 .17791 .60994 .17733 .60898 .17567 Mtetra
.644 .669 .859 r
.60898 .17567 .60994 .17733 .61181 .17673 .61086 .17505 Mtetra
.647 .666 .854 r
.61086 .17505 .61181 .17673 .61369 .17611 .61273 .1744 Mtetra
.649 .664 .851 r
.61273 .1744 .61369 .17611 .61557 .17546 .61461 .17375 Mtetra
.652 .664 .849 r
.61461 .17375 .61557 .17546 .61744 .17479 .61649 .17307 Mtetra
.657 .665 .847 r
.61649 .17307 .61744 .17479 .61932 .17409 .61836 .17236 Mtetra
.661 .667 .845 r
.61836 .17236 .61932 .17409 .6212 .17335 .62024 .17163 Mtetra
.663 .669 .846 r
.62024 .17163 .6212 .17335 .62307 .1726 .62212 .17089 Mtetra
.695 .685 .836 r
.62212 .17089 .62307 .1726 .62495 .17163 .62399 .16995 Mtetra
.714 .697 .832 r
.62399 .16995 .62495 .17163 .62681 .17052 .62586 .16888 Mtetra
.642 .67 .861 r
.62586 .16888 .62681 .17052 .6287 .1699 .62775 .16826 Mtetra
.2 .423 .853 r
.62775 .16826 .6287 .1699 .63064 .17089 .62969 .16919 Mtetra
.864 .482 0 r
.62969 .16919 .63064 .17089 .63283 .17865 .63185 .17598 Mtetra
.976 .674 .357 r
.63185 .17598 .63283 .17865 .64242 .38809 .64141 .38655 Mtetra
0 0 .427 r
.64141 .38655 .64242 .38809 .64458 .391 .64358 .38968 Mtetra
.542 .698 .941 r
.64358 .38968 .64458 .391 .64663 .39074 .64563 .38944 Mtetra
.697 .766 .905 r
.64563 .38944 .64663 .39074 .64866 .38982 .64766 .38852 Mtetra
.646 .748 .923 r
.64766 .38852 .64866 .38982 .65069 .3891 .6497 .38786 Mtetra
.438 .661 .955 r
.6497 .38786 .65069 .3891 .65276 .38903 .65177 .38792 Mtetra
.604 .768 .958 r
.65177 .38792 .65276 .38903 .6548 .38841 .65381 .38741 Mtetra
.873 .851 .818 r
.65381 .38741 .6548 .38841 .65677 .38607 .65579 .38517 Mtetra
.983 .773 .543 r
.65579 .38517 .65677 .38607 .65846 .37693 .6575 .3765 Mtetra
.978 .681 .368 r
.6575 .3765 .65846 .37693 .65158 .16589 .65066 .1647 Mtetra
.942 .794 .668 r
.65066 .1647 .65158 .16589 .65334 .1618 .65241 .16049 Mtetra
.721 .758 .881 r
.65241 .16049 .65334 .1618 .65522 .16079 .6543 .15949 Mtetra
.585 .703 .924 r
.6543 .15949 .65522 .16079 .65714 .16041 .65622 .15912 Mtetra
.556 .694 .931 r
.65622 .15912 .65714 .16041 .65906 .16011 .65814 .15886 Mtetra
.667 .748 .912 r
.65814 .15886 .65906 .16011 .66097 .15938 .66005 .15815 Mtetra
.678 .758 .912 r
.66005 .15815 .66097 .15938 .66287 .15861 .66195 .15739 Mtetra
.728 .777 .892 r
.66195 .15739 .66287 .15861 .66477 .15763 .66385 .15636 Mtetra
.78 .784 .856 r
.66385 .15636 .66477 .15763 .66665 .15635 .66572 .15497 Mtetra
.699 .739 .882 r
.66572 .15497 .66665 .15635 .66855 .15556 .66762 .15408 Mtetra
.333 .534 .901 r
.66762 .15408 .66855 .15556 .67053 .15616 .6696 .15458 Mtetra
.837 .445 0 r
.6696 .15458 .67053 .15616 .67281 .16297 .67185 .16088 Mtetra
.975 .669 .338 r
.67185 .16088 .67281 .16297 .68535 .37374 .68437 .37235 Mtetra
.653 .215 0 r
.68437 .37235 .68535 .37374 .68763 .37729 .68665 .37602 Mtetra
.455 .665 .952 r
.68665 .37602 .68763 .37729 .68973 .37744 .68875 .37604 Mtetra
.697 .753 .895 r
.68875 .37604 .68973 .37744 .69179 .3765 .6908 .3751 Mtetra
.811 .787 .831 r
.6908 .3751 .69179 .3765 .69377 .37417 .69282 .37331 Mtetra
.925 .868 .763 r
.69282 .37331 .69377 .37417 .69554 .36787 .69476 .37036 Mtetra
0 0 0 r
.69476 .37036 .69554 .36787 .6862 .15664 .69658 .36491 Mtetra
0 0 .375 r
.69658 .36491 .6862 .15664 .68784 .15069 .68747 .15915 Mtetra
0 0 .284 r
.68747 .15915 .68784 .15069 .68971 .14897 .689 .15115 Mtetra
0 0 0 r
.689 .15115 .68971 .14897 .69162 .14795 .69078 .14784 Mtetra
.857 .993 .83 r
.69078 .14784 .69162 .14795 .69355 .14726 .69264 .14591 Mtetra
.691 .743 .891 r
.69264 .14591 .69355 .14726 .69548 .14657 .69456 .14506 Mtetra
.624 .687 .889 r
.69456 .14506 .69548 .14657 .69742 .14597 .6965 .14453 Mtetra
.607 .692 .903 r
.6965 .14453 .69742 .14597 .69936 .14536 .69845 .14408 Mtetra
.667 .748 .911 r
.69845 .14408 .69936 .14536 .70129 .1446 .70038 .14336 Mtetra
.678 .758 .912 r
.70038 .14336 .70129 .1446 .70321 .14381 .70232 .14258 Mtetra
.713 .775 .901 r
.70232 .14258 .70321 .14381 .70514 .14289 .70424 .14163 Mtetra
.786 .793 .858 r
.70424 .14163 .70514 .14289 .70704 .14157 .70613 .1402 Mtetra
.708 .747 .883 r
.70613 .1402 .70704 .14157 .70897 .14072 .70805 .13925 Mtetra
.436 .598 .913 r
.70805 .13925 .70897 .14072 .71096 .14096 .71005 .13944 Mtetra
.797 .398 0 r
.71005 .13944 .71096 .14096 .71331 .14662 .7124 .14525 Mtetra
.973 .663 .318 r
.7124 .14525 .71331 .14662 .72891 .35886 .72798 .35803 Mtetra
.768 .298 0 r
.72798 .35803 .72891 .35886 .73132 .36301 .73039 .3621 Mtetra
.513 .777 .992 r
.73039 .3621 .73132 .36301 .73345 .36283 .73251 .36179 Mtetra
.729 .836 .931 r
.73251 .36179 .73345 .36283 .73553 .36188 .73458 .3607 Mtetra
.764 .819 .896 r
.73458 .3607 .73553 .36188 .7376 .3607 .73664 .35939 Mtetra
.535 .702 .947 r
.73664 .35939 .7376 .3607 .73973 .36053 .73878 .35916 Mtetra
.596 .72 .931 r
.73878 .35916 .73973 .36053 .74185 .35996 .7409 .3587 Mtetra
.713 .789 .911 r
.7409 .3587 .74185 .35996 .7439 .35848 .74298 .35768 Mtetra
.923 .891 .781 r
.74298 .35768 .7439 .35848 .74567 .35304 .74494 .35492 Mtetra
.694 .761 .266 r
.74494 .35492 .74567 .35304 .73299 .1417 .74675 .34995 Mtetra
0 0 .391 r
.74675 .34995 .73299 .1417 .73445 .13388 .73439 .14436 Mtetra
0 0 .313 r
.73439 .14436 .73445 .13388 .73631 .13189 .73567 .13405 Mtetra
0 0 0 r
.73567 .13405 .73631 .13189 .73824 .13072 .73743 .13048 Mtetra
.886 .982 .819 r
.73743 .13048 .73824 .13072 .74019 .12996 .73929 .12837 Mtetra
.672 .701 .869 r
.73929 .12837 .74019 .12996 .74216 .12928 .74125 .12758 Mtetra
.597 .647 .871 r
.74125 .12758 .74216 .12928 .74413 .12875 .74323 .12718 Mtetra
.556 .647 .895 r
.74323 .12718 .74413 .12875 .74611 .12825 .74523 .12695 Mtetra
.639 .735 .919 r
.74523 .12695 .74611 .12825 .74808 .12759 .74721 .12635 Mtetra
.656 .755 .923 r
.74721 .12635 .74808 .12759 .75005 .12687 .74918 .12567 Mtetra
.675 .77 .922 r
.74918 .12567 .75005 .12687 .75202 .12611 .75114 .12489 Mtetra
.706 .78 .909 r
.75114 .12489 .75202 .12611 .75398 .12529 .7531 .12397 Mtetra
.71 .762 .893 r
.7531 .12397 .75398 .12529 .75594 .12444 .75505 .12301 Mtetra
.704 .74 .879 r
.75505 .12301 .75594 .12444 .7579 .12359 .757 .12206 Mtetra
.682 .715 .874 r
.757 .12206 .7579 .12359 .75986 .12276 .75897 .12122 Mtetra
.677 .71 .873 r
.75897 .12122 .75986 .12276 .76183 .12194 .76094 .1204 Mtetra
.676 .71 .874 r
.76094 .1204 .76183 .12194 .7638 .12112 .76291 .11959 Mtetra
.693 .82 .943 r
.13011 .34983 .13129 .35055 .13287 .34988 .13169 .34914 Mtetra
.695 .815 .939 r
.13169 .34914 .13287 .34988 .13445 .3492 .13327 .34845 Mtetra
.697 .812 .937 r
.13327 .34845 .13445 .3492 .13603 .3485 .13486 .34774 Mtetra
.783 .815 .878 r
.13486 .34774 .13603 .3485 .13768 .3473 .1365 .34658 Mtetra
.725 .822 .925 r
.1365 .34658 .13768 .3473 .13928 .34643 .1381 .34575 Mtetra
.487 .772 .995 r
.1381 .34575 .13928 .34643 .14081 .34619 .13963 .34557 Mtetra
.895 .49 .23 r
.13963 .34557 .14081 .34619 .14195 .34918 .14073 .34882 Mtetra
.938 .682 .524 r
.14073 .34882 .14195 .34918 .11933 .54982 .1179 .55057 Mtetra
.892 .574 .439 r
.1179 .55057 .11933 .54982 .11981 .55914 .11857 .55831 Mtetra
.037 .503 .884 r
.11857 .55831 .11981 .55914 .12136 .55967 .12012 .55879 Mtetra
.642 .786 .951 r
.12012 .55879 .12136 .55967 .12303 .55913 .1218 .55825 Mtetra
.741 .802 .902 r
.1218 .55825 .12303 .55913 .12476 .55813 .12352 .55726 Mtetra
.338 .675 .977 r
.12352 .55726 .12476 .55813 .12635 .55834 .12512 .55737 Mtetra
.54 .739 .967 r
.12512 .55737 .12635 .55834 .12798 .55819 .12676 .55714 Mtetra
.739 .771 .879 r
.12676 .55714 .12798 .55819 .12971 .55723 .1285 .55612 Mtetra
.904 .736 .663 r
.1285 .55612 .12971 .55723 .13198 .55158 .13075 .55067 Mtetra
.939 .687 .53 r
.13075 .55067 .13198 .55158 .15738 .34649 .15618 .34603 Mtetra
.933 .758 .641 r
.15618 .34603 .15738 .34649 .1596 .3404 .15844 .33967 Mtetra
.806 .821 .862 r
.15844 .33967 .1596 .3404 .16127 .33913 .16011 .33832 Mtetra
.606 .782 .965 r
.16011 .33832 .16127 .33913 .16282 .33882 .16168 .33792 Mtetra
.426 .694 .976 r
.16168 .33792 .16282 .33882 .16433 .33893 .16319 .33792 Mtetra
.635 .747 .929 r
.16319 .33792 .16433 .33893 .16589 .33852 .16477 .33745 Mtetra
.666 .742 .907 r
.16477 .33745 .16589 .33852 .16748 .33796 .16636 .33686 Mtetra
.675 .738 .898 r
.16636 .33686 .16748 .33796 .16907 .33733 .16795 .33622 Mtetra
.76 .753 .846 r
.16795 .33622 .16907 .33733 .17074 .33611 .16961 .33507 Mtetra
.727 .759 .878 r
.16961 .33507 .17074 .33611 .17237 .33516 .17124 .33417 Mtetra
.558 .727 .953 r
.17124 .33417 .17237 .33516 .17393 .33487 .17279 .33392 Mtetra
.9 .485 .162 r
.17279 .33392 .17393 .33487 .17508 .33825 .17396 .33719 Mtetra
.942 .683 .517 r
.17396 .33719 .17508 .33825 .15415 .54207 .15302 .54036 Mtetra
.956 .619 .321 r
.15302 .54036 .15415 .54207 .15507 .54859 .1539 .54719 Mtetra
.184 .471 .891 r
.1539 .54719 .15507 .54859 .15665 .54912 .15547 .54781 Mtetra
.663 .713 .885 r
.15547 .54781 .15665 .54912 .15837 .54839 .15718 .54717 Mtetra
.744 .747 .854 r
.15718 .54717 .15837 .54839 .16014 .54717 .15894 .54606 Mtetra
.548 .712 .948 r
.15894 .54606 .16014 .54717 .16181 .54689 .1606 .54583 Mtetra
.573 .732 .95 r
.1606 .54583 .16181 .54689 .16348 .54657 .16228 .54552 Mtetra
.734 .775 .886 r
.16228 .54552 .16348 .54657 .16523 .54558 .16403 .54454 Mtetra
.901 .75 .684 r
.16403 .54454 .16523 .54558 .16736 .54106 .16616 .54001 Mtetra
.942 .688 .523 r
.16616 .54001 .16736 .54106 .19056 .3373 .18944 .33619 Mtetra
.921 .722 .617 r
.18944 .33619 .19056 .3373 .19295 .32925 .19184 .32816 Mtetra
.823 .762 .794 r
.19184 .32816 .19295 .32925 .19469 .32742 .19357 .32634 Mtetra
.667 .742 .907 r
.19357 .32634 .19469 .32742 .1963 .32682 .19518 .32573 Mtetra
.535 .699 .945 r
.19518 .32573 .1963 .32682 .19786 .32665 .19675 .32557 Mtetra
.718 .754 .88 r
.19675 .32557 .19786 .32665 .19949 .32579 .19838 .32471 Mtetra
.712 .753 .884 r
.19838 .32471 .19949 .32579 .20113 .32497 .20001 .32388 Mtetra
.552 .705 .941 r
.20001 .32388 .20113 .32497 .2027 .32476 .20159 .32367 Mtetra
.871 .431 .05 r
.20159 .32367 .2027 .32476 .20395 .32764 .20284 .32655 Mtetra
.945 .684 .51 r
.20284 .32655 .20395 .32764 .18496 .53029 .18377 .52925 Mtetra
.944 .609 .361 r
.18377 .52925 .18496 .53029 .18586 .5378 .18466 .53677 Mtetra
.474 0 0 r
.18466 .53677 .18586 .5378 .18739 .53914 .18619 .53811 Mtetra
.556 .734 .958 r
.18619 .53811 .18739 .53914 .18908 .53887 .18788 .53784 Mtetra
.779 .784 .856 r
.18788 .53784 .18908 .53887 .19087 .53754 .18967 .53651 Mtetra
.9 .757 .694 r
.18967 .53651 .19087 .53754 .19295 .53336 .19175 .53233 Mtetra
.945 .688 .517 r
.19175 .53233 .19295 .53336 .21457 .33063 .21346 .32953 Mtetra
.929 .719 .598 r
.21346 .32953 .21457 .33063 .2171 .32074 .21599 .31965 Mtetra
.841 .762 .775 r
.21599 .31965 .2171 .32074 .21887 .31862 .21776 .31752 Mtetra
.678 .745 .902 r
.21776 .31752 .21887 .31862 .2205 .31796 .21939 .31687 Mtetra
.543 .701 .943 r
.21939 .31687 .2205 .31796 .22208 .31777 .22098 .31667 Mtetra
.702 .75 .89 r
.22098 .31667 .22208 .31777 .22372 .317 .22262 .3159 Mtetra
.717 .754 .881 r
.22262 .3159 .22372 .317 .22537 .31614 .22427 .31504 Mtetra
.574 .712 .936 r
.22427 .31504 .22537 .31614 .22696 .31586 .22586 .31476 Mtetra
.816 .35 0 r
.22586 .31476 .22696 .31586 .2283 .31834 .2272 .31723 Mtetra
.948 .684 .504 r
.2272 .31723 .2283 .31834 .2109 .52031 .20972 .51922 Mtetra
.948 .622 .375 r
.20972 .51922 .2109 .52031 .21176 .52909 .21057 .52804 Mtetra
.575 .056 0 r
.21057 .52804 .21176 .52909 .21329 .53069 .2121 .52964 Mtetra
.524 .72 .962 r
.2121 .52964 .21329 .53069 .21499 .5305 .2138 .52945 Mtetra
.766 .783 .867 r
.2138 .52945 .21499 .5305 .21679 .52928 .2156 .52823 Mtetra
.894 .763 .709 r
.2156 .52823 .21679 .52928 .21881 .52556 .21763 .52449 Mtetra
.948 .689 .512 r
.21763 .52449 .21881 .52556 .23849 .32763 .23743 .32607 Mtetra
.931 .702 .57 r
.23743 .32607 .23849 .32763 .24146 .31239 .24036 .31126 Mtetra
.854 .758 .756 r
.24036 .31126 .24146 .31239 .24326 .30996 .24216 .30883 Mtetra
.67 .738 .901 r
.24216 .30883 .24326 .30996 .2449 .30934 .2438 .3082 Mtetra
.507 .679 .943 r
.2438 .3082 .2449 .30934 .24649 .30926 .2454 .30811 Mtetra
.56 .698 .932 r
.2454 .30811 .24649 .30926 .24809 .30905 .247 .30788 Mtetra
.634 .72 .909 r
.247 .30788 .24809 .30905 .24972 .30859 .24863 .3074 Mtetra
.641 .718 .904 r
.24863 .3074 .24972 .30859 .25135 .3081 .25026 .30689 Mtetra
.657 .719 .894 r
.25026 .30689 .25135 .3081 .25299 .30754 .25191 .30631 Mtetra
.671 .72 .886 r
.25191 .30631 .25299 .30754 .25463 .30691 .25355 .30566 Mtetra
.679 .72 .88 r
.25355 .30566 .25463 .30691 .25628 .30623 .2552 .30497 Mtetra
.683 .72 .877 r
.2552 .30497 .25628 .30623 .25794 .30553 .25686 .30426 Mtetra
.686 .718 .874 r
.25686 .30426 .25794 .30553 .25959 .30482 .25852 .30353 Mtetra
.688 .717 .871 r
.25852 .30353 .25959 .30482 .26125 .30406 .26017 .30279 Mtetra
.732 .73 .849 r
.26017 .30279 .26125 .30406 .26293 .30306 .26186 .30177 Mtetra
.733 .728 .846 r
.26186 .30177 .26293 .30306 .26462 .30201 .26354 .30074 Mtetra
.649 .708 .89 r
.26354 .30074 .26462 .30201 .26628 .30128 .26519 .30019 Mtetra
0 .186 .682 r
.26519 .30019 .26628 .30128 .26786 .30146 .2667 .30132 Mtetra
.917 .564 .352 r
.2667 .30132 .26786 .30146 .26934 .30302 .2678 .30744 Mtetra
.945 .677 .498 r
.2678 .30744 .26934 .30302 .27057 .30763 .25284 .51032 Mtetra
.527 .293 .504 r
.25284 .51032 .27057 .30763 .25603 .50761 .25429 .51363 Mtetra
.537 .229 .393 r
.25429 .51363 .25603 .50761 .25733 .51281 .25596 .51421 Mtetra
.365 0 .004 r
.25596 .51421 .25733 .51281 .25889 .51478 .25769 .51412 Mtetra
.549 .819 .996 r
.25769 .51412 .25889 .51478 .26057 .51523 .25944 .51374 Mtetra
.636 .683 .878 r
.25944 .51374 .26057 .51523 .26233 .51477 .2612 .51321 Mtetra
.658 .681 .86 r
.2612 .51321 .26233 .51477 .26412 .514 .26298 .51255 Mtetra
.611 .68 .891 r
.26298 .51255 .26412 .514 .26589 .51339 .26474 .51212 Mtetra
.571 .698 .928 r
.26474 .51212 .26589 .51339 .26765 .51297 .26649 .51184 Mtetra
.684 .759 .908 r
.26649 .51184 .26765 .51297 .26943 .51227 .26827 .51109 Mtetra
.851 .768 .77 r
.26827 .51109 .26943 .51227 .27128 .51062 .27019 .50867 Mtetra
.903 .703 .623 r
.27019 .50867 .27128 .51062 .27326 .50733 .27247 .50137 Mtetra
.948 .684 .502 r
.27247 .50137 .27326 .50733 .27543 .50153 .28963 .29671 Mtetra
.53 .301 .512 r
.28963 .29671 .27543 .50153 .27786 .49213 .29156 .2927 Mtetra
.523 .295 .511 r
.29156 .2927 .27786 .49213 .27952 .49309 .29324 .29191 Mtetra
.521 .294 .51 r
.29324 .29191 .27952 .49309 .28119 .49382 .29488 .29166 Mtetra
.523 .295 .511 r
.29488 .29166 .28119 .49382 .29695 .3016 .29656 .29092 Mtetra
.588 .389 .58 r
.29656 .29092 .29695 .3016 .29919 .29312 .2983 .28938 Mtetra
.667 .524 .681 r
.2983 .28938 .29919 .29312 .30108 .28955 .30003 .28799 Mtetra
.714 .688 .824 r
.30003 .28799 .30108 .28955 .30283 .28777 .30173 .28699 Mtetra
.643 .811 .963 r
.30173 .28699 .30283 .28777 .3045 .28718 .3034 .28643 Mtetra
.6 .805 .978 r
.3034 .28643 .3045 .28718 .30615 .28692 .30507 .28599 Mtetra
.623 .772 .952 r
.30507 .28599 .30615 .28692 .30781 .28663 .30673 .28552 Mtetra
.661 .745 .912 r
.30673 .28552 .30781 .28663 .30948 .28607 .30841 .28492 Mtetra
.67 .739 .903 r
.30841 .28492 .30948 .28607 .31116 .28545 .31009 .28428 Mtetra
.681 .739 .894 r
.31009 .28428 .31116 .28545 .31284 .28473 .31178 .28357 Mtetra
.693 .745 .892 r
.31178 .28357 .31284 .28473 .31454 .28392 .31347 .28282 Mtetra
.695 .756 .899 r
.31347 .28282 .31454 .28392 .31623 .28311 .31516 .28206 Mtetra
.719 .773 .895 r
.31516 .28206 .31623 .28311 .31793 .28225 .31686 .28119 Mtetra
.733 .773 .885 r
.31686 .28119 .31793 .28225 .31963 .28139 .31856 .28023 Mtetra
.649 .733 .911 r
.31856 .28023 .31963 .28139 .32131 .2808 .32024 .27968 Mtetra
.101 .464 .89 r
.32024 .27968 .32131 .2808 .32295 .28084 .32185 .28031 Mtetra
.905 .503 .22 r
.32185 .28031 .32295 .28084 .32452 .28212 .32322 .28456 Mtetra
.953 .68 .482 r
.32322 .28456 .32452 .28212 .32595 .28552 .31172 .48889 Mtetra
.53 .296 .505 r
.31172 .48889 .32595 .28552 .31493 .48509 .31315 .49394 Mtetra
.543 .256 .429 r
.31315 .49394 .31493 .48509 .31621 .49274 .31487 .49476 Mtetra
.439 .021 .147 r
.31487 .49476 .31621 .49274 .31783 .49514 .31664 .49478 Mtetra
.449 .839 .982 r
.31664 .49478 .31783 .49514 .31955 .4959 .31843 .49443 Mtetra
.632 .688 .884 r
.31843 .49443 .31955 .4959 .32135 .49551 .32023 .4939 Mtetra
.656 .678 .859 r
.32023 .4939 .32135 .49551 .32316 .49475 .32205 .49323 Mtetra
.66 .692 .869 r
.32205 .49323 .32316 .49475 .32499 .49394 .32386 .49256 Mtetra
.641 .708 .895 r
.32386 .49256 .32499 .49394 .3268 .49334 .32567 .49199 Mtetra
.64 .713 .9 r
.32567 .49199 .3268 .49334 .32861 .49274 .32748 .49143 Mtetra
.609 .708 .915 r
.32748 .49143 .32861 .49274 .33042 .49223 .32929 .491 Mtetra
.545 .697 .939 r
.32929 .491 .33042 .49223 .33222 .49188 .33108 .49078 Mtetra
.654 .764 .93 r
.33108 .49078 .33222 .49188 .33404 .49127 .3329 .49016 Mtetra
.819 .789 .824 r
.3329 .49016 .33404 .49127 .33589 .49004 .33479 .48839 Mtetra
.903 .725 .652 r
.33479 .48839 .33589 .49004 .33783 .48744 .33688 .48295 Mtetra
.956 .686 .485 r
.33688 .48295 .33783 .48744 .33987 .48284 .35025 .27737 Mtetra
.536 .306 .513 r
.35025 .27737 .33987 .48284 .35269 .28381 .3523 .27053 Mtetra
.587 .381 .568 r
.3523 .27053 .35269 .28381 .35497 .27279 .35409 .26855 Mtetra
.639 .493 .668 r
.35409 .26855 .35497 .27279 .35684 .26929 .35582 .26736 Mtetra
.667 .631 .804 r
.35582 .26736 .35684 .26929 .35861 .2674 .35754 .26658 Mtetra
.644 .806 .961 r
.35754 .26658 .35861 .2674 .36032 .26675 .35925 .26601 Mtetra
.587 .808 .984 r
.35925 .26601 .36032 .26675 .36201 .26646 .36095 .26558 Mtetra
.597 .779 .967 r
.36095 .26558 .36201 .26646 .3637 .26626 .36265 .26517 Mtetra
.656 .752 .92 r
.36265 .26517 .3637 .26626 .36541 .26571 .36436 .26457 Mtetra
.667 .746 .909 r
.36436 .26457 .36541 .26571 .36713 .26509 .36608 .26393 Mtetra
.678 .744 .901 r
.36608 .26393 .36713 .26509 .36884 .26439 .36779 .26323 Mtetra
.692 .749 .896 r
.36779 .26323 .36884 .26439 .37057 .26358 .36952 .26247 Mtetra
.694 .76 .902 r
.36952 .26247 .37057 .26358 .3723 .26275 .37124 .2617 Mtetra
.706 .774 .905 r
.37124 .2617 .3723 .26275 .37402 .26191 .37297 .26088 Mtetra
.743 .786 .887 r
.37297 .26088 .37402 .26191 .37576 .261 .37471 .25986 Mtetra
.669 .746 .908 r
.37471 .25986 .37576 .261 .37748 .26034 .37643 .2592 Mtetra
.36 .614 .947 r
.37643 .2592 .37748 .26034 .37918 .26019 .37811 .25943 Mtetra
.878 .441 .09 r
.37811 .25943 .37918 .26019 .38082 .26131 .37964 .26301 Mtetra
.959 .681 .464 r
.37964 .26301 .38082 .26131 .38237 .26429 .37182 .46751 Mtetra
.533 .298 .505 r
.37182 .46751 .38237 .26429 .37503 .4625 .37332 .4742 Mtetra
.543 .267 .447 r
.37332 .4742 .37503 .4625 .37639 .47257 .3751 .47516 Mtetra
.469 .08 .219 r
.3751 .47516 .37639 .47257 .37808 .47527 .37691 .47525 Mtetra
.265 .772 .847 r
.37691 .47525 .37808 .47527 .37986 .47629 .37875 .47491 Mtetra
.621 .703 .904 r
.37875 .47491 .37986 .47629 .38169 .47598 .38059 .47442 Mtetra
.652 .688 .871 r
.38059 .47442 .38169 .47598 .38355 .47527 .38245 .47378 Mtetra
.656 .7 .879 r
.38245 .47378 .38355 .47527 .38541 .47442 .3843 .47312 Mtetra
.549 .688 .931 r
.3843 .47312 .38541 .47442 .38725 .47405 .38614 .47289 Mtetra
.642 .753 .93 r
.38614 .47289 .38725 .47405 .38911 .47345 .38799 .47231 Mtetra
.784 .789 .857 r
.38799 .47231 .38911 .47345 .39098 .47234 .38988 .47089 Mtetra
.912 .744 .66 r
.38988 .47089 .39098 .47234 .39293 .46949 .39192 .46582 Mtetra
.961 .687 .469 r
.39192 .46582 .39293 .46949 .39495 .46481 .40195 .26018 Mtetra
.539 .308 .513 r
.40195 .26018 .39495 .46481 .39725 .45274 .404 .25187 Mtetra
.524 .296 .511 r
.404 .25187 .39725 .45274 .40614 .26885 .40577 .25052 Mtetra
.537 .331 .549 r
.40577 .25052 .40614 .26885 .40749 .2788 .4075 .25005 Mtetra
.525 .311 .533 r
.4075 .25005 .40749 .2788 .40276 .45226 .40922 .25 Mtetra
.522 .294 .511 r
.40922 .25 .40276 .45226 .40447 .45539 .41096 .24958 Mtetra
.41096 .24958 .40447 .45539 .40631 .45539 .4127 .24905 Mtetra
.523 .295 .511 r
.4127 .24905 .40631 .45539 .40836 .44948 .41445 .24824 Mtetra
.524 .296 .511 r
.41445 .24824 .40836 .44948 .41712 .25201 .41623 .24665 Mtetra
.638 .47 .639 r
.41623 .24665 .41712 .25201 .41901 .24734 .41801 .24511 Mtetra
.716 .629 .76 r
.41801 .24511 .41901 .24734 .42082 .24467 .41979 .2438 Mtetra
.688 .813 .942 r
.41979 .2438 .42082 .24467 .42258 .24371 .42154 .24305 Mtetra
.634 .847 .981 r
.42154 .24305 .42258 .24371 .42433 .24314 .42329 .24246 Mtetra
.611 .835 .985 r
.42329 .24246 .42433 .24314 .42607 .24275 .42504 .24193 Mtetra
.659 .816 .959 r
.42504 .24193 .42607 .24275 .42783 .24212 .42679 .24129 Mtetra
.66 .815 .958 r
.42679 .24129 .42783 .24212 .42958 .24149 .42854 .24065 Mtetra
.661 .813 .956 r
.42854 .24065 .42958 .24149 .43133 .24086 .4303 .24 Mtetra
.664 .81 .954 r
.4303 .24 .43133 .24086 .43309 .24021 .43206 .23935 Mtetra
.662 .808 .953 r
.43206 .23935 .43309 .24021 .43485 .23958 .43381 .2387 Mtetra
.658 .804 .953 r
.43381 .2387 .43485 .23958 .4366 .23898 .43557 .23807 Mtetra
.639 .791 .955 r
.43557 .23807 .4366 .23898 .43836 .23852 .43733 .23751 Mtetra
.643 .771 .941 r
.43733 .23751 .43836 .23852 .44011 .23806 .43909 .23694 Mtetra
.653 .753 .923 r
.43909 .23694 .44011 .23806 .44187 .23754 .44085 .23634 Mtetra
.684 .746 .898 r
.44085 .23634 .44187 .23754 .44364 .23677 .44262 .2356 Mtetra
.692 .754 .899 r
.44262 .2356 .44364 .23677 .44541 .23594 .44439 .23482 Mtetra
.692 .765 .908 r
.44439 .23482 .44541 .23594 .44718 .2351 .44615 .23405 Mtetra
.747 .791 .889 r
.44615 .23405 .44718 .2351 .44895 .23416 .44793 .23299 Mtetra
.691 .755 .901 r
.44793 .23299 .44895 .23416 .45072 .23341 .4497 .23221 Mtetra
.544 .694 .938 r
.4497 .23221 .45072 .23341 .45248 .23303 .45146 .23201 Mtetra
.715 .229 0 r
.45146 .23201 .45248 .23303 .45422 .23381 .45316 .23449 Mtetra
.966 .681 .438 r
.45316 .23449 .45422 .23381 .45592 .23601 .45042 .43099 Mtetra
.552 .313 .507 r
.45042 .43099 .45592 .23601 .45749 .24494 .45192 .44754 Mtetra
.523 .29 .503 r
.45192 .44754 .45749 .24494 .45497 .44533 .45377 .44911 Mtetra
.506 .156 .308 r
.45377 .44911 .45497 .44533 .45678 .4489 .45566 .44938 Mtetra
.062 0 0 r
.45566 .44938 .45678 .4489 .45864 .45035 .45755 .44911 Mtetra
.606 .73 .933 r
.45755 .44911 .45864 .45035 .46053 .45024 .45945 .44866 Mtetra
.644 .687 .876 r
.45945 .44866 .46053 .45024 .46244 .44959 .46136 .44804 Mtetra
.663 .699 .873 r
.46136 .44804 .46244 .44959 .46435 .4487 .46327 .44732 Mtetra
.558 .683 .923 r
.46327 .44732 .46435 .4487 .46625 .44826 .46517 .44706 Mtetra
.61 .739 .936 r
.46517 .44706 .46625 .44826 .46816 .44773 .46708 .44659 Mtetra
.735 .789 .896 r
.46708 .44659 .46816 .44773 .47007 .44682 .469 .44552 Mtetra
.906 .772 .702 r
.469 .44552 .47007 .44682 .47201 .44469 .47096 .44171 Mtetra
.933 .688 .543 r
.47096 .44171 .47201 .44469 .47397 .44106 .4731 .4271 Mtetra
.957 .673 .457 r
.4731 .4271 .47397 .44106 .47601 .43222 .47808 .2258 Mtetra
.527 .298 .511 r
.47808 .2258 .47601 .43222 .48084 .22891 .4799 .22292 Mtetra
.625 .452 .628 r
.4799 .22292 .48084 .22891 .48269 .22418 .48171 .22144 Mtetra
.656 .566 .741 r
.48171 .22144 .48269 .22418 .4845 .22164 .4835 .2205 Mtetra
.67 .756 .915 r
.4835 .2205 .4845 .22164 .4863 .22062 .48529 .21982 Mtetra
.61 .811 .977 r
.48529 .21982 .4863 .22062 .48809 .22018 .48708 .21931 Mtetra
.587 .786 .975 r
.48708 .21931 .48809 .22018 .48987 .21999 .48887 .21889 Mtetra
.648 .757 .929 r
.48887 .21889 .48987 .21999 .49167 .21951 .49067 .2183 Mtetra
.667 .743 .907 r
.49067 .2183 .49167 .21951 .49346 .21888 .49246 .21762 Mtetra
.675 .737 .897 r
.49246 .21762 .49346 .21888 .49526 .21818 .49426 .21691 Mtetra
.743 .756 .863 r
.49426 .21691 .49526 .21818 .49706 .21713 .49607 .2158 Mtetra
.716 .739 .869 r
.49607 .2158 .49706 .21713 .49886 .21614 .49787 .21484 Mtetra
.608 .704 .912 r
.49787 .21484 .49886 .21614 .50066 .2155 .49967 .21442 Mtetra
0 0 .485 r
.49967 .21442 .50066 .2155 .50245 .216 .50145 .21634 Mtetra
.938 .592 .341 r
.50145 .21634 .50245 .216 .50424 .21792 .50317 .22762 Mtetra
.96 .667 .435 r
.50317 .22762 .50424 .21792 .506 .22427 .50366 .42994 Mtetra
.524 .291 .503 r
.50366 .42994 .506 .22427 .50667 .42687 .50557 .43198 Mtetra
.511 .187 .355 r
.50557 .43198 .50667 .42687 .50858 .43104 .50751 .43225 Mtetra
.272 0 0 r
.50751 .43225 .50858 .43104 .51051 .4327 .50944 .43196 Mtetra
.391 .744 .992 r
.50944 .43196 .51051 .4327 .51244 .43312 .51138 .43189 Mtetra
.568 .718 .943 r
.51138 .43189 .51244 .43312 .51439 .43283 .51332 .43156 Mtetra
.712 .766 .894 r
.51332 .43156 .51439 .43283 .51633 .43194 .51527 .43059 Mtetra
.892 .777 .728 r
.51527 .43059 .51633 .43194 .51828 .43002 .51722 .42733 Mtetra
.924 .694 .572 r
.51722 .42733 .51828 .43002 .52023 .42671 .51918 .41753 Mtetra
.966 .679 .437 r
.51918 .41753 .52023 .42671 .52218 .41985 .52136 .21088 Mtetra
.528 .299 .511 r
.52136 .21088 .52218 .41985 .52417 .21513 .52318 .20746 Mtetra
.606 .421 .605 r
.52318 .20746 .52417 .21513 .52599 .20943 .525 .20594 Mtetra
.636 .518 .702 r
.525 .20594 .52599 .20943 .5278 .20661 .52682 .20497 Mtetra
.674 .678 .846 r
.52682 .20497 .5278 .20661 .52962 .20527 .52864 .20419 Mtetra
.665 .772 .929 r
.52864 .20419 .52962 .20527 .53144 .20458 .53046 .20352 Mtetra
.647 .769 .938 r
.53046 .20352 .53144 .20458 .53326 .20411 .53228 .20292 Mtetra
.731 .769 .883 r
.53228 .20292 .53326 .20411 .53509 .20321 .53411 .2019 Mtetra
.725 .748 .87 r
.53411 .2019 .53509 .20321 .53691 .20219 .53593 .20089 Mtetra
.629 .714 .908 r
.53593 .20089 .53691 .20219 .53873 .2015 .53776 .20037 Mtetra
0 .173 .683 r
.53776 .20037 .53873 .2015 .54056 .2018 .53959 .20183 Mtetra
.923 .543 .262 r
.53959 .20183 .54056 .2018 .54241 .20347 .54147 .20927 Mtetra
.967 .671 .414 r
.54147 .20927 .54241 .20347 .54427 .20841 .54456 .41566 Mtetra
.525 .291 .503 r
.54456 .41566 .54427 .20841 .54754 .41219 .54655 .41834 Mtetra
.52 .209 .38 r
.54655 .41834 .54754 .41219 .54954 .41718 .54852 .41872 Mtetra
.337 0 .008 r
.54852 .41872 .54954 .41718 .55153 .41906 .55049 .41849 Mtetra
.354 .76 .983 r
.55049 .41849 .55153 .41906 .55351 .41962 .55246 .41837 Mtetra
.546 .707 .946 r
.55246 .41837 .55351 .41962 .55548 .41941 .55444 .41812 Mtetra
.693 .758 .902 r
.55444 .41812 .55548 .41941 .55745 .4186 .55641 .41724 Mtetra
.879 .783 .751 r
.55641 .41724 .55745 .4186 .55942 .41683 .55836 .41438 Mtetra
.923 .704 .588 r
.55836 .41438 .55942 .41683 .56136 .41372 .56026 .40629 Mtetra
.97 .679 .42 r
.56026 .40629 .56136 .41372 .56327 .40769 .55982 .19768 Mtetra
.529 .3 .511 r
.55982 .19768 .56327 .40769 .56269 .20248 .56162 .19361 Mtetra
.599 .407 .593 r
.56162 .19361 .56269 .20248 .56446 .19583 .56346 .19199 Mtetra
.632 .504 .688 r
.56346 .19199 .56446 .19583 .56627 .1928 .5653 .19097 Mtetra
.669 .655 .827 r
.5653 .19097 .56627 .1928 .5681 .19128 .56714 .19018 Mtetra
.669 .773 .928 r
.56714 .19018 .5681 .19128 .56995 .19054 .56899 .18948 Mtetra
.65 .775 .94 r
.56899 .18948 .56995 .19054 .5718 .19004 .57084 .18886 Mtetra
.724 .774 .892 r
.57084 .18886 .5718 .19004 .57365 .1892 .57268 .18788 Mtetra
.736 .754 .867 r
.57268 .18788 .57365 .1892 .57549 .18813 .57452 .1868 Mtetra
.653 .722 .9 r
.57452 .1868 .57549 .18813 .57734 .18735 .57638 .18616 Mtetra
0 .367 .834 r
.57638 .18616 .57734 .18735 .5792 .18744 .57826 .18719 Mtetra
.9 .484 .158 r
.57826 .18719 .5792 .18744 .58109 .18883 .58023 .19267 Mtetra
.971 .671 .395 r
.58023 .19267 .58109 .18883 .58304 .19266 .58605 .4007 Mtetra
.526 .293 .504 r
.58605 .4007 .58304 .19266 .58896 .39625 .58812 .40427 Mtetra
.525 .23 .408 r
.58812 .40427 .58896 .39625 .5911 .40281 .59014 .40475 Mtetra
.371 0 .09 r
.59014 .40475 .5911 .40281 .59315 .40495 .59215 .40449 Mtetra
.377 .795 .976 r
.59215 .40449 .59315 .40495 .59518 .40568 .59415 .40425 Mtetra
.569 .687 .92 r
.59415 .40425 .59518 .40568 .59719 .40547 .59616 .40394 Mtetra
.718 .732 .862 r
.59616 .40394 .59719 .40547 .59918 .40429 .59816 .40286 Mtetra
.912 .776 .697 r
.59816 .40286 .59918 .40429 .6011 .40021 .60008 .39898 Mtetra
.976 .684 .394 r
.60008 .39898 .6011 .40021 .59799 .18876 .59706 .18845 Mtetra
.991 .779 .52 r
.59706 .18845 .59799 .18876 .59966 .18001 .59872 .17913 Mtetra
.91 .844 .767 r
.59872 .17913 .59966 .18001 .60148 .17743 .60054 .17647 Mtetra
.686 .812 .943 r
.60054 .17647 .60148 .17743 .60335 .17672 .6024 .17569 Mtetra
.545 .742 .967 r
.6024 .17569 .60335 .17672 .60523 .17652 .60428 .17541 Mtetra
.562 .732 .954 r
.60428 .17541 .60523 .17652 .60711 .17626 .60616 .1751 Mtetra
.647 .754 .927 r
.60616 .1751 .60711 .17626 .60898 .17567 .60804 .17448 Mtetra
.651 .752 .923 r
.60804 .17448 .60898 .17567 .61086 .17505 .60991 .17385 Mtetra
.655 .752 .921 r
.60991 .17385 .61086 .17505 .61273 .1744 .61179 .17321 Mtetra
.659 .753 .92 r
.61179 .17321 .61273 .1744 .61461 .17375 .61367 .17254 Mtetra
.663 .753 .918 r
.61367 .17254 .61461 .17375 .61649 .17307 .61554 .17186 Mtetra
.668 .755 .916 r
.61554 .17186 .61649 .17307 .61836 .17236 .61742 .17116 Mtetra
.672 .757 .914 r
.61742 .17116 .61836 .17236 .62024 .17163 .6193 .17043 Mtetra
.674 .758 .914 r
.6193 .17043 .62024 .17163 .62212 .17089 .62118 .1697 Mtetra
.714 .773 .899 r
.62118 .1697 .62212 .17089 .62399 .16995 .62306 .16876 Mtetra
.737 .782 .89 r
.62306 .16876 .62399 .16995 .62586 .16888 .62493 .1677 Mtetra
.644 .753 .928 r
.62493 .1677 .62586 .16888 .62775 .16826 .62681 .1671 Mtetra
.043 .409 .86 r
.62681 .1671 .62775 .16826 .62969 .16919 .62876 .16803 Mtetra
.897 .501 .072 r
.62876 .16803 .62969 .16919 .63185 .17598 .63091 .17485 Mtetra
.975 .673 .361 r
.63091 .17485 .63185 .17598 .64141 .38655 .64041 .38523 Mtetra
.619 .166 0 r
.64041 .38523 .64141 .38655 .64358 .38968 .64258 .38836 Mtetra
.536 .695 .942 r
.64258 .38836 .64358 .38968 .64563 .38944 .64463 .38814 Mtetra
.695 .766 .906 r
.64463 .38814 .64563 .38944 .64766 .38852 .64666 .38723 Mtetra
.653 .753 .923 r
.64666 .38723 .64766 .38852 .6497 .38786 .6487 .38654 Mtetra
.477 .665 .945 r
.6487 .38654 .6497 .38786 .65177 .38792 .65076 .38651 Mtetra
.632 .723 .913 r
.65076 .38651 .65177 .38792 .65381 .38741 .65281 .38592 Mtetra
.847 .777 .784 r
.65281 .38592 .65381 .38741 .65579 .38517 .65478 .38358 Mtetra
.967 .743 .546 r
.65478 .38358 .65579 .38517 .6575 .3765 .65647 .37426 Mtetra
.977 .679 .372 r
.65647 .37426 .6575 .3765 .65066 .1647 .64972 .16324 Mtetra
.922 .769 .674 r
.64972 .16324 .65066 .1647 .65241 .16049 .65148 .15919 Mtetra
.718 .758 .884 r
.65148 .15919 .65241 .16049 .6543 .15949 .65337 .15821 Mtetra
.581 .707 .929 r
.65337 .15821 .6543 .15949 .65622 .15912 .65529 .15785 Mtetra
.554 .696 .934 r
.65529 .15785 .65622 .15912 .65814 .15886 .65722 .15759 Mtetra
.665 .746 .91 r
.65722 .15759 .65814 .15886 .66005 .15815 .65912 .15689 Mtetra
.674 .75 .908 r
.65912 .15689 .66005 .15815 .66195 .15739 .66103 .15614 Mtetra
.719 .77 .892 r
.66103 .15614 .66195 .15739 .66385 .15636 .66293 .15516 Mtetra
.773 .794 .87 r
.66293 .15516 .66385 .15636 .66572 .15497 .66481 .15385 Mtetra
.691 .784 .922 r
.66481 .15385 .66572 .15497 .66762 .15408 .66672 .15302 Mtetra
.184 .531 .923 r
.66672 .15302 .66762 .15408 .6696 .15458 .66869 .1536 Mtetra
.893 .49 .065 r
.66869 .1536 .6696 .15458 .67185 .16088 .67098 .16047 Mtetra
.975 .668 .343 r
.67098 .16047 .67185 .16088 .68437 .37235 .6834 .37129 Mtetra
.696 .225 0 r
.6834 .37129 .68437 .37235 .68665 .37602 .68567 .37473 Mtetra
.506 .688 .949 r
.68567 .37473 .68665 .37602 .68875 .37604 .68776 .37459 Mtetra
.694 .745 .89 r
.68776 .37459 .68875 .37604 .6908 .3751 .68982 .37366 Mtetra
.744 .764 .868 r
.68982 .37366 .6908 .3751 .69282 .37331 .69186 .37241 Mtetra
.707 .855 .953 r
.69186 .37241 .69282 .37331 .69476 .37036 .69391 .37144 Mtetra
0 0 0 r
.69391 .37144 .69476 .37036 .69658 .36491 .69594 .3699 Mtetra
.18 0 .261 r
.69594 .3699 .69658 .36491 .68747 .15915 .69788 .36675 Mtetra
0 0 .386 r
.69788 .36675 .68747 .15915 .689 .15115 .68923 .17075 Mtetra
0 0 .292 r
.68923 .17075 .689 .15115 .69078 .14784 .68996 .14808 Mtetra
.953 .945 .637 r
.68996 .14808 .69078 .14784 .69264 .14591 .69173 .14455 Mtetra
.719 .754 .88 r
.69173 .14455 .69264 .14591 .69456 .14506 .69364 .14354 Mtetra
.611 .681 .892 r
.69364 .14354 .69456 .14506 .6965 .14453 .69559 .14307 Mtetra
.571 .673 .908 r
.69559 .14307 .6965 .14453 .69845 .14408 .69754 .14277 Mtetra
.663 .742 .908 r
.69754 .14277 .69845 .14408 .70038 .14336 .69948 .14207 Mtetra
.671 .748 .909 r
.69948 .14207 .70038 .14336 .70232 .14258 .70141 .14133 Mtetra
.701 .766 .902 r
.70141 .14133 .70232 .14258 .70424 .14163 .70334 .14043 Mtetra
.777 .801 .872 r
.70334 .14043 .70424 .14163 .70613 .1402 .70524 .13909 Mtetra
.701 .795 .923 r
.70524 .13909 .70613 .1402 .70805 .13925 .70717 .13821 Mtetra
.334 .63 .96 r
.70717 .13821 .70805 .13925 .71005 .13944 .70917 .13846 Mtetra
.858 .441 0 r
.70917 .13846 .71005 .13944 .7124 .14525 .71154 .1445 Mtetra
.973 .663 .32 r
.71154 .1445 .7124 .14525 .72798 .35803 .72702 .35668 Mtetra
.668 .23 0 r
.72702 .35668 .72798 .35803 .73039 .3621 .72942 .36064 Mtetra
.553 .683 .925 r
.72942 .36064 .73039 .3621 .73251 .36179 .73154 .36037 Mtetra
.711 .759 .89 r
.73154 .36037 .73251 .36179 .73458 .3607 .73362 .35934 Mtetra
.754 .783 .877 r
.73362 .35934 .73458 .3607 .73664 .35939 .73568 .35804 Mtetra
.605 .727 .931 r
.73568 .35804 .73664 .35939 .73878 .35916 .7378 .35754 Mtetra
.622 .69 .892 r
.7378 .35754 .73878 .35916 .7409 .3587 .73991 .35698 Mtetra
.652 .688 .871 r
.73991 .35698 .7409 .3587 .74298 .35768 .74202 .35625 Mtetra
.701 .754 .893 r
.74202 .35625 .74298 .35768 .74494 .35492 .74411 .35527 Mtetra
.564 .914 .709 r
.74411 .35527 .74494 .35492 .74675 .34995 .74616 .35373 Mtetra
.123 0 .194 r
.74616 .35373 .74675 .34995 .73439 .14436 .74812 .35092 Mtetra
.492 .267 .501 r
.74812 .35092 .73439 .14436 .73567 .13405 .74919 .33555 Mtetra
0 0 .385 r
.74919 .33555 .73567 .13405 .73743 .13048 .73669 .13125 Mtetra
.879 .905 .494 r
.73669 .13125 .73743 .13048 .73929 .12837 .73842 .12729 Mtetra
.734 .816 .916 r
.73842 .12729 .73929 .12837 .74125 .12758 .74036 .12625 Mtetra
.601 .712 .922 r
.74036 .12625 .74125 .12758 .74323 .12718 .74234 .1258 Mtetra
.525 .666 .926 r
.74234 .1258 .74323 .12718 .74523 .12695 .74435 .12566 Mtetra
.639 .737 .92 r
.74435 .12566 .74523 .12695 .74721 .12635 .74633 .12505 Mtetra
.648 .741 .917 r
.74633 .12505 .74721 .12635 .74918 .12567 .7483 .1244 Mtetra
.662 .753 .918 r
.7483 .1244 .74918 .12567 .75114 .12489 .75027 .12369 Mtetra
.688 .776 .918 r
.75027 .12369 .75114 .12489 .7531 .12397 .75223 .12286 Mtetra
.697 .798 .928 r
.75223 .12286 .7531 .12397 .75505 .12301 .75419 .12199 Mtetra
.7 .818 .938 r
.75419 .12199 .75505 .12301 .757 .12206 .75616 .1211 Mtetra
.687 .829 .952 r
.75616 .1211 .757 .12206 .75897 .12122 .75812 .12027 Mtetra
.685 .831 .953 r
.75812 .12027 .75897 .12122 .76094 .1204 .76009 .11944 Mtetra
.686 .829 .952 r
.76009 .11944 .76094 .1204 .76291 .11959 .76206 .11861 Mtetra
.73 .816 .918 r
.12893 .34909 .13011 .34983 .13169 .34914 .13053 .34824 Mtetra
.712 .782 .906 r
.13053 .34824 .13169 .34914 .13327 .34845 .13213 .34746 Mtetra
.681 .759 .911 r
.13213 .34746 .13327 .34845 .13486 .34774 .13371 .34681 Mtetra
.662 .767 .928 r
.13371 .34681 .13486 .34774 .1365 .34658 .13528 .34624 Mtetra
.362 .791 .97 r
.13528 .34624 .1365 .34658 .1381 .34575 .1368 .34607 Mtetra
.501 0 0 r
.1368 .34607 .1381 .34575 .13963 .34557 .13823 .34662 Mtetra
.859 .525 .418 r
.13823 .34662 .13963 .34557 .14073 .34882 .1391 .35185 Mtetra
.933 .677 .526 r
.1391 .35185 .14073 .34882 .1179 .55057 .11625 .55307 Mtetra
.791 .46 .427 r
.11625 .55307 .1179 .55057 .11857 .55831 .11732 .55754 Mtetra
.051 .526 .89 r
.11732 .55754 .11857 .55831 .12012 .55879 .11887 .55796 Mtetra
.607 .791 .969 r
.11887 .55796 .12012 .55879 .1218 .55825 .12054 .55752 Mtetra
.735 .833 .925 r
.12054 .55752 .1218 .55825 .12352 .55726 .12226 .55659 Mtetra
.658 .834 .967 r
.12226 .55659 .12352 .55726 .12512 .55737 .12395 .55596 Mtetra
.724 .713 .839 r
.12395 .55596 .12512 .55737 .12676 .55714 .12568 .55493 Mtetra
.757 .646 .738 r
.12568 .55493 .12676 .55714 .1285 .55612 .12752 .55305 Mtetra
.86 .655 .625 r
.12752 .55305 .1285 .55612 .13075 .55067 .13001 .54557 Mtetra
.934 .682 .532 r
.13001 .54557 .13075 .55067 .15618 .34603 .1552 .34366 Mtetra
.847 .664 .655 r
.1552 .34366 .15618 .34603 .15844 .33967 .15728 .33886 Mtetra
.794 .806 .862 r
.15728 .33886 .15844 .33967 .16011 .33832 .15895 .33757 Mtetra
.635 .804 .964 r
.15895 .33757 .16011 .33832 .16168 .33792 .16052 .33707 Mtetra
.505 .741 .979 r
.16052 .33707 .16168 .33792 .16319 .33792 .16206 .33691 Mtetra
.67 .755 .914 r
.16206 .33691 .16319 .33792 .16477 .33745 .16365 .3363 Mtetra
.676 .731 .891 r
.16365 .3363 .16477 .33745 .16636 .33686 .16525 .33566 Mtetra
.655 .716 .893 r
.16525 .33566 .16636 .33686 .16795 .33622 .16683 .3351 Mtetra
.665 .734 .901 r
.16683 .3351 .16795 .33622 .16961 .33507 .16843 .33451 Mtetra
.503 .81 1 r
.16843 .33451 .16961 .33507 .17124 .33417 .16998 .33424 Mtetra
.378 0 0 r
.16998 .33424 .17124 .33417 .17279 .33392 .17146 .33467 Mtetra
.865 .517 .39 r
.17146 .33467 .17279 .33392 .17396 .33719 .17246 .33946 Mtetra
.938 .679 .519 r
.17246 .33946 .17396 .33719 .15302 .54036 .1516 .54127 Mtetra
.853 .499 .382 r
.1516 .54127 .15302 .54036 .1539 .54719 .15271 .54594 Mtetra
.218 .522 .917 r
.15271 .54594 .1539 .54719 .15547 .54781 .1543 .54642 Mtetra
.643 .696 .884 r
.1543 .54642 .15547 .54781 .15718 .54717 .15599 .54588 Mtetra
.715 .731 .863 r
.15599 .54588 .15718 .54717 .15894 .54606 .15774 .54495 Mtetra
.495 .694 .957 r
.15774 .54495 .15894 .54606 .1606 .54583 .15939 .54486 Mtetra
.533 .737 .969 r
.15939 .54486 .1606 .54583 .16228 .54552 .16105 .54464 Mtetra
.727 .804 .912 r
.16105 .54464 .16228 .54552 .16403 .54454 .1628 .54372 Mtetra
.911 .768 .691 r
.1628 .54372 .16403 .54454 .16616 .54001 .16491 .53933 Mtetra
.943 .688 .522 r
.16491 .53933 .16616 .54001 .18944 .33619 .18826 .33568 Mtetra
.939 .742 .61 r
.18826 .33568 .18944 .33619 .19184 .32816 .19072 .32712 Mtetra
.828 .767 .794 r
.19072 .32712 .19184 .32816 .19357 .32634 .19246 .32525 Mtetra
.668 .743 .906 r
.19246 .32525 .19357 .32634 .19518 .32573 .19407 .32464 Mtetra
.534 .698 .944 r
.19407 .32464 .19518 .32573 .19675 .32557 .19563 .32448 Mtetra
.719 .754 .88 r
.19563 .32448 .19675 .32557 .19838 .32471 .19727 .32362 Mtetra
.713 .752 .883 r
.19727 .32362 .19838 .32471 .20001 .32388 .1989 .32279 Mtetra
.554 .704 .94 r
.1989 .32279 .20001 .32388 .20159 .32367 .20047 .32257 Mtetra
.869 .429 .046 r
.20047 .32257 .20159 .32367 .20284 .32655 .20173 .32544 Mtetra
.945 .684 .51 r
.20173 .32544 .20284 .32655 .18377 .52925 .18257 .52816 Mtetra
.945 .611 .361 r
.18257 .52816 .18377 .52925 .18466 .53677 .18346 .53573 Mtetra
.474 0 0 r
.18346 .53573 .18466 .53677 .18619 .53811 .18499 .53707 Mtetra
.556 .733 .958 r
.18499 .53707 .18619 .53811 .18788 .53784 .18668 .5368 Mtetra
.779 .783 .856 r
.18668 .5368 .18788 .53784 .18967 .53651 .18847 .53547 Mtetra
.9 .757 .694 r
.18847 .53547 .18967 .53651 .19175 .53233 .19056 .53129 Mtetra
.945 .688 .517 r
.19056 .53129 .19175 .53233 .21346 .32953 .21234 .32843 Mtetra
.929 .719 .598 r
.21234 .32843 .21346 .32953 .21599 .31965 .21489 .31855 Mtetra
.841 .762 .775 r
.21489 .31855 .21599 .31965 .21776 .31752 .21666 .31642 Mtetra
.678 .745 .901 r
.21666 .31642 .21776 .31752 .21939 .31687 .21829 .31577 Mtetra
.544 .701 .943 r
.21829 .31577 .21939 .31687 .22098 .31667 .21987 .31557 Mtetra
.702 .75 .889 r
.21987 .31557 .22098 .31667 .22262 .3159 .22151 .3148 Mtetra
.718 .753 .881 r
.22151 .3148 .22262 .3159 .22427 .31504 .22316 .31393 Mtetra
.574 .712 .936 r
.22316 .31393 .22427 .31504 .22586 .31476 .22476 .31365 Mtetra
.814 .349 0 r
.22476 .31365 .22586 .31476 .2272 .31723 .22609 .31611 Mtetra
.948 .684 .504 r
.22609 .31611 .2272 .31723 .20972 .51922 .20854 .51811 Mtetra
.949 .622 .375 r
.20854 .51811 .20972 .51922 .21057 .52804 .20938 .52698 Mtetra
.576 .056 0 r
.20938 .52698 .21057 .52804 .2121 .52964 .21091 .52858 Mtetra
.525 .72 .962 r
.21091 .52858 .2121 .52964 .2138 .52945 .21261 .5284 Mtetra
.767 .783 .866 r
.21261 .5284 .2138 .52945 .2156 .52823 .21441 .52717 Mtetra
.894 .762 .708 r
.21441 .52717 .2156 .52823 .21763 .52449 .21644 .52341 Mtetra
.948 .689 .512 r
.21644 .52341 .21763 .52449 .23743 .32607 .23637 .32443 Mtetra
.929 .701 .572 r
.23637 .32443 .23743 .32607 .24036 .31126 .23927 .31012 Mtetra
.853 .757 .756 r
.23927 .31012 .24036 .31126 .24216 .30883 .24107 .30769 Mtetra
.671 .737 .899 r
.24107 .30769 .24216 .30883 .2438 .3082 .24271 .30705 Mtetra
.515 .68 .94 r
.24271 .30705 .2438 .3082 .2454 .30811 .2443 .30694 Mtetra
.567 .697 .929 r
.2443 .30694 .2454 .30811 .247 .30788 .24591 .30669 Mtetra
.639 .72 .906 r
.24591 .30669 .247 .30788 .24863 .3074 .24754 .30619 Mtetra
.649 .719 .899 r
.24754 .30619 .24863 .3074 .25026 .30689 .24918 .30565 Mtetra
.672 .72 .885 r
.24918 .30565 .25026 .30689 .25191 .30631 .25083 .305 Mtetra
.687 .713 .868 r
.25083 .305 .25191 .30631 .25355 .30566 .25248 .30426 Mtetra
.688 .699 .855 r
.25248 .30426 .25355 .30566 .2552 .30497 .25414 .30349 Mtetra
.691 .688 .843 r
.25414 .30349 .2552 .30497 .25686 .30426 .2558 .30269 Mtetra
.683 .673 .834 r
.2558 .30269 .25686 .30426 .25852 .30353 .25747 .30191 Mtetra
.662 .659 .837 r
.25747 .30191 .25852 .30353 .26017 .30279 .25912 .30125 Mtetra
.649 .665 .852 r
.25912 .30125 .26017 .30279 .26186 .30177 .26077 .30067 Mtetra
.59 .721 .934 r
.26077 .30067 .26186 .30177 .26354 .30074 .26239 .30033 Mtetra
0 .539 .822 r
.26239 .30033 .26354 .30074 .26519 .30019 .26397 .30062 Mtetra
.834 .425 .268 r
.26397 .30062 .26519 .30019 .2667 .30132 .26532 .30365 Mtetra
.948 .68 .497 r
.26532 .30365 .2667 .30132 .2678 .30744 .25015 .50694 Mtetra
.533 .298 .505 r
.25015 .50694 .2678 .30744 .25284 .51032 .25134 .51331 Mtetra
.617 .254 .331 r
.25134 .51331 .25284 .51032 .25429 .51363 .25295 .51463 Mtetra
.157 0 0 r
.25295 .51463 .25429 .51363 .25596 .51421 .2547 .51423 Mtetra
.614 .948 .931 r
.2547 .51423 .25596 .51421 .25769 .51412 .25649 .51335 Mtetra
.693 .833 .95 r
.25649 .51335 .25769 .51412 .25944 .51374 .25827 .51257 Mtetra
.633 .738 .924 r
.25827 .51257 .25944 .51374 .2612 .51321 .26004 .51205 Mtetra
.658 .748 .917 r
.26004 .51205 .2612 .51321 .26298 .51255 .26181 .51143 Mtetra
.673 .759 .916 r
.26181 .51143 .26298 .51255 .26474 .51212 .26359 .51074 Mtetra
.703 .723 .865 r
.26359 .51074 .26474 .51212 .26649 .51184 .26539 .50985 Mtetra
.744 .665 .773 r
.26539 .50985 .26649 .51184 .26827 .51109 .26723 .50833 Mtetra
.824 .651 .668 r
.26723 .50833 .26827 .51109 .27019 .50867 .26927 .50429 Mtetra
.949 .686 .502 r
.26927 .50429 .27019 .50867 .27247 .50137 .28659 .30006 Mtetra
.54 .309 .514 r
.28659 .30006 .27247 .50137 .28963 .29671 .28885 .29169 Mtetra
.697 .516 .639 r
.28885 .29169 .28963 .29671 .29156 .2927 .29066 .28913 Mtetra
.623 .502 .695 r
.29066 .28913 .29156 .2927 .29324 .29191 .29234 .28833 Mtetra
.575 .471 .699 r
.29234 .28833 .29324 .29191 .29488 .29166 .29399 .288 Mtetra
.569 .464 .695 r
.29399 .288 .29488 .29166 .29656 .29092 .29564 .28771 Mtetra
.599 .502 .716 r
.29564 .28771 .29656 .29092 .2983 .28938 .2973 .28721 Mtetra
.62 .582 .79 r
.2973 .28721 .2983 .28938 .30003 .28799 .29897 .28671 Mtetra
.651 .71 .891 r
.29897 .28671 .30003 .28799 .30173 .28699 .30064 .28614 Mtetra
.673 .802 .944 r
.30064 .28614 .30173 .28699 .3034 .28643 .30232 .28549 Mtetra
.68 .783 .928 r
.30232 .28549 .3034 .28643 .30507 .28599 .304 .28481 Mtetra
.682 .737 .893 r
.304 .28481 .30507 .28599 .30673 .28552 .30568 .28411 Mtetra
.675 .697 .862 r
.30568 .28411 .30673 .28552 .30841 .28492 .30736 .2834 Mtetra
.656 .675 .856 r
.30736 .2834 .30841 .28492 .31009 .28428 .30904 .28278 Mtetra
.606 .659 .875 r
.30904 .28278 .31009 .28428 .31178 .28357 .31071 .28241 Mtetra
.488 .668 .943 r
.31071 .28241 .31178 .28357 .31347 .28282 .31235 .28236 Mtetra
.226 .695 .943 r
.31235 .28236 .31347 .28282 .31516 .28206 .31398 .28241 Mtetra
0 0 0 r
.31398 .28241 .31516 .28206 .31686 .28119 .31565 .28203 Mtetra
.31565 .28203 .31686 .28119 .31856 .28023 .31737 .281 Mtetra
.31737 .281 .31856 .28023 .32024 .27968 .31905 .28043 Mtetra
.676 .205 .125 r
.31905 .28043 .32024 .27968 .32185 .28031 .32061 .28177 Mtetra
.954 .681 .481 r
.32061 .28177 .32185 .28031 .32322 .28456 .30925 .48106 Mtetra
.544 .308 .507 r
.30925 .48106 .32322 .28456 .31172 .48889 .31023 .49304 Mtetra
.651 .313 .387 r
.31023 .49304 .31172 .48889 .31315 .49394 .31185 .49522 Mtetra
.287 0 0 r
.31185 .49522 .31315 .49394 .31487 .49476 .31364 .49496 Mtetra
.488 .902 .855 r
.31364 .49496 .31487 .49476 .31664 .49478 .31546 .49414 Mtetra
.712 .868 .955 r
.31546 .49414 .31664 .49478 .31843 .49443 .31729 .49325 Mtetra
.633 .741 .926 r
.31729 .49325 .31843 .49443 .32023 .4939 .31909 .49272 Mtetra
.654 .746 .917 r
.31909 .49272 .32023 .4939 .32205 .49323 .3209 .4921 Mtetra
.703 .768 .903 r
.3209 .4921 .32205 .49323 .32386 .49256 .32273 .49124 Mtetra
.753 .75 .849 r
.32273 .49124 .32386 .49256 .32567 .49199 .32458 .49 Mtetra
.729 .662 .784 r
.32458 .49 .32567 .49199 .32748 .49143 .32644 .48865 Mtetra
.66 .572 .745 r
.32644 .48865 .32748 .49143 .32929 .491 .32828 .48766 Mtetra
.552 .479 .727 r
.32828 .48766 .32929 .491 .33108 .49078 .33007 .48753 Mtetra
.606 .516 .726 r
.33007 .48753 .33108 .49078 .3329 .49016 .33188 .48695 Mtetra
.743 .596 .693 r
.33188 .48695 .3329 .49016 .33479 .48839 .3338 .48461 Mtetra
.921 .674 .547 r
.3338 .48461 .33479 .48839 .33688 .48295 .33673 .46458 Mtetra
.939 .667 .497 r
.33673 .46458 .33688 .48295 .35025 .27737 .34951 .2706 Mtetra
.693 .492 .611 r
.34951 .2706 .35025 .27737 .3523 .27053 .35137 .26718 Mtetra
.635 .52 .705 r
.35137 .26718 .3523 .27053 .35409 .26855 .35309 .26629 Mtetra
.592 .561 .789 r
.35309 .26629 .35409 .26855 .35582 .26736 .35478 .26594 Mtetra
.554 .651 .899 r
.35478 .26594 .35582 .26736 .35754 .26658 .35647 .26575 Mtetra
.638 .803 .962 r
.35647 .26575 .35754 .26658 .35925 .26601 .35818 .2652 Mtetra
.644 .81 .963 r
.35818 .2652 .35925 .26601 .36095 .26558 .35988 .26463 Mtetra
.667 .783 .936 r
.35988 .26463 .36095 .26558 .36265 .26517 .3616 .26398 Mtetra
.694 .746 .891 r
.3616 .26398 .36265 .26517 .36436 .26457 .36332 .26321 Mtetra
.677 .71 .872 r
.36332 .26321 .36436 .26457 .36608 .26393 .36504 .26249 Mtetra
.636 .683 .877 r
.36504 .26249 .36608 .26393 .36779 .26323 .36675 .26197 Mtetra
.507 .66 .929 r
.36675 .26197 .36779 .26323 .36952 .26247 .36844 .26189 Mtetra
.275 .7 .968 r
.36844 .26189 .36952 .26247 .37124 .2617 .37012 .26195 Mtetra
.029 0 0 r
.37012 .26195 .37124 .2617 .37297 .26088 .37182 .26181 Mtetra
0 0 0 r
.37182 .26181 .37297 .26088 .37471 .25986 .37356 .26072 Mtetra
.37356 .26072 .37471 .25986 .37643 .2592 .37529 .26003 Mtetra
.541 .038 .009 r
.37529 .26003 .37643 .2592 .37811 .25943 .37695 .2607 Mtetra
.959 .681 .464 r
.37695 .2607 .37811 .25943 .37964 .26301 .36956 .45223 Mtetra
.562 .322 .509 r
.36956 .45223 .37964 .26301 .37182 .46751 .37038 .4731 Mtetra
.652 .331 .415 r
.37038 .4731 .37182 .46751 .37332 .4742 .37207 .47587 Mtetra
.373 0 .055 r
.37207 .47587 .37332 .4742 .3751 .47516 .3739 .47572 Mtetra
0 0 0 r
.3739 .47572 .3751 .47516 .37691 .47525 .37575 .4749 Mtetra
.772 .937 .936 r
.37575 .4749 .37691 .47525 .37875 .47491 .37763 .47366 Mtetra
.758 .767 .86 r
.37763 .47366 .37875 .47491 .38059 .47442 .37951 .4724 Mtetra
.731 .664 .784 r
.37951 .4724 .38059 .47442 .38245 .47378 .3814 .47102 Mtetra
.687 .589 .741 r
.3814 .47102 .38245 .47378 .3843 .47312 .38328 .46976 Mtetra
.556 .483 .728 r
.38328 .46976 .3843 .47312 .38614 .47289 .38511 .46959 Mtetra
.599 .511 .726 r
.38511 .46959 .38614 .47289 .38799 .47231 .38696 .46905 Mtetra
.703 .573 .707 r
.38696 .46905 .38799 .47231 .38988 .47089 .38886 .46735 Mtetra
.897 .666 .58 r
.38886 .46735 .38988 .47089 .39192 .46582 .39114 .45647 Mtetra
.955 .68 .475 r
.39114 .45647 .39192 .46582 .40195 .26018 .40118 .25236 Mtetra
.698 .487 .598 r
.40118 .25236 .40195 .26018 .404 .25187 .40306 .2482 Mtetra
.646 .515 .689 r
.40306 .2482 .404 .25187 .40577 .25052 .40482 .24708 Mtetra
.597 .494 .707 r
.40482 .24708 .40577 .25052 .4075 .25005 .40656 .24655 Mtetra
.566 .472 .707 r
.40656 .24655 .4075 .25005 .40922 .25 .40828 .2463 Mtetra
.6 .485 .694 r
.40828 .2463 .40922 .25 .41096 .24958 .41003 .24569 Mtetra
.596 .476 .687 r
.41003 .24569 .41096 .24958 .4127 .24905 .41177 .24511 Mtetra
.593 .473 .685 r
.41177 .24511 .4127 .24905 .41445 .24824 .41351 .24454 Mtetra
.594 .482 .696 r
.41351 .24454 .41445 .24824 .41623 .24665 .41526 .244 Mtetra
.612 .545 .755 r
.41526 .244 .41623 .24665 .41801 .24511 .417 .24347 Mtetra
.636 .655 .852 r
.417 .24347 .41801 .24511 .41979 .2438 .41875 .24293 Mtetra
.647 .802 .958 r
.41875 .24293 .41979 .2438 .42154 .24305 .42049 .24234 Mtetra
.647 .838 .974 r
.42049 .24234 .42154 .24305 .42329 .24246 .42225 .24172 Mtetra
.658 .836 .968 r
.42225 .24172 .42329 .24246 .42504 .24193 .424 .24106 Mtetra
.68 .813 .946 r
.424 .24106 .42504 .24193 .42679 .24129 .42576 .24035 Mtetra
.684 .798 .935 r
.42576 .24035 .42679 .24129 .42854 .24065 .42751 .23962 Mtetra
.684 .779 .923 r
.42751 .23962 .42854 .24065 .4303 .24 .42927 .2389 Mtetra
.672 .76 .917 r
.42927 .2389 .4303 .24 .43206 .23935 .43103 .23822 Mtetra
.668 .754 .915 r
.43103 .23822 .43206 .23935 .43381 .2387 .43279 .23756 Mtetra
.666 .751 .913 r
.43279 .23756 .43381 .2387 .43557 .23807 .43455 .2369 Mtetra
.684 .752 .903 r
.43455 .2369 .43557 .23807 .43733 .23751 .43631 .23616 Mtetra
.668 .715 .884 r
.43631 .23616 .43733 .23751 .43909 .23694 .43808 .23548 Mtetra
.642 .686 .876 r
.43808 .23548 .43909 .23694 .44085 .23634 .43984 .23492 Mtetra
.536 .646 .905 r
.43984 .23492 .44085 .23634 .44262 .2356 .44159 .23478 Mtetra
.39 .708 .985 r
.44159 .23478 .44262 .2356 .44439 .23482 .44334 .23479 Mtetra
0 .57 .714 r
.44334 .23479 .44439 .23482 .44615 .23405 .44508 .23483 Mtetra
0 0 0 r
.44508 .23483 .44615 .23405 .44793 .23299 .44686 .23379 Mtetra
.44686 .23379 .44793 .23299 .4497 .23221 .44864 .23295 Mtetra
.256 0 0 r
.44864 .23295 .4497 .23221 .45146 .23201 .45039 .23287 Mtetra
.886 .511 .324 r
.45039 .23287 .45146 .23201 .45316 .23449 .45201 .23885 Mtetra
.962 .676 .444 r
.45201 .23885 .45316 .23449 .45042 .43099 .44898 .44529 Mtetra
.614 .334 .47 r
.44898 .44529 .45042 .43099 .45192 .44754 .45076 .44947 Mtetra
.482 .054 .15 r
.45076 .44947 .45192 .44754 .45377 .44911 .45264 .44977 Mtetra
0 0 0 r
.45264 .44977 .45377 .44911 .45566 .44938 .45455 .44914 Mtetra
.72 .957 .947 r
.45455 .44914 .45566 .44938 .45755 .44911 .45646 .44802 Mtetra
.762 .802 .885 r
.45646 .44802 .45755 .44911 .45945 .44866 .45838 .44678 Mtetra
.738 .685 .8 r
.45838 .44678 .45945 .44866 .46136 .44804 .4603 .4454 Mtetra
.706 .609 .747 r
.4603 .4454 .46136 .44804 .46327 .44732 .46222 .44398 Mtetra
.571 .495 .73 r
.46222 .44398 .46327 .44732 .46517 .44706 .46413 .44368 Mtetra
.581 .499 .727 r
.46413 .44368 .46517 .44706 .46708 .44659 .46603 .44329 Mtetra
.659 .549 .719 r
.46603 .44329 .46708 .44659 .469 .44552 .46795 .44213 Mtetra
.867 .656 .615 r
.46795 .44213 .469 .44552 .47096 .44171 .46997 .43545 Mtetra
.965 .683 .448 r
.46997 .43545 .47096 .44171 .4731 .4271 .47526 .22711 Mtetra
.533 .303 .512 r
.47526 .22711 .4731 .4271 .47808 .2258 .47712 .2217 Mtetra
.663 .514 .672 r
.47712 .2217 .47808 .2258 .4799 .22292 .47892 .2202 Mtetra
.613 .543 .752 r
.47892 .2202 .4799 .22292 .48171 .22144 .48071 .21963 Mtetra
.558 .6 .851 r
.48071 .21963 .48171 .22144 .4835 .2205 .48249 .21945 Mtetra
.62 .759 .945 r
.48249 .21945 .4835 .2205 .48529 .21982 .48428 .21896 Mtetra
.643 .81 .963 r
.48428 .21896 .48529 .21982 .48708 .21931 .48608 .21836 Mtetra
.657 .793 .947 r
.48608 .21836 .48708 .21931 .48887 .21889 .48787 .21773 Mtetra
.695 .761 .903 r
.48787 .21773 .48887 .21889 .49067 .2183 .48967 .21692 Mtetra
.689 .721 .874 r
.48967 .21692 .49067 .2183 .49246 .21762 .49147 .21612 Mtetra
.664 .691 .865 r
.49147 .21612 .49246 .21762 .49426 .21691 .49327 .21542 Mtetra
.649 .689 .874 r
.49327 .21542 .49426 .21691 .49607 .2158 .49507 .21481 Mtetra
.538 .741 .969 r
.49507 .21481 .49607 .2158 .49787 .21484 .49686 .21456 Mtetra
0 .41 .689 r
.49686 .21456 .49787 .21484 .49967 .21442 .49865 .21504 Mtetra
.876 .475 .267 r
.49865 .21504 .49967 .21442 .50145 .21634 .50041 .22001 Mtetra
.967 .675 .426 r
.50041 .22001 .50145 .21634 .50317 .22762 .50067 .42759 Mtetra
.528 .294 .504 r
.50067 .42759 .50317 .22762 .50366 .42994 .50257 .43222 Mtetra
.54 .131 .215 r
.50257 .43222 .50366 .42994 .50557 .43198 .50449 .43288 Mtetra
.086 0 0 r
.50449 .43288 .50557 .43198 .50751 .43225 .50643 .43233 Mtetra
.6 .951 .881 r
.50643 .43233 .50751 .43225 .50944 .43196 .50838 .43126 Mtetra
.693 .872 .966 r
.50838 .43126 .50944 .43196 .51138 .43189 .51032 .43038 Mtetra
.72 .73 .858 r
.51032 .43038 .51138 .43189 .51332 .43156 .51226 .4293 Mtetra
.757 .662 .756 r
.51226 .4293 .51332 .43156 .51527 .43059 .51421 .42747 Mtetra
.866 .663 .627 r
.51421 .42747 .51527 .43059 .51722 .42733 .51617 .42163 Mtetra
.969 .683 .432 r
.51617 .42163 .51722 .42733 .51918 .41753 .51855 .21237 Mtetra
.534 .303 .512 r
.51855 .21237 .51918 .41753 .52136 .21088 .52038 .20628 Mtetra
.672 .507 .654 r
.52038 .20628 .52136 .21088 .52318 .20746 .5222 .20442 Mtetra
.615 .527 .731 r
.5222 .20442 .52318 .20746 .525 .20594 .52402 .20378 Mtetra
.569 .567 .811 r
.52402 .20378 .525 .20594 .52682 .20497 .52583 .20354 Mtetra
.633 .694 .889 r
.52583 .20354 .52682 .20497 .52864 .20419 .52766 .20301 Mtetra
.674 .754 .911 r
.52766 .20301 .52864 .20419 .53046 .20352 .52948 .20229 Mtetra
.655 .74 .912 r
.52948 .20229 .53046 .20352 .53228 .20292 .5313 .20166 Mtetra
.657 .735 .907 r
.5313 .20166 .53228 .20292 .53411 .2019 .53313 .20102 Mtetra
.574 .784 .978 r
.53313 .20102 .53411 .2019 .53593 .20089 .53495 .20063 Mtetra
0 .536 .779 r
.53495 .20063 .53593 .20089 .53776 .20037 .53678 .20089 Mtetra
.843 .408 .194 r
.53678 .20089 .53776 .20037 .53959 .20183 .53863 .20463 Mtetra
.97 .675 .41 r
.53863 .20463 .53959 .20183 .54147 .20927 .54154 .41279 Mtetra
.53 .295 .504 r
.54154 .41279 .54147 .20927 .54456 .41566 .54354 .41836 Mtetra
.571 .179 .26 r
.54354 .41836 .54456 .41566 .54655 .41834 .54551 .41931 Mtetra
.112 0 0 r
.54551 .41931 .54655 .41834 .54852 .41872 .54748 .41876 Mtetra
.618 .957 .888 r
.54748 .41876 .54852 .41872 .55049 .41849 .54945 .41765 Mtetra
.707 .852 .952 r
.54945 .41765 .55049 .41849 .55246 .41837 .55142 .41672 Mtetra
.695 .703 .854 r
.55142 .41672 .55246 .41837 .55444 .41812 .55339 .41577 Mtetra
.737 .648 .761 r
.55339 .41577 .55444 .41812 .55641 .41724 .55535 .41413 Mtetra
.849 .657 .643 r
.55535 .41413 .55641 .41724 .55836 .41438 .55728 .40921 Mtetra
.972 .682 .417 r
.55728 .40921 .55836 .41438 .56026 .40629 .55703 .19973 Mtetra
.535 .305 .512 r
.55703 .19973 .56026 .40629 .55982 .19768 .55881 .19262 Mtetra
.679 .503 .642 r
.55881 .19262 .55982 .19768 .56162 .19361 .56063 .19043 Mtetra
.618 .522 .723 r
.56063 .19043 .56162 .19361 .56346 .19199 .56248 .18972 Mtetra
.573 .56 .801 r
.56248 .18972 .56346 .19199 .5653 .19097 .56433 .18946 Mtetra
.615 .676 .884 r
.56433 .18946 .5653 .19097 .56714 .19018 .56617 .189 Mtetra
.675 .759 .914 r
.56617 .189 .56714 .19018 .56899 .18948 .56802 .18828 Mtetra
.66 .749 .916 r
.56802 .18828 .56899 .18948 .57084 .18886 .56987 .18762 Mtetra
.661 .742 .91 r
.56987 .18762 .57084 .18886 .57268 .18788 .57172 .18695 Mtetra
.606 .787 .967 r
.57172 .18695 .57268 .18788 .57452 .1868 .57358 .18646 Mtetra
.121 .647 .878 r
.57358 .18646 .57452 .1868 .57638 .18616 .57544 .18656 Mtetra
.795 .32 .097 r
.57544 .18656 .57638 .18616 .57826 .18719 .57736 .18934 Mtetra
.972 .673 .392 r
.57736 .18934 .57826 .18719 .58023 .19267 .58297 .39701 Mtetra
.532 .297 .504 r
.58297 .39701 .58023 .19267 .58605 .4007 .58511 .40408 Mtetra
.593 .221 .307 r
.58511 .40408 .58605 .4007 .58812 .40427 .58714 .40536 Mtetra
.131 0 0 r
.58714 .40536 .58812 .40427 .59014 .40475 .58914 .40475 Mtetra
.633 .963 .89 r
.58914 .40475 .59014 .40475 .59215 .40449 .59113 .4036 Mtetra
.675 .836 .96 r
.59113 .4036 .59215 .40449 .59415 .40425 .59312 .40279 Mtetra
.597 .696 .912 r
.59312 .40279 .59415 .40425 .59616 .40394 .59513 .40237 Mtetra
.698 .72 .866 r
.59513 .40237 .59616 .40394 .59816 .40286 .59713 .4014 Mtetra
.888 .777 .733 r
.59713 .4014 .59816 .40286 .60008 .39898 .59907 .39825 Mtetra
.984 .736 .479 r
.59907 .39825 .60008 .39898 .59706 .18845 .60071 .38219 Mtetra
0 0 .321 r
.60071 .38219 .59706 .18845 .59872 .17913 .59782 .18024 Mtetra
.761 .894 .492 r
.59782 .18024 .59872 .17913 .60054 .17647 .59963 .17714 Mtetra
0 0 0 r
.59963 .17714 .60054 .17647 .6024 .17569 .6015 .17628 Mtetra
.111 0 0 r
.6015 .17628 .6024 .17569 .60428 .17541 .60338 .17599 Mtetra
.1 0 0 r
.60338 .17599 .60428 .17541 .60616 .1751 .60526 .17568 Mtetra
0 0 0 r
.60526 .17568 .60616 .1751 .60804 .17448 .60714 .17507 Mtetra
.60714 .17507 .60804 .17448 .60991 .17385 .60902 .17446 Mtetra
.60902 .17446 .60991 .17385 .61179 .17321 .6109 .17382 Mtetra
.6109 .17382 .61179 .17321 .61367 .17254 .61278 .17316 Mtetra
.61278 .17316 .61367 .17254 .61554 .17186 .61466 .17248 Mtetra
.61466 .17248 .61554 .17186 .61742 .17116 .61654 .17177 Mtetra
.61654 .17177 .61742 .17116 .6193 .17043 .61842 .17104 Mtetra
.61842 .17104 .6193 .17043 .62118 .1697 .6203 .17029 Mtetra
.6203 .17029 .62118 .1697 .62306 .16876 .62217 .16931 Mtetra
.62217 .16931 .62306 .16876 .62493 .1677 .62404 .16819 Mtetra
.62404 .16819 .62493 .1677 .62681 .1671 .62593 .16759 Mtetra
.606 .064 0 r
.62593 .16759 .62681 .1671 .62876 .16803 .62789 .16882 Mtetra
.945 .596 .317 r
.62789 .16882 .62876 .16803 .63091 .17485 .63035 .18433 Mtetra
.967 .661 .385 r
.63035 .18433 .63091 .17485 .64041 .38523 .63943 .38463 Mtetra
.662 .132 0 r
.63943 .38463 .64041 .38523 .64258 .38836 .64157 .38703 Mtetra
.549 .699 .939 r
.64157 .38703 .64258 .38836 .64463 .38814 .64362 .38676 Mtetra
.684 .749 .901 r
.64362 .38676 .64463 .38814 .64666 .38723 .64566 .38591 Mtetra
.649 .745 .92 r
.64566 .38591 .64666 .38723 .6487 .38654 .6477 .38524 Mtetra
.503 .683 .947 r
.6477 .38524 .6487 .38654 .65076 .38651 .64976 .38512 Mtetra
.649 .734 .911 r
.64976 .38512 .65076 .38651 .65281 .38592 .6518 .38444 Mtetra
.855 .78 .778 r
.6518 .38444 .65281 .38592 .65478 .38358 .65377 .382 Mtetra
.97 .74 .535 r
.65377 .382 .65478 .38358 .65647 .37426 .65544 .37194 Mtetra
.977 .679 .372 r
.65544 .37194 .65647 .37426 .64972 .16324 .64878 .1618 Mtetra
.92 .773 .681 r
.64878 .1618 .64972 .16324 .65148 .15919 .65055 .1579 Mtetra
.715 .76 .888 r
.65055 .1579 .65148 .15919 .65337 .15821 .65244 .15693 Mtetra
.579 .708 .93 r
.65244 .15693 .65337 .15821 .65529 .15785 .65436 .15658 Mtetra
.553 .697 .935 r
.65436 .15658 .65529 .15785 .65722 .15759 .65629 .15632 Mtetra
.665 .746 .911 r
.65629 .15632 .65722 .15759 .65912 .15689 .6582 .15562 Mtetra
.671 .749 .909 r
.6582 .15562 .65912 .15689 .66103 .15614 .66011 .15489 Mtetra
.711 .766 .895 r
.66011 .15489 .66103 .15614 .66293 .15516 .66201 .15394 Mtetra
.762 .789 .876 r
.66201 .15394 .66293 .15516 .66481 .15385 .66389 .15271 Mtetra
.674 .776 .927 r
.66389 .15271 .66481 .15385 .66672 .15302 .6658 .15197 Mtetra
.12 .488 .901 r
.6658 .15197 .66672 .15302 .66869 .1536 .66779 .15268 Mtetra
.914 .525 .119 r
.66779 .15268 .66869 .1536 .67098 .16047 .67014 .16088 Mtetra
.974 .667 .345 r
.67014 .16088 .67098 .16047 .6834 .37129 .68244 .37057 Mtetra
.716 .215 0 r
.68244 .37057 .6834 .37129 .68567 .37473 .6847 .37366 Mtetra
.539 .752 .975 r
.6847 .37366 .68567 .37473 .68776 .37459 .68678 .37335 Mtetra
.712 .786 .91 r
.68678 .37335 .68776 .37459 .68982 .37366 .68884 .37234 Mtetra
.708 .772 .902 r
.68884 .37234 .68982 .37366 .69186 .37241 .69089 .37135 Mtetra
.464 .716 .978 r
.69089 .37135 .69186 .37241 .69391 .37144 .69299 .37125 Mtetra
.428 .863 .922 r
.69299 .37125 .69391 .37144 .69594 .3699 .69507 .37065 Mtetra
.555 .859 .553 r
.69507 .37065 .69594 .3699 .69788 .36675 .69708 .36864 Mtetra
.926 .814 .352 r
.69708 .36864 .69788 .36675 .68923 .17075 .69874 .36027 Mtetra
0 0 .338 r
.69874 .36027 .68923 .17075 .68996 .14808 .68909 .14757 Mtetra
.984 .855 .632 r
.68909 .14757 .68996 .14808 .69173 .14455 .6908 .14299 Mtetra
.713 .718 .853 r
.6908 .14299 .69173 .14455 .69364 .14354 .69272 .14195 Mtetra
.588 .658 .886 r
.69272 .14195 .69364 .14354 .69559 .14307 .69467 .14159 Mtetra
.532 .648 .908 r
.69467 .14159 .69559 .14307 .69754 .14277 .69664 .14145 Mtetra
.656 .735 .908 r
.69664 .14145 .69754 .14277 .69948 .14207 .69857 .14077 Mtetra
.664 .745 .91 r
.69857 .14077 .69948 .14207 .70141 .14133 .70051 .14006 Mtetra
.689 .76 .906 r
.70051 .14006 .70141 .14133 .70334 .14043 .70244 .13923 Mtetra
.754 .794 .886 r
.70244 .13923 .70334 .14043 .70524 .13909 .70435 .13805 Mtetra
.686 .804 .938 r
.70435 .13805 .70524 .13909 .70717 .13821 .70629 .13724 Mtetra
.369 .668 .973 r
.70629 .13724 .70717 .13821 .70917 .13846 .70828 .13737 Mtetra
.737 .29 0 r
.70828 .13737 .70917 .13846 .71154 .1445 .71052 .14136 Mtetra
.974 .664 .313 r
.71052 .14136 .71154 .1445 .72702 .35668 .72581 .35134 Mtetra
0 0 .528 r
.72581 .35134 .72702 .35668 .72942 .36064 .72831 .35713 Mtetra
.467 .431 .734 r
.72831 .35713 .72942 .36064 .73154 .36037 .73049 .35766 Mtetra
.572 .543 .784 r
.73049 .35766 .73154 .36037 .73362 .35934 .73262 .35736 Mtetra
.638 .649 .845 r
.73262 .35736 .73362 .35934 .73568 .35804 .73472 .35669 Mtetra
.63 .74 .926 r
.73472 .35669 .73568 .35804 .7378 .35754 .73683 .35608 Mtetra
.65 .729 .907 r
.73683 .35608 .7378 .35754 .73991 .35698 .73894 .35538 Mtetra
.639 .701 .891 r
.73894 .35538 .73991 .35698 .74202 .35625 .74105 .35472 Mtetra
.513 .652 .921 r
.74105 .35472 .74202 .35625 .74411 .35527 .7432 .35462 Mtetra
.525 .843 .999 r
.7432 .35462 .74411 .35527 .74616 .35373 .74533 .35413 Mtetra
.456 .855 .668 r
.74533 .35413 .74616 .35373 .74812 .35092 .74739 .35279 Mtetra
.69 .759 .265 r
.74739 .35279 .74812 .35092 .74919 .33555 .74921 .34784 Mtetra
.973 .676 .287 r
.74921 .34784 .74919 .33555 .73669 .13125 .73641 .13849 Mtetra
0 0 .189 r
.73641 .13849 .73669 .13125 .73842 .12729 .73771 .12848 Mtetra
0 0 0 r
.73771 .12848 .73842 .12729 .74036 .12625 .73958 .12638 Mtetra
.565 .932 .795 r
.73958 .12638 .74036 .12625 .74234 .1258 .74151 .12517 Mtetra
.649 .889 .983 r
.74151 .12517 .74234 .1258 .74435 .12566 .74347 .12439 Mtetra
.669 .756 .916 r
.74347 .12439 .74435 .12566 .74633 .12505 .74544 .12365 Mtetra
.641 .719 .904 r
.74544 .12365 .74633 .12505 .7483 .1244 .74741 .12303 Mtetra
.633 .721 .911 r
.74741 .12303 .7483 .1244 .75027 .12369 .7494 .12245 Mtetra
.668 .761 .92 r
.7494 .12245 .75027 .12369 .75223 .12286 .75137 .12171 Mtetra
.675 .783 .931 r
.75137 .12171 .75223 .12286 .75419 .12199 .75334 .12094 Mtetra
.682 .807 .942 r
.75334 .12094 .75419 .12199 .75616 .1211 .7553 .12013 Mtetra
.684 .826 .951 r
.7553 .12013 .75616 .1211 .75812 .12027 .75727 .11931 Mtetra
.69 .83 .951 r
.75727 .11931 .75812 .12027 .76009 .11944 .75924 .11847 Mtetra
.695 .829 .947 r
.75924 .11847 .76009 .11944 .76206 .11861 .76121 .1176 Mtetra
.754 .754 .852 r
.1278 .34801 .12893 .34909 .13053 .34824 .12943 .34692 Mtetra
.713 .709 .845 r
.12943 .34692 .13053 .34824 .13213 .34746 .13103 .34603 Mtetra
.642 .672 .863 r
.13103 .34603 .13213 .34746 .13371 .34681 .1326 .34553 Mtetra
.029 .38 .844 r
.1326 .34553 .13371 .34681 .13528 .34624 .134 .34628 Mtetra
.803 .353 .173 r
.134 .34628 .13528 .34624 .1368 .34607 .13526 .3483 Mtetra
.842 .528 .458 r
.13526 .3483 .1368 .34607 .13823 .34662 .13594 .355 Mtetra
.926 .669 .529 r
.13594 .355 .13823 .34662 .1391 .35185 .11351 .5513 Mtetra
.528 .294 .505 r
.11351 .5513 .1391 .35185 .11625 .55307 .11464 .55523 Mtetra
.665 .289 .323 r
.11464 .55523 .11625 .55307 .11732 .55754 .11605 .55682 Mtetra
.09 .561 .906 r
.11605 .55682 .11732 .55754 .11887 .55796 .11762 .55717 Mtetra
.548 .779 .984 r
.11762 .55717 .11887 .55796 .12054 .55752 .11927 .55686 Mtetra
.729 .847 .937 r
.11927 .55686 .12054 .55752 .12226 .55659 .12099 .55596 Mtetra
.863 .829 .812 r
.12099 .55596 .12226 .55659 .12395 .55596 .12285 .55388 Mtetra
.833 .678 .692 r
.12285 .55388 .12395 .55596 .12568 .55493 .12489 .55032 Mtetra
.842 .624 .608 r
.12489 .55032 .12568 .55493 .12752 .55305 .12759 .54106 Mtetra
.926 .673 .535 r
.12759 .54106 .12752 .55305 .13001 .54557 .15233 .34443 Mtetra
.531 .302 .512 r
.15233 .34443 .13001 .54557 .1552 .34366 .15437 .34005 Mtetra
.728 .564 .669 r
.15437 .34005 .1552 .34366 .15728 .33886 .15616 .33767 Mtetra
.733 .736 .854 r
.15616 .33767 .15728 .33886 .15895 .33757 .15779 .33669 Mtetra
.645 .778 .944 r
.15779 .33669 .15895 .33757 .16052 .33707 .15937 .33618 Mtetra
.575 .755 .963 r
.15937 .33618 .16052 .33707 .16206 .33691 .16093 .33587 Mtetra
.707 .758 .892 r
.16093 .33587 .16206 .33691 .16365 .3363 .16254 .33509 Mtetra
.687 .722 .876 r
.16254 .33509 .16365 .3363 .16525 .33566 .16414 .33438 Mtetra
.615 .689 .896 r
.16414 .33438 .16525 .33566 .16683 .3351 .16571 .33399 Mtetra
.031 .42 .863 r
.16571 .33399 .16683 .3351 .16843 .33451 .16716 .33465 Mtetra
.787 .332 .163 r
.16716 .33465 .16843 .33451 .16998 .33424 .16847 .33659 Mtetra
.835 .516 .45 r
.16847 .33659 .16998 .33424 .17146 .33467 .16929 .34296 Mtetra
.93 .67 .522 r
.16929 .34296 .17146 .33467 .17246 .33946 .14883 .53954 Mtetra
.528 .294 .504 r
.14883 .53954 .17246 .33946 .1516 .54127 .15001 .54356 Mtetra
.662 .288 .325 r
.15001 .54356 .1516 .54127 .15271 .54594 .15147 .54517 Mtetra
.363 .71 .986 r
.15147 .54517 .15271 .54594 .1543 .54642 .15311 .5452 Mtetra
.645 .723 .905 r
.15311 .5452 .1543 .54642 .15599 .54588 .1548 .54465 Mtetra
.688 .734 .886 r
.1548 .54465 .15599 .54588 .15774 .54495 .15653 .54389 Mtetra
.422 .672 .966 r
.15653 .54389 .15774 .54495 .15939 .54486 .15816 .54394 Mtetra
.476 .727 .98 r
.15816 .54394 .15939 .54486 .16105 .54464 .15982 .54383 Mtetra
.706 .817 .934 r
.15982 .54383 .16105 .54464 .1628 .54372 .16155 .54302 Mtetra
.914 .779 .698 r
.16155 .54302 .1628 .54372 .16491 .53933 .16365 .53882 Mtetra
.943 .689 .522 r
.16365 .53882 .16491 .53933 .18826 .33568 .18702 .33569 Mtetra
.953 .754 .598 r
.18702 .33569 .18826 .33568 .19072 .32712 .18959 .3261 Mtetra
.834 .771 .792 r
.18959 .3261 .19072 .32712 .19246 .32525 .19134 .32417 Mtetra
.67 .745 .906 r
.19134 .32417 .19246 .32525 .19407 .32464 .19295 .32355 Mtetra
.534 .698 .945 r
.19295 .32355 .19407 .32464 .19563 .32448 .19451 .32339 Mtetra
.72 .754 .879 r
.19451 .32339 .19563 .32448 .19727 .32362 .19615 .32252 Mtetra
.714 .752 .882 r
.19615 .32252 .19727 .32362 .1989 .32279 .19779 .32168 Mtetra
.556 .704 .939 r
.19779 .32168 .1989 .32279 .20047 .32257 .19936 .32146 Mtetra
.868 .427 .041 r
.19936 .32146 .20047 .32257 .20173 .32544 .20062 .32431 Mtetra
.945 .684 .51 r
.20062 .32431 .20173 .32544 .18257 .52816 .18138 .52705 Mtetra
.946 .612 .361 r
.18138 .52705 .18257 .52816 .18346 .53573 .18226 .53468 Mtetra
.475 0 0 r
.18226 .53468 .18346 .53573 .18499 .53707 .18378 .53603 Mtetra
.555 .733 .958 r
.18378 .53603 .18499 .53707 .18668 .5368 .18547 .53576 Mtetra
.779 .783 .856 r
.18547 .53576 .18668 .5368 .18847 .53547 .18727 .53444 Mtetra
.9 .757 .694 r
.18727 .53444 .18847 .53547 .19056 .53129 .18936 .53025 Mtetra
.945 .688 .517 r
.18936 .53025 .19056 .53129 .21234 .32843 .21123 .32733 Mtetra
.929 .719 .598 r
.21123 .32733 .21234 .32843 .21489 .31855 .21378 .31746 Mtetra
.841 .762 .775 r
.21378 .31746 .21489 .31855 .21666 .31642 .21555 .31533 Mtetra
.678 .745 .901 r
.21555 .31533 .21666 .31642 .21829 .31577 .21718 .31467 Mtetra
.544 .701 .942 r
.21718 .31467 .21829 .31577 .21987 .31557 .21876 .31447 Mtetra
.702 .75 .889 r
.21876 .31447 .21987 .31557 .22151 .3148 .2204 .31369 Mtetra
.718 .753 .88 r
.2204 .31369 .22151 .3148 .22316 .31393 .22206 .31283 Mtetra
.575 .712 .935 r
.22206 .31283 .22316 .31393 .22476 .31365 .22365 .31255 Mtetra
.813 .347 0 r
.22365 .31255 .22476 .31365 .22609 .31611 .22499 .315 Mtetra
.948 .684 .504 r
.22499 .315 .22609 .31611 .20854 .51811 .20736 .51699 Mtetra
.949 .623 .376 r
.20736 .51699 .20854 .51811 .20938 .52698 .20819 .52592 Mtetra
.576 .057 0 r
.20819 .52592 .20938 .52698 .21091 .52858 .20972 .52753 Mtetra
.525 .719 .962 r
.20972 .52753 .21091 .52858 .21261 .5284 .21142 .52734 Mtetra
.767 .782 .865 r
.21142 .52734 .21261 .5284 .21441 .52717 .21322 .5261 Mtetra
.895 .762 .708 r
.21322 .5261 .21441 .52717 .21644 .52341 .21526 .52233 Mtetra
.948 .689 .512 r
.21526 .52233 .21644 .52341 .23637 .32443 .23532 .32273 Mtetra
.927 .7 .574 r
.23532 .32273 .23637 .32443 .23927 .31012 .23817 .30896 Mtetra
.852 .756 .756 r
.23817 .30896 .23927 .31012 .24107 .30769 .23997 .30654 Mtetra
.673 .736 .897 r
.23997 .30654 .24107 .30769 .24271 .30705 .24162 .30589 Mtetra
.523 .681 .938 r
.24162 .30589 .24271 .30705 .2443 .30694 .24321 .30576 Mtetra
.573 .697 .926 r
.24321 .30576 .2443 .30694 .24591 .30669 .24482 .3055 Mtetra
.644 .719 .902 r
.24482 .3055 .24591 .30669 .24754 .30619 .24646 .30497 Mtetra
.657 .72 .894 r
.24646 .30497 .24754 .30619 .24918 .30565 .2481 .30439 Mtetra
.689 .722 .875 r
.2481 .30439 .24918 .30565 .25083 .305 .24975 .30365 Mtetra
.705 .712 .854 r
.24975 .30365 .25083 .305 .25248 .30426 .25142 .30279 Mtetra
.701 .694 .84 r
.25142 .30279 .25248 .30426 .25414 .30349 .25309 .30193 Mtetra
.706 .683 .825 r
.25309 .30193 .25414 .30349 .2558 .30269 .25476 .301 Mtetra
.689 .661 .817 r
.25476 .301 .2558 .30269 .25747 .30191 .25643 .30015 Mtetra
.636 .631 .828 r
.25643 .30015 .25747 .30191 .25912 .30125 .25807 .29961 Mtetra
.414 .54 .875 r
.25807 .29961 .25912 .30125 .26077 .30067 .25964 .29989 Mtetra
.65 .115 0 r
.25964 .29989 .26077 .30067 .26239 .30033 .26111 .30146 Mtetra
.846 .485 .369 r
.26111 .30146 .26239 .30033 .26397 .30062 .26233 .30596 Mtetra
.943 .675 .5 r
.26233 .30596 .26397 .30062 .26532 .30365 .24725 .50602 Mtetra
.53 .296 .505 r
.24725 .50602 .26532 .30365 .25015 .50694 .24852 .51134 Mtetra
.638 .307 .394 r
.24852 .51134 .25015 .50694 .25134 .51331 .25007 .51334 Mtetra
.331 0 0 r
.25007 .51334 .25134 .51331 .25295 .51463 .25175 .51378 Mtetra
.605 .793 .971 r
.25175 .51378 .25295 .51463 .2547 .51423 .25351 .51331 Mtetra
.693 .802 .933 r
.25351 .51331 .2547 .51423 .25649 .51335 .25529 .51254 Mtetra
.644 .814 .965 r
.25529 .51254 .25649 .51335 .25827 .51257 .25706 .51194 Mtetra
.552 .826 .997 r
.25706 .51194 .25827 .51257 .26004 .51205 .25882 .51154 Mtetra
.649 .879 .983 r
.25882 .51154 .26004 .51205 .26181 .51143 .2606 .51085 Mtetra
.82 .875 .885 r
.2606 .51085 .26181 .51143 .26359 .51074 .26244 .50936 Mtetra
.855 .745 .74 r
.26244 .50936 .26359 .51074 .26539 .50985 .26439 .50653 Mtetra
.832 .638 .641 r
.26439 .50653 .26539 .50985 .26723 .50833 .26653 .50121 Mtetra
.946 .682 .504 r
.26653 .50121 .26723 .50833 .26927 .50429 .2838 .29999 Mtetra
.537 .307 .513 r
.2838 .29999 .26927 .50429 .28659 .30006 .28599 .29262 Mtetra
.673 .473 .606 r
.28599 .29262 .28659 .30006 .28885 .29169 .28785 .28949 Mtetra
.744 .637 .742 r
.28785 .28949 .28885 .29169 .29066 .28913 .28959 .28785 Mtetra
.685 .72 .876 r
.28959 .28785 .29066 .28913 .29234 .28833 .29127 .28712 Mtetra
.613 .71 .914 r
.29127 .28712 .29234 .28833 .29399 .288 .29292 .28671 Mtetra
.593 .688 .908 r
.29292 .28671 .29399 .288 .29564 .28771 .29457 .28638 Mtetra
.614 .688 .896 r
.29457 .28638 .29564 .28771 .2973 .28721 .29623 .28597 Mtetra
.619 .706 .907 r
.29623 .28597 .2973 .28721 .29897 .28671 .29789 .28554 Mtetra
.656 .732 .905 r
.29789 .28554 .29897 .28671 .30064 .28614 .29956 .28495 Mtetra
.695 .741 .886 r
.29956 .28495 .30064 .28614 .30232 .28549 .30125 .28418 Mtetra
.697 .721 .868 r
.30125 .28418 .30232 .28549 .304 .28481 .30294 .28338 Mtetra
.699 .702 .849 r
.30294 .28338 .304 .28481 .30568 .28411 .30463 .28253 Mtetra
.689 .678 .834 r
.30463 .28253 .30568 .28411 .30736 .2834 .30633 .28169 Mtetra
.641 .642 .836 r
.30633 .28169 .30736 .2834 .30904 .28278 .308 .28113 Mtetra
.446 .557 .874 r
.308 .28113 .30904 .28278 .31071 .28241 .30963 .28133 Mtetra
.569 .067 0 r
.30963 .28133 .31071 .28241 .31235 .28236 .31115 .28302 Mtetra
.85 .46 .307 r
.31115 .28302 .31235 .28236 .31398 .28241 .31253 .28685 Mtetra
.827 .514 .46 r
.31253 .28685 .31398 .28241 .31565 .28203 .31356 .29601 Mtetra
.43 .179 .43 r
.31356 .29601 .31565 .28203 .31737 .281 .31536 .29376 Mtetra
.421 .168 .422 r
.31536 .29376 .31737 .281 .31905 .28043 .31716 .2915 Mtetra
.941 .666 .491 r
.31716 .2915 .31905 .28043 .32061 .28177 .30624 .48154 Mtetra
.537 .302 .506 r
.30624 .48154 .32061 .28177 .30925 .48106 .30741 .49044 Mtetra
.618 .327 .453 r
.30741 .49044 .30925 .48106 .31023 .49304 .30898 .49339 Mtetra
.593 .053 0 r
.30898 .49339 .31023 .49304 .31185 .49522 .31068 .49439 Mtetra
.564 .79 .984 r
.31068 .49439 .31185 .49522 .31364 .49496 .31248 .49401 Mtetra
.68 .8 .939 r
.31248 .49401 .31364 .49496 .31546 .49414 .31429 .49328 Mtetra
.671 .816 .953 r
.31429 .49328 .31546 .49414 .31729 .49325 .31611 .49257 Mtetra
.544 .817 .997 r
.31611 .49257 .31729 .49325 .31909 .49272 .31791 .49219 Mtetra
.625 .875 .988 r
.31791 .49219 .31909 .49272 .3209 .4921 .31972 .49155 Mtetra
.806 .892 .905 r
.31972 .49155 .3209 .4921 .32273 .49124 .32158 .49016 Mtetra
.886 .782 .741 r
.32158 .49016 .32273 .49124 .32458 .49 .32354 .48711 Mtetra
.847 .658 .647 r
.32354 .48711 .32458 .49 .32644 .48865 .32563 .482 Mtetra
.819 .587 .589 r
.32563 .482 .32644 .48865 .32828 .48766 .32798 .47239 Mtetra
.521 .326 .557 r
.32798 .47239 .32828 .48766 .33007 .48753 .32974 .47256 Mtetra
.495 .307 .554 r
.32974 .47256 .33007 .48753 .33188 .48695 .33146 .47356 Mtetra
.944 .674 .495 r
.33146 .47356 .33188 .48695 .3338 .48461 .34415 .28584 Mtetra
.552 .319 .515 r
.34415 .28584 .3338 .48461 .33673 .46458 .34663 .272 Mtetra
.53 .301 .512 r
.34663 .272 .33673 .46458 .34951 .2706 .34853 .26798 Mtetra
.757 .621 .709 r
.34853 .26798 .34951 .2706 .35137 .26718 .35032 .26584 Mtetra
.669 .711 .879 r
.35032 .26584 .35137 .26718 .35309 .26629 .35203 .26517 Mtetra
.575 .719 .94 r
.35203 .26517 .35309 .26629 .35478 .26594 .35372 .26487 Mtetra
.546 .717 .952 r
.35372 .26487 .35478 .26594 .35647 .26575 .35541 .26464 Mtetra
.646 .745 .921 r
.35541 .26464 .35647 .26575 .35818 .2652 .35712 .26409 Mtetra
.661 .749 .915 r
.35712 .26409 .35818 .2652 .35988 .26463 .35883 .26347 Mtetra
.691 .75 .897 r
.35883 .26347 .35988 .26463 .3616 .26398 .36055 .26272 Mtetra
.732 .741 .859 r
.36055 .26272 .3616 .26398 .36332 .26321 .36229 .26169 Mtetra
.686 .689 .848 r
.36229 .26169 .36332 .26321 .36504 .26249 .36401 .26089 Mtetra
.557 .624 .874 r
.36401 .26089 .36504 .26249 .36675 .26197 .3657 .26071 Mtetra
0 .089 .617 r
.3657 .26071 .36675 .26197 .36844 .26189 .36731 .26222 Mtetra
.855 .44 .244 r
.36731 .26222 .36844 .26189 .37012 .26195 .36882 .26578 Mtetra
.955 .677 .469 r
.36882 .26578 .37012 .26195 .37182 .26181 .36124 .4512 Mtetra
.506 .276 .499 r
.36124 .4512 .37182 .26181 .37356 .26072 .36333 .44522 Mtetra
0 0 .263 r
.36333 .44522 .37356 .26072 .37529 .26003 .37339 .27618 Mtetra
.939 .658 .481 r
.37339 .27618 .37529 .26003 .37695 .2607 .36615 .4613 Mtetra
.538 .303 .506 r
.36615 .4613 .37695 .2607 .36956 .45223 .36749 .471 Mtetra
.577 .312 .477 r
.36749 .471 .36956 .45223 .37038 .4731 .36916 .4741 Mtetra
.644 .173 .12 r
.36916 .4741 .37038 .4731 .37207 .47587 .37091 .47539 Mtetra
.429 .81 .991 r
.37091 .47539 .37207 .47587 .3739 .47572 .37275 .47512 Mtetra
.697 .881 .966 r
.37275 .47512 .3739 .47572 .37575 .4749 .37461 .47425 Mtetra
.822 .88 .887 r
.37461 .47425 .37575 .4749 .37763 .47366 .3765 .47272 Mtetra
.893 .809 .758 r
.3765 .47272 .37763 .47366 .37951 .4724 .37845 .46986 Mtetra
.853 .675 .66 r
.37845 .46986 .37951 .4724 .3814 .47102 .38048 .46528 Mtetra
.838 .606 .588 r
.38048 .46528 .3814 .47102 .38328 .46976 .38271 .45576 Mtetra
.563 .362 .566 r
.38271 .45576 .38328 .46976 .38511 .46959 .38459 .45455 Mtetra
.503 .313 .556 r
.38459 .45455 .38511 .46959 .38696 .46905 .38638 .45533 Mtetra
.677 .45 .571 r
.38638 .45533 .38696 .46905 .38886 .46735 .38846 .4491 Mtetra
.944 .668 .484 r
.38846 .4491 .38886 .46735 .39114 .45647 .39832 .25382 Mtetra
.53 .301 .512 r
.39832 .25382 .39114 .45647 .40118 .25236 .40022 .24934 Mtetra
.762 .606 .685 r
.40022 .24934 .40118 .25236 .40306 .2482 .40203 .24678 Mtetra
.711 .716 .853 r
.40203 .24678 .40306 .2482 .40482 .24708 .40378 .24585 Mtetra
.646 .725 .906 r
.40378 .24585 .40482 .24708 .40656 .24655 .40552 .24529 Mtetra
.602 .703 .914 r
.40552 .24529 .40656 .24655 .40828 .2463 .40726 .2449 Mtetra
.657 .7 .878 r
.40726 .2449 .40828 .2463 .41003 .24569 .409 .24427 Mtetra
.651 .695 .877 r
.409 .24427 .41003 .24569 .41177 .24511 .41074 .24367 Mtetra
.643 .689 .878 r
.41074 .24367 .41177 .24511 .41351 .24454 .41249 .24311 Mtetra
.619 .68 .886 r
.41249 .24311 .41351 .24454 .41526 .244 .41423 .24266 Mtetra
.614 .693 .9 r
.41423 .24266 .41526 .244 .417 .24347 .41597 .24222 Mtetra
.619 .713 .913 r
.41597 .24222 .417 .24347 .41875 .24293 .41771 .24177 Mtetra
.647 .741 .918 r
.41771 .24177 .41875 .24293 .42049 .24234 .41946 .2412 Mtetra
.663 .75 .915 r
.41946 .2412 .42049 .24234 .42225 .24172 .42122 .24056 Mtetra
.678 .751 .906 r
.42122 .24056 .42225 .24172 .424 .24106 .42297 .23985 Mtetra
.7 .748 .889 r
.42297 .23985 .424 .24106 .42576 .24035 .42473 .23903 Mtetra
.699 .729 .873 r
.42473 .23903 .42576 .24035 .42751 .23962 .42649 .23818 Mtetra
.692 .708 .86 r
.42649 .23818 .42751 .23962 .42927 .2389 .42826 .23736 Mtetra
.669 .685 .856 r
.42826 .23736 .42927 .2389 .43103 .23822 .43002 .23665 Mtetra
.661 .676 .854 r
.43002 .23665 .43103 .23822 .43279 .23756 .43178 .23597 Mtetra
.656 .673 .854 r
.43178 .23597 .43279 .23756 .43455 .2369 .43354 .23532 Mtetra
.694 .688 .84 r
.43354 .23532 .43455 .2369 .43631 .23616 .43531 .23443 Mtetra
.661 .656 .834 r
.43531 .23443 .43631 .23616 .43808 .23548 .43707 .23373 Mtetra
.596 .624 .849 r
.43707 .23373 .43808 .23548 .43984 .23492 .43882 .23337 Mtetra
.008 .312 .802 r
.43882 .23337 .43984 .23492 .44159 .23478 .44054 .23453 Mtetra
.818 .338 .037 r
.44054 .23453 .44159 .23478 .44334 .23479 .44222 .23723 Mtetra
.874 .534 .403 r
.44222 .23723 .44334 .23479 .44508 .23483 .44373 .24609 Mtetra
.613 .328 .46 r
.44373 .24609 .44508 .23483 .44686 .23379 .44541 .24942 Mtetra
.39 .152 .429 r
.44541 .24942 .44686 .23379 .44864 .23295 .44727 .24557 Mtetra
.56 .286 .457 r
.44727 .24557 .44864 .23295 .45039 .23287 .44899 .24719 Mtetra
.949 .661 .458 r
.44899 .24719 .45039 .23287 .45201 .23885 .44603 .44292 Mtetra
.527 .293 .503 r
.44603 .44292 .45201 .23885 .44898 .44529 .44782 .44701 Mtetra
.679 .257 .236 r
.44782 .44701 .44898 .44529 .45076 .44947 .44966 .44882 Mtetra
.251 .681 .962 r
.44966 .44882 .45076 .44947 .45264 .44977 .45155 .44894 Mtetra
.619 .82 .977 r
.45155 .44894 .45264 .44977 .45455 .44914 .45345 .44837 Mtetra
.762 .864 .924 r
.45345 .44837 .45455 .44914 .45646 .44802 .45537 .4472 Mtetra
.892 .843 .789 r
.45537 .4472 .45646 .44802 .45838 .44678 .45731 .44466 Mtetra
.868 .705 .678 r
.45731 .44466 .45838 .44678 .4603 .4454 .45929 .44055 Mtetra
.851 .622 .591 r
.45929 .44055 .4603 .4454 .46222 .44398 .46135 .43198 Mtetra
.648 .432 .577 r
.46135 .43198 .46222 .44398 .46413 .44368 .46332 .42787 Mtetra
.489 .302 .553 r
.46332 .42787 .46413 .44368 .46603 .44329 .46518 .42918 Mtetra
.562 .361 .566 r
.46518 .42918 .46603 .44329 .46795 .44213 .4671 .42798 Mtetra
.956 .673 .459 r
.4671 .42798 .46795 .44213 .46997 .43545 .47243 .22838 Mtetra
.532 .302 .512 r
.47243 .22838 .46997 .43545 .47526 .22711 .4743 .22297 Mtetra
.739 .56 .652 r
.4743 .22297 .47526 .22711 .47712 .2217 .47612 .22004 Mtetra
.717 .689 .822 r
.47612 .22004 .47712 .2217 .47892 .2202 .47792 .21896 Mtetra
.617 .719 .919 r
.47792 .21896 .47892 .2202 .48071 .21963 .4797 .2185 Mtetra
.539 .708 .949 r
.4797 .2185 .48071 .21963 .48249 .21945 .48149 .21828 Mtetra
.625 .736 .927 r
.48149 .21828 .48249 .21945 .48428 .21896 .48328 .21779 Mtetra
.657 .746 .916 r
.48328 .21779 .48428 .21896 .48608 .21836 .48507 .21716 Mtetra
.671 .746 .907 r
.48507 .21716 .48608 .21836 .48787 .21773 .48687 .21646 Mtetra
.733 .755 .87 r
.48687 .21646 .48787 .21773 .48967 .21692 .48867 .21542 Mtetra
.71 .71 .849 r
.48867 .21542 .48967 .21692 .49147 .21612 .49047 .21446 Mtetra
.647 .663 .852 r
.49047 .21446 .49147 .21612 .49327 .21542 .49227 .21384 Mtetra
.327 .51 .884 r
.49227 .21384 .49327 .21542 .49507 .21481 .49406 .21436 Mtetra
.693 .155 0 r
.49406 .21436 .49507 .21481 .49686 .21456 .49584 .21629 Mtetra
.87 .505 .354 r
.49584 .21629 .49686 .21456 .49865 .21504 .49757 .22307 Mtetra
.962 .67 .433 r
.49757 .22307 .49865 .21504 .50041 .22001 .49768 .42611 Mtetra
.527 .293 .503 r
.49768 .42611 .50041 .22001 .50067 .42759 .49957 .43017 Mtetra
.637 .244 .283 r
.49957 .43017 .50067 .42759 .50257 .43222 .50149 .43178 Mtetra
.068 .596 .868 r
.50149 .43178 .50257 .43222 .50449 .43288 .50342 .43203 Mtetra
.592 .81 .983 r
.50342 .43203 .50449 .43288 .50643 .43233 .50536 .43153 Mtetra
.743 .862 .935 r
.50536 .43153 .50643 .43233 .50838 .43126 .50731 .43044 Mtetra
.861 .862 .838 r
.50731 .43044 .50838 .43126 .51032 .43038 .50926 .42844 Mtetra
.856 .718 .709 r
.50926 .42844 .51032 .43038 .51226 .4293 .51121 .42512 Mtetra
.849 .63 .606 r
.51121 .42512 .51226 .4293 .51421 .42747 .51318 .41823 Mtetra
.965 .679 .438 r
.51318 .41823 .51421 .42747 .51617 .42163 .51574 .21277 Mtetra
.532 .302 .511 r
.51574 .21277 .51617 .42163 .51855 .21237 .51757 .20714 Mtetra
.702 .516 .633 r
.51757 .20714 .51855 .21237 .52038 .20628 .51939 .20435 Mtetra
.721 .663 .792 r
.51939 .20435 .52038 .20628 .5222 .20442 .52121 .20311 Mtetra
.629 .714 .908 r
.52121 .20311 .5222 .20442 .52402 .20378 .52303 .2026 Mtetra
.549 .705 .943 r
.52303 .2026 .52402 .20378 .52583 .20354 .52485 .20236 Mtetra
.663 .75 .915 r
.52485 .20236 .52583 .20354 .52766 .20301 .52667 .20169 Mtetra
.69 .736 .886 r
.52667 .20169 .52766 .20301 .52948 .20229 .52849 .20089 Mtetra
.633 .698 .892 r
.52849 .20089 .52948 .20229 .5313 .20166 .53032 .20035 Mtetra
.336 .567 .924 r
.53032 .20035 .5313 .20166 .53313 .20102 .53214 .20072 Mtetra
.647 .091 0 r
.53214 .20072 .53313 .20102 .53495 .20063 .53398 .2024 Mtetra
.841 .459 .326 r
.53398 .2024 .53495 .20063 .53678 .20089 .53583 .20768 Mtetra
.966 .67 .417 r
.53583 .20768 .53678 .20089 .53863 .20463 .53853 .41158 Mtetra
.528 .294 .503 r
.53853 .41158 .53863 .20463 .54154 .41279 .54051 .41629 Mtetra
.631 .264 .329 r
.54051 .41629 .54154 .41279 .54354 .41836 .54249 .41809 Mtetra
0 .541 .778 r
.54249 .41809 .54354 .41836 .54551 .41931 .54446 .41836 Mtetra
.633 .805 .965 r
.54446 .41836 .54551 .41931 .54748 .41876 .54643 .41774 Mtetra
.759 .826 .904 r
.54643 .41774 .54748 .41876 .54945 .41765 .5484 .41652 Mtetra
.841 .817 .826 r
.5484 .41652 .54945 .41765 .55142 .41672 .55036 .41455 Mtetra
.839 .701 .71 r
.55036 .41455 .55142 .41672 .55339 .41577 .55231 .41142 Mtetra
.832 .618 .612 r
.55231 .41142 .55339 .41577 .55535 .41413 .55424 .40525 Mtetra
.968 .678 .424 r
.55424 .40525 .55535 .41413 .55728 .40921 .55422 .19971 Mtetra
.533 .303 .511 r
.55422 .19971 .55728 .40921 .55703 .19973 .55601 .19346 Mtetra
.686 .491 .616 r
.55601 .19346 .55703 .19973 .55881 .19262 .55783 .19048 Mtetra
.728 .649 .77 r
.55783 .19048 .55881 .19262 .56063 .19043 .55966 .18908 Mtetra
.633 .712 .904 r
.55966 .18908 .56063 .19043 .56248 .18972 .56151 .18854 Mtetra
.547 .707 .945 r
.56151 .18854 .56248 .18972 .56433 .18946 .56336 .1883 Mtetra
.64 .749 .928 r
.56336 .1883 .56433 .18946 .56617 .189 .56521 .18772 Mtetra
.694 .748 .893 r
.56521 .18772 .56617 .189 .56802 .18828 .56705 .18689 Mtetra
.643 .71 .896 r
.56705 .18689 .56802 .18828 .56987 .18762 .5689 .18631 Mtetra
.404 .607 .931 r
.5689 .18631 .56987 .18762 .57172 .18695 .57077 .18651 Mtetra
.545 0 0 r
.57077 .18651 .57172 .18695 .57358 .18646 .57265 .18799 Mtetra
.824 .42 .283 r
.57265 .18799 .57358 .18646 .57544 .18656 .57459 .19231 Mtetra
.969 .669 .4 r
.57459 .19231 .57544 .18656 .57736 .18934 .57996 .39649 Mtetra
.529 .295 .503 r
.57996 .39649 .57736 .18934 .58297 .39701 .58206 .40205 Mtetra
.617 .278 .374 r
.58206 .40205 .58297 .39701 .58511 .40408 .5841 .40404 Mtetra
.122 0 0 r
.5841 .40404 .58511 .40408 .58714 .40536 .58611 .40427 Mtetra
.685 .799 .936 r
.58611 .40427 .58714 .40536 .58914 .40475 .58811 .40345 Mtetra
.745 .776 .878 r
.58811 .40345 .58914 .40475 .59113 .4036 .5901 .40224 Mtetra
.695 .752 .896 r
.5901 .40224 .59113 .4036 .59312 .40279 .59209 .40134 Mtetra
.622 .708 .907 r
.59209 .40134 .59312 .40279 .59513 .40237 .5941 .40081 Mtetra
.679 .714 .875 r
.5941 .40081 .59513 .40237 .59713 .4014 .5961 .39997 Mtetra
.832 .776 .799 r
.5961 .39997 .59713 .4014 .59907 .39825 .59807 .39786 Mtetra
.978 .86 .655 r
.59807 .39786 .59907 .39825 .60071 .38219 .59998 .39322 Mtetra
.742 .634 .072 r
.59998 .39322 .60071 .38219 .59782 .18024 .60144 .36953 Mtetra
0 0 .341 r
.60144 .36953 .59782 .18024 .59963 .17714 .59886 .18339 Mtetra
.432 .14 .367 r
.59886 .18339 .59963 .17714 .6015 .17628 .60073 .18244 Mtetra
.533 .224 .388 r
.60073 .18244 .6015 .17628 .60338 .17599 .60264 .18304 Mtetra
.544 .241 .405 r
.60264 .18304 .60338 .17599 .60526 .17568 .60456 .18387 Mtetra
.493 .208 .409 r
.60456 .18387 .60526 .17568 .60714 .17507 .60646 .18367 Mtetra
.493 .21 .413 r
.60646 .18367 .60714 .17507 .60902 .17446 .60835 .18343 Mtetra
.489 .21 .416 r
.60835 .18343 .60902 .17446 .6109 .17382 .61025 .18308 Mtetra
.483 .207 .418 r
.61025 .18308 .6109 .17382 .61278 .17316 .61214 .18258 Mtetra
.477 .203 .418 r
.61214 .18258 .61278 .17316 .61466 .17248 .61403 .18194 Mtetra
.47 .197 .417 r
.61403 .18194 .61466 .17248 .61654 .17177 .61591 .18111 Mtetra
.462 .19 .414 r
.61591 .18111 .61654 .17177 .61842 .17104 .61779 .18014 Mtetra
.457 .185 .411 r
.61779 .18014 .61842 .17104 .6203 .17029 .61967 .1791 Mtetra
.405 .142 .398 r
.61967 .1791 .6203 .17029 .62217 .16931 .62152 .17712 Mtetra
.373 .109 .379 r
.62152 .17712 .62217 .16931 .62404 .16819 .62336 .1749 Mtetra
.465 .173 .383 r
.62336 .1749 .62404 .16819 .62593 .16759 .62526 .17435 Mtetra
.832 .499 .425 r
.62526 .17435 .62593 .16759 .62789 .16882 .62761 .18687 Mtetra
.957 .649 .404 r
.62761 .18687 .62789 .16882 .63035 .18433 .63629 .38108 Mtetra
.526 .292 .503 r
.63629 .38108 .63035 .18433 .63943 .38463 .63847 .3846 Mtetra
.477 0 0 r
.63847 .3846 .63943 .38463 .64157 .38703 .64057 .38568 Mtetra
.582 .712 .932 r
.64057 .38568 .64157 .38703 .64362 .38676 .64261 .38529 Mtetra
.663 .726 .896 r
.64261 .38529 .64362 .38676 .64566 .38591 .64465 .38455 Mtetra
.62 .726 .922 r
.64465 .38455 .64566 .38591 .6477 .38524 .6467 .384 Mtetra
.493 .692 .957 r
.6467 .384 .6477 .38524 .64976 .38512 .64876 .38389 Mtetra
.647 .763 .934 r
.64876 .38389 .64976 .38512 .6518 .38444 .6508 .38322 Mtetra
.873 .817 .791 r
.6508 .38322 .6518 .38444 .65377 .382 .65278 .38079 Mtetra
.978 .753 .529 r
.65278 .38079 .65377 .382 .65544 .37194 .65445 .37079 Mtetra
.977 .68 .37 r
.65445 .37079 .65544 .37194 .64878 .1618 .64785 .16054 Mtetra
.931 .789 .682 r
.64785 .16054 .64878 .1618 .65055 .1579 .64962 .15662 Mtetra
.715 .762 .89 r
.64962 .15662 .65055 .1579 .65244 .15693 .65151 .15566 Mtetra
.578 .707 .931 r
.65151 .15566 .65244 .15693 .65436 .15658 .65344 .15531 Mtetra
.551 .695 .935 r
.65344 .15531 .65436 .15658 .65629 .15632 .65536 .15506 Mtetra
.664 .747 .912 r
.65536 .15506 .65629 .15632 .6582 .15562 .65727 .15436 Mtetra
.67 .75 .911 r
.65727 .15436 .6582 .15562 .66011 .15489 .65918 .15363 Mtetra
.712 .767 .895 r
.65918 .15363 .66011 .15489 .66201 .15394 .66108 .15269 Mtetra
.761 .782 .87 r
.66108 .15269 .66201 .15394 .66389 .15271 .66297 .15144 Mtetra
.672 .749 .909 r
.66297 .15144 .66389 .15271 .6658 .15197 .66488 .1507 Mtetra
.168 .473 .893 r
.66488 .1507 .6658 .15197 .66779 .15268 .66687 .15147 Mtetra
.92 .545 .128 r
.66687 .15147 .66779 .15268 .67014 .16088 .66928 .16094 Mtetra
.974 .667 .344 r
.66928 .16094 .67014 .16088 .68244 .37057 .68148 .36982 Mtetra
.687 .182 0 r
.68148 .36982 .68244 .37057 .6847 .37366 .68373 .37272 Mtetra
.566 .791 .984 r
.68373 .37272 .6847 .37366 .68678 .37335 .68581 .37227 Mtetra
.738 .827 .92 r
.68581 .37227 .68678 .37335 .68884 .37234 .68786 .37115 Mtetra
.722 .8 .912 r
.68786 .37115 .68884 .37234 .69089 .37135 .68991 .3701 Mtetra
.456 .671 .955 r
.68991 .3701 .69089 .37135 .69299 .37125 .69202 .3701 Mtetra
.599 .762 .957 r
.69202 .3701 .69299 .37125 .69507 .37065 .69411 .3696 Mtetra
.849 .851 .844 r
.69411 .3696 .69507 .37065 .69708 .36864 .69612 .36765 Mtetra
.985 .773 .536 r
.69612 .36765 .69708 .36864 .69874 .36027 .69776 .359 Mtetra
.977 .676 .35 r
.69776 .359 .69874 .36027 .68909 .14757 .68815 .14582 Mtetra
.92 .748 .652 r
.68815 .14582 .68909 .14757 .6908 .14299 .68987 .14133 Mtetra
.695 .697 .848 r
.68987 .14133 .6908 .14299 .69272 .14195 .69179 .14038 Mtetra
.562 .649 .893 r
.69179 .14038 .69272 .14195 .69467 .14159 .69375 .14013 Mtetra
.497 .634 .914 r
.69375 .14013 .69467 .14159 .69664 .14145 .69573 .14011 Mtetra
.645 .728 .909 r
.69573 .14011 .69664 .14145 .69857 .14077 .69767 .13948 Mtetra
.659 .743 .912 r
.69767 .13948 .69857 .14077 .70051 .14006 .69961 .1388 Mtetra
.682 .757 .908 r
.69961 .1388 .70051 .14006 .70244 .13923 .70154 .138 Mtetra
.73 .781 .894 r
.70154 .138 .70244 .13923 .70435 .13805 .70346 .13695 Mtetra
.689 .794 .93 r
.70346 .13695 .70435 .13805 .70629 .13724 .7054 .13613 Mtetra
.548 .73 .96 r
.7054 .13613 .70629 .13724 .70828 .13737 .70737 .13584 Mtetra
.092 .37 .835 r
.70737 .13584 .70828 .13737 .71052 .14136 .70943 .13702 Mtetra
.115 .152 .623 r
.70943 .13702 .71052 .14136 .72581 .35134 .71163 .14034 Mtetra
0 0 .396 r
.71163 .14034 .72581 .35134 .72831 .35713 .7266 .34407 Mtetra
.212 .121 .529 r
.7266 .34407 .72831 .35713 .73049 .35766 .72926 .3521 Mtetra
.322 .268 .64 r
.72926 .3521 .73049 .35766 .73262 .35736 .73156 .3545 Mtetra
.387 .421 .775 r
.73156 .3545 .73262 .35736 .73472 .35669 .73376 .35537 Mtetra
.583 .725 .941 r
.73376 .35537 .73472 .35669 .73683 .35608 .73589 .35496 Mtetra
.66 .797 .948 r
.73589 .35496 .73683 .35608 .73894 .35538 .73799 .3542 Mtetra
.67 .789 .938 r
.73799 .3542 .73894 .35538 .74105 .35472 .74009 .35339 Mtetra
.506 .684 .947 r
.74009 .35339 .74105 .35472 .7432 .35462 .74224 .35326 Mtetra
.572 .712 .937 r
.74224 .35326 .7432 .35462 .74533 .35413 .74438 .35289 Mtetra
.686 .784 .925 r
.74438 .35289 .74533 .35413 .74739 .35279 .74648 .35201 Mtetra
.898 .905 .821 r
.74648 .35201 .74739 .35279 .74921 .34784 .74848 .34965 Mtetra
0 0 0 r
.74848 .34965 .74921 .34784 .73641 .13849 .75037 .34579 Mtetra
.502 .274 .501 r
.75037 .34579 .73641 .13849 .73771 .12848 .75185 .33633 Mtetra
0 0 .39 r
.75185 .33633 .73771 .12848 .73958 .12638 .73908 .1304 Mtetra
0 0 .145 r
.73908 .1304 .73958 .12638 .74151 .12517 .74076 .12568 Mtetra
.777 .946 .61 r
.74076 .12568 .74151 .12517 .74347 .12439 .74259 .12316 Mtetra
.721 .783 .901 r
.74259 .12316 .74347 .12439 .74544 .12365 .74454 .12216 Mtetra
.636 .701 .893 r
.74454 .12216 .74544 .12365 .74741 .12303 .74652 .12156 Mtetra
.596 .686 .905 r
.74652 .12156 .74741 .12303 .7494 .12245 .74851 .12115 Mtetra
.668 .749 .911 r
.74851 .12115 .7494 .12245 .75137 .12171 .75049 .12041 Mtetra
.674 .751 .909 r
.75049 .12041 .75137 .12171 .75334 .12094 .75246 .11963 Mtetra
.68 .754 .907 r
.75246 .11963 .75334 .12094 .7553 .12013 .75443 .11883 Mtetra
.684 .755 .905 r
.75443 .11883 .7553 .12013 .75727 .11931 .7564 .118 Mtetra
.691 .757 .902 r
.7564 .118 .75727 .11931 .75924 .11847 .75836 .11714 Mtetra
.698 .758 .898 r
.75836 .11714 .75924 .11847 .76121 .1176 .76033 .11624 Mtetra
.763 .756 .847 r
.12666 .34694 .1278 .34801 .12943 .34692 .1283 .34578 Mtetra
.712 .739 .872 r
.1283 .34578 .12943 .34692 .13103 .34603 .1299 .34495 Mtetra
.565 .709 .938 r
.1299 .34495 .13103 .34603 .1326 .34553 .13143 .34471 Mtetra
.868 .422 .1 r
.13143 .34471 .1326 .34553 .134 .34628 .13261 .34727 Mtetra
.935 .679 .526 r
.13261 .34727 .134 .34628 .13526 .3483 .11052 .53862 Mtetra
.554 .317 .511 r
.11052 .53862 .13526 .3483 .13594 .355 .11015 .55466 Mtetra
.522 .289 .503 r
.11015 .55466 .13594 .355 .11351 .5513 .11158 .55603 Mtetra
.514 .191 .358 r
.11158 .55603 .11351 .5513 .11464 .55523 .11316 .55629 Mtetra
.242 0 0 r
.11316 .55629 .11464 .55523 .11605 .55682 .1148 .55605 Mtetra
.305 .68 .976 r
.1148 .55605 .11605 .55682 .11762 .55717 .11639 .55616 Mtetra
.583 .744 .953 r
.11639 .55616 .11762 .55717 .11927 .55686 .11804 .55582 Mtetra
.742 .773 .878 r
.11804 .55582 .11927 .55686 .12099 .55596 .11978 .55478 Mtetra
.883 .741 .699 r
.11978 .55478 .12099 .55596 .12285 .55388 .12187 .55082 Mtetra
.936 .684 .532 r
.12187 .55082 .12285 .55388 .12489 .55032 .14552 .36562 Mtetra
.58 .345 .523 r
.14552 .36562 .12489 .55032 .12759 .54106 .14997 .34091 Mtetra
.526 .297 .511 r
.14997 .34091 .12759 .54106 .15233 .34443 .15177 .33853 Mtetra
.618 .446 .628 r
.15177 .33853 .15233 .34443 .15437 .34005 .15343 .33728 Mtetra
.643 .546 .73 r
.15343 .33728 .15437 .34005 .15616 .33767 .15504 .33649 Mtetra
.68 .725 .884 r
.15504 .33649 .15616 .33767 .15779 .33669 .15664 .33582 Mtetra
.651 .78 .942 r
.15664 .33582 .15779 .33669 .15937 .33618 .15822 .33528 Mtetra
.631 .771 .947 r
.15822 .33528 .15937 .33618 .16093 .33587 .1598 .33481 Mtetra
.735 .759 .872 r
.1598 .33481 .16093 .33587 .16254 .33509 .16143 .33386 Mtetra
.696 .722 .87 r
.16143 .33386 .16254 .33509 .16414 .33438 .16304 .3331 Mtetra
.567 .671 .909 r
.16304 .3331 .16414 .33438 .16571 .33399 .16459 .33288 Mtetra
.818 .351 0 r
.16459 .33288 .16571 .33399 .16716 .33465 .16585 .3352 Mtetra
.939 .681 .518 r
.16585 .3352 .16716 .33465 .16847 .33659 .14614 .52282 Mtetra
.563 .324 .512 r
.14614 .52282 .16847 .33659 .16929 .34296 .1455 .5428 Mtetra
.523 .29 .503 r
.1455 .5428 .16929 .34296 .14883 .53954 .14695 .54443 Mtetra
.513 .192 .36 r
.14695 .54443 .14883 .53954 .15001 .54356 .14856 .54468 Mtetra
.24 0 0 r
.14856 .54468 .15001 .54356 .15147 .54517 .15023 .5444 Mtetra
.59 .8 .98 r
.15023 .5444 .15147 .54517 .15311 .5452 .15191 .54398 Mtetra
.644 .726 .908 r
.15191 .54398 .15311 .5452 .1548 .54465 .15361 .54344 Mtetra
.657 .731 .903 r
.15361 .54344 .1548 .54465 .15653 .54389 .15532 .54284 Mtetra
.433 .678 .967 r
.15532 .54284 .15653 .54389 .15816 .54394 .15696 .54286 Mtetra
.526 .712 .957 r
.15696 .54286 .15816 .54394 .15982 .54383 .15862 .54268 Mtetra
.711 .755 .887 r
.15862 .54268 .15982 .54383 .16155 .54302 .16036 .54181 Mtetra
.891 .741 .689 r
.16036 .54181 .16155 .54302 .16365 .53882 .16246 .53754 Mtetra
.942 .688 .523 r
.16246 .53754 .16365 .53882 .18702 .33569 .18595 .33416 Mtetra
.914 .705 .607 r
.18595 .33416 .18702 .33569 .18959 .3261 .18847 .32503 Mtetra
.829 .764 .79 r
.18847 .32503 .18959 .3261 .19134 .32417 .19022 .32312 Mtetra
.673 .75 .908 r
.19022 .32312 .19134 .32417 .19295 .32355 .19183 .32249 Mtetra
.539 .705 .947 r
.19183 .32249 .19295 .32355 .19451 .32339 .1934 .3223 Mtetra
.721 .755 .879 r
.1934 .3223 .19451 .32339 .19615 .32252 .19504 .32142 Mtetra
.715 .752 .881 r
.19504 .32142 .19615 .32252 .19779 .32168 .19667 .32058 Mtetra
.558 .705 .939 r
.19667 .32058 .19779 .32168 .19936 .32146 .19825 .32035 Mtetra
.867 .425 .039 r
.19825 .32035 .19936 .32146 .20062 .32431 .19951 .32319 Mtetra
.945 .684 .51 r
.19951 .32319 .20062 .32431 .18138 .52705 .18019 .52594 Mtetra
.946 .613 .363 r
.18019 .52594 .18138 .52705 .18226 .53468 .18106 .53363 Mtetra
.478 0 0 r
.18106 .53363 .18226 .53468 .18378 .53603 .18258 .53499 Mtetra
.554 .732 .958 r
.18258 .53499 .18378 .53603 .18547 .53576 .18427 .53472 Mtetra
.779 .783 .856 r
.18427 .53472 .18547 .53576 .18727 .53444 .18607 .5334 Mtetra
.9 .757 .694 r
.18607 .5334 .18727 .53444 .18936 .53025 .18816 .52921 Mtetra
.945 .688 .517 r
.18816 .52921 .18936 .53025 .21123 .32733 .21012 .32623 Mtetra
.929 .719 .598 r
.21012 .32623 .21123 .32733 .21378 .31746 .21267 .31636 Mtetra
.841 .762 .775 r
.21267 .31636 .21378 .31746 .21555 .31533 .21444 .31423 Mtetra
.678 .745 .901 r
.21444 .31423 .21555 .31533 .21718 .31467 .21607 .31357 Mtetra
.545 .701 .942 r
.21607 .31357 .21718 .31467 .21876 .31447 .21765 .31337 Mtetra
.702 .75 .889 r
.21765 .31337 .21876 .31447 .2204 .31369 .2193 .31259 Mtetra
.718 .753 .88 r
.2193 .31259 .2204 .31369 .22206 .31283 .22095 .31172 Mtetra
.576 .712 .935 r
.22095 .31172 .22206 .31283 .22365 .31255 .22255 .31143 Mtetra
.811 .344 0 r
.22255 .31143 .22365 .31255 .22499 .315 .22388 .31387 Mtetra
.948 .684 .504 r
.22388 .31387 .22499 .315 .20736 .51699 .20617 .51584 Mtetra
.95 .624 .376 r
.20617 .51584 .20736 .51699 .20819 .52592 .20699 .52486 Mtetra
.577 .058 0 r
.20699 .52486 .20819 .52592 .20972 .52753 .20853 .52646 Mtetra
.526 .719 .961 r
.20853 .52646 .20972 .52753 .21142 .52734 .21023 .52627 Mtetra
.767 .782 .865 r
.21023 .52627 .21142 .52734 .21322 .5261 .21203 .52503 Mtetra
.895 .761 .707 r
.21203 .52503 .21322 .5261 .21526 .52233 .21407 .52123 Mtetra
.948 .689 .512 r
.21407 .52123 .21526 .52233 .23532 .32273 .23427 .32098 Mtetra
.925 .699 .577 r
.23427 .32098 .23532 .32273 .23817 .30896 .23707 .30779 Mtetra
.851 .755 .756 r
.23707 .30779 .23817 .30896 .23997 .30654 .23888 .30538 Mtetra
.676 .735 .895 r
.23888 .30538 .23997 .30654 .24162 .30589 .24052 .30472 Mtetra
.532 .683 .935 r
.24052 .30472 .24162 .30589 .24321 .30576 .24212 .30457 Mtetra
.584 .699 .921 r
.24212 .30457 .24321 .30576 .24482 .3055 .24373 .30427 Mtetra
.651 .716 .896 r
.24373 .30427 .24482 .3055 .24646 .30497 .24537 .30371 Mtetra
.66 .713 .887 r
.24537 .30371 .24646 .30497 .2481 .30439 .24701 .30312 Mtetra
.681 .717 .876 r
.24701 .30312 .2481 .30439 .24975 .30365 .24867 .30241 Mtetra
.696 .728 .875 r
.24867 .30241 .24975 .30365 .25142 .30279 .25033 .30163 Mtetra
.7 .743 .885 r
.25033 .30163 .25142 .30279 .25309 .30193 .25199 .30085 Mtetra
.735 .764 .876 r
.25199 .30085 .25309 .30193 .25476 .301 .25367 .29988 Mtetra
.725 .755 .877 r
.25367 .29988 .25476 .301 .25643 .30015 .25534 .29896 Mtetra
.625 .716 .912 r
.25534 .29896 .25643 .30015 .25807 .29961 .25697 .29851 Mtetra
0 .143 .642 r
.25697 .29851 .25807 .29961 .25964 .29989 .25847 .29971 Mtetra
.918 .564 .35 r
.25847 .29971 .25964 .29989 .26111 .30146 .25956 .30576 Mtetra
.945 .677 .499 r
.25956 .30576 .26111 .30146 .26233 .30596 .24405 .50879 Mtetra
.526 .292 .504 r
.24405 .50879 .26233 .30596 .24725 .50602 .24548 .51212 Mtetra
.539 .231 .394 r
.24548 .51212 .24725 .50602 .24852 .51134 .24714 .51274 Mtetra
.374 0 .01 r
.24714 .51274 .24852 .51134 .25007 .51334 .24886 .51269 Mtetra
.535 .816 .998 r
.24886 .51269 .25007 .51334 .25175 .51378 .25061 .51233 Mtetra
.633 .69 .885 r
.25061 .51233 .25175 .51378 .25351 .51331 .25237 .51181 Mtetra
.657 .69 .869 r
.25237 .51181 .25351 .51331 .25529 .51254 .25414 .51117 Mtetra
.607 .693 .904 r
.25414 .51117 .25529 .51254 .25706 .51194 .2559 .51076 Mtetra
.569 .713 .94 r
.2559 .51076 .25706 .51194 .25882 .51154 .25765 .51047 Mtetra
.686 .771 .916 r
.25765 .51047 .25882 .51154 .2606 .51085 .25943 .50971 Mtetra
.851 .774 .776 r
.25943 .50971 .2606 .51085 .26244 .50936 .26135 .50736 Mtetra
.896 .701 .632 r
.26135 .50736 .26244 .50936 .26439 .50653 .2636 .50071 Mtetra
.947 .684 .503 r
.2636 .50071 .26439 .50653 .26653 .50121 .28133 .29571 Mtetra
.531 .302 .512 r
.28133 .29571 .26653 .50121 .2838 .29999 .28333 .29083 Mtetra
.606 .411 .591 r
.28333 .29083 .2838 .29999 .28599 .29262 .28509 .28905 Mtetra
.65 .519 .69 r
.28509 .28905 .28599 .29262 .28785 .28949 .2868 .28793 Mtetra
.686 .678 .837 r
.2868 .28793 .28785 .28949 .28959 .28785 .28848 .28713 Mtetra
.665 .829 .962 r
.28848 .28713 .28959 .28785 .29127 .28712 .29015 .28649 Mtetra
.611 .837 .986 r
.29015 .28649 .29127 .28712 .29292 .28671 .29181 .28599 Mtetra
.61 .815 .979 r
.29181 .28599 .29292 .28671 .29457 .28638 .29347 .28552 Mtetra
.634 .789 .957 r
.29347 .28552 .29457 .28638 .29623 .28597 .29514 .285 Mtetra
.644 .769 .939 r
.29514 .285 .29623 .28597 .29789 .28554 .29681 .28446 Mtetra
.668 .754 .915 r
.29681 .28446 .29789 .28554 .29956 .28495 .29848 .28383 Mtetra
.691 .75 .897 r
.29848 .28383 .29956 .28495 .30125 .28418 .30017 .28309 Mtetra
.694 .758 .901 r
.30017 .28309 .30125 .28418 .30294 .28338 .30186 .28233 Mtetra
.72 .774 .895 r
.30186 .28233 .30294 .28338 .30463 .28253 .30355 .28145 Mtetra
.728 .77 .886 r
.30355 .28145 .30463 .28253 .30633 .28169 .30525 .28052 Mtetra
.641 .727 .911 r
.30525 .28052 .30633 .28169 .308 .28113 .30693 .28 Mtetra
.003 .396 .849 r
.30693 .28 .308 .28113 .30963 .28133 .30851 .28078 Mtetra
.917 .53 .256 r
.30851 .28078 .30963 .28133 .31115 .28302 .30982 .28559 Mtetra
.952 .68 .485 r
.30982 .28559 .31115 .28302 .31253 .28685 .29743 .48991 Mtetra
.527 .293 .504 r
.29743 .48991 .31253 .28685 .31356 .29601 .29892 .49382 Mtetra
.518 .286 .502 r
.29892 .49382 .31356 .29601 .31536 .29376 .3007 .49354 Mtetra
.517 .285 .502 r
.3007 .49354 .31536 .29376 .31716 .2915 .30252 .4926 Mtetra
.518 .286 .502 r
.30252 .4926 .31716 .2915 .30624 .48154 .30432 .49208 Mtetra
.528 .25 .437 r
.30432 .49208 .30624 .48154 .30741 .49044 .30605 .49259 Mtetra
.506 .098 .2 r
.30605 .49259 .30741 .49044 .30898 .49339 .30779 .49296 Mtetra
.234 .711 .936 r
.30779 .49296 .30898 .49339 .31068 .49439 .30955 .49296 Mtetra
.623 .693 .894 r
.30955 .49296 .31068 .49439 .31248 .49401 .31135 .49248 Mtetra
.651 .687 .871 r
.31135 .49248 .31248 .49401 .31429 .49328 .31316 .49185 Mtetra
.628 .695 .893 r
.31316 .49185 .31429 .49328 .31611 .49257 .31497 .49134 Mtetra
.553 .701 .938 r
.31497 .49134 .31611 .49257 .31791 .49219 .31676 .4911 Mtetra
.663 .767 .927 r
.31676 .4911 .31791 .49219 .31972 .49155 .31857 .49043 Mtetra
.83 .788 .812 r
.31857 .49043 .31972 .49155 .32158 .49016 .32047 .48851 Mtetra
.908 .723 .641 r
.32047 .48851 .32158 .49016 .32354 .48711 .32261 .48255 Mtetra
.955 .686 .488 r
.32261 .48255 .32354 .48711 .32563 .482 .33688 .27661 Mtetra
.533 .303 .512 r
.33688 .27661 .32563 .482 .32798 .47239 .33888 .27101 Mtetra
.522 .294 .51 r
.33888 .27101 .32798 .47239 .32974 .47256 .34061 .27005 Mtetra
.521 .293 .51 r
.34061 .27005 .32974 .47256 .33146 .47356 .34229 .26974 Mtetra
.34229 .26974 .33146 .47356 .34415 .28584 .34399 .26921 Mtetra
.566 .356 .555 r
.34399 .26921 .34415 .28584 .34663 .272 .34575 .26761 Mtetra
.655 .5 .661 r
.34575 .26761 .34663 .272 .34853 .26798 .34751 .26614 Mtetra
.715 .661 .794 r
.34751 .26614 .34853 .26798 .35032 .26584 .34925 .26501 Mtetra
.651 .806 .958 r
.34925 .26501 .35032 .26584 .35203 .26517 .35095 .26442 Mtetra
.599 .809 .98 r
.35095 .26442 .35203 .26517 .35372 .26487 .35265 .26397 Mtetra
.609 .778 .961 r
.35265 .26397 .35372 .26487 .35541 .26464 .35435 .26352 Mtetra
.66 .747 .915 r
.35435 .26352 .35541 .26464 .35712 .26409 .35606 .26291 Mtetra
.667 .739 .904 r
.35606 .26291 .35712 .26409 .35883 .26347 .35778 .26226 Mtetra
.694 .741 .888 r
.35778 .26226 .35883 .26347 .36055 .26272 .3595 .26148 Mtetra
.742 .749 .858 r
.3595 .26148 .36055 .26272 .36229 .26169 .36124 .2604 Mtetra
.677 .723 .884 r
.36124 .2604 .36229 .26169 .36401 .26089 .36296 .2597 Mtetra
.344 .593 .938 r
.36296 .2597 .36401 .26089 .3657 .26071 .36463 .25998 Mtetra
.899 .482 .153 r
.36463 .25998 .3657 .26071 .36731 .26222 .3661 .26407 Mtetra
.958 .681 .468 r
.3661 .26407 .36731 .26222 .36882 .26578 .35736 .46911 Mtetra
.529 .295 .504 r
.35736 .46911 .36882 .26578 .36124 .4512 .3589 .4744 Mtetra
.512 .261 .471 r
.3589 .4744 .36124 .4512 .36333 .44522 .36071 .47427 Mtetra
.503 .257 .476 r
.36071 .47427 .36333 .44522 .37339 .27618 .36256 .47344 Mtetra
.517 .285 .502 r
.36256 .47344 .37339 .27618 .36615 .4613 .36441 .47272 Mtetra
.529 .254 .441 r
.36441 .47272 .36615 .4613 .36749 .471 .3662 .4733 Mtetra
.515 .112 .215 r
.3662 .4733 .36749 .471 .36916 .4741 .36799 .47373 Mtetra
.098 .628 .87 r
.36799 .47373 .36916 .4741 .37091 .47539 .3698 .47387 Mtetra
.56 .657 .901 r
.3698 .47387 .37091 .47539 .37275 .47512 .37164 .47364 Mtetra
.671 .706 .874 r
.37164 .47364 .37275 .47512 .37461 .47425 .37349 .4729 Mtetra
.795 .757 .818 r
.37349 .4729 .37461 .47425 .3765 .47272 .37539 .47124 Mtetra
.91 .741 .66 r
.37539 .47124 .3765 .47272 .37845 .46986 .37744 .46615 Mtetra
.96 .687 .472 r
.37744 .46615 .37845 .46986 .38048 .46528 .38837 .26064 Mtetra
.538 .307 .513 r
.38837 .26064 .38048 .46528 .38271 .45576 .39044 .25234 Mtetra
.523 .295 .51 r
.39044 .25234 .38271 .45576 .38459 .45455 .3922 .25114 Mtetra
.521 .293 .51 r
.3922 .25114 .38459 .45455 .38638 .45533 .39393 .2507 Mtetra
.39393 .2507 .38638 .45533 .38846 .4491 .39566 .25036 Mtetra
.524 .296 .51 r
.39566 .25036 .38846 .4491 .39832 .25382 .39744 .24873 Mtetra
.643 .478 .645 r
.39744 .24873 .39832 .25382 .40022 .24934 .39921 .2472 Mtetra
.717 .636 .767 r
.39921 .2472 .40022 .24934 .40203 .24678 .40098 .24591 Mtetra
.688 .812 .941 r
.40098 .24591 .40203 .24678 .40378 .24585 .40273 .24517 Mtetra
.636 .842 .979 r
.40273 .24517 .40378 .24585 .40552 .24529 .40447 .24458 Mtetra
.615 .829 .982 r
.40447 .24458 .40552 .24529 .40726 .2449 .40621 .24405 Mtetra
.657 .809 .956 r
.40621 .24405 .40726 .2449 .409 .24427 .40795 .24342 Mtetra
.653 .809 .958 r
.40795 .24342 .409 .24427 .41074 .24367 .4097 .24281 Mtetra
.648 .804 .958 r
.4097 .24281 .41074 .24367 .41249 .24311 .41144 .24221 Mtetra
.631 .791 .959 r
.41144 .24221 .41249 .24311 .41423 .24266 .41319 .24168 Mtetra
.633 .774 .948 r
.41319 .24168 .41423 .24266 .41597 .24222 .41493 .24115 Mtetra
.64 .756 .933 r
.41493 .24115 .41597 .24222 .41771 .24177 .41668 .2406 Mtetra
.658 .744 .913 r
.41668 .2406 .41771 .24177 .41946 .2412 .41843 .23999 Mtetra
.666 .738 .903 r
.41843 .23999 .41946 .2412 .42122 .24056 .42019 .23933 Mtetra
.675 .737 .898 r
.42019 .23933 .42122 .24056 .42297 .23985 .42194 .23863 Mtetra
.688 .743 .893 r
.42194 .23863 .42297 .23985 .42473 .23903 .4237 .23787 Mtetra
.692 .756 .9 r
.4237 .23787 .42473 .23903 .42649 .23818 .42546 .23709 Mtetra
.692 .768 .91 r
.42546 .23709 .42649 .23818 .42826 .23736 .42722 .23632 Mtetra
.681 .776 .923 r
.42722 .23632 .42826 .23736 .43002 .23665 .42899 .2356 Mtetra
.675 .774 .925 r
.42899 .2356 .43002 .23665 .43178 .23597 .43075 .23491 Mtetra
.67 .77 .925 r
.43075 .23491 .43178 .23597 .43354 .23532 .43251 .23424 Mtetra
.739 .785 .89 r
.43251 .23424 .43354 .23532 .43531 .23443 .43428 .23322 Mtetra
.681 .744 .898 r
.43428 .23322 .43531 .23443 .43707 .23373 .43605 .23249 Mtetra
.532 .681 .934 r
.43605 .23249 .43707 .23373 .43882 .23337 .4378 .23233 Mtetra
.772 .3 0 r
.4378 .23233 .43882 .23337 .44054 .23453 .43947 .23515 Mtetra
.966 .681 .442 r
.43947 .23515 .44054 .23453 .44222 .23723 .4357 .43681 Mtetra
.541 .304 .505 r
.4357 .43681 .44222 .23723 .44373 .24609 .43727 .44802 Mtetra
.52 .287 .502 r
.43727 .44802 .44373 .24609 .44541 .24942 .43913 .44839 Mtetra
.517 .285 .502 r
.43913 .44839 .44541 .24942 .44727 .24557 .44103 .44766 Mtetra
.44103 .44766 .44727 .24557 .44899 .24719 .44294 .4466 Mtetra
.52 .287 .502 r
.44294 .4466 .44899 .24719 .44603 .44292 .44481 .44697 Mtetra
.52 .175 .323 r
.44481 .44697 .44603 .44292 .44782 .44701 .44669 .44738 Mtetra
.268 0 0 r
.44669 .44738 .44782 .44701 .44966 .44882 .44857 .44756 Mtetra
.482 .671 .948 r
.44857 .44756 .44966 .44882 .45155 .44894 .45046 .44752 Mtetra
.622 .703 .903 r
.45046 .44752 .45155 .44894 .45345 .44837 .45236 .44701 Mtetra
.744 .755 .861 r
.45236 .44701 .45345 .44837 .45537 .4472 .45428 .44581 Mtetra
.908 .762 .688 r
.45428 .44581 .45537 .4472 .45731 .44466 .45626 .44167 Mtetra
.954 .69 .496 r
.45626 .44167 .45731 .44466 .45929 .44055 .45879 .41078 Mtetra
.935 .651 .478 r
.45879 .41078 .45929 .44055 .46135 .43198 .46434 .22586 Mtetra
.524 .296 .51 r
.46434 .22586 .46135 .43198 .46332 .42787 .46614 .22406 Mtetra
.521 .293 .51 r
.46614 .22406 .46332 .42787 .46518 .42918 .46793 .22351 Mtetra
.52 .293 .51 r
.46793 .22351 .46518 .42918 .4671 .42798 .46971 .22331 Mtetra
.523 .295 .51 r
.46971 .22331 .4671 .42798 .47243 .22838 .47151 .22187 Mtetra
.622 .444 .62 r
.47151 .22187 .47243 .22838 .4743 .22297 .47331 .22029 Mtetra
.699 .593 .733 r
.47331 .22029 .4743 .22297 .47612 .22004 .47511 .21892 Mtetra
.69 .768 .911 r
.47511 .21892 .47612 .22004 .47792 .21896 .4769 .21815 Mtetra
.62 .812 .974 r
.4769 .21815 .47792 .21896 .4797 .2185 .47869 .21761 Mtetra
.599 .787 .971 r
.47869 .21761 .4797 .2185 .48149 .21828 .48048 .21716 Mtetra
.65 .754 .926 r
.48048 .21716 .48149 .21828 .48328 .21779 .48228 .21656 Mtetra
.666 .74 .905 r
.48228 .21656 .48328 .21779 .48507 .21716 .48407 .21589 Mtetra
.672 .734 .897 r
.48407 .21589 .48507 .21716 .48687 .21646 .48587 .21518 Mtetra
.741 .754 .863 r
.48587 .21518 .48687 .21646 .48867 .21542 .48767 .21408 Mtetra
.713 .735 .869 r
.48767 .21408 .48867 .21542 .49047 .21446 .48947 .21314 Mtetra
.602 .699 .911 r
.48947 .21314 .49047 .21446 .49227 .21384 .49127 .21274 Mtetra
.529 .044 0 r
.49127 .21274 .49227 .21384 .49406 .21436 .49304 .21471 Mtetra
.939 .596 .347 r
.49304 .21471 .49406 .21436 .49584 .21629 .49472 .22652 Mtetra
.959 .667 .437 r
.49472 .22652 .49584 .21629 .49757 .22307 .49465 .42843 Mtetra
.523 .29 .502 r
.49465 .42843 .49757 .22307 .49768 .42611 .49656 .43053 Mtetra
.517 .18 .334 r
.49656 .43053 .49768 .42611 .49957 .43017 .49849 .43092 Mtetra
.195 0 0 r
.49849 .43092 .49957 .43017 .50149 .43178 .50042 .43071 Mtetra
.486 .716 .972 r
.50042 .43071 .50149 .43178 .50342 .43203 .50236 .43058 Mtetra
.604 .695 .907 r
.50236 .43058 .50342 .43203 .50536 .43153 .5043 .43014 Mtetra
.726 .75 .871 r
.5043 .43014 .50536 .43153 .50731 .43044 .50624 .42906 Mtetra
.892 .773 .724 r
.50624 .42906 .50731 .43044 .50926 .42844 .5082 .42573 Mtetra
.923 .694 .573 r
.5082 .42573 .50926 .42844 .51121 .42512 .51019 .41592 Mtetra
.965 .679 .439 r
.51019 .41592 .51121 .42512 .51318 .41823 .51294 .20919 Mtetra
.527 .298 .511 r
.51294 .20919 .51318 .41823 .51574 .21277 .51476 .20568 Mtetra
.617 .434 .612 r
.51476 .20568 .51574 .21277 .51757 .20714 .51658 .20405 Mtetra
.655 .547 .72 r
.51658 .20405 .51757 .20714 .51939 .20435 .5184 .203 Mtetra
.678 .727 .887 r
.5184 .203 .51939 .20435 .52121 .20311 .52022 .20226 Mtetra
.628 .808 .969 r
.52022 .20226 .52121 .20311 .52303 .2026 .52204 .20169 Mtetra
.599 .787 .97 r
.52204 .20169 .52303 .2026 .52485 .20236 .52386 .20123 Mtetra
.711 .778 .904 r
.52386 .20123 .52485 .20236 .52667 .20169 .52568 .20034 Mtetra
.705 .735 .875 r
.52568 .20034 .52667 .20169 .52849 .20089 .52751 .19945 Mtetra
.606 .681 .895 r
.52751 .19945 .52849 .20089 .53032 .20035 .52933 .19903 Mtetra
0 .138 .67 r
.52933 .19903 .53032 .20035 .53214 .20072 .53116 .20067 Mtetra
.936 .571 .287 r
.53116 .20067 .53214 .20072 .53398 .2024 .53302 .20979 Mtetra
.965 .669 .419 r
.53302 .20979 .53398 .2024 .53583 .20768 .53553 .41439 Mtetra
.524 .29 .503 r
.53553 .41439 .53583 .20768 .53853 .41158 .5375 .41691 Mtetra
.522 .199 .361 r
.5375 .41691 .53853 .41158 .54051 .41629 .53947 .41735 Mtetra
.276 0 0 r
.53947 .41735 .54051 .41629 .54249 .41809 .54144 .41716 Mtetra
.507 .759 .987 r
.54144 .41716 .54249 .41809 .54446 .41836 .54341 .41691 Mtetra
.614 .703 .908 r
.54341 .41691 .54446 .41836 .54643 .41774 .54538 .41642 Mtetra
.732 .767 .88 r
.54538 .41642 .54643 .41774 .5484 .41652 .54735 .41531 Mtetra
.898 .798 .741 r
.54735 .41531 .5484 .41652 .55036 .41455 .54931 .41219 Mtetra
.933 .708 .574 r
.54931 .41219 .55036 .41455 .55231 .41142 .55121 .40305 Mtetra
.969 .679 .423 r
.55121 .40305 .55231 .41142 .55424 .40525 .55136 .19556 Mtetra
.528 .299 .511 r
.55136 .19556 .55424 .40525 .55422 .19971 .55318 .19172 Mtetra
.609 .42 .601 r
.55318 .19172 .55422 .19971 .55601 .19346 .55501 .19004 Mtetra
.647 .528 .705 r
.55501 .19004 .55601 .19346 .55783 .19048 .55685 .18897 Mtetra
.671 .7 .868 r
.55685 .18897 .55783 .19048 .55966 .18908 .55869 .18823 Mtetra
.621 .81 .973 r
.55869 .18823 .55966 .18908 .56151 .18854 .56054 .18768 Mtetra
.584 .794 .979 r
.56054 .18768 .56151 .18854 .56336 .1883 .56239 .18724 Mtetra
.694 .79 .924 r
.56239 .18724 .56336 .1883 .56521 .18772 .56424 .18643 Mtetra
.714 .751 .881 r
.56424 .18643 .56521 .18772 .56705 .18689 .56608 .18548 Mtetra
.623 .697 .897 r
.56608 .18548 .56705 .18689 .5689 .18631 .56793 .18498 Mtetra
0 .286 .784 r
.56793 .18498 .5689 .18631 .57077 .18651 .56982 .18627 Mtetra
.923 .534 .218 r
.56982 .18627 .57077 .18651 .57265 .18799 .57179 .19349 Mtetra
.969 .67 .4 r
.57179 .19349 .57265 .18799 .57459 .19231 .57701 .40008 Mtetra
.524 .291 .503 r
.57701 .40008 .57459 .19231 .57996 .39649 .57906 .40306 Mtetra
.523 .215 .386 r
.57906 .40306 .57996 .39649 .58206 .40205 .58107 .40351 Mtetra
.326 0 0 r
.58107 .40351 .58206 .40205 .5841 .40404 .58307 .40327 Mtetra
.616 .843 .986 r
.58307 .40327 .5841 .40404 .58611 .40427 .58507 .40264 Mtetra
.681 .704 .865 r
.58507 .40264 .58611 .40427 .58811 .40345 .58707 .40178 Mtetra
.702 .707 .852 r
.58707 .40178 .58811 .40345 .5901 .40224 .58906 .40077 Mtetra
.681 .728 .885 r
.58906 .40077 .5901 .40224 .59209 .40134 .59106 .39993 Mtetra
.644 .723 .906 r
.59106 .39993 .59209 .40134 .5941 .40081 .59307 .39929 Mtetra
.659 .712 .887 r
.59307 .39929 .5941 .40081 .5961 .39997 .59507 .39856 Mtetra
.732 .757 .873 r
.59507 .39856 .5961 .39997 .59807 .39786 .59706 .39742 Mtetra
.828 .949 .899 r
.59706 .39742 .59807 .39786 .59998 .39322 .59905 .39578 Mtetra
.099 0 .062 r
.59905 .39578 .59998 .39322 .60144 .36953 .60103 .39399 Mtetra
.492 .245 .469 r
.60103 .39399 .60144 .36953 .59886 .18339 .60302 .39266 Mtetra
.518 .286 .502 r
.60302 .39266 .59886 .18339 .60073 .18244 .60504 .39209 Mtetra
.60504 .39209 .60073 .18244 .60264 .18304 .60706 .39176 Mtetra
.60706 .39176 .60264 .18304 .60456 .18387 .60908 .39136 Mtetra
.60908 .39136 .60456 .18387 .60646 .18367 .61109 .39081 Mtetra
.61109 .39081 .60646 .18367 .60835 .18343 .61311 .39023 Mtetra
.61311 .39023 .60835 .18343 .61025 .18308 .61513 .38963 Mtetra
.518 .285 .502 r
.61513 .38963 .61025 .18308 .61214 .18258 .61715 .389 Mtetra
.61715 .389 .61214 .18258 .61403 .18194 .61917 .38835 Mtetra
.61917 .38835 .61403 .18194 .61591 .18111 .6212 .38767 Mtetra
.6212 .38767 .61591 .18111 .61779 .18014 .62322 .38697 Mtetra
.62322 .38697 .61779 .18014 .61967 .1791 .62524 .38624 Mtetra
.517 .285 .502 r
.62524 .38624 .61967 .1791 .62152 .17712 .62726 .38541 Mtetra
.62726 .38541 .62152 .17712 .62336 .1749 .62928 .38449 Mtetra
.518 .285 .502 r
.62928 .38449 .62336 .1749 .62526 .17435 .63131 .38376 Mtetra
.519 .286 .502 r
.63131 .38376 .62526 .17435 .62761 .18687 .63336 .38364 Mtetra
.52 .287 .502 r
.63336 .38364 .62761 .18687 .63629 .38108 .63543 .38409 Mtetra
.5 .119 .249 r
.63543 .38409 .63629 .38108 .63847 .3846 .6375 .38442 Mtetra
.132 .673 .834 r
.6375 .38442 .63847 .3846 .64057 .38568 .63956 .38436 Mtetra
.614 .731 .929 r
.63956 .38436 .64057 .38568 .64261 .38529 .6416 .38384 Mtetra
.642 .719 .904 r
.6416 .38384 .64261 .38529 .64465 .38455 .64364 .38319 Mtetra
.588 .714 .931 r
.64364 .38319 .64465 .38455 .6467 .384 .64569 .38278 Mtetra
.492 .694 .958 r
.64569 .38278 .6467 .384 .64876 .38389 .64776 .38267 Mtetra
.646 .764 .934 r
.64776 .38267 .64876 .38389 .6508 .38322 .64981 .382 Mtetra
.872 .817 .792 r
.64981 .382 .6508 .38322 .65278 .38079 .65178 .37958 Mtetra
.978 .753 .53 r
.65178 .37958 .65278 .38079 .65445 .37079 .65346 .36967 Mtetra
.977 .68 .37 r
.65346 .36967 .65445 .37079 .64785 .16054 .64692 .15929 Mtetra
.933 .791 .681 r
.64692 .15929 .64785 .16054 .64962 .15662 .64869 .15536 Mtetra
.716 .765 .891 r
.64869 .15536 .64962 .15662 .65151 .15566 .65059 .15439 Mtetra
.577 .709 .932 r
.65059 .15439 .65151 .15566 .65344 .15531 .65251 .15405 Mtetra
.55 .696 .936 r
.65251 .15405 .65344 .15531 .65536 .15506 .65444 .1538 Mtetra
.663 .747 .912 r
.65444 .1538 .65536 .15506 .65727 .15436 .65635 .1531 Mtetra
.67 .75 .91 r
.65635 .1531 .65727 .15436 .65918 .15363 .65826 .15237 Mtetra
.711 .765 .895 r
.65826 .15237 .65918 .15363 .66108 .15269 .66016 .15143 Mtetra
.76 .782 .871 r
.66016 .15143 .66108 .15269 .66297 .15144 .66205 .15019 Mtetra
.673 .754 .912 r
.66205 .15019 .66297 .15144 .66488 .1507 .66396 .14945 Mtetra
.175 .482 .898 r
.66396 .14945 .66488 .1507 .66687 .15147 .66595 .15019 Mtetra
.911 .532 .102 r
.66595 .15019 .66687 .15147 .66928 .16094 .66832 .15897 Mtetra
.975 .669 .338 r
.66832 .15897 .66928 .16094 .68148 .36982 .68049 .36826 Mtetra
0 0 .486 r
.68049 .36826 .68148 .36982 .68373 .37272 .68273 .37125 Mtetra
.581 .694 .919 r
.68273 .37125 .68373 .37272 .68581 .37227 .68482 .37088 Mtetra
.718 .763 .888 r
.68482 .37088 .68581 .37227 .68786 .37115 .68687 .36981 Mtetra
.716 .772 .896 r
.68687 .36981 .68786 .37115 .68991 .3701 .68893 .36877 Mtetra
.497 .678 .946 r
.68893 .36877 .68991 .3701 .69202 .3701 .69103 .36867 Mtetra
.63 .723 .914 r
.69103 .36867 .69202 .3701 .69411 .3696 .69312 .36807 Mtetra
.825 .774 .804 r
.69312 .36807 .69411 .3696 .69612 .36765 .69512 .36602 Mtetra
.97 .746 .544 r
.69512 .36602 .69612 .36765 .69776 .359 .69675 .35705 Mtetra
.977 .675 .352 r
.69675 .35705 .69776 .359 .68815 .14582 .68724 .14457 Mtetra
.947 .792 .656 r
.68724 .14457 .68815 .14582 .68987 .14133 .68897 .14016 Mtetra
.722 .789 .905 r
.68897 .14016 .68987 .14133 .69179 .14038 .69088 .13917 Mtetra
.564 .716 .943 r
.69088 .13917 .69179 .14038 .69375 .14013 .69284 .13885 Mtetra
.5 .67 .94 r
.69284 .13885 .69375 .14013 .69573 .14011 .69481 .13876 Mtetra
.642 .726 .909 r
.69481 .13876 .69573 .14011 .69767 .13948 .69676 .13815 Mtetra
.652 .733 .909 r
.69676 .13815 .69767 .13948 .69961 .1388 .6987 .13749 Mtetra
.669 .746 .908 r
.6987 .13749 .69961 .1388 .70154 .138 .70064 .13675 Mtetra
.702 .769 .904 r
.70064 .13675 .70154 .138 .70346 .13695 .70257 .13586 Mtetra
.692 .796 .929 r
.70257 .13586 .70346 .13695 .7054 .13613 .7045 .13502 Mtetra
.662 .782 .938 r
.7045 .13502 .7054 .13613 .70737 .13584 .70645 .13431 Mtetra
.627 .689 .888 r
.70645 .13431 .70737 .13584 .70943 .13702 .7084 .13377 Mtetra
.542 .477 .733 r
.7084 .13377 .70943 .13702 .71163 .14034 .71039 .1337 Mtetra
.458 .333 .621 r
.71039 .1337 .71163 .14034 .7266 .34407 .71246 .13482 Mtetra
.495 .274 .508 r
.71246 .13482 .7266 .34407 .72926 .3521 .71523 .14696 Mtetra
0 0 .39 r
.71523 .14696 .72926 .3521 .73156 .3545 .73046 .35108 Mtetra
.044 .158 .659 r
.73046 .35108 .73156 .3545 .73376 .35537 .73281 .35407 Mtetra
.522 .699 .95 r
.73281 .35407 .73376 .35537 .73589 .35496 .73494 .35388 Mtetra
.673 .81 .949 r
.73494 .35388 .73589 .35496 .73799 .3542 .73704 .35305 Mtetra
.715 .813 .926 r
.73704 .35305 .73799 .3542 .74009 .35339 .73913 .35203 Mtetra
.574 .713 .936 r
.73913 .35203 .74009 .35339 .74224 .35326 .74127 .35165 Mtetra
.598 .682 .9 r
.74127 .35165 .74224 .35326 .74438 .35289 .7434 .3512 Mtetra
.63 .685 .883 r
.7434 .3512 .74438 .35289 .74648 .35201 .74552 .35059 Mtetra
.667 .744 .908 r
.74552 .35059 .74648 .35201 .74848 .34965 .74763 .3498 Mtetra
.564 .932 .799 r
.74763 .3498 .74848 .34965 .75037 .34579 .7497 .34851 Mtetra
.056 0 .087 r
.7497 .34851 .75037 .34579 .75185 .33633 .75171 .34619 Mtetra
.058 0 .323 r
.75171 .34619 .75185 .33633 .73908 .1304 .75326 .33766 Mtetra
0 0 .384 r
.75326 .33766 .73908 .1304 .74076 .12568 .74004 .12676 Mtetra
.876 .863 .415 r
.74004 .12676 .74076 .12568 .74259 .12316 .74171 .12191 Mtetra
.758 .791 .88 r
.74171 .12191 .74259 .12316 .74454 .12216 .74364 .12067 Mtetra
.633 .702 .895 r
.74364 .12067 .74454 .12216 .74652 .12156 .74562 .12009 Mtetra
.562 .669 .91 r
.74562 .12009 .74652 .12156 .74851 .12115 .74763 .11982 Mtetra
.669 .744 .907 r
.74763 .11982 .74851 .12115 .75049 .12041 .7496 .11907 Mtetra
.673 .745 .905 r
.7496 .11907 .75049 .12041 .75246 .11963 .75157 .11829 Mtetra
.679 .748 .903 r
.75157 .11829 .75246 .11963 .75443 .11883 .75354 .11749 Mtetra
.688 .752 .901 r
.75354 .11749 .75443 .11883 .7564 .118 .75551 .11664 Mtetra
.692 .75 .896 r
.75551 .11664 .7564 .118 .75836 .11714 .75748 .11577 Mtetra
.694 .749 .894 r
.75748 .11577 .75836 .11714 .76033 .11624 .75945 .11489 Mtetra
.66 .705 .88 r
.12554 .34568 .12666 .34694 .1283 .34578 .12711 .3451 Mtetra
.464 .763 .995 r
.12711 .3451 .1283 .34578 .1299 .34495 .12862 .34495 Mtetra
.505 0 0 r
.12862 .34495 .1299 .34495 .13143 .34471 .13004 .34562 Mtetra
.884 .565 .442 r
.13004 .34562 .13143 .34471 .13261 .34727 .13067 .35266 Mtetra
.93 .673 .528 r
.13067 .35266 .13261 .34727 .11052 .53862 .10739 .55306 Mtetra
.612 .342 .484 r
.10739 .55306 .11052 .53862 .11015 .55466 .10853 .55683 Mtetra
.484 .082 .201 r
.10853 .55683 .11015 .55466 .11158 .55603 .11011 .55703 Mtetra
.022 0 0 r
.11011 .55703 .11158 .55603 .11316 .55629 .11178 .55645 Mtetra
.691 .973 .919 r
.11178 .55645 .11316 .55629 .1148 .55605 .11352 .5554 Mtetra
.672 .841 .964 r
.11352 .5554 .1148 .55605 .11639 .55616 .11521 .55472 Mtetra
.729 .71 .833 r
.11521 .55472 .11639 .55616 .11804 .55582 .11696 .55364 Mtetra
.762 .65 .738 r
.11696 .55364 .11804 .55582 .11978 .55478 .1188 .5517 Mtetra
.865 .658 .62 r
.1188 .5517 .11978 .55478 .12187 .55082 .12138 .54362 Mtetra
.931 .679 .533 r
.12138 .54362 .12187 .55082 .14552 .36562 .1471 .3417 Mtetra
.602 .379 .55 r
.1471 .3417 .14552 .36562 .14997 .34091 .14916 .33709 Mtetra
.652 .51 .678 r
.14916 .33709 .14997 .34091 .15177 .33853 .15082 .3359 Mtetra
.602 .532 .748 r
.15082 .3359 .15177 .33853 .15343 .33728 .15239 .33546 Mtetra
.541 .576 .839 r
.15239 .33546 .15343 .33728 .15504 .33649 .15392 .33538 Mtetra
.639 .727 .912 r
.15392 .33538 .15504 .33649 .15664 .33582 .15549 .33489 Mtetra
.66 .77 .931 r
.15549 .33489 .15664 .33582 .15822 .33528 .15708 .33432 Mtetra
.669 .766 .923 r
.15708 .33432 .15822 .33528 .1598 .33481 .15867 .33372 Mtetra
.757 .756 .852 r
.15867 .33372 .1598 .33481 .16143 .33386 .16032 .3326 Mtetra
.71 .721 .858 r
.16032 .3326 .16143 .33386 .16304 .3331 .16194 .33175 Mtetra
.559 .655 .9 r
.16194 .33175 .16304 .3331 .16459 .33288 .16349 .33156 Mtetra
.91 .505 .136 r
.16349 .33156 .16459 .33288 .16585 .3352 .16461 .33506 Mtetra
.94 .682 .518 r
.16461 .33506 .16585 .3352 .14614 .52282 .14302 .53853 Mtetra
.651 .38 .496 r
.14302 .53853 .14614 .52282 .1455 .5428 .14394 .54484 Mtetra
.534 .129 .219 r
.14394 .54484 .1455 .5428 .14695 .54443 .14552 .54535 Mtetra
0 0 0 r
.14552 .54535 .14695 .54443 .14856 .54468 .14723 .54467 Mtetra
.745 .966 .934 r
.14723 .54467 .14856 .54468 .15023 .5444 .14899 .54353 Mtetra
.641 .792 .955 r
.14899 .54353 .15023 .5444 .15191 .54398 .15069 .54298 Mtetra
.609 .756 .949 r
.15069 .54298 .15191 .54398 .15361 .54344 .15238 .54255 Mtetra
.635 .788 .955 r
.15238 .54255 .15361 .54344 .15532 .54284 .15408 .54202 Mtetra
.644 .806 .961 r
.15408 .54202 .15532 .54284 .15696 .54286 .15578 .54145 Mtetra
.709 .713 .852 r
.15578 .54145 .15696 .54286 .15862 .54268 .15753 .54053 Mtetra
.747 .647 .751 r
.15753 .54053 .15862 .54268 .16036 .54181 .15935 .53885 Mtetra
.846 .652 .641 r
.15935 .53885 .16036 .54181 .16246 .53754 .16163 .53304 Mtetra
.939 .683 .524 r
.16163 .53304 .16246 .53754 .18595 .33416 .1852 .32956 Mtetra
.799 .592 .622 r
.1852 .32956 .18595 .33416 .18847 .32503 .18737 .32378 Mtetra
.801 .74 .796 r
.18737 .32378 .18847 .32503 .19022 .32312 .18909 .32212 Mtetra
.673 .762 .918 r
.18909 .32212 .19022 .32312 .19183 .32249 .1907 .32149 Mtetra
.563 .73 .953 r
.1907 .32149 .19183 .32249 .1934 .3223 .19228 .32123 Mtetra
.735 .76 .872 r
.19228 .32123 .1934 .3223 .19504 .32142 .19393 .32027 Mtetra
.723 .743 .868 r
.19393 .32027 .19504 .32142 .19667 .32058 .19557 .31936 Mtetra
.585 .691 .915 r
.19557 .31936 .19667 .32058 .19825 .32035 .19715 .31906 Mtetra
.839 .394 0 r
.19715 .31906 .19825 .32035 .19951 .32319 .19842 .32177 Mtetra
.946 .685 .51 r
.19842 .32177 .19951 .32319 .18019 .52594 .17905 .52424 Mtetra
.959 .632 .351 r
.17905 .52424 .18019 .52594 .18106 .53363 .17986 .53254 Mtetra
.488 0 0 r
.17986 .53254 .18106 .53363 .18258 .53499 .18138 .53395 Mtetra
.551 .731 .959 r
.18138 .53395 .18258 .53499 .18427 .53472 .18307 .53369 Mtetra
.779 .785 .857 r
.18307 .53369 .18427 .53472 .18607 .5334 .18487 .53236 Mtetra
.9 .757 .694 r
.18487 .53236 .18607 .5334 .18816 .52921 .18696 .52818 Mtetra
.945 .688 .517 r
.18696 .52818 .18816 .52921 .21012 .32623 .209 .32517 Mtetra
.93 .72 .597 r
.209 .32517 .21012 .32623 .21267 .31636 .21155 .31526 Mtetra
.842 .762 .775 r
.21155 .31526 .21267 .31636 .21444 .31423 .21333 .31313 Mtetra
.679 .745 .901 r
.21333 .31313 .21444 .31423 .21607 .31357 .21496 .31246 Mtetra
.546 .702 .942 r
.21496 .31246 .21607 .31357 .21765 .31337 .21654 .31226 Mtetra
.703 .75 .889 r
.21654 .31226 .21765 .31337 .2193 .31259 .21819 .31148 Mtetra
.718 .753 .88 r
.21819 .31148 .2193 .31259 .22095 .31172 .21984 .31061 Mtetra
.577 .712 .934 r
.21984 .31061 .22095 .31172 .22255 .31143 .22144 .31032 Mtetra
.809 .341 0 r
.22144 .31032 .22255 .31143 .22388 .31387 .22278 .31274 Mtetra
.948 .684 .504 r
.22278 .31274 .22388 .31387 .20617 .51584 .20499 .51467 Mtetra
.95 .626 .377 r
.20499 .51467 .20617 .51584 .20699 .52486 .2058 .52378 Mtetra
.577 .06 0 r
.2058 .52378 .20699 .52486 .20853 .52646 .20733 .5254 Mtetra
.527 .718 .96 r
.20733 .5254 .20853 .52646 .21023 .52627 .20904 .52521 Mtetra
.768 .781 .864 r
.20904 .52521 .21023 .52627 .21203 .52503 .21084 .52396 Mtetra
.895 .76 .705 r
.21084 .52396 .21203 .52503 .21407 .52123 .21289 .52013 Mtetra
.948 .689 .512 r
.21289 .52013 .21407 .52123 .23427 .32098 .23323 .31921 Mtetra
.923 .699 .58 r
.23323 .31921 .23427 .32098 .23707 .30779 .23598 .30662 Mtetra
.85 .754 .756 r
.23598 .30662 .23707 .30779 .23888 .30538 .23778 .30421 Mtetra
.679 .734 .892 r
.23778 .30421 .23888 .30538 .24052 .30472 .23943 .30353 Mtetra
.541 .684 .931 r
.23943 .30353 .24052 .30472 .24212 .30457 .24103 .30336 Mtetra
.607 .704 .913 r
.24103 .30336 .24212 .30457 .24373 .30427 .24265 .30298 Mtetra
.664 .71 .882 r
.24265 .30298 .24373 .30427 .24537 .30371 .24429 .30236 Mtetra
.648 .693 .878 r
.24429 .30236 .24537 .30371 .24701 .30312 .24593 .30181 Mtetra
.585 .678 .904 r
.24593 .30181 .24701 .30312 .24867 .30241 .24755 .30151 Mtetra
.464 .715 .978 r
.24755 .30151 .24867 .30241 .25033 .30163 .24915 .30143 Mtetra
.153 .684 .861 r
.24915 .30143 .25033 .30163 .25199 .30085 .25074 .3014 Mtetra
0 0 0 r
.25074 .3014 .25199 .30085 .25367 .29988 .2524 .30071 Mtetra
.2524 .30071 .25367 .29988 .25534 .29896 .25408 .2997 Mtetra
.044 0 0 r
.25408 .2997 .25534 .29896 .25697 .29851 .25572 .29927 Mtetra
.79 .375 .264 r
.25572 .29927 .25697 .29851 .25847 .29971 .2571 .30176 Mtetra
.947 .68 .498 r
.2571 .30176 .25847 .29971 .25956 .30576 .2414 .50486 Mtetra
.533 .298 .505 r
.2414 .50486 .25956 .30576 .24405 .50879 .24252 .5118 Mtetra
.624 .262 .335 r
.24252 .5118 .24405 .50879 .24548 .51212 .24412 .51322 Mtetra
.206 0 0 r
.24412 .51322 .24548 .51212 .24714 .51274 .24586 .51287 Mtetra
.592 .946 .905 r
.24586 .51287 .24714 .51274 .24886 .51269 .24765 .51196 Mtetra
.768 .849 .912 r
.24765 .51196 .24886 .51269 .25061 .51233 .24947 .51081 Mtetra
.742 .713 .824 r
.24947 .51081 .25061 .51233 .25237 .51181 .25129 .50957 Mtetra
.715 .632 .764 r
.25129 .50957 .25237 .51181 .25414 .51117 .25312 .50824 Mtetra
.627 .543 .741 r
.25312 .50824 .25414 .51117 .2559 .51076 .2549 .50754 Mtetra
.562 .489 .731 r
.2549 .50754 .2559 .51076 .25765 .51047 .25664 .50733 Mtetra
.628 .533 .728 r
.25664 .50733 .25765 .51047 .25943 .50971 .25842 .50658 Mtetra
.791 .623 .673 r
.25842 .50658 .25943 .50971 .26135 .50736 .26042 .50315 Mtetra
.949 .686 .503 r
.26042 .50315 .26135 .50736 .2636 .50071 .27822 .29977 Mtetra
.542 .31 .514 r
.27822 .29977 .2636 .50071 .28133 .29571 .28058 .29033 Mtetra
.691 .506 .633 r
.28058 .29033 .28133 .29571 .28333 .29083 .2824 .28773 Mtetra
.628 .525 .717 r
.2824 .28773 .28333 .29083 .28509 .28905 .28408 .28697 Mtetra
.582 .572 .808 r
.28408 .28697 .28509 .28905 .2868 .28793 .28572 .28669 Mtetra
.58 .693 .919 r
.28572 .28669 .2868 .28793 .28848 .28713 .28737 .2864 Mtetra
.644 .822 .969 r
.28737 .2864 .28848 .28713 .29015 .28649 .28903 .28583 Mtetra
.646 .839 .974 r
.28903 .28583 .29015 .28649 .29181 .28599 .2907 .28524 Mtetra
.677 .826 .954 r
.2907 .28524 .29181 .28599 .29347 .28552 .29238 .28456 Mtetra
.697 .786 .919 r
.29238 .28456 .29347 .28552 .29514 .285 .29406 .28381 Mtetra
.677 .735 .894 r
.29406 .28381 .29514 .285 .29681 .28446 .29574 .28313 Mtetra
.615 .689 .896 r
.29574 .28313 .29681 .28446 .29848 .28383 .2974 .28271 Mtetra
.491 .681 .951 r
.2974 .28271 .29848 .28383 .30017 .28309 .29904 .28265 Mtetra
.237 .704 .945 r
.29904 .28265 .30017 .28309 .30186 .28233 .30067 .28267 Mtetra
0 0 0 r
.30067 .28267 .30186 .28233 .30355 .28145 .30234 .28224 Mtetra
.30234 .28224 .30355 .28145 .30525 .28052 .30405 .28123 Mtetra
.30405 .28123 .30525 .28052 .30693 .28 .30572 .28069 Mtetra
.702 .235 .139 r
.30572 .28069 .30693 .28 .30851 .28078 .30726 .2822 Mtetra
.953 .681 .484 r
.30726 .2822 .30851 .28078 .30982 .28559 .29494 .48284 Mtetra
.541 .304 .506 r
.29494 .48284 .30982 .28559 .29743 .48991 .29595 .49352 Mtetra
.653 .305 .37 r
.29595 .49352 .29743 .48991 .29892 .49382 .29757 .49556 Mtetra
.339 0 .045 r
.29757 .49556 .29892 .49382 .3007 .49354 .29935 .49527 Mtetra
.152 0 0 r
.29935 .49527 .3007 .49354 .30252 .4926 .30117 .49444 Mtetra
.159 0 0 r
.30117 .49444 .30252 .4926 .30432 .49208 .30299 .49356 Mtetra
.217 0 0 r
.30299 .49356 .30432 .49208 .30605 .49259 .30479 .49303 Mtetra
0 0 0 r
.30479 .49303 .30605 .49259 .30779 .49296 .3066 .49241 Mtetra
.698 .885 .967 r
.3066 .49241 .30779 .49296 .30955 .49296 .30842 .49155 Mtetra
.746 .735 .841 r
.30842 .49155 .30955 .49296 .31135 .49248 .31027 .49033 Mtetra
.719 .645 .774 r
.31027 .49033 .31135 .49248 .31316 .49185 .31212 .489 Mtetra
.653 .564 .742 r
.31212 .489 .31316 .49185 .31497 .49134 .31395 .48807 Mtetra
.555 .484 .731 r
.31395 .48807 .31497 .49134 .31676 .4911 .31574 .48791 Mtetra
.612 .523 .729 r
.31574 .48791 .31676 .4911 .31857 .49043 .31755 .48729 Mtetra
.755 .605 .691 r
.31755 .48729 .31857 .49043 .32047 .48851 .31948 .48476 Mtetra
.955 .687 .488 r
.31948 .48476 .32047 .48851 .32261 .48255 .33324 .29017 Mtetra
.565 .329 .517 r
.33324 .29017 .32261 .48255 .33688 .27661 .33611 .27063 Mtetra
.705 .508 .62 r
.33611 .27063 .33688 .27661 .33888 .27101 .33797 .26733 Mtetra
.631 .505 .69 r
.33797 .26733 .33888 .27101 .34061 .27005 .33969 .26639 Mtetra
.581 .474 .697 r
.33969 .26639 .34061 .27005 .34229 .26974 .34138 .26599 Mtetra
.563 .459 .693 r
.34138 .26599 .34229 .26974 .34399 .26921 .34306 .26574 Mtetra
.595 .49 .704 r
.34306 .26574 .34399 .26921 .34575 .26761 .34476 .26522 Mtetra
.615 .564 .773 r
.34476 .26522 .34575 .26761 .34751 .26614 .34646 .26471 Mtetra
.644 .687 .875 r
.34646 .26471 .34751 .26614 .34925 .26501 .34817 .26415 Mtetra
.668 .805 .948 r
.34817 .26415 .34925 .26501 .35095 .26442 .34988 .2635 Mtetra
.676 .794 .938 r
.34988 .2635 .35095 .26442 .35265 .26397 .35159 .26283 Mtetra
.68 .75 .904 r
.35159 .26283 .35265 .26397 .35435 .26352 .35331 .26212 Mtetra
.679 .706 .868 r
.35331 .26212 .35435 .26352 .35606 .26291 .35502 .26139 Mtetra
.66 .68 .858 r
.35502 .26139 .35606 .26291 .35778 .26226 .35674 .26074 Mtetra
.64 .672 .865 r
.35674 .26074 .35778 .26226 .3595 .26148 .35845 .2602 Mtetra
.621 .704 .904 r
.35845 .2602 .3595 .26148 .36124 .2604 .36016 .25974 Mtetra
.317 .706 .98 r
.36016 .25974 .36124 .2604 .36296 .2597 .36184 .25979 Mtetra
.695 .169 0 r
.36184 .25979 .36296 .2597 .36463 .25998 .36344 .26127 Mtetra
.959 .681 .467 r
.36344 .26127 .36463 .25998 .3661 .26407 .35485 .45985 Mtetra
.546 .309 .507 r
.35485 .45985 .3661 .26407 .35736 .46911 .35594 .47352 Mtetra
.664 .327 .393 r
.35594 .47352 .35736 .46911 .3589 .4744 .35762 .47609 Mtetra
.401 0 .074 r
.35762 .47609 .3589 .4744 .36071 .47427 .35943 .47605 Mtetra
.222 0 0 r
.35943 .47605 .36071 .47427 .36256 .47344 .36128 .47536 Mtetra
.111 0 0 r
.36128 .47536 .36256 .47344 .36441 .47272 .36315 .47427 Mtetra
0 0 0 r
.36315 .47427 .36441 .47272 .3662 .4733 .36503 .47304 Mtetra
.8 .951 .918 r
.36503 .47304 .3662 .4733 .36799 .47373 .36691 .47164 Mtetra
.714 .651 .785 r
.36691 .47164 .36799 .47373 .3698 .47387 .36879 .47038 Mtetra
.562 .48 .72 r
.36879 .47038 .3698 .47387 .37164 .47364 .37062 .47015 Mtetra
.602 .504 .716 r
.37062 .47015 .37164 .47364 .37349 .4729 .37247 .46957 Mtetra
.708 .573 .701 r
.37247 .46957 .37349 .4729 .37539 .47124 .37437 .46775 Mtetra
.897 .667 .581 r
.37437 .46775 .37539 .47124 .37744 .46615 .37668 .45696 Mtetra
.955 .68 .478 r
.37668 .45696 .37744 .46615 .38837 .26064 .38762 .25265 Mtetra
.694 .483 .597 r
.38762 .25265 .38837 .26064 .39044 .25234 .38951 .24854 Mtetra
.641 .508 .685 r
.38951 .24854 .39044 .25234 .3922 .25114 .39127 .24744 Mtetra
.591 .479 .695 r
.39127 .24744 .3922 .25114 .39393 .2507 .393 .24692 Mtetra
.562 .458 .694 r
.393 .24692 .39393 .2507 .39566 .25036 .39472 .24668 Mtetra
.595 .483 .696 r
.39472 .24668 .39566 .25036 .39744 .24873 .39646 .24614 Mtetra
.613 .549 .759 r
.39646 .24614 .39744 .24873 .39921 .2472 .39819 .2456 Mtetra
.64 .663 .856 r
.39819 .2456 .39921 .2472 .40098 .24591 .39993 .24504 Mtetra
.67 .806 .948 r
.39993 .24504 .40098 .24591 .40273 .24517 .40167 .24437 Mtetra
.674 .824 .955 r
.40167 .24437 .40273 .24517 .40447 .24458 .40342 .24367 Mtetra
.676 .802 .943 r
.40342 .24367 .40447 .24458 .40621 .24405 .40517 .24298 Mtetra
.664 .764 .924 r
.40517 .24298 .40621 .24405 .40795 .24342 .40691 .24234 Mtetra
.662 .76 .923 r
.40691 .24234 .40795 .24342 .4097 .24281 .40866 .24171 Mtetra
.661 .757 .921 r
.40866 .24171 .4097 .24281 .41144 .24221 .41041 .24108 Mtetra
.662 .751 .916 r
.41041 .24108 .41144 .24221 .41319 .24168 .41216 .24045 Mtetra
.661 .732 .902 r
.41216 .24045 .41319 .24168 .41493 .24115 .41391 .23981 Mtetra
.661 .713 .887 r
.41391 .23981 .41493 .24115 .41668 .2406 .41566 .23917 Mtetra
.675 .702 .867 r
.41566 .23917 .41668 .2406 .41843 .23999 .41741 .23844 Mtetra
.662 .68 .857 r
.41741 .23844 .41843 .23999 .42019 .23933 .41917 .23776 Mtetra
.64 .669 .862 r
.41917 .23776 .42019 .23933 .42194 .23863 .42092 .2372 Mtetra
.53 .643 .905 r
.42092 .2372 .42194 .23863 .4237 .23787 .42266 .23708 Mtetra
.383 .713 .987 r
.42266 .23708 .4237 .23787 .42546 .23709 .42439 .23709 Mtetra
.003 0 0 r
.42439 .23709 .42546 .23709 .42722 .23632 .42613 .23709 Mtetra
.01 0 0 r
.42613 .23709 .42722 .23632 .42899 .2356 .42789 .23653 Mtetra
0 0 0 r
.42789 .23653 .42899 .2356 .43075 .23491 .42965 .23579 Mtetra
.42965 .23579 .43075 .23491 .43251 .23424 .43142 .23499 Mtetra
.43142 .23499 .43251 .23424 .43428 .23322 .4332 .2338 Mtetra
.4332 .2338 .43428 .23322 .43605 .23249 .43497 .23303 Mtetra
.274 0 0 r
.43497 .23303 .43605 .23249 .4378 .23233 .43672 .2331 Mtetra
.894 .524 .33 r
.43672 .2331 .4378 .23233 .43947 .23515 .43828 .23949 Mtetra
.962 .676 .447 r
.43828 .23949 .43947 .23515 .4357 .43681 .43432 .44584 Mtetra
.651 .35 .449 r
.43432 .44584 .4357 .43681 .43727 .44802 .43609 .44992 Mtetra
.465 .034 .135 r
.43609 .44992 .43727 .44802 .43913 .44839 .43796 .45013 Mtetra
.255 0 0 r
.43796 .45013 .43913 .44839 .44103 .44766 .43986 .44954 Mtetra
.161 0 0 r
.43986 .44954 .44103 .44766 .44294 .4466 .44176 .44856 Mtetra
.278 0 .047 r
.44176 .44856 .44294 .4466 .44481 .44697 .44366 .44794 Mtetra
.036 0 0 r
.44366 .44794 .44481 .44697 .44669 .44738 .44557 .44727 Mtetra
.569 .928 .94 r
.44557 .44727 .44669 .44738 .44857 .44756 .44747 .44646 Mtetra
.678 .78 .928 r
.44747 .44646 .44857 .44756 .45046 .44752 .44938 .4457 Mtetra
.715 .684 .818 r
.44938 .4457 .45046 .44752 .45236 .44701 .4513 .44455 Mtetra
.757 .645 .737 r
.4513 .44455 .45236 .44701 .45428 .44581 .45323 .44256 Mtetra
.884 .666 .603 r
.45323 .44256 .45428 .44581 .45626 .44167 .45529 .4349 Mtetra
.964 .683 .452 r
.45529 .4349 .45626 .44167 .45879 .41078 .46151 .22683 Mtetra
.532 .302 .512 r
.46151 .22683 .45879 .41078 .46434 .22586 .46338 .2218 Mtetra
.661 .514 .673 r
.46338 .2218 .46434 .22586 .46614 .22406 .46518 .22033 Mtetra
.6 .486 .695 r
.46518 .22033 .46614 .22406 .46793 .22351 .46696 .21971 Mtetra
.561 .459 .695 r
.46696 .21971 .46793 .22351 .46971 .22331 .46874 .21947 Mtetra
.586 .473 .692 r
.46874 .21947 .46971 .22331 .47151 .22187 .47053 .21898 Mtetra
.607 .529 .741 r
.47053 .21898 .47151 .22187 .47331 .22029 .47231 .21843 Mtetra
.632 .63 .831 r
.47231 .21843 .47331 .22029 .47511 .21892 .4741 .21787 Mtetra
.665 .775 .931 r
.4741 .21787 .47511 .21892 .4769 .21815 .47589 .21721 Mtetra
.675 .802 .943 r
.47589 .21721 .4769 .21815 .47869 .21761 .47768 .21651 Mtetra
.679 .768 .918 r
.47768 .21651 .47869 .21761 .48048 .21716 .47948 .21578 Mtetra
.683 .72 .877 r
.47948 .21578 .48048 .21716 .48228 .21656 .48127 .21501 Mtetra
.669 .688 .859 r
.48127 .21501 .48228 .21656 .48407 .21589 .48307 .21428 Mtetra
.646 .67 .859 r
.48307 .21428 .48407 .21589 .48587 .21518 .48487 .21367 Mtetra
.644 .683 .872 r
.48487 .21367 .48587 .21518 .48767 .21408 .48666 .21308 Mtetra
.539 .739 .968 r
.48666 .21308 .48767 .21408 .48947 .21314 .48846 .21283 Mtetra
0 .425 .712 r
.48846 .21283 .48947 .21314 .49127 .21274 .49025 .2133 Mtetra
.88 .48 .266 r
.49025 .2133 .49127 .21274 .49304 .21471 .49199 .21835 Mtetra
.966 .676 .428 r
.49199 .21835 .49304 .21471 .49472 .22652 .49166 .42608 Mtetra
.528 .293 .503 r
.49166 .42608 .49472 .22652 .49465 .42843 .49354 .43069 Mtetra
.535 .124 .208 r
.49354 .43069 .49465 .42843 .49656 .43053 .49547 .43131 Mtetra
.036 0 0 r
.49547 .43131 .49656 .43053 .49849 .43092 .49741 .43076 Mtetra
.674 .961 .939 r
.49741 .43076 .49849 .43092 .50042 .43071 .49935 .42969 Mtetra
.695 .806 .934 r
.49935 .42969 .50042 .43071 .50236 .43058 .50129 .42884 Mtetra
.708 .693 .834 r
.50129 .42884 .50236 .43058 .5043 .43014 .50324 .42777 Mtetra
.75 .65 .75 r
.50324 .42777 .5043 .43014 .50624 .42906 .50519 .42595 Mtetra
.866 .664 .627 r
.50519 .42595 .50624 .42906 .5082 .42573 .50716 .42009 Mtetra
.969 .683 .434 r
.50716 .42009 .5082 .42573 .51019 .41592 .51012 .21066 Mtetra
.533 .302 .511 r
.51012 .21066 .51019 .41592 .51294 .20919 .51196 .20456 Mtetra
.669 .506 .654 r
.51196 .20456 .51294 .20919 .51476 .20568 .51378 .20273 Mtetra
.616 .532 .737 r
.51378 .20273 .51476 .20568 .51658 .20405 .51559 .20208 Mtetra
.568 .588 .833 r
.51559 .20208 .51658 .20405 .5184 .203 .51741 .20185 Mtetra
.615 .739 .934 r
.51741 .20185 .5184 .203 .52022 .20226 .51923 .20138 Mtetra
.653 .813 .96 r
.51923 .20138 .52022 .20226 .52204 .20169 .52105 .20074 Mtetra
.663 .798 .947 r
.52105 .20074 .52204 .20169 .52386 .20123 .52287 .20007 Mtetra
.747 .779 .879 r
.52287 .20007 .52386 .20123 .52568 .20034 .5247 .19896 Mtetra
.723 .736 .861 r
.5247 .19896 .52568 .20034 .52751 .19945 .52652 .19794 Mtetra
.605 .67 .886 r
.52652 .19794 .52751 .19945 .52933 .19903 .52835 .19753 Mtetra
0 0 .476 r
.52835 .19753 .52933 .19903 .53116 .20067 .53018 .19998 Mtetra
.973 .679 .405 r
.53018 .19998 .53116 .20067 .53302 .20979 .5325 .40756 Mtetra
.536 .3 .504 r
.5325 .40756 .53302 .20979 .53553 .41439 .53448 .41659 Mtetra
.599 .185 .228 r
.53448 .41659 .53553 .41439 .5375 .41691 .53646 .41777 Mtetra
.047 0 0 r
.53646 .41777 .5375 .41691 .53947 .41735 .53842 .41716 Mtetra
.697 .966 .937 r
.53842 .41716 .53947 .41735 .54144 .41716 .54039 .41602 Mtetra
.607 .757 .95 r
.54039 .41602 .54144 .41716 .54341 .41691 .54236 .41552 Mtetra
.563 .69 .926 r
.54236 .41552 .54341 .41691 .54538 .41642 .54433 .41523 Mtetra
.706 .782 .911 r
.54433 .41523 .54538 .41642 .54735 .41531 .5463 .41431 Mtetra
.931 .814 .707 r
.5463 .41431 .54735 .41531 .54931 .41219 .54825 .41051 Mtetra
.974 .686 .414 r
.54825 .41051 .54931 .41219 .55121 .40305 .54861 .20337 Mtetra
.546 .313 .512 r
.54861 .20337 .55121 .40305 .55136 .19556 .55036 .19106 Mtetra
.708 .533 .65 r
.55036 .19106 .55136 .19556 .55318 .19172 .55218 .18857 Mtetra
.618 .524 .726 r
.55218 .18857 .55318 .19172 .55501 .19004 .55403 .18788 Mtetra
.556 .561 .814 r
.55403 .18788 .55501 .19004 .55685 .18897 .55588 .18771 Mtetra
.577 .703 .928 r
.55588 .18771 .55685 .18897 .55869 .18823 .55772 .18738 Mtetra
.635 .817 .97 r
.55772 .18738 .55869 .18823 .56054 .18768 .55957 .18678 Mtetra
.644 .809 .962 r
.55957 .18678 .56054 .18768 .56239 .18724 .56142 .18616 Mtetra
.73 .796 .904 r
.56142 .18616 .56239 .18724 .56424 .18643 .56327 .18517 Mtetra
.728 .761 .879 r
.56327 .18517 .56424 .18643 .56608 .18548 .56511 .18414 Mtetra
.611 .704 .91 r
.56511 .18414 .56608 .18548 .56793 .18498 .56697 .18369 Mtetra
0 .015 .557 r
.56697 .18369 .56793 .18498 .56982 .18627 .56886 .18575 Mtetra
.974 .677 .389 r
.56886 .18575 .56982 .18627 .57179 .19349 .57387 .39245 Mtetra
.538 .301 .504 r
.57387 .39245 .57179 .19349 .57701 .40008 .57603 .40261 Mtetra
.622 .22 .261 r
.57603 .40261 .57701 .40008 .57906 .40306 .57806 .4041 Mtetra
.102 0 0 r
.57806 .4041 .57906 .40306 .58107 .40351 .58006 .40346 Mtetra
.683 .976 .902 r
.58006 .40346 .58107 .40351 .58307 .40327 .58204 .40222 Mtetra
.75 .823 .909 r
.58204 .40222 .58307 .40327 .58507 .40264 .58403 .40105 Mtetra
.679 .709 .87 r
.58403 .40105 .58507 .40264 .58707 .40178 .58603 .4002 Mtetra
.675 .71 .874 r
.58603 .4002 .58707 .40178 .58906 .40077 .58803 .39938 Mtetra
.67 .738 .901 r
.58803 .39938 .58906 .40077 .59106 .39993 .59003 .39861 Mtetra
.659 .746 .914 r
.59003 .39861 .59106 .39993 .59307 .39929 .59203 .3979 Mtetra
.647 .729 .909 r
.59203 .3979 .59307 .39929 .59507 .39856 .59404 .39724 Mtetra
.632 .736 .922 r
.59404 .39724 .59507 .39856 .59706 .39742 .59605 .39665 Mtetra
.583 .831 .992 r
.59605 .39665 .59706 .39742 .59905 .39578 .59806 .39612 Mtetra
0 0 0 r
.59806 .39612 .59905 .39578 .60103 .39399 .60007 .3956 Mtetra
.269 0 0 r
.60007 .3956 .60103 .39399 .60302 .39266 .60209 .39508 Mtetra
.349 0 .142 r
.60209 .39508 .60302 .39266 .60504 .39209 .6041 .39453 Mtetra
.349 0 .144 r
.6041 .39453 .60504 .39209 .60706 .39176 .60612 .39397 Mtetra
.326 0 .108 r
.60612 .39397 .60706 .39176 .60908 .39136 .60814 .39339 Mtetra
.303 0 .073 r
.60814 .39339 .60908 .39136 .61109 .39081 .61016 .39279 Mtetra
.294 0 .061 r
.61016 .39279 .61109 .39081 .61311 .39023 .61218 .39217 Mtetra
.286 0 .052 r
.61218 .39217 .61311 .39023 .61513 .38963 .6142 .39154 Mtetra
.28 0 .045 r
.6142 .39154 .61513 .38963 .61715 .389 .61623 .3909 Mtetra
.276 0 .041 r
.61623 .3909 .61715 .389 .61917 .38835 .61825 .39024 Mtetra
.273 0 .039 r
.61825 .39024 .61917 .38835 .6212 .38767 .62027 .38957 Mtetra
.271 0 .04 r
.62027 .38957 .6212 .38767 .62322 .38697 .6223 .38889 Mtetra
.272 0 .044 r
.6223 .38889 .62322 .38697 .62524 .38624 .62433 .3882 Mtetra
.273 0 .05 r
.62433 .3882 .62524 .38624 .62726 .38541 .62636 .3875 Mtetra
.285 0 .074 r
.62636 .3875 .62726 .38541 .62928 .38449 .62839 .38678 Mtetra
.305 0 .11 r
.62839 .38678 .62928 .38449 .63131 .38376 .63042 .38605 Mtetra
.3 0 .108 r
.63042 .38605 .63131 .38376 .63336 .38364 .63245 .3853 Mtetra
.209 0 0 r
.63245 .3853 .63336 .38364 .63543 .38409 .63448 .38453 Mtetra
0 0 0 r
.63448 .38453 .63543 .38409 .6375 .38442 .63651 .38378 Mtetra
.597 .868 .993 r
.63651 .38378 .6375 .38442 .63956 .38436 .63855 .38313 Mtetra
.612 .749 .943 r
.63855 .38313 .63956 .38436 .6416 .38384 .6406 .38261 Mtetra
.603 .746 .945 r
.6406 .38261 .6416 .38384 .64364 .38319 .64265 .38212 Mtetra
.532 .745 .974 r
.64265 .38212 .64364 .38319 .64569 .38278 .6447 .38183 Mtetra
.453 .734 .988 r
.6447 .38183 .64569 .38278 .64776 .38267 .64677 .38171 Mtetra
.639 .816 .968 r
.64677 .38171 .64776 .38267 .64981 .382 .64881 .38103 Mtetra
.887 .857 .807 r
.64881 .38103 .64981 .382 .65178 .37958 .6508 .37864 Mtetra
.984 .768 .534 r
.6508 .37864 .65178 .37958 .65346 .36967 .6525 .36939 Mtetra
.978 .681 .368 r
.6525 .36939 .65346 .36967 .64692 .15929 .64599 .15817 Mtetra
.944 .803 .675 r
.64599 .15817 .64692 .15929 .64869 .15536 .64776 .15411 Mtetra
.719 .77 .893 r
.64776 .15411 .64869 .15536 .65059 .15439 .64965 .15313 Mtetra
.577 .71 .933 r
.64965 .15313 .65059 .15439 .65251 .15405 .65158 .15278 Mtetra
.549 .696 .937 r
.65158 .15278 .65251 .15405 .65444 .1538 .65351 .15253 Mtetra
.663 .748 .913 r
.65351 .15253 .65444 .1538 .65635 .1531 .65542 .15183 Mtetra
.67 .75 .911 r
.65542 .15183 .65635 .1531 .65826 .15237 .65733 .1511 Mtetra
.706 .763 .897 r
.65733 .1511 .65826 .15237 .66016 .15143 .65923 .15019 Mtetra
.751 .782 .878 r
.65923 .15019 .66016 .15143 .66205 .15019 .66113 .14901 Mtetra
.678 .77 .92 r
.66113 .14901 .66205 .15019 .66396 .14945 .66304 .14824 Mtetra
.309 .578 .936 r
.66304 .14824 .66396 .14945 .66595 .15019 .66501 .14864 Mtetra
.726 .316 0 r
.66501 .14864 .66595 .15019 .66832 .15897 .66717 .15309 Mtetra
.976 .672 .327 r
.66717 .15309 .66832 .15897 .68049 .36826 .67929 .36266 Mtetra
.018 .058 .56 r
.67929 .36266 .68049 .36826 .68273 .37125 .68163 .36759 Mtetra
.468 .423 .724 r
.68163 .36759 .68273 .37125 .68482 .37088 .68376 .36812 Mtetra
.565 .534 .78 r
.68376 .36812 .68482 .37088 .68687 .36981 .68586 .36787 Mtetra
.601 .633 .855 r
.68586 .36787 .68687 .36981 .68893 .36877 .68794 .36742 Mtetra
.522 .686 .942 r
.68794 .36742 .68893 .36877 .69103 .36867 .69005 .36724 Mtetra
.656 .734 .907 r
.69005 .36724 .69103 .36867 .69312 .36807 .69212 .36652 Mtetra
.815 .769 .809 r
.69212 .36652 .69312 .36807 .69512 .36602 .69413 .36456 Mtetra
.961 .77 .599 r
.69413 .36456 .69512 .36602 .69675 .35705 .69591 .35816 Mtetra
.978 .678 .345 r
.69591 .35816 .69675 .35705 .68724 .14457 .6865 .14659 Mtetra
.793 .785 .285 r
.6865 .14659 .68724 .14457 .68897 .14016 .68816 .14071 Mtetra
.555 .882 .615 r
.68816 .14071 .68897 .14016 .69088 .13917 .69004 .13904 Mtetra
.599 .947 .915 r
.69004 .13904 .69088 .13917 .69284 .13885 .69196 .13807 Mtetra
.631 .845 .982 r
.69196 .13807 .69284 .13885 .69481 .13876 .6939 .13742 Mtetra
.659 .735 .905 r
.6939 .13742 .69481 .13876 .69676 .13815 .69584 .13673 Mtetra
.642 .713 .899 r
.69584 .13673 .69676 .13815 .6987 .13749 .69779 .13611 Mtetra
.646 .722 .904 r
.69779 .13611 .6987 .13749 .70064 .13675 .69973 .13548 Mtetra
.681 .756 .908 r
.69973 .13548 .70064 .13675 .70257 .13586 .70167 .13468 Mtetra
.691 .78 .919 r
.70167 .13468 .70257 .13586 .7045 .13502 .70361 .13385 Mtetra
.715 .788 .909 r
.70361 .13385 .7045 .13502 .70645 .13431 .70554 .13289 Mtetra
.765 .76 .848 r
.70554 .13289 .70645 .13431 .7084 .13377 .70744 .13153 Mtetra
.667 .62 .792 r
.70744 .13153 .7084 .13377 .71039 .1337 .70938 .13062 Mtetra
.518 .473 .746 r
.70938 .13062 .71039 .1337 .71246 .13482 .71138 .13072 Mtetra
0 0 .536 r
.71138 .13072 .71246 .13482 .71523 .14696 .71368 .1355 Mtetra
.971 .667 .283 r
.71368 .1355 .71523 .14696 .73046 .35108 .72938 .34799 Mtetra
0 0 .482 r
.72938 .34799 .73046 .35108 .73281 .35407 .73185 .3528 Mtetra
.478 .682 .955 r
.73185 .3528 .73281 .35407 .73494 .35388 .734 .35274 Mtetra
.683 .803 .939 r
.734 .35274 .73494 .35388 .73704 .35305 .73609 .35188 Mtetra
.74 .814 .91 r
.73609 .35188 .73704 .35305 .73913 .35203 .73817 .35071 Mtetra
.605 .735 .937 r
.73817 .35071 .73913 .35203 .74127 .35165 .7403 .3502 Mtetra
.618 .717 .917 r
.7403 .3502 .74127 .35165 .7434 .3512 .74242 .34965 Mtetra
.634 .708 .9 r
.74242 .34965 .7434 .3512 .74552 .35059 .74454 .34902 Mtetra
.618 .698 .901 r
.74454 .34902 .74552 .35059 .74763 .3498 .74667 .34847 Mtetra
.708 .777 .906 r
.74667 .34847 .74763 .3498 .7497 .34851 .74877 .34747 Mtetra
.853 .862 .847 r
.74877 .34747 .7497 .34851 .75171 .34619 .7508 .34548 Mtetra
.994 .801 .535 r
.7508 .34548 .75171 .34619 .75326 .33766 .75242 .33786 Mtetra
.975 .67 .319 r
.75242 .33786 .75326 .33766 .74004 .12676 .73918 .1258 Mtetra
.979 .813 .609 r
.73918 .1258 .74004 .12676 .74171 .12191 .74082 .12057 Mtetra
.758 .776 .868 r
.74082 .12057 .74171 .12191 .74364 .12067 .74275 .11931 Mtetra
.634 .723 .912 r
.74275 .11931 .74364 .12067 .74562 .12009 .74473 .11872 Mtetra
.556 .685 .925 r
.74473 .11872 .74562 .12009 .74763 .11982 .74674 .11845 Mtetra
.669 .739 .903 r
.74674 .11845 .74763 .11982 .7496 .11907 .74871 .1177 Mtetra
.674 .741 .901 r
.74871 .1177 .7496 .11907 .75157 .11829 .75069 .11692 Mtetra
.682 .743 .897 r
.75069 .11692 .75157 .11829 .75354 .11749 .75266 .1161 Mtetra
.715 .753 .882 r
.75266 .1161 .75354 .11749 .75551 .11664 .75461 .11509 Mtetra
.698 .72 .866 r
.75461 .11509 .75551 .11664 .75748 .11577 .75658 .11414 Mtetra
.671 .697 .865 r
.75658 .11414 .75748 .11577 .75945 .11489 .75855 .11334 Mtetra
.002 .348 .825 r
.12443 .34432 .12554 .34568 .12711 .3451 .12582 .34514 Mtetra
.819 .383 .207 r
.12582 .34514 .12711 .3451 .12862 .34495 .12704 .34738 Mtetra
.865 .566 .48 r
.12704 .34738 .12862 .34495 .13004 .34562 .12733 .35708 Mtetra
.922 .664 .531 r
.12733 .35708 .13004 .34562 .13067 .35266 .10463 .55147 Mtetra
.526 .292 .503 r
.10463 .55147 .13067 .35266 .10739 .55306 .1058 .55489 Mtetra
.66 .267 .291 r
.1058 .55489 .10739 .55306 .10853 .55683 .10723 .55631 Mtetra
.21 .679 .941 r
.10723 .55631 .10853 .55683 .11011 .55703 .10883 .5564 Mtetra
.625 .836 .981 r
.10883 .5564 .11011 .55703 .11178 .55645 .1105 .55586 Mtetra
.771 .859 .915 r
.1105 .55586 .11178 .55645 .11352 .5554 .11225 .55474 Mtetra
.862 .822 .807 r
.11225 .55474 .11352 .5554 .11521 .55472 .11412 .55262 Mtetra
.831 .677 .692 r
.11412 .55262 .11521 .55472 .11696 .55364 .11616 .54907 Mtetra
.841 .624 .609 r
.11616 .54907 .11696 .55364 .1188 .5517 .11887 .53992 Mtetra
.926 .673 .536 r
.11887 .53992 .1188 .5517 .12138 .54362 .14424 .3424 Mtetra
.53 .301 .512 r
.14424 .3424 .12138 .54362 .1471 .3417 .14628 .338 Mtetra
.724 .56 .667 r
.14628 .338 .1471 .3417 .14916 .33709 .14808 .33563 Mtetra
.697 .687 .836 r
.14808 .33563 .14916 .33709 .15082 .3359 .14969 .3348 Mtetra
.596 .718 .929 r
.14969 .3348 .15082 .3359 .15239 .33546 .15124 .33447 Mtetra
.503 .705 .961 r
.15124 .33447 .15239 .33546 .15392 .33538 .15278 .33435 Mtetra
.638 .745 .926 r
.15278 .33435 .15392 .33538 .15549 .33489 .15435 .33387 Mtetra
.669 .753 .913 r
.15435 .33387 .15549 .33489 .15708 .33432 .15594 .33326 Mtetra
.684 .75 .901 r
.15594 .33326 .15708 .33432 .15867 .33372 .15754 .33259 Mtetra
.769 .752 .837 r
.15754 .33259 .15867 .33372 .16032 .3326 .15921 .33135 Mtetra
.726 .726 .85 r
.15921 .33135 .16032 .3326 .16194 .33175 .16084 .3304 Mtetra
.584 .665 .894 r
.16084 .3304 .16194 .33175 .16349 .33156 .1624 .33012 Mtetra
.902 .495 .1 r
.1624 .33012 .16349 .33156 .16461 .33506 .16353 .33354 Mtetra
.942 .684 .517 r
.16353 .33354 .16461 .33506 .14302 .53853 .1418 .53756 Mtetra
.938 .597 .354 r
.1418 .53756 .14302 .53853 .14394 .54484 .14269 .54409 Mtetra
.024 .511 .876 r
.14269 .54409 .14394 .54484 .14552 .54535 .14427 .54453 Mtetra
.699 .815 .937 r
.14427 .54453 .14552 .54535 .14723 .54467 .146 .54376 Mtetra
.776 .803 .875 r
.146 .54376 .14723 .54467 .14899 .54353 .14777 .54252 Mtetra
.576 .746 .957 r
.14777 .54252 .14899 .54353 .15069 .54298 .14945 .54219 Mtetra
.517 .773 .99 r
.14945 .54219 .15069 .54298 .15238 .54255 .15111 .54195 Mtetra
.637 .849 .981 r
.15111 .54195 .15238 .54255 .15408 .54202 .15282 .54135 Mtetra
.846 .835 .835 r
.15282 .54135 .15408 .54202 .15578 .54145 .15467 .53952 Mtetra
.832 .689 .705 r
.15467 .53952 .15578 .54145 .15753 .54053 .15666 .53629 Mtetra
.828 .619 .62 r
.15666 .53629 .15753 .54053 .15935 .53885 .15908 .52924 Mtetra
.933 .677 .527 r
.15908 .52924 .15935 .53885 .16163 .53304 .18235 .33018 Mtetra
.532 .302 .512 r
.18235 .33018 .16163 .53304 .1852 .32956 .18445 .32499 Mtetra
.711 .533 .646 r
.18445 .32499 .1852 .32956 .18737 .32378 .18628 .32236 Mtetra
.744 .708 .817 r
.18628 .32236 .18737 .32378 .18909 .32212 .18795 .32118 Mtetra
.669 .775 .929 r
.18795 .32118 .18909 .32212 .1907 .32149 .18956 .32057 Mtetra
.61 .763 .952 r
.18956 .32057 .1907 .32149 .19228 .32123 .19115 .32016 Mtetra
.754 .764 .861 r
.19115 .32016 .19228 .32123 .19393 .32027 .19282 .31907 Mtetra
.736 .74 .855 r
.19282 .31907 .19393 .32027 .19557 .31936 .19447 .31807 Mtetra
.613 .689 .897 r
.19447 .31807 .19557 .31936 .19715 .31906 .19606 .31767 Mtetra
.796 .348 0 r
.19606 .31767 .19715 .31906 .19842 .32177 .19735 .3202 Mtetra
.946 .685 .509 r
.19735 .3202 .19842 .32177 .17905 .52424 .17798 .522 Mtetra
.968 .651 .353 r
.17798 .522 .17905 .52424 .17986 .53254 .17866 .53143 Mtetra
.516 .003 0 r
.17866 .53143 .17986 .53254 .18138 .53395 .18017 .53291 Mtetra
.546 .73 .96 r
.18017 .53291 .18138 .53395 .18307 .53369 .18186 .53266 Mtetra
.78 .786 .858 r
.18186 .53266 .18307 .53369 .18487 .53236 .18366 .53134 Mtetra
.9 .758 .694 r
.18366 .53134 .18487 .53236 .18696 .52818 .18575 .52715 Mtetra
.945 .688 .517 r
.18575 .52715 .18696 .52818 .209 .32517 .20787 .32414 Mtetra
.931 .721 .597 r
.20787 .32414 .209 .32517 .21155 .31526 .21044 .31417 Mtetra
.842 .762 .775 r
.21044 .31417 .21155 .31526 .21333 .31313 .21222 .31203 Mtetra
.68 .746 .901 r
.21222 .31203 .21333 .31313 .21496 .31246 .21385 .31136 Mtetra
.547 .702 .942 r
.21385 .31136 .21496 .31246 .21654 .31226 .21543 .31115 Mtetra
.703 .75 .888 r
.21543 .31115 .21654 .31226 .21819 .31148 .21708 .31036 Mtetra
.719 .753 .879 r
.21708 .31036 .21819 .31148 .21984 .31061 .21873 .30949 Mtetra
.579 .712 .934 r
.21873 .30949 .21984 .31061 .22144 .31032 .22033 .3092 Mtetra
.806 .337 0 r
.22033 .3092 .22144 .31032 .22278 .31274 .22167 .31161 Mtetra
.948 .684 .504 r
.22167 .31161 .22278 .31274 .20499 .51467 .20382 .51346 Mtetra
.951 .627 .378 r
.20382 .51346 .20499 .51467 .2058 .52378 .20461 .5227 Mtetra
.578 .062 0 r
.20461 .5227 .2058 .52378 .20733 .5254 .20614 .52432 Mtetra
.528 .718 .96 r
.20614 .52432 .20733 .5254 .20904 .52521 .20784 .52413 Mtetra
.769 .78 .862 r
.20784 .52413 .20904 .52521 .21084 .52396 .20965 .52287 Mtetra
.895 .76 .704 r
.20965 .52287 .21084 .52396 .21289 .52013 .2117 .519 Mtetra
.948 .689 .511 r
.2117 .519 .21289 .52013 .23323 .31921 .23218 .31741 Mtetra
.922 .699 .583 r
.23218 .31741 .23323 .31921 .23598 .30662 .23488 .30543 Mtetra
.849 .752 .756 r
.23488 .30543 .23598 .30662 .23778 .30421 .23668 .30302 Mtetra
.682 .733 .889 r
.23668 .30302 .23778 .30421 .23943 .30353 .23833 .30233 Mtetra
.55 .685 .928 r
.23833 .30233 .23943 .30353 .24103 .30336 .23994 .30213 Mtetra
.637 .712 .901 r
.23994 .30213 .24103 .30336 .24265 .30298 .24157 .30164 Mtetra
.682 .706 .866 r
.24157 .30164 .24265 .30298 .24429 .30236 .24322 .30092 Mtetra
.625 .671 .874 r
.24322 .30092 .24429 .30236 .24593 .30181 .24485 .30047 Mtetra
.216 .487 .896 r
.24485 .30047 .24593 .30181 .24755 .30151 .24639 .30102 Mtetra
.798 .304 0 r
.24639 .30102 .24755 .30151 .24915 .30143 .2478 .30309 Mtetra
.839 .495 .402 r
.2478 .30309 .24915 .30143 .25074 .3014 .24894 .30826 Mtetra
.809 .513 .489 r
.24894 .30826 .25074 .3014 .2524 .30071 .24953 .31979 Mtetra
.296 .075 .399 r
.24953 .31979 .2524 .30071 .25408 .2997 .25173 .31299 Mtetra
.445 .188 .43 r
.25173 .31299 .25408 .2997 .25572 .29927 .25348 .31127 Mtetra
.934 .665 .506 r
.25348 .31127 .25572 .29927 .2571 .30176 .23857 .50315 Mtetra
.531 .297 .504 r
.23857 .50315 .2571 .30176 .2414 .50486 .23975 .50927 Mtetra
.662 .332 .404 r
.23975 .50927 .2414 .50486 .24252 .5118 .24126 .51173 Mtetra
.456 0 0 r
.24126 .51173 .24252 .5118 .24412 .51322 .24291 .51245 Mtetra
.535 .791 .992 r
.24291 .51245 .24412 .51322 .24586 .51287 .24465 .51214 Mtetra
.718 .845 .942 r
.24465 .51214 .24586 .51287 .24765 .51196 .24644 .51125 Mtetra
.848 .842 .838 r
.24644 .51125 .24765 .51196 .24947 .51081 .24832 .5094 Mtetra
.867 .74 .72 r
.24832 .5094 .24947 .51081 .25129 .50957 .25031 .50613 Mtetra
.834 .636 .636 r
.25031 .50613 .25129 .50957 .25312 .50824 .25249 .5005 Mtetra
.763 .541 .597 r
.25249 .5005 .25312 .50824 .2549 .50754 .25479 .49338 Mtetra
.508 .318 .558 r
.25479 .49338 .2549 .50754 .25664 .50733 .25646 .49393 Mtetra
.522 .331 .563 r
.25646 .49393 .25664 .50733 .25842 .50658 .25817 .49405 Mtetra
.939 .674 .509 r
.25817 .49405 .25842 .50658 .26042 .50315 .27537 .30035 Mtetra
.539 .308 .513 r
.27537 .30035 .26042 .50315 .27822 .29977 .27767 .29174 Mtetra
.678 .473 .6 r
.27767 .29174 .27822 .29977 .28058 .29033 .27957 .28817 Mtetra
.751 .644 .742 r
.27957 .28817 .28058 .29033 .2824 .28773 .28132 .28647 Mtetra
.653 .714 .893 r
.28132 .28647 .2824 .28773 .28408 .28697 .28299 .28589 Mtetra
.561 .717 .946 r
.28299 .28589 .28408 .28697 .28572 .28669 .28463 .28563 Mtetra
.58 .728 .944 r
.28463 .28563 .28572 .28669 .28737 .2864 .28628 .28531 Mtetra
.655 .748 .918 r
.28628 .28531 .28737 .2864 .28903 .28583 .28794 .28474 Mtetra
.669 .75 .911 r
.28794 .28474 .28903 .28583 .2907 .28524 .28962 .2841 Mtetra
.71 .752 .885 r
.28962 .2841 .2907 .28524 .29238 .28456 .29131 .28326 Mtetra
.724 .728 .854 r
.29131 .28326 .29238 .28456 .29406 .28381 .29301 .28228 Mtetra
.673 .679 .848 r
.29301 .28228 .29406 .28381 .29574 .28313 .29469 .28157 Mtetra
.458 .579 .888 r
.29469 .28157 .29574 .28313 .2974 .28271 .29631 .28171 Mtetra
.598 .086 0 r
.29631 .28171 .2974 .28271 .29904 .28265 .29782 .28338 Mtetra
.846 .46 .316 r
.29782 .28338 .29904 .28265 .30067 .28267 .29918 .28723 Mtetra
.808 .494 .458 r
.29918 .28723 .30067 .28267 .30234 .28224 .30024 .29518 Mtetra
.422 .169 .422 r
.30024 .29518 .30234 .28224 .30405 .28123 .30205 .29296 Mtetra
.428 .169 .418 r
.30205 .29296 .30405 .28123 .30572 .28069 .30383 .29108 Mtetra
.941 .668 .493 r
.30383 .29108 .30572 .28069 .30726 .2822 .29201 .48206 Mtetra
.536 .301 .505 r
.29201 .48206 .30726 .2822 .29494 .48284 .29315 .49083 Mtetra
.63 .331 .445 r
.29315 .49083 .29494 .48284 .29595 .49352 .2947 .49374 Mtetra
.571 .015 0 r
.2947 .49374 .29595 .49352 .29757 .49556 .29639 .49469 Mtetra
.573 .785 .979 r
.29639 .49469 .29757 .49556 .29935 .49527 .29818 .49431 Mtetra
.682 .795 .935 r
.29818 .49431 .29935 .49527 .30117 .49444 .29999 .49356 Mtetra
.668 .812 .952 r
.29999 .49356 .30117 .49444 .30299 .49356 .3018 .49287 Mtetra
.552 .817 .995 r
.3018 .49287 .30299 .49356 .30479 .49303 .3036 .49248 Mtetra
.635 .871 .986 r
.3036 .49248 .30479 .49303 .3066 .49241 .30541 .49182 Mtetra
.811 .881 .896 r
.30541 .49182 .3066 .49241 .30842 .49155 .30727 .49039 Mtetra
.88 .772 .738 r
.30727 .49039 .30842 .49155 .31027 .49033 .30924 .48734 Mtetra
.842 .653 .647 r
.30924 .48734 .31027 .49033 .31212 .489 .31133 .48226 Mtetra
.803 .576 .594 r
.31133 .48226 .31212 .489 .31395 .48807 .31365 .47377 Mtetra
.521 .328 .56 r
.31365 .47377 .31395 .48807 .31574 .48791 .3154 .47392 Mtetra
.507 .318 .559 r
.3154 .47392 .31574 .48791 .31755 .48729 .31713 .47451 Mtetra
.944 .674 .496 r
.31713 .47451 .31755 .48729 .31948 .48476 .33071 .28553 Mtetra
.55 .317 .515 r
.33071 .28553 .31948 .48476 .33324 .29017 .33321 .27217 Mtetra
.611 .389 .556 r
.33321 .27217 .33324 .29017 .33611 .27063 .33512 .26815 Mtetra
.765 .632 .714 r
.33512 .26815 .33611 .27063 .33797 .26733 .33692 .266 Mtetra
.698 .721 .867 r
.33692 .266 .33797 .26733 .33969 .26639 .33863 .26517 Mtetra
.626 .716 .912 r
.33863 .26517 .33969 .26639 .34138 .26599 .34033 .2647 Mtetra
.589 .691 .912 r
.34033 .2647 .34138 .26599 .34306 .26574 .34201 .26438 Mtetra
.615 .687 .894 r
.34201 .26438 .34306 .26574 .34476 .26522 .34371 .26395 Mtetra
.616 .703 .907 r
.34371 .26395 .34476 .26522 .34646 .26471 .3454 .26352 Mtetra
.643 .728 .911 r
.3454 .26352 .34646 .26471 .34817 .26415 .34711 .26298 Mtetra
.692 .746 .893 r
.34711 .26298 .34817 .26415 .34988 .2635 .34883 .26221 Mtetra
.696 .727 .874 r
.34883 .26221 .34988 .2635 .35159 .26283 .35055 .2614 Mtetra
.696 .706 .855 r
.35055 .2614 .35159 .26283 .35331 .26212 .35227 .26056 Mtetra
.696 .687 .837 r
.35227 .26056 .35331 .26212 .35502 .26139 .354 .25968 Mtetra
.65 .65 .836 r
.354 .25968 .35502 .26139 .35674 .26074 .35571 .25905 Mtetra
.535 .6 .866 r
.35571 .25905 .35674 .26074 .35845 .2602 .3574 .25896 Mtetra
0 .242 .746 r
.3574 .25896 .35845 .2602 .36016 .25974 .35902 .26012 Mtetra
.834 .408 .223 r
.35902 .26012 .36016 .25974 .36184 .25979 .36054 .26322 Mtetra
.956 .678 .47 r
.36054 .26322 .36184 .25979 .36344 .26127 .35172 .4625 Mtetra
.537 .301 .505 r
.35172 .4625 .36344 .26127 .35485 .45985 .35304 .47161 Mtetra
.593 .311 .458 r
.35304 .47161 .35485 .45985 .35594 .47352 .35471 .47425 Mtetra
.611 .108 .032 r
.35471 .47425 .35594 .47352 .35762 .47609 .35647 .47533 Mtetra
.344 .708 .984 r
.35647 .47533 .35762 .47609 .35943 .47605 .35828 .47536 Mtetra
.606 .839 .988 r
.35828 .47536 .35943 .47605 .36128 .47536 .36012 .47481 Mtetra
.783 .899 .924 r
.36012 .47481 .36128 .47536 .36315 .47427 .362 .47355 Mtetra
.902 .838 .772 r
.362 .47355 .36315 .47427 .36503 .47304 .36395 .4708 Mtetra
.862 .692 .669 r
.36395 .4708 .36503 .47304 .36691 .47164 .36598 .46638 Mtetra
.83 .606 .599 r
.36598 .46638 .36691 .47164 .36879 .47038 .36818 .45828 Mtetra
.57 .373 .575 r
.36818 .45828 .36879 .47038 .37062 .47015 .37006 .45702 Mtetra
.52 .331 .565 r
.37006 .45702 .37062 .47015 .37247 .46957 .37186 .45722 Mtetra
.675 .452 .576 r
.37186 .45722 .37247 .46957 .37437 .46775 .37393 .45176 Mtetra
.946 .671 .485 r
.37393 .45176 .37437 .46775 .37668 .45696 .38474 .25422 Mtetra
.53 .3 .511 r
.38474 .25422 .37668 .45696 .38762 .25265 .38666 .24964 Mtetra
.762 .607 .686 r
.38666 .24964 .38762 .25265 .38951 .24854 .38848 .2471 Mtetra
.711 .713 .85 r
.38848 .2471 .38951 .24854 .39127 .24744 .39023 .24616 Mtetra
.644 .716 .9 r
.39023 .24616 .39127 .24744 .393 .24692 .39196 .2456 Mtetra
.594 .689 .909 r
.39196 .2456 .393 .24692 .39472 .24668 .39369 .24525 Mtetra
.618 .68 .886 r
.39369 .24525 .39472 .24668 .39646 .24614 .39542 .2448 Mtetra
.617 .696 .901 r
.39542 .2448 .39646 .24614 .39819 .2456 .39715 .24436 Mtetra
.633 .72 .91 r
.39715 .24436 .39819 .2456 .39993 .24504 .39889 .24385 Mtetra
.69 .748 .896 r
.39889 .24385 .39993 .24504 .40167 .24437 .40064 .24308 Mtetra
.696 .733 .879 r
.40064 .24308 .40167 .24437 .40342 .24367 .40239 .24227 Mtetra
.69 .711 .865 r
.40239 .24227 .40342 .24367 .40517 .24298 .40414 .24146 Mtetra
.663 .684 .86 r
.40414 .24146 .40517 .24298 .40691 .24234 .40589 .24078 Mtetra
.656 .677 .857 r
.40589 .24078 .40691 .24234 .40866 .24171 .40764 .24014 Mtetra
.653 .673 .857 r
.40764 .24014 .40866 .24171 .41041 .24108 .40938 .23951 Mtetra
.656 .674 .855 r
.40938 .23951 .41041 .24108 .41216 .24045 .41113 .23886 Mtetra
.655 .671 .853 r
.41113 .23886 .41216 .24045 .41391 .23981 .41289 .23821 Mtetra
.656 .67 .852 r
.41289 .23821 .41391 .23981 .41566 .23917 .41464 .23756 Mtetra
.692 .684 .837 r
.41464 .23756 .41566 .23917 .41741 .23844 .4164 .23668 Mtetra
.658 .651 .832 r
.4164 .23668 .41741 .23844 .41917 .23776 .41815 .23599 Mtetra
.591 .619 .848 r
.41815 .23599 .41917 .23776 .42092 .2372 .4199 .23566 Mtetra
0 .275 .78 r
.4199 .23566 .42092 .2372 .42266 .23708 .42159 .2369 Mtetra
.827 .355 .073 r
.42159 .2369 .42266 .23708 .42439 .23709 .42324 .23968 Mtetra
.876 .541 .413 r
.42324 .23968 .42439 .23709 .42613 .23709 .42467 .24915 Mtetra
.949 .664 .462 r
.42467 .24915 .42613 .23709 .42789 .23653 .42053 .43291 Mtetra
.506 .275 .499 r
.42053 .43291 .42789 .23653 .42965 .23579 .42257 .42692 Mtetra
0 0 .278 r
.42257 .42692 .42965 .23579 .43142 .23499 .42999 .2469 Mtetra
.314 .079 .389 r
.42999 .2469 .43142 .23499 .4332 .2338 .43187 .24262 Mtetra
.438 .166 .401 r
.43187 .24262 .4332 .2338 .43497 .23303 .43366 .24137 Mtetra
.646 .345 .447 r
.43366 .24137 .43497 .23303 .43672 .2331 .43531 .24498 Mtetra
.952 .665 .458 r
.43531 .24498 .43672 .2331 .43828 .23949 .43139 .44314 Mtetra
.527 .292 .503 r
.43139 .44314 .43828 .23949 .43432 .44584 .43315 .44732 Mtetra
.692 .26 .217 r
.43315 .44732 .43432 .44584 .43609 .44992 .43497 .4492 Mtetra
.323 .71 .981 r
.43497 .4492 .43609 .44992 .43796 .45013 .43685 .44924 Mtetra
.589 .796 .978 r
.43685 .44924 .43796 .45013 .43986 .44954 .43875 .44877 Mtetra
.663 .847 .97 r
.43875 .44877 .43986 .44954 .44176 .44856 .44065 .44804 Mtetra
.556 .862 .997 r
.44065 .44804 .44176 .44856 .44366 .44794 .44255 .44751 Mtetra
.618 .902 .986 r
.44255 .44751 .44366 .44794 .44557 .44727 .44445 .44679 Mtetra
.741 .921 .952 r
.44445 .44679 .44557 .44727 .44747 .44646 .44637 .44569 Mtetra
.876 .857 .819 r
.44637 .44569 .44747 .44646 .44938 .4457 .44831 .44349 Mtetra
.848 .695 .692 r
.44831 .44349 .44938 .4457 .4513 .44455 .45028 .43991 Mtetra
.853 .626 .594 r
.45028 .43991 .4513 .44455 .45323 .44256 .45236 .43157 Mtetra
.959 .678 .458 r
.45236 .43157 .45323 .44256 .45529 .4349 .45867 .22764 Mtetra
.53 .3 .511 r
.45867 .22764 .45529 .4349 .46151 .22683 .46055 .22277 Mtetra
.727 .555 .658 r
.46055 .22277 .46151 .22683 .46338 .2218 .46237 .22016 Mtetra
.727 .696 .82 r
.46237 .22016 .46338 .2218 .46518 .22033 .46417 .21902 Mtetra
.654 .719 .896 r
.46417 .21902 .46518 .22033 .46696 .21971 .46595 .2184 Mtetra
.592 .694 .913 r
.46595 .2184 .46696 .21971 .46874 .21947 .46773 .21803 Mtetra
.612 .682 .891 r
.46773 .21803 .46874 .21947 .47053 .21898 .46952 .2176 Mtetra
.616 .693 .899 r
.46952 .2176 .47053 .21898 .47231 .21843 .4713 .21714 Mtetra
.627 .714 .909 r
.4713 .21714 .47231 .21843 .4741 .21787 .47309 .21664 Mtetra
.681 .745 .899 r
.47309 .21664 .4741 .21787 .47589 .21721 .47488 .2159 Mtetra
.697 .735 .88 r
.47488 .2159 .47589 .21721 .47768 .21651 .47668 .21506 Mtetra
.694 .713 .863 r
.47668 .21506 .47768 .21651 .47948 .21578 .47848 .21421 Mtetra
.703 .698 .842 r
.47848 .21421 .47948 .21578 .48127 .21501 .48028 .21327 Mtetra
.672 .663 .833 r
.48028 .21327 .48127 .21501 .48307 .21428 .48207 .21249 Mtetra
.611 .629 .844 r
.48207 .21249 .48307 .21428 .48487 .21367 .48387 .21204 Mtetra
.309 .491 .875 r
.48387 .21204 .48487 .21367 .48666 .21308 .48565 .21262 Mtetra
.689 .151 0 r
.48565 .21262 .48666 .21308 .48846 .21283 .48742 .21453 Mtetra
.866 .498 .351 r
.48742 .21453 .48846 .21283 .49025 .2133 .48914 .22098 Mtetra
.962 .67 .435 r
.48914 .22098 .49025 .2133 .49199 .21835 .48867 .42441 Mtetra
.526 .292 .502 r
.48867 .42441 .49199 .21835 .49166 .42608 .49055 .42857 Mtetra
.641 .245 .278 r
.49055 .42857 .49166 .42608 .49354 .43069 .49246 .43021 Mtetra
.086 .605 .882 r
.49246 .43021 .49354 .43069 .49547 .43131 .49439 .43046 Mtetra
.593 .809 .982 r
.49439 .43046 .49547 .43131 .49741 .43076 .49633 .42995 Mtetra
.743 .861 .934 r
.49633 .42995 .49741 .43076 .49935 .42969 .49827 .42886 Mtetra
.86 .86 .839 r
.49827 .42886 .49935 .42969 .50129 .42884 .50022 .42687 Mtetra
.853 .716 .71 r
.50022 .42687 .50129 .42884 .50324 .42777 .50218 .42359 Mtetra
.845 .628 .609 r
.50218 .42359 .50324 .42777 .50519 .42595 .50417 .41688 Mtetra
.965 .679 .44 r
.50417 .41688 .50519 .42595 .50716 .42009 .50729 .21121 Mtetra
.532 .301 .511 r
.50729 .21121 .50716 .42009 .51012 .21066 .50914 .20547 Mtetra
.704 .518 .633 r
.50914 .20547 .51012 .21066 .51196 .20456 .51097 .20264 Mtetra
.721 .665 .794 r
.51097 .20264 .51196 .20456 .51378 .20273 .51279 .20142 Mtetra
.626 .714 .909 r
.51279 .20142 .51378 .20273 .51559 .20208 .5146 .20092 Mtetra
.545 .707 .946 r
.5146 .20092 .51559 .20208 .51741 .20185 .51642 .20068 Mtetra
.617 .736 .931 r
.51642 .20068 .51741 .20185 .51923 .20138 .51824 .2002 Mtetra
.664 .752 .916 r
.51824 .2002 .51923 .20138 .52105 .20074 .52006 .19954 Mtetra
.677 .753 .908 r
.52006 .19954 .52105 .20074 .52287 .20007 .52188 .1988 Mtetra
.759 .766 .859 r
.52188 .1988 .52287 .20007 .5247 .19896 .52371 .19758 Mtetra
.74 .742 .854 r
.52371 .19758 .5247 .19896 .52652 .19794 .52553 .19645 Mtetra
.625 .682 .883 r
.52553 .19645 .52652 .19794 .52835 .19753 .52736 .19594 Mtetra
0 0 .519 r
.52736 .19594 .52835 .19753 .53018 .19998 .52919 .19832 Mtetra
.974 .681 .403 r
.52919 .19832 .53018 .19998 .5325 .40756 .53144 .4062 Mtetra
.941 .577 .204 r
.53144 .4062 .5325 .40756 .53448 .41659 .53343 .41567 Mtetra
0 .284 .738 r
.53343 .41567 .53448 .41659 .53646 .41777 .5354 .41682 Mtetra
.653 .812 .96 r
.5354 .41682 .53646 .41777 .53842 .41716 .53737 .41612 Mtetra
.762 .823 .9 r
.53737 .41612 .53842 .41716 .54039 .41602 .53934 .41488 Mtetra
.593 .752 .954 r
.53934 .41488 .54039 .41602 .54236 .41552 .54131 .41444 Mtetra
.496 .721 .972 r
.54131 .41444 .54236 .41552 .54433 .41523 .54328 .41428 Mtetra
.68 .821 .951 r
.54328 .41428 .54433 .41523 .5463 .41431 .54525 .41347 Mtetra
.939 .833 .713 r
.54525 .41347 .5463 .41431 .54825 .41051 .54721 .40977 Mtetra
.975 .687 .412 r
.54721 .40977 .54825 .41051 .54861 .20337 .54763 .20286 Mtetra
.983 .746 .501 r
.54763 .20286 .54861 .20337 .55036 .19106 .54938 .18962 Mtetra
.856 .76 .756 r
.54938 .18962 .55036 .19106 .55218 .18857 .55121 .18715 Mtetra
.645 .703 .889 r
.55121 .18715 .55218 .18857 .55403 .18788 .55305 .18655 Mtetra
.495 .652 .929 r
.55305 .18655 .55403 .18788 .55588 .18771 .5549 .18651 Mtetra
.553 .705 .941 r
.5549 .18651 .55588 .18771 .55772 .18738 .55675 .18625 Mtetra
.647 .758 .93 r
.55675 .18625 .55772 .18738 .55957 .18678 .5586 .18564 Mtetra
.658 .761 .926 r
.5586 .18564 .55957 .18678 .56142 .18616 .56045 .18499 Mtetra
.734 .78 .89 r
.56045 .18499 .56142 .18616 .56327 .18517 .56229 .18395 Mtetra
.736 .773 .883 r
.56229 .18395 .56327 .18517 .56511 .18414 .56414 .1829 Mtetra
.612 .723 .925 r
.56414 .1829 .56511 .18414 .56697 .18369 .566 .18243 Mtetra
0 0 .51 r
.566 .18243 .56697 .18369 .56886 .18575 .56789 .18461 Mtetra
.975 .677 .388 r
.56789 .18461 .56886 .18575 .57387 .39245 .57286 .39273 Mtetra
.926 .55 .274 r
.57286 .39273 .57387 .39245 .57603 .40261 .575 .40182 Mtetra
0 .181 .63 r
.575 .40182 .57603 .40261 .57806 .4041 .57703 .40318 Mtetra
.659 .826 .963 r
.57703 .40318 .57806 .4041 .58006 .40346 .57902 .40244 Mtetra
.781 .835 .894 r
.57902 .40244 .58006 .40346 .58204 .40222 .58101 .40108 Mtetra
.758 .809 .893 r
.58101 .40108 .58204 .40222 .58403 .40105 .583 .39984 Mtetra
.689 .776 .918 r
.583 .39984 .58403 .40105 .58603 .4002 .585 .39898 Mtetra
.679 .772 .921 r
.585 .39898 .58603 .4002 .58803 .39938 .587 .39818 Mtetra
.672 .773 .926 r
.587 .39818 .58803 .39938 .59003 .39861 .589 .39741 Mtetra
.663 .77 .929 r
.589 .39741 .59003 .39861 .59203 .3979 .591 .39668 Mtetra
.646 .76 .932 r
.591 .39668 .59203 .3979 .59404 .39724 .59301 .39602 Mtetra
.611 .748 .942 r
.59301 .39602 .59404 .39724 .59605 .39665 .59502 .39551 Mtetra
.575 .748 .959 r
.59502 .39551 .59605 .39665 .59806 .39612 .59704 .39511 Mtetra
.56 .771 .977 r
.59704 .39511 .59806 .39612 .60007 .3956 .59906 .39473 Mtetra
.573 .804 .987 r
.59906 .39473 .60007 .3956 .60209 .39508 .60107 .39426 Mtetra
.599 .827 .987 r
.60107 .39426 .60209 .39508 .6041 .39453 .60309 .39369 Mtetra
.611 .828 .983 r
.60309 .39369 .6041 .39453 .60612 .39397 .60511 .3931 Mtetra
.619 .823 .979 r
.60511 .3931 .60612 .39397 .60814 .39339 .60713 .39248 Mtetra
.622 .817 .975 r
.60713 .39248 .60814 .39339 .61016 .39279 .60915 .39187 Mtetra
.626 .816 .973 r
.60915 .39187 .61016 .39279 .61218 .39217 .61117 .39124 Mtetra
.63 .815 .971 r
.61117 .39124 .61218 .39217 .6142 .39154 .61319 .3906 Mtetra
.633 .815 .97 r
.61319 .3906 .6142 .39154 .61623 .3909 .61522 .38995 Mtetra
.635 .815 .969 r
.61522 .38995 .61623 .3909 .61825 .39024 .61724 .3893 Mtetra
.637 .816 .969 r
.61724 .3893 .61825 .39024 .62027 .38957 .61927 .38863 Mtetra
.639 .817 .969 r
.61927 .38863 .62027 .38957 .6223 .38889 .6213 .38796 Mtetra
.641 .819 .969 r
.6213 .38796 .6223 .38889 .62433 .3882 .62332 .38728 Mtetra
.64 .822 .97 r
.62332 .38728 .62433 .3882 .62636 .3875 .62535 .3866 Mtetra
.638 .827 .973 r
.62535 .3866 .62636 .3875 .62839 .38678 .62739 .38592 Mtetra
.643 .836 .975 r
.62739 .38592 .62839 .38678 .63042 .38605 .62942 .38521 Mtetra
.665 .848 .97 r
.62942 .38521 .63042 .38605 .63245 .3853 .63145 .38442 Mtetra
.691 .848 .958 r
.63145 .38442 .63245 .3853 .63448 .38453 .63348 .38352 Mtetra
.685 .822 .948 r
.63348 .38352 .63448 .38453 .63651 .38378 .63551 .38267 Mtetra
.642 .784 .95 r
.63551 .38267 .63651 .38378 .63855 .38313 .63755 .38201 Mtetra
.572 .753 .963 r
.63755 .38201 .63855 .38313 .6406 .38261 .6396 .38161 Mtetra
.547 .768 .98 r
.6396 .38161 .6406 .38261 .64265 .38212 .64165 .38126 Mtetra
.471 .763 .994 r
.64165 .38126 .64265 .38212 .6447 .38183 .64372 .38105 Mtetra
.422 .755 .995 r
.64372 .38105 .6447 .38183 .64677 .38171 .64578 .38091 Mtetra
.631 .847 .982 r
.64578 .38091 .64677 .38171 .64881 .38103 .64783 .38022 Mtetra
.892 .882 .817 r
.64783 .38022 .64881 .38103 .6508 .37864 .64981 .37788 Mtetra
.986 .781 .543 r
.64981 .37788 .6508 .37864 .6525 .36939 .65155 .36942 Mtetra
.978 .681 .367 r
.65155 .36942 .6525 .36939 .64599 .15817 .64507 .15717 Mtetra
.954 .811 .664 r
.64507 .15717 .64599 .15817 .64776 .15411 .64683 .15288 Mtetra
.725 .776 .893 r
.64683 .15288 .64776 .15411 .64965 .15313 .64872 .15187 Mtetra
.578 .712 .934 r
.64872 .15187 .64965 .15313 .65158 .15278 .65065 .15152 Mtetra
.547 .696 .938 r
.65065 .15152 .65158 .15278 .65351 .15253 .65258 .15128 Mtetra
.664 .749 .913 r
.65258 .15128 .65351 .15253 .65542 .15183 .65449 .15057 Mtetra
.671 .751 .91 r
.65449 .15057 .65542 .15183 .65733 .1511 .6564 .14983 Mtetra
.697 .759 .9 r
.6564 .14983 .65733 .1511 .65923 .15019 .65831 .14896 Mtetra
.732 .78 .891 r
.65831 .14896 .65923 .15019 .66113 .14901 .66021 .14791 Mtetra
.69 .79 .926 r
.66021 .14791 .66113 .14901 .66304 .14824 .66212 .14709 Mtetra
.538 .714 .954 r
.66212 .14709 .66304 .14824 .66501 .14864 .66406 .14684 Mtetra
.221 .413 .84 r
.66406 .14684 .66501 .14864 .66717 .15309 .66606 .14783 Mtetra
.264 .225 .626 r
.66606 .14783 .66717 .15309 .67929 .36266 .66815 .15053 Mtetra
0 0 .387 r
.66815 .15053 .67929 .36266 .68163 .36759 .67979 .34887 Mtetra
.134 .047 .483 r
.67979 .34887 .68163 .36759 .68376 .36812 .68255 .36218 Mtetra
.285 .233 .622 r
.68255 .36218 .68376 .36812 .68586 .36787 .68479 .36504 Mtetra
.347 .398 .772 r
.68479 .36504 .68586 .36787 .68794 .36742 .68696 .36607 Mtetra
.503 .678 .944 r
.68696 .36607 .68794 .36742 .69005 .36724 .68906 .36596 Mtetra
.663 .763 .925 r
.68906 .36596 .69005 .36724 .69212 .36652 .69114 .3652 Mtetra
.787 .798 .861 r
.69114 .3652 .69212 .36652 .69413 .36456 .69317 .36367 Mtetra
.925 .866 .763 r
.69317 .36367 .69413 .36456 .69591 .35816 .69513 .36071 Mtetra
0 0 0 r
.69513 .36071 .69591 .35816 .6865 .14659 .69695 .3552 Mtetra
0 0 .373 r
.69695 .3552 .6865 .14659 .68816 .14071 .68778 .14916 Mtetra
0 0 .286 r
.68778 .14916 .68816 .14071 .69004 .13904 .68932 .14132 Mtetra
0 0 0 r
.68932 .14132 .69004 .13904 .69196 .13807 .69112 .13804 Mtetra
.844 .998 .816 r
.69112 .13804 .69196 .13807 .6939 .13742 .69299 .13609 Mtetra
.696 .751 .895 r
.69299 .13609 .6939 .13742 .69584 .13673 .69492 .13522 Mtetra
.63 .692 .889 r
.69492 .13522 .69584 .13673 .69779 .13611 .69687 .13465 Mtetra
.614 .694 .901 r
.69687 .13465 .69779 .13611 .69973 .13548 .69882 .13417 Mtetra
.675 .747 .905 r
.69882 .13417 .69973 .13548 .70167 .13468 .70076 .1334 Mtetra
.687 .757 .905 r
.70076 .1334 .70167 .13468 .70361 .13385 .7027 .13257 Mtetra
.718 .77 .894 r
.7027 .13257 .70361 .13385 .70554 .13289 .70463 .13158 Mtetra
.788 .786 .851 r
.70463 .13158 .70554 .13289 .70744 .13153 .70653 .1301 Mtetra
.716 .744 .873 r
.70653 .1301 .70744 .13153 .70938 .13062 .70846 .12909 Mtetra
.493 .621 .906 r
.70846 .12909 .70938 .13062 .71138 .13072 .71045 .12909 Mtetra
.679 .281 0 r
.71045 .12909 .71138 .13072 .71368 .1355 .71274 .13359 Mtetra
.973 .662 .313 r
.71274 .13359 .71368 .1355 .72938 .34799 .72841 .34645 Mtetra
.739 .324 0 r
.72841 .34645 .72938 .34799 .73185 .3528 .73089 .35156 Mtetra
.47 .684 .959 r
.73089 .35156 .73185 .3528 .734 .35274 .73304 .35151 Mtetra
.685 .786 .927 r
.73304 .35151 .734 .35274 .73609 .35188 .73514 .35064 Mtetra
.739 .803 .903 r
.73514 .35064 .73609 .35188 .73817 .35071 .73722 .34946 Mtetra
.563 .731 .953 r
.73722 .34946 .73817 .35071 .7403 .3502 .73936 .3491 Mtetra
.607 .781 .964 r
.73936 .3491 .7403 .3502 .74242 .34965 .74148 .34854 Mtetra
.703 .818 .936 r
.74148 .34854 .74242 .34965 .74454 .34902 .74358 .34758 Mtetra
.832 .794 .816 r
.74358 .34758 .74454 .34902 .74667 .34847 .74561 .34554 Mtetra
.808 .654 .691 r
.74561 .34554 .74667 .34847 .74877 .34747 .74755 .34239 Mtetra
.822 .598 .598 r
.74755 .34239 .74877 .34747 .7508 .34548 .74928 .33614 Mtetra
.973 .664 .344 r
.74928 .33614 .7508 .34548 .75242 .33786 .73651 .12796 Mtetra
.531 .3 .51 r
.73651 .12796 .75242 .33786 .73918 .1258 .73811 .12199 Mtetra
.752 .579 .662 r
.73811 .12199 .73918 .1258 .74082 .12057 .73992 .11913 Mtetra
.72 .746 .873 r
.73992 .11913 .74082 .12057 .74275 .11931 .74187 .11809 Mtetra
.637 .752 .932 r
.74187 .11809 .74275 .11931 .74473 .11872 .74385 .11748 Mtetra
.588 .726 .939 r
.74385 .11748 .74473 .11872 .74674 .11845 .74585 .11707 Mtetra
.669 .735 .899 r
.74585 .11707 .74674 .11845 .74871 .1177 .74782 .11631 Mtetra
.678 .738 .896 r
.74782 .11631 .74871 .1177 .75069 .11692 .7498 .11551 Mtetra
.689 .739 .889 r
.7498 .11551 .75069 .11692 .75266 .1161 .75176 .11464 Mtetra
.751 .756 .857 r
.75176 .11464 .75266 .1161 .75461 .11509 .7537 .11338 Mtetra
.707 .701 .842 r
.7537 .11338 .75461 .11509 .75658 .11414 .75566 .11233 Mtetra
.638 .656 .851 r
.75566 .11233 .75658 .11414 .75855 .11334 .75765 .11169 Mtetra
.882 .45 .132 r
.12326 .34346 .12443 .34432 .12582 .34514 .12441 .34623 Mtetra
.935 .679 .527 r
.12441 .34623 .12582 .34514 .12704 .34738 .1012 .5425 Mtetra
.543 .307 .507 r
.1012 .5425 .12704 .34738 .12733 .35708 .10139 .55369 Mtetra
.521 .288 .502 r
.10139 .55369 .12733 .35708 .10463 .55147 .10282 .55505 Mtetra
.516 .168 .316 r
.10282 .55505 .10463 .55147 .1058 .55489 .10438 .55537 Mtetra
.077 0 0 r
.10438 .55537 .1058 .55489 .10723 .55631 .10601 .55517 Mtetra
.465 .673 .954 r
.10601 .55517 .10723 .55631 .10883 .5564 .10762 .55516 Mtetra
.628 .714 .908 r
.10762 .55516 .10883 .5564 .1105 .55586 .10929 .55468 Mtetra
.752 .753 .853 r
.10929 .55468 .1105 .55586 .11225 .55474 .11104 .55353 Mtetra
.882 .738 .698 r
.11104 .55353 .11225 .55474 .11412 .55262 .11313 .54955 Mtetra
.912 .677 .57 r
.11313 .54955 .11412 .55262 .11616 .54907 .11751 .52684 Mtetra
.913 .659 .54 r
.11751 .52684 .11616 .54907 .11887 .53992 .14181 .33947 Mtetra
.526 .297 .51 r
.14181 .33947 .11887 .53992 .14424 .3424 .14362 .33696 Mtetra
.631 .462 .636 r
.14362 .33696 .14424 .3424 .14628 .338 .1453 .33558 Mtetra
.663 .58 .751 r
.1453 .33558 .14628 .338 .14808 .33563 .14692 .33471 Mtetra
.668 .774 .929 r
.14692 .33471 .14808 .33563 .14969 .3348 .14851 .33412 Mtetra
.601 .81 .98 r
.14851 .33412 .14969 .3348 .15124 .33447 .15007 .33369 Mtetra
.581 .784 .976 r
.15007 .33369 .15124 .33447 .15278 .33435 .15163 .33334 Mtetra
.659 .753 .92 r
.15163 .33334 .15278 .33435 .15435 .33387 .15322 .33278 Mtetra
.675 .742 .901 r
.15322 .33278 .15435 .33387 .15594 .33326 .15481 .33214 Mtetra
.684 .738 .892 r
.15481 .33214 .15594 .33326 .15754 .33259 .15641 .33146 Mtetra
.762 .75 .842 r
.15641 .33146 .15754 .33259 .15921 .33135 .15807 .33028 Mtetra
.726 .756 .876 r
.15807 .33028 .15921 .33135 .16084 .3304 .1597 .32938 Mtetra
.557 .722 .95 r
.1597 .32938 .16084 .3304 .1624 .33012 .16125 .32914 Mtetra
.903 .49 .167 r
.16125 .32914 .1624 .33012 .16353 .33354 .1624 .33244 Mtetra
.942 .683 .518 r
.1624 .33244 .16353 .33354 .1418 .53756 .14065 .53589 Mtetra
.955 .618 .326 r
.14065 .53589 .1418 .53756 .14269 .54409 .14151 .54272 Mtetra
.208 .494 .901 r
.14151 .54272 .14269 .54409 .14427 .54453 .14308 .54327 Mtetra
.67 .725 .891 r
.14308 .54327 .14427 .54453 .146 .54376 .14479 .54261 Mtetra
.749 .759 .86 r
.14479 .54261 .146 .54376 .14777 .54252 .14655 .54148 Mtetra
.534 .723 .96 r
.14655 .54148 .14777 .54252 .14945 .54219 .14822 .54127 Mtetra
.542 .751 .973 r
.14822 .54127 .14945 .54219 .15111 .54195 .14989 .54101 Mtetra
.71 .792 .916 r
.14989 .54101 .15111 .54195 .15282 .54135 .15162 .54017 Mtetra
.876 .749 .718 r
.15162 .54017 .15282 .54135 .15467 .53952 .15364 .53674 Mtetra
.897 .676 .595 r
.15364 .53674 .15467 .53952 .15666 .53629 .1566 .52482 Mtetra
.93 .674 .528 r
.1566 .52482 .15666 .53629 .15908 .52924 .18 .32609 Mtetra
.526 .297 .51 r
.18 .32609 .15908 .52924 .18235 .33018 .18186 .32321 Mtetra
.611 .43 .612 r
.18186 .32321 .18235 .33018 .18445 .32499 .18355 .32183 Mtetra
.641 .527 .71 r
.18355 .32183 .18445 .32499 .18628 .32236 .18519 .32095 Mtetra
.681 .693 .855 r
.18519 .32095 .18628 .32236 .18795 .32118 .18681 .32024 Mtetra
.667 .771 .928 r
.18681 .32024 .18795 .32118 .18956 .32057 .18842 .31963 Mtetra
.65 .769 .936 r
.18842 .31963 .18956 .32057 .19115 .32016 .19003 .31909 Mtetra
.752 .763 .862 r
.19003 .31909 .19115 .32016 .19282 .31907 .19169 .31802 Mtetra
.734 .763 .876 r
.19169 .31802 .19282 .31907 .19447 .31807 .19334 .31707 Mtetra
.589 .739 .947 r
.19334 .31707 .19447 .31807 .19606 .31767 .19493 .31673 Mtetra
.853 .397 .028 r
.19493 .31673 .19606 .31767 .19735 .3202 .19621 .31933 Mtetra
.945 .684 .51 r
.19621 .31933 .19735 .3202 .17798 .522 .17672 .52148 Mtetra
.934 .612 .404 r
.17672 .52148 .17798 .522 .17866 .53143 .17745 .53039 Mtetra
.535 .011 0 r
.17745 .53039 .17866 .53143 .18017 .53291 .17896 .53184 Mtetra
.545 .725 .958 r
.17896 .53184 .18017 .53291 .18186 .53266 .18065 .53161 Mtetra
.777 .781 .856 r
.18065 .53161 .18186 .53266 .18366 .53134 .18245 .53029 Mtetra
.9 .757 .695 r
.18245 .53029 .18366 .53134 .18575 .52715 .18455 .52612 Mtetra
.945 .688 .517 r
.18455 .52612 .18575 .52715 .20787 .32414 .20675 .32308 Mtetra
.931 .72 .597 r
.20675 .32308 .20787 .32414 .21044 .31417 .20932 .31307 Mtetra
.842 .763 .774 r
.20932 .31307 .21044 .31417 .21222 .31203 .2111 .31093 Mtetra
.681 .746 .901 r
.2111 .31093 .21222 .31203 .21385 .31136 .21273 .31025 Mtetra
.549 .703 .942 r
.21273 .31025 .21385 .31136 .21543 .31115 .21432 .31004 Mtetra
.704 .75 .887 r
.21432 .31004 .21543 .31115 .21708 .31036 .21597 .30925 Mtetra
.719 .752 .878 r
.21597 .30925 .21708 .31036 .21873 .30949 .21762 .30837 Mtetra
.58 .712 .933 r
.21762 .30837 .21873 .30949 .22033 .3092 .21922 .30807 Mtetra
.802 .332 0 r
.21922 .30807 .22033 .3092 .22167 .31161 .22056 .31046 Mtetra
.948 .684 .504 r
.22056 .31046 .22167 .31161 .20382 .51346 .20264 .5122 Mtetra
.952 .63 .379 r
.20264 .5122 .20382 .51346 .20461 .5227 .20341 .52161 Mtetra
.579 .064 0 r
.20341 .52161 .20461 .5227 .20614 .52432 .20494 .52324 Mtetra
.529 .717 .959 r
.20494 .52324 .20614 .52432 .20784 .52413 .20665 .52305 Mtetra
.769 .779 .861 r
.20665 .52305 .20784 .52413 .20965 .52287 .20845 .52178 Mtetra
.896 .758 .702 r
.20845 .52178 .20965 .52287 .2117 .519 .21051 .51786 Mtetra
.948 .689 .511 r
.21051 .51786 .2117 .519 .23218 .31741 .23114 .31558 Mtetra
.919 .698 .587 r
.23114 .31558 .23218 .31741 .23488 .30543 .23378 .30422 Mtetra
.848 .751 .756 r
.23378 .30422 .23488 .30543 .23668 .30302 .23559 .30183 Mtetra
.684 .732 .887 r
.23559 .30183 .23668 .30302 .23833 .30233 .23724 .30113 Mtetra
.556 .687 .926 r
.23724 .30113 .23833 .30233 .23994 .30213 .23884 .30091 Mtetra
.662 .72 .892 r
.23884 .30091 .23994 .30213 .24157 .30164 .24048 .30031 Mtetra
.697 .713 .861 r
.24048 .30031 .24157 .30164 .24322 .30092 .24215 .2995 Mtetra
.602 .666 .884 r
.24215 .2995 .24322 .30092 .24485 .30047 .24377 .29914 Mtetra
0 .031 .565 r
.24377 .29914 .24485 .30047 .24639 .30102 .24522 .30065 Mtetra
.933 .604 .389 r
.24522 .30065 .24639 .30102 .2478 .30309 .24608 .30893 Mtetra
.942 .675 .503 r
.24608 .30893 .2478 .30309 .24894 .30826 .2299 .50976 Mtetra
.522 .289 .502 r
.2299 .50976 .24894 .30826 .24953 .31979 .23142 .51182 Mtetra
.517 .284 .501 r
.23142 .51182 .24953 .31979 .25173 .31299 .23317 .51132 Mtetra
.516 .283 .501 r
.23317 .51132 .25173 .31299 .25348 .31127 .23497 .51032 Mtetra
.518 .285 .501 r
.23497 .51032 .25348 .31127 .23857 .50315 .23669 .51015 Mtetra
.53 .231 .404 r
.23669 .51015 .23857 .50315 .23975 .50927 .23836 .51066 Mtetra
.481 .021 .083 r
.23836 .51066 .23975 .50927 .24126 .51173 .24004 .511 Mtetra
.293 .686 .974 r
.24004 .511 .24126 .51173 .24291 .51245 .24175 .5111 Mtetra
.569 .682 .916 r
.24175 .5111 .24291 .51245 .24465 .51214 .24349 .51083 Mtetra
.699 .733 .877 r
.24349 .51083 .24465 .51214 .24644 .51125 .24528 .50998 Mtetra
.853 .757 .756 r
.24528 .50998 .24644 .51125 .24832 .5094 .24721 .50738 Mtetra
.901 .7 .622 r
.24721 .50738 .24832 .5094 .25031 .50613 .24955 .49989 Mtetra
.946 .683 .506 r
.24955 .49989 .25031 .50613 .25249 .5005 .26812 .29537 Mtetra
.528 .299 .51 r
.26812 .29537 .25249 .5005 .25479 .49338 .27004 .29158 Mtetra
.521 .293 .509 r
.27004 .29158 .25479 .49338 .25646 .49393 .27171 .29082 Mtetra
.52 .292 .509 r
.27171 .29082 .25646 .49393 .25817 .49405 .27335 .29059 Mtetra
.521 .293 .509 r
.27335 .29059 .25817 .49405 .27537 .30035 .27503 .28972 Mtetra
.59 .391 .58 r
.27503 .28972 .27537 .30035 .27767 .29174 .27678 .28811 Mtetra
.673 .531 .684 r
.27678 .28811 .27767 .29174 .27957 .28817 .27851 .28667 Mtetra
.716 .697 .83 r
.27851 .28667 .27957 .28817 .28132 .28647 .28021 .28568 Mtetra
.642 .81 .963 r
.28021 .28568 .28132 .28647 .28299 .28589 .28187 .28513 Mtetra
.6 .802 .977 r
.28187 .28513 .28299 .28589 .28463 .28563 .28353 .28469 Mtetra
.629 .77 .948 r
.28353 .28469 .28463 .28563 .28628 .28531 .28519 .2842 Mtetra
.665 .746 .91 r
.28519 .2842 .28628 .28531 .28794 .28474 .28686 .28358 Mtetra
.672 .739 .901 r
.28686 .28358 .28794 .28474 .28962 .2841 .28854 .28292 Mtetra
.716 .747 .877 r
.28854 .28292 .28962 .2841 .29131 .28326 .29023 .28203 Mtetra
.734 .744 .86 r
.29023 .28203 .29131 .28326 .29301 .28228 .29194 .28102 Mtetra
.657 .716 .891 r
.29194 .28102 .29301 .28228 .29469 .28157 .29361 .28042 Mtetra
0 .378 .838 r
.29361 .28042 .29469 .28157 .29631 .28171 .29518 .28123 Mtetra
.918 .538 .279 r
.29518 .28123 .29631 .28171 .29782 .28338 .29644 .28629 Mtetra
.951 .679 .488 r
.29644 .28629 .29782 .28338 .29918 .28723 .28318 .49046 Mtetra
.526 .292 .503 r
.28318 .49046 .29918 .28723 .30024 .29518 .28467 .49406 Mtetra
.517 .285 .501 r
.28467 .49406 .30024 .29518 .30205 .29296 .28644 .49373 Mtetra
.516 .284 .501 r
.28644 .49373 .30205 .29296 .30383 .29108 .28827 .49276 Mtetra
.517 .285 .501 r
.28827 .49276 .30383 .29108 .29201 .48206 .29005 .4923 Mtetra
.528 .249 .434 r
.29005 .4923 .29201 .48206 .29315 .49083 .29177 .49284 Mtetra
.506 .089 .184 r
.29177 .49284 .29315 .49083 .2947 .49374 .2935 .49323 Mtetra
.286 .727 .964 r
.2935 .49323 .2947 .49374 .29639 .49469 .29526 .49321 Mtetra
.626 .685 .886 r
.29526 .49321 .29639 .49469 .29818 .49431 .29705 .49271 Mtetra
.652 .679 .863 r
.29705 .49271 .29818 .49431 .29999 .49356 .29886 .49207 Mtetra
.625 .684 .885 r
.29886 .49207 .29999 .49356 .3018 .49287 .30066 .49158 Mtetra
.557 .691 .929 r
.30066 .49158 .3018 .49287 .3036 .49248 .30244 .49133 Mtetra
.665 .757 .919 r
.30244 .49133 .3036 .49248 .30541 .49182 .30425 .49066 Mtetra
.832 .78 .803 r
.30425 .49066 .30541 .49182 .30727 .49039 .30615 .48866 Mtetra
.905 .718 .639 r
.30615 .48866 .30727 .49039 .30924 .48734 .30832 .48253 Mtetra
.953 .686 .491 r
.30832 .48253 .30924 .48734 .31133 .48226 .32347 .27665 Mtetra
.531 .301 .511 r
.32347 .27665 .31133 .48226 .31365 .47377 .32547 .27135 Mtetra
.521 .293 .509 r
.32547 .27135 .31365 .47377 .3154 .47392 .32719 .27042 Mtetra
.52 .292 .509 r
.32719 .27042 .3154 .47392 .31713 .47451 .32887 .27013 Mtetra
.521 .292 .509 r
.32887 .27013 .31713 .47451 .33071 .28553 .33057 .26953 Mtetra
.568 .359 .557 r
.33057 .26953 .33071 .28553 .33321 .27217 .33233 .2679 Mtetra
.66 .506 .664 r
.33233 .2679 .33321 .27217 .33512 .26815 .33409 .26639 Mtetra
.724 .672 .799 r
.33409 .26639 .33512 .26815 .33692 .266 .33583 .26523 Mtetra
.676 .826 .956 r
.33583 .26523 .33692 .266 .33863 .26517 .33753 .26454 Mtetra
.619 .844 .985 r
.33753 .26454 .33863 .26517 .34033 .2647 .33923 .264 Mtetra
.606 .823 .983 r
.33923 .264 .34033 .2647 .34201 .26438 .34093 .26352 Mtetra
.631 .795 .961 r
.34093 .26352 .34201 .26438 .34371 .26395 .34263 .26299 Mtetra
.64 .775 .945 r
.34263 .26299 .34371 .26395 .3454 .26352 .34433 .26245 Mtetra
.66 .759 .923 r
.34433 .26245 .3454 .26352 .34711 .26298 .34604 .26184 Mtetra
.688 .754 .901 r
.34604 .26184 .34711 .26298 .34883 .26221 .34776 .2611 Mtetra
.693 .76 .903 r
.34776 .2611 .34883 .26221 .35055 .2614 .34948 .26034 Mtetra
.708 .773 .903 r
.34948 .26034 .35055 .2614 .35227 .26056 .3512 .25951 Mtetra
.737 .781 .888 r
.3512 .25951 .35227 .26056 .354 .25968 .35294 .25851 Mtetra
.659 .739 .909 r
.35294 .25851 .354 .25968 .35571 .25905 .35465 .2579 Mtetra
.294 .575 .937 r
.35465 .2579 .35571 .25905 .3574 .25896 .35631 .25825 Mtetra
.889 .462 .13 r
.35631 .25825 .3574 .25896 .35902 .26012 .35779 .26202 Mtetra
.958 .681 .469 r
.35779 .26202 .35902 .26012 .36054 .26322 .34849 .46688 Mtetra
.53 .295 .503 r
.34849 .46688 .36054 .26322 .35172 .4625 .34997 .47303 Mtetra
.544 .263 .439 r
.34997 .47303 .35172 .4625 .35304 .47161 .35172 .474 Mtetra
.468 .068 .198 r
.35172 .474 .35304 .47161 .35471 .47425 .35352 .47413 Mtetra
.216 .734 .862 r
.35352 .47413 .35471 .47425 .35647 .47533 .35534 .47393 Mtetra
.497 .65 .926 r
.35534 .47393 .35647 .47533 .35828 .47536 .35716 .47389 Mtetra
.636 .695 .887 r
.35716 .47389 .35828 .47536 .36012 .47481 .359 .47333 Mtetra
.776 .736 .816 r
.359 .47333 .36012 .47481 .362 .47355 .36089 .47178 Mtetra
.893 .722 .663 r
.36089 .47178 .362 .47355 .36395 .4708 .36295 .46688 Mtetra
.959 .687 .476 r
.36295 .46688 .36395 .4708 .36598 .46638 .37474 .26198 Mtetra
.54 .308 .512 r
.37474 .26198 .36598 .46638 .36818 .45828 .37689 .25284 Mtetra
.522 .293 .509 r
.37689 .25284 .36818 .45828 .37006 .45702 .37865 .25163 Mtetra
.52 .292 .509 r
.37865 .25163 .37006 .45702 .37186 .45722 .38037 .2512 Mtetra
.38037 .2512 .37186 .45722 .37393 .45176 .38209 .2508 Mtetra
.523 .295 .509 r
.38209 .2508 .37393 .45176 .38474 .25422 .38388 .2491 Mtetra
.645 .479 .644 r
.38388 .2491 .38474 .25422 .38666 .24964 .38565 .24752 Mtetra
.719 .639 .767 r
.38565 .24752 .38666 .24964 .38848 .2471 .38742 .24622 Mtetra
.692 .81 .938 r
.38742 .24622 .38848 .2471 .39023 .24616 .38916 .24546 Mtetra
.64 .838 .977 r
.38916 .24546 .39023 .24616 .39196 .2456 .3909 .24486 Mtetra
.614 .821 .98 r
.3909 .24486 .39196 .2456 .39369 .24525 .39263 .24435 Mtetra
.634 .79 .957 r
.39263 .24435 .39369 .24525 .39542 .2448 .39437 .24381 Mtetra
.639 .772 .944 r
.39437 .24381 .39542 .2448 .39715 .24436 .39611 .24326 Mtetra
.652 .755 .925 r
.39611 .24326 .39715 .24436 .39889 .24385 .39785 .24267 Mtetra
.683 .749 .902 r
.39785 .24267 .39889 .24385 .40064 .24308 .39959 .24194 Mtetra
.69 .758 .904 r
.39959 .24194 .40064 .24308 .40239 .24227 .40134 .24118 Mtetra
.69 .769 .912 r
.40134 .24118 .40239 .24227 .40414 .24146 .40309 .24043 Mtetra
.673 .775 .926 r
.40309 .24043 .40414 .24146 .40589 .24078 .40484 .23975 Mtetra
.669 .773 .928 r
.40484 .23975 .40589 .24078 .40764 .24014 .40659 .23908 Mtetra
.666 .769 .926 r
.40659 .23908 .40764 .24014 .40938 .23951 .40834 .23843 Mtetra
.669 .765 .922 r
.40834 .23843 .40938 .23951 .41113 .23886 .41009 .23777 Mtetra
.668 .762 .921 r
.41009 .23777 .41113 .23886 .41289 .23821 .41185 .23711 Mtetra
.668 .759 .919 r
.41185 .23711 .41289 .23821 .41464 .23756 .4136 .23645 Mtetra
.735 .776 .885 r
.4136 .23645 .41464 .23756 .4164 .23668 .41537 .23544 Mtetra
.675 .735 .895 r
.41537 .23544 .4164 .23668 .41815 .23599 .41712 .23473 Mtetra
.518 .67 .932 r
.41712 .23473 .41815 .23599 .4199 .23566 .41886 .23462 Mtetra
.804 .341 0 r
.41886 .23462 .4199 .23566 .42159 .2369 .42049 .23763 Mtetra
.964 .681 .448 r
.42049 .23763 .42159 .2369 .42324 .23968 .41543 .4404 Mtetra
.537 .301 .504 r
.41543 .4404 .42324 .23968 .42467 .24915 .41696 .45028 Mtetra
.519 .286 .501 r
.41696 .45028 .42467 .24915 .42053 .43291 .41881 .4506 Mtetra
.493 .237 .455 r
.41881 .4506 .42053 .43291 .42257 .42692 .4207 .44986 Mtetra
.488 .24 .464 r
.4207 .44986 .42257 .42692 .42999 .2469 .42261 .44858 Mtetra
.516 .284 .501 r
.42261 .44858 .42999 .2469 .43187 .24262 .42451 .44774 Mtetra
.517 .284 .501 r
.42451 .44774 .43187 .24262 .43366 .24137 .4264 .44705 Mtetra
.517 .285 .501 r
.4264 .44705 .43366 .24137 .43531 .24498 .42828 .44665 Mtetra
.519 .286 .501 r
.42828 .44665 .43531 .24498 .43139 .44314 .43014 .44714 Mtetra
.525 .178 .322 r
.43014 .44714 .43139 .44314 .43315 .44732 .432 .44761 Mtetra
.279 0 0 r
.432 .44761 .43315 .44732 .43497 .4492 .43387 .44787 Mtetra
.567 .697 .928 r
.43387 .44787 .43497 .4492 .43685 .44924 .43576 .44757 Mtetra
.619 .664 .871 r
.43576 .44757 .43685 .44924 .43875 .44877 .43766 .44707 Mtetra
.642 .669 .86 r
.43766 .44707 .43875 .44877 .44065 .44804 .43956 .44644 Mtetra
.577 .657 .891 r
.43956 .44644 .44065 .44804 .44255 .44751 .44145 .44614 Mtetra
.641 .719 .904 r
.44145 .44614 .44255 .44751 .44445 .44679 .44336 .44554 Mtetra
.75 .773 .872 r
.44336 .44554 .44445 .44679 .44637 .44569 .44527 .44434 Mtetra
.905 .766 .697 r
.44527 .44434 .44637 .44569 .44831 .44349 .44726 .44041 Mtetra
.93 .685 .547 r
.44726 .44041 .44831 .44349 .45028 .43991 .44949 .42581 Mtetra
.955 .674 .462 r
.44949 .42581 .45028 .43991 .45236 .43157 .45593 .22448 Mtetra
.525 .296 .51 r
.45593 .22448 .45236 .43157 .45867 .22764 .45776 .22163 Mtetra
.627 .453 .627 r
.45776 .22163 .45867 .22764 .46055 .22277 .45956 .22009 Mtetra
.666 .575 .743 r
.45956 .22009 .46055 .22277 .46237 .22016 .46136 .21907 Mtetra
.695 .776 .914 r
.46136 .21907 .46237 .22016 .46417 .21902 .46314 .21828 Mtetra
.641 .837 .976 r
.46314 .21828 .46417 .21902 .46595 .2184 .46493 .21766 Mtetra
.603 .826 .985 r
.46493 .21766 .46595 .2184 .46773 .21803 .46671 .21715 Mtetra
.628 .8 .965 r
.46671 .21715 .46773 .21803 .46952 .2176 .4685 .21661 Mtetra
.638 .779 .949 r
.4685 .21661 .46952 .2176 .4713 .21714 .47029 .21605 Mtetra
.65 .76 .93 r
.47029 .21605 .4713 .21714 .47309 .21664 .47208 .21545 Mtetra
.682 .752 .904 r
.47208 .21545 .47309 .21664 .47488 .2159 .47387 .2147 Mtetra
.693 .755 .899 r
.47387 .2147 .47488 .2159 .47668 .21506 .47567 .21391 Mtetra
.694 .763 .905 r
.47567 .21391 .47668 .21506 .47848 .21421 .47747 .21311 Mtetra
.741 .785 .889 r
.47747 .21311 .47848 .21421 .48028 .21327 .47927 .21206 Mtetra
.699 .755 .895 r
.47927 .21206 .48028 .21327 .48207 .21249 .48107 .21123 Mtetra
.574 .698 .926 r
.48107 .21123 .48207 .21249 .48387 .21204 .48286 .21092 Mtetra
.536 .054 0 r
.48286 .21092 .48387 .21204 .48565 .21262 .48462 .21291 Mtetra
.937 .591 .341 r
.48462 .21291 .48565 .21262 .48742 .21453 .48628 .22386 Mtetra
.96 .668 .438 r
.48628 .22386 .48742 .21453 .48914 .22098 .48563 .42671 Mtetra
.522 .289 .502 r
.48563 .42671 .48914 .22098 .48867 .42441 .48753 .42885 Mtetra
.52 .182 .334 r
.48753 .42885 .48867 .42441 .49055 .42857 .48945 .42928 Mtetra
.197 0 0 r
.48945 .42928 .49055 .42857 .49246 .43021 .49138 .42911 Mtetra
.481 .707 .969 r
.49138 .42911 .49246 .43021 .49439 .43046 .49332 .429 Mtetra
.604 .694 .907 r
.49332 .429 .49439 .43046 .49633 .42995 .49525 .42856 Mtetra
.726 .749 .871 r
.49525 .42856 .49633 .42995 .49827 .42886 .4972 .42747 Mtetra
.892 .772 .723 r
.4972 .42747 .49827 .42886 .50022 .42687 .49916 .42412 Mtetra
.921 .692 .575 r
.49916 .42412 .50022 .42687 .50218 .42359 .50117 .4144 Mtetra
.965 .679 .44 r
.50117 .4144 .50218 .42359 .50417 .41688 .5045 .20756 Mtetra
.527 .297 .51 r
.5045 .20756 .50417 .41688 .50729 .21121 .50633 .20404 Mtetra
.617 .433 .61 r
.50633 .20404 .50729 .21121 .50914 .20547 .50815 .20238 Mtetra
.657 .549 .721 r
.50815 .20238 .50914 .20547 .51097 .20264 .50997 .20132 Mtetra
.678 .73 .889 r
.50997 .20132 .51097 .20264 .51279 .20142 .51179 .20057 Mtetra
.623 .808 .971 r
.51179 .20057 .51279 .20142 .5146 .20092 .51361 .20003 Mtetra
.594 .789 .973 r
.51361 .20003 .5146 .20092 .51642 .20068 .51543 .19958 Mtetra
.647 .761 .932 r
.51543 .19958 .51642 .20068 .51824 .2002 .51725 .19898 Mtetra
.672 .746 .906 r
.51725 .19898 .51824 .2002 .52006 .19954 .51907 .19827 Mtetra
.68 .742 .898 r
.51907 .19827 .52006 .19954 .52188 .1988 .52089 .19752 Mtetra
.751 .761 .861 r
.52089 .19752 .52188 .1988 .52371 .19758 .52272 .19634 Mtetra
.738 .765 .875 r
.52272 .19634 .52371 .19758 .52553 .19645 .52454 .19527 Mtetra
.612 .734 .932 r
.52454 .19527 .52553 .19645 .52736 .19594 .52637 .19481 Mtetra
.596 .119 0 r
.52637 .19481 .52736 .19594 .52919 .19832 .5282 .19713 Mtetra
.973 .68 .404 r
.5282 .19713 .52919 .19832 .53144 .4062 .53039 .40408 Mtetra
.936 .584 .165 r
.53039 .40408 .53144 .4062 .53343 .41567 .53237 .41414 Mtetra
.004 .331 .815 r
.53237 .41414 .53343 .41567 .5354 .41682 .53434 .41538 Mtetra
.636 .713 .902 r
.53434 .41538 .5354 .41682 .53737 .41612 .53631 .41478 Mtetra
.734 .763 .877 r
.53631 .41478 .53737 .41612 .53934 .41488 .53828 .41365 Mtetra
.594 .733 .941 r
.53828 .41365 .53934 .41488 .54131 .41444 .54025 .41322 Mtetra
.528 .707 .953 r
.54025 .41322 .54131 .41444 .54328 .41428 .54223 .41301 Mtetra
.688 .762 .908 r
.54223 .41301 .54328 .41428 .54525 .41347 .5442 .41216 Mtetra
.909 .784 .711 r
.5442 .41216 .54525 .41347 .54721 .40977 .54616 .40853 Mtetra
.975 .687 .413 r
.54616 .40853 .54721 .40977 .54763 .20286 .54667 .20448 Mtetra
.997 .771 .436 r
.54667 .20448 .54763 .20286 .54938 .18962 .5484 .18876 Mtetra
.903 .843 .775 r
.5484 .18876 .54938 .18962 .55121 .18715 .55023 .18621 Mtetra
.659 .804 .953 r
.55023 .18621 .55121 .18715 .55305 .18655 .55208 .18554 Mtetra
.482 .716 .973 r
.55208 .18554 .55305 .18655 .5549 .18651 .55393 .18542 Mtetra
.562 .736 .957 r
.55393 .18542 .5549 .18651 .55675 .18625 .55578 .18511 Mtetra
.653 .76 .928 r
.55578 .18511 .55675 .18625 .5586 .18564 .55763 .18448 Mtetra
.661 .758 .922 r
.55763 .18448 .5586 .18564 .56045 .18499 .55948 .18381 Mtetra
.736 .779 .888 r
.55948 .18381 .56045 .18499 .56229 .18395 .56132 .18276 Mtetra
.739 .777 .884 r
.56132 .18276 .56229 .18395 .56414 .1829 .56317 .18168 Mtetra
.616 .732 .929 r
.56317 .18168 .56414 .1829 .566 .18243 .56502 .1812 Mtetra
0 0 .533 r
.56502 .1812 .566 .18243 .56789 .18461 .56692 .18328 Mtetra
.975 .678 .387 r
.56692 .18328 .56789 .18461 .57286 .39273 .57181 .39045 Mtetra
.917 .564 .114 r
.57181 .39045 .57286 .39273 .575 .40182 .57396 .4003 Mtetra
0 .272 .777 r
.57396 .4003 .575 .40182 .57703 .40318 .57599 .40176 Mtetra
.648 .724 .904 r
.57599 .40176 .57703 .40318 .57902 .40244 .57799 .4011 Mtetra
.753 .772 .869 r
.57799 .4011 .57902 .40244 .58101 .40108 .57998 .39983 Mtetra
.743 .785 .887 r
.57998 .39983 .58101 .40108 .583 .39984 .58197 .39865 Mtetra
.683 .78 .924 r
.58197 .39865 .583 .39984 .585 .39898 .58397 .39783 Mtetra
.677 .784 .93 r
.58397 .39783 .585 .39898 .587 .39818 .58597 .39703 Mtetra
.67 .783 .934 r
.58597 .39703 .587 .39818 .589 .39741 .58797 .39626 Mtetra
.661 .781 .938 r
.58797 .39626 .589 .39741 .591 .39668 .58998 .39554 Mtetra
.649 .777 .942 r
.58998 .39554 .591 .39668 .59301 .39602 .59198 .39486 Mtetra
.627 .766 .946 r
.59198 .39486 .59301 .39602 .59502 .39551 .59399 .39428 Mtetra
.61 .745 .941 r
.59399 .39428 .59502 .39551 .59704 .39511 .59601 .39377 Mtetra
.61 .724 .926 r
.59601 .39377 .59704 .39511 .59906 .39473 .59802 .39328 Mtetra
.621 .71 .909 r
.59802 .39328 .59906 .39473 .60107 .39426 .60004 .39274 Mtetra
.633 .703 .897 r
.60004 .39274 .60107 .39426 .60309 .39369 .60206 .39215 Mtetra
.637 .7 .892 r
.60206 .39215 .60309 .39369 .60511 .3931 .60408 .39153 Mtetra
.638 .699 .889 r
.60408 .39153 .60511 .3931 .60713 .39248 .6061 .39091 Mtetra
.639 .697 .888 r
.6061 .39091 .60713 .39248 .60915 .39187 .60812 .39028 Mtetra
.64 .697 .886 r
.60812 .39028 .60915 .39187 .61117 .39124 .61014 .38965 Mtetra
.641 .696 .885 r
.61014 .38965 .61117 .39124 .61319 .3906 .61216 .389 Mtetra
.643 .696 .885 r
.61216 .389 .61319 .3906 .61522 .38995 .61419 .38835 Mtetra
.644 .697 .884 r
.61419 .38835 .61522 .38995 .61724 .3893 .61621 .3877 Mtetra
.645 .697 .884 r
.61621 .3877 .61724 .3893 .61927 .38863 .61824 .38704 Mtetra
.646 .698 .884 r
.61824 .38704 .61927 .38863 .6213 .38796 .62027 .38637 Mtetra
.646 .699 .885 r
.62027 .38637 .6213 .38796 .62332 .38728 .6223 .3857 Mtetra
.646 .701 .886 r
.6223 .3857 .62332 .38728 .62535 .3866 .62433 .38503 Mtetra
.646 .702 .888 r
.62433 .38503 .62535 .3866 .62739 .38592 .62636 .38436 Mtetra
.648 .705 .889 r
.62636 .38436 .62739 .38592 .62942 .38521 .6284 .38368 Mtetra
.657 .714 .89 r
.6284 .38368 .62942 .38521 .63145 .38442 .63043 .38296 Mtetra
.666 .729 .896 r
.63043 .38296 .63145 .38442 .63348 .38352 .63247 .38219 Mtetra
.661 .749 .915 r
.63247 .38219 .63348 .38352 .63551 .38267 .6345 .38145 Mtetra
.634 .76 .939 r
.6345 .38145 .63551 .38267 .63755 .38201 .63654 .38084 Mtetra
.592 .752 .954 r
.63654 .38084 .63755 .38201 .6396 .38161 .63859 .38038 Mtetra
.588 .738 .947 r
.63859 .38038 .6396 .38161 .64165 .38126 .64065 .37995 Mtetra
.545 .703 .943 r
.64065 .37995 .64165 .38126 .64372 .38105 .64271 .37968 Mtetra
.514 .678 .94 r
.64271 .37968 .64372 .38105 .64578 .38091 .64477 .37954 Mtetra
.651 .739 .915 r
.64477 .37954 .64578 .38091 .64783 .38022 .64682 .37885 Mtetra
.856 .796 .791 r
.64682 .37885 .64783 .38022 .64981 .37788 .64881 .37651 Mtetra
.971 .756 .556 r
.64881 .37651 .64981 .37788 .65155 .36942 .65055 .36803 Mtetra
.977 .68 .37 r
.65055 .36803 .65155 .36942 .64507 .15717 .64413 .15595 Mtetra
.942 .791 .665 r
.64413 .15595 .64507 .15717 .64683 .15288 .6459 .15166 Mtetra
.727 .779 .894 r
.6459 .15166 .64683 .15288 .64872 .15187 .64779 .15064 Mtetra
.581 .719 .938 r
.64779 .15064 .64872 .15187 .65065 .15152 .64972 .15027 Mtetra
.551 .702 .94 r
.64972 .15027 .65065 .15152 .65258 .15128 .65165 .15001 Mtetra
.666 .749 .912 r
.65165 .15001 .65258 .15128 .65449 .15057 .65356 .1493 Mtetra
.673 .75 .908 r
.65356 .1493 .65449 .15057 .6564 .14983 .65547 .14855 Mtetra
.69 .754 .901 r
.65547 .14855 .6564 .14983 .65831 .14896 .65738 .14772 Mtetra
.712 .769 .897 r
.65738 .14772 .65831 .14896 .66021 .14791 .65929 .14677 Mtetra
.701 .787 .918 r
.65929 .14677 .66021 .14791 .66212 .14709 .6612 .1459 Mtetra
.678 .769 .919 r
.6612 .1459 .66212 .14709 .66406 .14684 .66311 .14513 Mtetra
.641 .665 .857 r
.66311 .14513 .66406 .14684 .66606 .14783 .66504 .1445 Mtetra
.55 .477 .727 r
.66504 .1445 .66606 .14783 .66815 .15053 .66699 .14436 Mtetra
.437 .324 .627 r
.66699 .14436 .66815 .15053 .67979 .34887 .66901 .14564 Mtetra
.491 .27 .506 r
.66901 .14564 .67979 .34887 .68255 .36218 .67161 .15878 Mtetra
0 0 .373 r
.67161 .15878 .68255 .36218 .68479 .36504 .68372 .36195 Mtetra
.004 .151 .666 r
.68372 .36195 .68479 .36504 .68696 .36607 .68597 .36473 Mtetra
.492 .673 .944 r
.68597 .36473 .68696 .36607 .68906 .36596 .68808 .36465 Mtetra
.669 .761 .919 r
.68808 .36465 .68906 .36596 .69114 .3652 .69015 .36386 Mtetra
.726 .776 .893 r
.69015 .36386 .69114 .3652 .69317 .36367 .69221 .36276 Mtetra
.698 .851 .956 r
.69221 .36276 .69317 .36367 .69513 .36071 .69428 .36182 Mtetra
0 0 0 r
.69428 .36182 .69513 .36071 .69695 .3552 .69632 .36031 Mtetra
.199 0 .268 r
.69632 .36031 .69695 .3552 .68778 .14916 .69828 .35727 Mtetra
.484 .26 .498 r
.69828 .35727 .68778 .14916 .68932 .14132 .69938 .33874 Mtetra
0 0 .366 r
.69938 .33874 .68932 .14132 .69112 .13804 .6903 .13844 Mtetra
.941 .941 .603 r
.6903 .13844 .69112 .13804 .69299 .13609 .69207 .13477 Mtetra
.728 .764 .881 r
.69207 .13477 .69299 .13609 .69492 .13522 .69399 .1337 Mtetra
.62 .688 .892 r
.69399 .1337 .69492 .13522 .69687 .13465 .69595 .13319 Mtetra
.582 .678 .906 r
.69595 .13319 .69687 .13465 .69882 .13417 .69791 .13284 Mtetra
.675 .745 .903 r
.69791 .13284 .69882 .13417 .70076 .1334 .69985 .13207 Mtetra
.683 .747 .9 r
.69985 .13207 .70076 .1334 .7027 .13257 .70179 .13125 Mtetra
.709 .76 .892 r
.70179 .13125 .7027 .13257 .70463 .13158 .70372 .1303 Mtetra
.78 .79 .861 r
.70372 .1303 .70463 .13158 .70653 .1301 .70563 .12891 Mtetra
.712 .783 .908 r
.70563 .12891 .70653 .1301 .70846 .12909 .70757 .12796 Mtetra
.42 .662 .961 r
.70757 .12796 .70846 .12909 .71045 .12909 .70957 .12804 Mtetra
.798 .362 0 r
.70957 .12804 .71045 .12909 .71274 .13359 .71187 .13283 Mtetra
.973 .662 .317 r
.71187 .13283 .71274 .13359 .72841 .34645 .72747 .34552 Mtetra
.8 .35 0 r
.72747 .34552 .72841 .34645 .73089 .35156 .72993 .35033 Mtetra
.474 .688 .961 r
.72993 .35033 .73089 .35156 .73304 .35151 .73208 .35026 Mtetra
.684 .782 .925 r
.73208 .35026 .73304 .35151 .73514 .35064 .73418 .34939 Mtetra
.735 .8 .904 r
.73418 .34939 .73514 .35064 .73722 .34946 .73627 .34824 Mtetra
.515 .712 .961 r
.73627 .34824 .73722 .34946 .73936 .3491 .73841 .34804 Mtetra
.608 .789 .968 r
.73841 .34804 .73936 .3491 .74148 .34854 .74054 .34747 Mtetra
.776 .844 .903 r
.74054 .34747 .74148 .34854 .74358 .34758 .74261 .34609 Mtetra
.943 .787 .658 r
.74261 .34609 .74358 .34758 .74561 .34554 .74446 .34143 Mtetra
.975 .668 .333 r
.74446 .34143 .74561 .34554 .74755 .34239 .73221 .1357 Mtetra
.545 .31 .51 r
.73221 .1357 .74755 .34239 .74928 .33614 .73331 .12263 Mtetra
.524 .295 .509 r
.73331 .12263 .74928 .33614 .73651 .12796 .73516 .12018 Mtetra
.6 .416 .604 r
.73516 .12018 .73651 .12796 .73811 .12199 .73707 .11869 Mtetra
.642 .536 .718 r
.73707 .11869 .73811 .12199 .73992 .11913 .73902 .11768 Mtetra
.675 .725 .888 r
.73902 .11768 .73992 .11913 .74187 .11809 .74099 .11688 Mtetra
.644 .76 .933 r
.74099 .11688 .74187 .11809 .74385 .11748 .74297 .11625 Mtetra
.632 .749 .932 r
.74297 .11625 .74385 .11748 .74585 .11707 .74496 .11566 Mtetra
.673 .733 .895 r
.74496 .11566 .74585 .11707 .74782 .11631 .74693 .11488 Mtetra
.68 .732 .889 r
.74693 .11488 .74782 .11631 .7498 .11551 .7489 .11406 Mtetra
.687 .732 .885 r
.7489 .11406 .7498 .11551 .75176 .11464 .75087 .1132 Mtetra
.759 .76 .854 r
.75087 .1132 .75176 .11464 .7537 .11338 .75281 .11188 Mtetra
.705 .731 .871 r
.75281 .11188 .7537 .11338 .75566 .11233 .75477 .1109 Mtetra
.578 .686 .915 r
.75477 .1109 .75566 .11233 .75765 .11169 .75678 .11055 Mtetra
.891 .581 .453 r
.12187 .34433 .12326 .34346 .12441 .34623 .12234 .35244 Mtetra
.928 .672 .53 r
.12234 .35244 .12441 .34623 .1012 .5425 .09862 .55209 Mtetra
.639 .354 .471 r
.09862 .55209 .1012 .5425 .10139 .55369 .09978 .55565 Mtetra
.465 .049 .164 r
.09978 .55565 .10139 .55369 .10282 .55505 .10136 .55579 Mtetra
0 0 0 r
.10136 .55579 .10282 .55505 .10438 .55537 .10304 .5552 Mtetra
.747 .941 .947 r
.10304 .5552 .10438 .55537 .10601 .55517 .10478 .55414 Mtetra
.673 .764 .919 r
.10478 .55414 .10601 .55517 .10762 .55516 .10647 .55348 Mtetra
.715 .678 .812 r
.10647 .55348 .10762 .55516 .10929 .55468 .10821 .55241 Mtetra
.756 .642 .734 r
.10821 .55241 .10929 .55468 .11104 .55353 .11005 .5505 Mtetra
.864 .658 .622 r
.11005 .5505 .11104 .55353 .11313 .54955 .11263 .54258 Mtetra
.931 .679 .534 r
.11263 .54258 .11313 .54955 .11751 .52684 .13892 .34029 Mtetra
.531 .302 .512 r
.13892 .34029 .11751 .52684 .14181 .33947 .14101 .33561 Mtetra
.65 .508 .676 r
.14101 .33561 .14181 .33947 .14362 .33696 .14266 .33442 Mtetra
.605 .54 .755 r
.14266 .33442 .14362 .33696 .1453 .33558 .14423 .33398 Mtetra
.538 .603 .867 r
.14423 .33398 .1453 .33558 .14692 .33471 .14575 .33388 Mtetra
.63 .784 .956 r
.14575 .33388 .14692 .33471 .14851 .33412 .14733 .33341 Mtetra
.646 .816 .965 r
.14733 .33341 .14851 .33412 .15007 .33369 .14891 .33286 Mtetra
.663 .793 .944 r
.14891 .33286 .15007 .33369 .15163 .33334 .15049 .33228 Mtetra
.701 .754 .893 r
.15049 .33228 .15163 .33334 .15322 .33278 .1521 .33152 Mtetra
.692 .718 .869 r
.1521 .33152 .15322 .33278 .15481 .33214 .15371 .33078 Mtetra
.669 .694 .865 r
.15371 .33078 .15481 .33214 .15641 .33146 .15531 .33014 Mtetra
.663 .699 .873 r
.15531 .33014 .15641 .33146 .15807 .33028 .1569 .32954 Mtetra
.531 .776 .988 r
.1569 .32954 .15807 .33028 .1597 .32938 .15845 .32928 Mtetra
.331 0 0 r
.15845 .32928 .1597 .32938 .16125 .32914 .15993 .32973 Mtetra
.87 .518 .381 r
.15993 .32973 .16125 .32914 .1624 .33244 .16092 .33441 Mtetra
.938 .679 .519 r
.16092 .33441 .1624 .33244 .14065 .53589 .13923 .53667 Mtetra
.86 .507 .381 r
.13923 .53667 .14065 .53589 .14151 .54272 .14031 .54145 Mtetra
.187 .503 .909 r
.14031 .54145 .14151 .54272 .14308 .54327 .14188 .54198 Mtetra
.639 .712 .899 r
.14188 .54198 .14308 .54327 .14479 .54261 .14358 .54146 Mtetra
.736 .758 .87 r
.14358 .54146 .14479 .54261 .14655 .54148 .14533 .54043 Mtetra
.668 .763 .921 r
.14533 .54043 .14655 .54148 .14822 .54127 .14705 .53978 Mtetra
.703 .7 .844 r
.14705 .53978 .14822 .54127 .14989 .54101 .14879 .53887 Mtetra
.749 .65 .751 r
.14879 .53887 .14989 .54101 .15162 .54017 .15062 .53717 Mtetra
.854 .655 .632 r
.15062 .53717 .15162 .54017 .15364 .53674 .15299 .53061 Mtetra
.936 .681 .526 r
.15299 .53061 .15364 .53674 .1566 .52482 .17711 .32706 Mtetra
.532 .302 .511 r
.17711 .32706 .1566 .52482 .18 .32609 .17922 .32185 Mtetra
.661 .506 .663 r
.17922 .32185 .18 .32609 .18186 .32321 .18093 .32035 Mtetra
.607 .522 .733 r
.18093 .32035 .18186 .32321 .18355 .32183 .18253 .31984 Mtetra
.555 .563 .818 r
.18253 .31984 .18355 .32183 .18519 .32095 .18408 .3197 Mtetra
.644 .706 .892 r
.18408 .3197 .18519 .32095 .18681 .32024 .18568 .31919 Mtetra
.674 .752 .91 r
.18568 .31919 .18681 .32024 .18842 .31963 .1873 .31855 Mtetra
.656 .742 .913 r
.1873 .31855 .18842 .31963 .19003 .31909 .18891 .31799 Mtetra
.668 .741 .905 r
.18891 .31799 .19003 .31909 .19169 .31802 .19052 .31738 Mtetra
.556 .811 .993 r
.19052 .31738 .19169 .31802 .19334 .31707 .19211 .31703 Mtetra
.241 0 0 r
.19211 .31703 .19334 .31707 .19493 .31673 .19363 .31733 Mtetra
.856 .486 .348 r
.19363 .31733 .19493 .31673 .19621 .31933 .19477 .3213 Mtetra
.941 .68 .512 r
.19477 .3213 .19621 .31933 .17672 .52148 .17511 .52423 Mtetra
.804 .474 .43 r
.17511 .52423 .17672 .52148 .17745 .53039 .17622 .52957 Mtetra
.495 0 0 r
.17622 .52957 .17745 .53039 .17896 .53184 .17776 .53078 Mtetra
.524 .717 .961 r
.17776 .53078 .17896 .53184 .18065 .53161 .17944 .5306 Mtetra
.764 .789 .873 r
.17944 .5306 .18065 .53161 .18245 .53029 .18123 .52941 Mtetra
.906 .771 .702 r
.18123 .52941 .18245 .53029 .18455 .52612 .18331 .52537 Mtetra
.945 .689 .517 r
.18331 .52537 .18455 .52612 .20675 .32308 .20553 .32292 Mtetra
.952 .744 .586 r
.20553 .32292 .20675 .32308 .20932 .31307 .2082 .31201 Mtetra
.847 .767 .774 r
.2082 .31201 .20932 .31307 .2111 .31093 .20999 .30982 Mtetra
.682 .746 .9 r
.20999 .30982 .2111 .31093 .21273 .31025 .21162 .30914 Mtetra
.551 .703 .94 r
.21162 .30914 .21273 .31025 .21432 .31004 .21321 .30893 Mtetra
.705 .75 .887 r
.21321 .30893 .21432 .31004 .21597 .30925 .21486 .30813 Mtetra
.72 .752 .877 r
.21486 .30813 .21597 .30925 .21762 .30837 .21651 .30724 Mtetra
.583 .711 .931 r
.21651 .30724 .21762 .30837 .21922 .30807 .21811 .30693 Mtetra
.796 .325 0 r
.21811 .30693 .21922 .30807 .22056 .31046 .21945 .30929 Mtetra
.948 .685 .504 r
.21945 .30929 .22056 .31046 .20264 .5122 .20147 .51086 Mtetra
.954 .633 .38 r
.20147 .51086 .20264 .5122 .20341 .52161 .20222 .52051 Mtetra
.581 .067 0 r
.20222 .52051 .20341 .52161 .20494 .52324 .20375 .52215 Mtetra
.531 .716 .957 r
.20375 .52215 .20494 .52324 .20665 .52305 .20545 .52195 Mtetra
.77 .778 .859 r
.20545 .52195 .20665 .52305 .20845 .52178 .20726 .52067 Mtetra
.896 .757 .7 r
.20726 .52067 .20845 .52178 .21051 .51786 .20933 .51671 Mtetra
.948 .689 .511 r
.20933 .51671 .21051 .51786 .23114 .31558 .23009 .31382 Mtetra
.919 .7 .59 r
.23009 .31382 .23114 .31558 .23378 .30422 .23268 .30301 Mtetra
.848 .75 .754 r
.23268 .30301 .23378 .30422 .23559 .30183 .23449 .30059 Mtetra
.695 .727 .875 r
.23449 .30059 .23559 .30183 .23724 .30113 .23615 .29982 Mtetra
.585 .679 .905 r
.23615 .29982 .23724 .30113 .23884 .30091 .23776 .29952 Mtetra
.677 .698 .862 r
.23776 .29952 .23884 .30091 .24048 .30031 .23941 .29882 Mtetra
.699 .69 .839 r
.23941 .29882 .24048 .30031 .24215 .2995 .24108 .29796 Mtetra
.589 .642 .871 r
.24108 .29796 .24215 .2995 .24377 .29914 .2427 .29766 Mtetra
.615 .17 0 r
.2427 .29766 .24377 .29914 .24522 .30065 .2441 .29973 Mtetra
.95 .684 .498 r
.2441 .29973 .24522 .30065 .24608 .30893 .22774 .50054 Mtetra
.543 .306 .506 r
.22774 .50054 .24608 .30893 .2299 .50976 .22842 .51196 Mtetra
.659 .273 .303 r
.22842 .51196 .2299 .50976 .23142 .51182 .22999 .51357 Mtetra
.301 0 .023 r
.22999 .51357 .23142 .51182 .23317 .51132 .23173 .51317 Mtetra
.116 0 0 r
.23173 .51317 .23317 .51132 .23497 .51032 .23352 .51221 Mtetra
.185 0 0 r
.23352 .51221 .23497 .51032 .23669 .51015 .2353 .51142 Mtetra
.16 0 0 r
.2353 .51142 .23669 .51015 .23836 .51066 .23706 .51089 Mtetra
.377 .842 .82 r
.23706 .51089 .23836 .51066 .24004 .511 .23883 .51025 Mtetra
.662 .832 .965 r
.23883 .51025 .24004 .511 .24175 .5111 .2406 .50959 Mtetra
.695 .701 .852 r
.2406 .50959 .24175 .5111 .24349 .51083 .24239 .50871 Mtetra
.736 .651 .765 r
.24239 .50871 .24349 .51083 .24528 .50998 .24424 .5072 Mtetra
.827 .652 .665 r
.24424 .5072 .24528 .50998 .24721 .50738 .24631 .503 Mtetra
.948 .685 .505 r
.24631 .503 .24721 .50738 .24955 .49989 .26507 .29834 Mtetra
.538 .307 .512 r
.26507 .29834 .24955 .49989 .26812 .29537 .26735 .2903 Mtetra
.691 .511 .639 r
.26735 .2903 .26812 .29537 .27004 .29158 .26916 .28786 Mtetra
.617 .493 .688 r
.26916 .28786 .27004 .29158 .27171 .29082 .27083 .28708 Mtetra
.57 .462 .692 r
.27083 .28708 .27171 .29082 .27335 .29059 .27247 .28676 Mtetra
.569 .459 .688 r
.27247 .28676 .27335 .29059 .27503 .28972 .27411 .28645 Mtetra
.598 .499 .713 r
.27411 .28645 .27503 .28972 .27678 .28811 .27577 .28594 Mtetra
.621 .583 .79 r
.27577 .28594 .27678 .28811 .27851 .28667 .27743 .28543 Mtetra
.654 .718 .895 r
.27743 .28543 .27851 .28667 .28021 .28568 .2791 .28485 Mtetra
.673 .806 .946 r
.2791 .28485 .28021 .28568 .28187 .28513 .28077 .28419 Mtetra
.68 .786 .93 r
.28077 .28419 .28187 .28513 .28353 .28469 .28244 .28351 Mtetra
.684 .74 .893 r
.28244 .28351 .28353 .28469 .28519 .2842 .28412 .2828 Mtetra
.678 .7 .864 r
.28412 .2828 .28519 .2842 .28686 .28358 .2858 .28209 Mtetra
.658 .68 .859 r
.2858 .28209 .28686 .28358 .28854 .28292 .28748 .28146 Mtetra
.648 .681 .867 r
.28748 .28146 .28854 .28292 .29023 .28203 .28915 .28089 Mtetra
.612 .724 .925 r
.28915 .28089 .29023 .28203 .29194 .28102 .29081 .28048 Mtetra
.201 .663 .942 r
.29081 .28048 .29194 .28102 .29361 .28042 .29243 .2806 Mtetra
.794 .333 .144 r
.29243 .2806 .29361 .28042 .29518 .28123 .29389 .28282 Mtetra
.952 .681 .487 r
.29389 .28282 .29518 .28123 .29644 .28629 .28058 .48526 Mtetra
.536 .3 .505 r
.28058 .48526 .29644 .28629 .28318 .49046 .28167 .49407 Mtetra
.639 .29 .363 r
.28167 .49407 .28318 .49046 .28467 .49406 .28329 .49587 Mtetra
.332 0 .05 r
.28329 .49587 .28467 .49406 .28644 .49373 .28507 .49554 Mtetra
.153 0 0 r
.28507 .49554 .28644 .49373 .28827 .49276 .28689 .49467 Mtetra
.158 0 0 r
.28689 .49467 .28827 .49276 .29005 .4923 .28871 .49376 Mtetra
.18 0 0 r
.28871 .49376 .29005 .4923 .29177 .49284 .29051 .49316 Mtetra
.289 .783 .744 r
.29051 .49316 .29177 .49284 .2935 .49323 .29231 .49255 Mtetra
.616 .839 .985 r
.29231 .49255 .2935 .49323 .29526 .49321 .2941 .49199 Mtetra
.627 .731 .922 r
.2941 .49199 .29526 .49321 .29705 .49271 .2959 .49148 Mtetra
.647 .736 .914 r
.2959 .49148 .29705 .49271 .29886 .49207 .2977 .49089 Mtetra
.663 .75 .915 r
.2977 .49089 .29886 .49207 .30066 .49158 .29951 .49023 Mtetra
.685 .728 .883 r
.29951 .49023 .30066 .49158 .30244 .49133 .30133 .48944 Mtetra
.735 .674 .792 r
.30133 .48944 .30244 .49133 .30425 .49066 .30319 .48808 Mtetra
.811 .656 .69 r
.30319 .48808 .30425 .49066 .30615 .48866 .30518 .4848 Mtetra
.954 .687 .491 r
.30518 .4848 .30615 .48866 .30832 .48253 .32021 .28356 Mtetra
.549 .315 .514 r
.32021 .28356 .30832 .48253 .32347 .27665 .32271 .27067 Mtetra
.697 .503 .621 r
.32271 .27067 .32347 .27665 .32547 .27135 .32457 .26759 Mtetra
.627 .499 .687 r
.32457 .26759 .32547 .27135 .32719 .27042 .32629 .26668 Mtetra
.577 .468 .693 r
.32629 .26668 .32719 .27042 .32887 .27013 .32797 .2663 Mtetra
.562 .455 .69 r
.32797 .2663 .32887 .27013 .33057 .26953 .32965 .26605 Mtetra
.595 .489 .703 r
.32965 .26605 .33057 .26953 .33233 .2679 .33134 .26553 Mtetra
.615 .565 .775 r
.33134 .26553 .33233 .2679 .33409 .26639 .33304 .26501 Mtetra
.64 .693 .884 r
.33304 .26501 .33409 .26639 .33583 .26523 .33473 .26448 Mtetra
.643 .823 .969 r
.33473 .26448 .33583 .26523 .33753 .26454 .33643 .2639 Mtetra
.645 .847 .977 r
.33643 .2639 .33753 .26454 .33923 .264 .33814 .26329 Mtetra
.67 .837 .964 r
.33814 .26329 .33923 .264 .34093 .26352 .33985 .26261 Mtetra
.697 .802 .93 r
.33985 .26261 .34093 .26352 .34263 .26299 .34157 .26184 Mtetra
.68 .748 .903 r
.34157 .26184 .34263 .26299 .34433 .26245 .34328 .26114 Mtetra
.633 .703 .897 r
.34328 .26114 .34433 .26245 .34604 .26184 .34498 .26064 Mtetra
.511 .675 .938 r
.34498 .26064 .34604 .26184 .34776 .2611 .34666 .26053 Mtetra
.303 .719 .975 r
.34666 .26053 .34776 .2611 .34948 .26034 .34834 .26054 Mtetra
0 0 0 r
.34834 .26054 .34948 .26034 .3512 .25951 .35003 .2603 Mtetra
.35003 .2603 .3512 .25951 .35294 .25851 .35177 .25924 Mtetra
.35177 .25924 .35294 .25851 .35465 .2579 .35349 .2586 Mtetra
.589 .082 .017 r
.35349 .2586 .35465 .2579 .35631 .25825 .35512 .25949 Mtetra
.958 .681 .469 r
.35512 .25949 .35631 .25825 .35779 .26202 .34605 .45668 Mtetra
.549 .311 .506 r
.34605 .45668 .35779 .26202 .34849 .46688 .34701 .4721 Mtetra
.65 .324 .407 r
.34701 .4721 .34849 .46688 .34997 .47303 .34868 .47469 Mtetra
.364 0 .046 r
.34868 .47469 .34997 .47303 .35172 .474 .3505 .47453 Mtetra
.298 .771 .658 r
.3505 .47453 .35172 .474 .35352 .47413 .35235 .4737 Mtetra
.75 .921 .948 r
.35235 .4737 .35352 .47413 .35534 .47393 .35422 .47259 Mtetra
.678 .731 .89 r
.35422 .47259 .35534 .47393 .35716 .47389 .35607 .47183 Mtetra
.716 .654 .787 r
.35607 .47183 .35716 .47389 .359 .47333 .35795 .47057 Mtetra
.774 .633 .705 r
.35795 .47057 .359 .47333 .36089 .47178 .35989 .46802 Mtetra
.897 .663 .575 r
.35989 .46802 .36089 .47178 .36295 .46688 .3623 .45608 Mtetra
.952 .678 .482 r
.3623 .45608 .36295 .46688 .37474 .26198 .37408 .25278 Mtetra
.672 .46 .589 r
.37408 .25278 .37474 .26198 .37689 .25284 .37597 .24887 Mtetra
.636 .499 .679 r
.37597 .24887 .37689 .25284 .37865 .25163 .37772 .24778 Mtetra
.587 .472 .689 r
.37772 .24778 .37865 .25163 .38037 .2512 .37945 .24728 Mtetra
.561 .453 .688 r
.37945 .24728 .38037 .2512 .38209 .2508 .38116 .24703 Mtetra
.594 .479 .692 r
.38116 .24703 .38209 .2508 .38388 .2491 .38289 .24647 Mtetra
.614 .547 .756 r
.38289 .24647 .38388 .2491 .38565 .24752 .38463 .24592 Mtetra
.644 .664 .855 r
.38463 .24592 .38565 .24752 .38742 .24622 .38636 .24534 Mtetra
.673 .806 .946 r
.38636 .24534 .38742 .24622 .38916 .24546 .3881 .24466 Mtetra
.678 .824 .954 r
.3881 .24466 .38916 .24546 .3909 .24486 .38984 .24395 Mtetra
.681 .801 .939 r
.38984 .24395 .3909 .24486 .39263 .24435 .39158 .24324 Mtetra
.684 .761 .91 r
.39158 .24324 .39263 .24435 .39437 .24381 .39333 .24251 Mtetra
.666 .721 .89 r
.39333 .24251 .39437 .24381 .39611 .24326 .39507 .24185 Mtetra
.634 .69 .885 r
.39507 .24185 .39611 .24326 .39785 .24267 .39681 .24133 Mtetra
.526 .656 .918 r
.39681 .24133 .39785 .24267 .39959 .24194 .39853 .24121 Mtetra
.375 .721 .988 r
.39853 .24121 .39959 .24194 .40134 .24118 .40025 .2412 Mtetra
.021 .594 .714 r
.40025 .2412 .40134 .24118 .40309 .24043 .40198 .24116 Mtetra
0 0 0 r
.40198 .24116 .40309 .24043 .40484 .23975 .40372 .24061 Mtetra
.40372 .24061 .40484 .23975 .40659 .23908 .40547 .23991 Mtetra
.40547 .23991 .40659 .23908 .40834 .23843 .40723 .23913 Mtetra
.40723 .23913 .40834 .23843 .41009 .23777 .40898 .23845 Mtetra
.40898 .23845 .41009 .23777 .41185 .23711 .41074 .23778 Mtetra
.41074 .23778 .41185 .23711 .4136 .23645 .41249 .2371 Mtetra
.433 .835 .635 r
.41249 .2371 .4136 .23645 .41537 .23544 .41427 .23593 Mtetra
0 0 0 r
.41427 .23593 .41537 .23544 .41712 .23473 .41603 .2352 Mtetra
.287 0 0 r
.41603 .2352 .41712 .23473 .41886 .23462 .41776 .23533 Mtetra
.902 .541 .343 r
.41776 .23533 .41886 .23462 .42049 .23763 .41925 .24236 Mtetra
.96 .676 .453 r
.41925 .24236 .42049 .23763 .41543 .4404 .41402 .44826 Mtetra
.658 .351 .441 r
.41402 .44826 .41543 .4404 .41696 .45028 .41575 .45215 Mtetra
.422 0 .107 r
.41575 .45215 .41696 .45028 .41881 .4506 .41762 .45216 Mtetra
.187 0 0 r
.41762 .45216 .41881 .4506 .4207 .44986 .41951 .45147 Mtetra
.068 0 0 r
.41951 .45147 .4207 .44986 .42261 .44858 .42141 .45043 Mtetra
.277 0 .028 r
.42141 .45043 .42261 .44858 .42451 .44774 .4233 .44987 Mtetra
.311 0 .086 r
.4233 .44987 .42451 .44774 .4264 .44705 .42519 .44931 Mtetra
.318 0 .106 r
.42519 .44931 .4264 .44705 .42828 .44665 .42708 .44872 Mtetra
.297 0 .071 r
.42708 .44872 .42828 .44665 .43014 .44714 .42897 .44813 Mtetra
.044 0 0 r
.42897 .44813 .43014 .44714 .432 .44761 .43087 .44747 Mtetra
.568 .924 .949 r
.43087 .44747 .432 .44761 .43387 .44787 .43277 .44669 Mtetra
.746 .784 .883 r
.43277 .44669 .43387 .44787 .43576 .44757 .43468 .44554 Mtetra
.72 .663 .793 r
.43468 .44554 .43576 .44757 .43766 .44707 .4366 .44425 Mtetra
.687 .589 .74 r
.4366 .44425 .43766 .44707 .43956 .44644 .43852 .44296 Mtetra
.561 .482 .723 r
.43852 .44296 .43956 .44644 .44145 .44614 .44041 .44272 Mtetra
.585 .5 .725 r
.44041 .44272 .44145 .44614 .44336 .44554 .44231 .44229 Mtetra
.666 .555 .72 r
.44231 .44229 .44336 .44554 .44527 .44434 .44423 .44107 Mtetra
.873 .661 .613 r
.44423 .44107 .44527 .44434 .44726 .44041 .44628 .43417 Mtetra
.964 .684 .454 r
.44628 .43417 .44726 .44041 .44949 .42581 .45308 .22564 Mtetra
.531 .301 .51 r
.45308 .22564 .44949 .42581 .45593 .22448 .45498 .22028 Mtetra
.655 .506 .669 r
.45498 .22028 .45593 .22448 .45776 .22163 .45678 .21886 Mtetra
.612 .539 .748 r
.45678 .21886 .45776 .22163 .45956 .22009 .45856 .21829 Mtetra
.561 .602 .852 r
.45856 .21829 .45956 .22009 .46136 .21907 .46033 .21809 Mtetra
.634 .777 .949 r
.46033 .21809 .46136 .21907 .46314 .21828 .46212 .21754 Mtetra
.643 .836 .975 r
.46212 .21754 .46314 .21828 .46493 .21766 .4639 .21692 Mtetra
.651 .837 .972 r
.4639 .21692 .46493 .21766 .46671 .21715 .46569 .21627 Mtetra
.693 .817 .942 r
.46569 .21627 .46671 .21715 .4685 .21661 .46748 .21548 Mtetra
.689 .766 .911 r
.46748 .21548 .4685 .21661 .47029 .21605 .46928 .21471 Mtetra
.664 .72 .89 r
.46928 .21471 .47029 .21605 .47208 .21545 .47107 .21404 Mtetra
.568 .668 .905 r
.47107 .21404 .47208 .21545 .47387 .2147 .47286 .21377 Mtetra
.455 .717 .98 r
.47286 .21377 .47387 .2147 .47567 .21391 .47464 .2137 Mtetra
.148 .68 .857 r
.47464 .2137 .47567 .21391 .47747 .21311 .47643 .21366 Mtetra
0 0 0 r
.47643 .21366 .47747 .21311 .47927 .21206 .47823 .21271 Mtetra
.47823 .21271 .47927 .21206 .48107 .21123 .48003 .2118 Mtetra
.132 0 0 r
.48003 .2118 .48107 .21123 .48286 .21092 .48182 .21158 Mtetra
.862 .453 .256 r
.48182 .21158 .48286 .21092 .48462 .21291 .48356 .21598 Mtetra
.967 .677 .429 r
.48356 .21598 .48462 .21291 .48628 .22386 .48265 .42404 Mtetra
.528 .293 .502 r
.48265 .42404 .48628 .22386 .48563 .42671 .48451 .42902 Mtetra
.537 .128 .214 r
.48451 .42902 .48563 .42671 .48753 .42885 .48643 .42966 Mtetra
.046 0 0 r
.48643 .42966 .48753 .42885 .48945 .42928 .48836 .42911 Mtetra
.676 .96 .942 r
.48836 .42911 .48945 .42928 .49138 .42911 .4903 .42805 Mtetra
.687 .797 .933 r
.4903 .42805 .49138 .42911 .49332 .429 .49224 .42723 Mtetra
.703 .689 .833 r
.49224 .42723 .49332 .429 .49525 .42856 .49419 .42618 Mtetra
.749 .65 .751 r
.49419 .42618 .49525 .42856 .4972 .42747 .49614 .42438 Mtetra
.868 .665 .627 r
.49614 .42438 .4972 .42747 .49916 .42412 .49813 .41848 Mtetra
.968 .683 .436 r
.49813 .41848 .49916 .42412 .50117 .4144 .50167 .20894 Mtetra
.532 .301 .51 r
.50167 .20894 .50117 .4144 .5045 .20756 .50352 .20285 Mtetra
.666 .501 .652 r
.50352 .20285 .5045 .20756 .50633 .20404 .50534 .20104 Mtetra
.615 .529 .734 r
.50534 .20104 .50633 .20404 .50815 .20238 .50716 .2004 Mtetra
.567 .586 .832 r
.50716 .2004 .50815 .20238 .50997 .20132 .50897 .20018 Mtetra
.613 .741 .937 r
.50897 .20018 .50997 .20132 .51179 .20057 .51079 .19971 Mtetra
.648 .815 .963 r
.51079 .19971 .51179 .20057 .51361 .20003 .51261 .19908 Mtetra
.661 .8 .95 r
.51261 .19908 .51361 .20003 .51543 .19958 .51443 .19842 Mtetra
.694 .767 .907 r
.51443 .19842 .51543 .19958 .51725 .19898 .51625 .19761 Mtetra
.694 .728 .877 r
.51625 .19761 .51725 .19898 .51907 .19827 .51808 .19676 Mtetra
.672 .699 .867 r
.51808 .19676 .51907 .19827 .52089 .19752 .5199 .19602 Mtetra
.662 .696 .871 r
.5199 .19602 .52089 .19752 .52272 .19634 .52173 .19533 Mtetra
.587 .759 .961 r
.52173 .19533 .52272 .19634 .52454 .19527 .52355 .19493 Mtetra
.023 .573 .831 r
.52355 .19493 .52454 .19527 .52637 .19481 .52538 .19517 Mtetra
.836 .388 .158 r
.52538 .19517 .52637 .19481 .5282 .19713 .52722 .1986 Mtetra
.971 .677 .409 r
.52722 .1986 .5282 .19713 .53039 .40408 .52934 .40671 Mtetra
.829 .46 .357 r
.52934 .40671 .53039 .40408 .53237 .41414 .53131 .41287 Mtetra
0 .357 .827 r
.53131 .41287 .53237 .41414 .53434 .41538 .53328 .41397 Mtetra
.591 .699 .918 r
.53328 .41397 .53434 .41538 .53631 .41478 .53525 .41357 Mtetra
.708 .778 .907 r
.53525 .41357 .53631 .41478 .53828 .41365 .53722 .41262 Mtetra
.686 .807 .939 r
.53722 .41262 .53828 .41365 .54025 .41322 .5392 .41179 Mtetra
.699 .739 .882 r
.5392 .41179 .54025 .41322 .54223 .41301 .54117 .41086 Mtetra
.744 .669 .777 r
.54117 .41086 .54223 .41301 .5442 .41216 .54314 .40926 Mtetra
.85 .666 .653 r
.54314 .40926 .5442 .41216 .54616 .40853 .54509 .40466 Mtetra
.973 .684 .417 r
.54509 .40466 .54616 .40853 .54667 .20448 .54563 .1958 Mtetra
.771 .531 .573 r
.54563 .1958 .54667 .20448 .5484 .18876 .54742 .18763 Mtetra
.868 .804 .785 r
.54742 .18763 .5484 .18876 .55023 .18621 .54926 .18535 Mtetra
.67 .826 .959 r
.54926 .18535 .55023 .18621 .55208 .18554 .5511 .18463 Mtetra
.52 .757 .983 r
.5511 .18463 .55208 .18554 .55393 .18542 .55295 .18438 Mtetra
.589 .756 .958 r
.55295 .18438 .55393 .18542 .55578 .18511 .5548 .18397 Mtetra
.659 .763 .927 r
.5548 .18397 .55578 .18511 .55763 .18448 .55665 .18332 Mtetra
.665 .76 .921 r
.55665 .18332 .55763 .18448 .55948 .18381 .5585 .18263 Mtetra
.738 .781 .887 r
.5585 .18263 .55948 .18381 .56132 .18276 .56035 .18157 Mtetra
.741 .779 .883 r
.56035 .18157 .56132 .18276 .56317 .18168 .5622 .18048 Mtetra
.618 .734 .929 r
.5622 .18048 .56317 .18168 .56502 .1812 .56405 .17999 Mtetra
0 0 .532 r
.56405 .17999 .56502 .1812 .56692 .18328 .56594 .18205 Mtetra
.975 .678 .388 r
.56594 .18205 .56692 .18328 .57181 .39045 .57077 .38902 Mtetra
.938 .573 .186 r
.57077 .38902 .57181 .39045 .57396 .4003 .57292 .39903 Mtetra
0 .218 .726 r
.57292 .39903 .57396 .4003 .57599 .40176 .57495 .40055 Mtetra
.624 .753 .939 r
.57495 .40055 .57599 .40176 .57799 .4011 .57695 .39998 Mtetra
.744 .811 .905 r
.57695 .39998 .57799 .4011 .57998 .39983 .57894 .39884 Mtetra
.734 .832 .925 r
.57894 .39884 .57998 .39983 .58197 .39865 .58094 .39776 Mtetra
.671 .835 .962 r
.58094 .39776 .58197 .39865 .58397 .39783 .58294 .39697 Mtetra
.667 .841 .967 r
.58294 .39697 .58397 .39783 .58597 .39703 .58494 .39618 Mtetra
.658 .842 .971 r
.58494 .39618 .58597 .39703 .58797 .39626 .58694 .39543 Mtetra
.646 .841 .975 r
.58694 .39543 .58797 .39626 .58998 .39554 .58895 .39472 Mtetra
.638 .84 .978 r
.58895 .39472 .58998 .39554 .59198 .39486 .59096 .39403 Mtetra
.63 .835 .979 r
.59096 .39403 .59198 .39486 .59399 .39428 .59297 .39337 Mtetra
.629 .818 .973 r
.59297 .39337 .59399 .39428 .59601 .39377 .59498 .39273 Mtetra
.633 .792 .959 r
.59498 .39273 .59601 .39377 .59802 .39328 .597 .3921 Mtetra
.636 .767 .942 r
.597 .3921 .59802 .39328 .60004 .39274 .59901 .39148 Mtetra
.638 .752 .931 r
.59901 .39148 .60004 .39274 .60206 .39215 .60103 .39086 Mtetra
.639 .746 .927 r
.60103 .39086 .60206 .39215 .60408 .39153 .60305 .39023 Mtetra
.64 .745 .925 r
.60305 .39023 .60408 .39153 .6061 .39091 .60507 .3896 Mtetra
.641 .744 .923 r
.60507 .3896 .6061 .39091 .60812 .39028 .60709 .38896 Mtetra
.642 .743 .922 r
.60709 .38896 .60812 .39028 .61014 .38965 .60911 .38832 Mtetra
.643 .742 .921 r
.60911 .38832 .61014 .38965 .61216 .389 .61114 .38767 Mtetra
.644 .742 .92 r
.61114 .38767 .61216 .389 .61419 .38835 .61316 .38702 Mtetra
.645 .742 .92 r
.61316 .38702 .61419 .38835 .61621 .3877 .61519 .38637 Mtetra
.646 .742 .92 r
.61519 .38637 .61621 .3877 .61824 .38704 .61722 .38571 Mtetra
.646 .743 .92 r
.61722 .38571 .61824 .38704 .62027 .38637 .61925 .38504 Mtetra
.646 .744 .92 r
.61925 .38504 .62027 .38637 .6223 .3857 .62128 .38438 Mtetra
.646 .746 .922 r
.62128 .38438 .6223 .3857 .62433 .38503 .62331 .38372 Mtetra
.645 .747 .923 r
.62331 .38372 .62433 .38503 .62636 .38436 .62535 .38306 Mtetra
.644 .748 .925 r
.62535 .38306 .62636 .38436 .6284 .38368 .62738 .38241 Mtetra
.634 .749 .931 r
.62738 .38241 .6284 .38368 .63043 .38296 .62942 .3818 Mtetra
.621 .766 .949 r
.62942 .3818 .63043 .38296 .63247 .38219 .63146 .38123 Mtetra
.632 .812 .969 r
.63146 .38123 .63247 .38219 .6345 .38145 .6335 .38058 Mtetra
.692 .85 .958 r
.6335 .38058 .6345 .38145 .63654 .38084 .63554 .37968 Mtetra
.756 .811 .896 r
.63554 .37968 .63654 .38084 .63859 .38038 .63756 .37843 Mtetra
.727 .687 .812 r
.63756 .37843 .63859 .38038 .64065 .37995 .63958 .37711 Mtetra
.638 .569 .761 r
.63958 .37711 .64065 .37995 .64271 .37968 .64162 .37628 Mtetra
.547 .483 .736 r
.64162 .37628 .64271 .37968 .64477 .37954 .64369 .37616 Mtetra
.602 .517 .731 r
.64369 .37616 .64477 .37954 .64682 .37885 .64574 .37555 Mtetra
.754 .607 .694 r
.64574 .37555 .64682 .37885 .64881 .37651 .64772 .37302 Mtetra
.94 .683 .521 r
.64772 .37302 .64881 .37651 .65055 .36803 .64926 .35927 Mtetra
.973 .673 .386 r
.64926 .35927 .65055 .36803 .64413 .15595 .64317 .15403 Mtetra
.879 .727 .689 r
.64317 .15403 .64413 .15595 .6459 .15166 .64496 .15046 Mtetra
.719 .779 .9 r
.64496 .15046 .6459 .15166 .64779 .15064 .64686 .14949 Mtetra
.59 .74 .947 r
.64686 .14949 .64779 .15064 .64972 .15027 .64879 .14907 Mtetra
.57 .721 .944 r
.64879 .14907 .64972 .15027 .65165 .15001 .65071 .14874 Mtetra
.669 .748 .91 r
.65071 .14874 .65165 .15001 .65356 .1493 .65263 .14801 Mtetra
.676 .749 .905 r
.65263 .14801 .65356 .1493 .65547 .14855 .65454 .14724 Mtetra
.69 .751 .898 r
.65454 .14724 .65547 .14855 .65738 .14772 .65645 .14641 Mtetra
.708 .757 .89 r
.65645 .14641 .65738 .14772 .65929 .14677 .65836 .14547 Mtetra
.699 .755 .896 r
.65836 .14547 .65929 .14677 .6612 .1459 .66027 .14459 Mtetra
.692 .751 .897 r
.66027 .14459 .6612 .1459 .66311 .14513 .66218 .14374 Mtetra
.684 .734 .889 r
.66218 .14374 .66311 .14513 .66504 .1445 .6641 .14292 Mtetra
.585 .659 .888 r
.6641 .14292 .66504 .1445 .66699 .14436 .66604 .14257 Mtetra
.22 .414 .84 r
.66604 .14257 .66699 .14436 .66901 .14564 .66804 .14355 Mtetra
.866 .505 .007 r
.66804 .14355 .66901 .14564 .67161 .15878 .67043 .15217 Mtetra
.976 .671 .322 r
.67043 .15217 .67161 .15878 .68372 .36195 .68272 .36031 Mtetra
0 0 .488 r
.68272 .36031 .68372 .36195 .68597 .36473 .68498 .3634 Mtetra
.51 .686 .946 r
.68498 .3634 .68597 .36473 .68808 .36465 .68709 .36325 Mtetra
.666 .745 .909 r
.68709 .36325 .68808 .36465 .69015 .36386 .68916 .36247 Mtetra
.662 .745 .911 r
.68916 .36247 .69015 .36386 .69221 .36276 .69124 .36172 Mtetra
.395 .685 .977 r
.69124 .36172 .69221 .36276 .69428 .36182 .69336 .36178 Mtetra
.28 .783 .836 r
.69336 .36178 .69428 .36182 .69632 .36031 .69546 .36132 Mtetra
0 0 0 r
.69546 .36132 .69632 .36031 .69828 .35727 .69749 .35953 Mtetra
.828 .788 .288 r
.69749 .35953 .69828 .35727 .69938 .33874 .69923 .35246 Mtetra
.977 .684 .309 r
.69923 .35246 .69938 .33874 .6903 .13844 .68947 .13873 Mtetra
.989 .881 .547 r
.68947 .13873 .6903 .13844 .69207 .13477 .69116 .13344 Mtetra
.747 .77 .872 r
.69116 .13344 .69207 .13477 .69399 .1337 .69307 .13225 Mtetra
.613 .695 .902 r
.69307 .13225 .69399 .1337 .69595 .13319 .69503 .13177 Mtetra
.558 .674 .916 r
.69503 .13177 .69595 .13319 .69791 .13284 .697 .13151 Mtetra
.676 .744 .902 r
.697 .13151 .69791 .13284 .69985 .13207 .69894 .13073 Mtetra
.682 .746 .9 r
.69894 .13073 .69985 .13207 .70179 .13125 .70088 .12992 Mtetra
.706 .757 .892 r
.70088 .12992 .70179 .13125 .70372 .1303 .70282 .12899 Mtetra
.773 .782 .86 r
.70282 .12899 .70372 .1303 .70563 .12891 .70473 .12762 Mtetra
.704 .765 .9 r
.70473 .12762 .70563 .12891 .70757 .12796 .70666 .12671 Mtetra
.429 .64 .945 r
.70666 .12671 .70757 .12796 .70957 .12804 .70867 .12681 Mtetra
.784 .359 0 r
.70867 .12681 .70957 .12804 .71187 .13283 .71097 .13173 Mtetra
.973 .662 .316 r
.71097 .13173 .71187 .13283 .72747 .34552 .72652 .34439 Mtetra
.77 .326 0 r
.72652 .34439 .72747 .34552 .72993 .35033 .72897 .34909 Mtetra
.477 .688 .959 r
.72897 .34909 .72993 .35033 .73208 .35026 .73112 .34901 Mtetra
.682 .782 .926 r
.73112 .34901 .73208 .35026 .73418 .34939 .73322 .34815 Mtetra
.727 .8 .909 r
.73322 .34815 .73418 .34939 .73627 .34824 .73531 .34704 Mtetra
.456 .687 .965 r
.73531 .34704 .73627 .34824 .73841 .34804 .73747 .34701 Mtetra
.588 .79 .976 r
.73747 .34701 .73841 .34804 .74054 .34747 .7396 .3465 Mtetra
.809 .872 .894 r
.7396 .3465 .74054 .34747 .74261 .34609 .74166 .34492 Mtetra
.982 .784 .563 r
.74166 .34492 .74261 .34609 .74446 .34143 .74333 .33772 Mtetra
.975 .669 .332 r
.74333 .33772 .74446 .34143 .73221 .1357 .73054 .12346 Mtetra
.672 .441 .563 r
.73054 .12346 .73221 .1357 .73331 .12263 .73218 .11798 Mtetra
.625 .479 .663 r
.73218 .11798 .73331 .12263 .73516 .12018 .73412 .1168 Mtetra
.584 .498 .724 r
.73412 .1168 .73516 .12018 .73707 .11869 .73611 .11635 Mtetra
.54 .544 .807 r
.73611 .11635 .73707 .11869 .73902 .11768 .73812 .11626 Mtetra
.644 .718 .902 r
.73812 .11626 .73902 .11768 .74099 .11688 .74011 .11562 Mtetra
.653 .752 .923 r
.74011 .11562 .74099 .11688 .74297 .11625 .74208 .11495 Mtetra
.666 .75 .913 r
.74208 .11495 .74297 .11625 .74496 .11566 .74406 .11421 Mtetra
.702 .739 .88 r
.74406 .11421 .74496 .11566 .74693 .11488 .74602 .11327 Mtetra
.689 .708 .863 r
.74602 .11327 .74693 .11488 .7489 .11406 .74799 .11236 Mtetra
.665 .685 .86 r
.74799 .11236 .7489 .11406 .75087 .1132 .74996 .11159 Mtetra
.656 .694 .873 r
.74996 .11159 .75087 .1132 .75281 .11188 .75195 .11087 Mtetra
.521 .748 .978 r
.75195 .11087 .75281 .11188 .75477 .1109 .75397 .11061 Mtetra
0 .407 .709 r
.75397 .11061 .75477 .1109 .75678 .11055 .75606 .11123 Mtetra
.919 .662 .533 r
.11892 .35739 .12187 .34433 .12234 .35244 .09588 .55036 Mtetra
.525 .291 .503 r
.09588 .55036 .12234 .35244 .09862 .55209 .09706 .55367 Mtetra
.663 .259 .268 r
.09706 .55367 .09862 .55209 .09978 .55565 .09848 .55506 Mtetra
.266 .698 .965 r
.09848 .55506 .09978 .55565 .10136 .55579 .10008 .55512 Mtetra
.632 .829 .976 r
.10008 .55512 .10136 .55579 .10304 .5552 .10175 .55457 Mtetra
.771 .852 .912 r
.10175 .55457 .10304 .5552 .10478 .55414 .1035 .55344 Mtetra
.858 .817 .808 r
.1035 .55344 .10478 .55414 .10647 .55348 .10537 .55135 Mtetra
.827 .674 .693 r
.10537 .55135 .10647 .55348 .10821 .55241 .1074 .54789 Mtetra
.835 .621 .613 r
.1074 .54789 .10821 .55241 .11005 .5505 .11005 .53946 Mtetra
.926 .674 .536 r
.11005 .53946 .11005 .5505 .11263 .54258 .13604 .34112 Mtetra
.53 .3 .511 r
.13604 .34112 .11263 .54258 .13892 .34029 .13811 .33656 Mtetra
.726 .56 .666 r
.13811 .33656 .13892 .34029 .14101 .33561 .13991 .33416 Mtetra
.698 .688 .837 r
.13991 .33416 .14101 .33561 .14266 .33442 .14152 .33332 Mtetra
.598 .718 .928 r
.14152 .33332 .14266 .33442 .14423 .33398 .14308 .33298 Mtetra
.504 .706 .961 r
.14308 .33298 .14423 .33398 .14575 .33388 .14461 .33286 Mtetra
.635 .745 .928 r
.14461 .33286 .14575 .33388 .14733 .33341 .14618 .33238 Mtetra
.663 .752 .917 r
.14618 .33238 .14733 .33341 .14891 .33286 .14777 .33181 Mtetra
.679 .749 .904 r
.14777 .33181 .14891 .33286 .15049 .33228 .14936 .33115 Mtetra
.74 .748 .859 r
.14936 .33115 .15049 .33228 .1521 .33152 .151 .33015 Mtetra
.709 .703 .842 r
.151 .33015 .1521 .33152 .15371 .33078 .15263 .32926 Mtetra
.646 .662 .851 r
.15263 .32926 .15371 .33078 .15531 .33014 .15421 .32871 Mtetra
.199 .457 .879 r
.15421 .32871 .15531 .33014 .1569 .32954 .15567 .32931 Mtetra
.788 .302 .065 r
.15567 .32931 .1569 .32954 .15845 .32928 .15698 .33114 Mtetra
.837 .509 .433 r
.15698 .33114 .15845 .32928 .15993 .32973 .15786 .33669 Mtetra
.931 .672 .523 r
.15786 .33669 .15993 .32973 .16092 .33441 .13649 .53462 Mtetra
.527 .293 .503 r
.13649 .53462 .16092 .33441 .13923 .53667 .13762 .539 Mtetra
.666 .293 .329 r
.13762 .539 .13923 .53667 .14031 .54145 .13906 .54068 Mtetra
.2 .622 .949 r
.13906 .54068 .14031 .54145 .14188 .54198 .14066 .54092 Mtetra
.623 .75 .938 r
.14066 .54092 .14188 .54198 .14358 .54146 .14235 .54045 Mtetra
.747 .785 .884 r
.14235 .54045 .14358 .54146 .14533 .54043 .14411 .53939 Mtetra
.831 .778 .802 r
.14411 .53939 .14533 .54043 .14705 .53978 .14597 .53744 Mtetra
.815 .662 .693 r
.14597 .53744 .14705 .53978 .14879 .53887 .14798 .53414 Mtetra
.826 .612 .613 r
.14798 .53414 .14879 .53887 .15062 .53717 .15049 .52637 Mtetra
.931 .675 .529 r
.15049 .52637 .15062 .53717 .15299 .53061 .17426 .32753 Mtetra
.53 .3 .511 r
.17426 .32753 .15299 .53061 .17711 .32706 .17634 .32272 Mtetra
.713 .539 .651 r
.17634 .32272 .17711 .32706 .17922 .32185 .17816 .32018 Mtetra
.71 .668 .806 r
.17816 .32018 .17922 .32185 .18093 .32035 .17981 .31918 Mtetra
.612 .71 .915 r
.17981 .31918 .18093 .32035 .18253 .31984 .18139 .31878 Mtetra
.52 .701 .953 r
.18139 .31878 .18253 .31984 .18408 .3197 .18295 .31864 Mtetra
.675 .75 .908 r
.18295 .31864 .18408 .3197 .18568 .31919 .18457 .318 Mtetra
.686 .73 .884 r
.18457 .318 .18568 .31919 .1873 .31855 .18619 .31729 Mtetra
.624 .698 .898 r
.18619 .31729 .1873 .31855 .18891 .31799 .18779 .31685 Mtetra
.168 .503 .91 r
.18779 .31685 .18891 .31799 .19052 .31738 .18928 .31735 Mtetra
.764 .277 .072 r
.18928 .31735 .19052 .31738 .19211 .31703 .19065 .31907 Mtetra
.825 .491 .423 r
.19065 .31907 .19211 .31703 .19363 .31733 .19166 .32424 Mtetra
.935 .672 .515 r
.19166 .32424 .19363 .31733 .19477 .3213 .17232 .52249 Mtetra
.528 .293 .503 r
.17232 .52249 .19477 .3213 .17511 .52423 .17349 .52713 Mtetra
.661 .303 .355 r
.17349 .52713 .17511 .52423 .17622 .52957 .17496 .52898 Mtetra
0 .295 .658 r
.17496 .52898 .17622 .52957 .17776 .53078 .17655 .5297 Mtetra
.491 .7 .962 r
.17655 .5297 .17776 .53078 .17944 .5306 .17822 .5296 Mtetra
.731 .787 .897 r
.17822 .5296 .17944 .5306 .18123 .52941 .17999 .52863 Mtetra
.908 .783 .711 r
.17999 .52863 .18123 .52941 .18331 .52537 .18205 .52481 Mtetra
.946 .689 .517 r
.18205 .52481 .18331 .52537 .20553 .32292 .20419 .32402 Mtetra
.973 .765 .564 r
.20419 .32402 .20553 .32292 .2082 .31201 .20708 .31098 Mtetra
.852 .77 .77 r
.20708 .31098 .2082 .31201 .20999 .30982 .20887 .30872 Mtetra
.685 .747 .898 r
.20887 .30872 .20999 .30982 .21162 .30914 .21051 .30802 Mtetra
.552 .702 .94 r
.21051 .30802 .21162 .30914 .21321 .30893 .2121 .30781 Mtetra
.706 .749 .885 r
.2121 .30781 .21321 .30893 .21486 .30813 .21374 .307 Mtetra
.721 .751 .876 r
.21374 .307 .21486 .30813 .21651 .30724 .2154 .3061 Mtetra
.587 .711 .929 r
.2154 .3061 .21651 .30724 .21811 .30693 .217 .30579 Mtetra
.788 .316 0 r
.217 .30579 .21811 .30693 .21945 .30929 .21835 .30811 Mtetra
.948 .685 .504 r
.21835 .30811 .21945 .30929 .20147 .51086 .20031 .50941 Mtetra
.956 .637 .381 r
.20031 .50941 .20147 .51086 .20222 .52051 .20102 .5194 Mtetra
.583 .071 0 r
.20102 .5194 .20222 .52051 .20375 .52215 .20255 .52105 Mtetra
.533 .715 .956 r
.20255 .52105 .20375 .52215 .20545 .52195 .20426 .52085 Mtetra
.772 .776 .857 r
.20426 .52085 .20545 .52195 .20726 .52067 .20607 .51955 Mtetra
.896 .756 .698 r
.20607 .51955 .20726 .52067 .20933 .51671 .20814 .51553 Mtetra
.948 .689 .511 r
.20814 .51553 .20933 .51671 .23009 .31382 .22903 .31207 Mtetra
.918 .701 .594 r
.22903 .31207 .23009 .31382 .23268 .30301 .23159 .30178 Mtetra
.849 .748 .752 r
.23159 .30178 .23268 .30301 .23449 .30059 .2334 .29932 Mtetra
.711 .726 .862 r
.2334 .29932 .23449 .30059 .23615 .29982 .23507 .29845 Mtetra
.617 .68 .887 r
.23507 .29845 .23615 .29982 .23776 .29952 .23669 .29804 Mtetra
.684 .686 .846 r
.23669 .29804 .23776 .29952 .23941 .29882 .23835 .29727 Mtetra
.697 .682 .831 r
.23835 .29727 .23941 .29882 .24108 .29796 .24002 .2964 Mtetra
.59 .639 .868 r
.24002 .2964 .24108 .29796 .2427 .29766 .24163 .2961 Mtetra
0 0 .423 r
.24163 .2961 .2427 .29766 .2441 .29973 .24304 .2981 Mtetra
.951 .685 .497 r
.24304 .2981 .2441 .29973 .22774 .50054 .22669 .49796 Mtetra
.972 .668 .377 r
.22669 .49796 .22774 .50054 .22842 .51196 .22722 .51108 Mtetra
.647 .115 0 r
.22722 .51108 .22842 .51196 .22999 .51357 .22877 .51277 Mtetra
.565 .792 .985 r
.22877 .51277 .22999 .51357 .23173 .51317 .23051 .5124 Mtetra
.727 .837 .932 r
.23051 .5124 .23173 .51317 .23352 .51221 .23231 .51146 Mtetra
.668 .832 .962 r
.23231 .51146 .23352 .51221 .2353 .51142 .23408 .51077 Mtetra
.564 .827 .995 r
.23408 .51077 .2353 .51142 .23706 .51089 .23583 .51035 Mtetra
.663 .876 .978 r
.23583 .51035 .23706 .51089 .23883 .51025 .2376 .50962 Mtetra
.824 .863 .876 r
.2376 .50962 .23883 .51025 .2406 .50959 .23945 .50809 Mtetra
.847 .732 .736 r
.23945 .50809 .2406 .50959 .24239 .50871 .24141 .50527 Mtetra
.827 .633 .64 r
.24141 .50527 .24239 .50871 .24424 .5072 .24357 .49998 Mtetra
.944 .682 .508 r
.24357 .49998 .24424 .5072 .24631 .503 .26223 .29862 Mtetra
.536 .305 .512 r
.26223 .29862 .24631 .503 .26507 .29834 .26446 .29128 Mtetra
.679 .48 .609 r
.26446 .29128 .26507 .29834 .26735 .2903 .26633 .28815 Mtetra
.743 .641 .747 r
.26633 .28815 .26735 .2903 .26916 .28786 .26808 .28655 Mtetra
.681 .715 .875 r
.26808 .28655 .26916 .28786 .27083 .28708 .26975 .28584 Mtetra
.609 .703 .911 r
.26975 .28584 .27083 .28708 .27247 .28676 .2714 .28544 Mtetra
.595 .683 .903 r
.2714 .28544 .27247 .28676 .27411 .28645 .27304 .28511 Mtetra
.614 .685 .893 r
.27304 .28511 .27411 .28645 .27577 .28594 .27469 .28469 Mtetra
.62 .705 .906 r
.27469 .28469 .27577 .28594 .27743 .28543 .27634 .28426 Mtetra
.659 .733 .904 r
.27634 .28426 .27743 .28543 .2791 .28485 .27801 .28366 Mtetra
.696 .74 .885 r
.27801 .28366 .2791 .28485 .28077 .28419 .27969 .28288 Mtetra
.697 .72 .867 r
.27969 .28288 .28077 .28419 .28244 .28351 .28138 .28207 Mtetra
.7 .701 .847 r
.28138 .28207 .28244 .28351 .28412 .2828 .28307 .28121 Mtetra
.689 .676 .833 r
.28307 .28121 .28412 .2828 .2858 .28209 .28476 .28038 Mtetra
.64 .642 .837 r
.28476 .28038 .2858 .28209 .28748 .28146 .28643 .27982 Mtetra
.472 .574 .876 r
.28643 .27982 .28748 .28146 .28915 .28089 .28805 .27993 Mtetra
0 .083 .561 r
.28805 .27993 .28915 .28089 .29081 .28048 .28958 .28121 Mtetra
.832 .435 .298 r
.28958 .28121 .29081 .28048 .29243 .2806 .29095 .2846 Mtetra
.949 .678 .489 r
.29095 .2846 .29243 .2806 .29389 .28282 .27765 .48437 Mtetra
.533 .298 .504 r
.27765 .48437 .29389 .28282 .28058 .48526 .27883 .49194 Mtetra
.624 .316 .428 r
.27883 .49194 .28058 .48526 .28167 .49407 .28041 .49434 Mtetra
.488 0 0 r
.28041 .49434 .28167 .49407 .28329 .49587 .28211 .49501 Mtetra
.586 .791 .977 r
.28211 .49501 .28329 .49587 .28507 .49554 .28389 .49459 Mtetra
.689 .799 .933 r
.28389 .49459 .28507 .49554 .28689 .49467 .2857 .49381 Mtetra
.694 .819 .942 r
.2857 .49381 .28689 .49467 .28871 .49376 .28751 .49302 Mtetra
.634 .83 .976 r
.28751 .49302 .28871 .49376 .29051 .49316 .28931 .49242 Mtetra
.632 .832 .977 r
.28931 .49242 .29051 .49316 .29231 .49255 .29111 .49183 Mtetra
.592 .823 .987 r
.29111 .49183 .29231 .49255 .2941 .49199 .29291 .49134 Mtetra
.533 .819 .998 r
.29291 .49134 .2941 .49199 .2959 .49148 .2947 .49097 Mtetra
.619 .876 .99 r
.2947 .49097 .2959 .49148 .2977 .49089 .2965 .49034 Mtetra
.792 .891 .915 r
.2965 .49034 .2977 .49089 .29951 .49023 .29836 .48904 Mtetra
.861 .773 .763 r
.29836 .48904 .29951 .49023 .30133 .48944 .3003 .48646 Mtetra
.831 .648 .655 r
.3003 .48646 .30133 .48944 .30319 .48808 .30237 .4819 Mtetra
.951 .684 .493 r
.30237 .4819 .30319 .48808 .30518 .4848 .31744 .28273 Mtetra
.544 .311 .513 r
.31744 .28273 .30518 .4848 .32021 .28356 .31984 .27168 Mtetra
.636 .422 .575 r
.31984 .27168 .32021 .28356 .32271 .27067 .32173 .26814 Mtetra
.746 .62 .719 r
.32173 .26814 .32271 .27067 .32457 .26759 .32351 .26625 Mtetra
.693 .717 .868 r
.32351 .26625 .32457 .26759 .32629 .26668 .32522 .26545 Mtetra
.619 .711 .911 r
.32522 .26545 .32629 .26668 .32797 .2663 .32691 .265 Mtetra
.586 .687 .911 r
.32691 .265 .32797 .2663 .32965 .26605 .32859 .26469 Mtetra
.615 .687 .895 r
.32859 .26469 .32965 .26605 .33134 .26553 .33028 .26426 Mtetra
.611 .703 .91 r
.33028 .26426 .33134 .26553 .33304 .26501 .33197 .26385 Mtetra
.624 .727 .921 r
.33197 .26385 .33304 .26501 .33473 .26448 .33366 .26338 Mtetra
.654 .75 .92 r
.33366 .26338 .33473 .26448 .33643 .2639 .33536 .26279 Mtetra
.669 .754 .914 r
.33536 .26279 .33643 .2639 .33814 .26329 .33707 .26214 Mtetra
.699 .754 .894 r
.33707 .26214 .33814 .26329 .33985 .26261 .33879 .26134 Mtetra
.73 .741 .86 r
.33879 .26134 .33985 .26261 .34157 .26184 .34052 .26033 Mtetra
.682 .689 .85 r
.34052 .26033 .34157 .26184 .34328 .26114 .34224 .25956 Mtetra
.538 .617 .88 r
.34224 .25956 .34328 .26114 .34498 .26064 .34392 .25944 Mtetra
0 .067 .587 r
.34392 .25944 .34498 .26064 .34666 .26053 .34551 .26094 Mtetra
.848 .435 .253 r
.34551 .26094 .34666 .26053 .34834 .26054 .34698 .26441 Mtetra
.862 .547 .452 r
.34698 .26441 .34834 .26054 .35003 .2603 .34801 .27586 Mtetra
.449 .198 .44 r
.34801 .27586 .35003 .2603 .35177 .25924 .34981 .27389 Mtetra
.418 .17 .428 r
.34981 .27389 .35177 .25924 .35349 .2586 .35165 .27121 Mtetra
.943 .664 .481 r
.35165 .27121 .35349 .2586 .35512 .25949 .34287 .46009 Mtetra
.537 .301 .504 r
.34287 .46009 .35512 .25949 .34605 .45668 .34413 .4699 Mtetra
.596 .318 .465 r
.34413 .4699 .34605 .45668 .34701 .4721 .34576 .47299 Mtetra
.637 .155 .092 r
.34576 .47299 .34701 .4721 .34868 .47469 .3475 .47421 Mtetra
.437 .815 .991 r
.3475 .47421 .34868 .47469 .3505 .47453 .34933 .47393 Mtetra
.7 .882 .965 r
.34933 .47393 .3505 .47453 .35235 .4737 .35118 .47305 Mtetra
.816 .877 .89 r
.35118 .47305 .35235 .4737 .35422 .47259 .35307 .47156 Mtetra
.866 .802 .785 r
.35307 .47156 .35422 .47259 .35607 .47183 .35501 .46916 Mtetra
.831 .662 .672 r
.35501 .46916 .35607 .47183 .35795 .47057 .35703 .46521 Mtetra
.871 .631 .574 r
.35703 .46521 .35795 .47057 .35989 .46802 .35947 .45269 Mtetra
.946 .672 .487 r
.35947 .45269 .35989 .46802 .3623 .45608 .37122 .25379 Mtetra
.528 .298 .51 r
.37122 .25379 .3623 .45608 .37408 .25278 .37312 .24964 Mtetra
.741 .591 .689 r
.37312 .24964 .37408 .25278 .37597 .24887 .37493 .2474 Mtetra
.708 .707 .847 r
.37493 .2474 .37597 .24887 .37772 .24778 .37668 .24646 Mtetra
.641 .708 .896 r
.37668 .24646 .37772 .24778 .37945 .24728 .37841 .24592 Mtetra
.593 .682 .903 r
.37841 .24592 .37945 .24728 .38116 .24703 .38013 .24557 Mtetra
.619 .676 .882 r
.38013 .24557 .38116 .24703 .38289 .24647 .38185 .24512 Mtetra
.619 .694 .897 r
.38185 .24512 .38289 .24647 .38463 .24592 .38358 .24467 Mtetra
.638 .719 .906 r
.38358 .24467 .38463 .24592 .38636 .24534 .38531 .24413 Mtetra
.694 .746 .892 r
.38531 .24413 .38636 .24534 .3881 .24466 .38706 .24334 Mtetra
.699 .729 .874 r
.38706 .24334 .3881 .24466 .38984 .24395 .3888 .24251 Mtetra
.694 .707 .858 r
.3888 .24251 .38984 .24395 .39158 .24324 .39055 .24167 Mtetra
.697 .69 .84 r
.39055 .24167 .39158 .24324 .39333 .24251 .39231 .24078 Mtetra
.655 .653 .835 r
.39231 .24078 .39333 .24251 .39507 .24185 .39405 .24011 Mtetra
.569 .612 .856 r
.39405 .24011 .39507 .24185 .39681 .24133 .39578 .23988 Mtetra
0 .242 .756 r
.39578 .23988 .39681 .24133 .39853 .24121 .39744 .24115 Mtetra
.831 .37 .115 r
.39744 .24115 .39853 .24121 .40025 .2412 .39905 .24397 Mtetra
.862 .527 .417 r
.39905 .24397 .40025 .2412 .40198 .24116 .40042 .25262 Mtetra
.948 .664 .467 r
.40042 .25262 .40198 .24116 .40372 .24061 .39495 .43314 Mtetra
0 0 .286 r
.39495 .43314 .40372 .24061 .40547 .23991 .40356 .26095 Mtetra
.206 .013 .383 r
.40356 .26095 .40547 .23991 .40723 .23913 .40571 .25032 Mtetra
.47 .203 .427 r
.40571 .25032 .40723 .23913 .40898 .23845 .40748 .24941 Mtetra
.469 .201 .425 r
.40748 .24941 .40898 .23845 .41074 .23778 .40925 .24851 Mtetra
.466 .198 .423 r
.40925 .24851 .41074 .23778 .41249 .2371 .41102 .24755 Mtetra
.327 .081 .381 r
.41102 .24755 .41249 .2371 .41427 .23593 .41289 .24407 Mtetra
.442 .163 .394 r
.41289 .24407 .41427 .23593 .41603 .2352 .41467 .24302 Mtetra
.646 .343 .443 r
.41467 .24302 .41603 .2352 .41776 .23533 .41629 .24646 Mtetra
.951 .667 .461 r
.41629 .24646 .41776 .23533 .41925 .24236 .4111 .44545 Mtetra
.526 .291 .502 r
.4111 .44545 .41925 .24236 .41402 .44826 .41282 .44956 Mtetra
.691 .249 .195 r
.41282 .44956 .41402 .44826 .41575 .45215 .41462 .45136 Mtetra
.483 .775 .996 r
.41462 .45136 .41575 .45215 .41762 .45216 .4165 .45113 Mtetra
.656 .787 .945 r
.4165 .45113 .41762 .45216 .41951 .45147 .41839 .45046 Mtetra
.699 .804 .93 r
.41839 .45046 .41951 .45147 .42141 .45043 .42029 .44961 Mtetra
.573 .803 .986 r
.42029 .44961 .42141 .45043 .4233 .44987 .42217 .44917 Mtetra
.553 .824 .996 r
.42217 .44917 .4233 .44987 .42519 .44931 .42406 .44874 Mtetra
.555 .852 .998 r
.42406 .44874 .42519 .44931 .42708 .44872 .42595 .44824 Mtetra
.539 .863 .995 r
.42595 .44824 .42708 .44872 .42897 .44813 .42784 .44773 Mtetra
.615 .906 .984 r
.42784 .44773 .42897 .44813 .43087 .44747 .42974 .44701 Mtetra
.74 .922 .952 r
.42974 .44701 .43087 .44747 .43277 .44669 .43165 .4459 Mtetra
.895 .846 .788 r
.43165 .4459 .43277 .44669 .43468 .44554 .43361 .44334 Mtetra
.86 .698 .681 r
.43361 .44334 .43468 .44554 .4366 .44425 .4356 .43936 Mtetra
.834 .612 .601 r
.4356 .43936 .4366 .44425 .43852 .44296 .43768 .43188 Mtetra
.601 .4 .581 r
.43768 .43188 .43852 .44296 .44041 .44272 .43962 .42976 Mtetra
.51 .324 .565 r
.43962 .42976 .44041 .44272 .44231 .44229 .44149 .43023 Mtetra
.574 .376 .575 r
.44149 .43023 .44231 .44229 .44423 .44107 .44341 .42881 Mtetra
.957 .676 .461 r
.44341 .42881 .44423 .44107 .44628 .43417 .45023 .2272 Mtetra
.531 .3 .51 r
.45023 .2272 .44628 .43417 .45308 .22564 .45213 .22159 Mtetra
.743 .565 .653 r
.45213 .22159 .45308 .22564 .45498 .22028 .45397 .21863 Mtetra
.711 .689 .827 r
.45397 .21863 .45498 .22028 .45678 .21886 .45576 .2176 Mtetra
.617 .717 .917 r
.45576 .2176 .45678 .21886 .45856 .21829 .45754 .21714 Mtetra
.542 .707 .947 r
.45754 .21714 .45856 .21829 .46033 .21809 .45931 .21692 Mtetra
.636 .741 .924 r
.45931 .21692 .46033 .21809 .46212 .21754 .4611 .21637 Mtetra
.662 .751 .916 r
.4611 .21637 .46212 .21754 .4639 .21692 .46289 .21572 Mtetra
.675 .75 .908 r
.46289 .21572 .4639 .21692 .46569 .21627 .46468 .21502 Mtetra
.732 .756 .872 r
.46468 .21502 .46569 .21627 .46748 .21548 .46647 .21398 Mtetra
.704 .708 .851 r
.46647 .21398 .46748 .21548 .46928 .21471 .46827 .21305 Mtetra
.641 .661 .854 r
.46827 .21305 .46928 .21471 .47107 .21404 .47006 .21246 Mtetra
.185 .425 .858 r
.47006 .21246 .47107 .21404 .47286 .21377 .47183 .2133 Mtetra
.755 .241 0 r
.47183 .2133 .47286 .21377 .47464 .2137 .47358 .2156 Mtetra
.854 .488 .357 r
.47358 .2156 .47464 .2137 .47643 .21366 .47526 .22174 Mtetra
.633 .329 .438 r
.47526 .22174 .47643 .21366 .47823 .21271 .47701 .2249 Mtetra
.406 .155 .417 r
.47701 .2249 .47823 .21271 .48003 .2118 .47884 .2223 Mtetra
.505 .23 .431 r
.47884 .2223 .48003 .2118 .48182 .21158 .48064 .22229 Mtetra
.957 .666 .441 r
.48064 .22229 .48182 .21158 .48356 .21598 .47966 .42145 Mtetra
.527 .292 .502 r
.47966 .42145 .48356 .21598 .48265 .42404 .48152 .4264 Mtetra
.679 .281 .285 r
.48152 .4264 .48265 .42404 .48451 .42902 .48342 .42849 Mtetra
.066 .582 .879 r
.48342 .42849 .48451 .42902 .48643 .42966 .48534 .4288 Mtetra
.592 .809 .983 r
.48534 .4288 .48643 .42966 .48836 .42911 .48728 .4283 Mtetra
.743 .86 .934 r
.48728 .4283 .48836 .42911 .4903 .42805 .48922 .42721 Mtetra
.859 .858 .839 r
.48922 .42721 .4903 .42805 .49224 .42723 .49117 .42522 Mtetra
.85 .712 .71 r
.49117 .42522 .49224 .42723 .49419 .42618 .49314 .42197 Mtetra
.843 .626 .61 r
.49314 .42197 .49419 .42618 .49614 .42438 .49514 .41534 Mtetra
.965 .679 .441 r
.49514 .41534 .49614 .42438 .49813 .41848 .49884 .20956 Mtetra
.531 .3 .51 r
.49884 .20956 .49813 .41848 .50167 .20894 .5007 .20377 Mtetra
.705 .518 .633 r
.5007 .20377 .50167 .20894 .50352 .20285 .50253 .20093 Mtetra
.719 .664 .795 r
.50253 .20093 .50352 .20285 .50534 .20104 .50435 .19973 Mtetra
.625 .711 .908 r
.50435 .19973 .50534 .20104 .50716 .2004 .50616 .19922 Mtetra
.543 .703 .944 r
.50616 .19922 .50716 .2004 .50897 .20018 .50798 .199 Mtetra
.616 .734 .931 r
.50798 .199 .50897 .20018 .51079 .19971 .50979 .19852 Mtetra
.66 .75 .916 r
.50979 .19852 .51079 .19971 .51261 .19908 .51161 .19787 Mtetra
.675 .75 .907 r
.51161 .19787 .51261 .19908 .51443 .19842 .51344 .19714 Mtetra
.73 .757 .874 r
.51344 .19714 .51443 .19842 .51625 .19761 .51526 .19611 Mtetra
.717 .717 .849 r
.51526 .19611 .51625 .19761 .51808 .19676 .51709 .19509 Mtetra
.659 .669 .848 r
.51709 .19509 .51808 .19676 .5199 .19602 .51891 .19438 Mtetra
.415 .553 .886 r
.51891 .19438 .5199 .19602 .52173 .19533 .52073 .19468 Mtetra
.533 0 0 r
.52073 .19468 .52173 .19533 .52355 .19493 .52256 .19624 Mtetra
.839 .44 .289 r
.52256 .19624 .52355 .19493 .52538 .19517 .52439 .20079 Mtetra
.966 .671 .417 r
.52439 .20079 .52538 .19517 .52722 .1986 .52632 .40494 Mtetra
.528 .292 .502 r
.52632 .40494 .52722 .1986 .52934 .40671 .52828 .41033 Mtetra
.639 .274 .335 r
.52828 .41033 .52934 .40671 .53131 .41287 .53025 .4123 Mtetra
0 .479 .821 r
.53025 .4123 .53131 .41287 .53328 .41397 .53222 .41285 Mtetra
.529 .731 .967 r
.53222 .41285 .53328 .41397 .53525 .41357 .5342 .41261 Mtetra
.687 .822 .948 r
.5342 .41261 .53525 .41357 .53722 .41262 .53617 .41177 Mtetra
.837 .866 .865 r
.53617 .41177 .53722 .41262 .5392 .41179 .53814 .41002 Mtetra
.857 .737 .73 r
.53814 .41002 .5392 .41179 .54117 .41086 .5401 .40703 Mtetra
.836 .631 .625 r
.5401 .40703 .54117 .41086 .54314 .40926 .54205 .40149 Mtetra
.969 .679 .424 r
.54205 .40149 .54314 .40926 .54509 .40466 .54281 .1965 Mtetra
.535 .303 .51 r
.54281 .1965 .54509 .40466 .54563 .1958 .54461 .18895 Mtetra
.682 .481 .608 r
.54461 .18895 .54563 .1958 .54742 .18763 .54644 .18579 Mtetra
.754 .69 .791 r
.54644 .18579 .54742 .18763 .54926 .18535 .54828 .18431 Mtetra
.655 .781 .941 r
.54828 .18431 .54926 .18535 .5511 .18463 .55012 .18367 Mtetra
.561 .761 .972 r
.55012 .18367 .5511 .18463 .55295 .18438 .55197 .18332 Mtetra
.611 .761 .951 r
.55197 .18332 .55295 .18438 .5548 .18397 .55382 .18284 Mtetra
.662 .765 .926 r
.55382 .18284 .5548 .18397 .55665 .18332 .55567 .18217 Mtetra
.669 .765 .922 r
.55567 .18217 .55665 .18332 .5585 .18263 .55753 .18147 Mtetra
.743 .784 .886 r
.55753 .18147 .5585 .18263 .56035 .18157 .55937 .18038 Mtetra
.744 .78 .882 r
.55937 .18038 .56035 .18157 .5622 .18048 .56122 .17928 Mtetra
.614 .733 .93 r
.56122 .17928 .5622 .18048 .56405 .17999 .56308 .1788 Mtetra
0 0 .475 r
.56308 .1788 .56405 .17999 .56594 .18205 .56497 .18102 Mtetra
.974 .677 .388 r
.56497 .18102 .56594 .18205 .57077 .38902 .56976 .38961 Mtetra
.918 .54 .285 r
.56976 .38961 .57077 .38902 .57292 .39903 .57188 .39831 Mtetra
.416 0 0 r
.57188 .39831 .57292 .39903 .57495 .40055 .57391 .39975 Mtetra
.592 .83 .989 r
.57391 .39975 .57495 .40055 .57695 .39998 .57592 .3992 Mtetra
.741 .876 .943 r
.57592 .3992 .57695 .39998 .57894 .39884 .57791 .39809 Mtetra
.725 .881 .953 r
.57791 .39809 .57894 .39884 .58094 .39776 .57991 .39705 Mtetra
.651 .869 .981 r
.57991 .39705 .58094 .39776 .58294 .39697 .58191 .39628 Mtetra
.647 .873 .983 r
.58191 .39628 .58294 .39697 .58494 .39618 .58392 .39552 Mtetra
.636 .874 .986 r
.58392 .39552 .58494 .39618 .58694 .39543 .58592 .39478 Mtetra
.624 .874 .989 r
.58592 .39478 .58694 .39543 .58895 .39472 .58793 .39408 Mtetra
.616 .872 .99 r
.58793 .39408 .58895 .39472 .59096 .39403 .58994 .39339 Mtetra
.608 .87 .992 r
.58994 .39339 .59096 .39403 .59297 .39337 .59195 .39272 Mtetra
.602 .867 .993 r
.59195 .39272 .59297 .39337 .59498 .39273 .59396 .39208 Mtetra
.6 .864 .993 r
.59396 .39208 .59498 .39273 .597 .3921 .59598 .39144 Mtetra
.601 .862 .992 r
.59598 .39144 .597 .3921 .59901 .39148 .598 .3908 Mtetra
.604 .86 .992 r
.598 .3908 .59901 .39148 .60103 .39086 .60001 .39016 Mtetra
.607 .858 .991 r
.60001 .39016 .60103 .39086 .60305 .39023 .60203 .38952 Mtetra
.609 .856 .99 r
.60203 .38952 .60305 .39023 .60507 .3896 .60406 .38888 Mtetra
.611 .855 .99 r
.60406 .38888 .60507 .3896 .60709 .38896 .60608 .38823 Mtetra
.613 .853 .989 r
.60608 .38823 .60709 .38896 .60911 .38832 .6081 .38758 Mtetra
.615 .853 .988 r
.6081 .38758 .60911 .38832 .61114 .38767 .61013 .38693 Mtetra
.616 .852 .988 r
.61013 .38693 .61114 .38767 .61316 .38702 .61215 .38628 Mtetra
.617 .852 .988 r
.61215 .38628 .61316 .38702 .61519 .38637 .61418 .38562 Mtetra
.61418 .38562 .61519 .38637 .61722 .38571 .61621 .38496 Mtetra
.617 .853 .988 r
.61621 .38496 .61722 .38571 .61925 .38504 .61824 .3843 Mtetra
.616 .853 .988 r
.61824 .3843 .61925 .38504 .62128 .38438 .62028 .38364 Mtetra
.613 .853 .989 r
.62028 .38364 .62128 .38438 .62331 .38372 .62231 .38299 Mtetra
.61 .854 .99 r
.62231 .38299 .62331 .38372 .62535 .38306 .62435 .38235 Mtetra
.608 .856 .991 r
.62435 .38235 .62535 .38306 .62738 .38241 .62638 .3817 Mtetra
.567 .842 .996 r
.62638 .3817 .62738 .38241 .62942 .3818 .62843 .38117 Mtetra
.517 .837 .999 r
.62843 .38117 .62942 .3818 .63146 .38123 .63047 .38072 Mtetra
.597 .895 .988 r
.63047 .38072 .63146 .38123 .6335 .38058 .63251 .38 Mtetra
.817 .932 .907 r
.63251 .38 .6335 .38058 .63554 .37968 .63453 .37843 Mtetra
.909 .808 .736 r
.63453 .37843 .63554 .37968 .63756 .37843 .63648 .3752 Mtetra
.86 .661 .632 r
.63648 .3752 .63756 .37843 .63958 .37711 .63836 .3699 Mtetra
.792 .557 .58 r
.63836 .3699 .63958 .37711 .64162 .37628 .64015 .36224 Mtetra
.505 .32 .563 r
.64015 .36224 .64162 .37628 .64369 .37616 .64224 .36293 Mtetra
.498 .317 .566 r
.64224 .36293 .64369 .37616 .64574 .37555 .64434 .36381 Mtetra
.741 .498 .561 r
.64434 .36381 .64574 .37555 .64772 .37302 .64607 .35484 Mtetra
.965 .663 .404 r
.64607 .35484 .64772 .37302 .64926 .35927 .64042 .15603 Mtetra
.528 .298 .509 r
.64042 .15603 .64926 .35927 .64317 .15403 .64218 .15154 Mtetra
.779 .651 .721 r
.64218 .15154 .64317 .15403 .64496 .15046 .64403 .14927 Mtetra
.694 .773 .912 r
.64403 .14927 .64496 .15046 .64686 .14949 .64594 .14843 Mtetra
.609 .767 .955 r
.64594 .14843 .64686 .14949 .64879 .14907 .64786 .14793 Mtetra
.606 .748 .945 r
.64786 .14793 .64879 .14907 .65071 .14874 .64978 .14745 Mtetra
.673 .748 .907 r
.64978 .14745 .65071 .14874 .65263 .14801 .65169 .1467 Mtetra
.68 .747 .901 r
.65169 .1467 .65263 .14801 .65454 .14724 .65361 .14591 Mtetra
.701 .751 .891 r
.65361 .14591 .65454 .14724 .65645 .14641 .65551 .14502 Mtetra
.724 .749 .872 r
.65551 .14502 .65645 .14641 .65836 .14547 .65742 .14397 Mtetra
.685 .716 .872 r
.65742 .14397 .65836 .14547 .66027 .14459 .65933 .14312 Mtetra
.588 .679 .904 r
.65933 .14312 .66027 .14459 .66218 .14374 .66127 .14275 Mtetra
.168 .539 .925 r
.66127 .14275 .66218 .14374 .6641 .14292 .66325 .1433 Mtetra
.662 .123 0 r
.66325 .1433 .6641 .14292 .66604 .14257 .66528 .14496 Mtetra
.834 .445 .313 r
.66528 .14496 .66604 .14257 .66804 .14355 .66753 .15089 Mtetra
.97 .66 .36 r
.66753 .15089 .66804 .14355 .67043 .15217 .6795 .3566 Mtetra
.525 .29 .501 r
.6795 .3566 .67043 .15217 .68272 .36031 .68181 .36077 Mtetra
.59 .035 0 r
.68181 .36077 .68272 .36031 .68498 .3634 .68399 .3621 Mtetra
.563 .718 .945 r
.68399 .3621 .68498 .3634 .68709 .36325 .68609 .36176 Mtetra
.654 .724 .9 r
.68609 .36176 .68709 .36325 .68916 .36247 .68817 .36104 Mtetra
.615 .717 .918 r
.68817 .36104 .68916 .36247 .69124 .36172 .69026 .3605 Mtetra
.337 .613 .951 r
.69026 .3605 .69124 .36172 .69336 .36178 .6924 .36081 Mtetra
.501 .757 .987 r
.6924 .36081 .69336 .36178 .69546 .36132 .69451 .36055 Mtetra
.816 .906 .903 r
.69451 .36055 .69546 .36132 .69749 .35953 .69655 .35897 Mtetra
.992 .822 .574 r
.69655 .35897 .69749 .35953 .69923 .35246 .69832 .3525 Mtetra
.977 .676 .344 r
.69832 .3525 .69923 .35246 .68947 .13873 .68858 .13794 Mtetra
.984 .81 .589 r
.68858 .13794 .68947 .13873 .69116 .13344 .69024 .13211 Mtetra
.752 .772 .869 r
.69024 .13211 .69116 .13344 .69307 .13225 .69215 .13089 Mtetra
.611 .71 .915 r
.69215 .13089 .69307 .13225 .69503 .13177 .69411 .13041 Mtetra
.548 .681 .926 r
.69411 .13041 .69503 .13177 .697 .13151 .69608 .13017 Mtetra
.673 .743 .903 r
.69608 .13017 .697 .13151 .69894 .13073 .69803 .1294 Mtetra
.682 .749 .901 r
.69803 .1294 .69894 .13073 .70088 .12992 .69997 .12859 Mtetra
.712 .76 .889 r
.69997 .12859 .70088 .12992 .70282 .12899 .7019 .12762 Mtetra
.783 .776 .847 r
.7019 .12762 .70282 .12899 .70473 .12762 .70381 .12615 Mtetra
.713 .736 .869 r
.70381 .12615 .70473 .12762 .70666 .12671 .70574 .12514 Mtetra
.491 .615 .902 r
.70574 .12514 .70666 .12671 .70867 .12681 .70774 .12516 Mtetra
.686 .289 0 r
.70774 .12516 .70867 .12681 .71097 .13173 .71003 .12976 Mtetra
.973 .662 .313 r
.71003 .12976 .71097 .13173 .72652 .34439 .72554 .34282 Mtetra
.725 .313 0 r
.72554 .34282 .72652 .34439 .72897 .34909 .72801 .34783 Mtetra
.471 .682 .958 r
.72801 .34783 .72897 .34909 .73112 .34901 .73016 .34777 Mtetra
.679 .783 .928 r
.73016 .34777 .73112 .34901 .73322 .34815 .73227 .34692 Mtetra
.72 .801 .914 r
.73227 .34692 .73322 .34815 .73531 .34704 .73436 .34586 Mtetra
.407 .663 .964 r
.73436 .34586 .73531 .34704 .73747 .34701 .73653 .34596 Mtetra
.559 .77 .977 r
.73653 .34596 .73747 .34701 .7396 .3465 .73867 .34556 Mtetra
.798 .875 .904 r
.73867 .34556 .7396 .3465 .74166 .34492 .74073 .34406 Mtetra
.99 .8 .555 r
.74073 .34406 .74166 .34492 .74333 .33772 .74241 .33691 Mtetra
.976 .67 .324 r
.74241 .33691 .74333 .33772 .73054 .12346 .72963 .12186 Mtetra
.952 .763 .611 r
.72963 .12186 .73054 .12346 .73218 .11798 .73126 .11634 Mtetra
.719 .715 .846 r
.73126 .11634 .73218 .11798 .73412 .1168 .73321 .11524 Mtetra
.583 .665 .895 r
.73321 .11524 .73412 .1168 .73611 .11635 .7352 .11488 Mtetra
.483 .629 .917 r
.7352 .11488 .73611 .11635 .73812 .11626 .73723 .1149 Mtetra
.644 .729 .911 r
.73723 .1149 .73812 .11626 .74011 .11562 .73921 .11426 Mtetra
.661 .736 .906 r
.73921 .11426 .74011 .11562 .74208 .11495 .74119 .11354 Mtetra
.679 .737 .895 r
.74119 .11354 .74208 .11495 .74406 .11421 .74316 .11273 Mtetra
.742 .75 .858 r
.74316 .11273 .74406 .11421 .74602 .11327 .7451 .11152 Mtetra
.7 .694 .841 r
.7451 .11152 .74602 .11327 .74799 .11236 .74706 .11051 Mtetra
.631 .647 .848 r
.74706 .11051 .74799 .11236 .74996 .11159 .74905 .10991 Mtetra
.283 .474 .87 r
.74905 .10991 .74996 .11159 .75195 .11087 .75115 .11067 Mtetra
.67 .125 0 r
.75115 .11067 .75195 .11087 .75397 .11061 .75337 .11295 Mtetra
.908 .53 .295 r
.75337 .11295 .75397 .11061 .75606 .11123 .75633 .1246 Mtetra
.52 .287 .501 r
.09265 .55238 .11892 .35739 .09588 .55036 .09408 .55371 Mtetra
.515 .161 .304 r
.09408 .55371 .09588 .55036 .09706 .55367 .09564 .55404 Mtetra
.037 0 0 r
.09564 .55404 .09706 .55367 .09848 .55506 .09726 .55386 Mtetra
.47 .664 .947 r
.09726 .55386 .09848 .55506 .10008 .55512 .09887 .55385 Mtetra
.63 .71 .904 r
.09887 .55385 .10008 .55512 .10175 .55457 .10053 .55337 Mtetra
.751 .749 .85 r
.10053 .55337 .10175 .55457 .1035 .55344 .10229 .55221 Mtetra
.88 .736 .699 r
.10229 .55221 .1035 .55344 .10537 .55135 .10439 .54826 Mtetra
.904 .674 .579 r
.10439 .54826 .10537 .55135 .1074 .54789 .10825 .53012 Mtetra
.918 .665 .539 r
.10825 .53012 .1074 .54789 .11005 .53946 .13362 .33812 Mtetra
.525 .296 .509 r
.13362 .33812 .11005 .53946 .13604 .34112 .13544 .33557 Mtetra
.631 .461 .634 r
.13544 .33557 .13604 .34112 .13811 .33656 .13713 .33415 Mtetra
.667 .581 .75 r
.13713 .33415 .13811 .33656 .13991 .33416 .13875 .33325 Mtetra
.671 .777 .929 r
.13875 .33325 .13991 .33416 .14152 .33332 .14033 .33264 Mtetra
.602 .811 .98 r
.14033 .33264 .14152 .33332 .14308 .33298 .1419 .33221 Mtetra
.579 .785 .977 r
.1419 .33221 .14308 .33298 .14461 .33286 .14346 .33186 Mtetra
.656 .755 .922 r
.14346 .33186 .14461 .33286 .14618 .33238 .14504 .3313 Mtetra
.672 .743 .904 r
.14504 .3313 .14618 .33238 .14777 .33181 .14663 .33068 Mtetra
.68 .737 .894 r
.14663 .33068 .14777 .33181 .14936 .33115 .14823 .33002 Mtetra
.75 .748 .851 r
.14823 .33002 .14936 .33115 .151 .33015 .14988 .32893 Mtetra
.713 .729 .863 r
.14988 .32893 .151 .33015 .15263 .32926 .1515 .32807 Mtetra
.593 .699 .917 r
.1515 .32807 .15263 .32926 .15421 .32871 .15306 .32775 Mtetra
.805 .323 0 r
.15306 .32775 .15421 .32871 .15567 .32931 .15434 .32987 Mtetra
.914 .614 .462 r
.15434 .32987 .15567 .32931 .15698 .33114 .15453 .34121 Mtetra
.927 .667 .524 r
.15453 .34121 .15698 .33114 .15786 .33669 .13314 .53791 Mtetra
.521 .288 .501 r
.13314 .53791 .15786 .33669 .13649 .53462 .13455 .53976 Mtetra
.521 .203 .368 r
.13455 .53976 .13649 .53462 .13762 .539 .13614 .54011 Mtetra
.265 0 0 r
.13614 .54011 .13762 .539 .13906 .54068 .1378 .5399 Mtetra
.402 .727 .99 r
.1378 .5399 .13906 .54068 .14066 .54092 .13944 .53986 Mtetra
.606 .744 .943 r
.13944 .53986 .14066 .54092 .14235 .54045 .14112 .53945 Mtetra
.751 .785 .881 r
.14112 .53945 .14235 .54045 .14411 .53939 .14289 .53836 Mtetra
.89 .758 .71 r
.14289 .53836 .14411 .53939 .14597 .53744 .14495 .53464 Mtetra
.911 .68 .575 r
.14495 .53464 .14597 .53744 .14798 .53414 .14857 .51701 Mtetra
.923 .667 .532 r
.14857 .51701 .14798 .53414 .15049 .52637 .17184 .32423 Mtetra
.525 .296 .509 r
.17184 .32423 .15049 .52637 .17426 .32753 .17369 .32144 Mtetra
.624 .449 .625 r
.17369 .32144 .17426 .32753 .17634 .32272 .17539 .32 Mtetra
.659 .56 .732 r
.17539 .32 .17634 .32272 .17816 .32018 .17703 .31907 Mtetra
.673 .742 .902 r
.17703 .31907 .17816 .32018 .17981 .31918 .17864 .31844 Mtetra
.613 .804 .973 r
.17864 .31844 .17981 .31918 .18139 .31878 .18024 .31798 Mtetra
.583 .782 .974 r
.18024 .31798 .18139 .31878 .18295 .31864 .18182 .31762 Mtetra
.718 .768 .892 r
.18182 .31762 .18295 .31864 .18457 .318 .18346 .31678 Mtetra
.698 .728 .873 r
.18346 .31678 .18457 .318 .18619 .31729 .18509 .316 Mtetra
.585 .679 .905 r
.18509 .316 .18619 .31729 .18779 .31685 .18667 .3157 Mtetra
.716 .227 0 r
.18667 .3157 .18779 .31685 .18928 .31735 .18801 .31765 Mtetra
.922 .616 .448 r
.18801 .31765 .18928 .31735 .19065 .31907 .18837 .32882 Mtetra
.931 .668 .517 r
.18837 .32882 .19065 .31907 .19166 .32424 .16897 .526 Mtetra
.522 .288 .501 r
.16897 .526 .19166 .32424 .17232 .52249 .1704 .52811 Mtetra
.524 .211 .379 r
.1704 .52811 .17232 .52249 .17349 .52713 .17202 .52851 Mtetra
.337 0 0 r
.17202 .52851 .17349 .52713 .17496 .52898 .1737 .52837 Mtetra
.239 .68 .957 r
.1737 .52837 .17496 .52898 .17655 .5297 .17535 .52847 Mtetra
.536 .689 .938 r
.17535 .52847 .17655 .5297 .17822 .5296 .17704 .52829 Mtetra
.71 .732 .867 r
.17704 .52829 .17822 .5296 .17999 .52863 .1788 .52738 Mtetra
.884 .744 .702 r
.1788 .52738 .17999 .52863 .18205 .52481 .18087 .52352 Mtetra
.945 .688 .517 r
.18087 .52352 .18205 .52481 .20419 .32402 .20317 .32182 Mtetra
.911 .688 .588 r
.20317 .32182 .20419 .32402 .20708 .31098 .20596 .30987 Mtetra
.846 .76 .768 r
.20596 .30987 .20708 .31098 .20887 .30872 .20775 .30763 Mtetra
.687 .751 .9 r
.20775 .30763 .20887 .30872 .21051 .30802 .20939 .30693 Mtetra
.557 .708 .941 r
.20939 .30693 .21051 .30802 .2121 .30781 .21098 .30669 Mtetra
.708 .75 .885 r
.21098 .30669 .2121 .30781 .21374 .307 .21263 .30587 Mtetra
.722 .751 .875 r
.21263 .30587 .21374 .307 .2154 .3061 .21429 .30497 Mtetra
.589 .712 .929 r
.21429 .30497 .2154 .3061 .217 .30579 .21589 .30464 Mtetra
.782 .308 0 r
.21589 .30464 .217 .30579 .21835 .30811 .21724 .30693 Mtetra
.948 .685 .504 r
.21724 .30693 .21835 .30811 .20031 .50941 .19916 .50789 Mtetra
.957 .641 .384 r
.19916 .50789 .20031 .50941 .20102 .5194 .19983 .51826 Mtetra
.585 .075 0 r
.19983 .51826 .20102 .5194 .20255 .52105 .20135 .51994 Mtetra
.536 .713 .954 r
.20135 .51994 .20255 .52105 .20426 .52085 .20306 .51973 Mtetra
.773 .774 .853 r
.20306 .51973 .20426 .52085 .20607 .51955 .20487 .51842 Mtetra
.897 .753 .695 r
.20487 .51842 .20607 .51955 .20814 .51553 .20696 .5143 Mtetra
.948 .689 .512 r
.20696 .5143 .20814 .51553 .22903 .31207 .22799 .31015 Mtetra
.911 .696 .599 r
.22799 .31015 .22903 .31207 .23159 .30178 .23049 .30053 Mtetra
.846 .747 .755 r
.23049 .30053 .23159 .30178 .2334 .29932 .2323 .29815 Mtetra
.706 .741 .879 r
.2323 .29815 .2334 .29932 .23507 .29845 .23396 .29732 Mtetra
.601 .72 .928 r
.23396 .29732 .23507 .29845 .23669 .29804 .23558 .29695 Mtetra
.693 .756 .9 r
.23558 .29695 .23669 .29804 .23835 .29727 .23724 .29621 Mtetra
.718 .766 .891 r
.23724 .29621 .23835 .29727 .24002 .2964 .2389 .29535 Mtetra
.582 .73 .944 r
.2389 .29535 .24002 .2964 .24163 .2961 .24052 .29503 Mtetra
.694 .195 0 r
.24052 .29503 .24163 .2961 .24304 .2981 .24194 .29694 Mtetra
.95 .685 .497 r
.24194 .29694 .24304 .2981 .22669 .49796 .22582 .4934 Mtetra
.983 .697 .356 r
.22582 .4934 .22669 .49796 .22722 .51108 .22606 .50959 Mtetra
0 0 .522 r
.22606 .50959 .22722 .51108 .22877 .51277 .22761 .51135 Mtetra
.591 .68 .903 r
.22761 .51135 .22877 .51277 .23051 .5124 .22935 .51101 Mtetra
.706 .723 .863 r
.22935 .51101 .23051 .5124 .23231 .51146 .23114 .51009 Mtetra
.644 .707 .893 r
.23114 .51009 .23231 .51146 .23408 .51077 .2329 .50952 Mtetra
.574 .703 .93 r
.2329 .50952 .23408 .51077 .23583 .51035 .23464 .50922 Mtetra
.691 .763 .907 r
.23464 .50922 .23583 .51035 .2376 .50962 .23643 .50844 Mtetra
.853 .767 .766 r
.23643 .50844 .2376 .50962 .23945 .50809 .23836 .50595 Mtetra
.893 .695 .628 r
.23836 .50595 .23945 .50809 .24141 .50527 .24067 .49901 Mtetra
.945 .683 .507 r
.24067 .49901 .24141 .50527 .24357 .49998 .2598 .29418 Mtetra
.529 .299 .51 r
.2598 .29418 .24357 .49998 .26223 .29862 .2618 .28956 Mtetra
.607 .412 .591 r
.2618 .28956 .26223 .29862 .26446 .29128 .26356 .28777 Mtetra
.653 .523 .693 r
.26356 .28777 .26446 .29128 .26633 .28815 .26527 .28663 Mtetra
.69 .686 .841 r
.26527 .28663 .26633 .28815 .26808 .28655 .26695 .28582 Mtetra
.663 .825 .961 r
.26695 .28582 .26808 .28655 .26975 .28584 .26862 .28519 Mtetra
.61 .831 .985 r
.26862 .28519 .26975 .28584 .2714 .28544 .27027 .28469 Mtetra
.612 .809 .976 r
.27027 .28469 .2714 .28544 .27304 .28511 .27192 .28422 Mtetra
.633 .785 .955 r
.27192 .28422 .27304 .28511 .27469 .28469 .27358 .28371 Mtetra
.644 .766 .938 r
.27358 .28371 .27469 .28469 .27634 .28426 .27525 .28317 Mtetra
.67 .753 .913 r
.27525 .28317 .27634 .28426 .27801 .28366 .27692 .28253 Mtetra
.692 .751 .896 r
.27692 .28253 .27801 .28366 .27969 .28288 .2786 .28178 Mtetra
.696 .757 .899 r
.2786 .28178 .27969 .28288 .28138 .28207 .28028 .28102 Mtetra
.724 .772 .891 r
.28028 .28102 .28138 .28207 .28307 .28121 .28197 .28011 Mtetra
.726 .765 .884 r
.28197 .28011 .28307 .28121 .28476 .28038 .28367 .27919 Mtetra
.637 .724 .911 r
.28367 .27919 .28476 .28038 .28643 .27982 .28534 .27868 Mtetra
0 .372 .833 r
.28534 .27868 .28643 .27982 .28805 .27993 .2869 .2795 Mtetra
.909 .518 .259 r
.2869 .2795 .28805 .27993 .28958 .28121 .28819 .28401 Mtetra
.95 .68 .489 r
.28819 .28401 .28958 .28121 .29095 .2846 .27436 .48833 Mtetra
.527 .292 .502 r
.27436 .48833 .29095 .2846 .27765 .48437 .27576 .49294 Mtetra
.544 .253 .424 r
.27576 .49294 .27765 .48437 .27883 .49194 .27744 .49379 Mtetra
.436 .005 .119 r
.27744 .49379 .27883 .49194 .28041 .49434 .27919 .49385 Mtetra
.47 .827 .996 r
.27919 .49385 .28041 .49434 .28211 .49501 .28096 .49353 Mtetra
.633 .688 .884 r
.28096 .49353 .28211 .49501 .28389 .49459 .28276 .493 Mtetra
.658 .682 .861 r
.28276 .493 .28389 .49459 .2857 .49381 .28456 .49232 Mtetra
.659 .697 .874 r
.28456 .49232 .2857 .49381 .28751 .49302 .28636 .49166 Mtetra
.639 .711 .899 r
.28636 .49166 .28751 .49302 .28931 .49242 .28816 .4911 Mtetra
.639 .717 .904 r
.28816 .4911 .28931 .49242 .29111 .49183 .28996 .49054 Mtetra
.598 .71 .922 r
.28996 .49054 .29111 .49183 .29291 .49134 .29175 .49015 Mtetra
.549 .709 .945 r
.29175 .49015 .29291 .49134 .2947 .49097 .29353 .48991 Mtetra
.664 .773 .931 r
.29353 .48991 .2947 .49097 .2965 .49034 .29534 .48924 Mtetra
.832 .789 .81 r
.29534 .48924 .2965 .49034 .29836 .48904 .29724 .48729 Mtetra
.898 .717 .649 r
.29724 .48729 .29836 .48904 .3003 .48646 .29939 .48168 Mtetra
.953 .686 .492 r
.29939 .48168 .3003 .48646 .30237 .4819 .31508 .27601 Mtetra
.533 .302 .511 r
.31508 .27601 .30237 .4819 .31744 .28273 .31717 .26961 Mtetra
.588 .381 .567 r
.31717 .26961 .31744 .28273 .31984 .27168 .31896 .26759 Mtetra
.647 .502 .672 r
.31896 .26759 .31984 .27168 .32173 .26814 .3207 .26634 Mtetra
.684 .653 .813 r
.3207 .26634 .32173 .26814 .32351 .26625 .32241 .26548 Mtetra
.671 .825 .958 r
.32241 .26548 .32351 .26625 .32522 .26545 .32411 .26481 Mtetra
.608 .839 .987 r
.32411 .26481 .32522 .26545 .32691 .265 .3258 .2643 Mtetra
.596 .819 .985 r
.3258 .2643 .32691 .265 .32859 .26469 .32749 .26384 Mtetra
.625 .796 .964 r
.32749 .26384 .32859 .26469 .33028 .26426 .32919 .26333 Mtetra
.631 .779 .952 r
.32919 .26333 .33028 .26426 .33197 .26385 .33089 .26282 Mtetra
.646 .762 .933 r
.33089 .26282 .33197 .26385 .33366 .26338 .33259 .26226 Mtetra
.666 .75 .913 r
.33259 .26226 .33366 .26338 .33536 .26279 .33429 .26162 Mtetra
.673 .742 .903 r
.33429 .26162 .33536 .26279 .33707 .26214 .336 .26095 Mtetra
.703 .747 .886 r
.336 .26095 .33707 .26214 .33879 .26134 .33772 .26012 Mtetra
.741 .752 .861 r
.33772 .26012 .33879 .26134 .34052 .26033 .33946 .25905 Mtetra
.673 .723 .887 r
.33946 .25905 .34052 .26033 .34224 .25956 .34117 .25836 Mtetra
.279 .559 .93 r
.34117 .25836 .34224 .25956 .34392 .25944 .34282 .25875 Mtetra
.904 .494 .18 r
.34282 .25875 .34392 .25944 .34551 .26094 .34425 .26298 Mtetra
.957 .681 .472 r
.34425 .26298 .34551 .26094 .34698 .26441 .33404 .46805 Mtetra
.527 .292 .502 r
.33404 .46805 .34698 .26441 .34801 .27586 .33555 .47301 Mtetra
.517 .284 .5 r
.33555 .47301 .34801 .27586 .34981 .27389 .33735 .47284 Mtetra
.515 .283 .5 r
.33735 .47284 .34981 .27389 .35165 .27121 .3392 .472 Mtetra
.516 .283 .5 r
.3392 .472 .35165 .27121 .34287 .46009 .34104 .47139 Mtetra
.531 .254 .44 r
.34104 .47139 .34287 .46009 .34413 .4699 .3428 .47206 Mtetra
.521 .11 .202 r
.3428 .47206 .34413 .4699 .34576 .47299 .34458 .47255 Mtetra
.109 .627 .887 r
.34458 .47255 .34576 .47299 .3475 .47421 .34638 .47272 Mtetra
.562 .662 .904 r
.34638 .47272 .3475 .47421 .34933 .47393 .3482 .47247 Mtetra
.675 .712 .876 r
.3482 .47247 .34933 .47393 .35118 .47305 .35005 .47171 Mtetra
.801 .76 .815 r
.35005 .47171 .35118 .47305 .35307 .47156 .35196 .47 Mtetra
.9 .736 .668 r
.35196 .47 .35307 .47156 .35501 .46916 .35402 .46523 Mtetra
.959 .687 .477 r
.35402 .46523 .35501 .46916 .35703 .46521 .36632 .26115 Mtetra
.541 .308 .512 r
.36632 .26115 .35703 .46521 .35947 .45269 .36853 .25118 Mtetra
.524 .295 .509 r
.36853 .25118 .35947 .45269 .37122 .25379 .37035 .24886 Mtetra
.639 .478 .649 r
.37035 .24886 .37122 .25379 .37312 .24964 .37212 .24746 Mtetra
.68 .615 .777 r
.37212 .24746 .37312 .24964 .37493 .2474 .37386 .2465 Mtetra
.692 .806 .935 r
.37386 .2465 .37493 .2474 .37668 .24646 .3756 .24574 Mtetra
.638 .831 .975 r
.3756 .24574 .37668 .24646 .37841 .24592 .37733 .24515 Mtetra
.613 .814 .977 r
.37733 .24515 .37841 .24592 .38013 .24557 .37906 .24465 Mtetra
.635 .786 .954 r
.37906 .24465 .38013 .24557 .38185 .24512 .38079 .24411 Mtetra
.641 .769 .941 r
.38079 .24411 .38185 .24512 .38358 .24467 .38252 .24356 Mtetra
.656 .753 .921 r
.38252 .24356 .38358 .24467 .38531 .24413 .38426 .24295 Mtetra
.689 .749 .897 r
.38426 .24295 .38531 .24413 .38706 .24334 .38601 .24219 Mtetra
.695 .755 .898 r
.38601 .24219 .38706 .24334 .3888 .24251 .38775 .2414 Mtetra
.7 .766 .903 r
.38775 .2414 .3888 .24251 .39055 .24167 .3895 .24059 Mtetra
.74 .781 .886 r
.3895 .24059 .39055 .24167 .39231 .24078 .39126 .23957 Mtetra
.673 .739 .901 r
.39126 .23957 .39231 .24078 .39405 .24011 .39301 .23888 Mtetra
.462 .65 .94 r
.39301 .23888 .39405 .24011 .39578 .23988 .39472 .2389 Mtetra
.837 .381 0 r
.39472 .2389 .39578 .23988 .39744 .24115 .39631 .24209 Mtetra
.962 .682 .455 r
.39631 .24209 .39744 .24115 .39905 .24397 .3896 .44567 Mtetra
.534 .298 .503 r
.3896 .44567 .39905 .24397 .40042 .25262 .39109 .45426 Mtetra
.518 .284 .5 r
.39109 .45426 .40042 .25262 .39495 .43314 .39293 .4545 Mtetra
.496 .244 .463 r
.39293 .4545 .39495 .43314 .40356 .26095 .39481 .45373 Mtetra
.515 .282 .499 r
.39481 .45373 .40356 .26095 .40571 .25032 .3967 .45247 Mtetra
.516 .283 .5 r
.3967 .45247 .40571 .25032 .40748 .24941 .39858 .45184 Mtetra
.39858 .45184 .40748 .24941 .40925 .24851 .40046 .45121 Mtetra
.40046 .45121 .40925 .24851 .41102 .24755 .40233 .45055 Mtetra
.40233 .45055 .41102 .24755 .41289 .24407 .40422 .44971 Mtetra
.40422 .44971 .41289 .24407 .41467 .24302 .4061 .44903 Mtetra
.517 .284 .5 r
.4061 .44903 .41467 .24302 .41629 .24646 .40797 .44867 Mtetra
.518 .285 .5 r
.40797 .44867 .41629 .24646 .4111 .44545 .40982 .44924 Mtetra
.525 .173 .313 r
.40982 .44924 .4111 .44545 .41282 .44956 .41166 .44973 Mtetra
.224 0 0 r
.41166 .44973 .41282 .44956 .41462 .45136 .41352 .44996 Mtetra
.613 .703 .908 r
.41352 .44996 .41462 .45136 .4165 .45113 .4154 .44949 Mtetra
.646 .679 .867 r
.4154 .44949 .4165 .45113 .41839 .45046 .41729 .44885 Mtetra
.658 .688 .866 r
.41729 .44885 .41839 .45046 .42029 .44961 .41918 .44815 Mtetra
.615 .695 .901 r
.41918 .44815 .42029 .44961 .42217 .44917 .42107 .44767 Mtetra
.615 .688 .895 r
.42107 .44767 .42217 .44917 .42406 .44874 .42296 .4472 Mtetra
.623 .685 .887 r
.42296 .4472 .42406 .44874 .42595 .44824 .42485 .44668 Mtetra
.572 .66 .897 r
.42485 .44668 .42595 .44824 .42784 .44773 .42674 .44639 Mtetra
.644 .725 .908 r
.42674 .44639 .42784 .44773 .42974 .44701 .42864 .44578 Mtetra
.754 .778 .872 r
.42864 .44578 .42974 .44701 .43165 .4459 .43055 .44455 Mtetra
.911 .763 .685 r
.43055 .44455 .43165 .4459 .43361 .44334 .43256 .44029 Mtetra
.954 .689 .495 r
.43256 .44029 .43361 .44334 .4356 .43936 .4354 .40566 Mtetra
.928 .645 .485 r
.4354 .40566 .4356 .43936 .43768 .43188 .44218 .22463 Mtetra
.522 .293 .508 r
.44218 .22463 .43768 .43188 .43962 .42976 .44398 .22299 Mtetra
.52 .291 .508 r
.44398 .22299 .43962 .42976 .44149 .43023 .44576 .22246 Mtetra
.519 .291 .508 r
.44576 .22246 .44149 .43023 .44341 .42881 .44753 .22225 Mtetra
.522 .293 .508 r
.44753 .22225 .44341 .42881 .45023 .2272 .44933 .22062 Mtetra
.625 .445 .618 r
.44933 .22062 .45023 .2272 .45213 .22159 .45114 .21896 Mtetra
.706 .599 .735 r
.45114 .21896 .45213 .22159 .45397 .21863 .45294 .21754 Mtetra
.689 .774 .916 r
.45294 .21754 .45397 .21863 .45576 .2176 .45473 .21678 Mtetra
.623 .81 .972 r
.45473 .21678 .45576 .2176 .45754 .21714 .45651 .21624 Mtetra
.601 .785 .969 r
.45651 .21624 .45754 .21714 .45931 .21692 .45829 .21578 Mtetra
.656 .754 .922 r
.45829 .21578 .45931 .21692 .4611 .21637 .46008 .21516 Mtetra
.669 .743 .906 r
.46008 .21516 .4611 .21637 .46289 .21572 .46187 .21447 Mtetra
.675 .739 .899 r
.46187 .21447 .46289 .21572 .46468 .21502 .46366 .21376 Mtetra
.744 .758 .864 r
.46366 .21376 .46468 .21502 .46647 .21398 .46546 .21264 Mtetra
.709 .734 .871 r
.46546 .21264 .46647 .21398 .46827 .21305 .46726 .21172 Mtetra
.594 .694 .912 r
.46726 .21172 .46827 .21305 .47006 .21246 .46904 .21135 Mtetra
.619 .135 0 r
.46904 .21135 .47006 .21246 .47183 .2133 .47079 .21358 Mtetra
.951 .628 .379 r
.47079 .21358 .47183 .2133 .47358 .2156 .47227 .23137 Mtetra
.95 .658 .45 r
.47227 .23137 .47358 .2156 .47526 .22174 .47081 .42717 Mtetra
.519 .285 .5 r
.47081 .42717 .47526 .22174 .47701 .2249 .47271 .42805 Mtetra
.516 .283 .5 r
.47271 .42805 .47701 .2249 .47884 .2223 .47464 .42734 Mtetra
.515 .282 .5 r
.47464 .42734 .47884 .2223 .48064 .22229 .47657 .42626 Mtetra
.518 .285 .5 r
.47657 .42626 .48064 .22229 .47966 .42145 .47849 .42653 Mtetra
.527 .199 .355 r
.47849 .42653 .47966 .42145 .48152 .4264 .48041 .42705 Mtetra
.369 0 0 r
.48041 .42705 .48152 .4264 .48342 .42849 .48233 .42733 Mtetra
.443 .677 .963 r
.48233 .42733 .48342 .42849 .48534 .4288 .48426 .42734 Mtetra
.603 .693 .907 r
.48426 .42734 .48534 .4288 .48728 .4283 .4862 .42691 Mtetra
.726 .749 .871 r
.4862 .42691 .48728 .4283 .48922 .42721 .48814 .42582 Mtetra
.892 .771 .721 r
.48814 .42582 .48922 .42721 .49117 .42522 .49011 .42243 Mtetra
.92 .691 .574 r
.49011 .42243 .49117 .42522 .49314 .42197 .49215 .41254 Mtetra
.964 .679 .442 r
.49215 .41254 .49314 .42197 .49514 .41534 .49604 .20584 Mtetra
.526 .296 .509 r
.49604 .20584 .49514 .41534 .49884 .20956 .49789 .20236 Mtetra
.617 .433 .61 r
.49789 .20236 .49884 .20956 .5007 .20377 .49971 .20069 Mtetra
.658 .55 .721 r
.49971 .20069 .5007 .20377 .50253 .20093 .50153 .19961 Mtetra
.678 .731 .89 r
.50153 .19961 .50253 .20093 .50435 .19973 .50334 .19886 Mtetra
.622 .805 .97 r
.50334 .19886 .50435 .19973 .50616 .19922 .50516 .19832 Mtetra
.592 .785 .972 r
.50516 .19832 .50616 .19922 .50798 .199 .50698 .19788 Mtetra
.645 .758 .931 r
.50698 .19788 .50798 .199 .50979 .19852 .5088 .19728 Mtetra
.669 .743 .905 r
.5088 .19728 .50979 .19852 .51161 .19787 .51062 .19658 Mtetra
.677 .738 .896 r
.51062 .19658 .51161 .19787 .51344 .19714 .51244 .19584 Mtetra
.739 .754 .865 r
.51244 .19584 .51344 .19714 .51526 .19611 .51427 .19474 Mtetra
.723 .739 .864 r
.51427 .19474 .51526 .19611 .51709 .19509 .51609 .19372 Mtetra
.629 .704 .9 r
.51609 .19372 .51709 .19509 .51891 .19438 .51792 .1932 Mtetra
0 .167 .683 r
.51792 .1932 .51891 .19438 .52073 .19468 .51974 .19468 Mtetra
.921 .539 .26 r
.51974 .19468 .52073 .19468 .52256 .19624 .52156 .20182 Mtetra
.966 .672 .418 r
.52156 .20182 .52256 .19624 .52439 .20079 .52329 .40863 Mtetra
.522 .288 .501 r
.52329 .40863 .52439 .20079 .52632 .40494 .52526 .41136 Mtetra
.523 .212 .382 r
.52526 .41136 .52632 .40494 .52828 .41033 .52722 .41183 Mtetra
.347 0 0 r
.52722 .41183 .52828 .41033 .53025 .4123 .52919 .41167 Mtetra
.346 .744 .984 r
.52919 .41167 .53025 .4123 .53222 .41285 .53116 .4116 Mtetra
.548 .71 .947 r
.53116 .4116 .53222 .41285 .5342 .41261 .53313 .41133 Mtetra
.696 .764 .904 r
.53313 .41133 .5342 .41261 .53617 .41177 .53511 .41044 Mtetra
.882 .787 .751 r
.53511 .41044 .53617 .41177 .53814 .41002 .53707 .40755 Mtetra
.919 .703 .594 r
.53707 .40755 .53814 .41002 .5401 .40703 .53902 .39979 Mtetra
.969 .68 .424 r
.53902 .39979 .5401 .40703 .54205 .40149 .53995 .19089 Mtetra
.527 .297 .509 r
.53995 .19089 .54205 .40149 .54281 .1965 .54177 .18673 Mtetra
.594 .397 .585 r
.54177 .18673 .54281 .1965 .54461 .18895 .54361 .18505 Mtetra
.631 .502 .686 r
.54361 .18505 .54461 .18895 .54644 .18579 .54545 .18402 Mtetra
.661 .66 .838 r
.54545 .18402 .54644 .18579 .54828 .18431 .5473 .18329 Mtetra
.633 .777 .95 r
.5473 .18329 .54828 .18431 .55012 .18367 .54915 .18272 Mtetra
.597 .781 .968 r
.54915 .18272 .55012 .18367 .55197 .18332 .551 .18226 Mtetra
.633 .77 .945 r
.551 .18226 .55197 .18332 .55382 .18284 .55285 .1817 Mtetra
.665 .765 .924 r
.55285 .1817 .55382 .18284 .55567 .18217 .5547 .18102 Mtetra
.672 .765 .92 r
.5547 .18102 .55567 .18217 .55753 .18147 .55655 .1803 Mtetra
.744 .784 .885 r
.55655 .1803 .55753 .18147 .55937 .18038 .5584 .1792 Mtetra
.744 .783 .884 r
.5584 .1792 .55937 .18038 .56122 .17928 .56025 .1781 Mtetra
.613 .738 .935 r
.56025 .1781 .56122 .17928 .56308 .1788 .56211 .17762 Mtetra
0 0 .472 r
.56211 .17762 .56308 .1788 .56497 .18102 .564 .17984 Mtetra
.975 .677 .388 r
.564 .17984 .56497 .18102 .56976 .38961 .56871 .38824 Mtetra
.928 .554 .156 r
.56871 .38824 .56976 .38961 .57188 .39831 .57084 .39698 Mtetra
0 .25 .754 r
.57084 .39698 .57188 .39831 .57391 .39975 .57287 .39843 Mtetra
.62 .731 .926 r
.57287 .39843 .57391 .39975 .57592 .3992 .57487 .39789 Mtetra
.728 .772 .887 r
.57487 .39789 .57592 .3992 .57791 .39809 .57687 .39679 Mtetra
.717 .771 .895 r
.57687 .39679 .57791 .39809 .57991 .39705 .57887 .39577 Mtetra
.667 .758 .918 r
.57887 .39577 .57991 .39705 .58191 .39628 .58087 .39502 Mtetra
.666 .76 .92 r
.58087 .39502 .58191 .39628 .58392 .39552 .58288 .39427 Mtetra
.662 .761 .923 r
.58288 .39427 .58392 .39552 .58592 .39478 .58488 .39354 Mtetra
.656 .76 .926 r
.58488 .39354 .58592 .39478 .58793 .39408 .58689 .39283 Mtetra
.653 .76 .928 r
.58689 .39283 .58793 .39408 .58994 .39339 .5889 .39214 Mtetra
.649 .758 .929 r
.5889 .39214 .58994 .39339 .59195 .39272 .59092 .39147 Mtetra
.646 .756 .929 r
.59092 .39147 .59195 .39272 .59396 .39208 .59293 .39081 Mtetra
.644 .753 .928 r
.59293 .39081 .59396 .39208 .59598 .39144 .59495 .39016 Mtetra
.644 .751 .927 r
.59495 .39016 .59598 .39144 .598 .3908 .59696 .38951 Mtetra
.644 .749 .925 r
.59696 .38951 .598 .3908 .60001 .39016 .59898 .38887 Mtetra
.644 .747 .924 r
.59898 .38887 .60001 .39016 .60203 .38952 .601 .38822 Mtetra
.644 .746 .923 r
.601 .38822 .60203 .38952 .60406 .38888 .60303 .38757 Mtetra
.644 .745 .922 r
.60303 .38757 .60406 .38888 .60608 .38823 .60505 .38691 Mtetra
.644 .744 .922 r
.60505 .38691 .60608 .38823 .6081 .38758 .60707 .38626 Mtetra
.645 .744 .921 r
.60707 .38626 .6081 .38758 .61013 .38693 .6091 .38561 Mtetra
.645 .743 .921 r
.6091 .38561 .61013 .38693 .61215 .38628 .61113 .38495 Mtetra
.61113 .38495 .61215 .38628 .61418 .38562 .61316 .38429 Mtetra
.61316 .38429 .61418 .38562 .61621 .38496 .61519 .38364 Mtetra
.645 .744 .921 r
.61519 .38364 .61621 .38496 .61824 .3843 .61722 .38298 Mtetra
.644 .744 .922 r
.61722 .38298 .61824 .3843 .62028 .38364 .61925 .38232 Mtetra
.642 .744 .923 r
.61925 .38232 .62028 .38364 .62231 .38299 .62129 .38168 Mtetra
.64 .744 .924 r
.62129 .38168 .62231 .38299 .62435 .38235 .62333 .38104 Mtetra
.64 .746 .926 r
.62333 .38104 .62435 .38235 .62638 .3817 .62537 .3804 Mtetra
.598 .73 .937 r
.62537 .3804 .62638 .3817 .62843 .38117 .62741 .37994 Mtetra
.558 .726 .953 r
.62741 .37994 .62843 .38117 .63047 .38072 .62946 .37961 Mtetra
.669 .795 .942 r
.62946 .37961 .63047 .38072 .63251 .38 .6315 .37883 Mtetra
.863 .825 .809 r
.6315 .37883 .63251 .38 .63453 .37843 .63349 .37659 Mtetra
.942 .742 .604 r
.63349 .37659 .63453 .37843 .63648 .3752 .63533 .36998 Mtetra
.975 .677 .383 r
.63533 .36998 .63648 .3752 .63836 .3699 .62997 .15917 Mtetra
.529 .298 .509 r
.62997 .15917 .63836 .3699 .64015 .36224 .63172 .15409 Mtetra
.52 .292 .508 r
.63172 .15409 .64015 .36224 .64224 .36293 .63362 .15318 Mtetra
.519 .291 .508 r
.63362 .15318 .64224 .36293 .64434 .36381 .63554 .15294 Mtetra
.52 .291 .508 r
.63554 .15294 .64434 .36381 .64607 .35484 .63745 .15236 Mtetra
.522 .293 .508 r
.63745 .15236 .64607 .35484 .64042 .15603 .63933 .15075 Mtetra
.635 .471 .643 r
.63933 .15075 .64042 .15603 .64218 .15154 .6412 .14924 Mtetra
.695 .626 .775 r
.6412 .14924 .64218 .15154 .64403 .14927 .6431 .14807 Mtetra
.664 .76 .922 r
.6431 .14807 .64403 .14927 .64594 .14843 .64501 .14736 Mtetra
.635 .778 .949 r
.64501 .14736 .64594 .14843 .64786 .14793 .64693 .14677 Mtetra
.645 .762 .934 r
.64693 .14677 .64786 .14793 .64978 .14745 .64884 .14614 Mtetra
.677 .746 .902 r
.64884 .14614 .64978 .14745 .65169 .1467 .65076 .14537 Mtetra
.683 .744 .897 r
.65076 .14537 .65169 .1467 .65361 .14591 .65267 .14456 Mtetra
.711 .751 .883 r
.65267 .14456 .65361 .14591 .65551 .14502 .65458 .1436 Mtetra
.741 .751 .86 r
.65458 .1436 .65551 .14502 .65742 .14397 .65647 .14242 Mtetra
.675 .706 .871 r
.65647 .14242 .65742 .14397 .65933 .14312 .65839 .14163 Mtetra
.417 .585 .91 r
.65839 .14163 .65933 .14312 .66127 .14275 .66036 .14187 Mtetra
.736 .26 0 r
.66036 .14187 .66127 .14275 .66325 .1433 .66247 .14521 Mtetra
.974 .665 .349 r
.66247 .14521 .66325 .1433 .66528 .14496 .67417 .35245 Mtetra
.53 .294 .501 r
.67417 .35245 .66528 .14496 .66753 .15089 .67663 .35987 Mtetra
.519 .286 .5 r
.67663 .35987 .66753 .15089 .6795 .3566 .67879 .36097 Mtetra
.493 .15 .314 r
.67879 .36097 .6795 .3566 .68181 .36077 .68091 .36113 Mtetra
.007 0 0 r
.68091 .36113 .68181 .36077 .68399 .3621 .683 .36082 Mtetra
.611 .744 .94 r
.683 .36082 .68399 .3621 .68609 .36176 .68509 .36029 Mtetra
.641 .723 .907 r
.68509 .36029 .68609 .36176 .68817 .36104 .68718 .35963 Mtetra
.595 .714 .927 r
.68718 .35963 .68817 .36104 .69026 .3605 .68927 .35918 Mtetra
.413 .636 .947 r
.68927 .35918 .69026 .3605 .6924 .36081 .6914 .35933 Mtetra
.58 .694 .92 r
.6914 .35933 .6924 .36081 .69451 .36055 .69351 .35895 Mtetra
.789 .757 .824 r
.69351 .35895 .69451 .36055 .69655 .35897 .69554 .35724 Mtetra
.955 .753 .59 r
.69554 .35724 .69655 .35897 .69832 .3525 .6973 .35038 Mtetra
.977 .675 .349 r
.6973 .35038 .69832 .3525 .68858 .13794 .68764 .13623 Mtetra
.941 .751 .618 r
.68764 .13623 .68858 .13794 .69024 .13211 .68932 .13078 Mtetra
.749 .771 .871 r
.68932 .13078 .69024 .13211 .69215 .13089 .69124 .12958 Mtetra
.612 .721 .923 r
.69124 .12958 .69215 .13089 .69411 .13041 .6932 .12908 Mtetra
.552 .691 .931 r
.6932 .12908 .69411 .13041 .69608 .13017 .69517 .12882 Mtetra
.676 .742 .901 r
.69517 .12882 .69608 .13017 .69803 .1294 .69711 .12804 Mtetra
.682 .742 .897 r
.69711 .12804 .69803 .1294 .69997 .12859 .69905 .12723 Mtetra
.707 .752 .887 r
.69905 .12723 .69997 .12859 .7019 .12762 .70099 .12628 Mtetra
.776 .779 .855 r
.70099 .12628 .7019 .12762 .70381 .12615 .7029 .12489 Mtetra
.709 .77 .9 r
.7029 .12489 .70381 .12615 .70574 .12514 .70484 .12394 Mtetra
.43 .652 .952 r
.70484 .12394 .70574 .12514 .70774 .12516 .70684 .12402 Mtetra
.789 .357 0 r
.70684 .12402 .70774 .12516 .71003 .12976 .70914 .12882 Mtetra
.973 .662 .316 r
.70914 .12882 .71003 .12976 .72554 .34282 .72459 .34176 Mtetra
.786 .341 0 r
.72459 .34176 .72554 .34282 .72801 .34783 .72704 .34657 Mtetra
.467 .681 .958 r
.72704 .34657 .72801 .34783 .73016 .34777 .7292 .34653 Mtetra
.675 .781 .929 r
.7292 .34653 .73016 .34777 .73227 .34692 .73131 .3457 Mtetra
.72 .8 .915 r
.73131 .3457 .73227 .34692 .73436 .34586 .7334 .34464 Mtetra
.443 .674 .962 r
.7334 .34464 .73436 .34586 .73653 .34596 .73557 .34465 Mtetra
.594 .735 .942 r
.73557 .34465 .73653 .34596 .73867 .34556 .7377 .34418 Mtetra
.783 .795 .862 r
.7377 .34418 .73867 .34556 .74073 .34406 .73977 .34265 Mtetra
.973 .773 .575 r
.73977 .34265 .74073 .34406 .74241 .33691 .74146 .33568 Mtetra
.976 .67 .325 r
.74146 .33568 .74241 .33691 .72963 .12186 .72876 .12092 Mtetra
.982 .807 .593 r
.72876 .12092 .72963 .12186 .73126 .11634 .73038 .11527 Mtetra
.757 .826 .906 r
.73038 .11527 .73126 .11634 .73321 .11524 .73232 .11408 Mtetra
.593 .747 .951 r
.73232 .11408 .73321 .11524 .7352 .11488 .73432 .11364 Mtetra
.495 .679 .948 r
.73432 .11364 .7352 .11488 .73723 .1149 .73633 .11354 Mtetra
.658 .737 .908 r
.73633 .11354 .73723 .1149 .73921 .11426 .73831 .11284 Mtetra
.666 .729 .896 r
.73831 .11284 .73921 .11426 .74119 .11354 .74029 .11209 Mtetra
.677 .728 .888 r
.74029 .11209 .74119 .11354 .74316 .11273 .74226 .11128 Mtetra
.753 .758 .856 r
.74226 .11128 .74316 .11273 .7451 .11152 .7442 .11 Mtetra
.699 .726 .871 r
.7442 .11 .7451 .11152 .74706 .11051 .74616 .10906 Mtetra
.567 .676 .913 r
.74616 .10906 .74706 .11051 .74905 .10991 .74818 .10875 Mtetra
0 0 .462 r
.74818 .10875 .74905 .10991 .75115 .11067 .75043 .11158 Mtetra
.97 .654 .298 r
.75043 .11158 .75115 .11067 .75337 .11295 .76851 .31829 Mtetra
.536 .298 .501 r
.76851 .31829 .75337 .11295 .75633 .1246 .77156 .32928 Mtetra
.455 .035 .151 r
.09103 .55431 .09265 .55238 .09408 .55371 .09262 .55442 Mtetra
0 0 0 r
.09262 .55442 .09408 .55371 .09564 .55404 .09429 .55382 Mtetra
.751 .931 .947 r
.09429 .55382 .09564 .55404 .09726 .55386 .09603 .55276 Mtetra
.664 .75 .914 r
.09603 .55276 .09726 .55386 .09887 .55385 .09771 .55214 Mtetra
.711 .673 .811 r
.09771 .55214 .09887 .55385 .10053 .55337 .09945 .5511 Mtetra
.754 .641 .735 r
.09945 .5511 .10053 .55337 .10229 .55221 .10129 .54922 Mtetra
.864 .659 .623 r
.10129 .54922 .10229 .55221 .10439 .54826 .10388 .5414 Mtetra
.931 .679 .535 r
.10388 .5414 .10439 .54826 .10825 .53012 .13073 .33887 Mtetra
.531 .3 .511 r
.13073 .33887 .10825 .53012 .13362 .33812 .13283 .33415 Mtetra
.646 .502 .673 r
.13283 .33415 .13362 .33812 .13544 .33557 .13448 .33298 Mtetra
.605 .536 .751 r
.13448 .33298 .13544 .33557 .13713 .33415 .13605 .33253 Mtetra
.539 .603 .866 r
.13605 .33253 .13713 .33415 .13875 .33325 .13757 .33243 Mtetra
.634 .789 .956 r
.13757 .33243 .13875 .33325 .14033 .33264 .13915 .33194 Mtetra
.647 .819 .966 r
.13915 .33194 .14033 .33264 .1419 .33221 .14073 .33139 Mtetra
.662 .796 .946 r
.14073 .33139 .1419 .33221 .14346 .33186 .14231 .33081 Mtetra
.7 .755 .895 r
.14231 .33081 .14346 .33186 .14504 .3313 .14392 .33006 Mtetra
.69 .718 .871 r
.14392 .33006 .14504 .3313 .14663 .33068 .14552 .32933 Mtetra
.666 .694 .866 r
.14552 .32933 .14663 .33068 .14823 .33002 .14712 .3287 Mtetra
.663 .699 .873 r
.14712 .3287 .14823 .33002 .14988 .32893 .14871 .32809 Mtetra
.539 .758 .977 r
.14871 .32809 .14988 .32893 .1515 .32807 .15026 .32785 Mtetra
.309 0 0 r
.15026 .32785 .1515 .32807 .15306 .32775 .15173 .32833 Mtetra
.878 .534 .395 r
.15173 .32833 .15306 .32775 .15434 .32987 .15264 .33354 Mtetra
.935 .677 .521 r
.15264 .33354 .15434 .32987 .15453 .34121 .13039 .53593 Mtetra
.527 .292 .502 r
.13039 .53593 .15453 .34121 .13314 .53791 .1315 .54036 Mtetra
.509 .12 .239 r
.1315 .54036 .13314 .53791 .13455 .53976 .13309 .5407 Mtetra
0 0 0 r
.13309 .5407 .13455 .53976 .13614 .54011 .1348 .54006 Mtetra
.721 .959 .945 r
.1348 .54006 .13614 .54011 .1378 .5399 .13656 .53902 Mtetra
.477 .737 .984 r
.13656 .53902 .1378 .5399 .13944 .53986 .13821 .53888 Mtetra
.563 .748 .964 r
.13821 .53888 .13944 .53986 .14112 .53945 .13988 .53858 Mtetra
.747 .81 .902 r
.13988 .53858 .14112 .53945 .14289 .53836 .14164 .53755 Mtetra
.916 .76 .674 r
.14164 .53755 .14289 .53836 .14495 .53464 .14385 .53253 Mtetra
.94 .686 .525 r
.14385 .53253 .14495 .53464 .14857 .51701 .1687 .3272 Mtetra
.536 .305 .512 r
.1687 .3272 .14857 .51701 .17184 .32423 .17102 .32028 Mtetra
.677 .523 .67 r
.17102 .32028 .17184 .32423 .17369 .32144 .17274 .31866 Mtetra
.606 .527 .739 r
.17274 .31866 .17369 .32144 .17539 .32 .17434 .31817 Mtetra
.533 .572 .84 r
.17434 .31817 .17539 .32 .17703 .31907 .17589 .31811 Mtetra
.61 .753 .946 r
.17589 .31811 .17703 .31907 .17864 .31844 .17747 .3177 Mtetra
.646 .813 .964 r
.17747 .3177 .17864 .31844 .18024 .31798 .17908 .31715 Mtetra
.658 .795 .948 r
.17908 .31715 .18024 .31798 .18182 .31762 .18069 .31657 Mtetra
.749 .767 .867 r
.18069 .31657 .18182 .31762 .18346 .31678 .18235 .31552 Mtetra
.714 .726 .86 r
.18235 .31552 .18346 .31678 .18509 .316 .18399 .31464 Mtetra
.576 .664 .898 r
.18399 .31464 .18509 .316 .18667 .3157 .18557 .31438 Mtetra
.867 .435 .019 r
.18557 .31438 .18667 .3157 .18801 .31765 .1868 .31735 Mtetra
.944 .683 .512 r
.1868 .31735 .18801 .31765 .18837 .32882 .16652 .52103 Mtetra
.533 .298 .504 r
.16652 .52103 .18837 .32882 .16897 .526 .16739 .52833 Mtetra
.589 .201 .275 r
.16739 .52833 .16897 .526 .1704 .52811 .16896 .52926 Mtetra
.108 0 0 r
.16896 .52926 .1704 .52811 .17202 .52851 .17068 .52872 Mtetra
.681 .975 .902 r
.17068 .52872 .17202 .52851 .1737 .52837 .17246 .52761 Mtetra
.689 .829 .95 r
.17246 .52761 .1737 .52837 .17535 .52847 .1742 .52686 Mtetra
.686 .682 .84 r
.1742 .52686 .17535 .52847 .17704 .52829 .17595 .52602 Mtetra
.729 .635 .753 r
.17595 .52602 .17704 .52829 .1788 .52738 .17778 .52451 Mtetra
.838 .652 .652 r
.17778 .52451 .1788 .52738 .18087 .52352 .17996 .51949 Mtetra
.942 .685 .519 r
.17996 .51949 .18087 .52352 .20317 .32182 .20261 .31524 Mtetra
.774 .556 .603 r
.20261 .31524 .20317 .32182 .20596 .30987 .20486 .30853 Mtetra
.814 .732 .774 r
.20486 .30853 .20596 .30987 .20775 .30763 .20663 .30659 Mtetra
.686 .76 .908 r
.20663 .30659 .20775 .30763 .20939 .30693 .20826 .3059 Mtetra
.578 .731 .947 r
.20826 .3059 .20939 .30693 .21098 .30669 .20986 .30559 Mtetra
.723 .756 .879 r
.20986 .30559 .21098 .30669 .21263 .30587 .21152 .30469 Mtetra
.73 .744 .863 r
.21152 .30469 .21263 .30587 .21429 .30497 .21319 .30372 Mtetra
.61 .699 .907 r
.21319 .30372 .21429 .30497 .21589 .30464 .2148 .30333 Mtetra
.719 .25 0 r
.2148 .30333 .21589 .30464 .21724 .30693 .21616 .30549 Mtetra
.948 .685 .504 r
.21616 .30549 .21724 .30693 .19916 .50789 .19814 .50505 Mtetra
.974 .671 .366 r
.19814 .50505 .19916 .50789 .19983 .51826 .19864 .51706 Mtetra
.591 .09 0 r
.19864 .51706 .19983 .51826 .20135 .51994 .20016 .51881 Mtetra
.537 .711 .952 r
.20016 .51881 .20135 .51994 .20306 .51973 .20186 .5186 Mtetra
.776 .773 .85 r
.20186 .5186 .20306 .51973 .20487 .51842 .20368 .51725 Mtetra
.9 .749 .686 r
.20368 .51725 .20487 .51842 .20696 .5143 .20579 .51285 Mtetra
.947 .688 .512 r
.20579 .51285 .20696 .5143 .22799 .31015 .22705 .30721 Mtetra
.876 .663 .61 r
.22705 .30721 .22799 .31015 .23049 .30053 .22941 .29906 Mtetra
.809 .719 .766 r
.22941 .29906 .23049 .30053 .2323 .29815 .23118 .29709 Mtetra
.565 .722 .947 r
.23118 .29709 .2323 .29815 .23396 .29732 .23279 .29682 Mtetra
.019 .548 .855 r
.23279 .29682 .23396 .29732 .23558 .29695 .23435 .29713 Mtetra
.218 .74 .765 r
.23435 .29713 .23558 .29695 .23724 .29621 .23597 .29676 Mtetra
.38 .824 .695 r
.23597 .29676 .23724 .29621 .2389 .29535 .23764 .29591 Mtetra
.018 0 0 r
.23764 .29591 .2389 .29535 .24052 .29503 .23926 .29557 Mtetra
.788 .356 .225 r
.23926 .29557 .24052 .29503 .24194 .29694 .24065 .29785 Mtetra
.948 .682 .499 r
.24065 .29785 .24194 .29694 .22582 .4934 .22395 .49986 Mtetra
.78 .477 .476 r
.22395 .49986 .22582 .4934 .22606 .50959 .22488 .5084 Mtetra
0 .01 .512 r
.22488 .5084 .22606 .50959 .22761 .51135 .22645 .50994 Mtetra
.565 .671 .909 r
.22645 .50994 .22761 .51135 .22935 .51101 .22818 .50969 Mtetra
.695 .731 .878 r
.22818 .50969 .22935 .51101 .23114 .51009 .22996 .50886 Mtetra
.693 .744 .891 r
.22996 .50886 .23114 .51009 .2329 .50952 .23175 .50806 Mtetra
.69 .707 .861 r
.23175 .50806 .2329 .50952 .23464 .50922 .23353 .50723 Mtetra
.741 .664 .774 r
.23353 .50723 .23464 .50922 .23643 .50844 .23538 .50574 Mtetra
.831 .656 .666 r
.23538 .50574 .23643 .50844 .23836 .50595 .23746 .50151 Mtetra
.947 .685 .506 r
.23746 .50151 .23836 .50595 .24067 .49901 .25677 .29681 Mtetra
.537 .306 .511 r
.25677 .29681 .24067 .49901 .2598 .29418 .25907 .28878 Mtetra
.681 .499 .633 r
.25907 .28878 .2598 .29418 .2618 .28956 .26088 .2864 Mtetra
.623 .519 .715 r
.26088 .2864 .2618 .28956 .26356 .28777 .26255 .28568 Mtetra
.577 .568 .807 r
.26255 .28568 .26356 .28777 .26527 .28663 .26418 .28542 Mtetra
.584 .699 .921 r
.26418 .28542 .26527 .28663 .26695 .28582 .26582 .2851 Mtetra
.642 .825 .971 r
.26582 .2851 .26695 .28582 .26862 .28519 .26748 .28454 Mtetra
.644 .841 .976 r
.26748 .28454 .26862 .28519 .27027 .28469 .26914 .28395 Mtetra
.677 .827 .955 r
.26914 .28395 .27027 .28469 .27192 .28422 .27081 .28327 Mtetra
.694 .786 .921 r
.27081 .28327 .27192 .28422 .27358 .28371 .27249 .28253 Mtetra
.675 .736 .897 r
.27249 .28253 .27358 .28371 .27525 .28317 .27417 .28186 Mtetra
.613 .692 .899 r
.27417 .28186 .27525 .28317 .27692 .28253 .27582 .28145 Mtetra
.503 .694 .954 r
.27582 .28145 .27692 .28253 .2786 .28178 .27745 .28134 Mtetra
.284 .733 .96 r
.27745 .28134 .2786 .28178 .28028 .28102 .27908 .2813 Mtetra
.276 .775 .747 r
.27908 .2813 .28028 .28102 .28197 .28011 .28074 .28077 Mtetra
.399 .824 .654 r
.28074 .28077 .28197 .28011 .28367 .27919 .28245 .27977 Mtetra
0 0 0 r
.28245 .27977 .28367 .27919 .28534 .27868 .28411 .27926 Mtetra
.728 .262 .145 r
.28411 .27926 .28534 .27868 .2869 .2795 .28561 .28094 Mtetra
.952 .681 .488 r
.28561 .28094 .2869 .2795 .28819 .28401 .27184 .48216 Mtetra
.538 .302 .504 r
.27184 .48216 .28819 .28401 .27436 .48833 .2728 .49239 Mtetra
.636 .296 .378 r
.2728 .49239 .27436 .48833 .27576 .49294 .2744 .49429 Mtetra
.274 0 0 r
.2744 .49429 .27576 .49294 .27744 .49379 .27617 .49398 Mtetra
.516 .916 .867 r
.27617 .49398 .27744 .49379 .27919 .49385 .27799 .49313 Mtetra
.705 .85 .952 r
.27799 .49313 .27919 .49385 .28096 .49353 .2798 .49228 Mtetra
.635 .729 .915 r
.2798 .49228 .28096 .49353 .28276 .493 .2816 .49174 Mtetra
.655 .733 .907 r
.2816 .49174 .28276 .493 .28456 .49232 .2834 .49111 Mtetra
.701 .755 .894 r
.2834 .49111 .28456 .49232 .28636 .49166 .28522 .49026 Mtetra
.74 .734 .846 r
.28522 .49026 .28636 .49166 .28816 .4911 .28706 .48909 Mtetra
.718 .656 .788 r
.28706 .48909 .28816 .4911 .28996 .49054 .28891 .48784 Mtetra
.643 .567 .755 r
.28891 .48784 .28996 .49054 .29175 .49015 .29072 .48704 Mtetra
.553 .492 .741 r
.29072 .48704 .29175 .49015 .29353 .48991 .2925 .48689 Mtetra
.617 .535 .739 r
.2925 .48689 .29353 .48991 .29534 .48924 .29431 .48624 Mtetra
.768 .617 .693 r
.29431 .48624 .29534 .48924 .29724 .48729 .29626 .48357 Mtetra
.954 .687 .492 r
.29626 .48357 .29724 .48729 .29939 .48168 .31139 .28868 Mtetra
.563 .327 .516 r
.31139 .28868 .29939 .48168 .31508 .27601 .31437 .26935 Mtetra
.687 .489 .613 r
.31437 .26935 .31508 .27601 .31717 .26961 .31624 .26618 Mtetra
.63 .513 .702 r
.31624 .26618 .31717 .26961 .31896 .26759 .31795 .26532 Mtetra
.587 .559 .789 r
.31795 .26532 .31896 .26759 .3207 .26634 .31963 .26499 Mtetra
.563 .668 .908 r
.31963 .26499 .3207 .26634 .32241 .26548 .3213 .26476 Mtetra
.636 .827 .974 r
.3213 .26476 .32241 .26548 .32411 .26481 .323 .26419 Mtetra
.633 .85 .983 r
.323 .26419 .32411 .26481 .3258 .2643 .3247 .26361 Mtetra
.653 .839 .972 r
.3247 .26361 .3258 .2643 .32749 .26384 .3264 .26298 Mtetra
.677 .807 .945 r
.3264 .26298 .32749 .26384 .32919 .26333 .32811 .2623 Mtetra
.681 .772 .919 r
.32811 .2623 .32919 .26333 .33089 .26282 .32982 .2616 Mtetra
.683 .736 .892 r
.32982 .2616 .33089 .26282 .33259 .26226 .33153 .26088 Mtetra
.682 .708 .868 r
.33153 .26088 .33259 .26226 .33429 .26162 .33324 .26013 Mtetra
.663 .685 .861 r
.33324 .26013 .33429 .26162 .336 .26095 .33495 .25947 Mtetra
.647 .681 .868 r
.33495 .25947 .336 .26095 .33772 .26012 .33666 .25889 Mtetra
.629 .717 .91 r
.33666 .25889 .33772 .26012 .33946 .25905 .33836 .2584 Mtetra
.327 .715 .982 r
.33836 .2584 .33946 .25905 .34117 .25836 .34003 .25842 Mtetra
.715 .196 0 r
.34003 .25842 .34117 .25836 .34282 .25875 .34161 .26001 Mtetra
.957 .682 .472 r
.34161 .26001 .34282 .25875 .34425 .26298 .33151 .45992 Mtetra
.543 .305 .505 r
.33151 .45992 .34425 .26298 .33404 .46805 .33257 .47243 Mtetra
.657 .32 .389 r
.33257 .47243 .33404 .46805 .33555 .47301 .33423 .47486 Mtetra
.4 0 .095 r
.33423 .47486 .33555 .47301 .33735 .47284 .33603 .47478 Mtetra
.233 0 .013 r
.33603 .47478 .33735 .47284 .3392 .472 .33787 .47406 Mtetra
.134 0 0 r
.33787 .47406 .3392 .472 .34104 .47139 .33974 .47297 Mtetra
0 0 0 r
.33974 .47297 .34104 .47139 .3428 .47206 .34161 .47179 Mtetra
.787 .948 .927 r
.34161 .47179 .3428 .47206 .34458 .47255 .34349 .47046 Mtetra
.699 .645 .792 r
.34349 .47046 .34458 .47255 .34638 .47272 .34536 .46935 Mtetra
.561 .485 .727 r
.34536 .46935 .34638 .47272 .3482 .47247 .34718 .46913 Mtetra
.605 .513 .723 r
.34718 .46913 .3482 .47247 .35005 .47171 .34902 .46853 Mtetra
.722 .587 .704 r
.34902 .46853 .35005 .47171 .35196 .47 .35094 .46657 Mtetra
.897 .668 .583 r
.35094 .46657 .35196 .47 .35402 .46523 .35331 .45587 Mtetra
.953 .68 .482 r
.35331 .45587 .35402 .46523 .36632 .26115 .36571 .25138 Mtetra
.668 .454 .585 r
.36571 .25138 .36632 .26115 .36853 .25118 .36761 .24736 Mtetra
.635 .503 .685 r
.36761 .24736 .36853 .25118 .37035 .24886 .36936 .24633 Mtetra
.602 .547 .765 r
.36936 .24633 .37035 .24886 .37212 .24746 .37108 .24587 Mtetra
.572 .636 .876 r
.37108 .24587 .37212 .24746 .37386 .2465 .37279 .24562 Mtetra
.674 .807 .946 r
.37279 .24562 .37386 .2465 .3756 .24574 .37453 .24494 Mtetra
.675 .823 .955 r
.37453 .24494 .3756 .24574 .37733 .24515 .37627 .24424 Mtetra
.678 .801 .94 r
.37627 .24424 .37733 .24515 .37906 .24465 .378 .24354 Mtetra
.684 .762 .91 r
.378 .24354 .37906 .24465 .38079 .24411 .37974 .24281 Mtetra
.667 .722 .89 r
.37974 .24281 .38079 .24411 .38252 .24356 .38148 .24215 Mtetra
.636 .692 .885 r
.38148 .24215 .38252 .24356 .38426 .24295 .38322 .24162 Mtetra
.541 .666 .919 r
.38322 .24162 .38426 .24295 .38601 .24219 .38494 .24145 Mtetra
.412 .739 .992 r
.38494 .24145 .38601 .24219 .38775 .2414 .38665 .24137 Mtetra
.149 .692 .798 r
.38665 .24137 .38775 .2414 .3895 .24059 .38837 .2412 Mtetra
.416 .832 .654 r
.38837 .2412 .3895 .24059 .39126 .23957 .39014 .24012 Mtetra
0 0 0 r
.39014 .24012 .39126 .23957 .39301 .23888 .39189 .23939 Mtetra
.352 0 0 r
.39189 .23939 .39301 .23888 .39472 .2389 .39359 .23963 Mtetra
.909 .557 .362 r
.39359 .23963 .39472 .2389 .39631 .24209 .39498 .24751 Mtetra
.957 .675 .46 r
.39498 .24751 .39631 .24209 .3896 .44567 .38814 .4526 Mtetra
.661 .348 .432 r
.38814 .4526 .3896 .44567 .39109 .45426 .38984 .45617 Mtetra
.411 0 .107 r
.38984 .45617 .39109 .45426 .39293 .4545 .39169 .45613 Mtetra
.189 0 0 r
.39169 .45613 .39293 .4545 .39481 .45373 .39357 .45541 Mtetra
.088 0 0 r
.39357 .45541 .39481 .45373 .3967 .45247 .39546 .4544 Mtetra
.287 0 .042 r
.39546 .4544 .3967 .45247 .39858 .45184 .39734 .45385 Mtetra
.295 0 .058 r
.39734 .45385 .39858 .45184 .40046 .45121 .39921 .45329 Mtetra
.3 0 .072 r
.39921 .45329 .40046 .45121 .40233 .45055 .40109 .45272 Mtetra
.299 0 .083 r
.40109 .45272 .40233 .45055 .40422 .44971 .40297 .45211 Mtetra
.316 0 .119 r
.40297 .45211 .40422 .44971 .4061 .44903 .40485 .45148 Mtetra
.316 0 .124 r
.40485 .45148 .4061 .44903 .40797 .44867 .40674 .45082 Mtetra
.277 0 .069 r
.40674 .45082 .40797 .44867 .40982 .44924 .40863 .45013 Mtetra
0 0 0 r
.40863 .45013 .40982 .44924 .41166 .44973 .41051 .44943 Mtetra
.578 .908 .977 r
.41051 .44943 .41166 .44973 .41352 .44996 .41241 .44873 Mtetra
.633 .742 .927 r
.41241 .44873 .41352 .44996 .4154 .44949 .41429 .44817 Mtetra
.643 .729 .911 r
.41429 .44817 .4154 .44949 .41729 .44885 .41618 .44757 Mtetra
.665 .743 .908 r
.41618 .44757 .41729 .44885 .41918 .44815 .41808 .44686 Mtetra
.738 .764 .874 r
.41808 .44686 .41918 .44815 .42107 .44767 .41998 .44574 Mtetra
.722 .673 .802 r
.41998 .44574 .42107 .44767 .42296 .4472 .4219 .44448 Mtetra
.688 .596 .747 r
.4219 .44448 .42296 .4472 .42485 .44668 .42381 .44322 Mtetra
.555 .479 .725 r
.42381 .44322 .42485 .44668 .42674 .44639 .4257 .44304 Mtetra
.587 .504 .728 r
.4257 .44304 .42674 .44639 .42864 .44578 .42759 .44259 Mtetra
.671 .561 .722 r
.42759 .44259 .42864 .44578 .43055 .44455 .4295 .44133 Mtetra
.88 .665 .608 r
.4295 .44133 .43055 .44455 .43256 .44029 .4316 .43397 Mtetra
.963 .684 .457 r
.4316 .43397 .43256 .44029 .4354 .40566 .43933 .22559 Mtetra
.531 .301 .51 r
.43933 .22559 .4354 .40566 .44218 .22463 .44123 .22042 Mtetra
.652 .503 .669 r
.44123 .22042 .44218 .22463 .44398 .22299 .44303 .21904 Mtetra
.594 .475 .686 r
.44303 .21904 .44398 .22299 .44576 .22246 .4448 .21844 Mtetra
.558 .449 .686 r
.4448 .21844 .44576 .22246 .44753 .22225 .44657 .2182 Mtetra
.586 .467 .683 r
.44657 .2182 .44753 .22225 .44933 .22062 .44835 .21767 Mtetra
.607 .526 .737 r
.44835 .21767 .44933 .22062 .45114 .21896 .45013 .21711 Mtetra
.635 .633 .831 r
.45013 .21711 .45114 .21896 .45294 .21754 .45191 .21653 Mtetra
.668 .784 .935 r
.45191 .21653 .45294 .21754 .45473 .21678 .4537 .21585 Mtetra
.677 .806 .944 r
.4537 .21585 .45473 .21678 .45651 .21624 .45549 .21514 Mtetra
.68 .77 .919 r
.45549 .21514 .45651 .21624 .45829 .21578 .45727 .21441 Mtetra
.684 .722 .878 r
.45727 .21441 .45829 .21578 .46008 .21516 .45907 .21363 Mtetra
.67 .692 .862 r
.45907 .21363 .46008 .21516 .46187 .21447 .46086 .2129 Mtetra
.648 .677 .863 r
.46086 .2129 .46187 .21447 .46366 .21376 .46265 .21228 Mtetra
.653 .694 .876 r
.46265 .21228 .46366 .21376 .46546 .21264 .46444 .21165 Mtetra
.548 .747 .969 r
.46444 .21165 .46546 .21264 .46726 .21172 .46622 .21137 Mtetra
0 .449 .742 r
.46622 .21137 .46726 .21172 .46904 .21135 .468 .21182 Mtetra
.886 .491 .271 r
.468 .21182 .46904 .21135 .47079 .21358 .46969 .21706 Mtetra
.965 .676 .433 r
.46969 .21706 .47079 .21358 .47227 .23137 .46782 .42492 Mtetra
.526 .291 .501 r
.46782 .42492 .47227 .23137 .47081 .42717 .46966 .42944 Mtetra
.507 .096 .195 r
.46966 .42944 .47081 .42717 .47271 .42805 .47157 .42987 Mtetra
.256 0 .011 r
.47157 .42987 .47271 .42805 .47464 .42734 .4735 .42924 Mtetra
.146 0 0 r
.4735 .42924 .47464 .42734 .47657 .42626 .47544 .4282 Mtetra
.265 0 .034 r
.47544 .4282 .47657 .42626 .47849 .42653 .47737 .42754 Mtetra
.091 0 0 r
.47737 .42754 .47849 .42653 .48041 .42705 .47931 .42694 Mtetra
.502 .901 .929 r
.47931 .42694 .48041 .42705 .48233 .42733 .48125 .42624 Mtetra
.658 .782 .94 r
.48125 .42624 .48233 .42733 .48426 .42734 .48318 .42555 Mtetra
.699 .685 .833 r
.48318 .42555 .48426 .42734 .4862 .42691 .48513 .42453 Mtetra
.747 .649 .752 r
.48513 .42453 .4862 .42691 .48814 .42582 .48708 .42275 Mtetra
.87 .667 .625 r
.48708 .42275 .48814 .42582 .49011 .42243 .48908 .41673 Mtetra
.968 .683 .438 r
.48908 .41673 .49011 .42243 .49215 .41254 .4932 .20709 Mtetra
.531 .3 .509 r
.4932 .20709 .49215 .41254 .49604 .20584 .49507 .20109 Mtetra
.662 .498 .652 r
.49507 .20109 .49604 .20584 .49789 .20236 .4969 .19933 Mtetra
.613 .526 .732 r
.4969 .19933 .49789 .20236 .49971 .20069 .49871 .19869 Mtetra
.566 .584 .831 r
.49871 .19869 .49971 .20069 .50153 .19961 .50052 .19847 Mtetra
.615 .743 .937 r
.50052 .19847 .50153 .19961 .50334 .19886 .50234 .19799 Mtetra
.648 .814 .963 r
.50234 .19799 .50334 .19886 .50516 .19832 .50416 .19736 Mtetra
.66 .799 .949 r
.50416 .19736 .50516 .19832 .50698 .19788 .50598 .1967 Mtetra
.693 .764 .906 r
.50598 .1967 .50698 .19788 .5088 .19728 .5078 .19589 Mtetra
.691 .725 .876 r
.5078 .19589 .5088 .19728 .51062 .19658 .50962 .19506 Mtetra
.67 .696 .866 r
.50962 .19506 .51062 .19658 .51244 .19584 .51144 .19433 Mtetra
.663 .695 .869 r
.51144 .19433 .51244 .19584 .51427 .19474 .51327 .19363 Mtetra
.593 .742 .947 r
.51327 .19363 .51427 .19474 .51609 .19372 .51509 .19322 Mtetra
.093 .601 .892 r
.51509 .19322 .51609 .19372 .51792 .1932 .51692 .19348 Mtetra
.849 .407 .166 r
.51692 .19348 .51792 .1932 .51974 .19468 .51874 .19716 Mtetra
.97 .676 .413 r
.51874 .19716 .51974 .19468 .52156 .20182 .52027 .40577 Mtetra
.528 .292 .501 r
.52027 .40577 .52156 .20182 .52329 .40863 .52222 .41154 Mtetra
.57 .184 .272 r
.52222 .41154 .52329 .40863 .52526 .41136 .52419 .4125 Mtetra
.181 0 0 r
.52419 .4125 .52526 .41136 .52722 .41183 .52616 .41202 Mtetra
.522 .917 .83 r
.52616 .41202 .52722 .41183 .52919 .41167 .52813 .41099 Mtetra
.682 .879 .972 r
.52813 .41099 .52919 .41167 .53116 .4116 .5301 .41012 Mtetra
.701 .732 .875 r
.5301 .41012 .53116 .4116 .53313 .41133 .53207 .40916 Mtetra
.748 .669 .774 r
.53207 .40916 .53313 .41133 .53511 .41044 .53404 .40752 Mtetra
.858 .668 .645 r
.53404 .40752 .53511 .41044 .53707 .40755 .536 .40259 Mtetra
.971 .683 .421 r
.536 .40259 .53707 .40755 .53902 .39979 .53712 .19284 Mtetra
.534 .302 .51 r
.53712 .19284 .53902 .39979 .53995 .19089 .53894 .18551 Mtetra
.668 .49 .636 r
.53894 .18551 .53995 .19089 .54177 .18673 .54078 .18337 Mtetra
.609 .509 .715 r
.54078 .18337 .54177 .18673 .54361 .18505 .54262 .18271 Mtetra
.557 .545 .797 r
.54262 .18271 .54361 .18505 .54545 .18402 .54447 .18254 Mtetra
.576 .663 .897 r
.54447 .18254 .54545 .18402 .5473 .18329 .54632 .18223 Mtetra
.621 .766 .949 r
.54632 .18223 .5473 .18329 .54915 .18272 .54817 .18171 Mtetra
.626 .779 .954 r
.54817 .18171 .54915 .18272 .551 .18226 .55002 .18117 Mtetra
.649 .769 .936 r
.55002 .18117 .551 .18226 .55285 .1817 .55187 .18055 Mtetra
.667 .763 .922 r
.55187 .18055 .55285 .1817 .5547 .18102 .55372 .17985 Mtetra
.675 .764 .918 r
.55372 .17985 .5547 .18102 .55655 .1803 .55557 .17912 Mtetra
.737 .781 .888 r
.55557 .17912 .55655 .1803 .5584 .1792 .55742 .17806 Mtetra
.74 .789 .893 r
.55742 .17806 .5584 .1792 .56025 .1781 .55927 .177 Mtetra
.623 .758 .943 r
.55927 .177 .56025 .1781 .56211 .17762 .56113 .17647 Mtetra
0 .11 .629 r
.56113 .17647 .56211 .17762 .564 .17984 .56302 .17815 Mtetra
.975 .678 .386 r
.56302 .17815 .564 .17984 .56871 .38824 .56743 .36873 Mtetra
0 0 .276 r
.56743 .36873 .56871 .38824 .57084 .39698 .56976 .39354 Mtetra
.235 .281 .706 r
.56976 .39354 .57084 .39698 .57287 .39843 .5718 .39533 Mtetra
.599 .529 .747 r
.5718 .39533 .57287 .39843 .57487 .39789 .5738 .39479 Mtetra
.664 .566 .734 r
.5738 .39479 .57487 .39789 .57687 .39679 .5758 .39362 Mtetra
.655 .557 .732 r
.5758 .39362 .57687 .39679 .57887 .39577 .57779 .39254 Mtetra
.622 .535 .735 r
.57779 .39254 .57887 .39577 .58087 .39502 .5798 .39176 Mtetra
.621 .534 .734 r
.5798 .39176 .58087 .39502 .58288 .39427 .5818 .391 Mtetra
.618 .531 .734 r
.5818 .391 .58288 .39427 .58488 .39354 .58381 .39025 Mtetra
.615 .529 .733 r
.58381 .39025 .58488 .39354 .58689 .39283 .58582 .38954 Mtetra
.613 .527 .733 r
.58582 .38954 .58689 .39283 .5889 .39214 .58783 .38884 Mtetra
.611 .525 .733 r
.58783 .38884 .5889 .39214 .59092 .39147 .58984 .38815 Mtetra
.61 .524 .733 r
.58984 .38815 .59092 .39147 .59293 .39081 .59185 .38748 Mtetra
.608 .523 .732 r
.59185 .38748 .59293 .39081 .59495 .39016 .59387 .38682 Mtetra
.608 .522 .732 r
.59387 .38682 .59495 .39016 .59696 .38951 .59589 .38617 Mtetra
.607 .521 .731 r
.59589 .38617 .59696 .38951 .59898 .38887 .59791 .38551 Mtetra
.59791 .38551 .59898 .38887 .601 .38822 .59993 .38486 Mtetra
.59993 .38486 .601 .38822 .60303 .38757 .60195 .38421 Mtetra
.60195 .38421 .60303 .38757 .60505 .38691 .60397 .38356 Mtetra
.60397 .38356 .60505 .38691 .60707 .38626 .60599 .3829 Mtetra
.60599 .3829 .60707 .38626 .6091 .38561 .60802 .38225 Mtetra
.60802 .38225 .6091 .38561 .61113 .38495 .61005 .38159 Mtetra
.61005 .38159 .61113 .38495 .61316 .38429 .61208 .38094 Mtetra
.607 .521 .732 r
.61208 .38094 .61316 .38429 .61519 .38364 .61411 .38028 Mtetra
.61411 .38028 .61519 .38364 .61722 .38298 .61614 .37963 Mtetra
.606 .521 .732 r
.61614 .37963 .61722 .38298 .61925 .38232 .61817 .37898 Mtetra
.605 .521 .733 r
.61817 .37898 .61925 .38232 .62129 .38168 .62021 .37835 Mtetra
.604 .521 .734 r
.62021 .37835 .62129 .38168 .62333 .38104 .62225 .37773 Mtetra
.605 .522 .735 r
.62225 .37773 .62333 .38104 .62537 .3804 .62428 .3771 Mtetra
.576 .506 .739 r
.62428 .3771 .62537 .3804 .62741 .37994 .62633 .37674 Mtetra
.554 .498 .748 r
.62633 .37674 .62741 .37994 .62946 .37961 .62839 .37656 Mtetra
.631 .552 .747 r
.62839 .37656 .62946 .37961 .6315 .37883 .63043 .37574 Mtetra
.792 .635 .687 r
.63043 .37574 .6315 .37883 .63349 .37659 .63239 .37266 Mtetra
.976 .679 .382 r
.63239 .37266 .63349 .37659 .63533 .36998 .6274 .16673 Mtetra
.546 .311 .51 r
.6274 .16673 .63533 .36998 .62997 .15917 .62886 .15322 Mtetra
.699 .502 .618 r
.62886 .15322 .62997 .15917 .63172 .15409 .63068 .15007 Mtetra
.619 .492 .685 r
.63068 .15007 .63172 .15409 .63362 .15318 .63257 .14914 Mtetra
.572 .461 .689 r
.63257 .14914 .63362 .15318 .63554 .15294 .63449 .14874 Mtetra
.559 .448 .684 r
.63449 .14874 .63554 .15294 .63745 .15236 .63641 .14846 Mtetra
.587 .476 .694 r
.63641 .14846 .63745 .15236 .63933 .15075 .63833 .14793 Mtetra
.603 .538 .754 r
.63833 .14793 .63933 .15075 .6412 .14924 .64024 .1474 Mtetra
.627 .642 .846 r
.64024 .1474 .6412 .14924 .6431 .14807 .64216 .14684 Mtetra
.647 .749 .924 r
.64216 .14684 .6431 .14807 .64501 .14736 .64408 .14621 Mtetra
.657 .768 .931 r
.64408 .14621 .64501 .14736 .64693 .14677 .64599 .14553 Mtetra
.67 .757 .916 r
.64599 .14553 .64693 .14677 .64884 .14614 .6479 .1448 Mtetra
.68 .741 .897 r
.6479 .1448 .64884 .14614 .65076 .14537 .64982 .14401 Mtetra
.686 .74 .892 r
.64982 .14401 .65076 .14537 .65267 .14456 .65173 .14318 Mtetra
.721 .75 .875 r
.65173 .14318 .65267 .14456 .65458 .1436 .65364 .14215 Mtetra
.758 .751 .846 r
.65364 .14215 .65458 .1436 .65647 .14242 .65553 .14084 Mtetra
.677 .7 .865 r
.65553 .14084 .65647 .14242 .65839 .14163 .65745 .14003 Mtetra
.314 .504 .884 r
.65745 .14003 .65839 .14163 .66036 .14187 .65943 .14062 Mtetra
.882 .485 .035 r
.65943 .14062 .66036 .14187 .66247 .14521 .6617 .14756 Mtetra
.973 .665 .35 r
.6617 .14756 .66247 .14521 .67417 .35245 .67354 .35878 Mtetra
.653 .32 .395 r
.67354 .35878 .67417 .35245 .67663 .35987 .6758 .36213 Mtetra
.379 0 .131 r
.6758 .36213 .67663 .35987 .67879 .36097 .6779 .36181 Mtetra
0 0 0 r
.6779 .36181 .67879 .36097 .68091 .36113 .67996 .36077 Mtetra
.713 .959 .946 r
.67996 .36077 .68091 .36113 .683 .36082 .68201 .35957 Mtetra
.623 .754 .94 r
.68201 .35957 .683 .36082 .68509 .36029 .6841 .35899 Mtetra
.632 .749 .932 r
.6841 .35899 .68509 .36029 .68718 .35963 .68619 .35837 Mtetra
.639 .758 .935 r
.68619 .35837 .68718 .35963 .68927 .35918 .68828 .35771 Mtetra
.636 .721 .909 r
.68828 .35771 .68927 .35918 .6914 .35933 .69037 .35708 Mtetra
.692 .645 .799 r
.69037 .35708 .6914 .35933 .69351 .35895 .69243 .35593 Mtetra
.77 .63 .705 r
.69243 .35593 .69351 .35895 .69554 .35724 .69442 .35338 Mtetra
.923 .671 .539 r
.69442 .35338 .69554 .35724 .6973 .35038 .69594 .34217 Mtetra
.974 .67 .363 r
.69594 .34217 .6973 .35038 .68764 .13623 .68665 .13351 Mtetra
.854 .673 .656 r
.68665 .13351 .68764 .13623 .68932 .13078 .68841 .12945 Mtetra
.735 .767 .879 r
.68841 .12945 .68932 .13078 .69124 .12958 .69033 .12834 Mtetra
.618 .739 .932 r
.69033 .12834 .69124 .12958 .6932 .12908 .69228 .12782 Mtetra
.576 .713 .936 r
.69228 .12782 .6932 .12908 .69517 .12882 .69425 .12746 Mtetra
.69 .745 .893 r
.69425 .12746 .69517 .12882 .69711 .12804 .69619 .1266 Mtetra
.68 .728 .886 r
.69619 .1266 .69711 .12804 .69905 .12723 .69813 .12579 Mtetra
.668 .723 .89 r
.69813 .12579 .69905 .12723 .70099 .12628 .70008 .12504 Mtetra
.678 .763 .916 r
.70008 .12504 .70099 .12628 .7029 .12489 .70203 .12425 Mtetra
.483 .815 .999 r
.70203 .12425 .7029 .12489 .70484 .12394 .70401 .12392 Mtetra
.366 0 0 r
.70401 .12392 .70484 .12394 .70684 .12402 .70605 .12469 Mtetra
.912 .514 .221 r
.70605 .12469 .70684 .12402 .70914 .12882 .70858 .13308 Mtetra
.972 .658 .331 r
.70858 .13308 .70914 .12882 .72459 .34176 .72371 .34195 Mtetra
.793 .297 0 r
.72371 .34195 .72459 .34176 .72704 .34657 .72608 .34536 Mtetra
.445 .678 .963 r
.72608 .34536 .72704 .34657 .7292 .34653 .72824 .34536 Mtetra
.652 .787 .947 r
.72824 .34536 .7292 .34653 .73131 .3457 .73036 .34463 Mtetra
.73 .836 .93 r
.73036 .34463 .73131 .3457 .7334 .34464 .73245 .34353 Mtetra
.649 .798 .954 r
.73245 .34353 .7334 .34464 .73557 .34465 .73457 .3428 Mtetra
.719 .704 .835 r
.73457 .3428 .73557 .34465 .7377 .34418 .73665 .34158 Mtetra
.779 .661 .732 r
.73665 .34158 .7377 .34418 .73977 .34265 .73867 .33925 Mtetra
.927 .683 .549 r
.73867 .33925 .73977 .34265 .74146 .33568 .74018 .32965 Mtetra
.975 .667 .337 r
.74018 .32965 .74146 .33568 .72876 .12092 .7278 .11879 Mtetra
.905 .724 .646 r
.7278 .11879 .72876 .12092 .73038 .11527 .72951 .11422 Mtetra
.759 .834 .909 r
.72951 .11422 .73038 .11527 .73232 .11408 .73145 .11303 Mtetra
.621 .783 .959 r
.73145 .11303 .73232 .11408 .73432 .11364 .73343 .11246 Mtetra
.551 .724 .954 r
.73343 .11246 .73432 .11364 .73633 .11354 .73544 .11216 Mtetra
.695 .748 .892 r
.73544 .11216 .73633 .11354 .73831 .11284 .7374 .11127 Mtetra
.68 .71 .871 r
.7374 .11127 .73831 .11284 .74029 .11209 .73937 .11042 Mtetra
.657 .685 .865 r
.73937 .11042 .74029 .11209 .74226 .11128 .74135 .1097 Mtetra
.655 .697 .877 r
.74135 .1097 .74226 .11128 .7442 .11 .74333 .10899 Mtetra
.522 .746 .977 r
.74333 .10899 .7442 .11 .74616 .10906 .74535 .10873 Mtetra
0 .405 .719 r
.74535 .10873 .74616 .10906 .74818 .10875 .74744 .10938 Mtetra
.91 .506 .195 r
.74744 .10938 .74818 .10875 .75043 .11158 .75013 .11789 Mtetra
.97 .651 .315 r
.75013 .11789 .75043 .11158 .76851 .31829 .76838 .32747 Mtetra
.626 .313 .42 r
.76838 .32747 .76851 .31829 .77156 .32928 .77086 .33108 Mtetra
.292 .703 .973 r
.08973 .55367 .09103 .55431 .09262 .55442 .09133 .55372 Mtetra
.635 .825 .974 r
.09133 .55372 .09262 .55442 .09429 .55382 .093 .55317 Mtetra
.77 .848 .909 r
.093 .55317 .09429 .55382 .09603 .55276 .09475 .55204 Mtetra
.856 .814 .808 r
.09475 .55204 .09603 .55276 .09771 .55214 .09662 .54997 Mtetra
.824 .671 .694 r
.09662 .54997 .09771 .55214 .09945 .5511 .09865 .54657 Mtetra
.831 .618 .615 r
.09865 .54657 .09945 .5511 .10129 .54922 .10127 .53849 Mtetra
.926 .674 .537 r
.10127 .53849 .10129 .54922 .10388 .5414 .12783 .33976 Mtetra
.529 .299 .51 r
.12783 .33976 .10388 .5414 .13073 .33887 .12992 .33512 Mtetra
.726 .56 .665 r
.12992 .33512 .13073 .33887 .13283 .33415 .13173 .33268 Mtetra
.696 .686 .836 r
.13173 .33268 .13283 .33415 .13448 .33298 .13334 .33186 Mtetra
.598 .715 .926 r
.13334 .33186 .13448 .33298 .13605 .33253 .1349 .33152 Mtetra
.504 .704 .96 r
.1349 .33152 .13605 .33253 .13757 .33243 .13642 .3314 Mtetra
.638 .745 .926 r
.13642 .3314 .13757 .33243 .13915 .33194 .13799 .33091 Mtetra
.663 .753 .917 r
.13799 .33091 .13915 .33194 .14073 .33139 .13958 .33033 Mtetra
.679 .749 .904 r
.13958 .33033 .14073 .33139 .14231 .33081 .14117 .32968 Mtetra
.74 .748 .859 r
.14117 .32968 .14231 .33081 .14392 .33006 .14281 .32867 Mtetra
.708 .701 .842 r
.14281 .32867 .14392 .33006 .14552 .32933 .14444 .32779 Mtetra
.643 .66 .851 r
.14444 .32779 .14552 .32933 .14712 .3287 .14602 .32726 Mtetra
.195 .454 .877 r
.14602 .32726 .14712 .3287 .14871 .32809 .14747 .32787 Mtetra
.79 .307 .07 r
.14747 .32787 .14871 .32809 .15026 .32785 .14877 .32971 Mtetra
.842 .517 .438 r
.14877 .32971 .15026 .32785 .15173 .32833 .14959 .33558 Mtetra
.93 .671 .524 r
.14959 .33558 .15173 .32833 .15264 .33354 .12763 .53408 Mtetra
.526 .291 .502 r
.12763 .53408 .15264 .33354 .13039 .53593 .12876 .53828 Mtetra
.661 .288 .327 r
.12876 .53828 .13039 .53593 .1315 .54036 .1302 .53991 Mtetra
.371 .78 .982 r
.1302 .53991 .1315 .54036 .13309 .5407 .13185 .53975 Mtetra
.695 .789 .923 r
.13185 .53975 .13309 .5407 .1348 .54006 .13357 .53899 Mtetra
.734 .773 .884 r
.13357 .53899 .1348 .54006 .13656 .53902 .13533 .538 Mtetra
.439 .69 .971 r
.13533 .538 .13656 .53902 .13821 .53888 .13696 .53799 Mtetra
.496 .742 .982 r
.13696 .53799 .13821 .53888 .13988 .53858 .13862 .53782 Mtetra
.726 .83 .929 r
.13862 .53782 .13988 .53858 .14164 .53755 .14036 .53692 Mtetra
.923 .773 .678 r
.14036 .53692 .14164 .53755 .14385 .53253 .14256 .53199 Mtetra
.942 .688 .524 r
.14256 .53199 .14385 .53253 .1687 .3272 .16757 .32605 Mtetra
.916 .724 .629 r
.16757 .32605 .1687 .3272 .17102 .32028 .16992 .31895 Mtetra
.787 .727 .796 r
.16992 .31895 .17102 .32028 .17274 .31866 .17163 .31738 Mtetra
.616 .691 .897 r
.17163 .31738 .17274 .31866 .17434 .31817 .17322 .31697 Mtetra
.449 .642 .939 r
.17322 .31697 .17434 .31817 .17589 .31811 .17475 .31702 Mtetra
.603 .727 .932 r
.17475 .31702 .17589 .31811 .17747 .3177 .17634 .31665 Mtetra
.658 .75 .918 r
.17634 .31665 .17747 .3177 .17908 .31715 .17794 .31608 Mtetra
.673 .749 .908 r
.17794 .31608 .17908 .31715 .18069 .31657 .17956 .31545 Mtetra
.761 .755 .848 r
.17956 .31545 .18069 .31657 .18235 .31552 .18123 .31428 Mtetra
.731 .731 .851 r
.18123 .31428 .18235 .31552 .18399 .31464 .18289 .31328 Mtetra
.601 .674 .892 r
.18289 .31328 .18399 .31464 .18557 .31438 .18448 .31293 Mtetra
.85 .42 0 r
.18448 .31293 .18557 .31438 .1868 .31735 .18571 .31585 Mtetra
.945 .685 .511 r
.18571 .31585 .1868 .31735 .16652 .52103 .16529 .52012 Mtetra
.94 .606 .368 r
.16529 .52012 .16652 .52103 .16739 .52833 .16614 .5276 Mtetra
.4 0 0 r
.16614 .5276 .16739 .52833 .16896 .52926 .1677 .52858 Mtetra
.633 .836 .978 r
.1677 .52858 .16896 .52926 .17068 .52872 .16942 .528 Mtetra
.8 .842 .883 r
.16942 .528 .17068 .52872 .17246 .52761 .17123 .52664 Mtetra
.837 .792 .808 r
.17123 .52664 .17246 .52761 .1742 .52686 .1731 .52467 Mtetra
.813 .671 .706 r
.1731 .52467 .1742 .52686 .17595 .52602 .17508 .52168 Mtetra
.808 .606 .628 r
.17508 .52168 .17595 .52602 .17778 .52451 .17736 .51585 Mtetra
.936 .679 .522 r
.17736 .51585 .17778 .52451 .17996 .51949 .19973 .31595 Mtetra
.533 .302 .511 r
.19973 .31595 .17996 .51949 .20261 .31524 .20193 .30982 Mtetra
.701 .513 .631 r
.20193 .30982 .20261 .31524 .20486 .30853 .20379 .30694 Mtetra
.751 .692 .795 r
.20379 .30694 .20486 .30853 .20663 .30659 .20549 .30561 Mtetra
.679 .77 .92 r
.20549 .30561 .20663 .30659 .20826 .3059 .20713 .30495 Mtetra
.619 .762 .948 r
.20713 .30495 .20826 .3059 .20986 .30559 .20874 .3045 Mtetra
.746 .764 .868 r
.20874 .3045 .20986 .30559 .21152 .30469 .21041 .30347 Mtetra
.742 .74 .849 r
.21041 .30347 .21152 .30469 .21319 .30372 .21209 .3024 Mtetra
.636 .694 .887 r
.21209 .3024 .21319 .30372 .2148 .30333 .21371 .3019 Mtetra
.621 .166 0 r
.21371 .3019 .2148 .30333 .21616 .30549 .21509 .30387 Mtetra
.948 .685 .503 r
.21509 .30387 .21616 .30549 .19814 .50505 .19747 .49858 Mtetra
.982 .714 .327 r
.19747 .49858 .19814 .50505 .19864 .51706 .19745 .5158 Mtetra
.615 .124 0 r
.19745 .5158 .19864 .51706 .20016 .51881 .19896 .51766 Mtetra
.538 .708 .95 r
.19896 .51766 .20016 .51881 .20186 .5186 .20067 .51745 Mtetra
.78 .771 .844 r
.20067 .51745 .20186 .5186 .20368 .51725 .20249 .51606 Mtetra
.905 .744 .671 r
.20249 .51606 .20368 .51725 .20579 .51285 .20466 .51111 Mtetra
.947 .688 .512 r
.20466 .51111 .20579 .51285 .22705 .30721 .22613 .30405 Mtetra
.855 .648 .623 r
.22613 .30405 .22705 .30721 .22941 .29906 .22835 .29743 Mtetra
.733 .683 .802 r
.22835 .29743 .22941 .29906 .23118 .29709 .23005 .29624 Mtetra
.472 0 0 r
.23005 .29624 .23118 .29709 .23279 .29682 .23152 .29743 Mtetra
.84 .451 .311 r
.23152 .29743 .23279 .29682 .23435 .29713 .23279 .30087 Mtetra
.717 .386 .416 r
.23279 .30087 .23435 .29713 .23597 .29676 .23407 .30417 Mtetra
.443 .158 .383 r
.23407 .30417 .23597 .29676 .23764 .29591 .23574 .30335 Mtetra
.472 .184 .394 r
.23574 .30335 .23764 .29591 .23926 .29557 .23738 .30291 Mtetra
.939 .672 .504 r
.23738 .30291 .23926 .29557 .24065 .29785 .22132 .49586 Mtetra
.536 .3 .504 r
.22132 .49586 .24065 .29785 .22395 .49986 .22218 .50511 Mtetra
.665 .346 .423 r
.22218 .50511 .22395 .49986 .22488 .5084 .22362 .50799 Mtetra
.466 0 0 r
.22362 .50799 .22488 .5084 .22645 .50994 .22525 .50892 Mtetra
.482 .712 .971 r
.22525 .50892 .22645 .50994 .22818 .50969 .22697 .50881 Mtetra
.675 .807 .946 r
.22697 .50881 .22818 .50969 .22996 .50886 .22874 .50811 Mtetra
.819 .84 .864 r
.22874 .50811 .22996 .50886 .23175 .50806 .23059 .50655 Mtetra
.845 .731 .738 r
.23059 .50655 .23175 .50806 .23353 .50723 .23255 .50377 Mtetra
.826 .632 .64 r
.23255 .50377 .23353 .50723 .23538 .50574 .23473 .49849 Mtetra
.944 .682 .509 r
.23473 .49849 .23538 .50574 .23746 .50151 .25394 .297 Mtetra
.535 .304 .511 r
.25394 .297 .23746 .50151 .25677 .29681 .25618 .28969 Mtetra
.677 .478 .609 r
.25618 .28969 .25677 .29681 .25907 .28878 .25806 .28659 Mtetra
.732 .634 .749 r
.25806 .28659 .25907 .28878 .26088 .2864 .25979 .28511 Mtetra
.646 .708 .892 r
.25979 .28511 .26088 .2864 .26255 .28568 .26145 .28457 Mtetra
.552 .708 .944 r
.26145 .28457 .26255 .28568 .26418 .28542 .26308 .28434 Mtetra
.582 .725 .941 r
.26308 .28434 .26418 .28542 .26582 .2851 .26472 .28401 Mtetra
.654 .747 .918 r
.26472 .28401 .26582 .2851 .26748 .28454 .26638 .28344 Mtetra
.668 .749 .911 r
.26638 .28344 .26748 .28454 .26914 .28395 .26805 .2828 Mtetra
.711 .752 .884 r
.26805 .2828 .26914 .28395 .27081 .28327 .26973 .28195 Mtetra
.721 .725 .853 r
.26973 .28195 .27081 .28327 .27249 .28253 .27143 .28099 Mtetra
.669 .677 .848 r
.27143 .28099 .27249 .28253 .27417 .28186 .2731 .2803 Mtetra
.434 .567 .889 r
.2731 .2803 .27417 .28186 .27582 .28145 .27471 .28049 Mtetra
.622 .103 0 r
.27471 .28049 .27582 .28145 .27745 .28134 .2762 .28216 Mtetra
.839 .454 .321 r
.2762 .28216 .27745 .28134 .27908 .2813 .27753 .28588 Mtetra
.766 .448 .447 r
.27753 .28588 .27908 .2813 .28074 .28077 .27871 .29154 Mtetra
.417 .155 .406 r
.27871 .29154 .28074 .28077 .28245 .27977 .28049 .2897 Mtetra
.436 .168 .407 r
.28049 .2897 .28245 .27977 .28411 .27926 .28222 .28836 Mtetra
.941 .67 .495 r
.28222 .28836 .28411 .27926 .28561 .28094 .26896 .4806 Mtetra
.536 .299 .504 r
.26896 .4806 .28561 .28094 .27184 .48216 .27 .48968 Mtetra
.635 .332 .441 r
.27 .48968 .27184 .48216 .2728 .49239 .27152 .4926 Mtetra
.55 0 0 r
.27152 .4926 .2728 .49239 .2744 .49429 .2732 .49348 Mtetra
.576 .798 .984 r
.2732 .49348 .2744 .49429 .27617 .49398 .27499 .49307 Mtetra
.686 .807 .94 r
.27499 .49307 .27617 .49398 .27799 .49313 .27679 .49231 Mtetra
.661 .82 .96 r
.27679 .49231 .27799 .49313 .2798 .49228 .2786 .49164 Mtetra
.548 .825 .997 r
.2786 .49164 .2798 .49228 .2816 .49174 .28038 .49123 Mtetra
.633 .88 .987 r
.28038 .49123 .2816 .49174 .2834 .49111 .28219 .49057 Mtetra
.819 .887 .893 r
.28219 .49057 .2834 .49111 .28522 .49026 .28405 .48908 Mtetra
.878 .77 .739 r
.28405 .48908 .28522 .49026 .28706 .48909 .28603 .48605 Mtetra
.837 .649 .649 r
.28603 .48605 .28706 .48909 .28891 .48784 .28814 .4811 Mtetra
.776 .557 .602 r
.28814 .4811 .28891 .48784 .29072 .48704 .29038 .47431 Mtetra
.517 .329 .565 r
.29038 .47431 .29072 .48704 .2925 .48689 .29212 .47454 Mtetra
.515 .329 .567 r
.29212 .47454 .2925 .48689 .29431 .48624 .29386 .47481 Mtetra
.944 .676 .499 r
.29386 .47481 .29431 .48624 .29626 .48357 .30867 .2872 Mtetra
.556 .321 .514 r
.30867 .2872 .29626 .48357 .31139 .28868 .31145 .27092 Mtetra
.612 .39 .556 r
.31145 .27092 .31139 .28868 .31437 .26935 .31338 .26687 Mtetra
.757 .628 .718 r
.31338 .26687 .31437 .26935 .31624 .26618 .31517 .26485 Mtetra
.661 .709 .883 r
.31517 .26485 .31624 .26618 .31795 .26532 .31687 .26422 Mtetra
.563 .717 .945 r
.31687 .26422 .31795 .26532 .31963 .26499 .31855 .26394 Mtetra
.55 .724 .955 r
.31855 .26394 .31963 .26499 .3213 .26476 .32022 .26369 Mtetra
.649 .756 .928 r
.32022 .26369 .3213 .26476 .323 .26419 .32192 .26313 Mtetra
.665 .76 .921 r
.32192 .26313 .323 .26419 .3247 .26361 .32362 .2625 Mtetra
.684 .756 .906 r
.32362 .2625 .3247 .26361 .3264 .26298 .32533 .26178 Mtetra
.701 .743 .884 r
.32533 .26178 .3264 .26298 .32811 .2623 .32705 .26096 Mtetra
.697 .72 .867 r
.32705 .26096 .32811 .2623 .32982 .2616 .32876 .26013 Mtetra
.696 .701 .85 r
.32876 .26013 .32982 .2616 .33153 .26088 .33048 .25928 Mtetra
.695 .683 .834 r
.33048 .25928 .33153 .26088 .33324 .26013 .33221 .2584 Mtetra
.649 .647 .835 r
.33221 .2584 .33324 .26013 .33495 .25947 .33391 .25777 Mtetra
.526 .596 .867 r
.33391 .25777 .33495 .25947 .33666 .25889 .33559 .25771 Mtetra
0 .23 .73 r
.33559 .25771 .33666 .25889 .33836 .2584 .33719 .25886 Mtetra
.829 .406 .234 r
.33719 .25886 .33836 .2584 .34003 .25842 .33868 .26191 Mtetra
.954 .678 .475 r
.33868 .26191 .34003 .25842 .34161 .26001 .32844 .46115 Mtetra
.536 .299 .503 r
.32844 .46115 .34161 .26001 .33151 .45992 .32968 .47041 Mtetra
.6 .312 .452 r
.32968 .47041 .33151 .45992 .33257 .47243 .33132 .47307 Mtetra
.606 .094 .006 r
.33132 .47307 .33257 .47243 .33423 .47486 .33305 .47413 Mtetra
.351 .719 .986 r
.33305 .47413 .33423 .47486 .33603 .47478 .33485 .47413 Mtetra
.612 .849 .988 r
.33485 .47413 .33603 .47478 .33787 .47406 .33669 .47355 Mtetra
.793 .905 .919 r
.33669 .47355 .33787 .47406 .33974 .47297 .33857 .47223 Mtetra
.899 .833 .772 r
.33857 .47223 .33974 .47297 .34161 .47179 .34053 .46948 Mtetra
.857 .687 .67 r
.34053 .46948 .34161 .47179 .34349 .47046 .34257 .46515 Mtetra
.811 .593 .607 r
.34257 .46515 .34349 .47046 .34536 .46935 .34476 .45822 Mtetra
.558 .367 .578 r
.34476 .45822 .34536 .46935 .34718 .46913 .34661 .45738 Mtetra
.525 .339 .572 r
.34661 .45738 .34718 .46913 .34902 .46853 .34841 .45742 Mtetra
.684 .463 .581 r
.34841 .45742 .34902 .46853 .35094 .46657 .3505 .45211 Mtetra
.947 .673 .487 r
.3505 .45211 .35094 .46657 .35331 .45587 .3628 .25297 Mtetra
.529 .298 .509 r
.3628 .25297 .35331 .45587 .36571 .25138 .36474 .24832 Mtetra
.755 .602 .687 r
.36474 .24832 .36571 .25138 .36761 .24736 .36657 .24588 Mtetra
.679 .696 .859 r
.36657 .24588 .36761 .24736 .36936 .24633 .3683 .24512 Mtetra
.6 .714 .924 r
.3683 .24512 .36936 .24633 .37108 .24587 .37002 .24473 Mtetra
.576 .718 .939 r
.37002 .24473 .37108 .24587 .37279 .24562 .37174 .24442 Mtetra
.694 .747 .892 r
.37174 .24442 .37279 .24562 .37453 .24494 .37348 .24363 Mtetra
.698 .729 .875 r
.37348 .24363 .37453 .24494 .37627 .24424 .37522 .2428 Mtetra
.693 .706 .858 r
.37522 .2428 .37627 .24424 .378 .24354 .37697 .24196 Mtetra
.696 .688 .838 r
.37697 .24196 .378 .24354 .37974 .24281 .37872 .24107 Mtetra
.655 .651 .834 r
.37872 .24107 .37974 .24281 .38148 .24215 .38046 .24041 Mtetra
.563 .609 .857 r
.38046 .24041 .38148 .24215 .38322 .24162 .38218 .2402 Mtetra
0 .246 .758 r
.38218 .2402 .38322 .24162 .38494 .24145 .38383 .24144 Mtetra
.823 .359 .113 r
.38383 .24144 .38494 .24145 .38665 .24137 .38542 .24413 Mtetra
.833 .49 .406 r
.38542 .24413 .38665 .24137 .38837 .2412 .38684 .25068 Mtetra
.473 .197 .415 r
.38684 .25068 .38837 .2412 .39014 .24012 .38859 .25004 Mtetra
.417 .152 .402 r
.38859 .25004 .39014 .24012 .39189 .23939 .39039 .24828 Mtetra
.608 .314 .444 r
.39039 .24828 .39189 .23939 .39359 .23963 .39201 .25086 Mtetra
.949 .667 .468 r
.39201 .25086 .39359 .23963 .39498 .24751 .38525 .44965 Mtetra
.525 .29 .501 r
.38525 .44965 .39498 .24751 .38814 .4526 .38692 .45368 Mtetra
.688 .231 .162 r
.38692 .45368 .38814 .4526 .38984 .45617 .3887 .45536 Mtetra
.503 .778 .994 r
.3887 .45536 .38984 .45617 .39169 .45613 .39056 .4551 Mtetra
.659 .788 .943 r
.39056 .4551 .39169 .45613 .39357 .45541 .39244 .45442 Mtetra
.696 .805 .932 r
.39244 .45442 .39357 .45541 .39546 .4544 .39432 .45358 Mtetra
.575 .805 .987 r
.39432 .45358 .39546 .4544 .39734 .45385 .39619 .45314 Mtetra
.557 .823 .995 r
.39619 .45314 .39734 .45385 .39921 .45329 .39807 .45271 Mtetra
.547 .844 .998 r
.39807 .45271 .39921 .45329 .40109 .45272 .39994 .45224 Mtetra
.568 .873 .994 r
.39994 .45224 .40109 .45272 .40297 .45211 .40182 .45168 Mtetra
.581 .886 .991 r
.40182 .45168 .40297 .45211 .40485 .45148 .40371 .45106 Mtetra
.6 .896 .988 r
.40371 .45106 .40485 .45148 .40674 .45082 .40559 .45038 Mtetra
.643 .906 .982 r
.40559 .45038 .40674 .45082 .40863 .45013 .40748 .4496 Mtetra
.664 .895 .98 r
.40748 .4496 .40863 .45013 .41051 .44943 .40938 .4488 Mtetra
.671 .876 .975 r
.40938 .4488 .41051 .44943 .41241 .44873 .41127 .448 Mtetra
.553 .817 .995 r
.41127 .448 .41241 .44873 .41429 .44817 .41316 .44758 Mtetra
.588 .86 .994 r
.41316 .44758 .41429 .44817 .41618 .44757 .41505 .44701 Mtetra
.701 .898 .967 r
.41505 .44701 .41618 .44757 .41808 .44686 .41695 .44609 Mtetra
.895 .846 .788 r
.41695 .44609 .41808 .44686 .41998 .44574 .41891 .44352 Mtetra
.859 .696 .68 r
.41891 .44352 .41998 .44574 .4219 .44448 .42091 .43953 Mtetra
.835 .611 .6 r
.42091 .43953 .4219 .44448 .42381 .44322 .42302 .43189 Mtetra
.582 .384 .579 r
.42302 .43189 .42381 .44322 .4257 .44304 .42494 .43033 Mtetra
.51 .325 .566 r
.42494 .43033 .4257 .44304 .42759 .44259 .4268 .43077 Mtetra
.58 .381 .576 r
.4268 .43077 .42759 .44259 .4295 .44133 .42872 .42919 Mtetra
.956 .676 .464 r
.42872 .42919 .4295 .44133 .4316 .43397 .43645 .22729 Mtetra
.53 .299 .509 r
.43645 .22729 .4316 .43397 .43933 .22559 .43837 .22178 Mtetra
.751 .576 .658 r
.43837 .22178 .43933 .22559 .44123 .22042 .44021 .21882 Mtetra
.726 .7 .826 r
.44021 .21882 .44123 .22042 .44303 .21904 .442 .2177 Mtetra
.652 .714 .893 r
.442 .2177 .44303 .21904 .4448 .21844 .44378 .21709 Mtetra
.592 .688 .908 r
.44378 .21709 .4448 .21844 .44657 .2182 .44555 .21673 Mtetra
.616 .677 .885 r
.44555 .21673 .44657 .2182 .44835 .21767 .44733 .21627 Mtetra
.618 .69 .895 r
.44733 .21627 .44835 .21767 .45013 .21711 .44911 .21581 Mtetra
.63 .713 .906 r
.44911 .21581 .45013 .21711 .45191 .21653 .45089 .21529 Mtetra
.685 .745 .897 r
.45089 .21529 .45191 .21653 .4537 .21585 .45268 .21453 Mtetra
.698 .734 .878 r
.45268 .21453 .4537 .21585 .45549 .21514 .45447 .21368 Mtetra
.694 .711 .861 r
.45447 .21368 .45549 .21514 .45727 .21441 .45626 .21283 Mtetra
.703 .696 .84 r
.45626 .21283 .45727 .21441 .45907 .21363 .45806 .21188 Mtetra
.67 .661 .832 r
.45806 .21188 .45907 .21363 .46086 .2129 .45985 .2111 Mtetra
.609 .627 .844 r
.45985 .2111 .46086 .2129 .46265 .21228 .46164 .21066 Mtetra
.3 .489 .876 r
.46164 .21066 .46265 .21228 .46444 .21165 .4634 .21124 Mtetra
.69 .149 0 r
.4634 .21124 .46444 .21165 .46622 .21137 .46515 .21309 Mtetra
.857 .488 .35 r
.46515 .21309 .46622 .21137 .468 .21182 .46682 .21909 Mtetra
.961 .671 .439 r
.46682 .21909 .468 .21182 .46969 .21706 .46484 .4229 Mtetra
.525 .29 .501 r
.46484 .4229 .46969 .21706 .46782 .42492 .46667 .4272 Mtetra
.649 .244 .264 r
.46667 .4272 .46782 .42492 .46966 .42944 .46856 .42887 Mtetra
.283 .72 .966 r
.46856 .42887 .46966 .42944 .47157 .42987 .47048 .42888 Mtetra
.64 .796 .957 r
.47048 .42888 .47157 .42987 .4735 .42924 .47241 .42825 Mtetra
.704 .815 .934 r
.47241 .42825 .4735 .42924 .47544 .4282 .47435 .42735 Mtetra
.588 .808 .984 r
.47435 .42735 .47544 .4282 .47737 .42754 .47628 .42686 Mtetra
.581 .843 .994 r
.47628 .42686 .47737 .42754 .47931 .42694 .47821 .42632 Mtetra
.686 .888 .972 r
.47821 .42632 .47931 .42694 .48125 .42624 .48015 .42545 Mtetra
.856 .867 .847 r
.48015 .42545 .48125 .42624 .48318 .42555 .48211 .42351 Mtetra
.849 .71 .709 r
.48211 .42351 .48318 .42555 .48513 .42453 .48408 .42026 Mtetra
.842 .625 .609 r
.48408 .42026 .48513 .42453 .48708 .42275 .48609 .41358 Mtetra
.964 .679 .443 r
.48609 .41358 .48708 .42275 .48908 .41673 .49037 .20774 Mtetra
.53 .299 .509 r
.49037 .20774 .48908 .41673 .4932 .20709 .49224 .202 Mtetra
.707 .521 .635 r
.49224 .202 .4932 .20709 .49507 .20109 .49407 .19918 Mtetra
.717 .664 .797 r
.49407 .19918 .49507 .20109 .4969 .19933 .49589 .19799 Mtetra
.623 .708 .906 r
.49589 .19799 .4969 .19933 .49871 .19869 .49771 .1975 Mtetra
.543 .7 .942 r
.49771 .1975 .49871 .19869 .50052 .19847 .49952 .19727 Mtetra
.617 .732 .928 r
.49952 .19727 .50052 .19847 .50234 .19799 .50134 .19679 Mtetra
.66 .747 .915 r
.50134 .19679 .50234 .19799 .50416 .19736 .50315 .19614 Mtetra
.675 .748 .906 r
.50315 .19614 .50416 .19736 .50598 .1967 .50497 .19541 Mtetra
.73 .754 .872 r
.50497 .19541 .50598 .1967 .5078 .19589 .5068 .19438 Mtetra
.715 .713 .847 r
.5068 .19438 .5078 .19589 .50962 .19506 .50862 .19336 Mtetra
.657 .665 .846 r
.50862 .19336 .50962 .19506 .51144 .19433 .51045 .19267 Mtetra
.419 .552 .883 r
.51045 .19267 .51144 .19433 .51327 .19363 .51227 .19295 Mtetra
.514 0 0 r
.51227 .19295 .51327 .19363 .51509 .19322 .51409 .19447 Mtetra
.84 .439 .285 r
.51409 .19447 .51509 .19322 .51692 .19348 .5159 .19897 Mtetra
.966 .672 .419 r
.5159 .19897 .51692 .19348 .51874 .19716 .51725 .40392 Mtetra
.527 .291 .501 r
.51725 .40392 .51874 .19716 .52027 .40577 .51919 .40928 Mtetra
.64 .272 .33 r
.51919 .40928 .52027 .40577 .52222 .41154 .52116 .41124 Mtetra
0 .477 .739 r
.52116 .41124 .52222 .41154 .52419 .4125 .52312 .41164 Mtetra
.57 .803 .987 r
.52312 .41164 .52419 .4125 .52616 .41202 .52509 .41119 Mtetra
.731 .86 .942 r
.52509 .41119 .52616 .41202 .52813 .41099 .52706 .41015 Mtetra
.849 .867 .854 r
.52706 .41015 .52813 .41099 .5301 .41012 .52903 .40828 Mtetra
.855 .73 .725 r
.52903 .40828 .5301 .41012 .53207 .40916 .531 .40522 Mtetra
.838 .63 .62 r
.531 .40522 .53207 .40916 .53404 .40752 .53296 .39942 Mtetra
.968 .679 .426 r
.53296 .39942 .53404 .40752 .536 .40259 .53429 .19319 Mtetra
.532 .301 .509 r
.53429 .19319 .536 .40259 .53712 .19284 .53611 .1864 Mtetra
.686 .488 .614 r
.53611 .1864 .53712 .19284 .53894 .18551 .53795 .18335 Mtetra
.722 .646 .772 r
.53795 .18335 .53894 .18551 .54078 .18337 .53979 .182 Mtetra
.615 .702 .906 r
.53979 .182 .54078 .18337 .54262 .18271 .54163 .18153 Mtetra
.507 .69 .95 r
.54163 .18153 .54262 .18271 .54447 .18254 .54348 .1814 Mtetra
.556 .723 .951 r
.54348 .1814 .54447 .18254 .54632 .18223 .54533 .18111 Mtetra
.623 .754 .94 r
.54533 .18111 .54632 .18223 .54817 .18171 .54718 .18059 Mtetra
.638 .759 .936 r
.54718 .18059 .54817 .18171 .55002 .18117 .54903 .18002 Mtetra
.655 .759 .926 r
.54903 .18002 .55002 .18117 .55187 .18055 .55089 .17937 Mtetra
.668 .76 .919 r
.55089 .17937 .55187 .18055 .55372 .17985 .55274 .17867 Mtetra
.676 .762 .915 r
.55274 .17867 .55372 .17985 .55557 .17912 .55459 .17793 Mtetra
.72 .775 .895 r
.55459 .17793 .55557 .17912 .55742 .17806 .55644 .17697 Mtetra
.727 .795 .906 r
.55644 .17697 .55742 .17806 .55927 .177 .5583 .17599 Mtetra
.651 .788 .948 r
.5583 .17599 .55927 .177 .56113 .17647 .56015 .17535 Mtetra
.156 .501 .909 r
.56015 .17535 .56113 .17647 .56302 .17815 .56203 .17598 Mtetra
0 0 .531 r
.56203 .17598 .56302 .17815 .56743 .36873 .56394 .1789 Mtetra
0 0 .321 r
.56394 .1789 .56743 .36873 .56976 .39354 .56846 .37287 Mtetra
.169 .06 .478 r
.56846 .37287 .56976 .39354 .5718 .39533 .57063 .38545 Mtetra
.551 .37 .589 r
.57063 .38545 .5718 .39533 .5738 .39479 .57263 .38489 Mtetra
.616 .416 .588 r
.57263 .38489 .5738 .39479 .5758 .39362 .5746 .38252 Mtetra
.61 .406 .58 r
.5746 .38252 .5758 .39362 .57779 .39254 .57657 .38004 Mtetra
.57 .371 .572 r
.57657 .38004 .57779 .39254 .5798 .39176 .57856 .37866 Mtetra
.567 .367 .569 r
.57856 .37866 .5798 .39176 .5818 .391 .58055 .37729 Mtetra
.562 .362 .566 r
.58055 .37729 .5818 .391 .58381 .39025 .58254 .37601 Mtetra
.557 .356 .564 r
.58254 .37601 .58381 .39025 .58582 .38954 .58453 .37489 Mtetra
.552 .352 .562 r
.58453 .37489 .58582 .38954 .58783 .38884 .58653 .37389 Mtetra
.549 .348 .561 r
.58653 .37389 .58783 .38884 .58984 .38815 .58853 .373 Mtetra
.546 .345 .56 r
.58853 .373 .58984 .38815 .59185 .38748 .59053 .37222 Mtetra
.543 .343 .56 r
.59053 .37222 .59185 .38748 .59387 .38682 .59254 .37152 Mtetra
.542 .342 .559 r
.59254 .37152 .59387 .38682 .59589 .38617 .59455 .37088 Mtetra
.541 .342 .559 r
.59455 .37088 .59589 .38617 .59791 .38551 .59656 .37026 Mtetra
.54 .341 .56 r
.59656 .37026 .59791 .38551 .59993 .38486 .59857 .36968 Mtetra
.59857 .36968 .59993 .38486 .60195 .38421 .60059 .3691 Mtetra
.54 .342 .56 r
.60059 .3691 .60195 .38421 .60397 .38356 .60261 .36853 Mtetra
.60261 .36853 .60397 .38356 .60599 .3829 .60462 .36796 Mtetra
.54 .342 .561 r
.60462 .36796 .60599 .3829 .60802 .38225 .60664 .36738 Mtetra
.60664 .36738 .60802 .38225 .61005 .38159 .60867 .36681 Mtetra
.60867 .36681 .61005 .38159 .61208 .38094 .61069 .36625 Mtetra
.54 .343 .562 r
.61069 .36625 .61208 .38094 .61411 .38028 .61272 .3657 Mtetra
.61272 .3657 .61411 .38028 .61614 .37963 .61474 .36517 Mtetra
.538 .342 .563 r
.61474 .36517 .61614 .37963 .61817 .37898 .61677 .36469 Mtetra
.536 .341 .563 r
.61677 .36469 .61817 .37898 .62021 .37835 .61881 .36431 Mtetra
.534 .34 .564 r
.61881 .36431 .62021 .37835 .62225 .37773 .62085 .36401 Mtetra
.534 .341 .566 r
.62085 .36401 .62225 .37773 .62428 .3771 .62289 .36371 Mtetra
.496 .315 .565 r
.62289 .36371 .62428 .3771 .62633 .37674 .62497 .36461 Mtetra
.48 .308 .57 r
.62497 .36461 .62633 .37674 .62839 .37656 .62707 .36587 Mtetra
.565 .375 .583 r
.62707 .36587 .62839 .37656 .63043 .37574 .6291 .36484 Mtetra
.97 .671 .397 r
.6291 .36484 .63043 .37574 .63239 .37266 .62459 .168 Mtetra
.545 .31 .51 r
.62459 .168 .63239 .37266 .6274 .16673 .62608 .15483 Mtetra
.645 .425 .569 r
.62608 .15483 .6274 .16673 .62886 .15322 .62787 .15072 Mtetra
.77 .647 .726 r
.62787 .15072 .62886 .15322 .63068 .15007 .62972 .14859 Mtetra
.686 .719 .875 r
.62972 .14859 .63068 .15007 .63257 .14914 .63162 .14775 Mtetra
.612 .703 .909 r
.63162 .14775 .63257 .14914 .63449 .14874 .63354 .14728 Mtetra
.583 .676 .904 r
.63354 .14728 .63449 .14874 .63641 .14846 .63546 .14693 Mtetra
.604 .674 .89 r
.63546 .14693 .63641 .14846 .63833 .14793 .63738 .14649 Mtetra
.6 .69 .905 r
.63738 .14649 .63833 .14793 .64024 .1474 .6393 .14607 Mtetra
.617 .717 .917 r
.6393 .14607 .64024 .1474 .64216 .14684 .64122 .14557 Mtetra
.652 .744 .917 r
.64122 .14557 .64216 .14684 .64408 .14621 .64314 .14492 Mtetra
.668 .745 .908 r
.64314 .14492 .64408 .14621 .64599 .14553 .64505 .14419 Mtetra
.676 .74 .898 r
.64505 .14419 .64599 .14553 .6479 .1448 .64696 .14342 Mtetra
.68 .734 .891 r
.64696 .14342 .6479 .1448 .64982 .14401 .64888 .14262 Mtetra
.688 .736 .887 r
.64888 .14262 .64982 .14401 .65173 .14318 .65079 .14178 Mtetra
.729 .749 .868 r
.65079 .14178 .65173 .14318 .65364 .14215 .65269 .14069 Mtetra
.771 .754 .838 r
.65269 .14069 .65364 .14215 .65553 .14084 .65458 .13928 Mtetra
.691 .71 .862 r
.65458 .13928 .65553 .14084 .65745 .14003 .6565 .13838 Mtetra
.342 .514 .882 r
.6565 .13838 .65745 .14003 .65943 .14062 .65848 .13891 Mtetra
.845 .461 0 r
.65848 .13891 .65943 .14062 .6617 .14756 .66074 .14569 Mtetra
.975 .669 .339 r
.66074 .14569 .6617 .14756 .67354 .35878 .67256 .35781 Mtetra
.708 .229 0 r
.67256 .35781 .67354 .35878 .6758 .36213 .67482 .36119 Mtetra
.552 .789 .987 r
.67482 .36119 .6758 .36213 .6779 .36181 .67692 .36078 Mtetra
.745 .84 .922 r
.67692 .36078 .6779 .36181 .67996 .36077 .67897 .35961 Mtetra
.758 .819 .9 r
.67897 .35961 .67996 .36077 .68201 .35957 .68103 .35834 Mtetra
.584 .742 .951 r
.68103 .35834 .68201 .35957 .6841 .35899 .68312 .3579 Mtetra
.628 .791 .96 r
.68312 .3579 .6841 .35899 .68619 .35837 .68521 .35727 Mtetra
.746 .829 .915 r
.68521 .35727 .68619 .35837 .68828 .35771 .68727 .35609 Mtetra
.849 .769 .773 r
.68727 .35609 .68828 .35771 .69037 .35708 .68927 .35361 Mtetra
.819 .635 .653 r
.68927 .35361 .69037 .35708 .69243 .35593 .69117 .34951 Mtetra
.89 .624 .53 r
.69117 .34951 .69243 .35593 .69442 .35338 .69255 .33544 Mtetra
.967 .66 .384 r
.69255 .33544 .69442 .35338 .69594 .34217 .68387 .13459 Mtetra
.526 .296 .508 r
.68387 .13459 .69594 .34217 .68665 .13351 .68563 .13039 Mtetra
.748 .603 .696 r
.68563 .13039 .68665 .13351 .68841 .12945 .68749 .12812 Mtetra
.707 .757 .892 r
.68749 .12812 .68841 .12945 .69033 .12834 .68942 .12718 Mtetra
.63 .76 .941 r
.68942 .12718 .69033 .12834 .69228 .12782 .69137 .1266 Mtetra
.617 .744 .936 r
.69137 .1266 .69228 .12782 .69425 .12746 .69333 .12608 Mtetra
.715 .752 .881 r
.69333 .12608 .69425 .12746 .69619 .1266 .69526 .12508 Mtetra
.676 .712 .876 r
.69526 .12508 .69619 .1266 .69813 .12579 .69721 .12427 Mtetra
.581 .67 .9 r
.69721 .12427 .69813 .12579 .70008 .12504 .69918 .12392 Mtetra
.096 .46 .888 r
.69918 .12392 .70008 .12504 .70203 .12425 .70123 .12474 Mtetra
.73 .216 0 r
.70123 .12474 .70203 .12425 .70401 .12392 .70336 .12703 Mtetra
.898 .533 .338 r
.70336 .12703 .70401 .12392 .70605 .12469 .70612 .1393 Mtetra
.965 .648 .359 r
.70612 .1393 .70605 .12469 .70858 .13308 .72052 .33955 Mtetra
.523 .288 .5 r
.72052 .33955 .70858 .13308 .72371 .34195 .72288 .34288 Mtetra
.597 .078 0 r
.72288 .34288 .72371 .34195 .72608 .34536 .72512 .34419 Mtetra
.414 .67 .966 r
.72512 .34419 .72608 .34536 .72824 .34536 .72729 .34426 Mtetra
.607 .782 .964 r
.72729 .34426 .72824 .34536 .73036 .34463 .72941 .3437 Mtetra
.752 .867 .932 r
.72941 .3437 .73036 .34463 .73245 .34353 .7315 .34247 Mtetra
.887 .859 .808 r
.7315 .34247 .73245 .34353 .73457 .3428 .73351 .34006 Mtetra
.853 .683 .67 r
.73351 .34006 .73457 .3428 .73665 .34158 .73541 .33608 Mtetra
.882 .627 .548 r
.73541 .33608 .73665 .34158 .73867 .33925 .73686 .3254 Mtetra
.971 .661 .357 r
.73686 .3254 .73867 .33925 .74018 .32965 .72504 .11986 Mtetra
.527 .296 .508 r
.72504 .11986 .74018 .32965 .7278 .11879 .72675 .11534 Mtetra
.746 .589 .681 r
.72675 .11534 .7278 .11879 .72951 .11422 .72861 .11286 Mtetra
.714 .759 .888 r
.72861 .11286 .72951 .11422 .73145 .11303 .73056 .11187 Mtetra
.638 .766 .941 r
.73056 .11187 .73145 .11303 .73343 .11246 .73254 .11125 Mtetra
.609 .743 .94 r
.73254 .11125 .73343 .11246 .73544 .11216 .73453 .11075 Mtetra
.74 .759 .869 r
.73453 .11075 .73544 .11216 .7374 .11127 .73648 .10958 Mtetra
.697 .7 .849 r
.73648 .10958 .7374 .11127 .73937 .11042 .73844 .1086 Mtetra
.624 .648 .854 r
.73844 .1086 .73937 .11042 .74135 .1097 .74043 .10804 Mtetra
.279 .475 .872 r
.74043 .10804 .74135 .1097 .74333 .10899 .74252 .10879 Mtetra
.668 .122 0 r
.74252 .10879 .74333 .10899 .74535 .10873 .74473 .11104 Mtetra
.903 .523 .295 r
.74473 .11104 .74535 .10873 .74744 .10938 .7476 .12192 Mtetra
.967 .645 .334 r
.7476 .12192 .74744 .10938 .75013 .11789 .76518 .32539 Mtetra
.523 .288 .5 r
.76518 .32539 .75013 .11789 .76838 .32747 .76764 .32882 Mtetra
.603 .115 .067 r
.76764 .32882 .76838 .32747 .77086 .33108 .76995 .33018 Mtetra
.468 .656 .942 r
.08851 .55244 .08973 .55367 .09133 .55372 .09012 .55244 Mtetra
.63 .708 .903 r
.09012 .55244 .09133 .55372 .093 .55317 .09178 .55196 Mtetra
.751 .748 .849 r
.09178 .55196 .093 .55317 .09475 .55204 .09353 .55079 Mtetra
.879 .735 .698 r
.09353 .55079 .09475 .55204 .09662 .54997 .09564 .54681 Mtetra
.903 .673 .58 r
.09564 .54681 .09662 .54997 .09865 .54657 .09956 .52857 Mtetra
.917 .664 .54 r
.09956 .52857 .09865 .54657 .10127 .53849 .12542 .33668 Mtetra
.524 .294 .508 r
.12542 .33668 .10127 .53849 .12783 .33976 .12725 .33413 Mtetra
.631 .46 .632 r
.12725 .33413 .12783 .33976 .12992 .33512 .12894 .33269 Mtetra
.668 .582 .749 r
.12894 .33269 .12992 .33512 .13173 .33268 .13056 .33177 Mtetra
.671 .777 .929 r
.13056 .33177 .13173 .33268 .13334 .33186 .13215 .33116 Mtetra
.602 .808 .979 r
.13215 .33116 .13334 .33186 .1349 .33152 .13371 .33074 Mtetra
.578 .782 .976 r
.13371 .33074 .1349 .33152 .13642 .3314 .13527 .33039 Mtetra
.657 .753 .921 r
.13527 .33039 .13642 .3314 .13799 .33091 .13685 .32983 Mtetra
.672 .743 .904 r
.13685 .32983 .13799 .33091 .13958 .33033 .13844 .32921 Mtetra
.68 .737 .894 r
.13844 .32921 .13958 .33033 .14117 .32968 .14004 .32854 Mtetra
.751 .748 .85 r
.14004 .32854 .14117 .32968 .14281 .32867 .14169 .32745 Mtetra
.711 .728 .863 r
.14169 .32745 .14281 .32867 .14444 .32779 .14331 .32659 Mtetra
.589 .696 .917 r
.14331 .32659 .14444 .32779 .14602 .32726 .14486 .32628 Mtetra
.813 .335 0 r
.14486 .32628 .14602 .32726 .14747 .32787 .14612 .32846 Mtetra
.915 .617 .467 r
.14612 .32846 .14747 .32787 .14877 .32971 .1462 .34051 Mtetra
.925 .666 .526 r
.1462 .34051 .14877 .32971 .14959 .33558 .12435 .53659 Mtetra
.521 .287 .5 r
.12435 .53659 .14959 .33558 .12763 .53408 .12575 .5385 Mtetra
.529 .198 .351 r
.12575 .5385 .12763 .53408 .12876 .53828 .12733 .53895 Mtetra
.192 0 0 r
.12733 .53895 .12876 .53828 .1302 .53991 .12898 .53882 Mtetra
.623 .744 .933 r
.12898 .53882 .1302 .53991 .13185 .53975 .13066 .53835 Mtetra
.667 .702 .873 r
.13066 .53835 .13185 .53975 .13357 .53899 .13238 .53768 Mtetra
.684 .721 .878 r
.13238 .53768 .13357 .53899 .13533 .538 .1341 .53693 Mtetra
.443 .682 .966 r
.1341 .53693 .13533 .538 .13696 .53799 .13573 .53693 Mtetra
.535 .722 .959 r
.13573 .53693 .13696 .53799 .13862 .53782 .1374 .53671 Mtetra
.722 .765 .886 r
.1374 .53671 .13862 .53782 .14036 .53692 .13914 .53578 Mtetra
.9 .742 .677 r
.13914 .53578 .14036 .53692 .14256 .53199 .14133 .53098 Mtetra
.941 .688 .525 r
.14133 .53098 .14256 .53199 .16757 .32605 .16636 .3256 Mtetra
.938 .752 .624 r
.16636 .3256 .16757 .32605 .16992 .31895 .16875 .31816 Mtetra
.83 .811 .832 r
.16875 .31816 .16992 .31895 .17163 .31738 .17047 .31652 Mtetra
.629 .782 .955 r
.17047 .31652 .17163 .31738 .17322 .31697 .17207 .31604 Mtetra
.451 .701 .974 r
.17207 .31604 .17322 .31697 .17475 .31702 .17361 .316 Mtetra
.621 .744 .935 r
.17361 .316 .17475 .31702 .17634 .31665 .1752 .31556 Mtetra
.666 .744 .908 r
.1752 .31556 .17634 .31665 .17794 .31608 .17682 .31496 Mtetra
.675 .739 .899 r
.17682 .31496 .17794 .31608 .17956 .31545 .17843 .31431 Mtetra
.755 .753 .851 r
.17843 .31431 .17956 .31545 .18123 .31428 .1801 .31319 Mtetra
.731 .758 .874 r
.1801 .31319 .18123 .31428 .18289 .31328 .18175 .31224 Mtetra
.581 .729 .944 r
.18175 .31224 .18289 .31328 .18448 .31293 .18334 .31193 Mtetra
.872 .431 .069 r
.18334 .31193 .18448 .31293 .18571 .31585 .18458 .31477 Mtetra
.945 .684 .511 r
.18458 .31477 .18571 .31585 .16529 .52012 .16414 .51845 Mtetra
.957 .626 .343 r
.16414 .51845 .16529 .52012 .16614 .5276 .16496 .52625 Mtetra
0 .203 .714 r
.16496 .52625 .16614 .5276 .1677 .52858 .16649 .52743 Mtetra
.611 .731 .931 r
.16649 .52743 .1677 .52858 .16942 .528 .1682 .527 Mtetra
.789 .79 .853 r
.1682 .527 .16942 .528 .17123 .52664 .17001 .52559 Mtetra
.885 .765 .724 r
.17001 .52559 .17123 .52664 .1731 .52467 .17204 .5222 Mtetra
.898 .683 .603 r
.17204 .5222 .1731 .52467 .17508 .52168 .17476 .51216 Mtetra
.935 .677 .522 r
.17476 .51216 .17508 .52168 .17736 .51585 .19742 .31116 Mtetra
.526 .296 .509 r
.19742 .31116 .17736 .51585 .19973 .31595 .19933 .30787 Mtetra
.605 .416 .599 r
.19933 .30787 .19973 .31595 .20193 .30982 .20105 .30635 Mtetra
.641 .516 .695 r
.20105 .30635 .20193 .30982 .20379 .30694 .20272 .30537 Mtetra
.681 .673 .836 r
.20272 .30537 .20379 .30694 .20549 .30561 .20436 .30461 Mtetra
.673 .766 .921 r
.20436 .30461 .20549 .30561 .20713 .30495 .20599 .30398 Mtetra
.656 .767 .932 r
.20599 .30398 .20713 .30495 .20874 .3045 .20762 .30341 Mtetra
.747 .762 .865 r
.20762 .30341 .20874 .3045 .21041 .30347 .20929 .30236 Mtetra
.741 .759 .867 r
.20929 .30236 .21041 .30347 .21209 .3024 .21097 .30134 Mtetra
.626 .741 .93 r
.21097 .30134 .21209 .3024 .21371 .3019 .21258 .30088 Mtetra
.74 .244 0 r
.21258 .30088 .21371 .3019 .21509 .30387 .21396 .30287 Mtetra
.948 .684 .504 r
.21396 .30287 .21509 .30387 .19747 .49858 .19625 .49767 Mtetra
.948 .653 .446 r
.19625 .49767 .19747 .49858 .19745 .5158 .19626 .51463 Mtetra
.637 .135 0 r
.19626 .51463 .19745 .5158 .19896 .51766 .19776 .51647 Mtetra
.547 .703 .942 r
.19776 .51647 .19896 .51766 .20067 .51745 .19947 .51624 Mtetra
.779 .761 .837 r
.19947 .51624 .20067 .51745 .20249 .51606 .2013 .51483 Mtetra
.907 .74 .663 r
.2013 .51483 .20249 .51606 .20466 .51111 .2035 .50956 Mtetra
.947 .688 .512 r
.2035 .50956 .20466 .51111 .22613 .30405 .22508 .30226 Mtetra
.892 .702 .639 r
.22508 .30226 .22613 .30405 .22835 .29743 .22724 .29627 Mtetra
.617 .721 .92 r
.22724 .29627 .22835 .29743 .23005 .29624 .22886 .29585 Mtetra
.895 .494 .246 r
.22886 .29585 .23005 .29624 .23152 .29743 .23009 .29963 Mtetra
.945 .68 .502 r
.23009 .29963 .23152 .29743 .23279 .30087 .21251 .50381 Mtetra
.525 .29 .501 r
.21251 .50381 .23279 .30087 .23407 .30417 .21384 .50766 Mtetra
.516 .282 .499 r
.21384 .50766 .23407 .30417 .23574 .30335 .21557 .50735 Mtetra
.515 .281 .499 r
.21557 .50735 .23574 .30335 .23738 .30291 .21736 .50647 Mtetra
.516 .283 .499 r
.21736 .50647 .23738 .30291 .22132 .49586 .21906 .50648 Mtetra
.531 .252 .437 r
.21906 .50648 .22132 .49586 .22218 .50511 .2207 .50712 Mtetra
.514 .099 .191 r
.2207 .50712 .22218 .50511 .22362 .50799 .22237 .50755 Mtetra
.054 .588 .859 r
.22237 .50755 .22362 .50799 .22525 .50892 .22406 .50777 Mtetra
.509 .699 .955 r
.22406 .50777 .22525 .50892 .22697 .50881 .22578 .50764 Mtetra
.683 .752 .904 r
.22578 .50764 .22697 .50881 .22874 .50811 .22756 .50689 Mtetra
.853 .763 .763 r
.22756 .50689 .22874 .50811 .23059 .50655 .2295 .50437 Mtetra
.892 .693 .627 r
.2295 .50437 .23059 .50655 .23255 .50377 .23183 .49733 Mtetra
.945 .683 .508 r
.23183 .49733 .23255 .50377 .23473 .49849 .25151 .29253 Mtetra
.528 .298 .509 r
.25151 .29253 .23473 .49849 .25394 .297 .25352 .28799 Mtetra
.607 .412 .591 r
.25352 .28799 .25394 .297 .25618 .28969 .25528 .28619 Mtetra
.653 .524 .693 r
.25528 .28619 .25618 .28969 .25806 .28659 .25699 .28506 Mtetra
.68 .681 .844 r
.25699 .28506 .25806 .28659 .25979 .28511 .25866 .2843 Mtetra
.636 .802 .962 r
.25866 .2843 .25979 .28511 .26145 .28457 .26032 .28377 Mtetra
.591 .792 .976 r
.26032 .28377 .26145 .28457 .26308 .28434 .26196 .28336 Mtetra
.626 .764 .945 r
.26196 .28336 .26308 .28434 .26472 .28401 .26362 .28289 Mtetra
.663 .743 .91 r
.26362 .28289 .26472 .28401 .26638 .28344 .26528 .28227 Mtetra
.671 .738 .901 r
.26528 .28227 .26638 .28344 .26805 .2828 .26695 .28162 Mtetra
.719 .748 .874 r
.26695 .28162 .26805 .2828 .26973 .28195 .26864 .28071 Mtetra
.731 .741 .86 r
.26864 .28071 .26973 .28195 .27143 .28099 .27034 .27971 Mtetra
.652 .712 .892 r
.27034 .27971 .27143 .28099 .2731 .2803 .27201 .27914 Mtetra
0 .312 .791 r
.27201 .27914 .2731 .2803 .27471 .28049 .27356 .28007 Mtetra
.918 .546 .299 r
.27356 .28007 .27471 .28049 .2762 .28216 .27476 .28532 Mtetra
.949 .679 .492 r
.27476 .28532 .2762 .28216 .27753 .28588 .26007 .48939 Mtetra
.523 .289 .501 r
.26007 .48939 .27753 .28588 .27871 .29154 .26154 .49269 Mtetra
.516 .282 .499 r
.26154 .49269 .27871 .29154 .28049 .2897 .26331 .49231 Mtetra
.514 .281 .499 r
.26331 .49231 .28049 .2897 .28222 .28836 .26513 .49133 Mtetra
.516 .282 .499 r
.26513 .49133 .28222 .28836 .26896 .4806 .2669 .491 Mtetra
.53 .25 .434 r
.2669 .491 .26896 .4806 .27 .48968 .26859 .49163 Mtetra
.513 .092 .179 r
.26859 .49163 .27 .48968 .27152 .4926 .2703 .49207 Mtetra
.29 .726 .967 r
.2703 .49207 .27152 .4926 .2732 .49348 .27205 .49205 Mtetra
.624 .694 .895 r
.27205 .49205 .2732 .49348 .27499 .49307 .27384 .49156 Mtetra
.653 .692 .874 r
.27384 .49156 .27499 .49307 .27679 .49231 .27564 .49093 Mtetra
.619 .7 .902 r
.27564 .49093 .27679 .49231 .2786 .49164 .27743 .49046 Mtetra
.558 .714 .945 r
.27743 .49046 .2786 .49164 .28038 .49123 .2792 .49018 Mtetra
.673 .777 .928 r
.2792 .49018 .28038 .49123 .28219 .49057 .28101 .48947 Mtetra
.844 .788 .797 r
.28101 .48947 .28219 .49057 .28405 .48908 .28293 .48735 Mtetra
.905 .717 .638 r
.28293 .48735 .28405 .48908 .28603 .48605 .28514 .48111 Mtetra
.952 .685 .495 r
.28514 .48111 .28603 .48605 .28814 .4811 .30172 .27528 Mtetra
.529 .299 .509 r
.30172 .27528 .28814 .4811 .29038 .47431 .30373 .27024 Mtetra
.52 .291 .507 r
.30373 .27024 .29038 .47431 .29212 .47454 .30544 .26936 Mtetra
.518 .289 .507 r
.30544 .26936 .29212 .47454 .29386 .47481 .30711 .26911 Mtetra
.519 .29 .507 r
.30711 .26911 .29386 .47481 .30867 .2872 .30881 .26841 Mtetra
.562 .349 .549 r
.30881 .26841 .30867 .2872 .31145 .27092 .31058 .26669 Mtetra
.663 .509 .665 r
.31058 .26669 .31145 .27092 .31338 .26687 .31234 .26514 Mtetra
.719 .674 .805 r
.31234 .26514 .31338 .26687 .31517 .26485 .31407 .26403 Mtetra
.642 .808 .962 r
.31407 .26403 .31517 .26485 .31687 .26422 .31577 .26347 Mtetra
.587 .806 .983 r
.31577 .26347 .31687 .26422 .31855 .26394 .31745 .26304 Mtetra
.606 .778 .963 r
.31745 .26304 .31855 .26394 .32022 .26369 .31914 .2626 Mtetra
.659 .753 .919 r
.31914 .2626 .32022 .26369 .32192 .26313 .32084 .26199 Mtetra
.671 .748 .909 r
.32084 .26199 .32192 .26313 .32362 .2625 .32254 .26133 Mtetra
.683 .747 .9 r
.32254 .26133 .32362 .2625 .32533 .26178 .32425 .26061 Mtetra
.695 .751 .894 r
.32425 .26061 .32533 .26178 .32705 .26096 .32597 .25983 Mtetra
.696 .758 .899 r
.32597 .25983 .32705 .26096 .32876 .26013 .32768 .25905 Mtetra
.713 .771 .897 r
.32768 .25905 .32876 .26013 .33048 .25928 .3294 .25819 Mtetra
.735 .773 .884 r
.3294 .25819 .33048 .25928 .33221 .2584 .33113 .2572 Mtetra
.656 .733 .906 r
.33113 .2572 .33221 .2584 .33391 .25777 .33284 .2566 Mtetra
.238 .541 .925 r
.33284 .2566 .33391 .25777 .33559 .25771 .33448 .25705 Mtetra
.895 .475 .159 r
.33448 .25705 .33559 .25771 .33719 .25886 .33592 .26094 Mtetra
.956 .681 .474 r
.33592 .26094 .33719 .25886 .33868 .26191 .32515 .4659 Mtetra
.528 .293 .502 r
.32515 .4659 .33868 .26191 .32844 .46115 .32658 .47172 Mtetra
.543 .262 .438 r
.32658 .47172 .32844 .46115 .32968 .47041 .32832 .47272 Mtetra
.469 .064 .188 r
.32832 .47272 .32968 .47041 .33132 .47307 .33011 .47288 Mtetra
.212 .727 .88 r
.33011 .47288 .33132 .47307 .33305 .47413 .33192 .47274 Mtetra
.5 .653 .927 r
.33192 .47274 .33305 .47413 .33485 .47413 .33372 .47268 Mtetra
.641 .701 .889 r
.33372 .47268 .33485 .47413 .33669 .47355 .33556 .47209 Mtetra
.787 .741 .811 r
.33556 .47209 .33669 .47355 .33857 .47223 .33746 .47044 Mtetra
.892 .72 .661 r
.33746 .47044 .33857 .47223 .34053 .46948 .33954 .46545 Mtetra
.958 .687 .48 r
.33954 .46545 .34053 .46948 .34257 .46515 .3528 .26032 Mtetra
.537 .305 .51 r
.3528 .26032 .34257 .46515 .34476 .45822 .35497 .25169 Mtetra
.52 .291 .507 r
.35497 .25169 .34476 .45822 .34661 .45738 .35672 .25054 Mtetra
.518 .29 .507 r
.35672 .25054 .34661 .45738 .34841 .45742 .35844 .25015 Mtetra
.519 .29 .507 r
.35844 .25015 .34841 .45742 .3505 .45211 .36016 .24965 Mtetra
.522 .292 .508 r
.36016 .24965 .3505 .45211 .3628 .25297 .36195 .24785 Mtetra
.648 .481 .643 r
.36195 .24785 .3628 .25297 .36474 .24832 .36373 .24622 Mtetra
.718 .64 .769 r
.36373 .24622 .36474 .24832 .36657 .24588 .36549 .24494 Mtetra
.668 .79 .94 r
.36549 .24494 .36657 .24588 .3683 .24512 .36723 .24428 Mtetra
.623 .8 .967 r
.36723 .24428 .3683 .24512 .37002 .24473 .36895 .24376 Mtetra
.63 .773 .949 r
.36895 .24376 .37002 .24473 .37174 .24442 .37068 .24325 Mtetra
.69 .752 .898 r
.37068 .24325 .37174 .24442 .37348 .24363 .37242 .24248 Mtetra
.695 .758 .9 r
.37242 .24248 .37348 .24363 .37522 .2428 .37416 .24169 Mtetra
.703 .767 .902 r
.37416 .24169 .37522 .2428 .37697 .24196 .37591 .24087 Mtetra
.739 .779 .885 r
.37591 .24087 .37697 .24196 .37872 .24107 .37766 .23985 Mtetra
.671 .737 .9 r
.37766 .23985 .37872 .24107 .38046 .24041 .3794 .23917 Mtetra
.439 .638 .94 r
.3794 .23917 .38046 .24041 .38218 .2402 .38111 .23925 Mtetra
.844 .39 0 r
.38111 .23925 .38218 .2402 .38383 .24144 .38267 .24245 Mtetra
.961 .682 .458 r
.38267 .24245 .38383 .24144 .38542 .24413 .37506 .44592 Mtetra
.533 .297 .502 r
.37506 .44592 .38542 .24413 .38684 .25068 .37651 .45433 Mtetra
.516 .283 .499 r
.37651 .45433 .38684 .25068 .38859 .25004 .37835 .45434 Mtetra
.515 .282 .499 r
.37835 .45434 .38859 .25004 .39039 .24828 .38023 .45348 Mtetra
.515 .281 .499 r
.38023 .45348 .39039 .24828 .39201 .25086 .38211 .45253 Mtetra
.518 .284 .499 r
.38211 .45253 .39201 .25086 .38525 .44965 .38392 .45318 Mtetra
.528 .169 .302 r
.38392 .45318 .38525 .44965 .38692 .45368 .38575 .4537 Mtetra
.162 0 0 r
.38575 .4537 .38692 .45368 .3887 .45536 .38758 .45392 Mtetra
.615 .696 .902 r
.38758 .45392 .3887 .45536 .39056 .4551 .38945 .45345 Mtetra
.646 .677 .865 r
.38945 .45345 .39056 .4551 .39244 .45442 .39133 .45281 Mtetra
.656 .687 .867 r
.39133 .45281 .39244 .45442 .39432 .45358 .39321 .45212 Mtetra
.617 .695 .899 r
.39321 .45212 .39432 .45358 .39619 .45314 .39508 .45164 Mtetra
.615 .687 .894 r
.39508 .45164 .39619 .45314 .39807 .45271 .39696 .45116 Mtetra
.619 .682 .887 r
.39696 .45116 .39807 .45271 .39994 .45224 .39883 .45067 Mtetra
.634 .683 .879 r
.39883 .45067 .39994 .45224 .40182 .45168 .40071 .4501 Mtetra
.641 .686 .877 r
.40071 .4501 .40182 .45168 .40371 .45106 .4026 .4495 Mtetra
.648 .691 .877 r
.4026 .4495 .40371 .45106 .40559 .45038 .40448 .44886 Mtetra
.659 .701 .877 r
.40448 .44886 .40559 .45038 .40748 .4496 .40637 .44816 Mtetra
.665 .716 .886 r
.40637 .44816 .40748 .4496 .40938 .4488 .40827 .44744 Mtetra
.666 .731 .898 r
.40827 .44744 .40938 .4488 .41127 .448 .41016 .44672 Mtetra
.548 .699 .939 r
.41016 .44672 .41127 .448 .41316 .44758 .41204 .44648 Mtetra
.625 .763 .945 r
.41204 .44648 .41316 .44758 .41505 .44701 .41393 .44593 Mtetra
.75 .802 .894 r
.41393 .44593 .41505 .44701 .41695 .44609 .41584 .44478 Mtetra
.914 .764 .681 r
.41584 .44478 .41695 .44609 .41891 .44352 .41785 .44039 Mtetra
.965 .688 .457 r
.41785 .44039 .41891 .44352 .42091 .43953 .42613 .24179 Mtetra
.555 .32 .513 r
.42613 .24179 .42091 .43953 .42302 .43189 .42843 .22482 Mtetra
.521 .292 .508 r
.42843 .22482 .42302 .43189 .42494 .43033 .43023 .22332 Mtetra
.519 .29 .507 r
.43023 .22332 .42494 .43033 .4268 .43077 .432 .22282 Mtetra
.518 .289 .507 r
.432 .22282 .4268 .43077 .42872 .42919 .43376 .2226 Mtetra
.521 .292 .508 r
.43376 .2226 .42872 .42919 .43645 .22729 .43557 .22091 Mtetra
.629 .449 .621 r
.43557 .22091 .43645 .22729 .43837 .22178 .43738 .21923 Mtetra
.712 .607 .739 r
.43738 .21923 .43837 .22178 .44021 .21882 .43918 .21779 Mtetra
.703 .789 .917 r
.43918 .21779 .44021 .21882 .442 .2177 .44096 .21696 Mtetra
.643 .836 .974 r
.44096 .21696 .442 .2177 .44378 .21709 .44274 .21634 Mtetra
.609 .823 .982 r
.44274 .21634 .44378 .21709 .44555 .21673 .44452 .21582 Mtetra
.632 .794 .96 r
.44452 .21582 .44555 .21673 .44733 .21627 .4463 .21526 Mtetra
.64 .775 .946 r
.4463 .21526 .44733 .21627 .44911 .21581 .44808 .2147 Mtetra
.652 .758 .927 r
.44808 .2147 .44911 .21581 .45089 .21529 .44986 .21409 Mtetra
.686 .751 .901 r
.44986 .21409 .45089 .21529 .45268 .21453 .45165 .21332 Mtetra
.695 .754 .897 r
.45165 .21332 .45268 .21453 .45447 .21368 .45344 .21251 Mtetra
.696 .761 .902 r
.45344 .21251 .45447 .21368 .45626 .21283 .45524 .2117 Mtetra
.742 .782 .885 r
.45524 .2117 .45626 .21283 .45806 .21188 .45703 .21064 Mtetra
.696 .748 .892 r
.45703 .21064 .45806 .21188 .45985 .2111 .45883 .20981 Mtetra
.569 .692 .924 r
.45883 .20981 .45985 .2111 .46164 .21066 .46061 .20953 Mtetra
.573 .09 0 r
.46061 .20953 .46164 .21066 .4634 .21124 .46235 .2116 Mtetra
.936 .592 .35 r
.46235 .2116 .4634 .21124 .46515 .21309 .46391 .22258 Mtetra
.958 .668 .443 r
.46391 .22258 .46515 .21309 .46682 .21909 .46176 .42529 Mtetra
.52 .286 .5 r
.46176 .42529 .46682 .21909 .46484 .4229 .46364 .42736 Mtetra
.521 .182 .333 r
.46364 .42736 .46484 .4229 .46667 .4272 .46554 .42782 Mtetra
.176 0 0 r
.46554 .42782 .46667 .4272 .46856 .42887 .46746 .42767 Mtetra
.595 .737 .943 r
.46746 .42767 .46856 .42887 .47048 .42888 .46939 .42723 Mtetra
.642 .682 .872 r
.46939 .42723 .47048 .42888 .47241 .42825 .47132 .4266 Mtetra
.663 .69 .865 r
.47132 .4266 .47241 .42825 .47435 .42735 .47326 .42586 Mtetra
.569 .674 .91 r
.47326 .42586 .47435 .42735 .47628 .42686 .47519 .42556 Mtetra
.601 .722 .93 r
.47519 .42556 .47628 .42686 .47821 .42632 .47712 .42511 Mtetra
.72 .779 .899 r
.47712 .42511 .47821 .42632 .48015 .42545 .47907 .42411 Mtetra
.896 .776 .72 r
.47907 .42411 .48015 .42545 .48211 .42351 .48104 .42067 Mtetra
.921 .69 .571 r
.48104 .42067 .48211 .42351 .48408 .42026 .48311 .41039 Mtetra
.963 .678 .445 r
.48311 .41039 .48408 .42026 .48609 .41358 .48758 .20405 Mtetra
.525 .295 .508 r
.48758 .20405 .48609 .41358 .49037 .20774 .48942 .20063 Mtetra
.618 .434 .611 r
.48942 .20063 .49037 .20774 .49224 .202 .49125 .19895 Mtetra
.66 .552 .722 r
.49125 .19895 .49224 .202 .49407 .19918 .49307 .19786 Mtetra
.678 .732 .891 r
.49307 .19786 .49407 .19918 .49589 .19799 .49488 .19711 Mtetra
.622 .801 .968 r
.49488 .19711 .49589 .19799 .49771 .1975 .4967 .19657 Mtetra
.592 .781 .97 r
.4967 .19657 .49771 .1975 .49952 .19727 .49851 .19613 Mtetra
.646 .754 .928 r
.49851 .19613 .49952 .19727 .50134 .19679 .50033 .19554 Mtetra
.669 .74 .904 r
.50033 .19554 .50134 .19679 .50315 .19614 .50215 .19484 Mtetra
.677 .735 .894 r
.50215 .19484 .50315 .19614 .50497 .19541 .50397 .19409 Mtetra
.739 .752 .863 r
.50397 .19409 .50497 .19541 .5068 .19438 .5058 .19298 Mtetra
.721 .735 .862 r
.5058 .19298 .5068 .19438 .50862 .19336 .50762 .19197 Mtetra
.628 .7 .897 r
.50762 .19197 .50862 .19336 .51045 .19267 .50945 .19145 Mtetra
0 .171 .688 r
.50945 .19145 .51045 .19267 .51227 .19295 .51126 .19293 Mtetra
.919 .534 .255 r
.51126 .19293 .51227 .19295 .51409 .19447 .51306 .19981 Mtetra
.966 .672 .419 r
.51306 .19981 .51409 .19447 .5159 .19897 .51421 .40684 Mtetra
.522 .287 .5 r
.51421 .40684 .5159 .19897 .51725 .40392 .51616 .40971 Mtetra
.531 .211 .371 r
.51616 .40971 .51725 .40392 .51919 .40928 .51812 .41032 Mtetra
.31 0 0 r
.51812 .41032 .51919 .40928 .52116 .41124 .52009 .41025 Mtetra
.457 .724 .983 r
.52009 .41025 .52116 .41124 .52312 .41164 .52205 .41015 Mtetra
.589 .685 .908 r
.52205 .41015 .52312 .41164 .52509 .41119 .52402 .40976 Mtetra
.713 .744 .876 r
.52402 .40976 .52509 .41119 .52706 .41015 .526 .40874 Mtetra
.882 .777 .741 r
.526 .40874 .52706 .41015 .52903 .40828 .52797 .40571 Mtetra
.92 .699 .587 r
.52797 .40571 .52903 .40828 .531 .40522 .52993 .39741 Mtetra
.969 .68 .426 r
.52993 .39741 .531 .40522 .53296 .39942 .53144 .18877 Mtetra
.526 .296 .508 r
.53144 .18877 .53296 .39942 .53429 .19319 .53328 .18472 Mtetra
.607 .415 .596 r
.53328 .18472 .53429 .19319 .53611 .1864 .53512 .18296 Mtetra
.649 .529 .704 r
.53512 .18296 .53611 .1864 .53795 .18335 .53696 .18185 Mtetra
.665 .7 .872 r
.53696 .18185 .53795 .18335 .53979 .182 .5388 .18113 Mtetra
.591 .796 .978 r
.5388 .18113 .53979 .182 .54163 .18153 .54065 .18067 Mtetra
.535 .776 .986 r
.54065 .18067 .54163 .18153 .54348 .1814 .5425 .18036 Mtetra
.588 .757 .958 r
.5425 .18036 .54348 .1814 .54533 .18111 .54435 .17995 Mtetra
.63 .747 .932 r
.54435 .17995 .54533 .18111 .54718 .18059 .5462 .1794 Mtetra
.643 .748 .925 r
.5462 .1794 .54718 .18059 .54903 .18002 .54805 .17881 Mtetra
.656 .75 .919 r
.54805 .17881 .54903 .18002 .55089 .17937 .5499 .17816 Mtetra
.668 .753 .914 r
.5499 .17816 .55089 .17937 .55274 .17867 .55176 .17746 Mtetra
.677 .755 .91 r
.55176 .17746 .55274 .17867 .55459 .17793 .55361 .17671 Mtetra
.7 .762 .9 r
.55361 .17671 .55459 .17793 .55644 .17697 .55547 .17585 Mtetra
.708 .785 .912 r
.55547 .17585 .55644 .17697 .5583 .17599 .55732 .17497 Mtetra
.681 .797 .936 r
.55732 .17497 .5583 .17599 .56015 .17535 .55918 .17421 Mtetra
.56 .724 .951 r
.55918 .17421 .56015 .17535 .56203 .17598 .56104 .1739 Mtetra
.487 .535 .832 r
.56104 .1739 .56203 .17598 .56394 .1789 .56291 .17405 Mtetra
.505 .393 .66 r
.56291 .17405 .56394 .1789 .56846 .37287 .56479 .17434 Mtetra
.518 .29 .507 r
.56479 .17434 .56846 .37287 .57063 .38545 .56666 .17416 Mtetra
.519 .29 .507 r
.56666 .17416 .57063 .38545 .57263 .38489 .56852 .17336 Mtetra
.52 .291 .507 r
.56852 .17336 .57263 .38489 .5746 .38252 .57039 .17237 Mtetra
.57039 .17237 .5746 .38252 .57657 .38004 .57225 .17146 Mtetra
.519 .29 .507 r
.57225 .17146 .57657 .38004 .57856 .37866 .57412 .17068 Mtetra
.57412 .17068 .57856 .37866 .58055 .37729 .57599 .16991 Mtetra
.57599 .16991 .58055 .37729 .58254 .37601 .57786 .16916 Mtetra
.57786 .16916 .58254 .37601 .58453 .37489 .57973 .16843 Mtetra
.57973 .16843 .58453 .37489 .58653 .37389 .58161 .16771 Mtetra
.58161 .16771 .58653 .37389 .58853 .373 .58348 .167 Mtetra
.58348 .167 .58853 .373 .59053 .37222 .58536 .1663 Mtetra
.58536 .1663 .59053 .37222 .59254 .37152 .58724 .1656 Mtetra
.58724 .1656 .59254 .37152 .59455 .37088 .58912 .16491 Mtetra
.58912 .16491 .59455 .37088 .59656 .37026 .591 .16421 Mtetra
.591 .16421 .59656 .37026 .59857 .36968 .59288 .16352 Mtetra
.59288 .16352 .59857 .36968 .60059 .3691 .59476 .16283 Mtetra
.59476 .16283 .60059 .3691 .60261 .36853 .59665 .16215 Mtetra
.59665 .16215 .60261 .36853 .60462 .36796 .59853 .16146 Mtetra
.59853 .16146 .60462 .36796 .60664 .36738 .60042 .16077 Mtetra
.60042 .16077 .60664 .36738 .60867 .36681 .60231 .16008 Mtetra
.60231 .16008 .60867 .36681 .61069 .36625 .6042 .15939 Mtetra
.6042 .15939 .61069 .36625 .61272 .3657 .60609 .15871 Mtetra
.60609 .15871 .61272 .3657 .61474 .36517 .60798 .15802 Mtetra
.60798 .15802 .61474 .36517 .61677 .36469 .60988 .15734 Mtetra
.60988 .15734 .61677 .36469 .61881 .36431 .61177 .15667 Mtetra
.61177 .15667 .61881 .36431 .62085 .36401 .61367 .15601 Mtetra
.61367 .15601 .62085 .36401 .62289 .36371 .61557 .15536 Mtetra
.61557 .15536 .62289 .36371 .62497 .36461 .61747 .15479 Mtetra
.61747 .15479 .62497 .36461 .62707 .36587 .61938 .15432 Mtetra
.61938 .15432 .62707 .36587 .6291 .36484 .62128 .15365 Mtetra
.52 .291 .507 r
.62128 .15365 .6291 .36484 .62459 .168 .62317 .15238 Mtetra
.569 .359 .556 r
.62317 .15238 .62459 .168 .62608 .15483 .62503 .15057 Mtetra
.666 .514 .668 r
.62503 .15057 .62608 .15483 .62787 .15072 .6269 .14892 Mtetra
.727 .69 .815 r
.6269 .14892 .62787 .15072 .62972 .14859 .62879 .1477 Mtetra
.662 .827 .963 r
.62879 .1477 .62972 .14859 .63162 .14775 .6307 .14698 Mtetra
.602 .834 .987 r
.6307 .14698 .63162 .14775 .63354 .14728 .63261 .14643 Mtetra
.592 .81 .983 r
.63261 .14643 .63354 .14728 .63546 .14693 .63453 .14593 Mtetra
.613 .784 .963 r
.63453 .14593 .63546 .14693 .63738 .14649 .63644 .1454 Mtetra
.62 .766 .95 r
.63644 .1454 .63738 .14649 .6393 .14607 .63836 .14486 Mtetra
.639 .75 .929 r
.63836 .14486 .6393 .14607 .64122 .14557 .64028 .14427 Mtetra
.663 .741 .908 r
.64028 .14427 .64122 .14557 .64314 .14492 .64219 .14356 Mtetra
.673 .736 .898 r
.64219 .14356 .64314 .14492 .64505 .14419 .64411 .1428 Mtetra
.679 .734 .891 r
.64411 .1428 .64505 .14419 .64696 .14342 .64602 .14201 Mtetra
.683 .731 .887 r
.64602 .14201 .64696 .14342 .64888 .14262 .64793 .14119 Mtetra
.687 .73 .883 r
.64793 .14119 .64888 .14262 .65079 .14178 .64985 .14034 Mtetra
.722 .742 .868 r
.64985 .14034 .65079 .14178 .65269 .14069 .65175 .13929 Mtetra
.765 .762 .851 r
.65175 .13929 .65269 .14069 .65458 .13928 .65365 .13796 Mtetra
.689 .75 .898 r
.65365 .13796 .65458 .13928 .6565 .13838 .65556 .13712 Mtetra
.257 .536 .92 r
.65556 .13712 .6565 .13838 .65848 .13891 .65754 .13766 Mtetra
.869 .466 .006 r
.65754 .13766 .65848 .13891 .66074 .14569 .65979 .14406 Mtetra
.975 .669 .34 r
.65979 .14406 .66074 .14569 .67256 .35781 .67154 .35611 Mtetra
0 0 .414 r
.67154 .35611 .67256 .35781 .67482 .36119 .67381 .35963 Mtetra
.568 .674 .91 r
.67381 .35963 .67482 .36119 .67692 .36078 .67591 .35931 Mtetra
.715 .753 .882 r
.67591 .35931 .67692 .36078 .67897 .35961 .67798 .35824 Mtetra
.728 .774 .89 r
.67798 .35824 .67897 .35961 .68103 .35834 .68004 .35712 Mtetra
.533 .72 .959 r
.68004 .35712 .68103 .35834 .68312 .3579 .68214 .35686 Mtetra
.633 .801 .964 r
.68214 .35686 .68312 .3579 .68521 .35727 .68423 .3562 Mtetra
.828 .849 .863 r
.68423 .3562 .68521 .35727 .68727 .35609 .68626 .35443 Mtetra
.945 .763 .626 r
.68626 .35443 .68727 .35609 .68927 .35361 .6881 .34881 Mtetra
.976 .673 .358 r
.6881 .34881 .68927 .35361 .69117 .34951 .67924 .13823 Mtetra
.532 .3 .508 r
.67924 .13823 .69117 .34951 .69255 .33544 .68085 .13106 Mtetra
.522 .292 .508 r
.68085 .13106 .69255 .33544 .68387 .13459 .68272 .12898 Mtetra
.616 .453 .638 r
.68272 .12898 .68387 .13459 .68563 .13039 .68463 .12769 Mtetra
.649 .574 .757 r
.68463 .12769 .68563 .13039 .68749 .12812 .68657 .12679 Mtetra
.673 .746 .905 r
.68657 .12679 .68749 .12812 .68942 .12718 .68851 .12602 Mtetra
.644 .768 .938 r
.68851 .12602 .68942 .12718 .69137 .1266 .69046 .12539 Mtetra
.659 .762 .926 r
.69046 .12539 .69137 .1266 .69333 .12608 .69241 .12469 Mtetra
.737 .759 .87 r
.69241 .12469 .69333 .12608 .69526 .12508 .69434 .12355 Mtetra
.674 .712 .877 r
.69434 .12355 .69526 .12508 .69721 .12427 .69628 .12275 Mtetra
.469 .612 .91 r
.69628 .12275 .69721 .12427 .69918 .12392 .69828 .12283 Mtetra
.681 .223 0 r
.69828 .12283 .69918 .12392 .70123 .12474 .70048 .12627 Mtetra
.973 .661 .327 r
.70048 .12627 .70123 .12474 .70336 .12703 .71506 .33509 Mtetra
.529 .292 .5 r
.71506 .33509 .70336 .12703 .70612 .1393 .71765 .34229 Mtetra
.518 .284 .499 r
.71765 .34229 .70612 .1393 .72052 .33955 .71986 .34324 Mtetra
.474 .115 .275 r
.71986 .34324 .72052 .33955 .72288 .34288 .72202 .3433 Mtetra
.033 0 0 r
.72202 .3433 .72288 .34288 .72512 .34419 .72416 .34298 Mtetra
.463 .69 .965 r
.72416 .34298 .72512 .34419 .72729 .34426 .72632 .34293 Mtetra
.62 .743 .934 r
.72632 .34293 .72729 .34426 .72941 .3437 .72844 .34235 Mtetra
.78 .798 .867 r
.72844 .34235 .72941 .3437 .7315 .34247 .73051 .34085 Mtetra
.939 .775 .653 r
.73051 .34085 .7315 .34247 .73351 .34006 .73236 .33605 Mtetra
.975 .669 .336 r
.73236 .33605 .73351 .34006 .73541 .33608 .7207 .12766 Mtetra
.54 .306 .508 r
.7207 .12766 .73541 .33608 .73686 .3254 .72196 .11624 Mtetra
.522 .293 .507 r
.72196 .11624 .73686 .3254 .72504 .11986 .72382 .11389 Mtetra
.617 .448 .631 r
.72382 .11389 .72504 .11986 .72675 .11534 .72575 .11248 Mtetra
.651 .566 .746 r
.72575 .11248 .72675 .11534 .72861 .11286 .7277 .11151 Mtetra
.681 .747 .901 r
.7277 .11151 .72861 .11286 .73056 .11187 .72967 .11069 Mtetra
.652 .77 .935 r
.72967 .11069 .73056 .11187 .73254 .11125 .73165 .11001 Mtetra
.65 .757 .928 r
.73165 .11001 .73254 .11125 .73453 .11075 .73363 .10934 Mtetra
.752 .766 .864 r
.73363 .10934 .73453 .11075 .73648 .10958 .73557 .10809 Mtetra
.697 .732 .877 r
.73557 .10809 .73648 .10958 .73844 .1086 .73754 .10716 Mtetra
.557 .675 .917 r
.73754 .10716 .73844 .1086 .74043 .10804 .73955 .1069 Mtetra
0 0 .453 r
.73955 .1069 .74043 .10804 .74252 .10879 .7418 .10971 Mtetra
.971 .655 .302 r
.7418 .10971 .74252 .10879 .74473 .11104 .75926 .31625 Mtetra
.536 .297 .5 r
.75926 .31625 .74473 .11104 .7476 .12192 .76229 .32739 Mtetra
.519 .284 .499 r
.76229 .32739 .7476 .12192 .76518 .32539 .76458 .3287 Mtetra
.487 .112 .253 r
.76458 .3287 .76518 .32539 .76764 .32882 .7668 .32894 Mtetra
0 0 0 r
.7668 .32894 .76764 .32882 .76995 .33018 .76898 .32864 Mtetra
.645 .704 .89 r
.08731 .55111 .08851 .55244 .09012 .55244 .08898 .55056 Mtetra
.694 .649 .801 r
.08898 .55056 .09012 .55244 .09178 .55196 .0907 .54959 Mtetra
.745 .632 .734 r
.0907 .54959 .09178 .55196 .09353 .55079 .09254 .54779 Mtetra
.865 .659 .623 r
.09254 .54779 .09353 .55079 .09564 .54681 .09516 .53983 Mtetra
.93 .679 .536 r
.09516 .53983 .09564 .54681 .09956 .52857 .12255 .33732 Mtetra
.53 .299 .51 r
.12255 .33732 .09956 .52857 .12542 .33668 .12465 .33264 Mtetra
.641 .497 .671 r
.12465 .33264 .12542 .33668 .12725 .33413 .1263 .3315 Mtetra
.603 .533 .749 r
.1263 .3315 .12725 .33413 .12894 .33269 .12786 .33106 Mtetra
.538 .6 .864 r
.12786 .33106 .12894 .33269 .13056 .33177 .12938 .33096 Mtetra
.637 .791 .956 r
.12938 .33096 .13056 .33177 .13215 .33116 .13095 .33046 Mtetra
.647 .819 .966 r
.13095 .33046 .13215 .33116 .13371 .33074 .13253 .32991 Mtetra
.662 .795 .946 r
.13253 .32991 .13371 .33074 .13527 .33039 .13412 .32933 Mtetra
.699 .754 .894 r
.13412 .32933 .13527 .33039 .13685 .32983 .13572 .32858 Mtetra
.689 .718 .872 r
.13572 .32858 .13685 .32983 .13844 .32921 .13733 .32785 Mtetra
.666 .695 .867 r
.13733 .32785 .13844 .32921 .14004 .32854 .13892 .32723 Mtetra
.666 .702 .873 r
.13892 .32723 .14004 .32854 .14169 .32745 .14051 .32661 Mtetra
.544 .759 .976 r
.14051 .32661 .14169 .32745 .14331 .32659 .14206 .32635 Mtetra
.298 0 0 r
.14206 .32635 .14331 .32659 .14486 .32628 .14352 .32683 Mtetra
.881 .539 .398 r
.14352 .32683 .14486 .32628 .14612 .32846 .1444 .33218 Mtetra
.934 .676 .522 r
.1444 .33218 .14612 .32846 .1462 .34051 .1216 .53465 Mtetra
.526 .291 .502 r
.1216 .53465 .1462 .34051 .12435 .53659 .1227 .53902 Mtetra
.499 .108 .23 r
.1227 .53902 .12435 .53659 .12575 .5385 .1243 .5393 Mtetra
0 0 0 r
.1243 .5393 .12575 .5385 .12733 .53895 .12601 .53864 Mtetra
.75 .92 .948 r
.12601 .53864 .12733 .53895 .12898 .53882 .12776 .53759 Mtetra
.637 .724 .91 r
.12776 .53759 .12898 .53882 .13066 .53835 .12946 .53707 Mtetra
.621 .71 .909 r
.12946 .53707 .13066 .53835 .13238 .53768 .13114 .53662 Mtetra
.645 .757 .931 r
.13114 .53662 .13238 .53768 .1341 .53693 .13285 .53606 Mtetra
.635 .794 .959 r
.13285 .53606 .1341 .53693 .13573 .53693 .13454 .53553 Mtetra
.705 .714 .856 r
.13454 .53553 .13573 .53693 .1374 .53671 .13629 .53463 Mtetra
.749 .655 .756 r
.13629 .53463 .1374 .53671 .13914 .53578 .13812 .53298 Mtetra
.854 .66 .639 r
.13812 .53298 .13914 .53578 .14133 .53098 .14046 .52688 Mtetra
.938 .684 .526 r
.14046 .52688 .14133 .53098 .16636 .3256 .16541 .32291 Mtetra
.851 .657 .64 r
.16541 .32291 .16636 .3256 .16875 .31816 .16759 .31731 Mtetra
.818 .801 .835 r
.16759 .31731 .16875 .31816 .17047 .31652 .1693 .31576 Mtetra
.654 .81 .958 r
.1693 .31576 .17047 .31652 .17207 .31604 .17091 .31518 Mtetra
.524 .75 .978 r
.17091 .31518 .17207 .31604 .17361 .316 .17247 .31497 Mtetra
.671 .757 .915 r
.17247 .31497 .17361 .316 .1752 .31556 .17408 .31435 Mtetra
.688 .727 .88 r
.17408 .31435 .1752 .31556 .17682 .31496 .17571 .31363 Mtetra
.666 .701 .873 r
.17571 .31363 .17682 .31496 .17843 .31431 .17732 .313 Mtetra
.666 .704 .875 r
.17732 .313 .17843 .31431 .1801 .31319 .17894 .31237 Mtetra
.57 .775 .975 r
.17894 .31237 .1801 .31319 .18175 .31224 .18052 .31204 Mtetra
.184 0 0 r
.18052 .31204 .18175 .31224 .18334 .31193 .18204 .31237 Mtetra
.863 .491 .341 r
.18204 .31237 .18334 .31193 .18458 .31477 .18316 .31635 Mtetra
.941 .68 .513 r
.18316 .31635 .18458 .31477 .16414 .51845 .16268 .51965 Mtetra
.855 .51 .398 r
.16268 .51965 .16414 .51845 .16496 .52625 .16375 .52503 Mtetra
0 .182 .682 r
.16375 .52503 .16496 .52625 .16649 .52743 .16529 .52619 Mtetra
.554 .696 .934 r
.16529 .52619 .16649 .52743 .1682 .527 .16698 .52596 Mtetra
.772 .785 .863 r
.16698 .52596 .1682 .527 .17001 .52559 .16878 .52469 Mtetra
.909 .765 .691 r
.16878 .52469 .17001 .52559 .17204 .5222 .17091 .52032 Mtetra
.944 .687 .519 r
.17091 .52032 .17204 .5222 .17476 .51216 .19415 .31558 Mtetra
.539 .307 .512 r
.19415 .31558 .17476 .51216 .19742 .31116 .19665 .30673 Mtetra
.686 .519 .654 r
.19665 .30673 .19742 .31116 .19933 .30787 .19842 .30472 Mtetra
.611 .511 .716 r
.19842 .30472 .19933 .30787 .20105 .30635 .20004 .30412 Mtetra
.554 .541 .794 r
.20004 .30412 .20105 .30635 .20272 .30537 .20162 .30399 Mtetra
.628 .68 .88 r
.20162 .30399 .20272 .30537 .20436 .30461 .20324 .30352 Mtetra
.676 .749 .905 r
.20324 .30352 .20436 .30461 .20599 .30398 .20487 .30286 Mtetra
.663 .741 .908 r
.20487 .30286 .20599 .30398 .20762 .30341 .2065 .30226 Mtetra
.679 .74 .897 r
.2065 .30226 .20762 .30341 .20929 .30236 .20814 .30159 Mtetra
.62 .804 .97 r
.20814 .30159 .20929 .30236 .21097 .30134 .20976 .30111 Mtetra
.056 .611 .817 r
.20976 .30111 .21097 .30134 .21258 .30088 .21132 .30119 Mtetra
.832 .418 .257 r
.21132 .30119 .21258 .30088 .21396 .30287 .21261 .30403 Mtetra
.945 .681 .506 r
.21261 .30403 .21396 .30287 .19625 .49767 .19409 .50626 Mtetra
.733 .439 .482 r
.19409 .50626 .19625 .49767 .19626 .51463 .19503 .51376 Mtetra
.567 .022 0 r
.19503 .51376 .19626 .51463 .19776 .51647 .19658 .51518 Mtetra
.573 .694 .923 r
.19658 .51518 .19776 .51647 .19947 .51624 .1983 .51489 Mtetra
.762 .738 .83 r
.1983 .51489 .19947 .51624 .2013 .51483 .20012 .51354 Mtetra
.897 .74 .678 r
.20012 .51354 .2013 .51483 .2035 .50956 .20226 .50891 Mtetra
.948 .689 .511 r
.20226 .50891 .2035 .50956 .22508 .30226 .22371 .30378 Mtetra
.994 .852 .589 r
.22371 .30378 .22508 .30226 .22724 .29627 .22598 .29665 Mtetra
.358 0 0 r
.22598 .29665 .22724 .29627 .22886 .29585 .22754 .29693 Mtetra
.946 .681 .501 r
.22754 .29693 .22886 .29585 .23009 .29963 .21188 .47884 Mtetra
.58 .337 .512 r
.21188 .47884 .23009 .29963 .21251 .50381 .2108 .50814 Mtetra
.628 .294 .387 r
.2108 .50814 .21251 .50381 .21384 .50766 .21233 .50995 Mtetra
.37 0 .133 r
.21233 .50995 .21384 .50766 .21557 .50735 .21406 .50962 Mtetra
.23 0 .05 r
.21406 .50962 .21557 .50735 .21736 .50647 .21584 .5088 Mtetra
.285 0 .089 r
.21584 .5088 .21736 .50647 .21906 .50648 .21761 .50813 Mtetra
.257 0 0 r
.21761 .50813 .21906 .50648 .2207 .50712 .21936 .50766 Mtetra
0 0 0 r
.21936 .50766 .2207 .50712 .22237 .50755 .22112 .50708 Mtetra
.61 .876 .991 r
.22112 .50708 .22237 .50755 .22406 .50777 .22288 .50648 Mtetra
.692 .734 .882 r
.22288 .50648 .22406 .50777 .22578 .50764 .22466 .50566 Mtetra
.74 .665 .777 r
.22466 .50566 .22578 .50764 .22756 .50689 .22651 .5042 Mtetra
.833 .658 .665 r
.22651 .5042 .22756 .50689 .2295 .50437 .22861 .49987 Mtetra
.947 .685 .508 r
.22861 .49987 .2295 .50437 .23183 .49733 .24849 .29486 Mtetra
.536 .304 .511 r
.24849 .29486 .23183 .49733 .25151 .29253 .25078 .28713 Mtetra
.678 .497 .634 r
.25078 .28713 .25151 .29253 .25352 .28799 .25259 .2848 Mtetra
.621 .517 .714 r
.25259 .2848 .25352 .28799 .25528 .28619 .25426 .2841 Mtetra
.577 .568 .807 r
.25426 .2841 .25528 .28619 .25699 .28506 .25589 .28383 Mtetra
.599 .702 .916 r
.25589 .28383 .25699 .28506 .25866 .2843 .25753 .28347 Mtetra
.667 .806 .949 r
.25753 .28347 .25866 .2843 .26032 .28377 .2592 .28284 Mtetra
.672 .785 .934 r
.2592 .28284 .26032 .28377 .26196 .28336 .26086 .28219 Mtetra
.679 .739 .896 r
.26086 .28219 .26196 .28336 .26362 .28289 .26254 .2815 Mtetra
.675 .701 .867 r
.26254 .2815 .26362 .28289 .26528 .28227 .26421 .2808 Mtetra
.656 .682 .863 r
.26421 .2808 .26528 .28227 .26695 .28162 .26588 .28019 Mtetra
.652 .686 .869 r
.26588 .28019 .26695 .28162 .26864 .28071 .26754 .2796 Mtetra
.617 .731 .928 r
.26754 .2796 .26864 .28071 .27034 .27971 .2692 .27916 Mtetra
.215 .67 .948 r
.2692 .27916 .27034 .27971 .27201 .27914 .27081 .27927 Mtetra
.809 .355 .16 r
.27081 .27927 .27201 .27914 .27356 .28007 .27224 .28163 Mtetra
.951 .681 .491 r
.27224 .28163 .27356 .28007 .27476 .28532 .25744 .48469 Mtetra
.534 .297 .503 r
.25744 .48469 .27476 .28532 .26007 .48939 .25851 .49301 Mtetra
.629 .279 .359 r
.25851 .49301 .26007 .48939 .26154 .49269 .26011 .49467 Mtetra
.338 0 .076 r
.26011 .49467 .26154 .49269 .26331 .49231 .26188 .49431 Mtetra
.178 0 0 r
.26188 .49431 .26331 .49231 .26513 .49133 .2637 .49343 Mtetra
.206 0 .017 r
.2637 .49343 .26513 .49133 .2669 .491 .26551 .49258 Mtetra
.223 0 0 r
.26551 .49258 .2669 .491 .26859 .49163 .26729 .49204 Mtetra
.254 .754 .694 r
.26729 .49204 .26859 .49163 .2703 .49207 .26909 .49142 Mtetra
.705 .864 .957 r
.26909 .49142 .2703 .49207 .27205 .49205 .27091 .49055 Mtetra
.734 .719 .837 r
.27091 .49055 .27205 .49205 .27384 .49156 .27274 .48939 Mtetra
.709 .639 .777 r
.27274 .48939 .27384 .49156 .27564 .49093 .27459 .48816 Mtetra
.636 .56 .752 r
.27459 .48816 .27564 .49093 .27743 .49046 .2764 .4874 Mtetra
.557 .497 .744 r
.2764 .4874 .27743 .49046 .2792 .49018 .27817 .48722 Mtetra
.624 .542 .741 r
.27817 .48722 .2792 .49018 .28101 .48947 .27997 .48652 Mtetra
.779 .625 .689 r
.27997 .48652 .28101 .48947 .28293 .48735 .28194 .48365 Mtetra
.953 .687 .495 r
.28194 .48365 .28293 .48735 .28514 .48111 .29833 .28314 Mtetra
.55 .315 .513 r
.29833 .28314 .28514 .48111 .30172 .27528 .30098 .26936 Mtetra
.696 .503 .622 r
.30098 .26936 .30172 .27528 .30373 .27024 .30284 .26632 Mtetra
.621 .49 .681 r
.30284 .26632 .30373 .27024 .30544 .26936 .30455 .26544 Mtetra
.572 .458 .685 r
.30455 .26544 .30544 .26936 .30711 .26911 .30623 .26508 Mtetra
.561 .448 .682 r
.30623 .26508 .30711 .26911 .30881 .26841 .3079 .26481 Mtetra
.593 .483 .698 r
.3079 .26481 .30881 .26841 .31058 .26669 .30958 .26429 Mtetra
.614 .563 .773 r
.30958 .26429 .31058 .26669 .31234 .26514 .31127 .26378 Mtetra
.639 .696 .887 r
.31127 .26378 .31234 .26514 .31407 .26403 .31296 .26325 Mtetra
.641 .815 .967 r
.31296 .26325 .31407 .26403 .31577 .26347 .31466 .26268 Mtetra
.651 .818 .963 r
.31466 .26268 .31577 .26347 .31745 .26304 .31636 .26208 Mtetra
.675 .785 .932 r
.31636 .26208 .31745 .26304 .31914 .2626 .31806 .26141 Mtetra
.692 .744 .891 r
.31806 .26141 .31914 .2626 .32084 .26199 .31977 .26064 Mtetra
.676 .712 .875 r
.31977 .26064 .32084 .26199 .32254 .26133 .32148 .25993 Mtetra
.633 .688 .884 r
.32148 .25993 .32254 .26133 .32425 .26061 .32318 .25942 Mtetra
.525 .685 .939 r
.32318 .25942 .32425 .26061 .32597 .25983 .32485 .25927 Mtetra
.344 .744 .983 r
.32485 .25927 .32597 .25983 .32768 .25905 .32652 .25922 Mtetra
.201 .728 .754 r
.32652 .25922 .32768 .25905 .3294 .25819 .32821 .25885 Mtetra
.41 .827 .647 r
.32821 .25885 .3294 .25819 .33113 .2572 .32995 .25779 Mtetra
0 0 0 r
.32995 .25779 .33113 .2572 .33284 .2566 .33166 .25718 Mtetra
.627 .119 .022 r
.33166 .25718 .33284 .2566 .33448 .25705 .33326 .25825 Mtetra
.957 .682 .473 r
.33326 .25825 .33448 .25705 .33592 .26094 .32265 .45749 Mtetra
.544 .306 .504 r
.32265 .45749 .33592 .26094 .32515 .4659 .32361 .47101 Mtetra
.644 .317 .402 r
.32361 .47101 .32515 .4659 .32658 .47172 .32526 .47344 Mtetra
.357 0 .047 r
.32526 .47344 .32658 .47172 .32832 .47272 .32707 .47324 Mtetra
.32 .787 .673 r
.32707 .47324 .32832 .47272 .33011 .47288 .32892 .4724 Mtetra
.743 .91 .95 r
.32892 .4724 .33011 .47288 .33192 .47274 .33078 .47133 Mtetra
.671 .718 .884 r
.33078 .47133 .33192 .47274 .33372 .47268 .33262 .4706 Mtetra
.712 .651 .787 r
.33262 .4706 .33372 .47268 .33556 .47209 .3345 .46937 Mtetra
.781 .637 .703 r
.3345 .46937 .33556 .47209 .33746 .47044 .33645 .4667 Mtetra
.901 .665 .572 r
.33645 .4667 .33746 .47044 .33954 .46545 .33898 .45392 Mtetra
.949 .677 .487 r
.33898 .45392 .33954 .46545 .3528 .26032 .35217 .2513 Mtetra
.67 .459 .59 r
.35217 .2513 .3528 .26032 .35497 .25169 .35407 .24754 Mtetra
.629 .49 .673 r
.35407 .24754 .35497 .25169 .35672 .25054 .35582 .2465 Mtetra
.582 .462 .681 r
.35582 .2465 .35672 .25054 .35844 .25015 .35753 .24602 Mtetra
.56 .445 .679 r
.35753 .24602 .35844 .25015 .36016 .24965 .35924 .24576 Mtetra
.593 .474 .686 r
.35924 .24576 .36016 .24965 .36195 .24785 .36096 .24519 Mtetra
.615 .545 .753 r
.36096 .24519 .36195 .24785 .36373 .24622 .36269 .24462 Mtetra
.649 .667 .854 r
.36269 .24462 .36373 .24622 .36549 .24494 .36442 .24401 Mtetra
.691 .8 .932 r
.36442 .24401 .36549 .24494 .36723 .24428 .36616 .24325 Mtetra
.682 .778 .923 r
.36616 .24325 .36723 .24428 .36895 .24376 .36789 .24254 Mtetra
.647 .728 .908 r
.36789 .24254 .36895 .24376 .37068 .24325 .36962 .24197 Mtetra
.545 .678 .925 r
.36962 .24197 .37068 .24325 .37242 .24248 .37134 .24177 Mtetra
.419 .749 .994 r
.37134 .24177 .37242 .24248 .37416 .24169 .37305 .24167 Mtetra
.199 .727 .822 r
.37305 .24167 .37416 .24169 .37591 .24087 .37477 .24143 Mtetra
.454 .86 .69 r
.37477 .24143 .37591 .24087 .37766 .23985 .37653 .24035 Mtetra
0 0 0 r
.37653 .24035 .37766 .23985 .3794 .23917 .37827 .23962 Mtetra
.382 0 0 r
.37827 .23962 .3794 .23917 .38111 .23925 .37997 .23996 Mtetra
.911 .563 .368 r
.37997 .23996 .38111 .23925 .38267 .24245 .3813 .24811 Mtetra
.956 .675 .464 r
.3813 .24811 .38267 .24245 .37506 .44592 .37355 .45295 Mtetra
.655 .343 .432 r
.37355 .45295 .37506 .44592 .37651 .45433 .37523 .4564 Mtetra
.411 0 .128 r
.37523 .4564 .37651 .45433 .37835 .45434 .37707 .45632 Mtetra
.231 0 .018 r
.37707 .45632 .37835 .45434 .38023 .45348 .37895 .45556 Mtetra
.156 0 0 r
.37895 .45556 .38023 .45348 .38211 .45253 .38084 .45451 Mtetra
.27 0 .038 r
.38084 .45451 .38211 .45253 .38392 .45318 .38271 .45388 Mtetra
0 0 0 r
.38271 .45388 .38392 .45318 .38575 .4537 .38459 .45326 Mtetra
.585 .885 .991 r
.38459 .45326 .38575 .4537 .38758 .45392 .38646 .45264 Mtetra
.629 .729 .919 r
.38646 .45264 .38758 .45392 .38945 .45345 .38833 .4521 Mtetra
.642 .722 .907 r
.38833 .4521 .38945 .45345 .39133 .45281 .39021 .4515 Mtetra
.668 .739 .903 r
.39021 .4515 .39133 .45281 .39321 .45212 .39209 .45078 Mtetra
.737 .753 .866 r
.39209 .45078 .39321 .45212 .39508 .45164 .39399 .44965 Mtetra
.718 .666 .797 r
.39399 .44965 .39508 .45164 .39696 .45116 .39589 .4484 Mtetra
.683 .59 .745 r
.39589 .4484 .39696 .45116 .39883 .45067 .3978 .44718 Mtetra
.614 .513 .717 r
.3978 .44718 .39883 .45067 .40071 .4501 .39969 .44646 Mtetra
.595 .496 .711 r
.39969 .44646 .40071 .4501 .4026 .4495 .40157 .4459 Mtetra
.588 .493 .714 r
.40157 .4459 .4026 .4495 .40448 .44886 .40345 .44541 Mtetra
.601 .507 .721 r
.40345 .44541 .40448 .44886 .40637 .44816 .40533 .44482 Mtetra
.604 .514 .726 r
.40533 .44482 .40637 .44816 .40827 .44744 .40722 .44422 Mtetra
.607 .522 .733 r
.40722 .44422 .40827 .44744 .41016 .44672 .40911 .44361 Mtetra
.536 .486 .747 r
.40911 .44361 .41016 .44672 .41204 .44648 .41098 .44357 Mtetra
.6 .536 .754 r
.41098 .44357 .41204 .44648 .41393 .44593 .41287 .44306 Mtetra
.695 .59 .734 r
.41287 .44306 .41393 .44593 .41584 .44478 .41479 .44166 Mtetra
.887 .67 .604 r
.41479 .44166 .41584 .44478 .41785 .44039 .41692 .4339 Mtetra
.962 .683 .461 r
.41692 .4339 .41785 .44039 .42613 .24179 .42557 .22565 Mtetra
.636 .41 .558 r
.42557 .22565 .42613 .24179 .42843 .22482 .42749 .22062 Mtetra
.646 .5 .67 r
.42749 .22062 .42843 .22482 .43023 .22332 .42928 .21932 Mtetra
.592 .471 .684 r
.42928 .21932 .43023 .22332 .432 .22282 .43105 .21873 Mtetra
.556 .445 .683 r
.43105 .21873 .432 .22282 .43376 .2226 .43281 .2185 Mtetra
.587 .465 .681 r
.43281 .2185 .43376 .2226 .43557 .22091 .43459 .21796 Mtetra
.606 .525 .737 r
.43459 .21796 .43557 .22091 .43738 .21923 .43636 .2174 Mtetra
.632 .634 .834 r
.43636 .2174 .43738 .21923 .43918 .21779 .43814 .21684 Mtetra
.649 .791 .95 r
.43814 .21684 .43918 .21779 .44096 .21696 .43992 .21623 Mtetra
.646 .841 .975 r
.43992 .21623 .44096 .21696 .44274 .21634 .4417 .2156 Mtetra
.657 .841 .971 r
.4417 .2156 .44274 .21634 .44452 .21582 .44348 .21493 Mtetra
.695 .818 .941 r
.44348 .21493 .44452 .21582 .4463 .21526 .44527 .21414 Mtetra
.689 .767 .911 r
.44527 .21414 .4463 .21526 .44808 .2147 .44705 .21337 Mtetra
.664 .722 .892 r
.44705 .21337 .44808 .2147 .44986 .21409 .44884 .21269 Mtetra
.572 .673 .907 r
.44884 .21269 .44986 .21409 .45165 .21332 .45062 .21241 Mtetra
.476 .731 .982 r
.45062 .21241 .45165 .21332 .45344 .21251 .45239 .21227 Mtetra
.218 .726 .894 r
.45239 .21227 .45344 .21251 .45524 .2117 .45417 .21216 Mtetra
.433 .854 .705 r
.45417 .21216 .45524 .2117 .45703 .21064 .45597 .21114 Mtetra
.328 .786 .65 r
.45597 .21114 .45703 .21064 .45883 .20981 .45777 .21025 Mtetra
.087 0 0 r
.45777 .21025 .45883 .20981 .46061 .20953 .45955 .21006 Mtetra
.871 .466 .257 r
.45955 .21006 .46061 .20953 .46235 .2116 .46124 .21465 Mtetra
.966 .677 .434 r
.46124 .21465 .46235 .2116 .46391 .22258 .45878 .42281 Mtetra
.526 .29 .5 r
.45878 .42281 .46391 .22258 .46176 .42529 .4606 .42772 Mtetra
.51 .106 .211 r
.4606 .42772 .46176 .42529 .46364 .42736 .4625 .42816 Mtetra
0 0 0 r
.4625 .42816 .46364 .42736 .46554 .42782 .46443 .42754 Mtetra
.691 .949 .957 r
.46443 .42754 .46554 .42782 .46746 .42767 .46637 .4265 Mtetra
.649 .765 .933 r
.46637 .4265 .46746 .42767 .46939 .42723 .4683 .42585 Mtetra
.639 .721 .908 r
.4683 .42585 .46939 .42723 .47132 .4266 .47023 .42525 Mtetra
.662 .736 .904 r
.47023 .42525 .47132 .4266 .47326 .42586 .47217 .42454 Mtetra
.654 .739 .912 r
.47217 .42454 .47326 .42586 .47519 .42556 .47411 .42387 Mtetra
.701 .699 .845 r
.47411 .42387 .47519 .42556 .47712 .42511 .47605 .42287 Mtetra
.753 .662 .76 r
.47605 .42287 .47712 .42511 .47907 .42411 .478 .42109 Mtetra
.875 .671 .623 r
.478 .42109 .47907 .42411 .48104 .42067 .48002 .41491 Mtetra
.967 .683 .44 r
.48002 .41491 .48104 .42067 .48311 .41039 .48473 .20517 Mtetra
.53 .299 .509 r
.48473 .20517 .48311 .41039 .48758 .20405 .48661 .1993 Mtetra
.66 .497 .652 r
.48661 .1993 .48758 .20405 .48942 .20063 .48844 .19758 Mtetra
.612 .525 .731 r
.48844 .19758 .48942 .20063 .49125 .19895 .49025 .19695 Mtetra
.566 .584 .83 r
.49025 .19695 .49125 .19895 .49307 .19786 .49206 .19672 Mtetra
.618 .743 .936 r
.49206 .19672 .49307 .19786 .49488 .19711 .49387 .19623 Mtetra
.648 .811 .961 r
.49387 .19623 .49488 .19711 .4967 .19657 .49569 .1956 Mtetra
.66 .795 .947 r
.49569 .1956 .4967 .19657 .49851 .19613 .49751 .19494 Mtetra
.692 .76 .904 r
.49751 .19494 .49851 .19613 .50033 .19554 .49933 .19414 Mtetra
.689 .723 .875 r
.49933 .19414 .50033 .19554 .50215 .19484 .50115 .19331 Mtetra
.669 .696 .866 r
.50115 .19331 .50215 .19484 .50397 .19409 .50297 .19258 Mtetra
.666 .696 .868 r
.50297 .19258 .50397 .19409 .5058 .19298 .50479 .19186 Mtetra
.601 .742 .943 r
.50479 .19186 .5058 .19298 .50762 .19197 .50662 .19143 Mtetra
.141 .626 .918 r
.50662 .19143 .50762 .19197 .50945 .19145 .50844 .19165 Mtetra
.848 .402 .152 r
.50844 .19165 .50945 .19145 .51126 .19293 .51024 .19525 Mtetra
.969 .676 .415 r
.51024 .19525 .51126 .19293 .51306 .19981 .51119 .40388 Mtetra
.527 .291 .5 r
.51119 .40388 .51306 .19981 .51421 .40684 .51312 .4098 Mtetra
.562 .178 .271 r
.51312 .4098 .51421 .40684 .51616 .40971 .51508 .4107 Mtetra
.101 0 0 r
.51508 .4107 .51616 .40971 .51812 .41032 .51705 .41013 Mtetra
.689 .963 .94 r
.51705 .41013 .51812 .41032 .52009 .41025 .51902 .40901 Mtetra
.687 .768 .913 r
.51902 .40901 .52009 .41025 .52205 .41015 .52099 .40817 Mtetra
.674 .657 .825 r
.52099 .40817 .52205 .41015 .52402 .40976 .52296 .40727 Mtetra
.728 .635 .755 r
.52296 .40727 .52402 .40976 .526 .40874 .52493 .40567 Mtetra
.857 .663 .639 r
.52493 .40567 .526 .40874 .52797 .40571 .5269 .40049 Mtetra
.971 .683 .423 r
.5269 .40049 .52797 .40571 .52993 .39741 .52861 .19034 Mtetra
.532 .3 .509 r
.52861 .19034 .52993 .39741 .53144 .18877 .53044 .18353 Mtetra
.667 .492 .639 r
.53044 .18353 .53144 .18877 .53328 .18472 .53228 .18146 Mtetra
.61 .515 .721 r
.53228 .18146 .53328 .18472 .53512 .18296 .53412 .1808 Mtetra
.558 .565 .817 r
.53412 .1808 .53512 .18296 .53696 .18185 .53597 .18061 Mtetra
.572 .709 .935 r
.53597 .18061 .53696 .18185 .5388 .18113 .53782 .18029 Mtetra
.603 .809 .979 r
.53782 .18029 .5388 .18113 .54065 .18067 .53966 .17979 Mtetra
.609 .8 .973 r
.53966 .17979 .54065 .18067 .5425 .18036 .54151 .17927 Mtetra
.628 .763 .944 r
.54151 .17927 .5425 .18036 .54435 .17995 .54336 .17873 Mtetra
.639 .741 .923 r
.54336 .17873 .54435 .17995 .5462 .1794 .54521 .17815 Mtetra
.648 .738 .915 r
.54521 .17815 .5462 .1794 .54805 .17881 .54707 .17754 Mtetra
.658 .738 .909 r
.54707 .17754 .54805 .17881 .5499 .17816 .54892 .17688 Mtetra
.668 .74 .904 r
.54892 .17688 .5499 .17816 .55176 .17746 .55077 .17617 Mtetra
.676 .742 .901 r
.55077 .17617 .55176 .17746 .55361 .17671 .55263 .17543 Mtetra
.683 .745 .898 r
.55263 .17543 .55361 .17671 .55547 .17585 .55448 .17465 Mtetra
.69 .762 .907 r
.55448 .17465 .55547 .17585 .55732 .17497 .55634 .17384 Mtetra
.696 .779 .916 r
.55634 .17384 .55732 .17497 .55918 .17421 .5582 .17301 Mtetra
.698 .766 .904 r
.5582 .17301 .55918 .17421 .56104 .1739 .56006 .17216 Mtetra
.68 .673 .836 r
.56006 .17216 .56104 .1739 .56291 .17405 .56192 .1713 Mtetra
.644 .563 .749 r
.56192 .1713 .56291 .17405 .56479 .17434 .56378 .17045 Mtetra
.613 .491 .69 r
.56378 .17045 .56479 .17434 .56666 .17416 .56564 .16962 Mtetra
.6 .464 .667 r
.56564 .16962 .56666 .17416 .56852 .17336 .5675 .16883 Mtetra
.599 .463 .667 r
.5675 .16883 .56852 .17336 .57039 .17237 .56937 .16805 Mtetra
.6 .47 .675 r
.56937 .16805 .57039 .17237 .57225 .17146 .57123 .1673 Mtetra
.601 .475 .68 r
.57123 .1673 .57225 .17146 .57412 .17068 .5731 .16656 Mtetra
.601 .476 .682 r
.5731 .16656 .57412 .17068 .57599 .16991 .57497 .16583 Mtetra
.601 .477 .684 r
.57497 .16583 .57599 .16991 .57786 .16916 .57684 .16511 Mtetra
.601 .478 .685 r
.57684 .16511 .57786 .16916 .57973 .16843 .57871 .1644 Mtetra
.6 .479 .686 r
.57871 .1644 .57973 .16843 .58161 .16771 .58059 .16369 Mtetra
.58059 .16369 .58161 .16771 .58348 .167 .58246 .16299 Mtetra
.6 .479 .687 r
.58246 .16299 .58348 .167 .58536 .1663 .58434 .16229 Mtetra
.58434 .16229 .58536 .1663 .58724 .1656 .58621 .16159 Mtetra
.58621 .16159 .58724 .1656 .58912 .16491 .58809 .1609 Mtetra
.58809 .1609 .58912 .16491 .591 .16421 .58997 .1602 Mtetra
.58997 .1602 .591 .16421 .59288 .16352 .59185 .15951 Mtetra
.599 .479 .687 r
.59185 .15951 .59288 .16352 .59476 .16283 .59374 .15882 Mtetra
.59374 .15882 .59476 .16283 .59665 .16215 .59562 .15812 Mtetra
.59562 .15812 .59665 .16215 .59853 .16146 .5975 .15743 Mtetra
.599 .478 .687 r
.5975 .15743 .59853 .16146 .60042 .16077 .59939 .15673 Mtetra
.599 .478 .686 r
.59939 .15673 .60042 .16077 .60231 .16008 .60128 .15604 Mtetra
.60128 .15604 .60231 .16008 .6042 .15939 .60317 .15535 Mtetra
.60317 .15535 .6042 .15939 .60609 .15871 .60506 .15466 Mtetra
.599 .477 .686 r
.60506 .15466 .60609 .15871 .60798 .15802 .60695 .15396 Mtetra
.598 .477 .686 r
.60695 .15396 .60798 .15802 .60988 .15734 .60884 .15327 Mtetra
.598 .476 .685 r
.60884 .15327 .60988 .15734 .61177 .15667 .61074 .15259 Mtetra
.597 .476 .685 r
.61074 .15259 .61177 .15667 .61367 .15601 .61263 .15191 Mtetra
.596 .474 .684 r
.61263 .15191 .61367 .15601 .61557 .15536 .61453 .15123 Mtetra
.595 .473 .683 r
.61453 .15123 .61557 .15536 .61747 .15479 .61643 .15056 Mtetra
.593 .468 .68 r
.61643 .15056 .61747 .15479 .61938 .15432 .61833 .1499 Mtetra
.589 .461 .673 r
.61833 .1499 .61938 .15432 .62128 .15365 .62023 .14925 Mtetra
.588 .46 .674 r
.62023 .14925 .62128 .15365 .62317 .15238 .62213 .14863 Mtetra
.594 .486 .7 r
.62213 .14863 .62317 .15238 .62503 .15057 .62404 .14804 Mtetra
.616 .566 .775 r
.62404 .14804 .62503 .15057 .6269 .14892 .62595 .14745 Mtetra
.639 .701 .891 r
.62595 .14745 .6269 .14892 .62879 .1477 .62786 .14685 Mtetra
.631 .825 .975 r
.62786 .14685 .62879 .1477 .6307 .14698 .62977 .14623 Mtetra
.626 .846 .984 r
.62977 .14623 .6307 .14698 .63261 .14643 .63168 .1456 Mtetra
.636 .832 .976 r
.63168 .1456 .63261 .14643 .63453 .14593 .63359 .14495 Mtetra
.647 .802 .958 r
.63359 .14495 .63453 .14593 .63644 .1454 .63551 .1443 Mtetra
.658 .78 .939 r
.63551 .1443 .63644 .1454 .63836 .14486 .63742 .14362 Mtetra
.671 .756 .914 r
.63742 .14362 .63836 .14486 .64028 .14427 .63933 .14288 Mtetra
.683 .735 .89 r
.63933 .14288 .64028 .14427 .64219 .14356 .64124 .14207 Mtetra
.684 .717 .874 r
.64124 .14207 .64219 .14356 .64411 .1428 .64315 .14123 Mtetra
.687 .706 .862 r
.64315 .14123 .64411 .1428 .64602 .14201 .64507 .14036 Mtetra
.687 .695 .852 r
.64507 .14036 .64602 .14201 .64793 .14119 .64698 .13946 Mtetra
.672 .678 .848 r
.64698 .13946 .64793 .14119 .64985 .14034 .64889 .13865 Mtetra
.663 .679 .855 r
.64889 .13865 .64985 .14034 .65175 .13929 .65081 .13789 Mtetra
.658 .723 .897 r
.65081 .13789 .65175 .13929 .65365 .13796 .65274 .13721 Mtetra
.462 .774 .997 r
.65274 .13721 .65365 .13796 .65556 .13712 .65468 .13699 Mtetra
.501 0 0 r
.65468 .13699 .65556 .13712 .65754 .13766 .65669 .13819 Mtetra
.933 .561 .264 r
.65669 .13819 .65754 .13766 .65979 .14406 .65916 .14937 Mtetra
.972 .662 .357 r
.65916 .14937 .65979 .14406 .67154 .35611 .67056 .35521 Mtetra
.64 .139 0 r
.67056 .35521 .67154 .35611 .67381 .35963 .6728 .35799 Mtetra
.559 .656 .901 r
.6728 .35799 .67381 .35963 .67591 .35931 .6749 .35771 Mtetra
.685 .721 .877 r
.6749 .35771 .67591 .35931 .67798 .35824 .67697 .3568 Mtetra
.685 .746 .898 r
.67697 .3568 .67798 .35824 .68004 .35712 .67905 .35592 Mtetra
.469 .692 .964 r
.67905 .35592 .68004 .35712 .68214 .35686 .68116 .35585 Mtetra
.616 .802 .971 r
.68116 .35585 .68214 .35686 .68423 .3562 .68325 .35524 Mtetra
.865 .87 .84 r
.68325 .35524 .68423 .3562 .68626 .35443 .68527 .35316 Mtetra
.98 .759 .533 r
.68527 .35316 .68626 .35443 .6881 .34881 .68693 .34395 Mtetra
.976 .673 .358 r
.68693 .34395 .6881 .34881 .67924 .13823 .67803 .13144 Mtetra
.724 .508 .598 r
.67803 .13144 .67924 .13823 .68085 .13106 .67978 .12705 Mtetra
.627 .498 .686 r
.67978 .12705 .68085 .13106 .68272 .12898 .68171 .12602 Mtetra
.581 .518 .749 r
.68171 .12602 .68272 .12898 .68463 .12769 .68367 .12564 Mtetra
.549 .578 .835 r
.68367 .12564 .68463 .12769 .68657 .12679 .68564 .12548 Mtetra
.649 .738 .914 r
.68564 .12548 .68657 .12679 .68851 .12602 .68759 .12482 Mtetra
.658 .764 .928 r
.68759 .12482 .68851 .12602 .69046 .12539 .68954 .12413 Mtetra
.69 .766 .91 r
.68954 .12413 .69046 .12539 .69241 .12469 .69149 .12329 Mtetra
.758 .764 .857 r
.69149 .12329 .69241 .12469 .69434 .12355 .69341 .122 Mtetra
.682 .712 .871 r
.69341 .122 .69434 .12355 .69628 .12275 .69535 .12115 Mtetra
.415 .567 .897 r
.69535 .12115 .69628 .12275 .69828 .12283 .69736 .12144 Mtetra
.834 .431 0 r
.69736 .12144 .69828 .12283 .70048 .12627 .69973 .12768 Mtetra
.973 .661 .326 r
.69973 .12768 .70048 .12627 .71506 .33509 .71447 .3402 Mtetra
.693 .337 .368 r
.71447 .3402 .71506 .33509 .71765 .34229 .71686 .3441 Mtetra
.379 0 .062 r
.71686 .3441 .71765 .34229 .71986 .34324 .71901 .34396 Mtetra
0 0 0 r
.71901 .34396 .71986 .34324 .72202 .3433 .72111 .343 Mtetra
.728 .975 .925 r
.72111 .343 .72202 .3433 .72416 .34298 .72319 .34166 Mtetra
.656 .76 .927 r
.72319 .34166 .72416 .34298 .72632 .34293 .7253 .34092 Mtetra
.712 .683 .821 r
.7253 .34092 .72632 .34293 .72844 .34235 .72739 .3397 Mtetra
.782 .659 .727 r
.72739 .3397 .72844 .34235 .73051 .34085 .7294 .33728 Mtetra
.934 .681 .531 r
.7294 .33728 .73051 .34085 .73236 .33605 .73084 .32614 Mtetra
.973 .665 .349 r
.73084 .32614 .73236 .33605 .7207 .12766 .71913 .11633 Mtetra
.654 .431 .569 r
.71913 .11633 .7207 .12766 .72196 .11624 .72086 .11204 Mtetra
.63 .495 .679 r
.72086 .11204 .72196 .11624 .72382 .11389 .72281 .11091 Mtetra
.596 .527 .747 r
.72281 .11091 .72382 .11389 .72575 .11248 .72479 .1104 Mtetra
.563 .585 .833 r
.72479 .1104 .72575 .11248 .7277 .11151 .7268 .11016 Mtetra
.672 .745 .905 r
.7268 .11016 .7277 .11151 .72967 .11069 .72877 .10939 Mtetra
.665 .751 .914 r
.72877 .10939 .72967 .11069 .73165 .11001 .73075 .10865 Mtetra
.648 .733 .911 r
.73075 .10865 .73165 .11001 .73363 .10934 .73273 .10799 Mtetra
.668 .743 .906 r
.73273 .10799 .73363 .10934 .73557 .10809 .73471 .10723 Mtetra
.523 .785 .992 r
.73471 .10723 .73557 .10809 .73754 .10716 .73672 .1069 Mtetra
0 .407 .697 r
.73672 .1069 .73754 .10716 .73955 .1069 .7388 .10749 Mtetra
.91 .507 .195 r
.7388 .10749 .73955 .1069 .7418 .10971 .74146 .11595 Mtetra
.97 .652 .318 r
.74146 .11595 .7418 .10971 .75926 .31625 .75911 .32567 Mtetra
.623 .311 .421 r
.75911 .32567 .75926 .31625 .76229 .32739 .76157 .32925 Mtetra
.393 0 .073 r
.76157 .32925 .76229 .32739 .76458 .3287 .76377 .32916 Mtetra
0 0 0 r
.76377 .32916 .76458 .3287 .7668 .32894 .76591 .32832 Mtetra
.758 .936 .943 r
.76591 .32832 .7668 .32894 .76898 .32864 .76801 .327 Mtetra
.833 .765 .788 r
.08606 .55002 .08731 .55111 .08898 .55056 .08793 .54795 Mtetra
.804 .644 .685 r
.08793 .54795 .08898 .55056 .0907 .54959 .08997 .54459 Mtetra
.821 .607 .613 r
.08997 .54459 .0907 .54959 .09254 .54779 .09261 .53653 Mtetra
.925 .673 .538 r
.09261 .53653 .09254 .54779 .09516 .53983 .11964 .33819 Mtetra
.529 .298 .509 r
.11964 .33819 .09516 .53983 .12255 .33732 .12173 .33359 Mtetra
.727 .561 .666 r
.12173 .33359 .12255 .33732 .12465 .33264 .12355 .33116 Mtetra
.691 .683 .838 r
.12355 .33116 .12465 .33264 .1263 .3315 .12515 .33037 Mtetra
.595 .711 .924 r
.12515 .33037 .1263 .3315 .12786 .33106 .1267 .33003 Mtetra
.502 .7 .958 r
.1267 .33003 .12786 .33106 .12938 .33096 .12823 .32992 Mtetra
.639 .743 .924 r
.12823 .32992 .12938 .33096 .13095 .33046 .1298 .32943 Mtetra
.663 .751 .916 r
.1298 .32943 .13095 .33046 .13253 .32991 .13138 .32885 Mtetra
.679 .749 .904 r
.13138 .32885 .13253 .32991 .13412 .32933 .13297 .3282 Mtetra
.74 .748 .858 r
.13297 .3282 .13412 .32933 .13572 .32858 .13461 .32719 Mtetra
.706 .7 .842 r
.13461 .32719 .13572 .32858 .13733 .32785 .13624 .32631 Mtetra
.641 .658 .851 r
.13624 .32631 .13733 .32785 .13892 .32723 .13782 .32579 Mtetra
.19 .451 .876 r
.13782 .32579 .13892 .32723 .14051 .32661 .13926 .32639 Mtetra
.789 .306 .073 r
.13926 .32639 .14051 .32661 .14206 .32635 .14055 .32822 Mtetra
.841 .515 .438 r
.14055 .32822 .14206 .32635 .14352 .32683 .14137 .33404 Mtetra
.93 .671 .525 r
.14137 .33404 .14352 .32683 .1444 .33218 .11885 .53269 Mtetra
.525 .29 .501 r
.11885 .53269 .1444 .33218 .1216 .53465 .11997 .5369 Mtetra
.664 .287 .322 r
.11997 .5369 .1216 .53465 .1227 .53902 .1214 .53853 Mtetra
.401 .789 .989 r
.1214 .53853 .1227 .53902 .1243 .5393 .12305 .53835 Mtetra
.697 .789 .921 r
.12305 .53835 .1243 .5393 .12601 .53864 .12478 .53757 Mtetra
.736 .773 .882 r
.12478 .53757 .12601 .53864 .12776 .53759 .12653 .53657 Mtetra
.552 .735 .96 r
.12653 .53657 .12776 .53759 .12946 .53707 .12819 .5363 Mtetra
.524 .78 .991 r
.12819 .5363 .12946 .53707 .13114 .53662 .12986 .53603 Mtetra
.643 .854 .98 r
.12986 .53603 .13114 .53662 .13285 .53606 .13157 .53541 Mtetra
.847 .837 .836 r
.13157 .53541 .13285 .53606 .13454 .53553 .13342 .53357 Mtetra
.829 .688 .707 r
.13342 .53357 .13454 .53553 .13629 .53463 .13542 .53041 Mtetra
.824 .617 .623 r
.13542 .53041 .13629 .53463 .13812 .53298 .13784 .52369 Mtetra
.932 .677 .529 r
.13784 .52369 .13812 .53298 .14046 .52688 .16248 .324 Mtetra
.53 .299 .509 r
.16248 .324 .14046 .52688 .16541 .32291 .16463 .31864 Mtetra
.721 .546 .652 r
.16463 .31864 .16541 .32291 .16759 .31731 .16648 .31597 Mtetra
.743 .719 .829 r
.16648 .31597 .16759 .31731 .1693 .31576 .16814 .31484 Mtetra
.657 .776 .937 r
.16814 .31484 .1693 .31576 .17091 .31518 .16975 .31427 Mtetra
.593 .76 .958 r
.16975 .31427 .17091 .31518 .17247 .31497 .17133 .3139 Mtetra
.723 .76 .882 r
.17133 .3139 .17247 .31497 .17408 .31435 .17298 .31301 Mtetra
.712 .713 .85 r
.17298 .31301 .17408 .31435 .17571 .31363 .17462 .31212 Mtetra
.651 .669 .854 r
.17462 .31212 .17571 .31363 .17732 .313 .17623 .31154 Mtetra
.297 .511 .894 r
.17623 .31154 .17732 .313 .17894 .31237 .17773 .31198 Mtetra
.752 .235 0 r
.17773 .31198 .17894 .31237 .18052 .31204 .17909 .31363 Mtetra
.832 .489 .406 r
.17909 .31363 .18052 .31204 .18204 .31237 .18013 .31837 Mtetra
.935 .674 .516 r
.18013 .31837 .18204 .31237 .18316 .31635 .15992 .51749 Mtetra
.527 .292 .501 r
.15992 .51749 .18316 .31635 .16268 .51965 .16103 .52249 Mtetra
.666 .307 .353 r
.16103 .52249 .16268 .51965 .16375 .52503 .16249 .52439 Mtetra
0 .302 .673 r
.16249 .52439 .16375 .52503 .16529 .52619 .16407 .52512 Mtetra
.501 .707 .963 r
.16407 .52512 .16529 .52619 .16698 .52596 .16575 .52499 Mtetra
.745 .794 .893 r
.16575 .52499 .16698 .52596 .16878 .52469 .16753 .52394 Mtetra
.915 .778 .695 r
.16753 .52394 .16878 .52469 .17091 .52032 .16965 .51965 Mtetra
.945 .689 .518 r
.16965 .51965 .17091 .52032 .19415 .31558 .19305 .31422 Mtetra
.92 .713 .607 r
.19305 .31422 .19415 .31558 .19665 .30673 .19555 .30531 Mtetra
.81 .723 .769 r
.19555 .30531 .19665 .30673 .19842 .30472 .19732 .30336 Mtetra
.638 .688 .881 r
.19732 .30336 .19842 .30472 .20004 .30412 .19893 .30285 Mtetra
.489 .646 .927 r
.19893 .30285 .20004 .30412 .20162 .30399 .2005 .30283 Mtetra
.645 .728 .909 r
.2005 .30283 .20162 .30399 .20324 .30352 .20212 .3023 Mtetra
.69 .729 .88 r
.20212 .3023 .20324 .30352 .20487 .30286 .20377 .30156 Mtetra
.637 .699 .89 r
.20377 .30156 .20487 .30286 .2065 .30226 .20539 .30106 Mtetra
.33 .582 .935 r
.20539 .30106 .2065 .30226 .20814 .30159 .20693 .30134 Mtetra
.675 .128 0 r
.20693 .30134 .20814 .30159 .20976 .30111 .20837 .30264 Mtetra
.794 .427 .362 r
.20837 .30264 .20976 .30111 .21132 .30119 .2096 .30599 Mtetra
.94 .676 .508 r
.2096 .30599 .21132 .30119 .21261 .30403 .19134 .50384 Mtetra
.531 .295 .502 r
.19134 .50384 .21261 .30403 .19409 .50626 .19231 .51099 Mtetra
.646 .32 .406 r
.19231 .51099 .19409 .50626 .19503 .51376 .19377 .51324 Mtetra
0 .415 .741 r
.19377 .51324 .19503 .51376 .19658 .51518 .1954 .51376 Mtetra
.613 .687 .895 r
.1954 .51376 .19658 .51518 .1983 .51489 .19714 .51333 Mtetra
.728 .704 .828 r
.19714 .51333 .1983 .51489 .20012 .51354 .19894 .5122 Mtetra
.86 .744 .733 r
.19894 .5122 .20012 .51354 .20226 .50891 .20092 .50921 Mtetra
.968 .802 .624 r
.20092 .50921 .20226 .50891 .22371 .30378 .2033 .50209 Mtetra
0 0 .106 r
.2033 .50209 .22371 .30378 .22598 .29665 .22414 .30308 Mtetra
.692 .387 .455 r
.22414 .30308 .22598 .29665 .22754 .29693 .22533 .30722 Mtetra
.935 .668 .508 r
.22533 .30722 .22754 .29693 .21188 .47884 .20818 .50414 Mtetra
.578 .319 .488 r
.20818 .50414 .21188 .47884 .2108 .50814 .20949 .5082 Mtetra
.559 0 0 r
.20949 .5082 .2108 .50814 .21233 .50995 .2111 .50912 Mtetra
.565 .787 .982 r
.2111 .50912 .21233 .50995 .21406 .50962 .21284 .50875 Mtetra
.676 .808 .946 r
.21284 .50875 .21406 .50962 .21584 .5088 .21461 .50804 Mtetra
.604 .816 .981 r
.21461 .50804 .21584 .5088 .21761 .50813 .21636 .50755 Mtetra
.533 .83 .999 r
.21636 .50755 .21761 .50813 .21936 .50766 .2181 .50716 Mtetra
.651 .882 .983 r
.2181 .50716 .21936 .50766 .22112 .50708 .21987 .50646 Mtetra
.825 .865 .876 r
.21987 .50646 .22112 .50708 .22288 .50648 .22173 .50492 Mtetra
.843 .726 .735 r
.22173 .50492 .22288 .50648 .22466 .50566 .22369 .5021 Mtetra
.824 .629 .639 r
.22369 .5021 .22466 .50566 .22651 .5042 .22588 .49676 Mtetra
.943 .681 .51 r
.22588 .49676 .22651 .5042 .22861 .49987 .24565 .29514 Mtetra
.534 .302 .51 r
.24565 .29514 .22861 .49987 .24849 .29486 .24789 .28804 Mtetra
.681 .483 .612 r
.24789 .28804 .24849 .29486 .25078 .28713 .24977 .28496 Mtetra
.73 .635 .752 r
.24977 .28496 .25078 .28713 .25259 .2848 .2515 .28351 Mtetra
.643 .705 .892 r
.2515 .28351 .25259 .2848 .25426 .2841 .25316 .28297 Mtetra
.559 .709 .941 r
.25316 .28297 .25426 .2841 .25589 .28383 .25479 .28272 Mtetra
.62 .733 .927 r
.25479 .28272 .25589 .28383 .25753 .28347 .25643 .28228 Mtetra
.692 .738 .887 r
.25643 .28228 .25753 .28347 .2592 .28284 .25811 .28152 Mtetra
.693 .718 .868 r
.25811 .28152 .2592 .28284 .26086 .28219 .25979 .28073 Mtetra
.697 .698 .847 r
.25979 .28073 .26086 .28219 .26254 .2815 .26147 .27989 Mtetra
.684 .672 .832 r
.26147 .27989 .26254 .2815 .26421 .2808 .26316 .27908 Mtetra
.635 .639 .837 r
.26316 .27908 .26421 .2808 .26588 .28019 .26482 .27854 Mtetra
.458 .567 .877 r
.26482 .27854 .26588 .28019 .26754 .2796 .26642 .27869 Mtetra
.467 0 0 r
.26642 .27869 .26754 .2796 .2692 .27916 .26794 .27996 Mtetra
.827 .433 .305 r
.26794 .27996 .2692 .27916 .27081 .27927 .26928 .2833 Mtetra
.947 .677 .493 r
.26928 .2833 .27081 .27927 .27224 .28163 .25456 .48321 Mtetra
.532 .296 .502 r
.25456 .48321 .27224 .28163 .25744 .48469 .25568 .4908 Mtetra
.631 .317 .421 r
.25568 .4908 .25744 .48469 .25851 .49301 .25722 .4932 Mtetra
.46 0 0 r
.25722 .4932 .25851 .49301 .26011 .49467 .25891 .49383 Mtetra
.586 .796 .979 r
.25891 .49383 .26011 .49467 .26188 .49431 .26068 .4934 Mtetra
.691 .808 .937 r
.26068 .4934 .26188 .49431 .2637 .49343 .26249 .49262 Mtetra
.66 .822 .961 r
.26249 .49262 .2637 .49343 .26551 .49258 .26429 .49195 Mtetra
.556 .83 .997 r
.26429 .49195 .26551 .49258 .26729 .49204 .26607 .49152 Mtetra
.644 .88 .984 r
.26607 .49152 .26729 .49204 .26909 .49142 .26787 .49083 Mtetra
.824 .878 .884 r
.26787 .49083 .26909 .49142 .27091 .49055 .26974 .48929 Mtetra
.872 .76 .736 r
.26974 .48929 .27091 .49055 .27274 .48939 .27172 .48624 Mtetra
.833 .644 .647 r
.27172 .48624 .27274 .48939 .27459 .48816 .27385 .48129 Mtetra
.764 .547 .603 r
.27385 .48129 .27459 .48816 .2764 .4874 .27607 .47499 Mtetra
.517 .33 .566 r
.27607 .47499 .2764 .4874 .27817 .48722 .27781 .4752 Mtetra
.522 .335 .569 r
.27781 .4752 .27817 .48722 .27997 .48652 .27955 .47526 Mtetra
.943 .676 .501 r
.27955 .47526 .27997 .48652 .28194 .48365 .29537 .28486 Mtetra
.549 .315 .513 r
.29537 .28486 .28194 .48365 .29833 .28314 .29804 .271 Mtetra
.645 .428 .574 r
.29804 .271 .29833 .28314 .30098 .26936 .29998 .267 Mtetra
.764 .639 .723 r
.29998 .267 .30098 .26936 .30284 .26632 .30177 .26496 Mtetra
.69 .715 .868 r
.30177 .26496 .30284 .26632 .30455 .26544 .30348 .26418 Mtetra
.616 .706 .909 r
.30348 .26418 .30455 .26544 .30623 .26508 .30515 .26375 Mtetra
.588 .682 .906 r
.30515 .26375 .30623 .26508 .3079 .26481 .30683 .26342 Mtetra
.613 .682 .891 r
.30683 .26342 .3079 .26481 .30958 .26429 .30851 .263 Mtetra
.609 .699 .907 r
.30851 .263 .30958 .26429 .31127 .26378 .31019 .2626 Mtetra
.622 .723 .919 r
.31019 .2626 .31127 .26378 .31296 .26325 .31188 .26213 Mtetra
.651 .746 .919 r
.31188 .26213 .31296 .26325 .31466 .26268 .31357 .26156 Mtetra
.667 .749 .912 r
.31357 .26156 .31466 .26268 .31636 .26208 .31528 .26092 Mtetra
.702 .751 .89 r
.31528 .26092 .31636 .26208 .31806 .26141 .31699 .2601 Mtetra
.728 .734 .856 r
.31699 .2601 .31806 .26141 .31977 .26064 .31872 .25909 Mtetra
.68 .683 .846 r
.31872 .25909 .31977 .26064 .32148 .25993 .32043 .25832 Mtetra
.522 .606 .878 r
.32043 .25832 .32148 .25993 .32318 .25942 .3221 .25825 Mtetra
0 .045 .56 r
.3221 .25825 .32318 .25942 .32485 .25927 .32366 .25976 Mtetra
.843 .434 .263 r
.32366 .25976 .32485 .25927 .32652 .25922 .32511 .2632 Mtetra
.828 .507 .446 r
.32511 .2632 .32652 .25922 .32821 .25885 .32624 .27155 Mtetra
.432 .175 .422 r
.32624 .27155 .32821 .25885 .32995 .25779 .32804 .26966 Mtetra
.433 .173 .418 r
.32804 .26966 .32995 .25779 .33166 .25718 .32983 .26792 Mtetra
.944 .667 .483 r
.32983 .26792 .33166 .25718 .33326 .25825 .31957 .45875 Mtetra
.536 .299 .503 r
.31957 .45875 .33326 .25825 .32265 .45749 .32073 .46875 Mtetra
.606 .321 .457 r
.32073 .46875 .32265 .45749 .32361 .47101 .32233 .47183 Mtetra
.627 .137 .069 r
.32233 .47183 .32361 .47101 .32526 .47344 .32406 .47299 Mtetra
.447 .825 .99 r
.32406 .47299 .32526 .47344 .32707 .47324 .32588 .47267 Mtetra
.707 .887 .963 r
.32588 .47267 .32707 .47324 .32892 .4724 .32773 .47176 Mtetra
.82 .878 .888 r
.32773 .47176 .32892 .4724 .33078 .47133 .32962 .47024 Mtetra
.861 .794 .783 r
.32962 .47024 .33078 .47133 .33262 .4706 .33156 .46786 Mtetra
.827 .657 .672 r
.33156 .46786 .33262 .4706 .3345 .46937 .33359 .46395 Mtetra
.868 .63 .575 r
.33359 .46395 .3345 .46937 .33645 .4667 .33611 .45153 Mtetra
.945 .672 .49 r
.33611 .45153 .33645 .4667 .33898 .45392 .34928 .25241 Mtetra
.527 .296 .508 r
.34928 .25241 .33898 .45392 .35217 .2513 .35121 .24826 Mtetra
.743 .596 .693 r
.35121 .24826 .35217 .2513 .35407 .24754 .35302 .24606 Mtetra
.704 .703 .846 r
.35302 .24606 .35407 .24754 .35582 .2465 .35476 .24514 Mtetra
.636 .701 .892 r
.35476 .24514 .35582 .2465 .35753 .24602 .35648 .24461 Mtetra
.594 .675 .897 r
.35648 .24461 .35753 .24602 .35924 .24576 .35819 .24426 Mtetra
.621 .671 .877 r
.35819 .24426 .35924 .24576 .36096 .24519 .35991 .2438 Mtetra
.622 .689 .892 r
.35991 .2438 .36096 .24519 .36269 .24462 .36163 .24333 Mtetra
.651 .718 .897 r
.36163 .24333 .36269 .24462 .36442 .24401 .36336 .24274 Mtetra
.727 .745 .866 r
.36336 .24274 .36442 .24401 .36616 .24325 .36511 .24175 Mtetra
.689 .696 .851 r
.36511 .24175 .36616 .24325 .36789 .24254 .36686 .24092 Mtetra
.588 .639 .869 r
.36686 .24092 .36789 .24254 .36962 .24197 .36857 .2406 Mtetra
0 .238 .75 r
.36857 .2406 .36962 .24197 .37134 .24177 .37021 .24183 Mtetra
.822 .363 .132 r
.37021 .24183 .37134 .24177 .37305 .24167 .37179 .24452 Mtetra
.822 .479 .407 r
.37179 .24452 .37305 .24167 .37477 .24143 .37319 .25067 Mtetra
.455 .18 .406 r
.37319 .25067 .37477 .24143 .37653 .24035 .37495 .24975 Mtetra
.412 .144 .395 r
.37495 .24975 .37653 .24035 .37827 .23962 .37675 .24804 Mtetra
.625 .326 .444 r
.37675 .24804 .37827 .23962 .37997 .23996 .37832 .25101 Mtetra
.949 .667 .47 r
.37832 .25101 .37997 .23996 .3813 .24811 .37067 .44997 Mtetra
.524 .289 .5 r
.37067 .44997 .3813 .24811 .37355 .45295 .37232 .45399 Mtetra
.684 .223 .152 r
.37232 .45399 .37355 .45295 .37523 .4564 .37408 .45562 Mtetra
.504 .784 .995 r
.37408 .45562 .37523 .4564 .37707 .45632 .37593 .45534 Mtetra
.666 .8 .947 r
.37593 .45534 .37707 .45632 .37895 .45556 .37781 .45464 Mtetra
.709 .82 .934 r
.37781 .45464 .37895 .45556 .38084 .45451 .37969 .45374 Mtetra
.631 .834 .979 r
.37969 .45374 .38084 .45451 .38271 .45388 .38156 .45312 Mtetra
.631 .835 .979 r
.38156 .45312 .38271 .45388 .38459 .45326 .38344 .4525 Mtetra
.625 .835 .981 r
.38344 .4525 .38459 .45326 .38646 .45264 .38531 .45189 Mtetra
.535 .806 .996 r
.38531 .45189 .38646 .45264 .38833 .4521 .38718 .45153 Mtetra
.589 .862 .994 r
.38718 .45153 .38833 .4521 .39021 .4515 .38905 .45095 Mtetra
.723 .901 .959 r
.38905 .45095 .39021 .4515 .39209 .45078 .39095 .44996 Mtetra
.894 .833 .778 r
.39095 .44996 .39209 .45078 .39399 .44965 .39291 .4473 Mtetra
.854 .687 .674 r
.39291 .4473 .39399 .44965 .39589 .4484 .39493 .44316 Mtetra
.832 .607 .597 r
.39493 .44316 .39589 .4484 .3978 .44718 .3971 .43511 Mtetra
.663 .443 .576 r
.3971 .43511 .3978 .44718 .39969 .44646 .39914 .43029 Mtetra
.506 .312 .551 r
.39914 .43029 .39969 .44646 .40157 .4459 .40097 .4309 Mtetra
.441 .265 .546 r
.40097 .4309 .40157 .4459 .40345 .44541 .40273 .43337 Mtetra
.541 .351 .572 r
.40273 .43337 .40345 .44541 .40533 .44482 .40461 .43293 Mtetra
.541 .351 .573 r
.40461 .43293 .40533 .44482 .40722 .44422 .40648 .43249 Mtetra
.543 .353 .574 r
.40648 .43249 .40722 .44422 .40911 .44361 .40836 .43202 Mtetra
.463 .294 .566 r
.40836 .43202 .40911 .44361 .41098 .44357 .41017 .43349 Mtetra
.535 .355 .584 r
.41017 .43349 .41098 .44357 .41287 .44306 .41204 .4333 Mtetra
.642 .437 .589 r
.41204 .4333 .41287 .44306 .41479 .44166 .41402 .43018 Mtetra
.956 .677 .467 r
.41402 .43018 .41479 .44166 .41692 .4339 .42268 .22752 Mtetra
.529 .298 .508 r
.42268 .22752 .41692 .4339 .42557 .22565 .42461 .22199 Mtetra
.757 .583 .662 r
.42461 .22199 .42557 .22565 .42749 .22062 .42646 .21904 Mtetra
.723 .703 .831 r
.42646 .21904 .42749 .22062 .42928 .21932 .42825 .21796 Mtetra
.651 .711 .892 r
.42825 .21796 .42928 .21932 .43105 .21873 .43002 .21736 Mtetra
.591 .683 .906 r
.43002 .21736 .43105 .21873 .43281 .2185 .43179 .217 Mtetra
.617 .674 .881 r
.43179 .217 .43281 .2185 .43459 .21796 .43356 .21654 Mtetra
.614 .686 .894 r
.43356 .21654 .43459 .21796 .43636 .2174 .43533 .2161 Mtetra
.616 .707 .91 r
.43533 .2161 .43636 .2174 .43814 .21684 .4371 .21564 Mtetra
.647 .738 .915 r
.4371 .21564 .43814 .21684 .43992 .21623 .43888 .21505 Mtetra
.664 .747 .912 r
.43888 .21505 .43992 .21623 .4417 .2156 .44067 .21439 Mtetra
.678 .747 .903 r
.44067 .21439 .4417 .2156 .44348 .21493 .44245 .21366 Mtetra
.734 .754 .869 r
.44245 .21366 .44348 .21493 .44527 .21414 .44425 .21261 Mtetra
.702 .704 .849 r
.44425 .21261 .44527 .21414 .44705 .21337 .44604 .21169 Mtetra
.638 .657 .852 r
.44604 .21169 .44705 .21337 .44884 .21269 .44782 .21111 Mtetra
.156 .408 .851 r
.44782 .21111 .44884 .21269 .45062 .21241 .44957 .21199 Mtetra
.759 .245 0 r
.44957 .21199 .45062 .21241 .45239 .21227 .45129 .21424 Mtetra
.843 .476 .358 r
.45129 .21424 .45239 .21227 .45417 .21216 .45293 .21993 Mtetra
.562 .263 .419 r
.45293 .21993 .45417 .21216 .45597 .21114 .45469 .2212 Mtetra
.405 .143 .4 r
.45469 .2212 .45597 .21114 .45777 .21025 .45652 .21915 Mtetra
.5 .216 .415 r
.45652 .21915 .45777 .21025 .45955 .21006 .4583 .21912 Mtetra
.958 .669 .444 r
.4583 .21912 .45955 .21006 .46124 .21465 .45581 .41992 Mtetra
.526 .29 .5 r
.45581 .41992 .46124 .21465 .45878 .42281 .45761 .42505 Mtetra
.684 .282 .278 r
.45761 .42505 .45878 .42281 .4606 .42772 .45948 .42716 Mtetra
.255 .705 .957 r
.45948 .42716 .4606 .42772 .4625 .42816 .4614 .4272 Mtetra
.639 .803 .961 r
.4614 .4272 .4625 .42816 .46443 .42754 .46333 .42657 Mtetra
.704 .819 .937 r
.46333 .42657 .46443 .42754 .46637 .4265 .46527 .42567 Mtetra
.579 .809 .987 r
.46527 .42567 .46637 .4265 .4683 .42585 .4672 .4252 Mtetra
.575 .846 .996 r
.4672 .4252 .4683 .42585 .47023 .42525 .46913 .42467 Mtetra
.682 .894 .974 r
.46913 .42467 .47023 .42525 .47217 .42454 .47107 .42379 Mtetra
.859 .873 .848 r
.47107 .42379 .47217 .42454 .47411 .42387 .47303 .42185 Mtetra
.849 .711 .71 r
.47303 .42185 .47411 .42387 .47605 .42287 .47501 .41859 Mtetra
.842 .625 .609 r
.47501 .41859 .47605 .42287 .478 .42109 .47703 .41187 Mtetra
.964 .679 .445 r
.47703 .41187 .478 .42109 .48002 .41491 .48188 .20591 Mtetra
.529 .298 .508 r
.48188 .20591 .48002 .41491 .48473 .20517 .48377 .20022 Mtetra
.71 .526 .638 r
.48377 .20022 .48473 .20517 .48661 .1993 .48561 .1974 Mtetra
.716 .666 .799 r
.48561 .1974 .48661 .1993 .48844 .19758 .48743 .19623 Mtetra
.625 .706 .904 r
.48743 .19623 .48844 .19758 .49025 .19695 .48924 .19572 Mtetra
.547 .698 .939 r
.48924 .19572 .49025 .19695 .49206 .19672 .49105 .19549 Mtetra
.62 .728 .924 r
.49105 .19549 .49206 .19672 .49387 .19623 .49286 .195 Mtetra
.658 .742 .912 r
.49286 .195 .49387 .19623 .49569 .1956 .49468 .19435 Mtetra
.673 .744 .904 r
.49468 .19435 .49569 .1956 .49751 .19494 .4965 .19363 Mtetra
.728 .751 .871 r
.4965 .19363 .49751 .19494 .49933 .19414 .49832 .1926 Mtetra
.713 .711 .846 r
.49832 .1926 .49933 .19414 .50115 .19331 .50015 .1916 Mtetra
.656 .663 .845 r
.50015 .1916 .50115 .19331 .50297 .19258 .50197 .1909 Mtetra
.424 .554 .882 r
.50197 .1909 .50297 .19258 .50479 .19186 .50379 .19117 Mtetra
.482 0 0 r
.50379 .19117 .50479 .19186 .50662 .19143 .5056 .19261 Mtetra
.831 .424 .272 r
.5056 .19261 .50662 .19143 .50844 .19165 .5074 .19672 Mtetra
.966 .673 .42 r
.5074 .19672 .50844 .19165 .51024 .19525 .50816 .40169 Mtetra
.527 .291 .5 r
.50816 .40169 .51024 .19525 .51119 .40388 .51009 .40745 Mtetra
.641 .275 .333 r
.51009 .40745 .51119 .40388 .51312 .4098 .51204 .40945 Mtetra
.012 .567 .821 r
.51204 .40945 .51312 .4098 .51508 .4107 .51401 .40971 Mtetra
.642 .802 .96 r
.51401 .40971 .51508 .4107 .51705 .41013 .51597 .40905 Mtetra
.765 .817 .894 r
.51597 .40905 .51705 .41013 .51902 .40901 .51794 .40779 Mtetra
.835 .801 .818 r
.51794 .40779 .51902 .40901 .52099 .40817 .51992 .4058 Mtetra
.827 .684 .705 r
.51992 .4058 .52099 .40817 .52296 .40727 .52189 .40268 Mtetra
.825 .61 .611 r
.52189 .40268 .52296 .40727 .52493 .40567 .52386 .39649 Mtetra
.967 .678 .43 r
.52386 .39649 .52493 .40567 .5269 .40049 .52577 .1905 Mtetra
.53 .298 .508 r
.52577 .1905 .5269 .40049 .52861 .19034 .52761 .18436 Mtetra
.692 .497 .62 r
.52761 .18436 .52861 .19034 .53044 .18353 .52945 .18139 Mtetra
.72 .647 .775 r
.52945 .18139 .53044 .18353 .53228 .18146 .53129 .18007 Mtetra
.618 .698 .902 r
.53129 .18007 .53228 .18146 .53412 .1808 .53313 .17958 Mtetra
.519 .688 .944 r
.53313 .17958 .53412 .1808 .53597 .18061 .53498 .17943 Mtetra
.567 .717 .943 r
.53498 .17943 .53597 .18061 .53782 .18029 .53683 .17911 Mtetra
.623 .742 .932 r
.53683 .17911 .53782 .18029 .53966 .17979 .53867 .1786 Mtetra
.633 .744 .928 r
.53867 .1786 .53966 .17979 .54151 .17927 .54052 .17805 Mtetra
.641 .74 .921 r
.54052 .17805 .54151 .17927 .54336 .17873 .54237 .17746 Mtetra
.648 .735 .913 r
.54237 .17746 .54336 .17873 .54521 .17815 .54423 .17685 Mtetra
.655 .731 .905 r
.54423 .17685 .54521 .17815 .54707 .17754 .54608 .1762 Mtetra
.661 .727 .898 r
.54608 .1762 .54707 .17754 .54892 .17688 .54793 .17552 Mtetra
.667 .726 .893 r
.54793 .17552 .54892 .17688 .55077 .17617 .54979 .17481 Mtetra
.673 .727 .89 r
.54979 .17481 .55077 .17617 .55263 .17543 .55164 .17407 Mtetra
.675 .729 .89 r
.55164 .17407 .55263 .17543 .55448 .17465 .5535 .17331 Mtetra
.68 .736 .892 r
.5535 .17331 .55448 .17465 .55634 .17384 .55536 .17254 Mtetra
.689 .745 .894 r
.55536 .17254 .55634 .17384 .5582 .17301 .55722 .17172 Mtetra
.708 .754 .888 r
.55722 .17172 .5582 .17301 .56006 .17216 .55908 .1708 Mtetra
.716 .745 .875 r
.55908 .1708 .56006 .17216 .56192 .1713 .56093 .16982 Mtetra
.707 .723 .862 r
.56093 .16982 .56192 .1713 .56378 .17045 .56279 .16886 Mtetra
.688 .699 .855 r
.56279 .16886 .56378 .17045 .56564 .16962 .56466 .16799 Mtetra
.671 .686 .855 r
.56466 .16799 .56564 .16962 .5675 .16883 .56652 .16721 Mtetra
.666 .686 .86 r
.56652 .16721 .5675 .16883 .56937 .16805 .56839 .16647 Mtetra
.665 .691 .864 r
.56839 .16647 .56937 .16805 .57123 .1673 .57025 .16574 Mtetra
.665 .694 .868 r
.57025 .16574 .57123 .1673 .5731 .16656 .57212 .16501 Mtetra
.663 .696 .87 r
.57212 .16501 .5731 .16656 .57497 .16583 .57399 .16429 Mtetra
.662 .696 .871 r
.57399 .16429 .57497 .16583 .57684 .16511 .57586 .16358 Mtetra
.662 .697 .872 r
.57586 .16358 .57684 .16511 .57871 .1644 .57774 .16287 Mtetra
.661 .698 .873 r
.57774 .16287 .57871 .1644 .58059 .16369 .57961 .16216 Mtetra
.66 .698 .874 r
.57961 .16216 .58059 .16369 .58246 .16299 .58149 .16146 Mtetra
.58149 .16146 .58246 .16299 .58434 .16229 .58336 .16076 Mtetra
.659 .698 .874 r
.58336 .16076 .58434 .16229 .58621 .16159 .58524 .16006 Mtetra
.659 .698 .875 r
.58524 .16006 .58621 .16159 .58809 .1609 .58712 .15937 Mtetra
.659 .697 .875 r
.58712 .15937 .58809 .1609 .58997 .1602 .589 .15867 Mtetra
.589 .15867 .58997 .1602 .59185 .15951 .59088 .15798 Mtetra
.59088 .15798 .59185 .15951 .59374 .15882 .59276 .15728 Mtetra
.658 .697 .875 r
.59276 .15728 .59374 .15882 .59562 .15812 .59465 .15659 Mtetra
.658 .697 .874 r
.59465 .15659 .59562 .15812 .5975 .15743 .59653 .15589 Mtetra
.59653 .15589 .5975 .15743 .59939 .15673 .59842 .1552 Mtetra
.59842 .1552 .59939 .15673 .60128 .15604 .60031 .1545 Mtetra
.658 .696 .874 r
.60031 .1545 .60128 .15604 .60317 .15535 .6022 .15381 Mtetra
.6022 .15381 .60317 .15535 .60506 .15466 .60409 .15311 Mtetra
.657 .696 .874 r
.60409 .15311 .60506 .15466 .60695 .15396 .60598 .15242 Mtetra
.60598 .15242 .60695 .15396 .60884 .15327 .60788 .15173 Mtetra
.657 .695 .874 r
.60788 .15173 .60884 .15327 .61074 .15259 .60977 .15104 Mtetra
.656 .695 .874 r
.60977 .15104 .61074 .15259 .61263 .15191 .61167 .15035 Mtetra
.655 .694 .874 r
.61167 .15035 .61263 .15191 .61453 .15123 .61356 .14967 Mtetra
.655 .693 .873 r
.61356 .14967 .61453 .15123 .61643 .15056 .61546 .14899 Mtetra
.654 .691 .872 r
.61546 .14899 .61643 .15056 .61833 .1499 .61736 .1483 Mtetra
.648 .685 .871 r
.61736 .1483 .61833 .1499 .62023 .14925 .61927 .14765 Mtetra
.634 .677 .874 r
.61927 .14765 .62023 .14925 .62213 .14863 .62117 .14707 Mtetra
.614 .675 .885 r
.62117 .14707 .62213 .14863 .62404 .14804 .62308 .14659 Mtetra
.611 .693 .901 r
.62308 .14659 .62404 .14804 .62595 .14745 .625 .14612 Mtetra
.622 .719 .916 r
.625 .14612 .62595 .14745 .62786 .14685 .62691 .1456 Mtetra
.646 .744 .921 r
.62691 .1456 .62786 .14685 .62977 .14623 .62882 .14497 Mtetra
.656 .747 .917 r
.62882 .14497 .62977 .14623 .63168 .1456 .63073 .1443 Mtetra
.658 .741 .911 r
.63073 .1443 .63168 .1456 .63359 .14495 .63264 .14362 Mtetra
.655 .733 .907 r
.63264 .14362 .63359 .14495 .63551 .1443 .63456 .14295 Mtetra
.665 .734 .901 r
.63456 .14295 .63551 .1443 .63742 .14362 .63647 .14223 Mtetra
.684 .735 .889 r
.63647 .14223 .63742 .14362 .63933 .14288 .63838 .14141 Mtetra
.704 .73 .87 r
.63838 .14141 .63933 .14288 .64124 .14207 .64029 .14046 Mtetra
.7 .708 .853 r
.64029 .14046 .64124 .14207 .64315 .14123 .64219 .1395 Mtetra
.7 .69 .838 r
.64219 .1395 .64315 .14123 .64507 .14036 .6441 .13851 Mtetra
.696 .674 .824 r
.6441 .13851 .64507 .14036 .64698 .13946 .64601 .1375 Mtetra
.655 .641 .824 r
.64601 .1375 .64698 .13946 .64889 .13865 .64793 .13674 Mtetra
.556 .598 .851 r
.64793 .13674 .64889 .13865 .65081 .13789 .64987 .13654 Mtetra
.128 .433 .872 r
.64987 .13654 .65081 .13789 .65274 .13721 .65186 .13744 Mtetra
.745 .228 0 r
.65186 .13744 .65274 .13721 .65468 .13699 .65392 .13982 Mtetra
.903 .543 .347 r
.65392 .13982 .65468 .13699 .65669 .13819 .65643 .15213 Mtetra
.964 .652 .378 r
.65643 .15213 .65669 .13819 .65916 .14937 .66739 .35242 Mtetra
.522 .286 .499 r
.66739 .35242 .65916 .14937 .67056 .35521 .66964 .35564 Mtetra
.519 0 0 r
.66964 .35564 .67056 .35521 .6728 .35799 .6718 .35665 Mtetra
.588 .724 .937 r
.6718 .35665 .6728 .35799 .6749 .35771 .67389 .35621 Mtetra
.672 .732 .895 r
.67389 .35621 .6749 .35771 .67697 .3568 .67597 .35539 Mtetra
.643 .735 .915 r
.67597 .35539 .67697 .3568 .67905 .35592 .67806 .35472 Mtetra
.412 .663 .963 r
.67806 .35472 .67905 .35592 .68116 .35585 .68018 .35481 Mtetra
.581 .781 .975 r
.68018 .35481 .68116 .35585 .68325 .35524 .68228 .35433 Mtetra
.859 .879 .852 r
.68228 .35433 .68325 .35524 .68527 .35316 .68431 .35234 Mtetra
.99 .777 .524 r
.68431 .35234 .68527 .35316 .68693 .34395 .68597 .3433 Mtetra
.977 .676 .349 r
.68597 .3433 .68693 .34395 .67803 .13144 .67709 .12986 Mtetra
.929 .765 .657 r
.67709 .12986 .67803 .13144 .67978 .12705 .67884 .12544 Mtetra
.697 .709 .857 r
.67884 .12544 .67978 .12705 .68171 .12602 .68077 .12449 Mtetra
.562 .66 .902 r
.68077 .12449 .68171 .12602 .68367 .12564 .68274 .12423 Mtetra
.496 .646 .924 r
.68274 .12423 .68367 .12564 .68564 .12548 .68472 .12418 Mtetra
.648 .74 .917 r
.68472 .12418 .68564 .12548 .68759 .12482 .68667 .12353 Mtetra
.665 .749 .913 r
.68667 .12353 .68759 .12482 .68954 .12413 .68862 .1228 Mtetra
.703 .758 .894 r
.68862 .1228 .68954 .12413 .69149 .12329 .69056 .12188 Mtetra
.775 .768 .847 r
.69056 .12188 .69149 .12329 .69341 .122 .69247 .12046 Mtetra
.7 .721 .866 r
.69247 .12046 .69341 .122 .69535 .12115 .69441 .11951 Mtetra
.442 .576 .892 r
.69441 .11951 .69535 .12115 .69736 .12144 .69642 .11971 Mtetra
.794 .407 0 r
.69642 .11971 .69736 .12144 .69973 .12768 .69878 .12587 Mtetra
.974 .663 .317 r
.69878 .12587 .69973 .12768 .71447 .3402 .71352 .33924 Mtetra
.743 .275 0 r
.71352 .33924 .71447 .3402 .71686 .3441 .71591 .3432 Mtetra
.427 .737 .991 r
.71591 .3432 .71686 .3441 .71901 .34396 .71806 .34309 Mtetra
.719 .873 .954 r
.71806 .34309 .71901 .34396 .72111 .343 .72015 .34203 Mtetra
.84 .874 .867 r
.72015 .34203 .72111 .343 .72319 .34166 .7222 .3402 Mtetra
.861 .796 .785 r
.7222 .3402 .72319 .34166 .7253 .34092 .72421 .33774 Mtetra
.831 .653 .661 r
.72421 .33774 .7253 .34092 .72739 .3397 .72612 .33374 Mtetra
.886 .624 .537 r
.72612 .33374 .72739 .3397 .7294 .33728 .7275 .32161 Mtetra
.97 .66 .363 r
.7275 .32161 .7294 .33728 .73084 .32614 .71634 .11714 Mtetra
.526 .295 .507 r
.71634 .11714 .73084 .32614 .71913 .11633 .71808 .11277 Mtetra
.737 .58 .679 r
.71808 .11277 .71913 .11633 .72086 .11204 .71994 .11036 Mtetra
.677 .693 .858 r
.71994 .11036 .72086 .11204 .72281 .11091 .7219 .10952 Mtetra
.595 .702 .918 r
.7219 .10952 .72281 .11091 .72479 .1104 .72389 .10909 Mtetra
.551 .697 .936 r
.72389 .10909 .72479 .1104 .7268 .11016 .7259 .10882 Mtetra
.701 .758 .896 r
.7259 .10882 .7268 .11016 .72877 .10939 .72786 .1079 Mtetra
.67 .72 .886 r
.72786 .1079 .72877 .10939 .73075 .10865 .72984 .10712 Mtetra
.595 .678 .899 r
.72984 .10712 .73075 .10865 .73273 .10799 .73184 .1067 Mtetra
.192 .489 .901 r
.73184 .1067 .73273 .10799 .73471 .10723 .73392 .10744 Mtetra
.699 .159 0 r
.73392 .10744 .73471 .10723 .73672 .1069 .73611 .1096 Mtetra
.891 .511 .31 r
.73611 .1096 .73672 .1069 .7388 .10749 .7389 .11992 Mtetra
.967 .646 .336 r
.7389 .11992 .7388 .10749 .74146 .11595 .7559 .32354 Mtetra
.522 .286 .499 r
.7559 .32354 .74146 .11595 .75911 .32567 .75835 .327 Mtetra
.6 .109 .061 r
.75835 .327 .75911 .32567 .76157 .32925 .76065 .32833 Mtetra
.489 .771 .994 r
.76065 .32833 .76157 .32925 .76377 .32916 .76283 .32806 Mtetra
.688 .82 .946 r
.76283 .32806 .76377 .32916 .76591 .32832 .76497 .32715 Mtetra
.793 .838 .886 r
.76497 .32715 .76591 .32832 .76801 .327 .76706 .32562 Mtetra
.89 .743 .693 r
.08482 .54892 .08606 .55002 .08793 .54795 .08698 .54467 Mtetra
.934 .683 .536 r
.08698 .54467 .08793 .54795 .08997 .54459 .11394 .34897 Mtetra
.552 .318 .515 r
.11394 .34897 .08997 .54459 .09261 .53653 .11725 .33501 Mtetra
.523 .293 .508 r
.11725 .33501 .09261 .53653 .11964 .33819 .11906 .33258 Mtetra
.63 .459 .633 r
.11906 .33258 .11964 .33819 .12173 .33359 .12075 .33117 Mtetra
.668 .581 .749 r
.12075 .33117 .12173 .33359 .12355 .33116 .12237 .33024 Mtetra
.667 .776 .93 r
.12237 .33024 .12355 .33116 .12515 .33037 .12395 .32965 Mtetra
.598 .803 .978 r
.12395 .32965 .12515 .33037 .1267 .33003 .12551 .32923 Mtetra
.575 .778 .975 r
.12551 .32923 .1267 .33003 .12823 .32992 .12707 .3289 Mtetra
.657 .751 .92 r
.12707 .3289 .12823 .32992 .1298 .32943 .12865 .32834 Mtetra
.671 .742 .903 r
.12865 .32834 .1298 .32943 .13138 .32885 .13024 .32772 Mtetra
.68 .737 .893 r
.13024 .32772 .13138 .32885 .13297 .3282 .13183 .32705 Mtetra
.751 .748 .849 r
.13183 .32705 .13297 .3282 .13461 .32719 .13348 .32595 Mtetra
.71 .726 .863 r
.13348 .32595 .13461 .32719 .13624 .32631 .1351 .32511 Mtetra
.587 .694 .916 r
.1351 .32511 .13624 .32631 .13782 .32579 .13666 .3248 Mtetra
.82 .345 0 r
.13666 .3248 .13782 .32579 .13926 .32639 .1379 .32701 Mtetra
.915 .619 .47 r
.1379 .32701 .13926 .32639 .14055 .32822 .13791 .33938 Mtetra
.924 .665 .527 r
.13791 .33938 .14055 .32822 .14137 .33404 .11557 .53517 Mtetra
.52 .286 .5 r
.11557 .53517 .14137 .33404 .11885 .53269 .11696 .53706 Mtetra
.53 .198 .349 r
.11696 .53706 .11885 .53269 .11997 .5369 .11853 .53754 Mtetra
.186 0 0 r
.11853 .53754 .11997 .5369 .1214 .53853 .12017 .53742 Mtetra
.625 .74 .929 r
.12017 .53742 .1214 .53853 .12305 .53835 .12186 .53694 Mtetra
.669 .702 .871 r
.12186 .53694 .12305 .53835 .12478 .53757 .12357 .53625 Mtetra
.686 .721 .876 r
.12357 .53625 .12478 .53757 .12653 .53657 .12529 .53549 Mtetra
.495 .702 .962 r
.12529 .53549 .12653 .53657 .12819 .5363 .12694 .53538 Mtetra
.544 .754 .974 r
.12694 .53538 .12819 .5363 .12986 .53603 .12861 .5351 Mtetra
.712 .797 .917 r
.12861 .5351 .12986 .53603 .13157 .53541 .13034 .53426 Mtetra
.879 .751 .717 r
.13034 .53426 .13157 .53541 .13342 .53357 .13239 .53078 Mtetra
.895 .675 .597 r
.13239 .53078 .13342 .53357 .13542 .53041 .13538 .51915 Mtetra
.93 .674 .53 r
.13538 .51915 .13542 .53041 .13784 .52369 .16014 .31993 Mtetra
.524 .294 .508 r
.16014 .31993 .13784 .52369 .16248 .324 .16201 .31702 Mtetra
.613 .431 .612 r
.16201 .31702 .16248 .324 .16463 .31864 .16372 .31556 Mtetra
.648 .536 .713 r
.16372 .31556 .16463 .31864 .16648 .31597 .16536 .31463 Mtetra
.683 .706 .864 r
.16536 .31463 .16648 .31597 .16814 .31484 .16699 .31391 Mtetra
.66 .775 .935 r
.16699 .31391 .16814 .31484 .16975 .31427 .16859 .31333 Mtetra
.641 .769 .941 r
.16859 .31333 .16975 .31427 .17133 .3139 .17019 .31282 Mtetra
.741 .76 .868 r
.17019 .31282 .17133 .3139 .17298 .31301 .17185 .31181 Mtetra
.718 .737 .866 r
.17185 .31181 .17298 .31301 .17462 .31212 .1735 .31092 Mtetra
.61 .707 .913 r
.1735 .31092 .17462 .31212 .17623 .31154 .17509 .31053 Mtetra
.707 .2 0 r
.17509 .31053 .17623 .31154 .17773 .31198 .17643 .31231 Mtetra
.912 .593 .428 r
.17643 .31231 .17773 .31198 .17909 .31363 .17706 .3207 Mtetra
.934 .672 .517 r
.17706 .3207 .17909 .31363 .18013 .31837 .15654 .52101 Mtetra
.521 .286 .5 r
.15654 .52101 .18013 .31837 .15992 .51749 .15794 .52334 Mtetra
.529 .218 .384 r
.15794 .52334 .15992 .51749 .16103 .52249 .15955 .52383 Mtetra
.345 0 0 r
.15955 .52383 .16103 .52249 .16249 .52439 .16122 .52373 Mtetra
.231 .666 .957 r
.16122 .52373 .16249 .52439 .16407 .52512 .16287 .52387 Mtetra
.54 .688 .935 r
.16287 .52387 .16407 .52512 .16575 .52499 .16455 .52367 Mtetra
.718 .734 .863 r
.16455 .52367 .16575 .52499 .16753 .52394 .16632 .52271 Mtetra
.891 .743 .692 r
.16632 .52271 .16753 .52394 .16965 .51965 .16844 .51852 Mtetra
.945 .688 .518 r
.16844 .51852 .16965 .51965 .19305 .31422 .19185 .31374 Mtetra
.943 .742 .601 r
.19185 .31374 .19305 .31422 .19555 .30531 .1944 .30446 Mtetra
.853 .799 .798 r
.1944 .30446 .19555 .30531 .19732 .30336 .19617 .30244 Mtetra
.658 .78 .938 r
.19617 .30244 .19732 .30336 .19893 .30285 .1978 .30186 Mtetra
.495 .708 .966 r
.1978 .30186 .19893 .30285 .2005 .30283 .19937 .30174 Mtetra
.683 .752 .903 r
.19937 .30174 .2005 .30283 .20212 .3023 .20101 .30106 Mtetra
.704 .728 .869 r
.20101 .30106 .20212 .3023 .20377 .30156 .20266 .30023 Mtetra
.608 .684 .896 r
.20266 .30023 .20377 .30156 .20539 .30106 .20427 .29985 Mtetra
0 .008 .523 r
.20427 .29985 .20539 .30106 .20693 .30134 .20569 .3013 Mtetra
.913 .57 .376 r
.20569 .3013 .20693 .30134 .20837 .30264 .20663 .3076 Mtetra
.94 .676 .509 r
.20663 .3076 .20837 .30264 .2096 .30599 .18779 .50941 Mtetra
.522 .287 .5 r
.18779 .50941 .2096 .30599 .19134 .50384 .18917 .51232 Mtetra
.528 .238 .419 r
.18917 .51232 .19134 .50384 .19231 .51099 .1908 .51285 Mtetra
.379 0 .084 r
.1908 .51285 .19231 .51099 .19377 .51324 .19251 .51269 Mtetra
.531 .834 .999 r
.19251 .51269 .19377 .51324 .1954 .51376 .19423 .5123 Mtetra
.648 .693 .878 r
.19423 .5123 .1954 .51376 .19714 .51333 .19598 .51171 Mtetra
.691 .685 .839 r
.19598 .51171 .19714 .51333 .19894 .5122 .19776 .51083 Mtetra
.779 .74 .817 r
.19776 .51083 .19894 .5122 .20092 .50921 .1996 .50932 Mtetra
.886 .959 .842 r
.1996 .50932 .20092 .50921 .2033 .50209 .20149 .50728 Mtetra
.246 0 .244 r
.20149 .50728 .2033 .50209 .22414 .30308 .20337 .50529 Mtetra
.516 .282 .499 r
.20337 .50529 .22414 .30308 .22533 .30722 .20506 .50533 Mtetra
.518 .284 .499 r
.20506 .50533 .22533 .30722 .20818 .50414 .20664 .50655 Mtetra
.587 .198 .273 r
.20664 .50655 .20818 .50414 .20949 .5082 .20825 .50749 Mtetra
.266 .675 .968 r
.20825 .50749 .20949 .5082 .2111 .50912 .20994 .50761 Mtetra
.608 .672 .886 r
.20994 .50761 .2111 .50912 .21284 .50875 .21168 .50719 Mtetra
.642 .678 .869 r
.21168 .50719 .21284 .50875 .21461 .50804 .21344 .50662 Mtetra
.576 .673 .906 r
.21344 .50662 .21461 .50804 .21636 .50755 .21517 .50633 Mtetra
.559 .704 .937 r
.21517 .50633 .21636 .50755 .2181 .50716 .2169 .50606 Mtetra
.689 .768 .912 r
.2169 .50606 .2181 .50716 .21987 .50646 .21868 .5053 Mtetra
.858 .768 .761 r
.21868 .5053 .21987 .50646 .22173 .50492 .22063 .50271 Mtetra
.893 .692 .624 r
.22063 .50271 .22173 .50492 .22369 .5021 .22301 .49537 Mtetra
.944 .682 .51 r
.22301 .49537 .22369 .5021 .22588 .49676 .24322 .29078 Mtetra
.527 .297 .508 r
.24322 .29078 .22588 .49676 .24565 .29514 .24522 .28639 Mtetra
.609 .415 .593 r
.24522 .28639 .24565 .29514 .24789 .28804 .24699 .28459 Mtetra
.655 .527 .695 r
.24699 .28459 .24789 .28804 .24977 .28496 .24869 .28344 Mtetra
.682 .684 .846 r
.24869 .28344 .24977 .28496 .2515 .28351 .25037 .28268 Mtetra
.638 .798 .959 r
.25037 .28268 .2515 .28351 .25316 .28297 .25202 .28214 Mtetra
.601 .788 .97 r
.25202 .28214 .25316 .28297 .25479 .28272 .25367 .28171 Mtetra
.65 .763 .932 r
.25367 .28171 .25479 .28272 .25643 .28228 .25533 .28115 Mtetra
.689 .751 .898 r
.25533 .28115 .25643 .28228 .25811 .28152 .257 .28042 Mtetra
.693 .756 .9 r
.257 .28042 .25811 .28152 .25979 .28073 .25868 .27967 Mtetra
.723 .769 .889 r
.25868 .27967 .25979 .28073 .26147 .27989 .26037 .27876 Mtetra
.72 .758 .883 r
.26037 .27876 .26147 .27989 .26316 .27908 .26206 .27787 Mtetra
.629 .717 .91 r
.26206 .27787 .26316 .27908 .26482 .27854 .26372 .27739 Mtetra
0 .312 .791 r
.26372 .27739 .26482 .27854 .26642 .27869 .26526 .27831 Mtetra
.909 .525 .279 r
.26526 .27831 .26642 .27869 .26794 .27996 .26649 .28297 Mtetra
.948 .679 .493 r
.26649 .28297 .26794 .27996 .26928 .2833 .25122 .48727 Mtetra
.525 .29 .5 r
.25122 .48727 .26928 .2833 .25456 .48321 .25259 .49167 Mtetra
.544 .252 .422 r
.25259 .49167 .25456 .48321 .25568 .4908 .25426 .49255 Mtetra
.437 0 .104 r
.25426 .49255 .25568 .4908 .25722 .4932 .25599 .49265 Mtetra
.472 .815 .999 r
.25599 .49265 .25722 .4932 .25891 .49383 .25775 .49236 Mtetra
.63 .689 .886 r
.25775 .49236 .25891 .49383 .26068 .4934 .25954 .49184 Mtetra
.659 .686 .865 r
.25954 .49184 .26068 .4934 .26249 .49262 .26133 .49116 Mtetra
.619 .688 .893 r
.26133 .49116 .26249 .49262 .26429 .49195 .26312 .49069 Mtetra
.565 .702 .934 r
.26312 .49069 .26429 .49195 .26607 .49152 .26489 .49041 Mtetra
.676 .766 .919 r
.26489 .49041 .26607 .49152 .26787 .49083 .26669 .48969 Mtetra
.845 .779 .788 r
.26669 .48969 .26787 .49083 .26974 .48929 .26861 .48747 Mtetra
.903 .712 .634 r
.26861 .48747 .26974 .48929 .27172 .48624 .27086 .481 Mtetra
.95 .685 .498 r
.27086 .481 .27172 .48624 .27385 .48129 .28832 .27526 Mtetra
.528 .297 .508 r
.28832 .27526 .27385 .48129 .27607 .47499 .29032 .27053 Mtetra
.519 .289 .507 r
.29032 .27053 .27607 .47499 .27781 .4752 .29203 .26969 Mtetra
.517 .288 .506 r
.29203 .26969 .27781 .4752 .27955 .47526 .29369 .26944 Mtetra
.519 .289 .506 r
.29369 .26944 .27955 .47526 .29537 .28486 .29539 .26866 Mtetra
.569 .358 .555 r
.29539 .26866 .29537 .28486 .29804 .271 .29716 .26691 Mtetra
.668 .516 .669 r
.29716 .26691 .29804 .271 .29998 .267 .29892 .26535 Mtetra
.728 .685 .809 r
.29892 .26535 .29998 .267 .30177 .26496 .30066 .2642 Mtetra
.67 .825 .958 r
.30066 .2642 .30177 .26496 .30348 .26418 .30235 .26353 Mtetra
.611 .836 .986 r
.30235 .26353 .30348 .26418 .30515 .26375 .30404 .26302 Mtetra
.601 .815 .982 r
.30404 .26302 .30515 .26375 .30683 .26342 .30572 .26255 Mtetra
.624 .79 .961 r
.30572 .26255 .30683 .26342 .30851 .263 .30741 .26205 Mtetra
.629 .773 .949 r
.30741 .26205 .30851 .263 .31019 .2626 .3091 .26154 Mtetra
.645 .757 .931 r
.3091 .26154 .31019 .2626 .31188 .26213 .31079 .26099 Mtetra
.664 .745 .911 r
.31079 .26099 .31188 .26213 .31357 .26156 .31249 .26036 Mtetra
.671 .737 .9 r
.31249 .26036 .31357 .26156 .31528 .26092 .3142 .25969 Mtetra
.706 .742 .88 r
.3142 .25969 .31528 .26092 .31699 .2601 .31591 .25884 Mtetra
.739 .745 .856 r
.31591 .25884 .31699 .2601 .31872 .25909 .31765 .25777 Mtetra
.67 .716 .883 r
.31765 .25777 .31872 .25909 .32043 .25832 .31935 .2571 Mtetra
.216 .518 .915 r
.31935 .2571 .32043 .25832 .3221 .25825 .32098 .2576 Mtetra
.91 .508 .209 r
.32098 .2576 .3221 .25825 .32366 .25976 .32236 .26203 Mtetra
.955 .68 .477 r
.32236 .26203 .32366 .25976 .32511 .2632 .31067 .46711 Mtetra
.525 .29 .5 r
.31067 .46711 .32511 .2632 .32624 .27155 .31216 .47164 Mtetra
.515 .281 .498 r
.31216 .47164 .32624 .27155 .32804 .26966 .31397 .47141 Mtetra
.514 .28 .498 r
.31397 .47141 .32804 .26966 .32983 .26792 .31581 .47054 Mtetra
.515 .281 .498 r
.31581 .47054 .32983 .26792 .31957 .45875 .31763 .47005 Mtetra
.533 .255 .438 r
.31763 .47005 .31957 .45875 .32073 .46875 .31937 .47081 Mtetra
.527 .109 .193 r
.31937 .47081 .32073 .46875 .32233 .47183 .32114 .47135 Mtetra
.121 .629 .899 r
.32114 .47135 .32233 .47183 .32406 .47299 .32292 .47153 Mtetra
.567 .67 .908 r
.32292 .47153 .32406 .47299 .32588 .47267 .32474 .47125 Mtetra
.682 .72 .878 r
.32474 .47125 .32588 .47267 .32773 .47176 .32658 .47046 Mtetra
.811 .765 .81 r
.32658 .47046 .32773 .47176 .32962 .47024 .32849 .46863 Mtetra
.898 .731 .666 r
.32849 .46863 .32962 .47024 .33156 .46786 .33058 .46378 Mtetra
.957 .687 .482 r
.33058 .46378 .33156 .46786 .33359 .46395 .34436 .25931 Mtetra
.538 .305 .51 r
.34436 .25931 .33359 .46395 .33611 .45153 .3466 .24992 Mtetra
.522 .292 .507 r
.3466 .24992 .33611 .45153 .34928 .25241 .34842 .24757 Mtetra
.642 .482 .651 r
.34842 .24757 .34928 .25241 .35121 .24826 .35019 .24614 Mtetra
.685 .623 .781 r
.35019 .24614 .35121 .24826 .35302 .24606 .35194 .24515 Mtetra
.692 .805 .935 r
.35194 .24515 .35302 .24606 .35476 .24514 .35367 .2444 Mtetra
.638 .827 .973 r
.35367 .2444 .35476 .24514 .35648 .24461 .35539 .24382 Mtetra
.617 .808 .974 r
.35539 .24382 .35648 .24461 .35819 .24426 .35711 .24331 Mtetra
.64 .781 .949 r
.35711 .24331 .35819 .24426 .35991 .2438 .35884 .24276 Mtetra
.644 .763 .935 r
.35884 .24276 .35991 .2438 .36163 .24333 .36057 .24219 Mtetra
.673 .753 .911 r
.36057 .24219 .36163 .24333 .36336 .24274 .3623 .24151 Mtetra
.743 .755 .862 r
.3623 .24151 .36336 .24274 .36511 .24175 .36406 .24042 Mtetra
.686 .723 .878 r
.36406 .24042 .36511 .24175 .36686 .24092 .3658 .23965 Mtetra
.451 .636 .935 r
.3658 .23965 .36686 .24092 .36857 .2406 .3675 .23971 Mtetra
.859 .411 .028 r
.3675 .23971 .36857 .2406 .37021 .24183 .36903 .24304 Mtetra
.96 .682 .462 r
.36903 .24304 .37021 .24183 .37179 .24452 .36048 .44703 Mtetra
.531 .294 .501 r
.36048 .44703 .37179 .24452 .37319 .25067 .36193 .45462 Mtetra
.515 .282 .498 r
.36193 .45462 .37319 .25067 .37495 .24975 .36376 .45456 Mtetra
.514 .28 .498 r
.36376 .45456 .37495 .24975 .37675 .24804 .36564 .45366 Mtetra
.36564 .45366 .37675 .24804 .37832 .25101 .36751 .45276 Mtetra
.517 .283 .499 r
.36751 .45276 .37832 .25101 .37067 .44997 .36931 .45344 Mtetra
.53 .168 .298 r
.36931 .45344 .37067 .44997 .37232 .45399 .37112 .45398 Mtetra
.14 0 0 r
.37112 .45398 .37232 .45399 .37408 .45562 .37295 .45419 Mtetra
.616 .698 .903 r
.37295 .45419 .37408 .45562 .37593 .45534 .37482 .45371 Mtetra
.65 .681 .866 r
.37482 .45371 .37593 .45534 .37781 .45464 .37669 .45305 Mtetra
.663 .693 .868 r
.37669 .45305 .37781 .45464 .37969 .45374 .37857 .45233 Mtetra
.638 .711 .9 r
.37857 .45233 .37969 .45374 .38156 .45312 .38044 .45175 Mtetra
.638 .717 .905 r
.38044 .45175 .38156 .45312 .38344 .4525 .38231 .45117 Mtetra
.633 .723 .912 r
.38231 .45117 .38344 .4525 .38531 .45189 .38418 .45061 Mtetra
.534 .692 .94 r
.38418 .45061 .38531 .45189 .38718 .45153 .38604 .45041 Mtetra
.627 .762 .943 r
.38604 .45041 .38718 .45153 .38905 .45095 .38792 .44986 Mtetra
.767 .801 .881 r
.38792 .44986 .38905 .45095 .39095 .44996 .38983 .4486 Mtetra
.914 .756 .672 r
.38983 .4486 .39095 .44996 .39291 .4473 .39187 .44392 Mtetra
.963 .688 .464 r
.39187 .44392 .39291 .4473 .39493 .44316 .40191 .24018 Mtetra
.542 .308 .51 r
.40191 .24018 .39493 .44316 .3971 .43511 .4041 .22879 Mtetra
.52 .291 .507 r
.4041 .22879 .3971 .43511 .39914 .43029 .40589 .22732 Mtetra
.518 .289 .506 r
.40589 .22732 .39914 .43029 .40097 .4309 .40765 .2268 Mtetra
.517 .288 .506 r
.40765 .2268 .40097 .4309 .40273 .43337 .40939 .22678 Mtetra
.518 .289 .506 r
.40939 .22678 .40273 .43337 .40461 .43293 .41116 .22615 Mtetra
.41116 .22615 .40461 .43293 .40648 .43249 .41292 .22554 Mtetra
.41292 .22554 .40648 .43249 .40836 .43202 .41469 .22494 Mtetra
.41469 .22494 .40836 .43202 .41017 .43349 .41645 .22453 Mtetra
.41645 .22453 .41017 .43349 .41204 .4333 .41821 .22397 Mtetra
.519 .289 .506 r
.41821 .22397 .41204 .4333 .41402 .43018 .41999 .22309 Mtetra
.521 .291 .507 r
.41999 .22309 .41402 .43018 .42268 .22752 .42181 .22126 Mtetra
.633 .454 .622 r
.42181 .22126 .42268 .22752 .42461 .22199 .42362 .21952 Mtetra
.718 .615 .741 r
.42362 .21952 .42461 .22199 .42646 .21904 .42542 .21804 Mtetra
.703 .793 .921 r
.42542 .21804 .42646 .21904 .42825 .21796 .4272 .21721 Mtetra
.645 .834 .973 r
.4272 .21721 .42825 .21796 .43002 .21736 .42897 .21659 Mtetra
.608 .819 .981 r
.42897 .21659 .43002 .21736 .43179 .217 .43074 .21608 Mtetra
.629 .79 .959 r
.43074 .21608 .43179 .217 .43356 .21654 .43252 .21554 Mtetra
.631 .773 .949 r
.43252 .21554 .43356 .21654 .43533 .2161 .43429 .215 Mtetra
.638 .756 .934 r
.43429 .215 .43533 .2161 .4371 .21564 .43607 .21444 Mtetra
.66 .745 .913 r
.43607 .21444 .4371 .21564 .43888 .21505 .43785 .2138 Mtetra
.669 .738 .902 r
.43785 .2138 .43888 .21505 .44067 .21439 .43964 .21311 Mtetra
.676 .735 .895 r
.43964 .21311 .44067 .21439 .44245 .21366 .44142 .21239 Mtetra
.747 .756 .86 r
.44142 .21239 .44245 .21366 .44425 .21261 .44322 .21125 Mtetra
.706 .73 .87 r
.44322 .21125 .44425 .21261 .44604 .21169 .44501 .21034 Mtetra
.588 .689 .912 r
.44501 .21034 .44604 .21169 .44782 .21111 .44679 .20999 Mtetra
.665 .183 0 r
.44679 .20999 .44782 .21111 .44957 .21199 .4485 .21236 Mtetra
.967 .68 .434 r
.4485 .21236 .44957 .21199 .45129 .21424 .44572 .3976 Mtetra
.573 .328 .506 r
.44572 .3976 .45129 .21424 .45293 .21993 .44693 .42586 Mtetra
.517 .283 .499 r
.44693 .42586 .45293 .21993 .45469 .2212 .44882 .42651 Mtetra
.514 .281 .498 r
.44882 .42651 .45469 .2212 .45652 .21915 .45074 .42574 Mtetra
.513 .28 .498 r
.45074 .42574 .45652 .21915 .4583 .21912 .45268 .42463 Mtetra
.516 .282 .499 r
.45268 .42463 .4583 .21912 .45581 .41992 .45458 .42505 Mtetra
.53 .202 .356 r
.45458 .42505 .45581 .41992 .45761 .42505 .45648 .42563 Mtetra
.371 0 0 r
.45648 .42563 .45761 .42505 .45948 .42716 .45839 .42595 Mtetra
.567 .725 .948 r
.45839 .42595 .45948 .42716 .4614 .4272 .46031 .42562 Mtetra
.639 .689 .881 r
.46031 .42562 .4614 .4272 .46333 .42657 .46224 .42501 Mtetra
.66 .702 .877 r
.46224 .42501 .46333 .42657 .46527 .42567 .46417 .42429 Mtetra
.563 .691 .926 r
.46417 .42429 .46527 .42567 .4672 .4252 .4661 .424 Mtetra
.602 .742 .942 r
.4661 .424 .4672 .4252 .46913 .42467 .46803 .42353 Mtetra
.726 .794 .906 r
.46803 .42353 .46913 .42467 .47107 .42379 .46998 .4225 Mtetra
.9 .78 .72 r
.46998 .4225 .47107 .42379 .47303 .42185 .47196 .41902 Mtetra
.922 .69 .57 r
.47196 .41902 .47303 .42185 .47501 .41859 .47405 .40861 Mtetra
.963 .678 .447 r
.47405 .40861 .47501 .41859 .47703 .41187 .4791 .20232 Mtetra
.524 .294 .507 r
.4791 .20232 .47703 .41187 .48188 .20591 .48095 .19892 Mtetra
.621 .437 .612 r
.48095 .19892 .48188 .20591 .48377 .20022 .48278 .19721 Mtetra
.663 .557 .724 r
.48278 .19721 .48377 .20022 .48561 .1974 .48459 .19609 Mtetra
.682 .735 .891 r
.48459 .19609 .48561 .1974 .48743 .19623 .48641 .19533 Mtetra
.627 .799 .965 r
.48641 .19533 .48743 .19623 .48924 .19572 .48822 .19477 Mtetra
.597 .777 .966 r
.48822 .19477 .48924 .19572 .49105 .19549 .49004 .19432 Mtetra
.646 .75 .925 r
.49004 .19432 .49105 .19549 .49286 .195 .49185 .19373 Mtetra
.667 .736 .902 r
.49185 .19373 .49286 .195 .49468 .19435 .49367 .19303 Mtetra
.675 .732 .893 r
.49367 .19303 .49468 .19435 .4965 .19363 .49549 .1923 Mtetra
.738 .75 .861 r
.49549 .1923 .4965 .19363 .49832 .1926 .49732 .19119 Mtetra
.719 .732 .861 r
.49732 .19119 .49832 .1926 .50015 .1916 .49914 .19018 Mtetra
.628 .697 .895 r
.49914 .19018 .50015 .1916 .50197 .1909 .50096 .18966 Mtetra
0 .182 .699 r
.50096 .18966 .50197 .1909 .50379 .19117 .50277 .19111 Mtetra
.915 .524 .243 r
.50277 .19111 .50379 .19117 .5056 .19261 .50455 .1975 Mtetra
.967 .673 .421 r
.50455 .1975 .5056 .19261 .5074 .19672 .50511 .4048 Mtetra
.521 .286 .499 r
.50511 .4048 .5074 .19672 .50816 .40169 .50705 .4078 Mtetra
.532 .216 .377 r
.50705 .4078 .50816 .40169 .51009 .40745 .509 .40846 Mtetra
.301 0 0 r
.509 .40846 .51009 .40745 .51204 .40945 .51097 .40838 Mtetra
.504 .73 .974 r
.51097 .40838 .51204 .40945 .51401 .40971 .51293 .40819 Mtetra
.622 .696 .897 r
.51293 .40819 .51401 .40971 .51597 .40905 .5149 .40765 Mtetra
.74 .757 .866 r
.5149 .40765 .51597 .40905 .51794 .40779 .51687 .40645 Mtetra
.899 .783 .725 r
.51687 .40645 .51794 .40779 .51992 .4058 .51885 .40308 Mtetra
.932 .696 .56 r
.51885 .40308 .51992 .4058 .52189 .40268 .52083 .3923 Mtetra
.966 .677 .432 r
.52083 .3923 .52189 .40268 .52386 .39649 .52293 .18624 Mtetra
.524 .294 .507 r
.52293 .18624 .52386 .39649 .52577 .1905 .52477 .18266 Mtetra
.61 .421 .602 r
.52477 .18266 .52577 .1905 .52761 .18436 .52661 .18097 Mtetra
.65 .532 .707 r
.52661 .18097 .52761 .18436 .52945 .18139 .52845 .17987 Mtetra
.666 .698 .87 r
.52845 .17987 .52945 .18139 .53129 .18007 .5303 .17914 Mtetra
.601 .789 .971 r
.5303 .17914 .53129 .18007 .53313 .17958 .53214 .17867 Mtetra
.552 .77 .979 r
.53214 .17867 .53313 .17958 .53498 .17943 .53399 .17833 Mtetra
.598 .749 .949 r
.53399 .17833 .53498 .17943 .53683 .17911 .53583 .17789 Mtetra
.632 .737 .924 r
.53583 .17789 .53683 .17911 .53867 .1786 .53768 .17735 Mtetra
.64 .735 .917 r
.53768 .17735 .53867 .1786 .54052 .17805 .53953 .17676 Mtetra
.648 .732 .91 r
.53953 .17676 .54052 .17805 .54237 .17746 .54138 .17615 Mtetra
.655 .729 .904 r
.54138 .17615 .54237 .17746 .54423 .17685 .54324 .1755 Mtetra
.66 .725 .897 r
.54324 .1755 .54423 .17685 .54608 .1762 .54509 .17482 Mtetra
.664 .722 .892 r
.54509 .17482 .54608 .1762 .54793 .17552 .54695 .17413 Mtetra
.668 .721 .889 r
.54695 .17413 .54793 .17552 .54979 .17481 .5488 .17341 Mtetra
.671 .721 .887 r
.5488 .17341 .54979 .17481 .55164 .17407 .55066 .17267 Mtetra
.673 .723 .887 r
.55066 .17267 .55164 .17407 .5535 .17331 .55252 .17193 Mtetra
.675 .725 .887 r
.55252 .17193 .5535 .17331 .55536 .17254 .55437 .17117 Mtetra
.681 .731 .888 r
.55437 .17117 .55536 .17254 .55722 .17172 .55623 .17039 Mtetra
.693 .741 .888 r
.55623 .17039 .55722 .17172 .55908 .1708 .55809 .16954 Mtetra
.702 .758 .895 r
.55809 .16954 .55908 .1708 .56093 .16982 .55995 .16866 Mtetra
.703 .777 .909 r
.55995 .16866 .56093 .16982 .56279 .16886 .56182 .16779 Mtetra
.692 .791 .926 r
.56182 .16779 .56279 .16886 .56466 .16799 .56368 .16697 Mtetra
.679 .798 .938 r
.56368 .16697 .56466 .16799 .56652 .16721 .56555 .16622 Mtetra
.673 .801 .943 r
.56555 .16622 .56652 .16721 .56839 .16647 .56741 .16548 Mtetra
.671 .802 .945 r
.56741 .16548 .56839 .16647 .57025 .16574 .56928 .16476 Mtetra
.67 .804 .947 r
.56928 .16476 .57025 .16574 .57212 .16501 .57115 .16404 Mtetra
.668 .805 .948 r
.57115 .16404 .57212 .16501 .57399 .16429 .57302 .16332 Mtetra
.667 .805 .949 r
.57302 .16332 .57399 .16429 .57586 .16358 .57489 .16261 Mtetra
.665 .806 .95 r
.57489 .16261 .57586 .16358 .57774 .16287 .57677 .1619 Mtetra
.664 .806 .951 r
.57677 .1619 .57774 .16287 .57961 .16216 .57864 .1612 Mtetra
.57864 .1612 .57961 .16216 .58149 .16146 .58052 .1605 Mtetra
.663 .806 .952 r
.58052 .1605 .58149 .16146 .58336 .16076 .5824 .1598 Mtetra
.662 .806 .952 r
.5824 .1598 .58336 .16076 .58524 .16006 .58428 .1591 Mtetra
.58428 .1591 .58524 .16006 .58712 .15937 .58616 .1584 Mtetra
.58616 .1584 .58712 .15937 .589 .15867 .58804 .1577 Mtetra
.58804 .1577 .589 .15867 .59088 .15798 .58992 .15701 Mtetra
.661 .806 .952 r
.58992 .15701 .59088 .15798 .59276 .15728 .59181 .15631 Mtetra
.661 .805 .952 r
.59181 .15631 .59276 .15728 .59465 .15659 .59369 .15561 Mtetra
.59369 .15561 .59465 .15659 .59653 .15589 .59558 .15492 Mtetra
.59558 .15492 .59653 .15589 .59842 .1552 .59747 .15422 Mtetra
.59747 .15422 .59842 .1552 .60031 .1545 .59935 .15353 Mtetra
.59935 .15353 .60031 .1545 .6022 .15381 .60125 .15283 Mtetra
.66 .805 .952 r
.60125 .15283 .6022 .15381 .60409 .15311 .60314 .15214 Mtetra
.60314 .15214 .60409 .15311 .60598 .15242 .60503 .15144 Mtetra
.66 .805 .953 r
.60503 .15144 .60598 .15242 .60788 .15173 .60693 .15075 Mtetra
.659 .804 .953 r
.60693 .15075 .60788 .15173 .60977 .15104 .60882 .15006 Mtetra
.658 .804 .953 r
.60882 .15006 .60977 .15104 .61167 .15035 .61072 .14937 Mtetra
.657 .803 .953 r
.61072 .14937 .61167 .15035 .61356 .14967 .61262 .14868 Mtetra
.657 .802 .953 r
.61262 .14868 .61356 .14967 .61546 .14899 .61452 .148 Mtetra
.61452 .148 .61546 .14899 .61736 .1483 .61642 .14731 Mtetra
.652 .8 .954 r
.61642 .14731 .61736 .1483 .61927 .14765 .61832 .14665 Mtetra
.64 .793 .956 r
.61832 .14665 .61927 .14765 .62117 .14707 .62023 .14603 Mtetra
.625 .779 .955 r
.62023 .14603 .62117 .14707 .62308 .14659 .62214 .14547 Mtetra
.626 .762 .944 r
.62214 .14547 .62308 .14659 .625 .14612 .62405 .14491 Mtetra
.638 .749 .929 r
.62405 .14491 .625 .14612 .62691 .1456 .62596 .14432 Mtetra
.654 .742 .915 r
.62596 .14432 .62691 .1456 .62882 .14497 .62787 .14366 Mtetra
.66 .739 .908 r
.62787 .14366 .62882 .14497 .63073 .1443 .62978 .14297 Mtetra
.663 .736 .904 r
.62978 .14297 .63073 .1443 .63264 .14362 .63169 .14226 Mtetra
.663 .732 .901 r
.63169 .14226 .63264 .14362 .63456 .14295 .63361 .14155 Mtetra
.669 .727 .893 r
.63361 .14155 .63456 .14295 .63647 .14223 .63552 .14081 Mtetra
.682 .728 .885 r
.63552 .14081 .63647 .14223 .63838 .14141 .63743 .13999 Mtetra
.697 .735 .88 r
.63743 .13999 .63838 .14141 .64029 .14046 .63934 .13909 Mtetra
.7 .744 .886 r
.63934 .13909 .64029 .14046 .64219 .1395 .64125 .13818 Mtetra
.718 .76 .886 r
.64125 .13818 .64219 .1395 .6441 .13851 .64316 .13718 Mtetra
.736 .765 .877 r
.64316 .13718 .6441 .13851 .64601 .1375 .64506 .13607 Mtetra
.663 .722 .893 r
.64506 .13607 .64601 .1375 .64793 .13674 .64698 .13536 Mtetra
.37 .58 .923 r
.64698 .13536 .64793 .13674 .64987 .13654 .64895 .13568 Mtetra
.747 .272 0 r
.64895 .13568 .64987 .13654 .65186 .13744 .65105 .13905 Mtetra
.974 .666 .351 r
.65105 .13905 .65186 .13744 .65392 .13982 .66202 .34727 Mtetra
.529 .292 .499 r
.66202 .34727 .65392 .13982 .65643 .15213 .66444 .35467 Mtetra
.517 .283 .498 r
.66444 .35467 .65643 .15213 .66739 .35242 .66659 .35567 Mtetra
.466 .093 .247 r
.66659 .35567 .66739 .35242 .66964 .35564 .6687 .35572 Mtetra
.188 .719 .759 r
.6687 .35572 .66964 .35564 .6718 .35665 .6708 .35532 Mtetra
.624 .74 .93 r
.6708 .35532 .6718 .35665 .67389 .35621 .67289 .35473 Mtetra
.654 .727 .903 r
.67289 .35473 .67389 .35621 .67597 .35539 .67497 .35401 Mtetra
.612 .726 .927 r
.67497 .35401 .67597 .35539 .67806 .35472 .67706 .35347 Mtetra
.443 .67 .959 r
.67706 .35347 .67806 .35472 .68018 .35481 .67918 .3535 Mtetra
.607 .738 .938 r
.67918 .3535 .68018 .35481 .68228 .35433 .68128 .35297 Mtetra
.832 .803 .824 r
.68128 .35297 .68228 .35433 .68431 .35234 .68331 .35099 Mtetra
.976 .76 .545 r
.68331 .35099 .68431 .35234 .68597 .3433 .685 .34235 Mtetra
.977 .676 .35 r
.685 .34235 .68597 .3433 .67709 .12986 .67618 .12893 Mtetra
.966 .821 .648 r
.67618 .12893 .67709 .12986 .67884 .12544 .67793 .12439 Mtetra
.729 .818 .92 r
.67793 .12439 .67884 .12544 .68077 .12449 .67986 .12336 Mtetra
.565 .738 .957 r
.67986 .12336 .68077 .12449 .68274 .12423 .68182 .12301 Mtetra
.506 .692 .952 r
.68182 .12301 .68274 .12423 .68472 .12418 .6838 .12287 Mtetra
.658 .744 .913 r
.6838 .12287 .68472 .12418 .68667 .12353 .68575 .12218 Mtetra
.669 .74 .903 r
.68575 .12218 .68667 .12353 .68862 .1228 .6877 .12142 Mtetra
.7 .748 .889 r
.6877 .12142 .68862 .1228 .69056 .12188 .68964 .12051 Mtetra
.77 .773 .856 r
.68964 .12051 .69056 .12188 .69247 .12046 .69156 .11915 Mtetra
.699 .761 .899 r
.69156 .11915 .69247 .12046 .69441 .11951 .6935 .11825 Mtetra
.383 .615 .942 r
.6935 .11825 .69441 .11951 .69642 .11971 .69551 .11848 Mtetra
.837 .425 0 r
.69551 .11848 .69642 .11971 .69878 .12587 .69786 .12442 Mtetra
.973 .663 .318 r
.69786 .12442 .69878 .12587 .71352 .33924 .71252 .33759 Mtetra
.623 .212 0 r
.71252 .33759 .71352 .33924 .71591 .3432 .71492 .34167 Mtetra
.447 .62 .925 r
.71492 .34167 .71591 .3432 .71806 .34309 .71708 .34179 Mtetra
.699 .78 .914 r
.71708 .34179 .71806 .34309 .72015 .34203 .71919 .34083 Mtetra
.855 .835 .825 r
.71919 .34083 .72015 .34203 .7222 .3402 .72122 .33869 Mtetra
.949 .783 .642 r
.72122 .33869 .7222 .3402 .72421 .33774 .72306 .33362 Mtetra
.976 .67 .339 r
.72306 .33362 .72421 .33774 .72612 .33374 .7119 .12368 Mtetra
.536 .302 .507 r
.7119 .12368 .72612 .33374 .7275 .32161 .71331 .11421 Mtetra
.522 .292 .507 r
.71331 .11421 .7275 .32161 .71634 .11714 .71517 .11179 Mtetra
.632 .468 .643 r
.71517 .11179 .71634 .11714 .71808 .11277 .71709 .11028 Mtetra
.67 .603 .771 r
.71709 .11028 .71808 .11277 .71994 .11036 .71905 .10925 Mtetra
.661 .788 .942 r
.71905 .10925 .71994 .11036 .7219 .10952 .72102 .10853 Mtetra
.608 .793 .97 r
.72102 .10853 .7219 .10952 .72389 .10909 .72301 .10799 Mtetra
.608 .767 .956 r
.72301 .10799 .72389 .10909 .7259 .10882 .725 .10747 Mtetra
.732 .768 .882 r
.725 .10747 .7259 .10882 .72786 .1079 .72695 .10637 Mtetra
.674 .716 .88 r
.72695 .10637 .72786 .1079 .72984 .10712 .72892 .10556 Mtetra
.528 .64 .904 r
.72892 .10556 .72984 .10712 .73184 .1067 .73094 .10543 Mtetra
0 0 .443 r
.73094 .10543 .73184 .1067 .73392 .10744 .73319 .10845 Mtetra
.971 .656 .305 r
.73319 .10845 .73392 .10744 .73611 .1096 .75014 .31625 Mtetra
.532 .294 .499 r
.75014 .31625 .73611 .1096 .7389 .11992 .753 .32559 Mtetra
.518 .283 .498 r
.753 .32559 .7389 .11992 .7559 .32354 .75529 .32687 Mtetra
.486 .11 .252 r
.75529 .32687 .7559 .32354 .75835 .327 .7575 .3271 Mtetra
.113 .664 .716 r
.7575 .3271 .75835 .327 .76065 .32833 .75968 .32679 Mtetra
.55 .674 .92 r
.75968 .32679 .76065 .32833 .76283 .32806 .76186 .32652 Mtetra
.66 .727 .899 r
.76186 .32652 .76283 .32806 .76497 .32715 .76401 .32574 Mtetra
.78 .794 .864 r
.76401 .32574 .76497 .32715 .76706 .32562 .7661 .32422 Mtetra
.915 .741 .653 r
.08355 .54804 .08482 .54892 .08698 .54467 .08596 .54188 Mtetra
.934 .684 .535 r
.08596 .54188 .08698 .54467 .11394 .34897 .11421 .3368 Mtetra
.683 .462 .58 r
.11421 .3368 .11394 .34897 .11725 .33501 .11646 .33104 Mtetra
.645 .501 .673 r
.11646 .33104 .11725 .33501 .11906 .33258 .11812 .32987 Mtetra
.597 .524 .743 r
.11812 .32987 .11906 .33258 .12075 .33117 .11968 .32945 Mtetra
.517 .58 .857 r
.11968 .32945 .12075 .33117 .12237 .33024 .12118 .32943 Mtetra
.634 .791 .957 r
.12118 .32943 .12237 .33024 .12395 .32965 .12275 .32894 Mtetra
.643 .816 .967 r
.12275 .32894 .12395 .32965 .12551 .32923 .12433 .3284 Mtetra
.659 .793 .946 r
.12433 .3284 .12551 .32923 .12707 .3289 .12591 .32783 Mtetra
.697 .752 .894 r
.12591 .32783 .12707 .3289 .12865 .32834 .12751 .32709 Mtetra
.687 .718 .873 r
.12751 .32709 .12865 .32834 .13024 .32772 .12912 .32637 Mtetra
.665 .696 .869 r
.12912 .32637 .13024 .32772 .13183 .32705 .13071 .32575 Mtetra
.67 .704 .873 r
.13071 .32575 .13183 .32705 .13348 .32595 .1323 .32511 Mtetra
.55 .76 .975 r
.1323 .32511 .13348 .32595 .1351 .32511 .13385 .32484 Mtetra
.281 0 0 r
.13385 .32484 .1351 .32511 .13666 .3248 .13531 .32531 Mtetra
.883 .543 .4 r
.13531 .32531 .13666 .3248 .1379 .32701 .13616 .33075 Mtetra
.934 .676 .523 r
.13616 .33075 .1379 .32701 .13791 .33938 .11281 .5333 Mtetra
.525 .29 .501 r
.11281 .5333 .13791 .33938 .11557 .53517 .1139 .53764 Mtetra
.492 .102 .228 r
.1139 .53764 .11557 .53517 .11696 .53706 .11549 .53788 Mtetra
0 0 0 r
.11549 .53788 .11696 .53706 .11853 .53754 .1172 .53722 Mtetra
.752 .918 .947 r
.1172 .53722 .11853 .53754 .12017 .53742 .11896 .53616 Mtetra
.637 .719 .907 r
.11896 .53616 .12017 .53742 .12186 .53694 .12065 .53564 Mtetra
.624 .708 .906 r
.12065 .53564 .12186 .53694 .12357 .53625 .12234 .53518 Mtetra
.649 .755 .927 r
.12234 .53518 .12357 .53625 .12529 .53549 .12404 .5346 Mtetra
.635 .791 .957 r
.12404 .5346 .12529 .53549 .12694 .53538 .12573 .53407 Mtetra
.71 .729 .865 r
.12573 .53407 .12694 .53538 .12861 .5351 .12748 .53316 Mtetra
.759 .669 .762 r
.12748 .53316 .12861 .5351 .13034 .53426 .12931 .53146 Mtetra
.86 .663 .634 r
.12931 .53146 .13034 .53426 .13239 .53078 .13172 .52489 Mtetra
.936 .681 .528 r
.13172 .52489 .13239 .53078 .13538 .51915 .15723 .3208 Mtetra
.53 .299 .509 r
.15723 .3208 .13538 .51915 .16014 .31993 .15938 .31552 Mtetra
.655 .498 .659 r
.15938 .31552 .16014 .31993 .16201 .31702 .16109 .31407 Mtetra
.605 .516 .728 r
.16109 .31407 .16201 .31702 .16372 .31556 .16268 .31355 Mtetra
.554 .561 .816 r
.16268 .31355 .16372 .31556 .16536 .31463 .16424 .31341 Mtetra
.646 .714 .897 r
.16424 .31341 .16536 .31463 .16699 .31391 .16584 .31288 Mtetra
.67 .757 .916 r
.16584 .31288 .16699 .31391 .16859 .31333 .16745 .31226 Mtetra
.652 .744 .917 r
.16745 .31226 .16859 .31333 .17019 .31282 .16906 .31171 Mtetra
.675 .743 .902 r
.16906 .31171 .17019 .31282 .17185 .31181 .17067 .31106 Mtetra
.581 .794 .98 r
.17067 .31106 .17185 .31181 .1735 .31092 .17226 .31069 Mtetra
.14 0 0 r
.17226 .31069 .1735 .31092 .17509 .31053 .17377 .31098 Mtetra
.869 .505 .355 r
.17377 .31098 .17509 .31053 .17643 .31231 .17484 .31529 Mtetra
.939 .678 .515 r
.17484 .31529 .17643 .31231 .17706 .3207 .15379 .51882 Mtetra
.527 .291 .501 r
.15379 .51882 .17706 .3207 .15654 .52101 .15489 .52383 Mtetra
.554 .181 .288 r
.15489 .52383 .15654 .52101 .15794 .52334 .15647 .52451 Mtetra
.109 0 0 r
.15647 .52451 .15794 .52334 .15955 .52383 .15819 .52397 Mtetra
.674 .97 .917 r
.15819 .52397 .15955 .52383 .16122 .52373 .15997 .52292 Mtetra
.672 .816 .952 r
.15997 .52292 .16122 .52373 .16287 .52387 .16171 .52223 Mtetra
.681 .678 .84 r
.16171 .52223 .16287 .52387 .16455 .52367 .16346 .52143 Mtetra
.73 .636 .755 r
.16346 .52143 .16455 .52367 .16632 .52271 .16529 .51992 Mtetra
.843 .657 .65 r
.16529 .51992 .16632 .52271 .16844 .51852 .16751 .51473 Mtetra
.942 .685 .52 r
.16751 .51473 .16844 .51852 .19185 .31374 .191 .30999 Mtetra
.834 .627 .622 r
.191 .30999 .19185 .31374 .1944 .30446 .19325 .3035 Mtetra
.836 .785 .803 r
.19325 .3035 .1944 .30446 .19617 .30244 .19501 .30163 Mtetra
.681 .808 .943 r
.19501 .30163 .19617 .30244 .1978 .30186 .19665 .30096 Mtetra
.556 .754 .97 r
.19665 .30096 .1978 .30186 .19937 .30174 .19824 .30068 Mtetra
.722 .764 .886 r
.19824 .30068 .19937 .30174 .20101 .30106 .1999 .29979 Mtetra
.721 .73 .858 r
.1999 .29979 .20101 .30106 .20266 .30023 .20156 .29886 Mtetra
.603 .675 .891 r
.20156 .29886 .20266 .30023 .20427 .29985 .20317 .2985 Mtetra
.743 .281 0 r
.20317 .2985 .20427 .29985 .20569 .3013 .20451 .30076 Mtetra
.947 .683 .505 r
.20451 .30076 .20569 .3013 .20663 .3076 .18559 .50152 Mtetra
.54 .302 .504 r
.18559 .50152 .20663 .3076 .18779 .50941 .18615 .51251 Mtetra
.607 .245 .33 r
.18615 .51251 .18779 .50941 .18917 .51232 .18771 .51374 Mtetra
.14 0 0 r
.18771 .51374 .18917 .51232 .1908 .51285 .18946 .51311 Mtetra
.7 .982 .885 r
.18946 .51311 .1908 .51285 .19251 .51269 .19127 .51188 Mtetra
.74 .83 .92 r
.19127 .51188 .19251 .51269 .19423 .5123 .19305 .51089 Mtetra
.674 .709 .874 r
.19305 .51089 .19423 .5123 .19598 .51171 .19481 .51017 Mtetra
.663 .687 .862 r
.19481 .51017 .19598 .51171 .19776 .51083 .19657 .50948 Mtetra
.653 .713 .891 r
.19657 .50948 .19776 .51083 .1996 .50932 .19833 .50887 Mtetra
.584 .873 .994 r
.19833 .50887 .1996 .50932 .20149 .50728 .20007 .50832 Mtetra
.098 0 0 r
.20007 .50832 .20149 .50728 .20337 .50529 .20182 .50782 Mtetra
.352 0 .147 r
.20182 .50782 .20337 .50529 .20506 .50533 .20356 .50735 Mtetra
.314 0 .067 r
.20356 .50735 .20506 .50533 .20664 .50655 .2053 .50691 Mtetra
0 0 0 r
.2053 .50691 .20664 .50655 .20825 .50749 .20704 .50649 Mtetra
.572 .754 .964 r
.20704 .50649 .20825 .50749 .20994 .50761 .20877 .50615 Mtetra
.59 .673 .897 r
.20877 .50615 .20994 .50761 .21168 .50719 .2105 .50581 Mtetra
.619 .696 .899 r
.2105 .50581 .21168 .50719 .21344 .50662 .21225 .50534 Mtetra
.629 .719 .912 r
.21225 .50534 .21344 .50662 .21517 .50633 .21401 .50484 Mtetra
.678 .7 .864 r
.21401 .50484 .21517 .50633 .2169 .50606 .21578 .50407 Mtetra
.738 .663 .777 r
.21578 .50407 .2169 .50606 .21868 .5053 .21763 .50262 Mtetra
.837 .66 .663 r
.21763 .50262 .21868 .5053 .22063 .50271 .21974 .49817 Mtetra
.946 .685 .509 r
.21974 .49817 .22063 .50271 .22301 .49537 .24021 .29287 Mtetra
.534 .302 .51 r
.24021 .29287 .22301 .49537 .24322 .29078 .24249 .28546 Mtetra
.677 .498 .635 r
.24249 .28546 .24322 .29078 .24522 .28639 .2443 .2832 Mtetra
.62 .516 .714 r
.2443 .2832 .24522 .28639 .24699 .28459 .24596 .28249 Mtetra
.578 .569 .807 r
.24596 .28249 .24699 .28459 .24869 .28344 .24759 .28222 Mtetra
.615 .71 .913 r
.24759 .28222 .24869 .28344 .25037 .28268 .24924 .2818 Mtetra
.682 .799 .937 r
.24924 .2818 .25037 .28268 .25202 .28214 .25091 .28111 Mtetra
.666 .764 .923 r
.25091 .28111 .25202 .28214 .25367 .28171 .25257 .28049 Mtetra
.604 .706 .916 r
.25257 .28049 .25367 .28171 .25533 .28115 .25421 .28011 Mtetra
.508 .706 .959 r
.25421 .28011 .25533 .28115 .257 .28042 .25584 .27997 Mtetra
.321 .753 .971 r
.25584 .27997 .257 .28042 .25868 .27967 .25746 .27988 Mtetra
.377 .842 .818 r
.25746 .27988 .25868 .27967 .26037 .27876 .25912 .27928 Mtetra
.466 .877 .738 r
.25912 .27928 .26037 .27876 .26206 .27787 .26082 .27831 Mtetra
0 0 0 r
.26082 .27831 .26206 .27787 .26372 .27739 .26248 .27785 Mtetra
.755 .294 .155 r
.26248 .27785 .26372 .27739 .26526 .27831 .26394 .27973 Mtetra
.95 .681 .492 r
.26394 .27973 .26526 .27831 .26649 .28297 .24867 .48178 Mtetra
.536 .298 .502 r
.24867 .48178 .26649 .28297 .25122 .48727 .24961 .49133 Mtetra
.627 .285 .373 r
.24961 .49133 .25122 .48727 .25259 .49167 .2512 .49308 Mtetra
.269 0 0 r
.2512 .49308 .25259 .49167 .25426 .49255 .25296 .49275 Mtetra
.53 .922 .874 r
.25296 .49275 .25426 .49255 .25599 .49265 .25477 .49188 Mtetra
.698 .838 .95 r
.25477 .49188 .25599 .49265 .25775 .49236 .25658 .49107 Mtetra
.632 .72 .911 r
.25658 .49107 .25775 .49236 .25954 .49184 .25837 .49054 Mtetra
.653 .726 .902 r
.25837 .49054 .25954 .49184 .26133 .49116 .26016 .48992 Mtetra
.657 .737 .908 r
.26016 .48992 .26133 .49116 .26312 .49069 .26196 .48928 Mtetra
.678 .715 .877 r
.26196 .48928 .26312 .49069 .26489 .49041 .26376 .48852 Mtetra
.734 .674 .792 r
.26376 .48852 .26489 .49041 .26669 .48969 .26562 .48717 Mtetra
.822 .663 .685 r
.26562 .48717 .26669 .48969 .26861 .48747 .26764 .48362 Mtetra
.952 .686 .497 r
.26764 .48362 .26861 .48747 .27086 .481 .28511 .28019 Mtetra
.542 .309 .511 r
.28511 .28019 .27086 .481 .28832 .27526 .28759 .26938 Mtetra
.69 .499 .624 r
.28759 .26938 .28832 .27526 .29032 .27053 .28944 .26655 Mtetra
.617 .485 .679 r
.28944 .26655 .29032 .27053 .29203 .26969 .29115 .26569 Mtetra
.57 .454 .682 r
.29115 .26569 .29203 .26969 .29369 .26944 .29282 .26535 Mtetra
.562 .446 .679 r
.29282 .26535 .29369 .26944 .29539 .26866 .29448 .26507 Mtetra
.593 .484 .698 r
.29448 .26507 .29539 .26866 .29716 .26691 .29616 .26454 Mtetra
.615 .565 .775 r
.29616 .26454 .29716 .26691 .29892 .26535 .29785 .26402 Mtetra
.64 .704 .892 r
.29785 .26402 .29892 .26535 .30066 .2642 .29953 .26349 Mtetra
.636 .83 .975 r
.29953 .26349 .30066 .2642 .30235 .26353 .30122 .26292 Mtetra
.637 .852 .982 r
.30122 .26292 .30235 .26353 .30404 .26302 .30292 .26232 Mtetra
.656 .839 .97 r
.30292 .26232 .30404 .26302 .30572 .26255 .30461 .26169 Mtetra
.675 .806 .945 r
.30461 .26169 .30572 .26255 .30741 .26205 .30631 .26101 Mtetra
.679 .77 .919 r
.30631 .26101 .30741 .26205 .3091 .26154 .30802 .26032 Mtetra
.681 .735 .891 r
.30802 .26032 .3091 .26154 .31079 .26099 .30972 .2596 Mtetra
.68 .707 .868 r
.30972 .2596 .31079 .26099 .31249 .26036 .31143 .25886 Mtetra
.661 .684 .861 r
.31143 .25886 .31249 .26036 .3142 .25969 .31313 .25821 Mtetra
.65 .682 .867 r
.31313 .25821 .3142 .25969 .31591 .25884 .31483 .25761 Mtetra
.635 .72 .909 r
.31483 .25761 .31591 .25884 .31765 .25777 .31653 .2571 Mtetra
.344 .718 .985 r
.31653 .2571 .31765 .25777 .31935 .2571 .31819 .2571 Mtetra
.738 .227 0 r
.31819 .2571 .31935 .2571 .32098 .2576 .31974 .25883 Mtetra
.956 .682 .476 r
.31974 .25883 .32098 .2576 .32236 .26203 .30811 .46019 Mtetra
.539 .301 .503 r
.30811 .46019 .32236 .26203 .31067 .46711 .30916 .47138 Mtetra
.651 .311 .383 r
.30916 .47138 .31067 .46711 .31216 .47164 .3108 .47364 Mtetra
.395 0 .109 r
.3108 .47364 .31216 .47164 .31397 .47141 .31259 .47351 Mtetra
.24 0 .035 r
.31259 .47351 .31397 .47141 .31581 .47054 .31443 .47276 Mtetra
.155 0 .006 r
.31443 .47276 .31581 .47054 .31763 .47005 .31629 .47167 Mtetra
0 0 0 r
.31629 .47167 .31763 .47005 .31937 .47081 .31816 .47052 Mtetra
.775 .945 .934 r
.31816 .47052 .31937 .47081 .32114 .47135 .32003 .46926 Mtetra
.686 .639 .798 r
.32003 .46926 .32114 .47135 .32292 .47153 .32189 .46826 Mtetra
.561 .49 .733 r
.32189 .46826 .32292 .47153 .32474 .47125 .3237 .46804 Mtetra
.611 .523 .73 r
.3237 .46804 .32474 .47125 .32658 .47046 .32554 .4674 Mtetra
.739 .602 .704 r
.32554 .4674 .32658 .47046 .32849 .46863 .32747 .46525 Mtetra
.901 .67 .58 r
.32747 .46525 .32849 .46863 .33058 .46378 .32995 .45378 Mtetra
.951 .679 .487 r
.32995 .45378 .33058 .46378 .34436 .25931 .34377 .24986 Mtetra
.667 .454 .587 r
.34377 .24986 .34436 .25931 .3466 .24992 .34568 .24602 Mtetra
.631 .498 .682 r
.34568 .24602 .3466 .24992 .34842 .24757 .34743 .24501 Mtetra
.599 .544 .764 r
.34743 .24501 .34842 .24757 .35019 .24614 .34914 .24457 Mtetra
.577 .642 .878 r
.34914 .24457 .35019 .24614 .35194 .24515 .35085 .2443 Mtetra
.673 .812 .949 r
.35085 .2443 .35194 .24515 .35367 .2444 .35258 .24361 Mtetra
.673 .827 .957 r
.35258 .24361 .35367 .2444 .35539 .24382 .35431 .24292 Mtetra
.679 .805 .942 r
.35431 .24292 .35539 .24382 .35711 .24331 .35604 .24222 Mtetra
.687 .766 .912 r
.35604 .24222 .35711 .24331 .35884 .24276 .35778 .24148 Mtetra
.669 .726 .892 r
.35778 .24148 .35884 .24276 .36057 .24219 .35951 .2408 Mtetra
.65 .701 .883 r
.35951 .2408 .36057 .24219 .3623 .24151 .36124 .24021 Mtetra
.652 .716 .895 r
.36124 .24021 .3623 .24151 .36406 .24042 .36297 .23961 Mtetra
.469 .75 .991 r
.36297 .23961 .36406 .24042 .3658 .23965 .36468 .23946 Mtetra
.528 0 0 r
.36468 .23946 .3658 .23965 .3675 .23971 .36633 .24046 Mtetra
.922 .588 .391 r
.36633 .24046 .3675 .23971 .36903 .24304 .36751 .25079 Mtetra
.952 .672 .469 r
.36751 .25079 .36903 .24304 .36048 .44703 .35895 .45366 Mtetra
.648 .333 .425 r
.35895 .45366 .36048 .44703 .36193 .45462 .36062 .45676 Mtetra
.404 0 .13 r
.36062 .45676 .36193 .45462 .36376 .45456 .36246 .45663 Mtetra
.232 0 .029 r
.36246 .45663 .36376 .45456 .36564 .45366 .36433 .45584 Mtetra
.168 0 .012 r
.36433 .45584 .36564 .45366 .36751 .45276 .36622 .45478 Mtetra
.271 0 .043 r
.36622 .45478 .36751 .45276 .36931 .45344 .36808 .45415 Mtetra
0 0 0 r
.36808 .45415 .36931 .45344 .37112 .45398 .36995 .45352 Mtetra
.592 .884 .992 r
.36995 .45352 .37112 .45398 .37295 .45419 .37182 .45289 Mtetra
.632 .728 .917 r
.37182 .45289 .37295 .45419 .37482 .45371 .37369 .45234 Mtetra
.644 .72 .903 r
.37369 .45234 .37482 .45371 .37669 .45305 .37556 .45173 Mtetra
.671 .737 .9 r
.37556 .45173 .37669 .45305 .37857 .45233 .37744 .451 Mtetra
.734 .754 .868 r
.37744 .451 .37857 .45233 .38044 .45175 .37933 .44989 Mtetra
.721 .68 .81 r
.37933 .44989 .38044 .45175 .38231 .45117 .38123 .44867 Mtetra
.684 .608 .764 r
.38123 .44867 .38231 .45117 .38418 .45061 .38313 .44753 Mtetra
.546 .494 .749 r
.38313 .44753 .38418 .45061 .38604 .45041 .38499 .44742 Mtetra
.597 .529 .748 r
.38499 .44742 .38604 .45041 .38792 .44986 .38686 .44693 Mtetra
.698 .588 .729 r
.38686 .44693 .38792 .44986 .38983 .4486 .38878 .44544 Mtetra
.894 .672 .595 r
.38878 .44544 .38983 .4486 .39187 .44392 .39099 .43664 Mtetra
.959 .683 .468 r
.39099 .43664 .39187 .44392 .40191 .24018 .40124 .22932 Mtetra
.671 .45 .577 r
.40124 .22932 .40191 .24018 .4041 .22879 .40317 .22467 Mtetra
.639 .498 .674 r
.40317 .22467 .4041 .22879 .40589 .22732 .40495 .22348 Mtetra
.592 .477 .69 r
.40495 .22348 .40589 .22732 .40765 .2268 .40671 .22291 Mtetra
.559 .454 .691 r
.40671 .22291 .40765 .2268 .40939 .22678 .40846 .22266 Mtetra
.595 .469 .679 r
.40846 .22266 .40939 .22678 .41116 .22615 .41022 .22202 Mtetra
.594 .468 .678 r
.41022 .22202 .41116 .22615 .41292 .22554 .41199 .22139 Mtetra
.593 .467 .678 r
.41199 .22139 .41292 .22554 .41469 .22494 .41375 .22076 Mtetra
.593 .466 .677 r
.41375 .22076 .41469 .22494 .41645 .22453 .41552 .22013 Mtetra
.59 .458 .669 r
.41552 .22013 .41645 .22453 .41821 .22397 .41729 .2195 Mtetra
.588 .455 .667 r
.41729 .2195 .41821 .22397 .41999 .22309 .41906 .21888 Mtetra
.589 .463 .676 r
.41906 .21888 .41999 .22309 .42181 .22126 .42083 .2183 Mtetra
.61 .527 .736 r
.42083 .2183 .42181 .22126 .42362 .21952 .4226 .21771 Mtetra
.64 .641 .835 r
.4226 .21771 .42362 .21952 .42542 .21804 .42437 .21711 Mtetra
.668 .8 .946 r
.42437 .21711 .42542 .21804 .4272 .21721 .42614 .21643 Mtetra
.669 .833 .962 r
.42614 .21643 .4272 .21721 .42897 .21659 .42792 .21573 Mtetra
.673 .818 .953 r
.42792 .21573 .42897 .21659 .43074 .21608 .4297 .21502 Mtetra
.666 .774 .93 r
.4297 .21502 .43074 .21608 .43252 .21554 .43148 .21436 Mtetra
.664 .749 .913 r
.43148 .21436 .43252 .21554 .43429 .215 .43326 .21369 Mtetra
.663 .726 .896 r
.43326 .21369 .43429 .215 .43607 .21444 .43504 .21303 Mtetra
.679 .712 .874 r
.43504 .21303 .43607 .21444 .43785 .2138 .43683 .21227 Mtetra
.668 .691 .862 r
.43683 .21227 .43785 .2138 .43964 .21311 .43861 .21155 Mtetra
.649 .678 .864 r
.43861 .21155 .43964 .21311 .44142 .21239 .44039 .21093 Mtetra
.66 .699 .875 r
.44039 .21093 .44142 .21239 .44322 .21125 .44218 .21026 Mtetra
.555 .75 .968 r
.44218 .21026 .44322 .21125 .44501 .21034 .44396 .20995 Mtetra
0 .463 .762 r
.44396 .20995 .44501 .21034 .44679 .20999 .44572 .21039 Mtetra
.894 .505 .281 r
.44572 .21039 .44679 .20999 .4485 .21236 .44735 .21595 Mtetra
.964 .677 .439 r
.44735 .21595 .4485 .21236 .44572 .3976 .44394 .42384 Mtetra
.576 .313 .482 r
.44394 .42384 .44572 .3976 .44693 .42586 .44574 .42822 Mtetra
.487 .08 .194 r
.44574 .42822 .44693 .42586 .44882 .42651 .44764 .42852 Mtetra
.267 0 .042 r
.44764 .42852 .44882 .42651 .45074 .42574 .44956 .42786 Mtetra
.168 0 .009 r
.44956 .42786 .45074 .42574 .45268 .42463 .4515 .42678 Mtetra
.286 0 .07 r
.4515 .42678 .45268 .42463 .45458 .42505 .45343 .42612 Mtetra
.092 0 0 r
.45343 .42612 .45458 .42505 .45648 .42563 .45535 .42551 Mtetra
.52 .907 .938 r
.45535 .42551 .45648 .42563 .45839 .42595 .45728 .42479 Mtetra
.733 .789 .897 r
.45728 .42479 .45839 .42595 .46031 .42562 .45922 .42371 Mtetra
.721 .681 .811 r
.45922 .42371 .46031 .42562 .46224 .42501 .46117 .42248 Mtetra
.694 .614 .762 r
.46117 .42248 .46224 .42501 .46417 .42429 .46311 .42123 Mtetra
.573 .513 .75 r
.46311 .42123 .46417 .42429 .4661 .424 .46504 .42091 Mtetra
.581 .517 .748 r
.46504 .42091 .4661 .424 .46803 .42353 .46697 .42053 Mtetra
.664 .568 .737 r
.46697 .42053 .46803 .42353 .46998 .4225 .46891 .4194 Mtetra
.866 .664 .628 r
.46891 .4194 .46998 .4225 .47196 .41902 .47094 .41356 Mtetra
.967 .684 .442 r
.47094 .41356 .47196 .41902 .47405 .40861 .47624 .20365 Mtetra
.53 .298 .508 r
.47624 .20365 .47405 .40861 .4791 .20232 .47813 .19758 Mtetra
.66 .497 .652 r
.47813 .19758 .4791 .20232 .48095 .19892 .47996 .19586 Mtetra
.613 .525 .731 r
.47996 .19586 .48095 .19892 .48278 .19721 .48177 .19521 Mtetra
.572 .588 .831 r
.48177 .19521 .48278 .19721 .48459 .19609 .48358 .19495 Mtetra
.639 .753 .931 r
.48358 .19495 .48459 .19609 .48641 .19533 .48539 .19438 Mtetra
.672 .805 .946 r
.48539 .19438 .48641 .19533 .48822 .19477 .48721 .19368 Mtetra
.675 .773 .924 r
.48721 .19368 .48822 .19477 .49004 .19432 .48903 .19296 Mtetra
.681 .726 .883 r
.48903 .19296 .49004 .19432 .49185 .19373 .49084 .19218 Mtetra
.672 .694 .862 r
.49084 .19218 .49185 .19373 .49367 .19303 .49266 .19143 Mtetra
.654 .678 .86 r
.49266 .19143 .49367 .19303 .49549 .1923 .49448 .19076 Mtetra
.663 .691 .866 r
.49448 .19076 .49549 .1923 .49732 .19119 .49631 .19005 Mtetra
.607 .742 .94 r
.49631 .19005 .49732 .19119 .49914 .19018 .49813 .1896 Mtetra
.191 .651 .941 r
.49813 .1896 .49914 .19018 .50096 .18966 .49994 .18977 Mtetra
.844 .392 .131 r
.49994 .18977 .50096 .18966 .50277 .19111 .50174 .19322 Mtetra
.969 .677 .417 r
.50174 .19322 .50277 .19111 .50455 .1975 .50209 .4017 Mtetra
.527 .291 .5 r
.50209 .4017 .50455 .1975 .50511 .4048 .504 .40795 Mtetra
.554 .176 .28 r
.504 .40795 .50511 .4048 .50705 .4078 .50596 .40879 Mtetra
.068 0 0 r
.50596 .40879 .50705 .4078 .509 .40846 .50792 .40816 Mtetra
.712 .954 .95 r
.50792 .40816 .509 .40846 .51097 .40838 .50989 .40703 Mtetra
.602 .717 .925 r
.50989 .40703 .51097 .40838 .51293 .40819 .51186 .40658 Mtetra
.589 .668 .893 r
.51186 .40658 .51293 .40819 .5149 .40765 .51382 .40619 Mtetra
.722 .743 .869 r
.51382 .40619 .5149 .40765 .51687 .40645 .5158 .40511 Mtetra
.926 .774 .674 r
.5158 .40511 .51687 .40645 .51885 .40308 .51778 .40059 Mtetra
.973 .686 .421 r
.51778 .40059 .51885 .40308 .52083 .3923 .52008 .18971 Mtetra
.534 .302 .508 r
.52008 .18971 .52083 .3923 .52293 .18624 .52193 .18154 Mtetra
.685 .514 .649 r
.52193 .18154 .52293 .18624 .52477 .18266 .52377 .17938 Mtetra
.609 .513 .72 r
.52377 .17938 .52477 .18266 .52661 .18097 .52562 .17872 Mtetra
.553 .553 .808 r
.52562 .17872 .52661 .18097 .52845 .17987 .52746 .17856 Mtetra
.576 .697 .924 r
.52746 .17856 .52845 .17987 .5303 .17914 .5293 .17823 Mtetra
.615 .797 .969 r
.5293 .17823 .5303 .17914 .53214 .17867 .53115 .17771 Mtetra
.62 .788 .962 r
.53115 .17771 .53214 .17867 .53399 .17833 .53299 .17717 Mtetra
.632 .751 .933 r
.53299 .17717 .53399 .17833 .53583 .17789 .53484 .17662 Mtetra
.64 .731 .914 r
.53484 .17662 .53583 .17789 .53768 .17735 .53669 .17604 Mtetra
.648 .727 .907 r
.53669 .17604 .53768 .17735 .53953 .17676 .53854 .17542 Mtetra
.662 .726 .897 r
.53854 .17542 .53953 .17676 .54138 .17615 .54039 .17473 Mtetra
.671 .718 .884 r
.54039 .17473 .54138 .17615 .54324 .1755 .54225 .17399 Mtetra
.672 .704 .871 r
.54225 .17399 .54324 .1755 .54509 .17482 .5441 .17324 Mtetra
.667 .69 .862 r
.5441 .17324 .54509 .17482 .54695 .17413 .54595 .1725 Mtetra
.663 .682 .858 r
.54595 .1725 .54695 .17413 .5488 .17341 .54781 .17177 Mtetra
.663 .681 .857 r
.54781 .17177 .5488 .17341 .55066 .17267 .54967 .17104 Mtetra
.664 .683 .857 r
.54967 .17104 .55066 .17267 .55252 .17193 .55153 .1703 Mtetra
.666 .685 .858 r
.55153 .1703 .55252 .17193 .55437 .17117 .55339 .16956 Mtetra
.667 .687 .859 r
.55339 .16956 .55437 .17117 .55623 .17039 .55525 .16881 Mtetra
.669 .693 .864 r
.55525 .16881 .55623 .17039 .55809 .16954 .55711 .16806 Mtetra
.672 .708 .875 r
.55711 .16806 .55809 .16954 .55995 .16866 .55897 .1673 Mtetra
.674 .731 .893 r
.55897 .1673 .55995 .16866 .56182 .16779 .56084 .16655 Mtetra
.675 .753 .91 r
.56084 .16655 .56182 .16779 .56368 .16697 .5627 .16581 Mtetra
.674 .767 .921 r
.5627 .16581 .56368 .16697 .56555 .16622 .56457 .16508 Mtetra
.672 .771 .925 r
.56457 .16508 .56555 .16622 .56741 .16548 .56644 .16435 Mtetra
.671 .772 .926 r
.56644 .16435 .56741 .16548 .56928 .16476 .56831 .16363 Mtetra
.669 .773 .927 r
.56831 .16363 .56928 .16476 .57115 .16404 .57018 .16291 Mtetra
.668 .774 .929 r
.57018 .16291 .57115 .16404 .57302 .16332 .57205 .1622 Mtetra
.667 .775 .93 r
.57205 .1622 .57302 .16332 .57489 .16261 .57392 .1615 Mtetra
.666 .776 .931 r
.57392 .1615 .57489 .16261 .57677 .1619 .5758 .16079 Mtetra
.666 .776 .932 r
.5758 .16079 .57677 .1619 .57864 .1612 .57767 .16009 Mtetra
.665 .776 .932 r
.57767 .16009 .57864 .1612 .58052 .1605 .57955 .15939 Mtetra
.57955 .15939 .58052 .1605 .5824 .1598 .58143 .15869 Mtetra
.664 .776 .933 r
.58143 .15869 .5824 .1598 .58428 .1591 .58331 .15799 Mtetra
.58331 .15799 .58428 .1591 .58616 .1584 .58519 .15729 Mtetra
.664 .777 .933 r
.58519 .15729 .58616 .1584 .58804 .1577 .58707 .15659 Mtetra
.58707 .15659 .58804 .1577 .58992 .15701 .58896 .1559 Mtetra
.664 .776 .933 r
.58896 .1559 .58992 .15701 .59181 .15631 .59084 .1552 Mtetra
.59084 .1552 .59181 .15631 .59369 .15561 .59273 .1545 Mtetra
.663 .776 .933 r
.59273 .1545 .59369 .15561 .59558 .15492 .59462 .15381 Mtetra
.59462 .15381 .59558 .15492 .59747 .15422 .59651 .15311 Mtetra
.59651 .15311 .59747 .15422 .59935 .15353 .5984 .15241 Mtetra
.5984 .15241 .59935 .15353 .60125 .15283 .60029 .15171 Mtetra
.60029 .15171 .60125 .15283 .60314 .15214 .60218 .15102 Mtetra
.60218 .15102 .60314 .15214 .60503 .15144 .60407 .15032 Mtetra
.662 .776 .933 r
.60407 .15032 .60503 .15144 .60693 .15075 .60597 .14963 Mtetra
.662 .775 .933 r
.60597 .14963 .60693 .15075 .60882 .15006 .60787 .14893 Mtetra
.661 .775 .933 r
.60787 .14893 .60882 .15006 .61072 .14937 .60976 .14824 Mtetra
.661 .774 .933 r
.60976 .14824 .61072 .14937 .61262 .14868 .61166 .14755 Mtetra
.66 .773 .933 r
.61166 .14755 .61262 .14868 .61452 .148 .61357 .14687 Mtetra
.659 .773 .933 r
.61357 .14687 .61452 .148 .61642 .14731 .61547 .14618 Mtetra
.658 .773 .934 r
.61547 .14618 .61642 .14731 .61832 .14665 .61737 .1455 Mtetra
.657 .77 .932 r
.61737 .1455 .61832 .14665 .62023 .14603 .61928 .14483 Mtetra
.656 .758 .925 r
.61928 .14483 .62023 .14603 .62214 .14547 .62118 .14415 Mtetra
.657 .737 .909 r
.62118 .14415 .62214 .14547 .62405 .14491 .62309 .14348 Mtetra
.657 .716 .892 r
.62309 .14348 .62405 .14491 .62596 .14432 .625 .1428 Mtetra
.657 .701 .879 r
.625 .1428 .62596 .14432 .62787 .14366 .62691 .1421 Mtetra
.658 .696 .874 r
.62691 .1421 .62787 .14366 .62978 .14297 .62882 .14139 Mtetra
.665 .697 .87 r
.62882 .14139 .62978 .14297 .63169 .14226 .63073 .14065 Mtetra
.672 .694 .862 r
.63073 .14065 .63169 .14226 .63361 .14155 .63264 .13985 Mtetra
.66 .677 .855 r
.63264 .13985 .63361 .14155 .63552 .14081 .63456 .13911 Mtetra
.626 .663 .865 r
.63456 .13911 .63552 .14081 .63743 .13999 .63648 .13856 Mtetra
.558 .673 .915 r
.63648 .13856 .63743 .13999 .63934 .13909 .63841 .1383 Mtetra
.466 .767 .996 r
.63841 .1383 .63934 .13909 .64125 .13818 .64035 .13809 Mtetra
.384 .844 .886 r
.64035 .13809 .64125 .13818 .64316 .13718 .64228 .13755 Mtetra
.473 .874 .707 r
.64228 .13755 .64316 .13718 .64506 .13607 .64418 .13636 Mtetra
.287 .773 .695 r
.64418 .13636 .64506 .13607 .64698 .13536 .64611 .13562 Mtetra
.477 0 0 r
.64611 .13562 .64698 .13536 .64895 .13568 .6481 .13647 Mtetra
.936 .572 .287 r
.6481 .13647 .64895 .13568 .65105 .13905 .65059 .14916 Mtetra
.968 .657 .371 r
.65059 .14916 .65105 .13905 .66202 .34727 .66135 .35384 Mtetra
.623 .294 .393 r
.66135 .35384 .66202 .34727 .66444 .35467 .66357 .35651 Mtetra
.334 0 .047 r
.66357 .35651 .66444 .35467 .66659 .35567 .66567 .35615 Mtetra
0 0 0 r
.66567 .35615 .66659 .35567 .6687 .35572 .66773 .35515 Mtetra
.72 .927 .96 r
.66773 .35515 .6687 .35572 .6708 .35532 .6698 .35403 Mtetra
.63 .752 .935 r
.6698 .35403 .6708 .35532 .67289 .35473 .67188 .35341 Mtetra
.64 .751 .929 r
.67188 .35341 .67289 .35473 .67497 .35401 .67397 .35275 Mtetra
.644 .764 .936 r
.67397 .35275 .67497 .35401 .67706 .35347 .67606 .35207 Mtetra
.636 .734 .919 r
.67606 .35207 .67706 .35347 .67918 .3535 .67815 .35143 Mtetra
.702 .67 .816 r
.67815 .35143 .67918 .3535 .68128 .35297 .68022 .35027 Mtetra
.794 .659 .714 r
.68022 .35027 .68128 .35297 .68331 .35099 .68221 .34759 Mtetra
.945 .687 .515 r
.68221 .34759 .68331 .35099 .685 .34235 .68367 .3343 Mtetra
.974 .67 .365 r
.68367 .3343 .685 .34235 .67618 .12893 .67524 .12727 Mtetra
.91 .759 .681 r
.67524 .12727 .67618 .12893 .67793 .12439 .67702 .12341 Mtetra
.738 .837 .926 r
.67702 .12341 .67793 .12439 .67986 .12336 .67895 .12235 Mtetra
.596 .778 .967 r
.67895 .12235 .67986 .12336 .68182 .12301 .68091 .12186 Mtetra
.557 .731 .956 r
.68091 .12186 .68182 .12301 .6838 .12287 .68288 .12154 Mtetra
.68 .749 .903 r
.68288 .12154 .6838 .12287 .68575 .12218 .68482 .12074 Mtetra
.67 .726 .891 r
.68482 .12074 .68575 .12218 .6877 .12142 .68677 .11997 Mtetra
.662 .72 .892 r
.68677 .11997 .6877 .12142 .68964 .12051 .68872 .11925 Mtetra
.676 .761 .915 r
.68872 .11925 .68964 .12051 .69156 .11915 .69067 .11847 Mtetra
.486 .808 1 r
.69067 .11847 .69156 .11915 .6935 .11825 .69265 .11815 Mtetra
.379 0 0 r
.69265 .11815 .6935 .11825 .69551 .11848 .6947 .11902 Mtetra
.926 .541 .233 r
.6947 .11902 .69551 .11848 .69786 .12442 .69729 .12913 Mtetra
.972 .658 .335 r
.69729 .12913 .69786 .12442 .71252 .33759 .71157 .33685 Mtetra
.707 .209 0 r
.71157 .33685 .71252 .33759 .71492 .34167 .71392 .34008 Mtetra
.395 .579 .913 r
.71392 .34008 .71492 .34167 .71708 .34179 .7161 .34039 Mtetra
.661 .749 .916 r
.7161 .34039 .71708 .34179 .71919 .34083 .71822 .33962 Mtetra
.857 .836 .824 r
.71822 .33962 .71919 .34083 .72122 .33869 .72025 .33748 Mtetra
.981 .777 .556 r
.72025 .33748 .72122 .33869 .72306 .33362 .72193 .32983 Mtetra
.976 .67 .338 r
.72193 .32983 .72306 .33362 .7119 .12368 .71054 .11528 Mtetra
.716 .489 .581 r
.71054 .11528 .7119 .12368 .71331 .11421 .71222 .11009 Mtetra
.636 .501 .681 r
.71222 .11009 .71331 .11421 .71517 .11179 .71416 .1089 Mtetra
.594 .532 .754 r
.71416 .1089 .71517 .11179 .71709 .11028 .71615 .10841 Mtetra
.547 .602 .86 r
.71615 .10841 .71709 .11028 .71905 .10925 .71816 .10823 Mtetra
.647 .801 .957 r
.71816 .10823 .71905 .10925 .72102 .10853 .72014 .10756 Mtetra
.65 .813 .962 r
.72014 .10756 .72102 .10853 .72301 .10799 .72211 .10686 Mtetra
.671 .788 .937 r
.72211 .10686 .72301 .10799 .725 .10747 .72409 .10609 Mtetra
.758 .773 .865 r
.72409 .10609 .725 .10747 .72695 .10637 .72603 .10481 Mtetra
.686 .715 .871 r
.72603 .10481 .72695 .10637 .72892 .10556 .728 .10393 Mtetra
.5 .612 .895 r
.728 .10393 .72892 .10556 .73094 .10543 .73003 .10392 Mtetra
.741 .336 0 r
.73003 .10392 .73094 .10543 .73319 .10845 .73243 .10908 Mtetra
.971 .656 .304 r
.73243 .10908 .73319 .10845 .75014 .31625 .74974 .32276 Mtetra
.693 .349 .389 r
.74974 .32276 .75014 .31625 .753 .32559 .75227 .32746 Mtetra
.39 0 .072 r
.75227 .32746 .753 .32559 .75529 .32687 .75446 .32736 Mtetra
0 0 0 r
.75446 .32736 .75529 .32687 .7575 .3271 .7566 .32646 Mtetra
.755 .932 .945 r
.7566 .32646 .7575 .3271 .75968 .32679 .7587 .32516 Mtetra
.523 .646 .911 r
.7587 .32516 .75968 .32679 .76186 .32652 .7609 .32502 Mtetra
.617 .714 .915 r
.7609 .32502 .76186 .32652 .76401 .32574 .76306 .32445 Mtetra
.769 .81 .886 r
.76306 .32445 .76401 .32574 .7661 .32422 .76516 .32305 Mtetra
.923 .755 .655 r
.08224 .54741 .08355 .54804 .08596 .54188 .08465 .54128 Mtetra
.937 .687 .534 r
.08465 .54128 .08596 .54188 .11421 .3368 .11308 .33548 Mtetra
.897 .716 .65 r
.11308 .33548 .11421 .3368 .11646 .33104 .11534 .32966 Mtetra
.736 .71 .826 r
.11534 .32966 .11646 .33104 .11812 .32987 .11699 .32858 Mtetra
.59 .679 .903 r
.11699 .32858 .11812 .32987 .11968 .32945 .11853 .32827 Mtetra
.419 .63 .941 r
.11853 .32827 .11968 .32945 .12118 .32943 .12002 .32838 Mtetra
.636 .739 .923 r
.12002 .32838 .12118 .32943 .12275 .32894 .12159 .3279 Mtetra
.659 .748 .916 r
.12159 .3279 .12275 .32894 .12433 .3284 .12317 .32733 Mtetra
.675 .746 .904 r
.12317 .32733 .12433 .3284 .12591 .32783 .12476 .32669 Mtetra
.739 .747 .859 r
.12476 .32669 .12591 .32783 .12751 .32709 .1264 .32569 Mtetra
.705 .699 .842 r
.1264 .32569 .12751 .32709 .12912 .32637 .12802 .32483 Mtetra
.64 .657 .851 r
.12802 .32483 .12912 .32637 .13071 .32575 .1296 .3243 Mtetra
.186 .449 .875 r
.1296 .3243 .13071 .32575 .1323 .32511 .13104 .32491 Mtetra
.786 .303 .075 r
.13104 .32491 .1323 .32511 .13385 .32484 .13233 .32672 Mtetra
.839 .513 .437 r
.13233 .32672 .13385 .32484 .13531 .32531 .13314 .33243 Mtetra
.929 .671 .525 r
.13314 .33243 .13531 .32531 .13616 .33075 .11007 .53126 Mtetra
.525 .289 .5 r
.11007 .53126 .13616 .33075 .11281 .5333 .11116 .5355 Mtetra
.666 .287 .319 r
.11116 .5355 .11281 .5333 .1139 .53764 .11259 .53714 Mtetra
.42 .796 .993 r
.11259 .53714 .1139 .53764 .11549 .53788 .11424 .53693 Mtetra
.699 .79 .921 r
.11424 .53693 .11549 .53788 .1172 .53722 .11596 .53615 Mtetra
.737 .773 .882 r
.11596 .53615 .1172 .53722 .11896 .53616 .11771 .53513 Mtetra
.55 .734 .961 r
.11771 .53513 .11896 .53616 .12065 .53564 .11938 .53487 Mtetra
.53 .783 .99 r
.11938 .53487 .12065 .53564 .12234 .53518 .12104 .53459 Mtetra
.649 .856 .979 r
.12104 .53459 .12234 .53518 .12404 .5346 .12275 .53395 Mtetra
.847 .837 .835 r
.12275 .53395 .12404 .5346 .12573 .53407 .1246 .53211 Mtetra
.829 .687 .707 r
.1246 .53211 .12573 .53407 .12748 .53316 .12662 .52893 Mtetra
.827 .619 .621 r
.12662 .52893 .12748 .53316 .12931 .53146 .12908 .52194 Mtetra
.931 .677 .53 r
.12908 .52194 .12931 .53146 .13172 .52489 .15432 .32163 Mtetra
.529 .298 .509 r
.15432 .32163 .13172 .52489 .15723 .3208 .15646 .31648 Mtetra
.717 .542 .651 r
.15646 .31648 .15723 .3208 .15938 .31552 .1583 .31387 Mtetra
.709 .67 .81 r
.1583 .31387 .15938 .31552 .16109 .31407 .15996 .31288 Mtetra
.61 .709 .915 r
.15996 .31288 .16109 .31407 .16268 .31355 .16154 .31249 Mtetra
.515 .7 .953 r
.16154 .31249 .16268 .31355 .16424 .31341 .16309 .31235 Mtetra
.678 .753 .907 r
.16309 .31235 .16424 .31341 .16584 .31288 .16471 .31169 Mtetra
.683 .73 .886 r
.16471 .31169 .16584 .31288 .16745 .31226 .16633 .31099 Mtetra
.62 .698 .9 r
.16633 .31099 .16745 .31226 .16906 .31171 .16792 .31057 Mtetra
.178 .511 .913 r
.16792 .31057 .16906 .31171 .17067 .31106 .16941 .31104 Mtetra
.753 .259 .057 r
.16941 .31104 .17067 .31106 .17226 .31069 .17077 .31267 Mtetra
.821 .485 .419 r
.17077 .31267 .17226 .31069 .17377 .31098 .17177 .3176 Mtetra
.934 .673 .517 r
.17177 .3176 .17377 .31098 .17484 .31529 .15099 .51703 Mtetra
.525 .29 .5 r
.15099 .51703 .17484 .31529 .15379 .51882 .15212 .52173 Mtetra
.658 .299 .352 r
.15212 .52173 .15379 .51882 .15489 .52383 .15358 .52354 Mtetra
.006 .569 .801 r
.15358 .52354 .15489 .52383 .15647 .52451 .15522 .52372 Mtetra
.655 .816 .961 r
.15522 .52372 .15647 .52451 .15819 .52397 .15695 .52309 Mtetra
.771 .813 .886 r
.15695 .52309 .15819 .52397 .15997 .52292 .15874 .52189 Mtetra
.828 .784 .81 r
.15874 .52189 .15997 .52292 .16171 .52223 .16061 .52 Mtetra
.81 .668 .706 r
.16061 .52 .16171 .52223 .16346 .52143 .16259 .51704 Mtetra
.806 .603 .628 r
.16259 .51704 .16346 .52143 .16529 .51992 .16488 .51129 Mtetra
.936 .679 .523 r
.16488 .51129 .16529 .51992 .16751 .51473 .18807 .31103 Mtetra
.531 .3 .509 r
.18807 .31103 .16751 .51473 .191 .30999 .19029 .30486 Mtetra
.709 .522 .635 r
.19029 .30486 .191 .30999 .19325 .3035 .19216 .30196 Mtetra
.751 .698 .801 r
.19216 .30196 .19325 .3035 .19501 .30163 .19387 .30066 Mtetra
.674 .772 .924 r
.19387 .30066 .19501 .30163 .19665 .30096 .1955 .30001 Mtetra
.611 .761 .951 r
.1955 .30001 .19665 .30096 .19824 .30068 .19711 .29959 Mtetra
.746 .764 .867 r
.19711 .29959 .19824 .30068 .1999 .29979 .19878 .29855 Mtetra
.739 .736 .849 r
.19878 .29855 .1999 .29979 .20156 .29886 .20046 .29749 Mtetra
.628 .685 .885 r
.20046 .29749 .20156 .29886 .20317 .2985 .20208 .29703 Mtetra
.694 .243 0 r
.20208 .29703 .20317 .2985 .20451 .30076 .20342 .29923 Mtetra
.948 .685 .505 r
.20342 .29923 .20451 .30076 .18559 .50152 .18441 .50011 Mtetra
.955 .645 .405 r
.18441 .50011 .18559 .50152 .18615 .51251 .1849 .51173 Mtetra
.484 0 0 r
.1849 .51173 .18615 .51251 .18771 .51374 .18647 .51291 Mtetra
.692 .818 .943 r
.18647 .51291 .18771 .51374 .18946 .51311 .18823 .51214 Mtetra
.792 .8 .858 r
.18823 .51214 .18946 .51311 .19127 .51188 .19006 .51072 Mtetra
.747 .765 .868 r
.19006 .51072 .19127 .51188 .19305 .51089 .19186 .50959 Mtetra
.684 .73 .886 r
.19186 .50959 .19305 .51089 .19481 .51017 .19363 .50883 Mtetra
.662 .718 .89 r
.19363 .50883 .19481 .51017 .19657 .50948 .19538 .50818 Mtetra
.612 .708 .913 r
.19538 .50818 .19657 .50948 .19833 .50887 .19712 .50774 Mtetra
.566 .725 .949 r
.19712 .50774 .19833 .50887 .20007 .50832 .19884 .50744 Mtetra
.543 .769 .981 r
.19884 .50744 .20007 .50832 .20182 .50782 .20057 .50714 Mtetra
.589 .828 .99 r
.20057 .50714 .20182 .50782 .20356 .50735 .20231 .50667 Mtetra
.633 .839 .979 r
.20231 .50667 .20356 .50735 .2053 .50691 .20406 .50608 Mtetra
.638 .808 .965 r
.20406 .50608 .2053 .50691 .20704 .50649 .20582 .5055 Mtetra
.522 .737 .972 r
.20582 .5055 .20704 .50649 .20877 .50615 .20754 .50529 Mtetra
.458 .739 .989 r
.20754 .50529 .20877 .50615 .2105 .50581 .20926 .50516 Mtetra
.576 .832 .994 r
.20926 .50516 .2105 .50581 .21225 .50534 .211 .50471 Mtetra
.81 .864 .888 r
.211 .50471 .21225 .50534 .21401 .50484 .21284 .50328 Mtetra
.842 .726 .736 r
.21284 .50328 .21401 .50484 .21578 .50407 .21481 .50048 Mtetra
.825 .629 .637 r
.21481 .50048 .21578 .50407 .21763 .50262 .21703 .49504 Mtetra
.942 .681 .511 r
.21703 .49504 .21763 .50262 .21974 .49817 .23735 .29324 Mtetra
.533 .301 .509 r
.23735 .29324 .21974 .49817 .24021 .29287 .23959 .28638 Mtetra
.686 .49 .615 r
.23959 .28638 .24021 .29287 .24249 .28546 .24147 .28333 Mtetra
.731 .638 .755 r
.24147 .28333 .24249 .28546 .2443 .2832 .2432 .2819 Mtetra
.644 .705 .892 r
.2432 .2819 .2443 .2832 .24596 .28249 .24485 .28136 Mtetra
.561 .708 .939 r
.24485 .28136 .24596 .28249 .24759 .28222 .24648 .2811 Mtetra
.657 .743 .913 r
.24648 .2811 .24759 .28222 .24924 .2818 .24814 .28051 Mtetra
.713 .728 .862 r
.24814 .28051 .24924 .2818 .25091 .28111 .24983 .27962 Mtetra
.664 .681 .856 r
.24983 .27962 .25091 .28111 .25257 .28049 .25149 .27896 Mtetra
.404 .558 .894 r
.25149 .27896 .25257 .28049 .25421 .28011 .25308 .27921 Mtetra
.642 .116 0 r
.25308 .27921 .25421 .28011 .25584 .27997 .25455 .28085 Mtetra
.83 .444 .321 r
.25455 .28085 .25584 .27997 .25746 .27988 .25586 .2844 Mtetra
.725 .402 .432 r
.25586 .2844 .25746 .27988 .25912 .27928 .25713 .28846 Mtetra
.412 .141 .39 r
.25713 .28846 .25912 .27928 .26082 .27831 .25888 .28691 Mtetra
.443 .164 .395 r
.25888 .28691 .26082 .27831 .26248 .27785 .26059 .28592 Mtetra
.941 .671 .498 r
.26059 .28592 .26248 .27785 .26394 .27973 .24589 .47915 Mtetra
.535 .298 .502 r
.24589 .47915 .26394 .27973 .24867 .48178 .24682 .48855 Mtetra
.643 .335 .434 r
.24682 .48855 .24867 .48178 .24961 .49133 .24831 .49147 Mtetra
.52 0 0 r
.24831 .49147 .24961 .49133 .2512 .49308 .24998 .49228 Mtetra
.581 .803 .984 r
.24998 .49228 .2512 .49308 .25296 .49275 .25176 .49185 Mtetra
.689 .812 .941 r
.25176 .49185 .25296 .49275 .25477 .49188 .25356 .49108 Mtetra
.651 .822 .965 r
.25356 .49108 .25477 .49188 .25658 .49107 .25535 .49044 Mtetra
.545 .827 .998 r
.25535 .49044 .25658 .49107 .25837 .49054 .25713 .49003 Mtetra
.635 .881 .986 r
.25713 .49003 .25837 .49054 .26016 .48992 .25893 .48936 Mtetra
.804 .886 .904 r
.25893 .48936 .26016 .48992 .26196 .48928 .26079 .48798 Mtetra
.853 .759 .758 r
.26079 .48798 .26196 .48928 .26376 .48852 .26274 .48539 Mtetra
.825 .641 .654 r
.26274 .48539 .26376 .48852 .26562 .48717 .26485 .48083 Mtetra
.949 .683 .5 r
.26485 .48083 .26562 .48717 .26764 .48362 .28222 .28095 Mtetra
.541 .307 .51 r
.28222 .28095 .26764 .48362 .28511 .28019 .28468 .27048 Mtetra
.655 .445 .587 r
.28468 .27048 .28511 .28019 .28759 .26938 .28659 .26698 Mtetra
.746 .628 .728 r
.28659 .26698 .28759 .26938 .28944 .26655 .28837 .26517 Mtetra
.686 .711 .867 r
.28837 .26517 .28944 .26655 .29115 .26569 .29006 .26441 Mtetra
.612 .7 .907 r
.29006 .26441 .29115 .26569 .29282 .26535 .29174 .26399 Mtetra
.587 .678 .903 r
.29174 .26399 .29282 .26535 .29448 .26507 .2934 .26367 Mtetra
.612 .681 .891 r
.2934 .26367 .29448 .26507 .29616 .26454 .29508 .26326 Mtetra
.609 .699 .908 r
.29508 .26326 .29616 .26454 .29785 .26402 .29676 .26285 Mtetra
.622 .725 .92 r
.29676 .26285 .29785 .26402 .29953 .26349 .29844 .26239 Mtetra
.65 .749 .922 r
.29844 .26239 .29953 .26349 .30122 .26292 .30013 .26182 Mtetra
.666 .753 .915 r
.30013 .26182 .30122 .26292 .30292 .26232 .30183 .26118 Mtetra
.685 .751 .901 r
.30183 .26118 .30292 .26232 .30461 .26169 .30353 .26045 Mtetra
.699 .738 .881 r
.30353 .26045 .30461 .26169 .30631 .26101 .30524 .25964 Mtetra
.695 .714 .864 r
.30524 .25964 .30631 .26101 .30802 .26032 .30695 .25882 Mtetra
.695 .696 .846 r
.30695 .25882 .30802 .26032 .30972 .2596 .30867 .25797 Mtetra
.691 .676 .831 r
.30867 .25797 .30972 .2596 .31143 .25886 .31039 .2571 Mtetra
.645 .642 .832 r
.31039 .2571 .31143 .25886 .31313 .25821 .31209 .25649 Mtetra
.514 .587 .866 r
.31209 .25649 .31313 .25821 .31483 .25761 .31375 .25647 Mtetra
0 .214 .711 r
.31375 .25647 .31483 .25761 .31653 .2571 .31533 .25761 Mtetra
.827 .407 .245 r
.31533 .25761 .31653 .2571 .31819 .2571 .31679 .26067 Mtetra
.953 .678 .479 r
.31679 .26067 .31819 .2571 .31974 .25883 .3051 .46014 Mtetra
.534 .297 .502 r
.3051 .46014 .31974 .25883 .30811 .46019 .30627 .46926 Mtetra
.609 .314 .443 r
.30627 .46926 .30811 .46019 .30916 .47138 .30788 .47191 Mtetra
.597 .073 0 r
.30788 .47191 .30916 .47138 .3108 .47364 .3096 .47292 Mtetra
.362 .73 .988 r
.3096 .47292 .3108 .47364 .31259 .47351 .3114 .47289 Mtetra
.62 .859 .988 r
.3114 .47289 .31259 .47351 .31443 .47276 .31323 .47228 Mtetra
.802 .91 .914 r
.31323 .47228 .31443 .47276 .31629 .47167 .31511 .47091 Mtetra
.897 .828 .771 r
.31511 .47091 .31629 .47167 .31816 .47052 .31708 .46816 Mtetra
.852 .682 .671 r
.31708 .46816 .31816 .47052 .32003 .46926 .31914 .46388 Mtetra
.794 .581 .613 r
.31914 .46388 .32003 .46926 .32189 .46826 .32131 .45778 Mtetra
.552 .365 .581 r
.32131 .45778 .32189 .46826 .3237 .46804 .32314 .45715 Mtetra
.53 .346 .577 r
.32314 .45715 .3237 .46804 .32554 .4674 .32494 .45703 Mtetra
.702 .48 .584 r
.32494 .45703 .32554 .4674 .32747 .46525 .32709 .45121 Mtetra
.946 .674 .491 r
.32709 .45121 .32747 .46525 .32995 .45378 .34084 .25155 Mtetra
.527 .296 .508 r
.34084 .25155 .32995 .45378 .34377 .24986 .3428 .24691 Mtetra
.756 .606 .692 r
.3428 .24691 .34377 .24986 .34568 .24602 .34463 .24454 Mtetra
.676 .694 .86 r
.34463 .24454 .34568 .24602 .34743 .24501 .34636 .2438 Mtetra
.596 .711 .924 r
.34636 .2438 .34743 .24501 .34914 .24457 .34807 .24342 Mtetra
.583 .719 .937 r
.34807 .24342 .34914 .24457 .35085 .2443 .34978 .24309 Mtetra
.695 .745 .89 r
.34978 .24309 .35085 .2443 .35258 .24361 .35152 .24229 Mtetra
.697 .727 .873 r
.35152 .24229 .35258 .24361 .35431 .24292 .35325 .24146 Mtetra
.694 .704 .855 r
.35325 .24146 .35431 .24292 .35604 .24222 .355 .24061 Mtetra
.695 .685 .836 r
.355 .24061 .35604 .24222 .35778 .24148 .35674 .23972 Mtetra
.653 .649 .834 r
.35674 .23972 .35778 .24148 .35951 .2408 .35847 .23906 Mtetra
.562 .609 .858 r
.35847 .23906 .35951 .2408 .36124 .24021 .36018 .23885 Mtetra
.053 .385 .847 r
.36018 .23885 .36124 .24021 .36297 .23961 .36184 .23972 Mtetra
.791 .315 .095 r
.36184 .23972 .36297 .23961 .36468 .23946 .36342 .24201 Mtetra
.887 .562 .429 r
.36342 .24201 .36468 .23946 .36633 .24046 .36455 .2531 Mtetra
.946 .665 .475 r
.36455 .2531 .36633 .24046 .36751 .25079 .35603 .45139 Mtetra
.522 .287 .499 r
.35603 .45139 .36751 .25079 .35895 .45366 .35769 .45474 Mtetra
.633 .162 .118 r
.35769 .45474 .35895 .45366 .36062 .45676 .35946 .45598 Mtetra
.515 .79 .995 r
.35946 .45598 .36062 .45676 .36246 .45663 .3613 .45568 Mtetra
.672 .806 .947 r
.3613 .45568 .36246 .45663 .36433 .45584 .36317 .45494 Mtetra
.712 .826 .936 r
.36317 .45494 .36433 .45584 .36622 .45478 .36505 .45404 Mtetra
.633 .839 .979 r
.36505 .45404 .36622 .45478 .36808 .45415 .36692 .45341 Mtetra
.633 .84 .98 r
.36692 .45341 .36808 .45415 .36995 .45352 .36879 .45278 Mtetra
.623 .838 .982 r
.36879 .45278 .36995 .45352 .37182 .45289 .37066 .45217 Mtetra
.536 .812 .997 r
.37066 .45217 .37182 .45289 .37369 .45234 .37252 .45179 Mtetra
.591 .868 .994 r
.37252 .45179 .37369 .45234 .37556 .45173 .37439 .45121 Mtetra
.733 .906 .955 r
.37439 .45121 .37556 .45173 .37744 .451 .37628 .45016 Mtetra
.894 .83 .777 r
.37628 .45016 .37744 .451 .37933 .44989 .37825 .44749 Mtetra
.851 .683 .673 r
.37825 .44749 .37933 .44989 .38123 .44867 .38028 .44336 Mtetra
.822 .599 .601 r
.38028 .44336 .38123 .44867 .38313 .44753 .38246 .43587 Mtetra
.546 .355 .574 r
.38246 .43587 .38313 .44753 .38499 .44742 .38433 .4353 Mtetra
.509 .326 .568 r
.38433 .4353 .38499 .44742 .38686 .44693 .38616 .43568 Mtetra
.609 .405 .58 r
.38616 .43568 .38686 .44693 .38878 .44544 .38811 .43326 Mtetra
.954 .676 .473 r
.38811 .43326 .38878 .44544 .39099 .43664 .39833 .23116 Mtetra
.528 .297 .508 r
.39833 .23116 .39099 .43664 .40124 .22932 .40028 .22598 Mtetra
.762 .596 .672 r
.40028 .22598 .40124 .22932 .40317 .22467 .40213 .22316 Mtetra
.713 .708 .844 r
.40213 .22316 .40317 .22467 .40495 .22348 .4039 .22217 Mtetra
.648 .717 .899 r
.4039 .22217 .40495 .22348 .40671 .22291 .40566 .22158 Mtetra
.599 .695 .91 r
.40566 .22158 .40671 .22291 .40846 .22266 .40742 .2212 Mtetra
.658 .695 .873 r
.40742 .2212 .40846 .22266 .41022 .22202 .40918 .22055 Mtetra
.657 .694 .873 r
.40918 .22055 .41022 .22202 .41199 .22139 .41095 .2199 Mtetra
.656 .691 .871 r
.41095 .2199 .41199 .22139 .41375 .22076 .41272 .21926 Mtetra
.659 .69 .868 r
.41272 .21926 .41375 .22076 .41552 .22013 .41449 .2186 Mtetra
.655 .684 .865 r
.41449 .2186 .41552 .22013 .41729 .2195 .41626 .21795 Mtetra
.648 .679 .865 r
.41626 .21795 .41729 .2195 .41906 .21888 .41802 .21734 Mtetra
.62 .668 .875 r
.41802 .21734 .41906 .21888 .42083 .2183 .41979 .21686 Mtetra
.619 .685 .89 r
.41979 .21686 .42083 .2183 .4226 .21771 .42156 .21639 Mtetra
.631 .711 .904 r
.42156 .21639 .4226 .21771 .42437 .21711 .42333 .21587 Mtetra
.686 .746 .896 r
.42333 .21587 .42437 .21711 .42614 .21643 .42511 .2151 Mtetra
.696 .733 .879 r
.42511 .2151 .42614 .21643 .42792 .21573 .42689 .21427 Mtetra
.691 .71 .862 r
.42689 .21427 .42792 .21573 .4297 .21502 .42867 .21343 Mtetra
.665 .68 .855 r
.42867 .21343 .4297 .21502 .43148 .21436 .43046 .21272 Mtetra
.657 .671 .851 r
.43046 .21272 .43148 .21436 .43326 .21369 .43224 .21204 Mtetra
.654 .667 .85 r
.43224 .21204 .43326 .21369 .43504 .21303 .43402 .21137 Mtetra
.692 .683 .836 r
.43402 .21137 .43504 .21303 .43683 .21227 .43581 .21048 Mtetra
.665 .654 .83 r
.43581 .21048 .43683 .21227 .43861 .21155 .43759 .20973 Mtetra
.607 .624 .843 r
.43759 .20973 .43861 .21155 .44039 .21093 .43937 .2093 Mtetra
.287 .481 .874 r
.43937 .2093 .44039 .21093 .44218 .21026 .44112 .2099 Mtetra
.698 .158 0 r
.44112 .2099 .44218 .21026 .44396 .20995 .44284 .21172 Mtetra
.853 .485 .354 r
.44284 .21172 .44396 .20995 .44572 .21039 .44446 .2176 Mtetra
.96 .672 .444 r
.44446 .2176 .44572 .21039 .44735 .21595 .44096 .42163 Mtetra
.524 .288 .499 r
.44096 .42163 .44735 .21595 .44394 .42384 .44275 .42594 Mtetra
.653 .241 .251 r
.44275 .42594 .44394 .42384 .44574 .42822 .44462 .42762 Mtetra
.335 .742 .981 r
.44462 .42762 .44574 .42822 .44764 .42852 .44653 .42756 Mtetra
.646 .803 .958 r
.44653 .42756 .44764 .42852 .44956 .42786 .44845 .4269 Mtetra
.71 .823 .935 r
.44845 .4269 .44956 .42786 .4515 .42678 .45038 .42597 Mtetra
.582 .816 .988 r
.45038 .42597 .4515 .42678 .45343 .42612 .45231 .42549 Mtetra
.587 .854 .994 r
.45231 .42549 .45343 .42612 .45535 .42551 .45424 .42492 Mtetra
.694 .896 .97 r
.45424 .42492 .45535 .42551 .45728 .42479 .45617 .424 Mtetra
.884 .859 .811 r
.45617 .424 .45728 .42479 .45922 .42371 .45814 .42168 Mtetra
.865 .713 .692 r
.45814 .42168 .45922 .42371 .46117 .42248 .46013 .41793 Mtetra
.832 .615 .609 r
.46013 .41793 .46117 .42248 .46311 .42123 .46218 .41131 Mtetra
.632 .427 .588 r
.46218 .41131 .46311 .42123 .46504 .42091 .46415 .40846 Mtetra
.507 .324 .567 r
.46415 .40846 .46504 .42091 .46697 .42053 .46606 .40892 Mtetra
.563 .368 .576 r
.46606 .40892 .46697 .42053 .46891 .4194 .468 .40786 Mtetra
.961 .676 .45 r
.468 .40786 .46891 .4194 .47094 .41356 .47336 .20535 Mtetra
.53 .298 .508 r
.47336 .20535 .47094 .41356 .47624 .20365 .47527 .19892 Mtetra
.732 .544 .637 r
.47527 .19892 .47624 .20365 .47813 .19758 .47712 .19573 Mtetra
.724 .675 .802 r
.47712 .19573 .47813 .19758 .47996 .19586 .47894 .19451 Mtetra
.628 .709 .904 r
.47894 .19451 .47996 .19586 .48177 .19521 .48075 .194 Mtetra
.562 .706 .937 r
.48075 .194 .48177 .19521 .48358 .19495 .48256 .19371 Mtetra
.663 .741 .908 r
.48256 .19371 .48358 .19495 .48539 .19438 .48438 .19304 Mtetra
.695 .734 .881 r
.48438 .19304 .48539 .19438 .48721 .19368 .4862 .19219 Mtetra
.692 .711 .863 r
.4862 .19219 .48721 .19368 .48903 .19296 .48802 .19133 Mtetra
.7 .694 .841 r
.48802 .19133 .48903 .19296 .49084 .19218 .48984 .19039 Mtetra
.675 .661 .829 r
.48984 .19039 .49084 .19218 .49266 .19143 .49166 .18956 Mtetra
.623 .629 .836 r
.49166 .18956 .49266 .19143 .49448 .19076 .49348 .18904 Mtetra
.412 .54 .875 r
.49348 .18904 .49448 .19076 .49631 .19005 .49529 .18935 Mtetra
.451 0 0 r
.49529 .18935 .49631 .19005 .49813 .1896 .4971 .19071 Mtetra
.819 .403 .255 r
.4971 .19071 .49813 .1896 .49994 .18977 .49888 .19441 Mtetra
.967 .673 .422 r
.49888 .19441 .49994 .18977 .50174 .19322 .49907 .39906 Mtetra
.527 .291 .499 r
.49907 .39906 .50174 .19322 .50209 .4017 .50097 .40547 Mtetra
.643 .281 .341 r
.50097 .40547 .50209 .4017 .504 .40795 .50291 .40758 Mtetra
.143 .661 .889 r
.50291 .40758 .504 .40795 .50596 .40879 .50487 .40766 Mtetra
.683 .787 .929 r
.50487 .40766 .50596 .40879 .50792 .40816 .50684 .40684 Mtetra
.739 .77 .878 r
.50684 .40684 .50792 .40816 .50989 .40703 .50881 .40568 Mtetra
.597 .714 .926 r
.50881 .40568 .50989 .40703 .51186 .40658 .51078 .40524 Mtetra
.574 .708 .933 r
.51078 .40524 .51186 .40658 .51382 .40619 .51275 .40489 Mtetra
.724 .769 .888 r
.51275 .40489 .51382 .40619 .5158 .40511 .51472 .40383 Mtetra
.933 .777 .665 r
.51472 .40383 .5158 .40511 .51778 .40059 .5167 .39906 Mtetra
.974 .687 .42 r
.5167 .39906 .51778 .40059 .52008 .18971 .51908 .18728 Mtetra
.916 .698 .593 r
.51908 .18728 .52008 .18971 .52193 .18154 .52093 .17986 Mtetra
.812 .726 .771 r
.52093 .17986 .52193 .18154 .52377 .17938 .52278 .17783 Mtetra
.631 .679 .877 r
.52278 .17783 .52377 .17938 .52562 .17872 .52462 .17728 Mtetra
.501 .636 .914 r
.52462 .17728 .52562 .17872 .52746 .17856 .52646 .17723 Mtetra
.561 .686 .924 r
.52646 .17723 .52746 .17856 .5293 .17823 .52831 .17696 Mtetra
.629 .726 .917 r
.52831 .17696 .5293 .17823 .53115 .17771 .53015 .17643 Mtetra
.637 .728 .914 r
.53015 .17643 .53115 .17771 .53299 .17717 .532 .17586 Mtetra
.639 .723 .909 r
.532 .17586 .53299 .17717 .53484 .17662 .53385 .17528 Mtetra
.645 .722 .904 r
.53385 .17528 .53484 .17662 .53669 .17604 .5357 .17468 Mtetra
.657 .722 .897 r
.5357 .17468 .53669 .17604 .53854 .17542 .53755 .17401 Mtetra
.681 .724 .882 r
.53755 .17401 .53854 .17542 .54039 .17473 .5394 .17322 Mtetra
.692 .712 .863 r
.5394 .17322 .54039 .17473 .54225 .17399 .54125 .17235 Mtetra
.688 .69 .847 r
.54125 .17235 .54225 .17399 .5441 .17324 .54311 .17147 Mtetra
.671 .667 .837 r
.54311 .17147 .5441 .17324 .54595 .1725 .54496 .17066 Mtetra
.658 .653 .834 r
.54496 .17066 .54595 .1725 .54781 .17177 .54682 .16993 Mtetra
.655 .65 .834 r
.54682 .16993 .54781 .17177 .54967 .17104 .54868 .16921 Mtetra
.656 .652 .835 r
.54868 .16921 .54967 .17104 .55153 .1703 .55054 .16848 Mtetra
.657 .655 .836 r
.55054 .16848 .55153 .1703 .55339 .16956 .5524 .16775 Mtetra
.658 .657 .837 r
.5524 .16775 .55339 .16956 .55525 .16881 .55426 .16702 Mtetra
.659 .659 .839 r
.55426 .16702 .55525 .16881 .55711 .16806 .55612 .16628 Mtetra
.66 .662 .841 r
.55612 .16628 .55711 .16806 .55897 .1673 .55798 .16555 Mtetra
.66 .664 .843 r
.55798 .16555 .55897 .1673 .56084 .16655 .55985 .16481 Mtetra
.659 .666 .846 r
.55985 .16481 .56084 .16655 .5627 .16581 .56171 .16409 Mtetra
.658 .668 .848 r
.56171 .16409 .5627 .16581 .56457 .16508 .56358 .16337 Mtetra
.658 .67 .85 r
.56358 .16337 .56457 .16508 .56644 .16435 .56545 .16265 Mtetra
.657 .672 .852 r
.56545 .16265 .56644 .16435 .56831 .16363 .56732 .16194 Mtetra
.657 .673 .854 r
.56732 .16194 .56831 .16363 .57018 .16291 .56919 .16123 Mtetra
.657 .674 .855 r
.56919 .16123 .57018 .16291 .57205 .1622 .57107 .16053 Mtetra
.656 .675 .856 r
.57107 .16053 .57205 .1622 .57392 .1615 .57294 .15983 Mtetra
.656 .676 .857 r
.57294 .15983 .57392 .1615 .5758 .16079 .57482 .15912 Mtetra
.57482 .15912 .5758 .16079 .57767 .16009 .57669 .15842 Mtetra
.656 .677 .858 r
.57669 .15842 .57767 .16009 .57955 .15939 .57857 .15772 Mtetra
.57857 .15772 .57955 .15939 .58143 .15869 .58045 .15703 Mtetra
.58045 .15703 .58143 .15869 .58331 .15799 .58233 .15633 Mtetra
.58233 .15633 .58331 .15799 .58519 .15729 .58421 .15563 Mtetra
.655 .677 .859 r
.58421 .15563 .58519 .15729 .58707 .15659 .5861 .15493 Mtetra
.5861 .15493 .58707 .15659 .58896 .1559 .58798 .15423 Mtetra
.58798 .15423 .58896 .1559 .59084 .1552 .58987 .15354 Mtetra
.58987 .15354 .59084 .1552 .59273 .1545 .59175 .15284 Mtetra
.59175 .15284 .59273 .1545 .59462 .15381 .59364 .15214 Mtetra
.59364 .15214 .59462 .15381 .59651 .15311 .59553 .15144 Mtetra
.59553 .15144 .59651 .15311 .5984 .15241 .59742 .15074 Mtetra
.59742 .15074 .5984 .15241 .60029 .15171 .59931 .15004 Mtetra
.59931 .15004 .60029 .15171 .60218 .15102 .60121 .14934 Mtetra
.655 .676 .858 r
.60121 .14934 .60218 .15102 .60407 .15032 .6031 .14865 Mtetra
.654 .676 .858 r
.6031 .14865 .60407 .15032 .60597 .14963 .605 .14795 Mtetra
.605 .14795 .60597 .14963 .60787 .14893 .60689 .14725 Mtetra
.654 .675 .858 r
.60689 .14725 .60787 .14893 .60976 .14824 .60879 .14656 Mtetra
.653 .675 .858 r
.60879 .14656 .60976 .14824 .61166 .14755 .61069 .14586 Mtetra
.653 .674 .857 r
.61069 .14586 .61166 .14755 .61357 .14687 .6126 .14517 Mtetra
.652 .673 .857 r
.6126 .14517 .61357 .14687 .61547 .14618 .6145 .14448 Mtetra
.652 .672 .856 r
.6145 .14448 .61547 .14618 .61737 .1455 .6164 .14379 Mtetra
.651 .67 .855 r
.6164 .14379 .61737 .1455 .61928 .14483 .61831 .1431 Mtetra
.65 .668 .854 r
.61831 .1431 .61928 .14483 .62118 .14415 .62022 .14242 Mtetra
.651 .667 .853 r
.62022 .14242 .62118 .14415 .62309 .14348 .62212 .14173 Mtetra
.652 .666 .851 r
.62212 .14173 .62309 .14348 .625 .1428 .62403 .14103 Mtetra
.654 .665 .849 r
.62403 .14103 .625 .1428 .62691 .1421 .62594 .14032 Mtetra
.655 .663 .846 r
.62594 .14032 .62691 .1421 .62882 .14139 .62785 .1396 Mtetra
.669 .668 .84 r
.62785 .1396 .62882 .14139 .63073 .14065 .62976 .13879 Mtetra
.682 .667 .828 r
.62976 .13879 .63073 .14065 .63264 .13985 .63167 .13788 Mtetra
.644 .635 .826 r
.63167 .13788 .63264 .13985 .63456 .13911 .63359 .13719 Mtetra
.515 .574 .853 r
.63359 .13719 .63456 .13911 .63648 .13856 .63553 .13717 Mtetra
0 .276 .779 r
.63553 .13717 .63648 .13856 .63841 .1383 .63753 .13858 Mtetra
.798 .312 .045 r
.63753 .13858 .63841 .1383 .64035 .13809 .63959 .14162 Mtetra
.776 .403 .351 r
.63959 .14162 .64035 .13809 .64228 .13755 .64175 .14666 Mtetra
.42 .152 .398 r
.64175 .14666 .64228 .13755 .64418 .13636 .64364 .14498 Mtetra
.413 .143 .392 r
.64364 .14498 .64418 .13636 .64611 .13562 .64553 .14328 Mtetra
.759 .428 .424 r
.64553 .14328 .64611 .13562 .6481 .13647 .64783 .15155 Mtetra
.963 .651 .383 r
.64783 .15155 .6481 .13647 .65059 .14916 .65817 .35078 Mtetra
.522 .286 .498 r
.65817 .35078 .65059 .14916 .66135 .35384 .66042 .3544 Mtetra
.561 .009 0 r
.66042 .3544 .66135 .35384 .66357 .35651 .66258 .35555 Mtetra
.619 .815 .975 r
.66258 .35555 .66357 .35651 .66567 .35615 .66467 .35492 Mtetra
.722 .797 .911 r
.66467 .35492 .66567 .35615 .66773 .35515 .66673 .35385 Mtetra
.716 .783 .905 r
.66673 .35385 .66773 .35515 .6698 .35403 .6688 .35281 Mtetra
.589 .748 .953 r
.6688 .35281 .6698 .35403 .67188 .35341 .67089 .35235 Mtetra
.634 .798 .961 r
.67089 .35235 .67188 .35341 .67397 .35275 .67298 .35168 Mtetra
.752 .836 .916 r
.67298 .35168 .67397 .35275 .67606 .35207 .67505 .35046 Mtetra
.851 .771 .773 r
.67505 .35046 .67606 .35207 .67815 .35143 .67705 .34797 Mtetra
.821 .637 .653 r
.67705 .34797 .67815 .35143 .68022 .35027 .67897 .34382 Mtetra
.901 .631 .519 r
.67897 .34382 .68022 .35027 .68221 .34759 .68031 .32796 Mtetra
.966 .659 .39 r
.68031 .32796 .68221 .34759 .68367 .3343 .67245 .12851 Mtetra
.525 .294 .506 r
.67245 .12851 .68367 .3343 .67524 .12727 .67423 .12437 Mtetra
.757 .619 .707 r
.67423 .12437 .67524 .12727 .67702 .12341 .67609 .12213 Mtetra
.703 .767 .902 r
.67609 .12213 .67702 .12341 .67895 .12235 .67803 .12122 Mtetra
.619 .764 .949 r
.67803 .12122 .67895 .12235 .68091 .12186 .67999 .12068 Mtetra
.608 .746 .943 r
.67999 .12068 .68091 .12186 .68288 .12154 .68195 .12018 Mtetra
.708 .754 .888 r
.68195 .12018 .68288 .12154 .68482 .12074 .68389 .11922 Mtetra
.669 .712 .88 r
.68389 .11922 .68482 .12074 .68677 .11997 .68583 .11845 Mtetra
.571 .666 .902 r
.68583 .11845 .68677 .11997 .68872 .11925 .68781 .11814 Mtetra
.086 .456 .885 r
.68781 .11814 .68872 .11925 .69067 .11847 .68985 .11896 Mtetra
.732 .22 0 r
.68985 .11896 .69067 .11847 .69265 .11815 .69198 .12127 Mtetra
.91 .549 .34 r
.69198 .12127 .69265 .11815 .6947 .11902 .69479 .13536 Mtetra
.963 .646 .366 r
.69479 .13536 .6947 .11902 .69729 .12913 .70837 .33423 Mtetra
.521 .285 .498 r
.70837 .33423 .69729 .12913 .71157 .33685 .71071 .33751 Mtetra
.589 .046 0 r
.71071 .33751 .71157 .33685 .71392 .34008 .71295 .33883 Mtetra
.349 .618 .951 r
.71295 .33883 .71392 .34008 .7161 .34039 .71512 .33911 Mtetra
.622 .754 .941 r
.71512 .33911 .7161 .34039 .71822 .33962 .71725 .33851 Mtetra
.84 .85 .852 r
.71725 .33851 .71822 .33962 .72025 .33748 .7193 .33661 Mtetra
.99 .794 .547 r
.7193 .33661 .72025 .33748 .72193 .32983 .72099 .32903 Mtetra
.976 .672 .331 r
.72099 .32903 .72193 .32983 .71054 .11528 .70961 .11369 Mtetra
.947 .764 .623 r
.70961 .11369 .71054 .11528 .71222 .11009 .71129 .10845 Mtetra
.718 .717 .848 r
.71129 .10845 .71222 .11009 .71416 .1089 .71324 .10735 Mtetra
.586 .672 .898 r
.71324 .10735 .71416 .1089 .71615 .10841 .71523 .10697 Mtetra
.496 .645 .923 r
.71523 .10697 .71615 .10841 .71816 .10823 .71725 .10692 Mtetra
.65 .743 .918 r
.71725 .10692 .71816 .10823 .72014 .10756 .71923 .10625 Mtetra
.664 .751 .915 r
.71923 .10625 .72014 .10756 .72211 .10686 .72121 .10552 Mtetra
.686 .753 .903 r
.72121 .10552 .72211 .10686 .72409 .10609 .72318 .10468 Mtetra
.775 .772 .85 r
.72318 .10468 .72409 .10609 .72603 .10481 .72511 .10325 Mtetra
.705 .725 .865 r
.72511 .10325 .72603 .10481 .728 .10393 .72707 .10226 Mtetra
.525 .62 .889 r
.72707 .10226 .728 .10393 .73003 .10392 .7291 .10215 Mtetra
.686 .3 0 r
.7291 .10215 .73003 .10392 .73243 .10908 .73149 .10719 Mtetra
.971 .658 .297 r
.73149 .10719 .73243 .10908 .74974 .32276 .7488 .32167 Mtetra
.767 .322 0 r
.7488 .32167 .74974 .32276 .75227 .32746 .75134 .32649 Mtetra
.473 .749 .99 r
.75134 .32649 .75227 .32746 .75446 .32736 .75352 .32629 Mtetra
.71 .832 .94 r
.75352 .32629 .75446 .32736 .7566 .32646 .75565 .32527 Mtetra
.775 .829 .895 r
.75565 .32527 .7566 .32646 .7587 .32516 .75775 .32386 Mtetra
.456 .671 .956 r
.75775 .32386 .7587 .32516 .7609 .32502 .75995 .32386 Mtetra
.57 .757 .967 r
.75995 .32386 .7609 .32502 .76306 .32445 .76213 .32343 Mtetra
.757 .857 .924 r
.76213 .32343 .76306 .32445 .76516 .32305 .76424 .32216 Mtetra
.905 .731 .656 r
.081 .54628 .08224 .54741 .08465 .54128 .08338 .54034 Mtetra
.936 .686 .534 r
.08338 .54034 .08465 .54128 .11308 .33548 .11186 .33486 Mtetra
.923 .751 .649 r
.11186 .33486 .11308 .33548 .11534 .32966 .11415 .32885 Mtetra
.776 .807 .878 r
.11415 .32885 .11534 .32966 .11699 .32858 .1158 .3277 Mtetra
.598 .767 .96 r
.1158 .3277 .11699 .32858 .11853 .32827 .11736 .32732 Mtetra
.423 .685 .972 r
.11736 .32732 .11853 .32827 .12002 .32838 .11886 .32734 Mtetra
.651 .747 .92 r
.11886 .32734 .12002 .32838 .12159 .3279 .12044 .3268 Mtetra
.667 .74 .905 r
.12044 .3268 .12159 .3279 .12317 .32733 .12202 .3262 Mtetra
.675 .735 .895 r
.12202 .3262 .12317 .32733 .12476 .32669 .12361 .32555 Mtetra
.751 .748 .849 r
.12361 .32555 .12476 .32669 .1264 .32569 .12526 .32445 Mtetra
.709 .726 .863 r
.12526 .32445 .1264 .32569 .12802 .32483 .12688 .32361 Mtetra
.584 .693 .917 r
.12688 .32361 .12802 .32483 .1296 .3243 .12843 .32332 Mtetra
.827 .355 0 r
.12843 .32332 .1296 .3243 .13104 .32491 .12967 .32556 Mtetra
.914 .62 .472 r
.12967 .32556 .13104 .32491 .13233 .32672 .1296 .33822 Mtetra
.923 .665 .528 r
.1296 .33822 .13233 .32672 .13314 .33243 .10677 .53374 Mtetra
.519 .284 .499 r
.10677 .53374 .13314 .33243 .11007 .53126 .10815 .53562 Mtetra
.531 .198 .348 r
.10815 .53562 .11007 .53126 .11116 .5355 .10972 .53611 Mtetra
.186 0 0 r
.10972 .53611 .11116 .5355 .11259 .53714 .11135 .536 Mtetra
.626 .737 .927 r
.11135 .536 .11259 .53714 .11424 .53693 .11304 .53552 Mtetra
.67 .703 .871 r
.11304 .53552 .11424 .53693 .11596 .53615 .11475 .53483 Mtetra
.688 .722 .876 r
.11475 .53483 .11596 .53615 .11771 .53513 .11647 .53405 Mtetra
.491 .701 .963 r
.11647 .53405 .11771 .53513 .11938 .53487 .11812 .53395 Mtetra
.548 .756 .974 r
.11812 .53395 .11938 .53487 .12104 .53459 .11978 .53367 Mtetra
.715 .798 .916 r
.11978 .53367 .12104 .53459 .12275 .53395 .12152 .53281 Mtetra
.88 .75 .716 r
.12152 .53281 .12275 .53395 .1246 .53211 .12358 .52928 Mtetra
.895 .674 .596 r
.12358 .52928 .1246 .53211 .12662 .52893 .12665 .51724 Mtetra
.929 .674 .531 r
.12665 .51724 .12662 .52893 .12908 .52194 .1519 .31833 Mtetra
.523 .293 .507 r
.1519 .31833 .12908 .52194 .15432 .32163 .15379 .31535 Mtetra
.627 .448 .621 r
.15379 .31535 .15432 .32163 .15646 .31648 .1555 .3138 Mtetra
.667 .567 .733 r
.1555 .3138 .15646 .31648 .1583 .31387 .15716 .31279 Mtetra
.678 .75 .905 r
.15716 .31279 .1583 .31387 .15996 .31288 .15877 .31213 Mtetra
.612 .804 .974 r
.15877 .31213 .15996 .31288 .16154 .31249 .16036 .31168 Mtetra
.578 .78 .975 r
.16036 .31168 .16154 .31249 .16309 .31235 .16194 .31133 Mtetra
.72 .768 .891 r
.16194 .31133 .16309 .31235 .16471 .31169 .16358 .31047 Mtetra
.696 .727 .875 r
.16358 .31047 .16471 .31169 .16633 .31099 .16521 .3097 Mtetra
.579 .677 .907 r
.16521 .3097 .16633 .31099 .16792 .31057 .16679 .30942 Mtetra
.736 .249 0 r
.16679 .30942 .16792 .31057 .16941 .31104 .16811 .3114 Mtetra
.919 .614 .45 r
.16811 .3114 .16941 .31104 .17077 .31267 .1684 .32242 Mtetra
.93 .668 .519 r
.1684 .32242 .17077 .31267 .17177 .3176 .14767 .51987 Mtetra
.52 .285 .499 r
.14767 .51987 .17177 .3176 .15099 .51703 .14908 .5221 Mtetra
.534 .212 .368 r
.14908 .5221 .15099 .51703 .15212 .52173 .15067 .52265 Mtetra
.291 0 0 r
.15067 .52265 .15212 .52173 .15358 .52354 .15234 .52259 Mtetra
.489 .731 .979 r
.15234 .52259 .15358 .52354 .15522 .52372 .15401 .52244 Mtetra
.632 .717 .908 r
.15401 .52244 .15522 .52372 .15695 .52309 .15573 .52193 Mtetra
.75 .764 .864 r
.15573 .52193 .15695 .52309 .15874 .52189 .15752 .52079 Mtetra
.881 .761 .725 r
.15752 .52079 .15874 .52189 .16061 .52 .15955 .51745 Mtetra
.897 .681 .602 r
.15955 .51745 .16061 .52 .16259 .51704 .16234 .50708 Mtetra
.934 .677 .524 r
.16234 .50708 .16259 .51704 .16488 .51129 .18576 .30629 Mtetra
.524 .293 .507 r
.18576 .30629 .16488 .51129 .18807 .31103 .18768 .30302 Mtetra
.606 .417 .6 r
.18768 .30302 .18807 .31103 .19029 .30486 .1894 .30146 Mtetra
.646 .522 .698 r
.1894 .30146 .19029 .30486 .19216 .30196 .19108 .30044 Mtetra
.684 .681 .841 r
.19108 .30044 .19216 .30196 .19387 .30066 .19272 .29967 Mtetra
.67 .77 .925 r
.19272 .29967 .19387 .30066 .1955 .30001 .19435 .29905 Mtetra
.651 .769 .935 r
.19435 .29905 .1955 .30001 .19711 .29959 .19598 .29849 Mtetra
.748 .762 .864 r
.19598 .29849 .19711 .29959 .19878 .29855 .19766 .29743 Mtetra
.74 .758 .867 r
.19766 .29743 .19878 .29855 .20046 .29749 .19933 .29641 Mtetra
.622 .737 .929 r
.19933 .29641 .20046 .29749 .20208 .29703 .20095 .29597 Mtetra
.765 .278 0 r
.20095 .29597 .20208 .29703 .20342 .29923 .2023 .29808 Mtetra
.947 .684 .505 r
.2023 .29808 .20342 .29923 .18441 .50011 .18345 .49662 Mtetra
.979 .684 .372 r
.18345 .49662 .18441 .50011 .1849 .51173 .18373 .51024 Mtetra
0 .194 .716 r
.18373 .51024 .1849 .51173 .18647 .51291 .18528 .5115 Mtetra
.672 .71 .876 r
.18528 .5115 .18647 .51291 .18823 .51214 .18704 .51079 Mtetra
.765 .74 .831 r
.18704 .51079 .18823 .51214 .19006 .51072 .18887 .50943 Mtetra
.737 .744 .858 r
.18887 .50943 .19006 .51072 .19186 .50959 .19067 .50834 Mtetra
.684 .737 .891 r
.19067 .50834 .19186 .50959 .19363 .50883 .19243 .50758 Mtetra
.666 .733 .9 r
.19243 .50758 .19363 .50883 .19538 .50818 .19419 .50691 Mtetra
.619 .717 .916 r
.19419 .50691 .19538 .50818 .19712 .50774 .19593 .50645 Mtetra
.583 .699 .922 r
.19593 .50645 .19712 .50774 .19884 .50744 .19765 .50612 Mtetra
.578 .691 .919 r
.19765 .50612 .19884 .50744 .20057 .50714 .19938 .50581 Mtetra
.607 .7 .91 r
.19938 .50581 .20057 .50714 .20231 .50667 .20112 .50539 Mtetra
.625 .717 .912 r
.20112 .50539 .20231 .50667 .20406 .50608 .20286 .5049 Mtetra
.624 .735 .926 r
.20286 .5049 .20406 .50608 .20582 .5055 .20461 .50441 Mtetra
.486 .701 .964 r
.20461 .50441 .20582 .5055 .20754 .50529 .20632 .50431 Mtetra
.462 .716 .978 r
.20632 .50431 .20754 .50529 .20926 .50516 .20803 .50422 Mtetra
.656 .791 .947 r
.20803 .50422 .20926 .50516 .211 .50471 .2098 .50359 Mtetra
.861 .774 .764 r
.2098 .50359 .211 .50471 .21284 .50328 .21175 .50102 Mtetra
.893 .69 .622 r
.21175 .50102 .21284 .50328 .21481 .50048 .21417 .49344 Mtetra
.943 .682 .511 r
.21417 .49344 .21481 .50048 .21703 .49504 .23492 .28905 Mtetra
.526 .295 .507 r
.23492 .28905 .21703 .49504 .23735 .29324 .23691 .28479 Mtetra
.611 .418 .596 r
.23691 .28479 .23735 .29324 .23959 .28638 .23868 .283 Mtetra
.658 .531 .698 r
.23868 .283 .23959 .28638 .24147 .28333 .24039 .28184 Mtetra
.685 .69 .848 r
.24039 .28184 .24147 .28333 .2432 .2819 .24206 .28107 Mtetra
.641 .799 .959 r
.24206 .28107 .2432 .2819 .24485 .28136 .24371 .28052 Mtetra
.604 .787 .969 r
.24371 .28052 .24485 .28136 .24648 .2811 .24536 .28009 Mtetra
.701 .774 .909 r
.24536 .28009 .24648 .2811 .24814 .28051 .24704 .27931 Mtetra
.726 .745 .868 r
.24704 .27931 .24814 .28051 .24983 .27962 .24873 .27835 Mtetra
.645 .713 .897 r
.24873 .27835 .24983 .27962 .25149 .27896 .25039 .27781 Mtetra
0 .242 .734 r
.25039 .27781 .25149 .27896 .25308 .27921 .2519 .27885 Mtetra
.917 .55 .314 r
.2519 .27885 .25308 .27921 .25455 .28085 .25305 .28423 Mtetra
.947 .679 .496 r
.25305 .28423 .25455 .28085 .25586 .2844 .23692 .4882 Mtetra
.521 .286 .499 r
.23692 .4882 .25586 .2844 .25713 .28846 .23838 .49126 Mtetra
.514 .28 .497 r
.23838 .49126 .25713 .28846 .25888 .28691 .24015 .49084 Mtetra
.513 .279 .497 r
.24015 .49084 .25888 .28691 .26059 .28592 .24196 .48984 Mtetra
.514 .28 .498 r
.24196 .48984 .26059 .28592 .24589 .47915 .24371 .48967 Mtetra
.532 .251 .434 r
.24371 .48967 .24589 .47915 .24682 .48855 .24538 .49038 Mtetra
.52 .091 .168 r
.24538 .49038 .24682 .48855 .24831 .49147 .24708 .49088 Mtetra
.317 .729 .977 r
.24708 .49088 .24831 .49147 .24998 .49228 .24882 .49086 Mtetra
.624 .695 .895 r
.24882 .49086 .24998 .49228 .25176 .49185 .2506 .49036 Mtetra
.654 .696 .877 r
.2506 .49036 .25176 .49185 .25356 .49108 .25239 .48972 Mtetra
.611 .702 .909 r
.25239 .48972 .25356 .49108 .25535 .49044 .25417 .48928 Mtetra
.559 .72 .948 r
.25417 .48928 .25535 .49044 .25713 .49003 .25594 .48899 Mtetra
.678 .781 .928 r
.25594 .48899 .25713 .49003 .25893 .48936 .25774 .48827 Mtetra
.845 .787 .795 r
.25774 .48827 .25893 .48936 .26079 .48798 .25966 .48611 Mtetra
.895 .71 .644 r
.25966 .48611 .26079 .48798 .26274 .48539 .26188 .48022 Mtetra
.95 .685 .499 r
.26188 .48022 .26274 .48539 .26485 .48083 .2799 .27446 Mtetra
.53 .298 .508 r
.2799 .27446 .26485 .48083 .28222 .28095 .282 .2686 Mtetra
.591 .385 .57 r
.282 .2686 .28222 .28095 .28468 .27048 .2838 .26656 Mtetra
.653 .511 .677 r
.2838 .26656 .28468 .27048 .28659 .26698 .28553 .26528 Mtetra
.692 .667 .821 r
.28553 .26528 .28659 .26698 .28837 .26517 .28724 .26439 Mtetra
.668 .821 .957 r
.28724 .26439 .28837 .26517 .29006 .26441 .28893 .26374 Mtetra
.606 .83 .985 r
.28893 .26374 .29006 .26441 .29174 .26399 .29061 .26324 Mtetra
.598 .809 .981 r
.29061 .26324 .29174 .26399 .2934 .26367 .29229 .26279 Mtetra
.623 .787 .961 r
.29229 .26279 .2934 .26367 .29508 .26326 .29397 .2623 Mtetra
.627 .771 .949 r
.29397 .2623 .29508 .26326 .29676 .26285 .29566 .2618 Mtetra
.642 .756 .932 r
.29566 .2618 .29676 .26285 .29844 .26239 .29734 .26126 Mtetra
.66 .746 .914 r
.29734 .26126 .29844 .26239 .30013 .26182 .29904 .26064 Mtetra
.67 .741 .904 r
.29904 .26064 .30013 .26182 .30183 .26118 .30074 .25998 Mtetra
.682 .741 .895 r
.30074 .25998 .30183 .26118 .30353 .26045 .30244 .25926 Mtetra
.694 .746 .891 r
.30244 .25926 .30353 .26045 .30524 .25964 .30415 .25848 Mtetra
.695 .752 .895 r
.30415 .25848 .30524 .25964 .30695 .25882 .30586 .2577 Mtetra
.714 .764 .892 r
.30586 .2577 .30695 .25882 .30867 .25797 .30758 .25683 Mtetra
.729 .764 .88 r
.30758 .25683 .30867 .25797 .31039 .2571 .3093 .25586 Mtetra
.648 .723 .903 r
.3093 .25586 .31039 .2571 .31209 .25649 .311 .2553 Mtetra
.176 .498 .907 r
.311 .2553 .31209 .25649 .31375 .25647 .31262 .25585 Mtetra
.9 .488 .186 r
.31262 .25585 .31375 .25647 .31533 .25761 .31401 .25988 Mtetra
.954 .68 .478 r
.31401 .25988 .31533 .25761 .31679 .26067 .30176 .46493 Mtetra
.526 .29 .5 r
.30176 .46493 .31679 .26067 .3051 .46014 .30317 .47044 Mtetra
.543 .259 .434 r
.30317 .47044 .3051 .46014 .30627 .46926 .30488 .47145 Mtetra
.468 .056 .174 r
.30488 .47145 .30627 .46926 .30788 .47191 .30666 .47164 Mtetra
.217 .722 .901 r
.30666 .47164 .30788 .47191 .3096 .47292 .30845 .47154 Mtetra
.504 .657 .928 r
.30845 .47154 .3096 .47292 .3114 .47289 .31025 .47146 Mtetra
.647 .707 .89 r
.31025 .47146 .3114 .47289 .31323 .47228 .31208 .47085 Mtetra
.798 .746 .805 r
.31208 .47085 .31323 .47228 .31511 .47091 .31399 .46909 Mtetra
.892 .717 .659 r
.31399 .46909 .31511 .47091 .31708 .46816 .3161 .464 Mtetra
.956 .687 .485 r
.3161 .464 .31708 .46816 .31914 .46388 .33084 .25857 Mtetra
.534 .302 .509 r
.33084 .25857 .31914 .46388 .32131 .45778 .33302 .25052 Mtetra
.519 .289 .506 r
.33302 .25052 .32131 .45778 .32314 .45715 .33477 .24941 Mtetra
.517 .287 .505 r
.33477 .24941 .32314 .45715 .32494 .45703 .33647 .24905 Mtetra
.517 .288 .505 r
.33647 .24905 .32494 .45703 .32709 .45121 .33819 .24845 Mtetra
.52 .29 .506 r
.33819 .24845 .32709 .45121 .34084 .25155 .33999 .24656 Mtetra
.653 .486 .645 r
.33999 .24656 .34084 .25155 .3428 .24691 .34178 .24487 Mtetra
.721 .647 .775 r
.34178 .24487 .3428 .24691 .34463 .24454 .34354 .24359 Mtetra
.666 .79 .94 r
.34354 .24359 .34463 .24454 .34636 .2438 .34527 .24294 Mtetra
.62 .796 .966 r
.34527 .24294 .34636 .2438 .34807 .24342 .34699 .24244 Mtetra
.632 .771 .947 r
.34699 .24244 .34807 .24342 .34978 .24309 .34871 .24191 Mtetra
.692 .752 .897 r
.34871 .24191 .34978 .24309 .35152 .24229 .35044 .24114 Mtetra
.697 .757 .898 r
.35044 .24114 .35152 .24229 .35325 .24146 .35218 .24034 Mtetra
.707 .766 .898 r
.35218 .24034 .35325 .24146 .355 .24061 .35392 .23949 Mtetra
.736 .773 .882 r
.35392 .23949 .355 .24061 .35674 .23972 .35568 .23848 Mtetra
.667 .732 .898 r
.35568 .23848 .35674 .23972 .35847 .23906 .35741 .23782 Mtetra
.407 .621 .939 r
.35741 .23782 .35847 .23906 .36018 .23885 .3591 .23797 Mtetra
.839 .378 0 r
.3591 .23797 .36018 .23885 .36184 .23972 .36064 .24099 Mtetra
.96 .681 .464 r
.36064 .24099 .36184 .23972 .36342 .24201 .35159 .44368 Mtetra
.534 .296 .501 r
.35159 .44368 .36342 .24201 .36455 .2531 .35291 .45311 Mtetra
.518 .283 .498 r
.35291 .45311 .36455 .2531 .35603 .45139 .35467 .45445 Mtetra
.501 .126 .261 r
.35467 .45445 .35603 .45139 .35769 .45474 .35648 .45476 Mtetra
.142 .687 .779 r
.35648 .45476 .35769 .45474 .35946 .45598 .35832 .45455 Mtetra
.619 .7 .903 r
.35832 .45455 .35946 .45598 .3613 .45568 .36018 .45406 Mtetra
.654 .685 .867 r
.36018 .45406 .3613 .45568 .36317 .45494 .36205 .45338 Mtetra
.667 .698 .869 r
.36205 .45338 .36317 .45494 .36505 .45404 .36392 .45264 Mtetra
.64 .714 .901 r
.36392 .45264 .36505 .45404 .36692 .45341 .36579 .45205 Mtetra
.64 .721 .907 r
.36579 .45205 .36692 .45341 .36879 .45278 .36766 .45146 Mtetra
.631 .725 .916 r
.36766 .45146 .36879 .45278 .37066 .45217 .36952 .45092 Mtetra
.536 .698 .944 r
.36952 .45092 .37066 .45217 .37252 .45179 .37138 .4507 Mtetra
.632 .768 .945 r
.37138 .4507 .37252 .45179 .37439 .45121 .37325 .45014 Mtetra
.778 .805 .875 r
.37325 .45014 .37439 .45121 .37628 .45016 .37515 .44879 Mtetra
.913 .754 .67 r
.37515 .44879 .37628 .45016 .37825 .44749 .37722 .44404 Mtetra
.962 .687 .467 r
.37722 .44404 .37825 .44749 .38028 .44336 .38818 .23975 Mtetra
.54 .306 .509 r
.38818 .23975 .38028 .44336 .38246 .43587 .39038 .22918 Mtetra
.519 .289 .506 r
.39038 .22918 .38246 .43587 .38433 .4353 .39217 .22794 Mtetra
.517 .287 .505 r
.39217 .22794 .38433 .4353 .38616 .43568 .39391 .22752 Mtetra
.39391 .22752 .38616 .43568 .38811 .43326 .39566 .22724 Mtetra
.52 .29 .506 r
.39566 .22724 .38811 .43326 .39833 .23116 .39747 .22539 Mtetra
.64 .465 .63 r
.39747 .22539 .39833 .23116 .40028 .22598 .39927 .22367 Mtetra
.723 .629 .753 r
.39927 .22367 .40028 .22598 .40213 .22316 .40107 .22223 Mtetra
.694 .806 .935 r
.40107 .22223 .40213 .22316 .4039 .22217 .40284 .22145 Mtetra
.639 .838 .977 r
.40284 .22145 .4039 .22217 .40566 .22158 .4046 .22084 Mtetra
.613 .825 .982 r
.4046 .22084 .40566 .22158 .40742 .2212 .40636 .22031 Mtetra
.661 .808 .954 r
.40636 .22031 .40742 .2212 .40918 .22055 .40812 .21966 Mtetra
.662 .807 .953 r
.40812 .21966 .40918 .22055 .41095 .2199 .40989 .219 Mtetra
.663 .805 .951 r
.40989 .219 .41095 .2199 .41272 .21926 .41166 .21834 Mtetra
.666 .802 .948 r
.41166 .21834 .41272 .21926 .41449 .2186 .41343 .21767 Mtetra
.663 .8 .948 r
.41343 .21767 .41449 .2186 .41626 .21795 .4152 .21701 Mtetra
.659 .795 .948 r
.4152 .21701 .41626 .21795 .41802 .21734 .41697 .21637 Mtetra
.636 .782 .951 r
.41697 .21637 .41802 .21734 .41979 .21686 .41874 .21581 Mtetra
.639 .765 .94 r
.41874 .21581 .41979 .21686 .42156 .21639 .42051 .21525 Mtetra
.649 .751 .924 r
.42051 .21525 .42156 .21639 .42333 .21587 .42229 .21465 Mtetra
.684 .747 .9 r
.42229 .21465 .42333 .21587 .42511 .2151 .42407 .2139 Mtetra
.692 .753 .898 r
.42407 .2139 .42511 .2151 .42689 .21427 .42585 .2131 Mtetra
.694 .761 .903 r
.42585 .2131 .42689 .21427 .42867 .21343 .42763 .2123 Mtetra
.679 .764 .915 r
.42763 .2123 .42867 .21343 .43046 .21272 .42941 .21158 Mtetra
.673 .76 .916 r
.42941 .21158 .43046 .21272 .43224 .21204 .4312 .21088 Mtetra
.668 .755 .915 r
.4312 .21088 .43224 .21204 .43402 .21137 .43298 .2102 Mtetra
.733 .77 .883 r
.43298 .2102 .43402 .21137 .43581 .21048 .43477 .20918 Mtetra
.686 .735 .888 r
.43477 .20918 .43581 .21048 .43759 .20973 .43656 .2084 Mtetra
.559 .68 .92 r
.43656 .2084 .43759 .20973 .43937 .2093 .43833 .20815 Mtetra
.617 .134 0 r
.43833 .20815 .43937 .2093 .44112 .2099 .44004 .21034 Mtetra
.937 .599 .365 r
.44004 .21034 .44112 .2099 .44284 .21172 .44149 .2222 Mtetra
.956 .667 .449 r
.44149 .2222 .44284 .21172 .44446 .2176 .43786 .42402 Mtetra
.519 .284 .498 r
.43786 .42402 .44446 .2176 .44096 .42163 .43971 .426 Mtetra
.522 .18 .328 r
.43971 .426 .44096 .42163 .44275 .42594 .4416 .42648 Mtetra
.159 0 0 r
.4416 .42648 .44275 .42594 .44462 .42762 .44351 .42636 Mtetra
.597 .728 .936 r
.44351 .42636 .44462 .42762 .44653 .42756 .44543 .42593 Mtetra
.645 .685 .873 r
.44543 .42593 .44653 .42756 .44845 .4269 .44735 .42528 Mtetra
.667 .695 .867 r
.44735 .42528 .44845 .4269 .45038 .42597 .44928 .42451 Mtetra
.565 .678 .915 r
.44928 .42451 .45038 .42597 .45231 .42549 .4512 .42422 Mtetra
.609 .733 .933 r
.4512 .42422 .45231 .42549 .45424 .42492 .45313 .42374 Mtetra
.73 .787 .897 r
.45313 .42374 .45424 .42492 .45617 .424 .45507 .42268 Mtetra
.906 .773 .703 r
.45507 .42268 .45617 .424 .45814 .42168 .45707 .41885 Mtetra
.935 .692 .546 r
.45707 .41885 .45814 .42168 .46013 .41793 .45927 .4051 Mtetra
.959 .675 .454 r
.45927 .4051 .46013 .41793 .46218 .41131 .46518 .20225 Mtetra
.521 .29 .506 r
.46518 .20225 .46218 .41131 .46415 .40846 .46702 .20017 Mtetra
.517 .288 .506 r
.46702 .20017 .46415 .40846 .46606 .40892 .46882 .1996 Mtetra
.516 .287 .505 r
.46882 .1996 .46606 .40892 .468 .40786 .47062 .19936 Mtetra
.519 .289 .506 r
.47062 .19936 .468 .40786 .47336 .20535 .47245 .19778 Mtetra
.617 .429 .604 r
.47245 .19778 .47336 .20535 .47527 .19892 .47428 .19599 Mtetra
.702 .583 .718 r
.47428 .19599 .47527 .19892 .47712 .19573 .47611 .19447 Mtetra
.702 .751 .89 r
.47611 .19447 .47712 .19573 .47894 .19451 .47792 .1936 Mtetra
.635 .8 .962 r
.47792 .1936 .47894 .19451 .48075 .194 .47973 .19302 Mtetra
.615 .78 .96 r
.47973 .19302 .48075 .194 .48256 .19371 .48155 .19252 Mtetra
.676 .756 .911 r
.48155 .19252 .48256 .19371 .48438 .19304 .48336 .19179 Mtetra
.695 .752 .895 r
.48336 .19179 .48438 .19304 .4862 .19219 .48518 .19097 Mtetra
.696 .756 .898 r
.48518 .19097 .4862 .19219 .48802 .19133 .487 .19013 Mtetra
.735 .772 .882 r
.487 .19013 .48802 .19133 .48984 .19039 .48882 .18908 Mtetra
.704 .745 .884 r
.48882 .18908 .48984 .19039 .49166 .18956 .49065 .1882 Mtetra
.602 .696 .909 r
.49065 .1882 .49166 .18956 .49348 .18904 .49247 .18778 Mtetra
0 .176 .695 r
.49247 .18778 .49348 .18904 .49529 .18935 .49427 .18924 Mtetra
.91 .512 .227 r
.49427 .18924 .49529 .18935 .4971 .19071 .49603 .19512 Mtetra
.967 .674 .422 r
.49603 .19512 .4971 .19071 .49888 .19441 .496 .40264 Mtetra
.521 .285 .498 r
.496 .40264 .49888 .19441 .49907 .39906 .49792 .40581 Mtetra
.534 .223 .387 r
.49792 .40581 .49907 .39906 .50097 .40547 .49987 .40651 Mtetra
.31 0 0 r
.49987 .40651 .50097 .40547 .50291 .40758 .50183 .40645 Mtetra
.61 .764 .953 r
.50183 .40645 .50291 .40758 .50487 .40766 .50379 .40594 Mtetra
.667 .686 .858 r
.50379 .40594 .50487 .40766 .50684 .40684 .50576 .40514 Mtetra
.69 .698 .852 r
.50576 .40514 .50684 .40684 .50881 .40568 .50773 .40421 Mtetra
.568 .681 .916 r
.50773 .40421 .50881 .40568 .51078 .40524 .5097 .40389 Mtetra
.564 .702 .933 r
.5097 .40389 .51078 .40524 .51275 .40489 .51167 .40358 Mtetra
.719 .766 .89 r
.51167 .40358 .51275 .40489 .51472 .40383 .51364 .40255 Mtetra
.931 .778 .669 r
.51364 .40255 .51472 .40383 .5167 .39906 .51563 .39788 Mtetra
.974 .687 .419 r
.51563 .39788 .5167 .39906 .51908 .18728 .51808 .18647 Mtetra
.972 .771 .574 r
.51808 .18647 .51908 .18728 .52093 .17986 .51993 .17881 Mtetra
.861 .817 .805 r
.51993 .17881 .52093 .17986 .52278 .17783 .52178 .17672 Mtetra
.646 .765 .935 r
.52178 .17672 .52278 .17783 .52462 .17728 .52362 .17611 Mtetra
.501 .691 .953 r
.52362 .17611 .52462 .17728 .52646 .17723 .52546 .17598 Mtetra
.572 .708 .934 r
.52546 .17598 .52646 .17723 .52831 .17696 .52731 .17566 Mtetra
.635 .724 .912 r
.52731 .17566 .52831 .17696 .53015 .17643 .52916 .1751 Mtetra
.641 .721 .906 r
.52916 .1751 .53015 .17643 .532 .17586 .531 .17451 Mtetra
.646 .72 .902 r
.531 .17451 .532 .17586 .53385 .17528 .53285 .1739 Mtetra
.652 .717 .896 r
.53285 .1739 .53385 .17528 .5357 .17468 .5347 .17326 Mtetra
.66 .715 .888 r
.5347 .17326 .5357 .17468 .53755 .17401 .53656 .17258 Mtetra
.675 .717 .88 r
.53656 .17258 .53755 .17401 .5394 .17322 .53841 .17182 Mtetra
.686 .726 .88 r
.53841 .17182 .5394 .17322 .54125 .17235 .54026 .171 Mtetra
.689 .736 .886 r
.54026 .171 .54125 .17235 .54311 .17147 .54212 .17017 Mtetra
.682 .743 .897 r
.54212 .17017 .54311 .17147 .54496 .17066 .54397 .16938 Mtetra
.674 .744 .903 r
.54397 .16938 .54496 .17066 .54682 .16993 .54583 .16864 Mtetra
.671 .742 .904 r
.54583 .16864 .54682 .16993 .54868 .16921 .54769 .16791 Mtetra
.671 .741 .903 r
.54769 .16791 .54868 .16921 .55054 .16848 .54955 .16719 Mtetra
.671 .74 .903 r
.54955 .16719 .55054 .16848 .5524 .16775 .55141 .16646 Mtetra
.67 .741 .904 r
.55141 .16646 .5524 .16775 .55426 .16702 .55327 .16574 Mtetra
.67 .743 .905 r
.55327 .16574 .55426 .16702 .55612 .16628 .55513 .16501 Mtetra
.67 .745 .907 r
.55513 .16501 .55612 .16628 .55798 .16555 .557 .16429 Mtetra
.67 .748 .909 r
.557 .16429 .55798 .16555 .55985 .16481 .55887 .16357 Mtetra
.668 .75 .912 r
.55887 .16357 .55985 .16481 .56171 .16409 .56073 .16286 Mtetra
.667 .752 .914 r
.56073 .16286 .56171 .16409 .56358 .16337 .5626 .16215 Mtetra
.667 .754 .916 r
.5626 .16215 .56358 .16337 .56545 .16265 .56447 .16144 Mtetra
.666 .756 .917 r
.56447 .16144 .56545 .16265 .56732 .16194 .56634 .16074 Mtetra
.666 .757 .918 r
.56634 .16074 .56732 .16194 .56919 .16123 .56822 .16004 Mtetra
.665 .758 .919 r
.56822 .16004 .56919 .16123 .57107 .16053 .57009 .15933 Mtetra
.665 .759 .92 r
.57009 .15933 .57107 .16053 .57294 .15983 .57196 .15864 Mtetra
.665 .76 .921 r
.57196 .15864 .57294 .15983 .57482 .15912 .57384 .15794 Mtetra
.665 .76 .922 r
.57384 .15794 .57482 .15912 .57669 .15842 .57572 .15724 Mtetra
.664 .761 .922 r
.57572 .15724 .57669 .15842 .57857 .15772 .5776 .15654 Mtetra
.5776 .15654 .57857 .15772 .58045 .15703 .57948 .15584 Mtetra
.664 .761 .923 r
.57948 .15584 .58045 .15703 .58233 .15633 .58136 .15514 Mtetra
.664 .762 .923 r
.58136 .15514 .58233 .15633 .58421 .15563 .58324 .15444 Mtetra
.58324 .15444 .58421 .15563 .5861 .15493 .58513 .15375 Mtetra
.58513 .15375 .5861 .15493 .58798 .15423 .58701 .15305 Mtetra
.58701 .15305 .58798 .15423 .58987 .15354 .5889 .15235 Mtetra
.5889 .15235 .58987 .15354 .59175 .15284 .59079 .15165 Mtetra
.59079 .15165 .59175 .15284 .59364 .15214 .59267 .15095 Mtetra
.59267 .15095 .59364 .15214 .59553 .15144 .59457 .15025 Mtetra
.59457 .15025 .59553 .15144 .59742 .15074 .59646 .14955 Mtetra
.59646 .14955 .59742 .15074 .59931 .15004 .59835 .14885 Mtetra
.663 .762 .923 r
.59835 .14885 .59931 .15004 .60121 .14934 .60024 .14815 Mtetra
.663 .761 .923 r
.60024 .14815 .60121 .14934 .6031 .14865 .60214 .14745 Mtetra
.60214 .14745 .6031 .14865 .605 .14795 .60404 .14675 Mtetra
.60404 .14675 .605 .14795 .60689 .14725 .60594 .14605 Mtetra
.60594 .14605 .60689 .14725 .60879 .14656 .60784 .14536 Mtetra
.662 .76 .923 r
.60784 .14536 .60879 .14656 .61069 .14586 .60974 .14466 Mtetra
.662 .76 .922 r
.60974 .14466 .61069 .14586 .6126 .14517 .61164 .14396 Mtetra
.662 .759 .922 r
.61164 .14396 .6126 .14517 .6145 .14448 .61354 .14326 Mtetra
.662 .758 .921 r
.61354 .14326 .6145 .14448 .6164 .14379 .61545 .14257 Mtetra
.661 .757 .921 r
.61545 .14257 .6164 .14379 .61831 .1431 .61735 .14187 Mtetra
.661 .755 .92 r
.61735 .14187 .61831 .1431 .62022 .14242 .61926 .14118 Mtetra
.662 .753 .918 r
.61926 .14118 .62022 .14242 .62212 .14173 .62117 .14048 Mtetra
.665 .752 .915 r
.62117 .14048 .62212 .14173 .62403 .14103 .62308 .13977 Mtetra
.668 .751 .913 r
.62308 .13977 .62403 .14103 .62594 .14032 .62499 .13904 Mtetra
.668 .749 .911 r
.62499 .13904 .62594 .14032 .62785 .1396 .6269 .13831 Mtetra
.695 .757 .9 r
.6269 .13831 .62785 .1396 .62976 .13879 .62881 .13745 Mtetra
.72 .756 .881 r
.62881 .13745 .62976 .13879 .63167 .13788 .63072 .13643 Mtetra
.648 .711 .893 r
.63072 .13643 .63167 .13788 .63359 .13719 .63263 .13578 Mtetra
.297 .533 .91 r
.63263 .13578 .63359 .13719 .63553 .13717 .6346 .1363 Mtetra
.812 .358 0 r
.6346 .1363 .63553 .13717 .63753 .13858 .6367 .14043 Mtetra
.974 .667 .357 r
.6367 .14043 .63753 .13858 .63959 .14162 .6467 .35008 Mtetra
.524 .287 .498 r
.6467 .35008 .63959 .14162 .64175 .14666 .64899 .35507 Mtetra
.514 .28 .497 r
.64899 .35507 .64175 .14666 .64364 .14498 .65107 .35469 Mtetra
.513 .279 .497 r
.65107 .35469 .64364 .14498 .64553 .14328 .65312 .35357 Mtetra
.513 .28 .497 r
.65312 .35357 .64553 .14328 .64783 .15155 .6552 .35287 Mtetra
.516 .281 .497 r
.6552 .35287 .64783 .15155 .65817 .35078 .65733 .35353 Mtetra
.506 .108 .22 r
.65733 .35353 .65817 .35078 .66042 .3544 .65945 .35399 Mtetra
.218 .709 .923 r
.65945 .35399 .66042 .3544 .66258 .35555 .66156 .35397 Mtetra
.65 .71 .891 r
.66156 .35397 .66258 .35555 .66467 .35492 .66364 .35326 Mtetra
.679 .71 .871 r
.66364 .35326 .66467 .35492 .66673 .35385 .66572 .35237 Mtetra
.66 .729 .901 r
.66572 .35237 .66673 .35385 .6688 .35281 .6678 .35161 Mtetra
.537 .728 .962 r
.6678 .35161 .6688 .35281 .67089 .35235 .6699 .35132 Mtetra
.636 .808 .966 r
.6699 .35132 .67089 .35235 .67298 .35168 .67199 .35064 Mtetra
.835 .856 .861 r
.67199 .35064 .67298 .35168 .67505 .35046 .67403 .34882 Mtetra
.946 .764 .625 r
.67403 .34882 .67505 .35046 .67705 .34797 .67588 .34317 Mtetra
.976 .674 .361 r
.67588 .34317 .67705 .34797 .67897 .34382 .66781 .13239 Mtetra
.53 .298 .507 r
.66781 .13239 .67897 .34382 .68031 .32796 .66944 .12527 Mtetra
.52 .29 .506 r
.66944 .12527 .68031 .32796 .67245 .12851 .67132 .12314 Mtetra
.622 .461 .643 r
.67132 .12314 .67245 .12851 .67423 .12437 .67323 .1218 Mtetra
.657 .588 .766 r
.67323 .1218 .67423 .12437 .67609 .12213 .67517 .12087 Mtetra
.672 .757 .915 r
.67517 .12087 .67609 .12213 .67803 .12122 .67711 .12011 Mtetra
.638 .775 .946 r
.67711 .12011 .67803 .12122 .67999 .12068 .67907 .11949 Mtetra
.655 .766 .932 r
.67907 .11949 .67999 .12068 .68195 .12018 .68102 .11881 Mtetra
.733 .761 .875 r
.68102 .11881 .68195 .12018 .68389 .11922 .68295 .1177 Mtetra
.668 .711 .88 r
.68295 .1177 .68389 .11922 .68583 .11845 .6849 .11693 Mtetra
.452 .604 .91 r
.6849 .11693 .68583 .11845 .68781 .11814 .6869 .11705 Mtetra
.696 .237 0 r
.6869 .11705 .68781 .11814 .68985 .11896 .68909 .12055 Mtetra
.973 .661 .33 r
.68909 .12055 .68985 .11896 .69198 .12127 .7029 .32966 Mtetra
.527 .29 .498 r
.7029 .32966 .69198 .12127 .69479 .13536 .70545 .33667 Mtetra
.517 .282 .497 r
.70545 .33667 .69479 .13536 .70837 .33423 .70766 .33767 Mtetra
.474 .104 .257 r
.70766 .33767 .70837 .33423 .71071 .33751 .70982 .33778 Mtetra
0 0 0 r
.70982 .33778 .71071 .33751 .71295 .33883 .71196 .33753 Mtetra
.44 .661 .954 r
.71196 .33753 .71295 .33883 .71512 .33911 .71413 .33758 Mtetra
.623 .71 .908 r
.71413 .33758 .71512 .33911 .71725 .33851 .71626 .33699 Mtetra
.802 .778 .831 r
.71626 .33699 .71725 .33851 .7193 .33661 .71831 .33521 Mtetra
.974 .771 .568 r
.71831 .33521 .7193 .33661 .72099 .32903 .72003 .32788 Mtetra
.976 .672 .332 r
.72003 .32788 .72099 .32903 .70961 .11369 .70872 .11276 Mtetra
.979 .812 .606 r
.70872 .11276 .70961 .11369 .71129 .10845 .7104 .10738 Mtetra
.754 .827 .909 r
.7104 .10738 .71129 .10845 .71324 .10735 .71234 .10621 Mtetra
.592 .752 .954 r
.71234 .10621 .71324 .10735 .71523 .10697 .71433 .10576 Mtetra
.503 .692 .953 r
.71433 .10576 .71523 .10697 .71725 .10692 .71634 .10561 Mtetra
.661 .749 .915 r
.71634 .10561 .71725 .10692 .71923 .10625 .71832 .1049 Mtetra
.669 .743 .906 r
.71832 .1049 .71923 .10625 .72121 .10552 .7203 .10413 Mtetra
.686 .744 .896 r
.7203 .10413 .72121 .10552 .72318 .10468 .72227 .10328 Mtetra
.77 .774 .856 r
.72227 .10328 .72318 .10468 .72511 .10325 .7242 .10191 Mtetra
.707 .761 .894 r
.7242 .10191 .72511 .10325 .72707 .10226 .72617 .10095 Mtetra
.496 .67 .941 r
.72617 .10095 .72707 .10226 .7291 .10215 .7282 .10086 Mtetra
.752 .328 0 r
.7282 .10086 .7291 .10215 .73149 .10719 .73057 .10568 Mtetra
.971 .658 .298 r
.73057 .10568 .73149 .10719 .7488 .32167 .74781 .31987 Mtetra
.665 .271 0 r
.74781 .31987 .7488 .32167 .75134 .32649 .75036 .32487 Mtetra
.513 .643 .914 r
.75036 .32487 .75134 .32649 .75352 .32629 .75255 .32477 Mtetra
.686 .742 .893 r
.75255 .32477 .75352 .32629 .75565 .32527 .75468 .32384 Mtetra
.751 .781 .878 r
.75468 .32384 .75565 .32527 .75775 .32386 .75679 .32253 Mtetra
.469 .671 .952 r
.75679 .32253 .75775 .32386 .75995 .32386 .75899 .32249 Mtetra
.59 .728 .939 r
.75899 .32249 .75995 .32386 .76213 .32343 .76117 .32203 Mtetra
.75 .787 .883 r
.76117 .32203 .76213 .32343 .76424 .32216 .76328 .32073 Mtetra
.867 .665 .628 r
.07997 .5435 .081 .54628 .08338 .54034 .08256 .536 Mtetra
.933 .682 .536 r
.08256 .536 .08338 .54034 .11186 .33486 .11081 .33297 Mtetra
.865 .688 .66 r
.11081 .33297 .11186 .33486 .11415 .32885 .11295 .32809 Mtetra
.78 .818 .883 r
.11295 .32809 .11415 .32885 .1158 .3277 .1146 .32694 Mtetra
.63 .802 .965 r
.1146 .32694 .1158 .3277 .11736 .32732 .11617 .32645 Mtetra
.507 .738 .977 r
.11617 .32645 .11736 .32732 .11886 .32734 .1177 .32628 Mtetra
.692 .753 .898 r
.1177 .32628 .11886 .32734 .12044 .3268 .1193 .32556 Mtetra
.684 .72 .877 r
.1193 .32556 .12044 .3268 .12202 .3262 .1209 .32486 Mtetra
.661 .697 .873 r
.1209 .32486 .12202 .3262 .12361 .32555 .12248 .32426 Mtetra
.672 .708 .874 r
.12248 .32426 .12361 .32555 .12526 .32445 .12408 .32361 Mtetra
.554 .763 .975 r
.12408 .32361 .12526 .32445 .12688 .32361 .12562 .32333 Mtetra
.267 0 0 r
.12562 .32333 .12688 .32361 .12843 .32332 .12708 .32379 Mtetra
.885 .546 .402 r
.12708 .32379 .12843 .32332 .12967 .32556 .1279 .32933 Mtetra
.933 .676 .524 r
.1279 .32933 .12967 .32556 .1296 .33822 .10399 .53196 Mtetra
.525 .289 .5 r
.10399 .53196 .1296 .33822 .10677 .53374 .10507 .53626 Mtetra
.485 .096 .226 r
.10507 .53626 .10677 .53374 .10815 .53562 .10667 .53646 Mtetra
0 0 0 r
.10667 .53646 .10815 .53562 .10972 .53611 .10838 .53579 Mtetra
.753 .917 .946 r
.10838 .53579 .10972 .53611 .11135 .536 .11014 .53473 Mtetra
.635 .715 .905 r
.11014 .53473 .11135 .536 .11304 .53552 .11183 .53422 Mtetra
.626 .706 .903 r
.11183 .53422 .11304 .53552 .11475 .53483 .11351 .53374 Mtetra
.65 .753 .924 r
.11351 .53374 .11475 .53483 .11647 .53405 .11521 .53316 Mtetra
.631 .788 .957 r
.11521 .53316 .11647 .53405 .11812 .53395 .11691 .53264 Mtetra
.709 .729 .866 r
.11691 .53264 .11812 .53395 .11978 .53367 .11865 .53174 Mtetra
.76 .671 .764 r
.11865 .53174 .11978 .53367 .12152 .53281 .12048 .53004 Mtetra
.863 .664 .633 r
.12048 .53004 .12152 .53281 .12358 .52928 .12293 .52332 Mtetra
.935 .681 .529 r
.12293 .52332 .12358 .52928 .12665 .51724 .14899 .31916 Mtetra
.529 .298 .508 r
.14899 .31916 .12665 .51724 .1519 .31833 .15114 .31395 Mtetra
.653 .497 .66 r
.15114 .31395 .1519 .31833 .15379 .31535 .15284 .31253 Mtetra
.606 .525 .736 r
.15284 .31253 .15379 .31535 .1555 .3138 .15444 .31202 Mtetra
.548 .589 .847 r
.15444 .31202 .1555 .3138 .15716 .31279 .15599 .31189 Mtetra
.624 .772 .951 r
.15599 .31189 .15716 .31279 .15877 .31213 .15758 .31143 Mtetra
.648 .822 .967 r
.15758 .31143 .15877 .31213 .16036 .31168 .15918 .31086 Mtetra
.66 .8 .95 r
.15918 .31086 .16036 .31168 .16194 .31133 .16079 .31027 Mtetra
.751 .767 .866 r
.16079 .31027 .16194 .31133 .16358 .31047 .16246 .30921 Mtetra
.711 .726 .862 r
.16246 .30921 .16358 .31047 .16521 .3097 .1641 .30834 Mtetra
.565 .662 .902 r
.1641 .30834 .16521 .3097 .16679 .30942 .16567 .30811 Mtetra
.888 .466 .074 r
.16567 .30811 .16679 .30942 .16811 .3114 .16685 .31129 Mtetra
.942 .682 .514 r
.16685 .31129 .16811 .3114 .1684 .32242 .14516 .51553 Mtetra
.53 .294 .501 r
.14516 .51553 .1684 .32242 .14767 .51987 .14604 .52239 Mtetra
.564 .18 .272 r
.14604 .52239 .14767 .51987 .14908 .5221 .14761 .52314 Mtetra
.027 0 0 r
.14761 .52314 .14908 .5221 .15067 .52265 .14933 .52254 Mtetra
.738 .954 .945 r
.14933 .52254 .15067 .52265 .15234 .52259 .15111 .52145 Mtetra
.566 .72 .946 r
.15111 .52145 .15234 .52259 .15401 .52244 .1528 .52116 Mtetra
.578 .697 .923 r
.1528 .52116 .15401 .52244 .15573 .52193 .1545 .52085 Mtetra
.731 .774 .888 r
.1545 .52085 .15573 .52193 .15752 .52079 .15627 .51986 Mtetra
.908 .763 .69 r
.15627 .51986 .15752 .52079 .15955 .51745 .15842 .51545 Mtetra
.943 .687 .52 r
.15842 .51545 .15955 .51745 .16234 .50708 .18253 .31005 Mtetra
.536 .304 .51 r
.18253 .31005 .16234 .50708 .18576 .30629 .185 .30176 Mtetra
.68 .513 .653 r
.185 .30176 .18576 .30629 .18768 .30302 .18677 .29982 Mtetra
.609 .508 .714 r
.18677 .29982 .18768 .30302 .1894 .30146 .18839 .29922 Mtetra
.555 .541 .794 r
.18839 .29922 .1894 .30146 .19108 .30044 .18997 .29908 Mtetra
.63 .686 .883 r
.18997 .29908 .19108 .30044 .19272 .29967 .19158 .2986 Mtetra
.675 .753 .909 r
.19158 .2986 .19272 .29967 .19435 .29905 .19322 .29795 Mtetra
.662 .745 .911 r
.19322 .29795 .19435 .29905 .19598 .29849 .19485 .29735 Mtetra
.684 .742 .895 r
.19485 .29735 .19598 .29849 .19766 .29743 .19649 .29665 Mtetra
.632 .804 .965 r
.19649 .29665 .19766 .29743 .19933 .29641 .19811 .29613 Mtetra
.128 .658 .868 r
.19811 .29613 .19933 .29641 .20095 .29597 .19968 .29617 Mtetra
.833 .411 .238 r
.19968 .29617 .20095 .29597 .2023 .29808 .20097 .29891 Mtetra
.945 .682 .506 r
.20097 .29891 .2023 .29808 .18345 .49662 .18169 .50087 Mtetra
.813 .502 .463 r
.18169 .50087 .18345 .49662 .18373 .51024 .18254 .5089 Mtetra
0 .275 .77 r
.18254 .5089 .18373 .51024 .18528 .5115 .18412 .50995 Mtetra
.656 .682 .863 r
.18412 .50995 .18528 .5115 .18704 .51079 .18587 .5093 Mtetra
.74 .716 .829 r
.18587 .5093 .18704 .51079 .18887 .50943 .18768 .50809 Mtetra
.72 .733 .861 r
.18768 .50809 .18887 .50943 .19067 .50834 .18947 .50709 Mtetra
.679 .738 .895 r
.18947 .50709 .19067 .50834 .19243 .50758 .19123 .50636 Mtetra
.666 .74 .905 r
.19123 .50636 .19243 .50758 .19419 .50691 .19299 .50569 Mtetra
.635 .73 .917 r
.19299 .50569 .19419 .50691 .19593 .50645 .19473 .50516 Mtetra
.606 .709 .917 r
.19473 .50516 .19593 .50645 .19765 .50612 .19647 .50475 Mtetra
.591 .689 .91 r
.19647 .50475 .19765 .50612 .19938 .50581 .1982 .50439 Mtetra
.563 .671 .91 r
.1982 .50439 .19938 .50581 .20112 .50539 .19992 .50414 Mtetra
.554 .698 .935 r
.19992 .50414 .20112 .50539 .20286 .5049 .20164 .5039 Mtetra
.581 .757 .961 r
.20164 .5039 .20286 .5049 .20461 .50441 .20338 .50353 Mtetra
.589 .784 .973 r
.20338 .50353 .20461 .50441 .20632 .50431 .20512 .5031 Mtetra
.674 .745 .905 r
.20512 .5031 .20632 .50431 .20803 .50422 .2069 .5024 Mtetra
.744 .681 .79 r
.2069 .5024 .20803 .50422 .2098 .50359 .20874 .50098 Mtetra
.842 .664 .661 r
.20874 .50098 .2098 .50359 .21175 .50102 .21088 .49638 Mtetra
.946 .685 .51 r
.21088 .49638 .21175 .50102 .21417 .49344 .23192 .29087 Mtetra
.533 .301 .509 r
.23192 .29087 .21417 .49344 .23492 .28905 .23418 .2838 Mtetra
.676 .497 .637 r
.23418 .2838 .23492 .28905 .23691 .28479 .23599 .2816 Mtetra
.619 .516 .715 r
.23599 .2816 .23691 .28479 .23868 .283 .23765 .28091 Mtetra
.577 .57 .809 r
.23765 .28091 .23868 .283 .24039 .28184 .23928 .28065 Mtetra
.619 .717 .916 r
.23928 .28065 .24039 .28184 .24206 .28107 .24092 .28021 Mtetra
.685 .805 .939 r
.24092 .28021 .24206 .28107 .24371 .28052 .24259 .27951 Mtetra
.668 .769 .925 r
.24259 .27951 .24371 .28052 .24536 .28009 .24425 .27888 Mtetra
.664 .729 .898 r
.24425 .27888 .24536 .28009 .24704 .27931 .24592 .27825 Mtetra
.621 .745 .936 r
.24592 .27825 .24704 .27931 .24873 .27835 .24756 .2778 Mtetra
.221 .673 .95 r
.24756 .2778 .24873 .27835 .25039 .27781 .24917 .2779 Mtetra
.821 .375 .175 r
.24917 .2779 .25039 .27781 .2519 .27885 .25056 .2804 Mtetra
.949 .681 .495 r
.25056 .2804 .2519 .27885 .25305 .28423 .23429 .48389 Mtetra
.532 .295 .501 r
.23429 .48389 .25305 .28423 .23692 .4882 .23531 .4919 Mtetra
.618 .269 .356 r
.23531 .4919 .23692 .4882 .23838 .49126 .2369 .49343 Mtetra
.343 0 .101 r
.2369 .49343 .23838 .49126 .24015 .49084 .23867 .49305 Mtetra
.198 0 .022 r
.23867 .49305 .24015 .49084 .24196 .48984 .24048 .49215 Mtetra
.236 0 .055 r
.24048 .49215 .24196 .48984 .24371 .48967 .24228 .49132 Mtetra
.23 0 0 r
.24228 .49132 .24371 .48967 .24538 .49038 .24406 .49078 Mtetra
.269 .766 .711 r
.24406 .49078 .24538 .49038 .24708 .49088 .24585 .49015 Mtetra
.706 .85 .951 r
.24585 .49015 .24708 .49088 .24882 .49086 .24766 .4893 Mtetra
.725 .709 .835 r
.24766 .4893 .24882 .49086 .2506 .49036 .24949 .48818 Mtetra
.702 .635 .779 r
.24949 .48818 .2506 .49036 .25239 .48972 .25133 .48702 Mtetra
.625 .558 .759 r
.25133 .48702 .25239 .48972 .25417 .48928 .25313 .48636 Mtetra
.558 .506 .754 r
.25313 .48636 .25417 .48928 .25594 .48899 .25488 .48617 Mtetra
.63 .553 .749 r
.25488 .48617 .25594 .48899 .25774 .48827 .25669 .48544 Mtetra
.791 .636 .689 r
.25669 .48544 .25774 .48827 .25966 .48611 .25868 .48238 Mtetra
.951 .687 .499 r
.25868 .48238 .25966 .48611 .26188 .48022 .27655 .28093 Mtetra
.546 .312 .511 r
.27655 .28093 .26188 .48022 .2799 .27446 .27922 .268 Mtetra
.681 .486 .616 r
.27922 .268 .2799 .27446 .282 .2686 .28108 .2651 Mtetra
.624 .507 .699 r
.28108 .2651 .282 .2686 .2838 .26656 .28279 .26428 Mtetra
.584 .556 .789 r
.28279 .26428 .2838 .26656 .28553 .26528 .28445 .26396 Mtetra
.573 .68 .912 r
.28445 .26396 .28553 .26528 .28724 .26439 .28611 .26369 Mtetra
.635 .83 .976 r
.28611 .26369 .28724 .26439 .28893 .26374 .28779 .26312 Mtetra
.63 .85 .983 r
.28779 .26312 .28893 .26374 .29061 .26324 .28948 .26255 Mtetra
.651 .837 .972 r
.28948 .26255 .29061 .26324 .29229 .26279 .29117 .26193 Mtetra
.673 .805 .946 r
.29117 .26193 .29229 .26279 .29397 .2623 .29287 .26126 Mtetra
.677 .77 .921 r
.29287 .26126 .29397 .2623 .29566 .2618 .29457 .26058 Mtetra
.678 .735 .894 r
.29457 .26058 .29566 .2618 .29734 .26126 .29627 .25988 Mtetra
.675 .707 .872 r
.29627 .25988 .29734 .26126 .29904 .26064 .29797 .25917 Mtetra
.659 .686 .865 r
.29797 .25917 .29904 .26064 .30074 .25998 .29967 .25852 Mtetra
.62 .674 .881 r
.29967 .25852 .30074 .25998 .30244 .25926 .30135 .25807 Mtetra
.533 .689 .939 r
.30135 .25807 .30244 .25926 .30415 .25848 .30302 .2579 Mtetra
.385 .76 .991 r
.30302 .2579 .30415 .25848 .30586 .2577 .30468 .25779 Mtetra
.321 .809 .838 r
.30468 .25779 .30586 .2577 .30758 .25683 .30637 .25734 Mtetra
.489 .889 .741 r
.30637 .25734 .30758 .25683 .3093 .25586 .3081 .2563 Mtetra
0 0 0 r
.3081 .2563 .3093 .25586 .311 .2553 .3098 .25573 Mtetra
.665 .158 .028 r
.3098 .25573 .311 .2553 .31262 .25585 .31138 .25701 Mtetra
.955 .682 .478 r
.31138 .25701 .31262 .25585 .31401 .25988 .29923 .45769 Mtetra
.54 .301 .502 r
.29923 .45769 .31401 .25988 .30176 .46493 .30017 .46992 Mtetra
.639 .309 .397 r
.30017 .46992 .30176 .46493 .30317 .47044 .3018 .47219 Mtetra
.348 0 .043 r
.3018 .47219 .30317 .47044 .30488 .47145 .3036 .47196 Mtetra
.349 .808 .696 r
.3036 .47196 .30488 .47145 .30666 .47164 .30545 .4711 Mtetra
.735 .897 .952 r
.30545 .4711 .30666 .47164 .30845 .47154 .30731 .47007 Mtetra
.664 .707 .879 r
.30731 .47007 .30845 .47154 .31025 .47146 .30914 .46937 Mtetra
.71 .649 .787 r
.30914 .46937 .31025 .47146 .31208 .47085 .31101 .46815 Mtetra
.787 .642 .701 r
.31101 .46815 .31208 .47085 .31399 .46909 .31299 .46537 Mtetra
.906 .668 .568 r
.31299 .46537 .31399 .46909 .3161 .464 .31568 .45134 Mtetra
.947 .676 .492 r
.31568 .45134 .3161 .464 .33084 .25857 .33023 .2498 Mtetra
.668 .459 .592 r
.33023 .2498 .33084 .25857 .33302 .25052 .33214 .2462 Mtetra
.623 .481 .668 r
.33214 .2462 .33302 .25052 .33477 .24941 .33388 .24519 Mtetra
.577 .453 .675 r
.33388 .24519 .33477 .24941 .33647 .24905 .33559 .24473 Mtetra
.559 .438 .672 r
.33559 .24473 .33647 .24905 .33819 .24845 .33729 .24446 Mtetra
.591 .47 .683 r
.33729 .24446 .33819 .24845 .33999 .24656 .33901 .24388 Mtetra
.615 .545 .752 r
.33901 .24388 .33999 .24656 .34178 .24487 .34073 .2433 Mtetra
.652 .673 .857 r
.34073 .2433 .34178 .24487 .34354 .24359 .34245 .24268 Mtetra
.689 .803 .935 r
.34245 .24268 .34354 .24359 .34527 .24294 .34418 .24193 Mtetra
.68 .781 .926 r
.34418 .24193 .34527 .24294 .34699 .24244 .34591 .24123 Mtetra
.644 .73 .911 r
.34591 .24123 .34699 .24244 .34871 .24191 .34764 .24067 Mtetra
.553 .689 .929 r
.34764 .24067 .34871 .24191 .35044 .24114 .34934 .24043 Mtetra
.445 .764 .996 r
.34934 .24043 .35044 .24114 .35218 .24034 .35105 .24028 Mtetra
.303 .794 .878 r
.35105 .24028 .35218 .24034 .35392 .23949 .35276 .23994 Mtetra
.524 .909 .763 r
.35276 .23994 .35392 .23949 .35568 .23848 .35452 .23886 Mtetra
.32 .796 .719 r
.35452 .23886 .35568 .23848 .35741 .23782 .35626 .23816 Mtetra
.429 0 0 r
.35626 .23816 .35741 .23782 .3591 .23797 .35793 .23865 Mtetra
.914 .572 .378 r
.35793 .23865 .3591 .23797 .36064 .24099 .35916 .24734 Mtetra
.954 .674 .469 r
.35916 .24734 .36064 .24099 .35159 .44368 .34994 .45185 Mtetra
.636 .332 .439 r
.34994 .45185 .35159 .44368 .35291 .45311 .3516 .45511 Mtetra
.4 0 .109 r
.3516 .45511 .35291 .45311 .35467 .45445 .35343 .45501 Mtetra
0 0 0 r
.35343 .45501 .35467 .45445 .35648 .45476 .3553 .45425 Mtetra
.726 .906 .958 r
.3553 .45425 .35648 .45476 .35832 .45455 .35718 .45324 Mtetra
.634 .725 .913 r
.35718 .45324 .35832 .45455 .36018 .45406 .35905 .45267 Mtetra
.648 .718 .899 r
.35905 .45267 .36018 .45406 .36205 .45338 .36091 .45205 Mtetra
.676 .736 .895 r
.36091 .45205 .36205 .45338 .36392 .45264 .36279 .45128 Mtetra
.732 .749 .866 r
.36279 .45128 .36392 .45264 .36579 .45205 .36468 .45018 Mtetra
.718 .677 .81 r
.36468 .45018 .36579 .45205 .36766 .45146 .36658 .44899 Mtetra
.679 .606 .768 r
.36658 .44899 .36766 .45146 .36952 .45092 .36847 .44791 Mtetra
.547 .499 .754 r
.36847 .44791 .36952 .45092 .37138 .4507 .37032 .44779 Mtetra
.601 .536 .753 r
.37032 .44779 .37138 .4507 .37325 .45014 .37218 .44727 Mtetra
.711 .598 .729 r
.37218 .44727 .37325 .45014 .37515 .44879 .3741 .44567 Mtetra
.897 .674 .592 r
.3741 .44567 .37515 .44879 .37722 .44404 .37637 .43651 Mtetra
.958 .682 .471 r
.37637 .43651 .37722 .44404 .38818 .23975 .38753 .22948 Mtetra
.674 .455 .581 r
.38753 .22948 .38818 .23975 .39038 .22918 .38946 .22498 Mtetra
.634 .492 .672 r
.38946 .22498 .39038 .22918 .39217 .22794 .39124 .22384 Mtetra
.584 .462 .68 r
.39124 .22384 .39217 .22794 .39391 .22752 .39299 .22331 Mtetra
.552 .439 .678 r
.39299 .22331 .39391 .22752 .39566 .22724 .39473 .2231 Mtetra
.588 .464 .679 r
.39473 .2231 .39566 .22724 .39747 .22539 .39648 .22253 Mtetra
.609 .532 .742 r
.39648 .22253 .39747 .22539 .39927 .22367 .39824 .22197 Mtetra
.637 .652 .848 r
.39824 .22197 .39927 .22367 .40107 .22223 .4 .2214 Mtetra
.647 .815 .964 r
.4 .2214 .40107 .22223 .40284 .22145 .40176 .22079 Mtetra
.643 .852 .98 r
.40176 .22079 .40284 .22145 .4046 .22084 .40353 .22015 Mtetra
.654 .849 .975 r
.40353 .22015 .4046 .22084 .40636 .22031 .40529 .21949 Mtetra
.676 .825 .955 r
.40529 .21949 .40636 .22031 .40812 .21966 .40706 .21877 Mtetra
.681 .813 .946 r
.40706 .21877 .40812 .21966 .40989 .219 .40883 .21804 Mtetra
.681 .798 .937 r
.40883 .21804 .40989 .219 .41166 .21834 .4106 .21732 Mtetra
.672 .781 .932 r
.4106 .21732 .41166 .21834 .41343 .21767 .41238 .21663 Mtetra
.669 .777 .93 r
.41238 .21663 .41343 .21767 .4152 .21701 .41415 .21595 Mtetra
.667 .773 .929 r
.41415 .21595 .4152 .21701 .41697 .21637 .41592 .21528 Mtetra
.682 .772 .919 r
.41592 .21528 .41697 .21637 .41874 .21581 .4177 .21454 Mtetra
.669 .734 .898 r
.4177 .21454 .41874 .21581 .42051 .21525 .41947 .21385 Mtetra
.647 .703 .888 r
.41947 .21385 .42051 .21525 .42229 .21465 .42125 .21325 Mtetra
.562 .668 .909 r
.42125 .21325 .42229 .21465 .42407 .2139 .42301 .213 Mtetra
.476 .737 .984 r
.42301 .213 .42407 .2139 .42585 .2131 .42477 .21286 Mtetra
.252 .747 .908 r
.42477 .21286 .42585 .2131 .42763 .2123 .42654 .21271 Mtetra
0 0 0 r
.42654 .21271 .42763 .2123 .42941 .21158 .42832 .21212 Mtetra
.42832 .21212 .42941 .21158 .4312 .21088 .4301 .21139 Mtetra
.4301 .21139 .4312 .21088 .43298 .2102 .43189 .2106 Mtetra
.559 .925 .769 r
.43189 .2106 .43298 .2102 .43477 .20918 .43369 .20942 Mtetra
.442 .876 .803 r
.43369 .20942 .43477 .20918 .43656 .2084 .43548 .2086 Mtetra
.065 0 0 r
.43548 .2086 .43656 .2084 .43833 .20815 .43725 .20854 Mtetra
.883 .484 .264 r
.43725 .20854 .43833 .20815 .44004 .21034 .43888 .21347 Mtetra
.964 .678 .44 r
.43888 .21347 .44004 .21034 .44149 .2222 .43488 .42177 Mtetra
.524 .288 .499 r
.43488 .42177 .44149 .2222 .43786 .42402 .43665 .42652 Mtetra
.491 .09 .207 r
.43665 .42652 .43786 .42402 .43971 .426 .43854 .42683 Mtetra
0 0 0 r
.43854 .42683 .43971 .426 .4416 .42648 .44046 .42618 Mtetra
.702 .947 .957 r
.44046 .42618 .4416 .42648 .44351 .42636 .4424 .42513 Mtetra
.645 .751 .926 r
.4424 .42513 .44351 .42636 .44543 .42593 .44432 .4245 Mtetra
.641 .715 .902 r
.44432 .4245 .44543 .42593 .44735 .42528 .44625 .42389 Mtetra
.664 .73 .899 r
.44625 .42389 .44735 .42528 .44928 .42451 .44818 .42316 Mtetra
.647 .731 .91 r
.44818 .42316 .44928 .42451 .4512 .42422 .45011 .42252 Mtetra
.7 .697 .844 r
.45011 .42252 .4512 .42422 .45313 .42374 .45205 .42152 Mtetra
.757 .666 .761 r
.45205 .42152 .45313 .42374 .45507 .42268 .454 .41973 Mtetra
.884 .676 .616 r
.454 .41973 .45507 .42268 .45707 .41885 .45606 .41302 Mtetra
.966 .684 .446 r
.45606 .41302 .45707 .41885 .45927 .4051 .46232 .20319 Mtetra
.528 .296 .507 r
.46232 .20319 .45927 .4051 .46518 .20225 .46422 .19765 Mtetra
.658 .498 .657 r
.46422 .19765 .46518 .20225 .46702 .20017 .46605 .19602 Mtetra
.595 .469 .679 r
.46605 .19602 .46702 .20017 .46882 .1996 .46786 .19536 Mtetra
.558 .443 .678 r
.46786 .19536 .46882 .1996 .47062 .19936 .46966 .19508 Mtetra
.58 .457 .676 r
.46966 .19508 .47062 .19936 .47245 .19778 .47146 .19457 Mtetra
.605 .512 .723 r
.47146 .19457 .47245 .19778 .47428 .19599 .47327 .19397 Mtetra
.635 .616 .814 r
.47327 .19397 .47428 .19599 .47611 .19447 .47508 .19335 Mtetra
.681 .772 .919 r
.47508 .19335 .47611 .19447 .47792 .1936 .4769 .1926 Mtetra
.686 .797 .934 r
.4769 .1926 .47792 .1936 .47973 .19302 .47871 .19184 Mtetra
.669 .754 .915 r
.47871 .19184 .47973 .19302 .48155 .19252 .48053 .19114 Mtetra
.596 .69 .908 r
.48053 .19114 .48155 .19252 .48336 .19179 .48234 .19075 Mtetra
.528 .73 .967 r
.48234 .19075 .48336 .19179 .48518 .19097 .48415 .19052 Mtetra
.379 .793 .978 r
.48415 .19052 .48518 .19097 .487 .19013 .48597 .19031 Mtetra
.527 .92 .838 r
.48597 .19031 .487 .19013 .48882 .18908 .48779 .18936 Mtetra
.485 .896 .79 r
.48779 .18936 .48882 .18908 .49065 .1882 .48962 .18839 Mtetra
.153 .69 .706 r
.48962 .18839 .49065 .1882 .49247 .18778 .49144 .18802 Mtetra
.818 .354 .116 r
.49144 .18802 .49247 .18778 .49427 .18924 .49322 .191 Mtetra
.969 .677 .418 r
.49322 .191 .49427 .18924 .49603 .19512 .49298 .399 Mtetra
.528 .291 .499 r
.49298 .399 .49603 .19512 .496 .40264 .49487 .40604 Mtetra
.553 .183 .293 r
.49487 .40604 .496 .40264 .49792 .40581 .49682 .40689 Mtetra
.075 0 0 r
.49682 .40689 .49792 .40581 .49987 .40651 .49878 .40621 Mtetra
.729 .957 .945 r
.49878 .40621 .49987 .40651 .50183 .40645 .50075 .40503 Mtetra
.694 .739 .885 r
.50075 .40503 .50183 .40645 .50379 .40594 .50272 .40412 Mtetra
.65 .665 .852 r
.50272 .40412 .50379 .40594 .50576 .40514 .50468 .40341 Mtetra
.648 .677 .863 r
.50468 .40341 .50576 .40514 .50773 .40421 .50665 .40273 Mtetra
.533 .664 .921 r
.50665 .40273 .50773 .40421 .5097 .40389 .50862 .40255 Mtetra
.555 .698 .936 r
.50862 .40255 .5097 .40389 .51167 .40358 .51059 .40227 Mtetra
.716 .766 .891 r
.51059 .40227 .51167 .40358 .51364 .40255 .51256 .40125 Mtetra
.93 .778 .671 r
.51256 .40125 .51364 .40255 .51563 .39788 .51455 .39664 Mtetra
.974 .687 .42 r
.51455 .39664 .51563 .39788 .51808 .18647 .51707 .18545 Mtetra
.966 .76 .575 r
.51707 .18545 .51808 .18647 .51993 .17881 .51893 .17766 Mtetra
.859 .802 .794 r
.51893 .17766 .51993 .17881 .52178 .17672 .52078 .1755 Mtetra
.668 .752 .913 r
.52078 .1755 .52178 .17672 .52362 .17611 .52262 .1748 Mtetra
.55 .686 .929 r
.52262 .1748 .52362 .17611 .52546 .17598 .52446 .17456 Mtetra
.598 .686 .903 r
.52446 .17456 .52546 .17598 .52731 .17566 .52631 .17416 Mtetra
.641 .691 .881 r
.52631 .17416 .52731 .17566 .52916 .1751 .52816 .17356 Mtetra
.642 .687 .876 r
.52816 .17356 .52916 .1751 .531 .17451 .53001 .17296 Mtetra
.656 .69 .87 r
.53001 .17296 .531 .17451 .53285 .1739 .53186 .17228 Mtetra
.659 .681 .86 r
.53186 .17228 .53285 .1739 .5347 .17326 .53371 .17157 Mtetra
.645 .666 .855 r
.53371 .17157 .5347 .17326 .53656 .17258 .53556 .17093 Mtetra
.593 .648 .874 r
.53556 .17093 .53656 .17258 .53841 .17182 .53741 .17056 Mtetra
.52 .683 .941 r
.53741 .17056 .53841 .17182 .54026 .171 .53927 .17041 Mtetra
.375 .763 .989 r
.53927 .17041 .54026 .171 .54212 .17017 .54113 .17028 Mtetra
.215 .738 .763 r
.54113 .17028 .54212 .17017 .54397 .16938 .54299 .16987 Mtetra
0 0 0 r
.54299 .16987 .54397 .16938 .54583 .16864 .54485 .16915 Mtetra
.54485 .16915 .54583 .16864 .54769 .16791 .54671 .16833 Mtetra
.54671 .16833 .54769 .16791 .54955 .16719 .54857 .16755 Mtetra
.274 .761 .675 r
.54857 .16755 .54955 .16719 .55141 .16646 .55044 .16681 Mtetra
.274 .762 .678 r
.55044 .16681 .55141 .16646 .55327 .16574 .5523 .16608 Mtetra
.273 .761 .679 r
.5523 .16608 .55327 .16574 .55513 .16501 .55416 .16536 Mtetra
.268 .758 .677 r
.55416 .16536 .55513 .16501 .557 .16429 .55603 .16464 Mtetra
.26 .752 .671 r
.55603 .16464 .557 .16429 .55887 .16357 .5579 .16393 Mtetra
.251 .745 .663 r
.5579 .16393 .55887 .16357 .56073 .16286 .55977 .16323 Mtetra
0 0 0 r
.55977 .16323 .56073 .16286 .5626 .16215 .56164 .16253 Mtetra
.56164 .16253 .5626 .16215 .56447 .16144 .56351 .16183 Mtetra
.56351 .16183 .56447 .16144 .56634 .16074 .56538 .16113 Mtetra
.56538 .16113 .56634 .16074 .56822 .16004 .56726 .16044 Mtetra
.56726 .16044 .56822 .16004 .57009 .15933 .56913 .15974 Mtetra
.56913 .15974 .57009 .15933 .57196 .15864 .57101 .15905 Mtetra
.57101 .15905 .57196 .15864 .57384 .15794 .57289 .15835 Mtetra
.57289 .15835 .57384 .15794 .57572 .15724 .57477 .15765 Mtetra
.57477 .15765 .57572 .15724 .5776 .15654 .57665 .15696 Mtetra
.57665 .15696 .5776 .15654 .57948 .15584 .57853 .15626 Mtetra
.57853 .15626 .57948 .15584 .58136 .15514 .58042 .15556 Mtetra
.58042 .15556 .58136 .15514 .58324 .15444 .5823 .15486 Mtetra
.5823 .15486 .58324 .15444 .58513 .15375 .58419 .15417 Mtetra
.58419 .15417 .58513 .15375 .58701 .15305 .58607 .15347 Mtetra
.58607 .15347 .58701 .15305 .5889 .15235 .58796 .15277 Mtetra
.58796 .15277 .5889 .15235 .59079 .15165 .58985 .15207 Mtetra
.58985 .15207 .59079 .15165 .59267 .15095 .59174 .15137 Mtetra
.59174 .15137 .59267 .15095 .59457 .15025 .59364 .15067 Mtetra
.59364 .15067 .59457 .15025 .59646 .14955 .59553 .14997 Mtetra
.59553 .14997 .59646 .14955 .59835 .14885 .59743 .14927 Mtetra
.59743 .14927 .59835 .14885 .60024 .14815 .59932 .14857 Mtetra
.59932 .14857 .60024 .14815 .60214 .14745 .60122 .14787 Mtetra
.60122 .14787 .60214 .14745 .60404 .14675 .60312 .14717 Mtetra
.60312 .14717 .60404 .14675 .60594 .14605 .60502 .14647 Mtetra
.60502 .14647 .60594 .14605 .60784 .14536 .60692 .14577 Mtetra
.60692 .14577 .60784 .14536 .60974 .14466 .60882 .14507 Mtetra
.60882 .14507 .60974 .14466 .61164 .14396 .61073 .14438 Mtetra
.61073 .14438 .61164 .14396 .61354 .14326 .61263 .14368 Mtetra
.61263 .14368 .61354 .14326 .61545 .14257 .61454 .14298 Mtetra
.61454 .14298 .61545 .14257 .61735 .14187 .61645 .14228 Mtetra
.61645 .14228 .61735 .14187 .61926 .14118 .61836 .14158 Mtetra
.61836 .14158 .61926 .14118 .62117 .14048 .62027 .14087 Mtetra
.62027 .14087 .62117 .14048 .62308 .13977 .62218 .14014 Mtetra
.62218 .14014 .62308 .13977 .62499 .13904 .62409 .1394 Mtetra
.62409 .1394 .62499 .13904 .6269 .13831 .62601 .13866 Mtetra
.367 .817 .695 r
.62601 .13866 .6269 .13831 .62881 .13745 .62791 .13772 Mtetra
.514 .904 .761 r
.62791 .13772 .62881 .13745 .63072 .13643 .62981 .13657 Mtetra
.297 .791 .771 r
.62981 .13657 .63072 .13643 .63263 .13578 .63174 .13596 Mtetra
.555 0 0 r
.63174 .13596 .63263 .13578 .6346 .1363 .63373 .13714 Mtetra
.974 .668 .355 r
.63373 .13714 .6346 .1363 .6367 .14043 .64314 .33653 Mtetra
.548 .306 .5 r
.64314 .33653 .6367 .14043 .6467 .35008 .64592 .35482 Mtetra
.636 .282 .354 r
.64592 .35482 .6467 .35008 .64899 .35507 .64811 .35719 Mtetra
.358 0 .099 r
.64811 .35719 .64899 .35507 .65107 .35469 .65019 .35684 Mtetra
.227 0 .051 r
.65019 .35684 .65107 .35469 .65312 .35357 .65226 .35586 Mtetra
.21 0 .065 r
.65226 .35586 .65312 .35357 .6552 .35287 .65431 .35472 Mtetra
.225 0 .004 r
.65431 .35472 .6552 .35287 .65733 .35353 .65639 .3539 Mtetra
0 0 0 r
.65639 .3539 .65733 .35353 .65945 .35399 .65846 .35309 Mtetra
.649 .839 .973 r
.65846 .35309 .65945 .35399 .66156 .35397 .66054 .35234 Mtetra
.637 .697 .889 r
.66054 .35234 .66156 .35397 .66364 .35326 .66262 .35169 Mtetra
.632 .705 .899 r
.66262 .35169 .66364 .35326 .66572 .35237 .66471 .35108 Mtetra
.59 .735 .944 r
.66471 .35108 .66572 .35237 .6678 .35161 .66681 .35062 Mtetra
.466 .739 .987 r
.66681 .35062 .6678 .35161 .6699 .35132 .66892 .35046 Mtetra
.629 .84 .981 r
.66892 .35046 .6699 .35132 .67199 .35064 .67101 .34976 Mtetra
.879 .883 .833 r
.67101 .34976 .67199 .35064 .67403 .34882 .67303 .34756 Mtetra
.98 .758 .53 r
.67303 .34756 .67403 .34882 .67588 .34317 .6747 .33811 Mtetra
.976 .673 .361 r
.6747 .33811 .67588 .34317 .66781 .13239 .66661 .12554 Mtetra
.72 .505 .598 r
.66661 .12554 .66781 .13239 .66944 .12527 .66838 .12123 Mtetra
.627 .497 .685 r
.66838 .12123 .66944 .12527 .67132 .12314 .6703 .12018 Mtetra
.582 .519 .75 r
.6703 .12018 .67132 .12314 .67323 .1218 .67227 .11979 Mtetra
.553 .586 .841 r
.67227 .11979 .67323 .1218 .67517 .12087 .67424 .1196 Mtetra
.649 .748 .922 r
.67424 .1196 .67517 .12087 .67711 .12011 .67619 .11894 Mtetra
.655 .771 .935 r
.67619 .11894 .67711 .12011 .67907 .11949 .67814 .11826 Mtetra
.689 .771 .914 r
.67814 .11826 .67907 .11949 .68102 .11881 .68009 .11741 Mtetra
.755 .766 .861 r
.68009 .11741 .68102 .11881 .68295 .1177 .68201 .11615 Mtetra
.677 .711 .874 r
.68201 .11615 .68295 .1177 .6849 .11693 .68396 .11533 Mtetra
.388 .553 .896 r
.68396 .11533 .6849 .11693 .6869 .11705 .68597 .11569 Mtetra
.851 .451 0 r
.68597 .11569 .6869 .11705 .68909 .12055 .68834 .12228 Mtetra
.973 .661 .33 r
.68834 .12228 .68909 .12055 .7029 .32966 .70228 .33478 Mtetra
.687 .331 .366 r
.70228 .33478 .7029 .32966 .70545 .33667 .70464 .33853 Mtetra
.377 0 .065 r
.70464 .33853 .70545 .33667 .70766 .33767 .70679 .33837 Mtetra
0 0 0 r
.70679 .33837 .70766 .33767 .70982 .33778 .70889 .33742 Mtetra
.724 .967 .936 r
.70889 .33742 .70982 .33778 .71196 .33753 .71098 .33614 Mtetra
.644 .743 .921 r
.71098 .33614 .71196 .33753 .71413 .33758 .7131 .33545 Mtetra
.698 .665 .814 r
.7131 .33545 .71413 .33758 .71626 .33699 .71519 .3343 Mtetra
.774 .653 .729 r
.71519 .3343 .71626 .33699 .71831 .33521 .71722 .33197 Mtetra
.932 .689 .548 r
.71722 .33197 .71831 .33521 .72003 .32788 .71879 .32229 Mtetra
.975 .669 .342 r
.71879 .32229 .72003 .32788 .70872 .11276 .70777 .11089 Mtetra
.919 .745 .651 r
.70777 .11089 .70872 .11276 .7104 .10738 .70951 .10638 Mtetra
.76 .844 .915 r
.70951 .10638 .7104 .10738 .71234 .10621 .71145 .10519 Mtetra
.62 .791 .964 r
.71145 .10519 .71234 .10621 .71433 .10576 .71343 .10461 Mtetra
.557 .735 .959 r
.71343 .10461 .71433 .10576 .71634 .10561 .71543 .10427 Mtetra
.694 .756 .899 r
.71543 .10427 .71634 .10561 .71832 .1049 .7174 .10339 Mtetra
.681 .722 .88 r
.7174 .10339 .71832 .1049 .7203 .10413 .71937 .10254 Mtetra
.663 .701 .875 r
.71937 .10254 .7203 .10413 .72227 .10328 .72135 .10178 Mtetra
.671 .72 .886 r
.72135 .10178 .72227 .10328 .7242 .10191 .72333 .101 Mtetra
.541 .782 .987 r
.72333 .101 .7242 .10191 .72617 .10095 .72533 .10063 Mtetra
0 .445 .742 r
.72533 .10063 .72617 .10095 .7282 .10086 .72741 .10117 Mtetra
.895 .475 .15 r
.72741 .10117 .7282 .10086 .73057 .10568 .72992 .10804 Mtetra
.971 .655 .309 r
.72992 .10804 .73057 .10568 .74781 .31987 .7469 .31929 Mtetra
.768 .282 0 r
.7469 .31929 .74781 .31987 .75036 .32487 .74937 .3232 Mtetra
.477 .614 .908 r
.74937 .3232 .75036 .32487 .75255 .32477 .75157 .32325 Mtetra
.648 .726 .906 r
.75157 .32325 .75255 .32477 .75468 .32384 .75372 .32252 Mtetra
.735 .796 .901 r
.75372 .32252 .75468 .32384 .75679 .32253 .75584 .32135 Mtetra
.632 .782 .954 r
.75584 .32135 .75679 .32253 .75899 .32249 .758 .32068 Mtetra
.707 .709 .85 r
.758 .32068 .75899 .32249 .76117 .32203 .76012 .31956 Mtetra
.764 .667 .755 r
.76012 .31956 .76117 .32203 .76328 .32073 .76218 .31755 Mtetra
.926 .675 .538 r
.07992 .53336 .07997 .5435 .08256 .536 .1078 .33442 Mtetra
.528 .297 .508 r
.1078 .33442 .08256 .536 .11081 .33297 .10996 .32949 Mtetra
.74 .576 .671 r
.10996 .32949 .11081 .33297 .11295 .32809 .11179 .32696 Mtetra
.727 .746 .867 r
.11179 .32696 .11295 .32809 .1146 .32694 .11342 .32604 Mtetra
.644 .774 .942 r
.11342 .32604 .1146 .32694 .11617 .32645 .11499 .32552 Mtetra
.588 .753 .957 r
.11499 .32552 .11617 .32645 .1177 .32628 .11654 .32517 Mtetra
.738 .753 .864 r
.11654 .32517 .1177 .32628 .1193 .32556 .11818 .32418 Mtetra
.703 .702 .846 r
.11818 .32418 .1193 .32556 .1209 .32486 .11979 .32334 Mtetra
.637 .659 .855 r
.11979 .32334 .1209 .32486 .12248 .32426 .12137 .32283 Mtetra
.175 .445 .875 r
.12137 .32283 .12248 .32426 .12408 .32361 .1228 .32344 Mtetra
.785 .303 .081 r
.1228 .32344 .12408 .32361 .12562 .32333 .12409 .32524 Mtetra
.837 .511 .437 r
.12409 .32524 .12562 .32333 .12708 .32379 .12488 .33089 Mtetra
.929 .671 .526 r
.12488 .33089 .12708 .32379 .1279 .32933 .10126 .52986 Mtetra
.524 .288 .499 r
.10126 .52986 .1279 .32933 .10399 .53196 .10234 .53411 Mtetra
.667 .287 .316 r
.10234 .53411 .10399 .53196 .10507 .53626 .10376 .53575 Mtetra
.438 .803 .995 r
.10376 .53575 .10507 .53626 .10667 .53646 .10541 .53552 Mtetra
.701 .791 .92 r
.10541 .53552 .10667 .53646 .10838 .53579 .10713 .53473 Mtetra
.738 .774 .881 r
.10713 .53473 .10838 .53579 .11014 .53473 .10889 .5337 Mtetra
.547 .733 .962 r
.10889 .5337 .11014 .53473 .11183 .53422 .11054 .53345 Mtetra
.533 .785 .99 r
.11054 .53345 .11183 .53422 .11351 .53374 .11221 .53315 Mtetra
.651 .857 .978 r
.11221 .53315 .11351 .53374 .11521 .53316 .11392 .53251 Mtetra
.847 .836 .835 r
.11392 .53251 .11521 .53316 .11691 .53264 .11577 .53066 Mtetra
.828 .686 .706 r
.11577 .53066 .11691 .53264 .11865 .53174 .11779 .52749 Mtetra
.826 .618 .622 r
.11779 .52749 .11865 .53174 .12048 .53004 .12026 .52054 Mtetra
.931 .677 .531 r
.12026 .52054 .12048 .53004 .12293 .52332 .14606 .32008 Mtetra
.528 .297 .508 r
.14606 .32008 .12293 .52332 .14899 .31916 .14821 .31493 Mtetra
.72 .546 .653 r
.14821 .31493 .14899 .31916 .15114 .31395 .15006 .31232 Mtetra
.707 .672 .814 r
.15006 .31232 .15114 .31395 .15284 .31253 .15171 .31135 Mtetra
.606 .71 .918 r
.15171 .31135 .15284 .31253 .15444 .31202 .15328 .31098 Mtetra
.508 .701 .957 r
.15328 .31098 .15444 .31202 .15599 .31189 .15484 .31085 Mtetra
.625 .743 .932 r
.15484 .31085 .15599 .31189 .15758 .31143 .15643 .31039 Mtetra
.663 .755 .919 r
.15643 .31039 .15758 .31143 .15918 .31086 .15803 .3098 Mtetra
.678 .753 .908 r
.15803 .3098 .15918 .31086 .16079 .31027 .15965 .30915 Mtetra
.764 .756 .845 r
.15965 .30915 .16079 .31027 .16246 .30921 .16133 .30795 Mtetra
.729 .73 .851 r
.16133 .30795 .16246 .30921 .1641 .30834 .16299 .30696 Mtetra
.593 .669 .892 r
.16299 .30696 .1641 .30834 .16567 .30811 .16457 .30664 Mtetra
.873 .453 .026 r
.16457 .30664 .16567 .30811 .16685 .31129 .16576 .30975 Mtetra
.944 .684 .513 r
.16576 .30975 .16685 .31129 .14516 .51553 .14391 .51464 Mtetra
.938 .6 .363 r
.14391 .51464 .14516 .51553 .14604 .52239 .14476 .52168 Mtetra
0 .35 .734 r
.14476 .52168 .14604 .52239 .14761 .52314 .14634 .52236 Mtetra
.68 .824 .953 r
.14634 .52236 .14761 .52314 .14933 .52254 .14808 .52165 Mtetra
.771 .811 .885 r
.14808 .52165 .14933 .52254 .15111 .52145 .14987 .52044 Mtetra
.527 .733 .969 r
.14987 .52044 .15111 .52145 .1528 .52116 .15156 .52023 Mtetra
.499 .739 .98 r
.15156 .52023 .1528 .52116 .1545 .52085 .15324 .52005 Mtetra
.715 .826 .934 r
.15324 .52005 .1545 .52085 .15627 .51986 .155 .51918 Mtetra
.919 .782 .694 r
.155 .51918 .15627 .51986 .15842 .51545 .15715 .51481 Mtetra
.945 .689 .519 r
.15715 .51481 .15842 .51545 .18253 .31005 .18142 .30872 Mtetra
.918 .715 .612 r
.18142 .30872 .18253 .31005 .185 .30176 .18389 .30033 Mtetra
.805 .722 .773 r
.18389 .30033 .185 .30176 .18677 .29982 .18566 .29844 Mtetra
.635 .686 .881 r
.18566 .29844 .18677 .29982 .18839 .29922 .18727 .29794 Mtetra
.488 .645 .927 r
.18727 .29794 .18839 .29922 .18997 .29908 .18884 .29792 Mtetra
.647 .73 .909 r
.18884 .29792 .18997 .29908 .19158 .2986 .19046 .29738 Mtetra
.688 .729 .882 r
.19046 .29738 .19158 .2986 .19322 .29795 .19211 .29664 Mtetra
.637 .7 .891 r
.19211 .29664 .19322 .29795 .19485 .29735 .19372 .29614 Mtetra
.341 .59 .937 r
.19372 .29614 .19485 .29735 .19649 .29665 .19527 .2964 Mtetra
.65 .093 0 r
.19527 .2964 .19649 .29665 .19811 .29613 .19671 .29761 Mtetra
.784 .41 .348 r
.19671 .29761 .19811 .29613 .19968 .29617 .19796 .30065 Mtetra
.94 .676 .509 r
.19796 .30065 .19968 .29617 .20097 .29891 .179 .49783 Mtetra
.532 .295 .501 r
.179 .49783 .20097 .29891 .18169 .50087 .17982 .50603 Mtetra
.643 .322 .413 r
.17982 .50603 .18169 .50087 .18254 .5089 .18126 .50838 Mtetra
.081 .597 .883 r
.18126 .50838 .18254 .5089 .18412 .50995 .18292 .50862 Mtetra
.679 .724 .883 r
.18292 .50862 .18412 .50995 .18587 .5093 .18468 .50787 Mtetra
.732 .723 .843 r
.18468 .50787 .18587 .5093 .18768 .50809 .18649 .50676 Mtetra
.71 .733 .869 r
.18649 .50676 .18768 .50809 .18947 .50709 .18827 .50584 Mtetra
.672 .735 .897 r
.18827 .50584 .18947 .50709 .19123 .50636 .19003 .50514 Mtetra
.654 .736 .91 r
.19003 .50514 .19123 .50636 .19299 .50569 .19178 .50453 Mtetra
.62 .736 .929 r
.19178 .50453 .19299 .50569 .19473 .50516 .19352 .50405 Mtetra
.585 .735 .946 r
.19352 .50405 .19473 .50516 .19647 .50475 .19525 .50369 Mtetra
.558 .736 .959 r
.19525 .50369 .19647 .50475 .1982 .50439 .19698 .50339 Mtetra
.428 .696 .976 r
.19698 .50339 .1982 .50439 .19992 .50414 .19868 .50338 Mtetra
.378 .726 .989 r
.19868 .50338 .19992 .50414 .20164 .5039 .20038 .50336 Mtetra
.536 .84 .999 r
.20038 .50336 .20164 .5039 .20338 .50353 .20212 .50295 Mtetra
.811 .874 .893 r
.20212 .50295 .20338 .50353 .20512 .5031 .20396 .50152 Mtetra
.841 .724 .734 r
.20396 .50152 .20512 .5031 .2069 .5024 .20593 .49871 Mtetra
.825 .627 .635 r
.20593 .49871 .2069 .5024 .20874 .50098 .20817 .49312 Mtetra
.942 .681 .512 r
.20817 .49312 .20874 .50098 .21088 .49638 .22905 .29129 Mtetra
.531 .299 .508 r
.22905 .29129 .21088 .49638 .23192 .29087 .23127 .28472 Mtetra
.691 .497 .62 r
.23127 .28472 .23192 .29087 .23418 .2838 .23315 .28171 Mtetra
.73 .641 .76 r
.23315 .28171 .23418 .2838 .23599 .2816 .23488 .28032 Mtetra
.639 .706 .895 r
.23488 .28032 .23599 .2816 .23765 .28091 .23653 .2798 Mtetra
.555 .709 .943 r
.23653 .2798 .23765 .28091 .23928 .28065 .23816 .27955 Mtetra
.661 .749 .915 r
.23816 .27955 .23928 .28065 .24092 .28021 .23982 .27895 Mtetra
.716 .733 .864 r
.23982 .27895 .24092 .28021 .24259 .27951 .2415 .27804 Mtetra
.667 .686 .858 r
.2415 .27804 .24259 .27951 .24425 .27888 .24317 .27736 Mtetra
.467 .594 .896 r
.24317 .27736 .24425 .27888 .24592 .27825 .24477 .27745 Mtetra
.499 0 0 r
.24477 .27745 .24592 .27825 .24756 .2778 .24627 .27867 Mtetra
.821 .429 .311 r
.24627 .27867 .24756 .2778 .24917 .2779 .24759 .28196 Mtetra
.946 .677 .497 r
.24759 .28196 .24917 .2779 .25056 .2804 .23144 .48197 Mtetra
.531 .294 .501 r
.23144 .48197 .25056 .2804 .23429 .48389 .23249 .48963 Mtetra
.636 .318 .416 r
.23249 .48963 .23429 .48389 .23531 .4919 .234 .49204 Mtetra
.428 0 0 r
.234 .49204 .23531 .4919 .2369 .49343 .23568 .49262 Mtetra
.591 .803 .981 r
.23568 .49262 .2369 .49343 .23867 .49305 .23745 .49217 Mtetra
.694 .815 .939 r
.23745 .49217 .23867 .49305 .24048 .49215 .23925 .49137 Mtetra
.652 .828 .967 r
.23925 .49137 .24048 .49215 .24228 .49132 .24104 .49072 Mtetra
.556 .837 .997 r
.24104 .49072 .24228 .49132 .24406 .49078 .24281 .49028 Mtetra
.648 .885 .984 r
.24281 .49028 .24406 .49078 .24585 .49015 .24461 .48957 Mtetra
.83 .876 .877 r
.24461 .48957 .24585 .49015 .24766 .4893 .24648 .48798 Mtetra
.867 .753 .735 r
.24648 .48798 .24766 .4893 .24949 .48818 .24848 .48494 Mtetra
.826 .638 .648 r
.24848 .48494 .24949 .48818 .25133 .48702 .25062 .4801 Mtetra
.741 .53 .608 r
.25062 .4801 .25133 .48702 .25313 .48636 .25279 .47488 Mtetra
.515 .331 .57 r
.25279 .47488 .25313 .48636 .25488 .48617 .25451 .47509 Mtetra
.529 .344 .574 r
.25451 .47509 .25488 .48617 .25669 .48544 .25626 .47496 Mtetra
.943 .677 .504 r
.25626 .47496 .25669 .48544 .25868 .48238 .27345 .2841 Mtetra
.55 .315 .512 r
.27345 .2841 .25868 .48238 .27655 .28093 .27626 .26961 Mtetra
.651 .435 .578 r
.27626 .26961 .27655 .28093 .27922 .268 .27821 .26564 Mtetra
.754 .634 .728 r
.27821 .26564 .27922 .268 .28108 .2651 .28 .26375 Mtetra
.657 .704 .882 r
.28 .26375 .28108 .2651 .28279 .26428 .28168 .26314 Mtetra
.561 .709 .94 r
.28168 .26314 .28279 .26428 .28445 .26396 .28334 .26287 Mtetra
.564 .721 .947 r
.28334 .26287 .28445 .26396 .28611 .26369 .28501 .26259 Mtetra
.648 .749 .923 r
.28501 .26259 .28611 .26369 .28779 .26312 .28669 .26203 Mtetra
.663 .754 .918 r
.28669 .26203 .28779 .26312 .28948 .26255 .28838 .2614 Mtetra
.683 .75 .903 r
.28838 .2614 .28948 .26255 .29117 .26193 .29008 .26069 Mtetra
.697 .737 .881 r
.29008 .26069 .29117 .26193 .29287 .26126 .29179 .25988 Mtetra
.693 .713 .864 r
.29179 .25988 .29287 .26126 .29457 .26058 .2935 .25907 Mtetra
.693 .694 .846 r
.2935 .25907 .29457 .26058 .29627 .25988 .29521 .25823 Mtetra
.687 .673 .831 r
.29521 .25823 .29627 .25988 .29797 .25917 .29692 .25739 Mtetra
.641 .638 .832 r
.29692 .25739 .29797 .25917 .29967 .25852 .29861 .2568 Mtetra
.473 .565 .868 r
.29861 .2568 .29967 .25852 .30135 .25807 .30026 .25691 Mtetra
0 .03 .541 r
.30026 .25691 .30135 .25807 .30302 .2579 .3018 .25842 Mtetra
.836 .426 .263 r
.3018 .25842 .30302 .2579 .30468 .25779 .30322 .26171 Mtetra
.787 .459 .433 r
.30322 .26171 .30468 .25779 .30637 .25734 .30447 .26758 Mtetra
.429 .162 .404 r
.30447 .26758 .30637 .25734 .3081 .2563 .30623 .26611 Mtetra
.444 .172 .405 r
.30623 .26611 .3081 .2563 .3098 .25573 .30798 .26497 Mtetra
.945 .669 .486 r
.30798 .26497 .3098 .25573 .31138 .25701 .29625 .45722 Mtetra
.536 .298 .501 r
.29625 .45722 .31138 .25701 .29923 .45769 .2973 .46759 Mtetra
.616 .323 .45 r
.2973 .46759 .29923 .45769 .30017 .46992 .29887 .47067 Mtetra
.616 .117 .044 r
.29887 .47067 .30017 .46992 .3018 .47219 .30058 .47176 Mtetra
.459 .833 .99 r
.30058 .47176 .3018 .47219 .3036 .47196 .30239 .47141 Mtetra
.714 .892 .961 r
.30239 .47141 .3036 .47196 .30545 .4711 .30424 .47047 Mtetra
.823 .878 .885 r
.30424 .47047 .30545 .4711 .30731 .47007 .30614 .46893 Mtetra
.856 .785 .781 r
.30614 .46893 .30731 .47007 .30914 .46937 .30808 .46656 Mtetra
.822 .652 .672 r
.30808 .46656 .30914 .46937 .31101 .46815 .31013 .46268 Mtetra
.867 .629 .576 r
.31013 .46268 .31101 .46815 .31299 .46537 .31273 .4502 Mtetra
.943 .672 .494 r
.31273 .4502 .31299 .46537 .31568 .45134 .32732 .25101 Mtetra
.525 .294 .507 r
.32732 .25101 .31568 .45134 .33023 .2498 .32926 .24686 Mtetra
.744 .601 .697 r
.32926 .24686 .33023 .2498 .33214 .2462 .33108 .2447 Mtetra
.701 .7 .846 r
.33108 .2447 .33214 .2462 .33388 .24519 .33281 .24381 Mtetra
.632 .695 .89 r
.33281 .24381 .33388 .24519 .33559 .24473 .33453 .2433 Mtetra
.594 .67 .892 r
.33453 .2433 .33559 .24473 .33729 .24446 .33623 .24294 Mtetra
.62 .668 .875 r
.33623 .24294 .33729 .24446 .33901 .24388 .33794 .24248 Mtetra
.621 .688 .891 r
.33794 .24248 .33901 .24388 .34073 .2433 .33966 .24201 Mtetra
.657 .72 .895 r
.33966 .24201 .34073 .2433 .34245 .24268 .34138 .2414 Mtetra
.724 .741 .865 r
.34138 .2414 .34245 .24268 .34418 .24193 .34313 .24041 Mtetra
.686 .693 .851 r
.34313 .24041 .34418 .24193 .34591 .24123 .34486 .2396 Mtetra
.573 .632 .872 r
.34486 .2396 .34591 .24123 .34764 .24067 .34657 .23934 Mtetra
0 .222 .735 r
.34657 .23934 .34764 .24067 .34934 .24043 .34819 .24057 Mtetra
.818 .362 .146 r
.34819 .24057 .34934 .24043 .35105 .24028 .34974 .24321 Mtetra
.798 .451 .401 r
.34974 .24321 .35105 .24028 .35276 .23994 .35114 .24834 Mtetra
.437 .158 .39 r
.35114 .24834 .35276 .23994 .35452 .23886 .35291 .24728 Mtetra
.412 .137 .383 r
.35291 .24728 .35452 .23886 .35626 .23816 .35469 .24584 Mtetra
.654 .349 .443 r
.35469 .24584 .35626 .23816 .35793 .23865 .3562 .24945 Mtetra
.948 .668 .474 r
.3562 .24945 .35793 .23865 .35916 .24734 .34707 .44883 Mtetra
.523 .287 .498 r
.34707 .44883 .35916 .24734 .34994 .45185 .34868 .45284 Mtetra
.676 .21 .138 r
.34868 .45284 .34994 .45185 .3516 .45511 .35042 .45438 Mtetra
.5 .795 .998 r
.35042 .45438 .3516 .45511 .35343 .45501 .35227 .45409 Mtetra
.668 .812 .952 r
.35227 .45409 .35343 .45501 .3553 .45425 .35414 .45337 Mtetra
.699 .828 .944 r
.35414 .45337 .3553 .45425 .35718 .45324 .35601 .45252 Mtetra
.543 .815 .996 r
.35601 .45252 .35718 .45324 .35905 .45267 .35787 .45212 Mtetra
.602 .87 .993 r
.35787 .45212 .35905 .45267 .36091 .45205 .35973 .45151 Mtetra
.747 .905 .948 r
.35973 .45151 .36091 .45205 .36279 .45128 .36163 .45041 Mtetra
.891 .824 .775 r
.36163 .45041 .36279 .45128 .36468 .45018 .3636 .44773 Mtetra
.848 .68 .673 r
.3636 .44773 .36468 .45018 .36658 .44899 .36564 .44361 Mtetra
.812 .592 .605 r
.36564 .44361 .36658 .44899 .36847 .44791 .36781 .43663 Mtetra
.542 .354 .575 r
.36781 .43663 .36847 .44791 .37032 .44779 .36967 .43617 Mtetra
.513 .33 .57 r
.36967 .43617 .37032 .44779 .37218 .44727 .3715 .43644 Mtetra
.625 .418 .582 r
.3715 .43644 .37218 .44727 .3741 .44567 .37347 .43357 Mtetra
.953 .676 .476 r
.37347 .43357 .3741 .44567 .37637 .43651 .3846 .23138 Mtetra
.527 .295 .507 r
.3846 .23138 .37637 .43651 .38753 .22948 .38656 .22623 Mtetra
.763 .6 .676 r
.38656 .22623 .38753 .22948 .38946 .22498 .38841 .22347 Mtetra
.711 .707 .844 r
.38841 .22347 .38946 .22498 .39124 .22384 .39019 .2225 Mtetra
.64 .709 .897 r
.39019 .2225 .39124 .22384 .39299 .22331 .39194 .22194 Mtetra
.583 .68 .907 r
.39194 .22194 .39299 .22331 .39473 .2231 .39368 .22162 Mtetra
.619 .676 .882 r
.39368 .22162 .39473 .2231 .39648 .22253 .39544 .22115 Mtetra
.614 .692 .899 r
.39544 .22115 .39648 .22253 .39824 .22197 .39719 .2207 Mtetra
.618 .715 .915 r
.39719 .2207 .39824 .22197 .4 .2214 .39894 .22024 Mtetra
.649 .746 .921 r
.39894 .22024 .4 .2214 .40176 .22079 .40071 .21965 Mtetra
.665 .755 .918 r
.40071 .21965 .40176 .22079 .40353 .22015 .40247 .21899 Mtetra
.68 .755 .909 r
.40247 .21899 .40353 .22015 .40529 .21949 .40424 .21826 Mtetra
.7 .75 .89 r
.40424 .21826 .40529 .21949 .40706 .21877 .40602 .21742 Mtetra
.699 .728 .873 r
.40602 .21742 .40706 .21877 .40883 .21804 .40779 .21656 Mtetra
.691 .705 .859 r
.40779 .21656 .40883 .21804 .4106 .21732 .40957 .21572 Mtetra
.668 .681 .853 r
.40957 .21572 .4106 .21732 .41238 .21663 .41134 .21499 Mtetra
.66 .672 .851 r
.41134 .21499 .41238 .21663 .41415 .21595 .41312 .2143 Mtetra
.655 .668 .85 r
.41312 .2143 .41415 .21595 .41592 .21528 .41489 .21363 Mtetra
.691 .683 .838 r
.41489 .21363 .41592 .21528 .4177 .21454 .41667 .21275 Mtetra
.659 .651 .831 r
.41667 .21275 .4177 .21454 .41947 .21385 .41845 .21203 Mtetra
.599 .621 .845 r
.41845 .21203 .41947 .21385 .42125 .21325 .42022 .21164 Mtetra
.087 .359 .827 r
.42022 .21164 .42125 .21325 .42301 .213 .42194 .21266 Mtetra
.775 .268 0 r
.42194 .21266 .42301 .213 .42477 .21286 .42362 .21495 Mtetra
.835 .471 .365 r
.42362 .21495 .42477 .21286 .42654 .21271 .4252 .22048 Mtetra
.649 .342 .437 r
.4252 .22048 .42654 .21271 .42832 .21212 .42685 .22404 Mtetra
.44 .178 .419 r
.42685 .22404 .42832 .21212 .4301 .21139 .42867 .22244 Mtetra
.338 .091 .385 r
.42867 .22244 .4301 .21139 .43189 .2106 .43055 .219 Mtetra
.323 .064 .356 r
.43055 .219 .43189 .2106 .43369 .20942 .43241 .21625 Mtetra
.41 .122 .361 r
.43241 .21625 .43369 .20942 .43548 .2086 .43421 .21506 Mtetra
.574 .262 .403 r
.43421 .21506 .43548 .2086 .43725 .20854 .43595 .21643 Mtetra
.958 .671 .447 r
.43595 .21643 .43725 .20854 .43888 .21347 .43192 .41862 Mtetra
.524 .288 .499 r
.43192 .41862 .43888 .21347 .43488 .42177 .43367 .42383 Mtetra
.689 .281 .266 r
.43367 .42383 .43488 .42177 .43665 .42652 .43552 .42593 Mtetra
.312 .734 .974 r
.43552 .42593 .43665 .42652 .43854 .42683 .43742 .42589 Mtetra
.644 .809 .962 r
.43742 .42589 .43854 .42683 .44046 .42618 .43934 .42524 Mtetra
.708 .825 .938 r
.43934 .42524 .44046 .42618 .4424 .42513 .44128 .42432 Mtetra
.569 .812 .99 r
.44128 .42432 .4424 .42513 .44432 .4245 .4432 .42387 Mtetra
.579 .852 .996 r
.4432 .42387 .44432 .4245 .44625 .42389 .44512 .42332 Mtetra
.688 .898 .972 r
.44512 .42332 .44625 .42389 .44818 .42316 .44706 .42242 Mtetra
.862 .871 .844 r
.44706 .42242 .44818 .42316 .45011 .42252 .44902 .42044 Mtetra
.845 .705 .708 r
.44902 .42044 .45011 .42252 .45205 .42152 .45101 .41717 Mtetra
.841 .623 .608 r
.45101 .41717 .45205 .42152 .454 .41973 .45308 .41035 Mtetra
.962 .679 .451 r
.45308 .41035 .454 .41973 .45606 .41302 .45945 .20428 Mtetra
.528 .296 .507 r
.45945 .20428 .45606 .41302 .46232 .20319 .46136 .19868 Mtetra
.723 .542 .646 r
.46136 .19868 .46232 .20319 .46422 .19765 .46321 .19585 Mtetra
.731 .683 .804 r
.46321 .19585 .46422 .19765 .46605 .19602 .46503 .1946 Mtetra
.658 .707 .884 r
.46503 .1946 .46605 .19602 .46786 .19536 .46683 .19394 Mtetra
.597 .683 .902 r
.46683 .19394 .46786 .19536 .46966 .19508 .46864 .19355 Mtetra
.614 .672 .882 r
.46864 .19355 .46966 .19508 .47146 .19457 .47044 .19309 Mtetra
.622 .684 .887 r
.47044 .19309 .47146 .19457 .47327 .19397 .47225 .1926 Mtetra
.631 .706 .9 r
.47225 .1926 .47327 .19397 .47508 .19335 .47406 .19206 Mtetra
.715 .75 .88 r
.47406 .19206 .47508 .19335 .4769 .1926 .47588 .19112 Mtetra
.707 .716 .856 r
.47588 .19112 .4769 .1926 .47871 .19184 .4777 .19017 Mtetra
.652 .668 .853 r
.4777 .19017 .47871 .19184 .48053 .19114 .47952 .1895 Mtetra
.308 .494 .878 r
.47952 .1895 .48053 .19114 .48234 .19075 .48131 .19007 Mtetra
.61 .07 0 r
.48131 .19007 .48234 .19075 .48415 .19052 .4831 .19186 Mtetra
.814 .407 .277 r
.4831 .19186 .48415 .19052 .48597 .19031 .48486 .19564 Mtetra
.566 .24 .376 r
.48486 .19564 .48597 .19031 .48779 .18936 .48666 .19677 Mtetra
.387 .109 .365 r
.48666 .19677 .48779 .18936 .48962 .18839 .4885 .19509 Mtetra
.443 .149 .369 r
.4885 .19509 .48962 .18839 .49144 .18802 .49033 .19434 Mtetra
.964 .671 .426 r
.49033 .19434 .49144 .18802 .49322 .191 .48998 .39457 Mtetra
.53 .293 .499 r
.48998 .39457 .49322 .191 .49298 .399 .49184 .40298 Mtetra
.669 .31 .357 r
.49184 .40298 .49298 .399 .49487 .40604 .49377 .40561 Mtetra
.142 .653 .898 r
.49377 .40561 .49487 .40604 .49682 .40689 .49573 .40573 Mtetra
.697 .788 .92 r
.49573 .40573 .49682 .40689 .49878 .40621 .49769 .40484 Mtetra
.748 .765 .866 r
.49769 .40484 .49878 .40621 .50075 .40503 .49966 .4036 Mtetra
.698 .74 .884 r
.49966 .4036 .50075 .40503 .50272 .40412 .50163 .40267 Mtetra
.654 .722 .898 r
.50163 .40267 .50272 .40412 .50468 .40341 .5036 .40198 Mtetra
.643 .72 .904 r
.5036 .40198 .50468 .40341 .50665 .40273 .50557 .40135 Mtetra
.51 .671 .936 r
.50557 .40135 .50665 .40273 .50862 .40255 .50754 .40122 Mtetra
.545 .698 .939 r
.50754 .40122 .50862 .40255 .51059 .40227 .50951 .40097 Mtetra
.719 .769 .892 r
.50951 .40097 .51059 .40227 .51256 .40125 .51148 .39994 Mtetra
.933 .774 .661 r
.51148 .39994 .51256 .40125 .51455 .39664 .51347 .39505 Mtetra
.974 .687 .42 r
.51347 .39505 .51455 .39664 .51707 .18545 .51607 .1831 Mtetra
.916 .701 .597 r
.51607 .1831 .51707 .18545 .51893 .17766 .51793 .17597 Mtetra
.816 .727 .766 r
.51793 .17597 .51893 .17766 .52078 .1755 .51978 .17386 Mtetra
.66 .679 .857 r
.51978 .17386 .52078 .1755 .52262 .1748 .52162 .17315 Mtetra
.569 .636 .878 r
.52162 .17315 .52262 .1748 .52446 .17456 .52346 .17288 Mtetra
.606 .649 .867 r
.52346 .17288 .52446 .17456 .52631 .17416 .52531 .17244 Mtetra
.641 .661 .853 r
.52531 .17244 .52631 .17416 .52816 .17356 .52716 .17182 Mtetra
.642 .658 .85 r
.52716 .17182 .52816 .17356 .53001 .17296 .52901 .1712 Mtetra
.669 .667 .839 r
.52901 .1712 .53001 .17296 .53186 .17228 .53086 .17041 Mtetra
.666 .652 .827 r
.53086 .17041 .53186 .17228 .53371 .17157 .53271 .16962 Mtetra
.62 .621 .829 r
.53271 .16962 .53371 .17157 .53556 .17093 .53456 .16908 Mtetra
.377 .503 .859 r
.53456 .16908 .53556 .17093 .53741 .17056 .53642 .16955 Mtetra
0 .005 .508 r
.53642 .16955 .53741 .17056 .53927 .17041 .53829 .17141 Mtetra
.84 .423 .245 r
.53829 .17141 .53927 .17041 .54113 .17028 .54017 .17566 Mtetra
.796 .459 .416 r
.54017 .17566 .54113 .17028 .54299 .16987 .54208 .18366 Mtetra
.549 .274 .45 r
.54208 .18366 .54299 .16987 .54485 .16915 .54397 .18522 Mtetra
.317 .095 .41 r
.54397 .18522 .54485 .16915 .54671 .16833 .5458 .17927 Mtetra
.397 .141 .405 r
.5458 .17927 .54671 .16833 .54857 .16755 .54766 .17682 Mtetra
.454 .179 .405 r
.54766 .17682 .54857 .16755 .55044 .16681 .54953 .17586 Mtetra
.454 .177 .403 r
.54953 .17586 .55044 .16681 .5523 .16608 .5514 .17492 Mtetra
.456 .178 .401 r
.5514 .17492 .5523 .16608 .55416 .16536 .55327 .17406 Mtetra
.46 .179 .4 r
.55327 .17406 .55416 .16536 .55603 .16464 .55514 .17328 Mtetra
.462 .181 .4 r
.55514 .17328 .55603 .16464 .5579 .16393 .55702 .17254 Mtetra
.465 .183 .401 r
.55702 .17254 .5579 .16393 .55977 .16323 .5589 .17187 Mtetra
.468 .186 .402 r
.5589 .17187 .55977 .16323 .56164 .16253 .56077 .17125 Mtetra
.469 .187 .403 r
.56077 .17125 .56164 .16253 .56351 .16183 .56265 .17064 Mtetra
.469 .188 .404 r
.56265 .17064 .56351 .16183 .56538 .16113 .56454 .17003 Mtetra
.468 .188 .404 r
.56454 .17003 .56538 .16113 .56726 .16044 .56642 .16939 Mtetra
.468 .188 .405 r
.56642 .16939 .56726 .16044 .56913 .15974 .5683 .16875 Mtetra
.468 .189 .405 r
.5683 .16875 .56913 .15974 .57101 .15905 .57019 .1681 Mtetra
.468 .189 .406 r
.57019 .1681 .57101 .15905 .57289 .15835 .57207 .16744 Mtetra
.57207 .16744 .57289 .15835 .57477 .15765 .57396 .16678 Mtetra
.468 .189 .407 r
.57396 .16678 .57477 .15765 .57665 .15696 .57585 .16612 Mtetra
.57585 .16612 .57665 .15696 .57853 .15626 .57774 .16545 Mtetra
.468 .19 .407 r
.57774 .16545 .57853 .15626 .58042 .15556 .57963 .16477 Mtetra
.57963 .16477 .58042 .15556 .5823 .15486 .58153 .1641 Mtetra
.58153 .1641 .5823 .15486 .58419 .15417 .58342 .16342 Mtetra
.468 .19 .408 r
.58342 .16342 .58419 .15417 .58607 .15347 .58531 .16274 Mtetra
.58531 .16274 .58607 .15347 .58796 .15277 .58721 .16205 Mtetra
.469 .19 .408 r
.58721 .16205 .58796 .15277 .58985 .15207 .58911 .16137 Mtetra
.58911 .16137 .58985 .15207 .59174 .15137 .59101 .16069 Mtetra
.469 .191 .408 r
.59101 .16069 .59174 .15137 .59364 .15067 .59291 .16 Mtetra
.59291 .16 .59364 .15067 .59553 .14997 .59481 .15932 Mtetra
.469 .191 .409 r
.59481 .15932 .59553 .14997 .59743 .14927 .59671 .15864 Mtetra
.59671 .15864 .59743 .14927 .59932 .14857 .59862 .15796 Mtetra
.47 .192 .409 r
.59862 .15796 .59932 .14857 .60122 .14787 .60052 .15728 Mtetra
.60052 .15728 .60122 .14787 .60312 .14717 .60243 .15661 Mtetra
.47 .192 .41 r
.60243 .15661 .60312 .14717 .60502 .14647 .60434 .15594 Mtetra
.471 .193 .41 r
.60434 .15594 .60502 .14647 .60692 .14577 .60625 .15528 Mtetra
.60625 .15528 .60692 .14577 .60882 .14507 .60816 .15461 Mtetra
.471 .194 .411 r
.60816 .15461 .60882 .14507 .61073 .14438 .61008 .15395 Mtetra
.61008 .15395 .61073 .14438 .61263 .14368 .61199 .15329 Mtetra
.61199 .15329 .61263 .14368 .61454 .14298 .61391 .15262 Mtetra
.471 .194 .412 r
.61391 .15262 .61454 .14298 .61645 .14228 .61582 .15194 Mtetra
.47 .193 .412 r
.61582 .15194 .61645 .14228 .61836 .14158 .61774 .15124 Mtetra
.468 .192 .411 r
.61774 .15124 .61836 .14158 .62027 .14087 .61966 .15049 Mtetra
.463 .188 .41 r
.61966 .15049 .62027 .14087 .62218 .14014 .62157 .14965 Mtetra
.458 .183 .408 r
.62157 .14965 .62218 .14014 .62409 .1394 .62349 .14869 Mtetra
.456 .181 .406 r
.62349 .14869 .62409 .1394 .62601 .13866 .6254 .14774 Mtetra
.408 .141 .394 r
.6254 .14774 .62601 .13866 .62791 .13772 .62729 .14587 Mtetra
.359 .096 .373 r
.62729 .14587 .62791 .13772 .62981 .13657 .62915 .14345 Mtetra
.466 .17 .378 r
.62915 .14345 .62981 .13657 .63174 .13596 .63108 .14298 Mtetra
.97 .661 .371 r
.63108 .14298 .63174 .13596 .63373 .13714 .64004 .33505 Mtetra
.545 .303 .499 r
.64004 .33505 .63373 .13714 .64314 .33653 .64274 .35176 Mtetra
.586 .302 .453 r
.64274 .35176 .64314 .33653 .64592 .35482 .64496 .35514 Mtetra
.531 0 0 r
.64496 .35514 .64592 .35482 .64811 .35719 .6471 .35624 Mtetra
.571 .796 .984 r
.6471 .35624 .64811 .35719 .65019 .35684 .64919 .35577 Mtetra
.69 .818 .943 r
.64919 .35577 .65019 .35684 .65226 .35586 .65125 .35487 Mtetra
.724 .844 .938 r
.65125 .35487 .65226 .35586 .65431 .35472 .65332 .35382 Mtetra
.699 .854 .957 r
.65332 .35382 .65431 .35472 .65639 .3539 .65539 .35287 Mtetra
.698 .827 .944 r
.65539 .35287 .65639 .3539 .65846 .35309 .65746 .35193 Mtetra
.667 .791 .941 r
.65746 .35193 .65846 .35309 .66054 .35234 .65953 .35114 Mtetra
.599 .758 .954 r
.65953 .35114 .66054 .35234 .66262 .35169 .66163 .35064 Mtetra
.574 .776 .974 r
.66163 .35064 .66262 .35169 .66471 .35108 .66372 .35018 Mtetra
.513 .784 .994 r
.66372 .35018 .66471 .35108 .66681 .35062 .66582 .34985 Mtetra
.41 .758 .995 r
.66582 .34985 .66681 .35062 .66892 .35046 .66794 .34971 Mtetra
.617 .86 .989 r
.66794 .34971 .66892 .35046 .67101 .34976 .67003 .34901 Mtetra
.884 .905 .838 r
.67003 .34901 .67101 .34976 .67303 .34756 .67205 .34681 Mtetra
.991 .778 .521 r
.67205 .34681 .67303 .34756 .6747 .33811 .67374 .33761 Mtetra
.978 .677 .352 r
.67374 .33761 .6747 .33811 .66661 .12554 .66566 .12398 Mtetra
.929 .768 .66 r
.66566 .12398 .66661 .12554 .66838 .12123 .66743 .11963 Mtetra
.698 .712 .859 r
.66743 .11963 .66838 .12123 .6703 .12018 .66936 .11867 Mtetra
.562 .664 .906 r
.66936 .11867 .6703 .12018 .67227 .11979 .67133 .1184 Mtetra
.499 .653 .928 r
.67133 .1184 .67227 .11979 .67424 .1196 .67331 .11832 Mtetra
.649 .747 .921 r
.67331 .11832 .67424 .1196 .67619 .11894 .67526 .11767 Mtetra
.665 .754 .917 r
.67526 .11767 .67619 .11894 .67814 .11826 .67721 .11694 Mtetra
.705 .762 .896 r
.67721 .11694 .67814 .11826 .68009 .11741 .67915 .11601 Mtetra
.773 .769 .849 r
.67915 .11601 .68009 .11741 .68201 .11615 .68107 .1146 Mtetra
.696 .719 .867 r
.68107 .1146 .68201 .11615 .68396 .11533 .68301 .11366 Mtetra
.421 .562 .89 r
.68301 .11366 .68396 .11533 .68597 .11569 .68502 .11394 Mtetra
.811 .426 0 r
.68502 .11394 .68597 .11569 .68834 .12228 .68738 .12041 Mtetra
.974 .664 .32 r
.68738 .12041 .68834 .12228 .70228 .33478 .70131 .33381 Mtetra
.733 .262 0 r
.70131 .33381 .70228 .33478 .70464 .33853 .70368 .33762 Mtetra
.435 .743 .992 r
.70368 .33762 .70464 .33853 .70679 .33837 .70583 .33749 Mtetra
.72 .871 .952 r
.70583 .33749 .70679 .33837 .70889 .33742 .70792 .33642 Mtetra
.836 .869 .868 r
.70792 .33642 .70889 .33742 .71098 .33614 .70998 .33461 Mtetra
.852 .788 .788 r
.70998 .33461 .71098 .33614 .7131 .33545 .712 .33223 Mtetra
.82 .647 .667 r
.712 .33223 .7131 .33545 .71519 .3343 .71394 .32847 Mtetra
.856 .608 .563 r
.71394 .32847 .71519 .3343 .71722 .33197 .71554 .31922 Mtetra
.972 .663 .359 r
.71554 .31922 .71722 .33197 .71879 .32229 .70501 .11233 Mtetra
.525 .293 .506 r
.70501 .11233 .71879 .32229 .70777 .11089 .70673 .10757 Mtetra
.755 .6 .684 r
.70673 .10757 .70777 .11089 .70951 .10638 .70859 .10504 Mtetra
.716 .764 .891 r
.70859 .10504 .70951 .10638 .71145 .10519 .71055 .10404 Mtetra
.638 .77 .943 r
.71055 .10404 .71145 .10519 .71343 .10461 .71253 .10341 Mtetra
.615 .751 .942 r
.71253 .10341 .71343 .10461 .71543 .10427 .71452 .10288 Mtetra
.739 .763 .872 r
.71452 .10288 .71543 .10427 .7174 .10339 .71647 .10171 Mtetra
.697 .704 .853 r
.71647 .10171 .7174 .10339 .71937 .10254 .71843 .10074 Mtetra
.622 .652 .858 r
.71843 .10074 .71937 .10254 .72135 .10178 .72042 .10018 Mtetra
.292 .495 .884 r
.72042 .10018 .72135 .10178 .72333 .101 .7225 .10084 Mtetra
.635 .076 0 r
.7225 .10084 .72333 .101 .72533 .10063 .72467 .1028 Mtetra
.863 .464 .28 r
.72467 .1028 .72533 .10063 .72741 .10117 .72719 .1099 Mtetra
.969 .65 .329 r
.72719 .1099 .72741 .10117 .72992 .10804 .74364 .31649 Mtetra
.521 .285 .497 r
.74364 .31649 .72992 .10804 .7469 .31929 .7461 .32043 Mtetra
.621 .117 .032 r
.7461 .32043 .7469 .31929 .74937 .3232 .74841 .32194 Mtetra
.409 .654 .959 r
.74841 .32194 .74937 .3232 .75157 .32325 .75062 .32205 Mtetra
.602 .767 .958 r
.75062 .32205 .75157 .32325 .75372 .32252 .75278 .32151 Mtetra
.737 .854 .935 r
.75278 .32151 .75372 .32252 .75584 .32135 .7549 .32035 Mtetra
.879 .878 .829 r
.7549 .32035 .75584 .32135 .758 .32068 .75695 .3181 Mtetra
.85 .694 .688 r
.75695 .3181 .758 .32068 .76012 .31956 .75889 .31449 Mtetra
.859 .619 .575 r
.75889 .31449 .76012 .31956 .76218 .31755 .7605 .30658 Mtetra
.521 .291 .506 r
.1055 .33058 .07992 .53336 .1078 .33442 .10732 .32815 Mtetra
.619 .443 .621 r
.10732 .32815 .1078 .33442 .10996 .32949 .10901 .32675 Mtetra
.657 .557 .73 r
.10901 .32675 .10996 .32949 .11179 .32696 .11064 .32583 Mtetra
.689 .739 .889 r
.11064 .32583 .11179 .32696 .11342 .32604 .11223 .32512 Mtetra
.656 .775 .937 r
.11223 .32512 .11342 .32604 .11499 .32552 .11381 .32457 Mtetra
.641 .763 .937 r
.11381 .32457 .11499 .32552 .11654 .32517 .11538 .32406 Mtetra
.752 .753 .853 r
.11538 .32406 .11654 .32517 .11818 .32418 .11703 .32297 Mtetra
.708 .729 .867 r
.11703 .32297 .11818 .32418 .11979 .32334 .11865 .32214 Mtetra
.58 .695 .92 r
.11865 .32214 .11979 .32334 .12137 .32283 .12019 .32185 Mtetra
.836 .369 0 r
.12019 .32185 .12137 .32283 .1228 .32344 .12141 .32415 Mtetra
.915 .623 .477 r
.12141 .32415 .1228 .32344 .12409 .32524 .1212 .33769 Mtetra
.922 .663 .529 r
.1212 .33769 .12409 .32524 .12488 .33089 .09795 .53235 Mtetra
.518 .283 .498 r
.09795 .53235 .12488 .33089 .10126 .52986 .09933 .53419 Mtetra
.531 .197 .346 r
.09933 .53419 .10126 .52986 .10234 .53411 .10089 .5347 Mtetra
.183 0 0 r
.10089 .5347 .10234 .53411 .10376 .53575 .10252 .5346 Mtetra
.628 .736 .925 r
.10252 .5346 .10376 .53575 .10541 .53552 .1042 .53411 Mtetra
.672 .704 .871 r
.1042 .53411 .10541 .53552 .10713 .53473 .10592 .53341 Mtetra
.69 .723 .876 r
.10592 .53341 .10713 .53473 .10889 .5337 .10764 .53263 Mtetra
.486 .701 .964 r
.10764 .53263 .10889 .5337 .11054 .53345 .10928 .53253 Mtetra
.551 .758 .974 r
.10928 .53253 .11054 .53345 .11221 .53315 .11094 .53224 Mtetra
.717 .799 .915 r
.11094 .53224 .11221 .53315 .11392 .53251 .11268 .53136 Mtetra
.88 .75 .714 r
.11268 .53136 .11392 .53251 .11577 .53066 .11475 .52779 Mtetra
.895 .674 .595 r
.11475 .52779 .11577 .53066 .11779 .52749 .11788 .51551 Mtetra
.928 .673 .532 r
.11788 .51551 .11779 .52749 .12026 .52054 .14364 .31681 Mtetra
.523 .292 .506 r
.14364 .31681 .12026 .52054 .14606 .32008 .14553 .31385 Mtetra
.628 .449 .622 r
.14553 .31385 .14606 .32008 .14821 .31493 .14725 .31228 Mtetra
.669 .57 .735 r
.14725 .31228 .14821 .31493 .15006 .31232 .1489 .31127 Mtetra
.675 .754 .91 r
.1489 .31127 .15006 .31232 .15171 .31135 .15051 .31062 Mtetra
.603 .805 .977 r
.15051 .31062 .15171 .31135 .15328 .31098 .1521 .31019 Mtetra
.57 .782 .979 r
.1521 .31019 .15328 .31098 .15484 .31085 .15368 .30985 Mtetra
.648 .758 .93 r
.15368 .30985 .15484 .31085 .15643 .31039 .15528 .30931 Mtetra
.671 .747 .908 r
.15528 .30931 .15643 .31039 .15803 .3098 .15689 .30868 Mtetra
.68 .743 .898 r
.15689 .30868 .15803 .3098 .15965 .30915 .15851 .30801 Mtetra
.759 .754 .848 r
.15851 .30801 .15965 .30915 .16133 .30795 .16019 .30684 Mtetra
.731 .756 .873 r
.16019 .30684 .16133 .30795 .16299 .30696 .16184 .30589 Mtetra
.576 .723 .943 r
.16184 .30589 .16299 .30696 .16457 .30664 .16342 .3056 Mtetra
.886 .455 .103 r
.16342 .3056 .16457 .30664 .16576 .30975 .16461 .30862 Mtetra
.944 .684 .513 r
.16461 .30862 .16576 .30975 .14391 .51464 .14275 .51298 Mtetra
.956 .622 .336 r
.14275 .51298 .14391 .51464 .14476 .52168 .14356 .52034 Mtetra
.048 .405 .858 r
.14356 .52034 .14476 .52168 .14634 .52236 .14513 .5211 Mtetra
.66 .728 .9 r
.14513 .5211 .14634 .52236 .14808 .52165 .14686 .52047 Mtetra
.745 .761 .865 r
.14686 .52047 .14808 .52165 .14987 .52044 .14864 .51936 Mtetra
.534 .72 .959 r
.14864 .51936 .14987 .52044 .15156 .52023 .15033 .51914 Mtetra
.531 .719 .959 r
.15033 .51914 .15156 .52023 .15324 .52005 .15201 .51893 Mtetra
.714 .766 .893 r
.15201 .51893 .15324 .52005 .155 .51918 .15377 .51804 Mtetra
.896 .749 .691 r
.15377 .51804 .155 .51918 .15715 .51481 .15591 .51375 Mtetra
.944 .688 .519 r
.15591 .51375 .15715 .51481 .18142 .30872 .1802 .30828 Mtetra
.943 .746 .606 r
.1802 .30828 .18142 .30872 .18389 .30033 .18273 .29948 Mtetra
.848 .799 .803 r
.18273 .29948 .18389 .30033 .18566 .29844 .1845 .29751 Mtetra
.655 .778 .939 r
.1845 .29751 .18566 .29844 .18727 .29794 .18613 .29694 Mtetra
.493 .707 .965 r
.18613 .29694 .18727 .29794 .18884 .29792 .1877 .29683 Mtetra
.685 .752 .902 r
.1877 .29683 .18884 .29792 .19046 .29738 .18934 .29613 Mtetra
.702 .728 .87 r
.18934 .29613 .19046 .29738 .19211 .29664 .19099 .29531 Mtetra
.607 .684 .897 r
.19099 .29531 .19211 .29664 .19372 .29614 .1926 .29493 Mtetra
0 .009 .523 r
.1926 .29493 .19372 .29614 .19527 .2964 .19402 .29637 Mtetra
.91 .563 .37 r
.19402 .29637 .19527 .2964 .19671 .29761 .19496 .30233 Mtetra
.94 .676 .51 r
.19496 .30233 .19671 .29761 .19796 .30065 .1753 .50438 Mtetra
.521 .285 .498 r
.1753 .50438 .19796 .30065 .179 .49783 .17666 .50741 Mtetra
.527 .243 .426 r
.17666 .50741 .179 .49783 .17982 .50603 .17828 .50798 Mtetra
.383 0 .097 r
.17828 .50798 .17982 .50603 .18126 .50838 .17998 .50783 Mtetra
.614 .86 .99 r
.17998 .50783 .18126 .50838 .18292 .50862 .18173 .50725 Mtetra
.695 .724 .872 r
.18173 .50725 .18292 .50862 .18468 .50787 .1835 .50642 Mtetra
.713 .714 .85 r
.1835 .50642 .18468 .50787 .18649 .50676 .18529 .50543 Mtetra
.693 .729 .878 r
.18529 .50543 .18649 .50676 .18827 .50584 .18706 .50461 Mtetra
.661 .737 .906 r
.18706 .50461 .18827 .50584 .19003 .50514 .18882 .50397 Mtetra
.638 .74 .922 r
.18882 .50397 .19003 .50514 .19178 .50453 .19057 .50342 Mtetra
.599 .741 .944 r
.19057 .50342 .19178 .50453 .19352 .50405 .1923 .50301 Mtetra
.564 .743 .96 r
.1923 .50301 .19352 .50405 .19525 .50369 .19403 .5027 Mtetra
.545 .746 .969 r
.19403 .5027 .19525 .50369 .19698 .50339 .19575 .50242 Mtetra
.383 .68 .976 r
.19575 .50242 .19698 .50339 .19868 .50338 .19744 .50248 Mtetra
.409 .709 .984 r
.19744 .50248 .19868 .50338 .20038 .50336 .19914 .50247 Mtetra
.647 .8 .956 r
.19914 .50247 .20038 .50336 .20212 .50295 .20091 .50187 Mtetra
.865 .777 .762 r
.20091 .50187 .20212 .50295 .20396 .50152 .20287 .49922 Mtetra
.895 .689 .617 r
.20287 .49922 .20396 .50152 .20593 .49871 .20535 .49115 Mtetra
.942 .681 .513 r
.20535 .49115 .20593 .49871 .20817 .49312 .22661 .28725 Mtetra
.525 .294 .506 r
.22661 .28725 .20817 .49312 .22905 .29129 .22859 .28318 Mtetra
.614 .422 .599 r
.22859 .28318 .22905 .29129 .23127 .28472 .23036 .28141 Mtetra
.659 .535 .701 r
.23036 .28141 .23127 .28472 .23315 .28171 .23206 .28026 Mtetra
.684 .695 .854 r
.23206 .28026 .23315 .28171 .23488 .28032 .23374 .2795 Mtetra
.634 .801 .962 r
.23374 .2795 .23488 .28032 .23653 .2798 .23539 .27897 Mtetra
.597 .788 .972 r
.23539 .27897 .23653 .2798 .23816 .27955 .23703 .27855 Mtetra
.704 .778 .909 r
.23703 .27855 .23816 .27955 .23982 .27895 .2387 .27776 Mtetra
.728 .749 .869 r
.2387 .27776 .23982 .27895 .2415 .27804 .2404 .27679 Mtetra
.648 .718 .899 r
.2404 .27679 .2415 .27804 .24317 .27736 .24205 .27624 Mtetra
0 .276 .759 r
.24205 .27624 .24317 .27736 .24477 .27745 .24357 .2772 Mtetra
.907 .531 .303 r
.24357 .2772 .24477 .27745 .24627 .27867 .24475 .28204 Mtetra
.946 .679 .497 r
.24475 .28204 .24627 .27867 .24759 .28196 .22804 .48625 Mtetra
.523 .287 .499 r
.22804 .48625 .24759 .28196 .23144 .48197 .22939 .49042 Mtetra
.544 .251 .42 r
.22939 .49042 .23144 .48197 .23249 .48963 .23104 .49131 Mtetra
.437 0 .091 r
.23104 .49131 .23249 .48963 .234 .49204 .23275 .49144 Mtetra
.48 .807 1 r
.23275 .49144 .234 .49204 .23568 .49262 .23451 .49115 Mtetra
.632 .691 .887 r
.23451 .49115 .23568 .49262 .23745 .49217 .23629 .49062 Mtetra
.661 .69 .867 r
.23629 .49062 .23745 .49217 .23925 .49137 .23808 .48994 Mtetra
.614 .69 .898 r
.23808 .48994 .23925 .49137 .24104 .49072 .23985 .48949 Mtetra
.568 .709 .937 r
.23985 .48949 .24104 .49072 .24281 .49028 .24161 .48919 Mtetra
.682 .772 .919 r
.24161 .48919 .24281 .49028 .24461 .48957 .24342 .48844 Mtetra
.852 .779 .78 r
.24342 .48844 .24461 .48957 .24648 .48798 .24535 .48609 Mtetra
.901 .708 .632 r
.24535 .48609 .24648 .48798 .24848 .48494 .24765 .47942 Mtetra
.948 .684 .502 r
.24765 .47942 .24848 .48494 .25062 .4801 .26655 .27379 Mtetra
.526 .294 .507 r
.26655 .27379 .25062 .4801 .25279 .47488 .26855 .26937 Mtetra
.517 .287 .505 r
.26855 .26937 .25279 .47488 .25451 .47509 .27024 .26858 Mtetra
.516 .286 .504 r
.27024 .26858 .25451 .47509 .25626 .47496 .27189 .26835 Mtetra
.517 .287 .505 r
.27189 .26835 .25626 .47496 .27345 .2841 .2736 .26743 Mtetra
.568 .356 .553 r
.2736 .26743 .27345 .2841 .27626 .26961 .27538 .2656 Mtetra
.673 .521 .671 r
.27538 .2656 .27626 .26961 .27821 .26564 .27715 .264 Mtetra
.722 .685 .814 r
.27715 .264 .27821 .26564 .28 .26375 .27887 .26291 Mtetra
.644 .802 .959 r
.27887 .26291 .28 .26375 .28168 .26314 .28055 .26234 Mtetra
.591 .797 .978 r
.28055 .26234 .28168 .26314 .28334 .26287 .28223 .26192 Mtetra
.613 .768 .954 r
.28223 .26192 .28334 .26287 .28501 .26259 .2839 .26147 Mtetra
.657 .747 .916 r
.2839 .26147 .28501 .26259 .28669 .26203 .28559 .26086 Mtetra
.667 .742 .906 r
.28559 .26086 .28669 .26203 .28838 .2614 .28729 .26022 Mtetra
.681 .742 .897 r
.28729 .26022 .28838 .2614 .29008 .26069 .28898 .2595 Mtetra
.694 .746 .891 r
.28898 .2595 .29008 .26069 .29179 .25988 .29069 .25872 Mtetra
.695 .751 .895 r
.29069 .25872 .29179 .25988 .2935 .25907 .2924 .25795 Mtetra
.715 .762 .89 r
.2924 .25795 .2935 .25907 .29521 .25823 .29411 .25707 Mtetra
.725 .758 .879 r
.29411 .25707 .29521 .25823 .29692 .25739 .29583 .25612 Mtetra
.643 .716 .901 r
.29583 .25612 .29692 .25739 .29861 .2568 .29752 .25557 Mtetra
.104 .448 .882 r
.29752 .25557 .29861 .2568 .30026 .25691 .29913 .25624 Mtetra
.912 .513 .219 r
.29913 .25624 .30026 .25691 .3018 .25842 .30046 .26071 Mtetra
.953 .68 .481 r
.30046 .26071 .3018 .25842 .30322 .26171 .2873 .46579 Mtetra
.523 .287 .499 r
.2873 .46579 .30322 .26171 .30447 .26758 .28876 .47016 Mtetra
.513 .279 .496 r
.28876 .47016 .30447 .26758 .30623 .26611 .29055 .4699 Mtetra
.512 .278 .496 r
.29055 .4699 .30623 .26611 .30798 .26497 .29239 .46902 Mtetra
.513 .279 .496 r
.29239 .46902 .30798 .26497 .29625 .45722 .29419 .46868 Mtetra
.535 .256 .438 r
.29419 .46868 .29625 .45722 .2973 .46759 .29591 .46954 Mtetra
.533 .11 .184 r
.29591 .46954 .2973 .46759 .29887 .47067 .29766 .47013 Mtetra
.134 .63 .91 r
.29766 .47013 .29887 .47067 .30058 .47176 .29943 .47032 Mtetra
.573 .678 .911 r
.29943 .47032 .30058 .47176 .30239 .47141 .30124 .47002 Mtetra
.689 .728 .88 r
.30124 .47002 .30239 .47141 .30424 .47047 .30308 .46919 Mtetra
.82 .768 .804 r
.30308 .46919 .30424 .47047 .30614 .46893 .305 .46726 Mtetra
.896 .727 .664 r
.305 .46726 .30614 .46893 .30808 .46656 .30712 .46232 Mtetra
.955 .686 .486 r
.30712 .46232 .30808 .46656 .31013 .46268 .32237 .25751 Mtetra
.536 .302 .508 r
.32237 .25751 .31013 .46268 .31273 .4502 .32463 .24864 Mtetra
.521 .29 .506 r
.32463 .24864 .31273 .4502 .32732 .25101 .32646 .24627 Mtetra
.646 .486 .653 r
.32646 .24627 .32732 .25101 .32926 .24686 .32824 .24481 Mtetra
.691 .632 .786 r
.32824 .24481 .32926 .24686 .33108 .2447 .32998 .2438 Mtetra
.691 .804 .935 r
.32998 .2438 .33108 .2447 .33281 .24381 .33171 .24305 Mtetra
.636 .823 .972 r
.33171 .24305 .33281 .24381 .33453 .2433 .33342 .24247 Mtetra
.617 .803 .971 r
.33342 .24247 .33453 .2433 .33623 .24294 .33514 .24197 Mtetra
.639 .777 .947 r
.33514 .24197 .33623 .24294 .33794 .24248 .33686 .24142 Mtetra
.643 .76 .934 r
.33686 .24142 .33794 .24248 .33966 .24201 .33857 .24086 Mtetra
.679 .753 .907 r
.33857 .24086 .33966 .24201 .34138 .2414 .34031 .24015 Mtetra
.741 .753 .862 r
.34031 .24015 .34138 .2414 .34313 .24041 .34206 .23907 Mtetra
.682 .72 .878 r
.34206 .23907 .34313 .24041 .34486 .2396 .34379 .23832 Mtetra
.405 .613 .934 r
.34379 .23832 .34486 .2396 .34657 .23934 .34547 .23849 Mtetra
.872 .43 .064 r
.34547 .23849 .34657 .23934 .34819 .24057 .34697 .24193 Mtetra
.959 .681 .467 r
.34697 .24193 .34819 .24057 .34974 .24321 .33692 .44625 Mtetra
.528 .291 .499 r
.33692 .44625 .34974 .24321 .35114 .24834 .33833 .45322 Mtetra
.514 .279 .497 r
.33833 .45322 .35114 .24834 .35291 .24728 .34016 .4531 Mtetra
.512 .278 .496 r
.34016 .4531 .35291 .24728 .35469 .24584 .34203 .45218 Mtetra
.34203 .45218 .35469 .24584 .3562 .24945 .34389 .45141 Mtetra
.516 .281 .497 r
.34389 .45141 .3562 .24945 .34707 .44883 .34567 .45218 Mtetra
.535 .169 .292 r
.34567 .45218 .34707 .44883 .34868 .45284 .34746 .45279 Mtetra
.132 0 0 r
.34746 .45279 .34868 .45284 .35042 .45438 .34928 .45301 Mtetra
.608 .705 .913 r
.34928 .45301 .35042 .45438 .35227 .45409 .35113 .45256 Mtetra
.648 .694 .88 r
.35113 .45256 .35227 .45409 .35414 .45337 .353 .45192 Mtetra
.652 .71 .89 r
.353 .45192 .35414 .45337 .35601 .45252 .35487 .45127 Mtetra
.542 .702 .944 r
.35487 .45127 .35601 .45252 .35787 .45212 .35671 .45103 Mtetra
.639 .77 .943 r
.35671 .45103 .35787 .45212 .35973 .45151 .35858 .45044 Mtetra
.788 .805 .867 r
.35858 .45044 .35973 .45151 .36163 .45041 .36049 .44901 Mtetra
.912 .751 .668 r
.36049 .44901 .36163 .45041 .3636 .44773 .36257 .44418 Mtetra
.961 .687 .471 r
.36257 .44418 .3636 .44773 .36564 .44361 .37446 .23944 Mtetra
.538 .304 .508 r
.37446 .23944 .36564 .44361 .36781 .43663 .37667 .22954 Mtetra
.518 .288 .505 r
.37667 .22954 .36781 .43663 .36967 .43617 .37845 .22834 Mtetra
.516 .286 .505 r
.37845 .22834 .36967 .43617 .3715 .43644 .38019 .22794 Mtetra
.38019 .22794 .3715 .43644 .37347 .43357 .38193 .22761 Mtetra
.519 .289 .505 r
.38193 .22761 .37347 .43357 .3846 .23138 .38374 .22572 Mtetra
.643 .468 .632 r
.38374 .22572 .3846 .23138 .38656 .22623 .38555 .22397 Mtetra
.725 .634 .756 r
.38555 .22397 .38656 .22623 .38841 .22347 .38734 .22255 Mtetra
.692 .807 .936 r
.38734 .22255 .38841 .22347 .39019 .2225 .38911 .22177 Mtetra
.632 .835 .979 r
.38911 .22177 .39019 .2225 .39194 .22194 .39086 .22119 Mtetra
.599 .818 .984 r
.39086 .22119 .39194 .22194 .39368 .22162 .39261 .2207 Mtetra
.629 .791 .96 r
.39261 .2207 .39368 .22162 .39544 .22115 .39437 .22017 Mtetra
.63 .777 .951 r
.39437 .22017 .39544 .22115 .39719 .2207 .39613 .21963 Mtetra
.639 .761 .936 r
.39613 .21963 .39719 .2207 .39894 .22024 .39789 .21907 Mtetra
.659 .749 .917 r
.39789 .21907 .39894 .22024 .40071 .21965 .39965 .21844 Mtetra
.669 .744 .906 r
.39965 .21844 .40071 .21965 .40247 .21899 .40142 .21775 Mtetra
.679 .743 .899 r
.40142 .21775 .40247 .21899 .40424 .21826 .40319 .21702 Mtetra
.693 .747 .892 r
.40319 .21702 .40424 .21826 .40602 .21742 .40496 .21622 Mtetra
.697 .754 .896 r
.40496 .21622 .40602 .21742 .40779 .21656 .40674 .2154 Mtetra
.696 .761 .902 r
.40674 .2154 .40779 .21656 .40957 .21572 .40852 .21459 Mtetra
.682 .764 .913 r
.40852 .21459 .40957 .21572 .41134 .21499 .41029 .21385 Mtetra
.675 .76 .915 r
.41029 .21385 .41134 .21499 .41312 .2143 .41207 .21315 Mtetra
.669 .755 .915 r
.41207 .21315 .41312 .2143 .41489 .21363 .41384 .21246 Mtetra
.734 .771 .883 r
.41384 .21246 .41489 .21363 .41667 .21275 .41563 .21144 Mtetra
.679 .731 .889 r
.41563 .21144 .41667 .21275 .41845 .21203 .41741 .2107 Mtetra
.544 .672 .922 r
.41741 .2107 .41845 .21203 .42022 .21164 .41917 .2105 Mtetra
.722 .247 0 r
.41917 .2105 .42022 .21164 .42194 .21266 .42084 .2131 Mtetra
.966 .681 .442 r
.42084 .2131 .42194 .21266 .42362 .21495 .41599 .40918 Mtetra
.549 .308 .502 r
.41599 .40918 .42362 .21495 .4252 .22048 .41729 .42653 Mtetra
.515 .28 .497 r
.41729 .42653 .4252 .22048 .42685 .22404 .41916 .42712 Mtetra
.512 .278 .496 r
.41916 .42712 .42685 .22404 .42867 .22244 .42107 .42639 Mtetra
.511 .277 .496 r
.42107 .42639 .42867 .22244 .43055 .219 .423 .42506 Mtetra
.512 .278 .496 r
.423 .42506 .43055 .219 .43241 .21625 .42493 .42411 Mtetra
.42493 .42411 .43241 .21625 .43421 .21506 .42684 .42336 Mtetra
.513 .279 .496 r
.42684 .42336 .43421 .21506 .43595 .21643 .42875 .42297 Mtetra
.515 .281 .497 r
.42875 .42297 .43595 .21643 .43192 .41862 .43063 .42366 Mtetra
.535 .204 .353 r
.43063 .42366 .43192 .41862 .43367 .42383 .43251 .42432 Mtetra
.371 0 0 r
.43251 .42432 .43367 .42383 .43552 .42593 .4344 .42469 Mtetra
.574 .722 .943 r
.4344 .42469 .43552 .42593 .43742 .42589 .43632 .42433 Mtetra
.64 .694 .884 r
.43632 .42433 .43742 .42589 .43934 .42524 .43824 .42371 Mtetra
.663 .708 .881 r
.43824 .42371 .43934 .42524 .44128 .42432 .44017 .42298 Mtetra
.556 .696 .933 r
.44017 .42298 .44128 .42432 .4432 .42387 .44208 .4227 Mtetra
.608 .751 .946 r
.44208 .4227 .4432 .42387 .44512 .42332 .44401 .42221 Mtetra
.734 .8 .905 r
.44401 .42221 .44512 .42332 .44706 .42242 .44595 .42114 Mtetra
.904 .779 .713 r
.44595 .42114 .44706 .42242 .44902 .42044 .44795 .41751 Mtetra
.922 .688 .567 r
.44795 .41751 .44902 .42044 .45101 .41717 .45012 .40646 Mtetra
.961 .678 .453 r
.45012 .40646 .45101 .41717 .45308 .41035 .45667 .20081 Mtetra
.522 .291 .506 r
.45667 .20081 .45308 .41035 .45945 .20428 .45854 .19753 Mtetra
.625 .442 .615 r
.45854 .19753 .45945 .20428 .46136 .19868 .46036 .1958 Mtetra
.672 .569 .73 r
.46036 .1958 .46136 .19868 .46321 .19585 .46218 .19464 Mtetra
.701 .759 .897 r
.46218 .19464 .46321 .19585 .46503 .1946 .46399 .19378 Mtetra
.651 .827 .968 r
.46399 .19378 .46503 .1946 .46683 .19394 .4658 .19313 Mtetra
.612 .816 .979 r
.4658 .19313 .46683 .19394 .46864 .19355 .46761 .1926 Mtetra
.633 .791 .958 r
.46761 .1926 .46864 .19355 .47044 .19309 .46942 .19203 Mtetra
.643 .772 .942 r
.46942 .19203 .47044 .19309 .47225 .1926 .47123 .19144 Mtetra
.652 .755 .925 r
.47123 .19144 .47225 .1926 .47406 .19206 .47304 .19082 Mtetra
.737 .764 .875 r
.47304 .19082 .47406 .19206 .47588 .19112 .47486 .18974 Mtetra
.715 .737 .868 r
.47486 .18974 .47588 .19112 .4777 .19017 .47668 .18877 Mtetra
.62 .698 .9 r
.47668 .18877 .4777 .19017 .47952 .1895 .47849 .18828 Mtetra
0 .06 .587 r
.47849 .18828 .47952 .1895 .48131 .19007 .48028 .19001 Mtetra
.927 .555 .28 r
.48028 .19001 .48131 .19007 .4831 .19186 .48198 .19772 Mtetra
.964 .672 .428 r
.48198 .19772 .4831 .19186 .48486 .19564 .48099 .40375 Mtetra
.517 .282 .497 r
.48099 .40375 .48486 .19564 .48666 .19677 .48292 .40514 Mtetra
.512 .278 .496 r
.48292 .40514 .48666 .19677 .4885 .19509 .48488 .40432 Mtetra
.511 .277 .496 r
.48488 .40432 .4885 .19509 .49033 .19434 .48684 .40302 Mtetra
.514 .28 .497 r
.48684 .40302 .49033 .19434 .48998 .39457 .48879 .40331 Mtetra
.531 .236 .411 r
.48879 .40331 .48998 .39457 .49184 .40298 .49073 .40403 Mtetra
.446 0 0 r
.49073 .40403 .49184 .40298 .49377 .40561 .49268 .40442 Mtetra
.592 .744 .949 r
.49268 .40442 .49377 .40561 .49573 .40573 .49464 .40398 Mtetra
.68 .687 .849 r
.49464 .40398 .49573 .40573 .49769 .40484 .49661 .40309 Mtetra
.701 .695 .841 r
.49661 .40309 .49769 .40484 .49966 .4036 .49858 .40206 Mtetra
.674 .715 .879 r
.49858 .40206 .49966 .4036 .50163 .40267 .50055 .40125 Mtetra
.646 .724 .905 r
.50055 .40125 .50163 .40267 .5036 .40198 .50252 .4006 Mtetra
.636 .726 .913 r
.50252 .4006 .5036 .40198 .50557 .40135 .50449 .4 Mtetra
.5 .672 .941 r
.50449 .4 .50557 .40135 .50754 .40122 .50645 .3999 Mtetra
.541 .697 .94 r
.50645 .3999 .50754 .40122 .50951 .40097 .50843 .39965 Mtetra
.717 .766 .891 r
.50843 .39965 .50951 .40097 .51148 .39994 .5104 .39863 Mtetra
.933 .775 .661 r
.5104 .39863 .51148 .39994 .51347 .39505 .5124 .39374 Mtetra
.974 .687 .42 r
.5124 .39374 .51347 .39505 .51607 .1831 .51506 .1819 Mtetra
.957 .756 .59 r
.51506 .1819 .51607 .1831 .51793 .17597 .51693 .17478 Mtetra
.852 .796 .796 r
.51693 .17478 .51793 .17597 .51978 .17386 .51877 .17267 Mtetra
.672 .758 .915 r
.51877 .17267 .51978 .17386 .52162 .17315 .52062 .17194 Mtetra
.558 .71 .942 r
.52062 .17194 .52162 .17315 .52346 .17288 .52246 .17166 Mtetra
.606 .728 .931 r
.52246 .17166 .52346 .17288 .52531 .17244 .52431 .1712 Mtetra
.652 .743 .916 r
.52431 .1712 .52531 .17244 .52716 .17182 .52616 .17057 Mtetra
.652 .74 .914 r
.52616 .17057 .52716 .17182 .52901 .1712 .52801 .16993 Mtetra
.703 .756 .893 r
.52801 .16993 .52901 .1712 .53086 .17041 .52986 .16905 Mtetra
.696 .737 .882 r
.52986 .16905 .53086 .17041 .53271 .16962 .53171 .16818 Mtetra
.605 .688 .901 r
.53171 .16818 .53271 .16962 .53456 .16908 .53356 .16775 Mtetra
0 .243 .753 r
.53356 .16775 .53456 .16908 .53642 .16955 .53543 .16912 Mtetra
.919 .524 .195 r
.53543 .16912 .53642 .16955 .53829 .17141 .53731 .17573 Mtetra
.969 .672 .405 r
.53731 .17573 .53829 .17141 .54017 .17566 .54017 .38379 Mtetra
.519 .283 .497 r
.54017 .38379 .54017 .17566 .54208 .18366 .54218 .38624 Mtetra
.513 .279 .496 r
.54218 .38624 .54208 .18366 .54397 .18522 .54418 .3858 Mtetra
.512 .277 .496 r
.54418 .3858 .54397 .18522 .5458 .17927 .54618 .38461 Mtetra
.512 .278 .496 r
.54618 .38461 .5458 .17927 .54766 .17682 .54818 .38358 Mtetra
.513 .278 .496 r
.54818 .38358 .54766 .17682 .54953 .17586 .55018 .38287 Mtetra
.55018 .38287 .54953 .17586 .5514 .17492 .55218 .38216 Mtetra
.55218 .38216 .5514 .17492 .55327 .17406 .55419 .38147 Mtetra
.55419 .38147 .55327 .17406 .55514 .17328 .55619 .3808 Mtetra
.55619 .3808 .55514 .17328 .55702 .17254 .5582 .38014 Mtetra
.5582 .38014 .55702 .17254 .5589 .17187 .56021 .37949 Mtetra
.56021 .37949 .5589 .17187 .56077 .17125 .56222 .37885 Mtetra
.56222 .37885 .56077 .17125 .56265 .17064 .56423 .37822 Mtetra
.56423 .37822 .56265 .17064 .56454 .17003 .56625 .37758 Mtetra
.56625 .37758 .56454 .17003 .56642 .16939 .56826 .37694 Mtetra
.56826 .37694 .56642 .16939 .5683 .16875 .57028 .37629 Mtetra
.57028 .37629 .5683 .16875 .57019 .1681 .5723 .37563 Mtetra
.5723 .37563 .57019 .1681 .57207 .16744 .57432 .37498 Mtetra
.57432 .37498 .57207 .16744 .57396 .16678 .57634 .37432 Mtetra
.57634 .37432 .57396 .16678 .57585 .16612 .57836 .37366 Mtetra
.57836 .37366 .57585 .16612 .57774 .16545 .58039 .37299 Mtetra
.58039 .37299 .57774 .16545 .57963 .16477 .58241 .37233 Mtetra
.58241 .37233 .57963 .16477 .58153 .1641 .58444 .37166 Mtetra
.58444 .37166 .58153 .1641 .58342 .16342 .58647 .37099 Mtetra
.58647 .37099 .58342 .16342 .58531 .16274 .5885 .37032 Mtetra
.5885 .37032 .58531 .16274 .58721 .16205 .59053 .36965 Mtetra
.59053 .36965 .58721 .16205 .58911 .16137 .59256 .36898 Mtetra
.59256 .36898 .58911 .16137 .59101 .16069 .5946 .36831 Mtetra
.5946 .36831 .59101 .16069 .59291 .16 .59663 .36763 Mtetra
.59663 .36763 .59291 .16 .59481 .15932 .59867 .36696 Mtetra
.59867 .36696 .59481 .15932 .59671 .15864 .60071 .36628 Mtetra
.60071 .36628 .59671 .15864 .59862 .15796 .60275 .36561 Mtetra
.60275 .36561 .59862 .15796 .60052 .15728 .60479 .36494 Mtetra
.60479 .36494 .60052 .15728 .60243 .15661 .60683 .36426 Mtetra
.60683 .36426 .60243 .15661 .60434 .15594 .60888 .36359 Mtetra
.60888 .36359 .60434 .15594 .60625 .15528 .61093 .36291 Mtetra
.61093 .36291 .60625 .15528 .60816 .15461 .61297 .36224 Mtetra
.61297 .36224 .60816 .15461 .61008 .15395 .61502 .36156 Mtetra
.61502 .36156 .61008 .15395 .61199 .15329 .61707 .36088 Mtetra
.61707 .36088 .61199 .15329 .61391 .15262 .61913 .3602 Mtetra
.61913 .3602 .61391 .15262 .61582 .15194 .62118 .35952 Mtetra
.62118 .35952 .61582 .15194 .61774 .15124 .62324 .35884 Mtetra
.62324 .35884 .61774 .15124 .61966 .15049 .62529 .35814 Mtetra
.62529 .35814 .61966 .15049 .62157 .14965 .62735 .35744 Mtetra
.62735 .35744 .62157 .14965 .62349 .14869 .62941 .35673 Mtetra
.62941 .35673 .62349 .14869 .6254 .14774 .63147 .356 Mtetra
.512 .278 .496 r
.63147 .356 .6254 .14774 .62729 .14587 .63353 .35518 Mtetra
.63353 .35518 .62729 .14587 .62915 .14345 .63558 .35424 Mtetra
.513 .278 .496 r
.63558 .35424 .62915 .14345 .63108 .14298 .63765 .35353 Mtetra
.514 .279 .497 r
.63765 .35353 .63108 .14298 .64004 .33505 .63974 .35349 Mtetra
.521 .257 .455 r
.63974 .35349 .64004 .33505 .64274 .35176 .64186 .35416 Mtetra
.502 .086 .185 r
.64186 .35416 .64274 .35176 .64496 .35514 .64397 .35463 Mtetra
.253 .715 .949 r
.64397 .35463 .64496 .35514 .6471 .35624 .64607 .35462 Mtetra
.633 .696 .891 r
.64607 .35462 .6471 .35624 .64919 .35577 .64815 .354 Mtetra
.663 .688 .863 r
.64815 .354 .64919 .35577 .65125 .35487 .65022 .35319 Mtetra
.678 .706 .869 r
.65022 .35319 .65125 .35487 .65332 .35382 .65229 .3523 Mtetra
.676 .732 .892 r
.65229 .3523 .65332 .35382 .65539 .35287 .65437 .35145 Mtetra
.674 .747 .906 r
.65437 .35145 .65539 .35287 .65746 .35193 .65644 .35062 Mtetra
.652 .758 .927 r
.65644 .35062 .65746 .35193 .65953 .35114 .65853 .34991 Mtetra
.606 .753 .948 r
.65853 .34991 .65953 .35114 .66163 .35064 .66062 .34938 Mtetra
.597 .745 .947 r
.66062 .34938 .66163 .35064 .66372 .35018 .66271 .34889 Mtetra
.565 .723 .948 r
.66271 .34889 .66372 .35018 .66582 .34985 .66482 .34852 Mtetra
.505 .688 .949 r
.66482 .34852 .66582 .34985 .66794 .34971 .66693 .34838 Mtetra
.644 .752 .927 r
.66693 .34838 .66794 .34971 .67003 .34901 .66902 .34769 Mtetra
.847 .811 .815 r
.66902 .34769 .67003 .34901 .67205 .34681 .67105 .34555 Mtetra
.978 .764 .546 r
.67105 .34555 .67205 .34681 .67374 .33761 .67277 .33697 Mtetra
.977 .677 .352 r
.67277 .33697 .67374 .33761 .66566 .12398 .66474 .12313 Mtetra
.97 .828 .647 r
.66474 .12313 .66566 .12398 .66743 .11963 .66651 .11859 Mtetra
.731 .823 .922 r
.66651 .11859 .66743 .11963 .66936 .11867 .66844 .11756 Mtetra
.565 .742 .96 r
.66844 .11756 .66936 .11867 .67133 .1184 .6704 .1172 Mtetra
.509 .698 .954 r
.6704 .1172 .67133 .1184 .67331 .11832 .67238 .11703 Mtetra
.66 .749 .916 r
.67238 .11703 .67331 .11832 .67526 .11767 .67433 .11633 Mtetra
.67 .744 .906 r
.67433 .11633 .67526 .11767 .67721 .11694 .67628 .11557 Mtetra
.703 .751 .89 r
.67628 .11557 .67721 .11694 .67915 .11601 .67822 .11464 Mtetra
.769 .774 .857 r
.67822 .11464 .67915 .11601 .68107 .1146 .68014 .11327 Mtetra
.697 .758 .899 r
.68014 .11327 .68107 .1146 .68301 .11366 .68209 .11238 Mtetra
.363 .6 .938 r
.68209 .11238 .68301 .11366 .68502 .11394 .6841 .11266 Mtetra
.846 .438 0 r
.6841 .11266 .68502 .11394 .68738 .12041 .68644 .11886 Mtetra
.974 .664 .321 r
.68644 .11886 .68738 .12041 .70131 .33381 .7003 .33214 Mtetra
.608 .198 0 r
.7003 .33214 .70131 .33381 .70368 .33762 .70268 .33609 Mtetra
.454 .625 .926 r
.70268 .33609 .70368 .33762 .70583 .33749 .70484 .33618 Mtetra
.702 .781 .913 r
.70484 .33618 .70583 .33749 .70792 .33642 .70694 .3352 Mtetra
.855 .832 .824 r
.70694 .3352 .70792 .33642 .70998 .33461 .70898 .33306 Mtetra
.944 .78 .647 r
.70898 .33306 .70998 .33461 .712 .33223 .71085 .32809 Mtetra
.976 .67 .342 r
.71085 .32809 .712 .33223 .71394 .32847 .70052 .11892 Mtetra
.536 .301 .506 r
.70052 .11892 .71394 .32847 .71554 .31922 .70193 .10864 Mtetra
.52 .289 .505 r
.70193 .10864 .71554 .31922 .70501 .11233 .70379 .10623 Mtetra
.619 .447 .627 r
.70379 .10623 .70501 .11233 .70673 .10757 .70572 .10474 Mtetra
.659 .572 .747 r
.70572 .10474 .70673 .10757 .70859 .10504 .70767 .1037 Mtetra
.682 .751 .904 r
.70767 .1037 .70859 .10504 .71055 .10404 .70964 .10287 Mtetra
.652 .774 .938 r
.70964 .10287 .71055 .10404 .71253 .10341 .71162 .10219 Mtetra
.656 .764 .929 r
.71162 .10219 .71253 .10341 .71452 .10288 .7136 .10149 Mtetra
.754 .77 .866 r
.7136 .10149 .71452 .10288 .71647 .10171 .71555 .10023 Mtetra
.698 .734 .879 r
.71555 .10023 .71647 .10171 .71843 .10074 .71751 .09929 Mtetra
.547 .672 .919 r
.71751 .09929 .71843 .10074 .72042 .10018 .71953 .09905 Mtetra
0 0 .457 r
.71953 .09905 .72042 .10018 .7225 .10084 .72174 .10176 Mtetra
.971 .657 .308 r
.72174 .10176 .7225 .10084 .72467 .1028 .73769 .30637 Mtetra
.537 .296 .498 r
.73769 .30637 .72467 .1028 .72719 .1099 .74077 .31938 Mtetra
.516 .281 .497 r
.74077 .31938 .72719 .1099 .74364 .31649 .74305 .3207 Mtetra
.493 .141 .298 r
.74305 .3207 .74364 .31649 .7461 .32043 .74527 .32094 Mtetra
.092 0 0 r
.74527 .32094 .7461 .32043 .74841 .32194 .74745 .32067 Mtetra
.452 .675 .96 r
.74745 .32067 .74841 .32194 .75062 .32205 .74965 .32066 Mtetra
.608 .731 .932 r
.74965 .32066 .75062 .32205 .75278 .32151 .75182 .32012 Mtetra
.751 .789 .884 r
.75182 .32012 .75278 .32151 .7549 .32035 .75393 .31882 Mtetra
.939 .792 .671 r
.75393 .31882 .7549 .32035 .75695 .3181 .75581 .31444 Mtetra
.966 .685 .448 r
.75581 .31444 .75695 .3181 .75889 .31449 .7565 .29398 Mtetra
.967 .652 .358 r
.7565 .29398 .75889 .31449 .7605 .30658 .74366 .09353 Mtetra
.632 .486 .666 r
.10475 .32634 .1055 .33058 .10732 .32815 .1064 .32527 Mtetra
.596 .514 .732 r
.1064 .32527 .10732 .32815 .10901 .32675 .10796 .32483 Mtetra
.544 .567 .828 r
.10796 .32483 .10901 .32675 .11064 .32583 .10947 .32473 Mtetra
.671 .74 .901 r
.10947 .32473 .11064 .32583 .11223 .32512 .11106 .3241 Mtetra
.669 .755 .915 r
.11106 .3241 .11223 .32512 .11381 .32457 .11265 .32349 Mtetra
.65 .741 .916 r
.11265 .32349 .11381 .32457 .11538 .32406 .11422 .32296 Mtetra
.686 .744 .895 r
.11422 .32296 .11538 .32406 .11703 .32297 .11582 .32226 Mtetra
.561 .797 .987 r
.11582 .32226 .11703 .32297 .11865 .32214 .11737 .32193 Mtetra
.257 0 0 r
.11737 .32193 .11865 .32214 .12019 .32185 .11883 .32233 Mtetra
.887 .551 .408 r
.11883 .32233 .12019 .32185 .12141 .32415 .11961 .32806 Mtetra
.933 .676 .525 r
.11961 .32806 .12141 .32415 .1212 .33769 .09516 .53069 Mtetra
.524 .288 .499 r
.09516 .53069 .1212 .33769 .09795 .53235 .09623 .5349 Mtetra
.477 .088 .223 r
.09623 .5349 .09795 .53235 .09933 .53419 .09783 .53506 Mtetra
0 0 0 r
.09783 .53506 .09933 .53419 .10089 .5347 .09954 .53438 Mtetra
.755 .917 .945 r
.09954 .53438 .10089 .5347 .10252 .5346 .1013 .53331 Mtetra
.635 .712 .903 r
.1013 .53331 .10252 .5346 .1042 .53411 .10299 .53279 Mtetra
.629 .706 .901 r
.10299 .53279 .1042 .53411 .10592 .53341 .10467 .53231 Mtetra
.652 .751 .922 r
.10467 .53231 .10592 .53341 .10764 .53263 .10637 .53172 Mtetra
.627 .785 .957 r
.10637 .53172 .10764 .53263 .10928 .53253 .10806 .53121 Mtetra
.707 .728 .867 r
.10806 .53121 .10928 .53253 .11094 .53224 .1098 .53032 Mtetra
.76 .673 .765 r
.1098 .53032 .11094 .53224 .11268 .53136 .11164 .52863 Mtetra
.865 .666 .632 r
.11164 .52863 .11268 .53136 .11475 .52779 .11411 .52179 Mtetra
.935 .681 .53 r
.11411 .52179 .11475 .52779 .11788 .51551 .14073 .31755 Mtetra
.528 .296 .507 r
.14073 .31755 .11788 .51551 .14364 .31681 .14289 .31239 Mtetra
.649 .494 .659 r
.14289 .31239 .14364 .31681 .14553 .31385 .14459 .31101 Mtetra
.604 .523 .735 r
.14459 .31101 .14553 .31385 .14725 .31228 .14618 .31051 Mtetra
.546 .588 .848 r
.14618 .31051 .14725 .31228 .1489 .31127 .14772 .31038 Mtetra
.619 .775 .956 r
.14772 .31038 .1489 .31127 .15051 .31062 .14931 .30993 Mtetra
.64 .824 .971 r
.14931 .30993 .15051 .31062 .1521 .31019 .15091 .30939 Mtetra
.656 .803 .954 r
.15091 .30939 .1521 .31019 .15368 .30985 .15252 .30881 Mtetra
.692 .761 .905 r
.15252 .30881 .15368 .30985 .15528 .30931 .15414 .30809 Mtetra
.688 .727 .88 r
.15414 .30809 .15528 .30931 .15689 .30868 .15577 .30736 Mtetra
.669 .705 .874 r
.15577 .30736 .15689 .30868 .15851 .30801 .15738 .30671 Mtetra
.678 .712 .874 r
.15738 .30671 .15851 .30801 .16019 .30684 .159 .30602 Mtetra
.592 .783 .971 r
.159 .30602 .16019 .30684 .16184 .30589 .16059 .30563 Mtetra
0 .478 .719 r
.16059 .30563 .16184 .30589 .16342 .3056 .1621 .30591 Mtetra
.87 .498 .338 r
.1621 .30591 .16342 .3056 .16461 .30862 .16318 .30995 Mtetra
.941 .68 .515 r
.16318 .30995 .16461 .30862 .14275 .51298 .14131 .51369 Mtetra
.872 .522 .384 r
.14131 .51369 .14275 .51298 .14356 .52034 .14235 .51906 Mtetra
.025 .402 .855 r
.14235 .51906 .14356 .52034 .14513 .5211 .14392 .51981 Mtetra
.615 .709 .912 r
.14392 .51981 .14513 .5211 .14686 .52047 .14562 .51937 Mtetra
.724 .77 .889 r
.14562 .51937 .14686 .52047 .14864 .51936 .14739 .51842 Mtetra
.661 .789 .943 r
.14739 .51842 .14864 .51936 .15033 .51914 .14912 .51779 Mtetra
.693 .722 .872 r
.14912 .51779 .15033 .51914 .15201 .51893 .15088 .51697 Mtetra
.746 .666 .772 r
.15088 .51697 .15201 .51893 .15377 .51804 .15271 .51543 Mtetra
.851 .666 .652 r
.15271 .51543 .15377 .51804 .15591 .51375 .15496 .51018 Mtetra
.941 .685 .521 r
.15496 .51018 .15591 .51375 .1802 .30828 .17929 .30504 Mtetra
.849 .644 .625 r
.17929 .30504 .1802 .30828 .18273 .29948 .18157 .29856 Mtetra
.837 .792 .808 r
.18157 .29856 .18273 .29948 .1845 .29751 .18333 .29671 Mtetra
.681 .81 .944 r
.18333 .29671 .1845 .29751 .18613 .29694 .18497 .29604 Mtetra
.556 .754 .97 r
.18497 .29604 .18613 .29694 .1877 .29683 .18656 .29575 Mtetra
.723 .762 .884 r
.18656 .29575 .1877 .29683 .18934 .29613 .18822 .29485 Mtetra
.718 .728 .859 r
.18822 .29485 .18934 .29613 .19099 .29531 .18989 .29393 Mtetra
.598 .673 .893 r
.18989 .29393 .19099 .29531 .1926 .29493 .19149 .29359 Mtetra
.76 .299 0 r
.19149 .29359 .1926 .29493 .19402 .29637 .19281 .2959 Mtetra
.946 .683 .507 r
.19281 .2959 .19402 .29637 .19496 .30233 .17308 .49686 Mtetra
.538 .3 .502 r
.17308 .49686 .19496 .30233 .1753 .50438 .1736 .5078 Mtetra
.596 .241 .338 r
.1736 .5078 .1753 .50438 .17666 .50741 .17516 .50898 Mtetra
.156 0 0 r
.17516 .50898 .17666 .50741 .17828 .50798 .17691 .50832 Mtetra
.703 .984 .87 r
.17691 .50832 .17828 .50798 .17998 .50783 .17873 .50703 Mtetra
.76 .833 .908 r
.17873 .50703 .17998 .50783 .18173 .50725 .18053 .50592 Mtetra
.706 .731 .87 r
.18053 .50592 .18173 .50725 .1835 .50642 .18231 .50502 Mtetra
.698 .72 .866 r
.18231 .50502 .1835 .50642 .18529 .50543 .18409 .50415 Mtetra
.676 .732 .893 r
.18409 .50415 .18529 .50543 .18706 .50461 .18585 .50344 Mtetra
.646 .742 .919 r
.18585 .50344 .18706 .50461 .18882 .50397 .1876 .50286 Mtetra
.618 .747 .938 r
.1876 .50286 .18882 .50397 .19057 .50342 .18934 .50238 Mtetra
.559 .742 .962 r
.18934 .50238 .19057 .50342 .1923 .50301 .19107 .50208 Mtetra
.527 .753 .979 r
.19107 .50208 .1923 .50301 .19403 .5027 .19279 .50183 Mtetra
.558 .779 .981 r
.19279 .50183 .19403 .5027 .19575 .50242 .19452 .50149 Mtetra
.559 .765 .975 r
.19452 .50149 .19575 .50242 .19744 .50248 .19625 .50116 Mtetra
.65 .719 .899 r
.19625 .50116 .19744 .50248 .19914 .50247 .19801 .50056 Mtetra
.732 .669 .789 r
.19801 .50056 .19914 .50247 .20091 .50187 .19984 .49922 Mtetra
.845 .664 .658 r
.19984 .49922 .20091 .50187 .20287 .49922 .20201 .49443 Mtetra
.945 .684 .511 r
.20201 .49443 .20287 .49922 .20535 .49115 .22363 .28878 Mtetra
.531 .299 .508 r
.22363 .28878 .20535 .49115 .22661 .28725 .22587 .28212 Mtetra
.674 .498 .639 r
.22587 .28212 .22661 .28725 .22859 .28318 .22766 .28 Mtetra
.616 .514 .716 r
.22766 .28 .22859 .28318 .23036 .28141 .22933 .27934 Mtetra
.571 .569 .812 r
.22933 .27934 .23036 .28141 .23206 .28026 .23095 .2791 Mtetra
.606 .719 .925 r
.23095 .2791 .23206 .28026 .23374 .2795 .23258 .27871 Mtetra
.664 .814 .955 r
.23258 .27871 .23374 .2795 .23539 .27897 .23424 .27808 Mtetra
.652 .789 .947 r
.23424 .27808 .23539 .27897 .23703 .27855 .2359 .2775 Mtetra
.67 .761 .918 r
.2359 .2775 .23703 .27855 .2387 .27776 .23756 .27685 Mtetra
.637 .783 .951 r
.23756 .27685 .2387 .27776 .2404 .27679 .23922 .27633 Mtetra
.235 .701 .946 r
.23922 .27633 .2404 .27679 .24205 .27624 .24082 .27636 Mtetra
.818 .373 .179 r
.24082 .27636 .24205 .27624 .24357 .2772 .24221 .27883 Mtetra
.948 .681 .496 r
.24221 .27883 .24357 .2772 .24475 .28204 .22538 .4823 Mtetra
.531 .294 .5 r
.22538 .4823 .24475 .28204 .22804 .48625 .22637 .49037 Mtetra
.61 .268 .367 r
.22637 .49037 .22804 .48625 .22939 .49042 .22796 .49188 Mtetra
.258 0 0 r
.22796 .49188 .22939 .49042 .23104 .49131 .22972 .49151 Mtetra
.55 .931 .88 r
.22972 .49151 .23104 .49131 .23275 .49144 .23153 .49061 Mtetra
.695 .827 .946 r
.23153 .49061 .23275 .49144 .23451 .49115 .23333 .48981 Mtetra
.635 .714 .904 r
.23333 .48981 .23451 .49115 .23629 .49062 .23511 .48927 Mtetra
.653 .718 .896 r
.23511 .48927 .23629 .49062 .23808 .48994 .23689 .48865 Mtetra
.65 .727 .905 r
.23689 .48865 .23808 .48994 .23985 .48949 .23868 .48804 Mtetra
.672 .708 .875 r
.23868 .48804 .23985 .48949 .24161 .48919 .24048 .4873 Mtetra
.733 .675 .794 r
.24048 .4873 .24161 .48919 .24342 .48844 .24233 .48597 Mtetra
.829 .667 .682 r
.24233 .48597 .24342 .48844 .24535 .48609 .24439 .48224 Mtetra
.95 .686 .501 r
.24439 .48224 .24535 .48609 .24765 .47942 .26337 .27787 Mtetra
.539 .305 .509 r
.26337 .27787 .24765 .47942 .26655 .27379 .26583 .26792 Mtetra
.684 .495 .624 r
.26583 .26792 .26655 .27379 .26855 .26937 .26769 .26522 Mtetra
.611 .477 .673 r
.26769 .26522 .26855 .26937 .27024 .26858 .26938 .2644 Mtetra
.565 .445 .675 r
.26938 .2644 .27024 .26858 .27189 .26835 .27104 .26407 Mtetra
.562 .44 .672 r
.27104 .26407 .27189 .26835 .2736 .26743 .2727 .26376 Mtetra
.593 .48 .695 r
.2727 .26376 .2736 .26743 .27538 .2656 .27438 .26323 Mtetra
.618 .567 .774 r
.27438 .26323 .27538 .2656 .27715 .264 .27606 .26268 Mtetra
.651 .709 .89 r
.27606 .26268 .27715 .264 .27887 .26291 .27774 .2621 Mtetra
.665 .815 .955 r
.27774 .2621 .27887 .26291 .28055 .26234 .27943 .26145 Mtetra
.672 .8 .943 r
.27943 .26145 .28055 .26234 .28223 .26192 .28112 .26079 Mtetra
.677 .752 .908 r
.28112 .26079 .28223 .26192 .2839 .26147 .28282 .26011 Mtetra
.673 .71 .876 r
.28282 .26011 .2839 .26147 .28559 .26086 .28451 .25941 Mtetra
.658 .69 .868 r
.28451 .25941 .28559 .26086 .28729 .26022 .28621 .25878 Mtetra
.618 .678 .884 r
.28621 .25878 .28729 .26022 .28898 .2595 .28789 .25833 Mtetra
.539 .696 .941 r
.28789 .25833 .28898 .2595 .29069 .25872 .28955 .25814 Mtetra
.406 .77 .994 r
.28955 .25814 .29069 .25872 .2924 .25795 .29121 .258 Mtetra
.384 .845 .874 r
.29121 .258 .2924 .25795 .29411 .25707 .29289 .25749 Mtetra
.527 .914 .786 r
.29289 .25749 .29411 .25707 .29583 .25612 .29462 .25647 Mtetra
.239 .746 .701 r
.29462 .25647 .29583 .25612 .29752 .25557 .29632 .25593 Mtetra
.68 .171 .024 r
.29632 .25593 .29752 .25557 .29913 .25624 .29787 .25728 Mtetra
.955 .682 .481 r
.29787 .25728 .29913 .25624 .30046 .26071 .28488 .45738 Mtetra
.54 .301 .502 r
.28488 .45738 .30046 .26071 .2873 .46579 .28573 .47008 Mtetra
.65 .31 .383 r
.28573 .47008 .2873 .46579 .28876 .47016 .28734 .47235 Mtetra
.398 0 .131 r
.28734 .47235 .28876 .47016 .29055 .4699 .28913 .47219 Mtetra
.252 0 .062 r
.28913 .47219 .29055 .4699 .29239 .46902 .29096 .47141 Mtetra
.18 0 .036 r
.29096 .47141 .29239 .46902 .29419 .46868 .29282 .47034 Mtetra
.012 0 0 r
.29282 .47034 .29419 .46868 .29591 .46954 .29468 .46924 Mtetra
.761 .941 .941 r
.29468 .46924 .29591 .46954 .29766 .47013 .29655 .46805 Mtetra
.672 .634 .803 r
.29655 .46805 .29766 .47013 .29943 .47032 .29839 .46716 Mtetra
.561 .496 .74 r
.29839 .46716 .29943 .47032 .30124 .47002 .30019 .46693 Mtetra
.617 .533 .737 r
.30019 .46693 .30124 .47002 .30308 .46919 .30203 .46626 Mtetra
.755 .615 .704 r
.30203 .46626 .30308 .46919 .305 .46726 .30397 .46392 Mtetra
.906 .673 .575 r
.30397 .46392 .305 .46726 .30712 .46232 .3066 .45144 Mtetra
.948 .678 .491 r
.3066 .45144 .30712 .46232 .32237 .25751 .32181 .24834 Mtetra
.665 .454 .589 r
.32181 .24834 .32237 .25751 .32463 .24864 .32373 .24468 Mtetra
.628 .494 .68 r
.32373 .24468 .32463 .24864 .32646 .24627 .32547 .2437 Mtetra
.597 .542 .764 r
.32547 .2437 .32646 .24627 .32824 .24481 .32717 .24327 Mtetra
.581 .649 .882 r
.32717 .24327 .32824 .24481 .32998 .2438 .32887 .24297 Mtetra
.672 .817 .953 r
.32887 .24297 .32998 .2438 .33171 .24305 .3306 .24229 Mtetra
.671 .832 .961 r
.3306 .24229 .33171 .24305 .33342 .24247 .33232 .2416 Mtetra
.678 .809 .945 r
.33232 .2416 .33342 .24247 .33514 .24197 .33405 .2409 Mtetra
.685 .77 .915 r
.33405 .2409 .33514 .24197 .33686 .24142 .33578 .24017 Mtetra
.668 .73 .896 r
.33578 .24017 .33686 .24142 .33857 .24086 .33751 .2395 Mtetra
.655 .706 .885 r
.33751 .2395 .33857 .24086 .34031 .24015 .33923 .23888 Mtetra
.657 .724 .898 r
.33923 .23888 .34031 .24015 .34206 .23907 .34096 .23826 Mtetra
.477 .753 .99 r
.34096 .23826 .34206 .23907 .34379 .23832 .34266 .23809 Mtetra
.566 0 0 r
.34266 .23809 .34379 .23832 .34547 .23849 .34429 .2392 Mtetra
.927 .601 .404 r
.34429 .2392 .34547 .23849 .34697 .24193 .34529 .25093 Mtetra
.949 .67 .475 r
.34529 .25093 .34697 .24193 .33692 .44625 .33532 .45262 Mtetra
.645 .327 .42 r
.33532 .45262 .33692 .44625 .33833 .45322 .33698 .45552 Mtetra
.403 0 .146 r
.33698 .45552 .33833 .45322 .34016 .4531 .3388 .45536 Mtetra
.247 0 .058 r
.3388 .45536 .34016 .4531 .34203 .45218 .34067 .45456 Mtetra
.203 0 .05 r
.34067 .45456 .34203 .45218 .34389 .45141 .34255 .45354 Mtetra
.298 0 .069 r
.34255 .45354 .34389 .45141 .34567 .45218 .34441 .45298 Mtetra
0 0 0 r
.34441 .45298 .34567 .45218 .34746 .45279 .34627 .45236 Mtetra
.637 .905 .983 r
.34627 .45236 .34746 .45279 .34928 .45301 .34814 .45161 Mtetra
.728 .741 .862 r
.34814 .45161 .34928 .45301 .35113 .45256 .35003 .45052 Mtetra
.708 .657 .797 r
.35003 .45052 .35113 .45256 .353 .45192 .35192 .44934 Mtetra
.669 .595 .763 r
.35192 .44934 .353 .45192 .35487 .45127 .35381 .44832 Mtetra
.549 .504 .758 r
.35381 .44832 .35487 .45127 .35671 .45103 .35565 .44818 Mtetra
.605 .542 .757 r
.35565 .44818 .35671 .45103 .35858 .45044 .35751 .44764 Mtetra
.723 .608 .728 r
.35751 .44764 .35858 .45044 .36049 .44901 .35944 .44591 Mtetra
.9 .675 .59 r
.35944 .44591 .36049 .44901 .36257 .44418 .36175 .43634 Mtetra
.957 .682 .475 r
.36175 .43634 .36257 .44418 .37446 .23944 .37382 .22962 Mtetra
.675 .458 .583 r
.37382 .22962 .37446 .23944 .37667 .22954 .37576 .22526 Mtetra
.631 .488 .669 r
.37576 .22526 .37667 .22954 .37845 .22834 .37753 .22415 Mtetra
.581 .457 .677 r
.37753 .22415 .37845 .22834 .38019 .22794 .37927 .22364 Mtetra
.552 .435 .674 r
.37927 .22364 .38019 .22794 .38193 .22761 .38101 .22343 Mtetra
.587 .462 .677 r
.38101 .22343 .38193 .22761 .38374 .22572 .38276 .22285 Mtetra
.608 .532 .743 r
.38276 .22285 .38374 .22572 .38555 .22397 .38451 .22229 Mtetra
.636 .655 .851 r
.38451 .22229 .38555 .22397 .38734 .22255 .38626 .22173 Mtetra
.643 .817 .967 r
.38626 .22173 .38734 .22255 .38911 .22177 .38802 .22113 Mtetra
.637 .854 .982 r
.38802 .22113 .38911 .22177 .39086 .22119 .38978 .22051 Mtetra
.649 .85 .977 r
.38978 .22051 .39086 .22119 .39261 .2207 .39154 .21985 Mtetra
.673 .819 .953 r
.39154 .21985 .39261 .2207 .39437 .22017 .39331 .21915 Mtetra
.68 .785 .93 r
.39331 .21915 .39437 .22017 .39613 .21963 .39507 .21843 Mtetra
.679 .748 .904 r
.39507 .21843 .39613 .21963 .39789 .21907 .39684 .2177 Mtetra
.681 .719 .878 r
.39684 .2177 .39789 .21907 .39965 .21844 .39861 .21694 Mtetra
.667 .695 .866 r
.39861 .21694 .39965 .21844 .40142 .21775 .40038 .21623 Mtetra
.648 .684 .87 r
.40038 .21623 .40142 .21775 .40319 .21702 .40214 .21562 Mtetra
.567 .67 .908 r
.40214 .21562 .40319 .21702 .40496 .21622 .4039 .21536 Mtetra
.488 .75 .987 r
.4039 .21536 .40496 .21622 .40674 .2154 .40565 .21517 Mtetra
.278 .766 .913 r
.40565 .21517 .40674 .2154 .40852 .21459 .4074 .21497 Mtetra
.243 .743 .676 r
.4074 .21497 .40852 .21459 .41029 .21385 .40918 .21434 Mtetra
0 0 0 r
.40918 .21434 .41029 .21385 .41207 .21315 .41095 .2136 Mtetra
.308 .78 .672 r
.41095 .2136 .41207 .21315 .41384 .21246 .41273 .21281 Mtetra
.595 .945 .8 r
.41273 .21281 .41384 .21246 .41563 .21144 .41453 .21163 Mtetra
.455 .885 .833 r
.41453 .21163 .41563 .21144 .41741 .2107 .41631 .21084 Mtetra
.081 0 0 r
.41631 .21084 .41741 .2107 .41917 .2105 .41807 .21085 Mtetra
.895 .508 .286 r
.41807 .21085 .41917 .2105 .42084 .2131 .41963 .21637 Mtetra
.963 .678 .446 r
.41963 .21637 .42084 .2131 .41599 .40918 .41431 .4245 Mtetra
.611 .33 .467 r
.41431 .4245 .41599 .40918 .41729 .42653 .41604 .42893 Mtetra
.465 .06 .185 r
.41604 .42893 .41729 .42653 .41916 .42712 .41793 .4291 Mtetra
.253 0 .025 r
.41793 .4291 .41916 .42712 .42107 .42639 .41984 .42842 Mtetra
.146 0 0 r
.41984 .42842 .42107 .42639 .423 .42506 .42177 .42735 Mtetra
.302 0 .093 r
.42177 .42735 .423 .42506 .42493 .42411 .42369 .42672 Mtetra
.336 0 .144 r
.42369 .42672 .42493 .42411 .42684 .42336 .4256 .42612 Mtetra
.344 0 .162 r
.4256 .42612 .42684 .42336 .42875 .42297 .42752 .42551 Mtetra
.329 0 .133 r
.42752 .42551 .42875 .42297 .43063 .42366 .42944 .4249 Mtetra
.114 0 0 r
.42944 .4249 .43063 .42366 .43251 .42432 .43136 .42423 Mtetra
.53 .914 .931 r
.43136 .42423 .43251 .42432 .4344 .42469 .43328 .42347 Mtetra
.73 .78 .892 r
.43328 .42347 .4344 .42469 .43632 .42433 .43522 .4224 Mtetra
.714 .676 .811 r
.43522 .4224 .43632 .42433 .43824 .42371 .43716 .42121 Mtetra
.689 .614 .767 r
.43716 .42121 .43824 .42371 .44017 .42298 .4391 .42003 Mtetra
.565 .516 .759 r
.4391 .42003 .44017 .42298 .44208 .4227 .44101 .41977 Mtetra
.587 .529 .758 r
.44101 .41977 .44208 .4227 .44401 .42221 .44294 .41935 Mtetra
.674 .582 .744 r
.44294 .41935 .44401 .42221 .44595 .42114 .44488 .41816 Mtetra
.875 .672 .624 r
.44488 .41816 .44595 .42114 .44795 .41751 .44694 .41196 Mtetra
.966 .684 .447 r
.44694 .41196 .44795 .41751 .45012 .40646 .45379 .20192 Mtetra
.528 .296 .506 r
.45379 .20192 .45012 .40646 .45667 .20081 .45572 .19606 Mtetra
.652 .492 .653 r
.45572 .19606 .45667 .20081 .45854 .19753 .45755 .19446 Mtetra
.611 .523 .731 r
.45755 .19446 .45854 .19753 .46036 .1958 .45935 .19383 Mtetra
.567 .59 .836 r
.45935 .19383 .46036 .1958 .46218 .19464 .46115 .19359 Mtetra
.631 .77 .946 r
.46115 .19359 .46218 .19464 .46399 .19378 .46295 .19304 Mtetra
.645 .842 .976 r
.46295 .19304 .46399 .19378 .4658 .19313 .46476 .1924 Mtetra
.652 .845 .974 r
.46476 .1924 .4658 .19313 .46761 .1926 .46657 .19172 Mtetra
.692 .825 .946 r
.46657 .19172 .46761 .1926 .46942 .19203 .46839 .19093 Mtetra
.692 .777 .917 r
.46839 .19093 .46942 .19203 .47123 .19144 .4702 .19013 Mtetra
.671 .732 .895 r
.4702 .19013 .47123 .19144 .47304 .19082 .47202 .18941 Mtetra
.676 .718 .88 r
.47202 .18941 .47304 .19082 .47486 .18974 .47383 .18866 Mtetra
.608 .753 .947 r
.47383 .18866 .47486 .18974 .47668 .18877 .47565 .18819 Mtetra
.177 .643 .935 r
.47565 .18819 .47668 .18877 .47849 .18828 .47745 .18838 Mtetra
.859 .419 .159 r
.47745 .18838 .47849 .18828 .48028 .19001 .4792 .19215 Mtetra
.968 .677 .423 r
.4792 .19215 .48028 .19001 .48198 .19772 .47798 .40103 Mtetra
.525 .288 .498 r
.47798 .40103 .48198 .19772 .48099 .40375 .47984 .40684 Mtetra
.536 .155 .267 r
.47984 .40684 .48099 .40375 .48292 .40514 .48178 .4075 Mtetra
.299 0 .1 r
.48178 .4075 .48292 .40514 .48488 .40432 .48373 .40681 Mtetra
.195 0 .069 r
.48373 .40681 .48488 .40432 .48684 .40302 .4857 .40562 Mtetra
.263 0 .111 r
.4857 .40562 .48684 .40302 .48879 .40331 .48766 .40465 Mtetra
.082 0 0 r
.48766 .40465 .48879 .40331 .49073 .40403 .48963 .40381 Mtetra
.598 .931 .957 r
.48963 .40381 .49073 .40403 .49268 .40442 .49159 .40296 Mtetra
.681 .729 .887 r
.49159 .40296 .49268 .40442 .49464 .40398 .49356 .40213 Mtetra
.665 .668 .843 r
.49356 .40213 .49464 .40398 .49661 .40309 .49553 .40132 Mtetra
.66 .677 .855 r
.49553 .40132 .49661 .40309 .49858 .40206 .49749 .40056 Mtetra
.65 .711 .892 r
.49749 .40056 .49858 .40206 .50055 .40125 .49946 .39988 Mtetra
.637 .729 .915 r
.49946 .39988 .50055 .40125 .50252 .4006 .50143 .39928 Mtetra
.629 .734 .923 r
.50143 .39928 .50252 .4006 .50449 .4 .5034 .3987 Mtetra
.507 .686 .948 r
.5034 .3987 .50449 .4 .50645 .3999 .50537 .39856 Mtetra
.548 .698 .939 r
.50537 .39856 .50645 .3999 .50843 .39965 .50734 .3983 Mtetra
.704 .755 .892 r
.50734 .3983 .50843 .39965 .5104 .39863 .50932 .39734 Mtetra
.921 .783 .692 r
.50932 .39734 .5104 .39863 .5124 .39374 .51131 .39324 Mtetra
.974 .688 .419 r
.51131 .39324 .5124 .39374 .51506 .1819 .51404 .18515 Mtetra
.931 .81 .349 r
.51404 .18515 .51506 .1819 .51693 .17478 .51591 .17515 Mtetra
.865 .992 .744 r
.51591 .17515 .51693 .17478 .51877 .17267 .51776 .17284 Mtetra
.382 .843 .797 r
.51776 .17284 .51877 .17267 .52062 .17194 .51961 .17212 Mtetra
0 0 0 r
.51961 .17212 .52062 .17194 .52246 .17166 .52146 .17188 Mtetra
.159 .692 .69 r
.52146 .17188 .52246 .17166 .52431 .1712 .52331 .17146 Mtetra
.278 .773 .726 r
.52331 .17146 .52431 .1712 .52616 .17057 .52516 .17083 Mtetra
.275 .771 .724 r
.52516 .17083 .52616 .17057 .52801 .16993 .52701 .1702 Mtetra
.484 .894 .785 r
.52701 .1702 .52801 .16993 .52986 .16905 .52886 .16921 Mtetra
.515 .914 .833 r
.52886 .16921 .52986 .16905 .53171 .16818 .53071 .16825 Mtetra
.178 .713 .764 r
.53071 .16825 .53171 .16818 .53356 .16775 .53257 .16793 Mtetra
.79 .302 .051 r
.53257 .16793 .53356 .16775 .53543 .16912 .53444 .17058 Mtetra
.972 .675 .4 r
.53444 .17058 .53543 .16912 .53731 .17573 .5371 .37957 Mtetra
.528 .29 .498 r
.5371 .37957 .53731 .17573 .54017 .38379 .53912 .38691 Mtetra
.589 .205 .283 r
.53912 .38691 .54017 .38379 .54218 .38624 .54113 .38815 Mtetra
.3 0 .04 r
.54113 .38815 .54218 .38624 .54418 .3858 .54313 .38765 Mtetra
.153 0 0 r
.54313 .38765 .54418 .3858 .54618 .38461 .54513 .38664 Mtetra
.215 0 .02 r
.54513 .38664 .54618 .38461 .54818 .38358 .54714 .38574 Mtetra
.286 0 .071 r
.54714 .38574 .54818 .38358 .55018 .38287 .54914 .38506 Mtetra
.287 0 .075 r
.54914 .38506 .55018 .38287 .55218 .38216 .55115 .38437 Mtetra
.292 0 .08 r
.55115 .38437 .55218 .38216 .55419 .38147 .55316 .38369 Mtetra
.297 0 .084 r
.55316 .38369 .55419 .38147 .55619 .3808 .55517 .38303 Mtetra
.301 0 .087 r
.55517 .38303 .55619 .3808 .5582 .38014 .55718 .38238 Mtetra
.31 0 .092 r
.55718 .38238 .5582 .38014 .56021 .37949 .55919 .38177 Mtetra
.319 0 .1 r
.55919 .38177 .56021 .37949 .56222 .37885 .5612 .38118 Mtetra
.323 0 .108 r
.5612 .38118 .56222 .37885 .56423 .37822 .56322 .3806 Mtetra
.322 0 .113 r
.56322 .3806 .56423 .37822 .56625 .37758 .56524 .37998 Mtetra
.318 0 .115 r
.56524 .37998 .56625 .37758 .56826 .37694 .56726 .37934 Mtetra
.316 0 .114 r
.56726 .37934 .56826 .37694 .57028 .37629 .56928 .37868 Mtetra
.315 0 .113 r
.56928 .37868 .57028 .37629 .5723 .37563 .5713 .37802 Mtetra
.314 0 .112 r
.5713 .37802 .5723 .37563 .57432 .37498 .57332 .37736 Mtetra
.314 0 .111 r
.57332 .37736 .57432 .37498 .57634 .37432 .57535 .3767 Mtetra
.313 0 .111 r
.57535 .3767 .57634 .37432 .57836 .37366 .57737 .37604 Mtetra
.312 0 .11 r
.57737 .37604 .57836 .37366 .58039 .37299 .5794 .37537 Mtetra
.5794 .37537 .58039 .37299 .58241 .37233 .58143 .3747 Mtetra
.58143 .3747 .58241 .37233 .58444 .37166 .58346 .37403 Mtetra
.311 0 .109 r
.58346 .37403 .58444 .37166 .58647 .37099 .58549 .37336 Mtetra
.58549 .37336 .58647 .37099 .5885 .37032 .58752 .37269 Mtetra
.58752 .37269 .5885 .37032 .59053 .36965 .58956 .37202 Mtetra
.58956 .37202 .59053 .36965 .59256 .36898 .59159 .37134 Mtetra
.311 0 .108 r
.59159 .37134 .59256 .36898 .5946 .36831 .59363 .37067 Mtetra
.31 0 .108 r
.59363 .37067 .5946 .36831 .59663 .36763 .59567 .37 Mtetra
.59567 .37 .59663 .36763 .59867 .36696 .59771 .36932 Mtetra
.59771 .36932 .59867 .36696 .60071 .36628 .59975 .36864 Mtetra
.31 0 .107 r
.59975 .36864 .60071 .36628 .60275 .36561 .6018 .36797 Mtetra
.6018 .36797 .60275 .36561 .60479 .36494 .60384 .36729 Mtetra
.60384 .36729 .60479 .36494 .60683 .36426 .60589 .36661 Mtetra
.309 0 .106 r
.60589 .36661 .60683 .36426 .60888 .36359 .60794 .36594 Mtetra
.60794 .36594 .60888 .36359 .61093 .36291 .60999 .36526 Mtetra
.309 0 .105 r
.60999 .36526 .61093 .36291 .61297 .36224 .61204 .36458 Mtetra
.61204 .36458 .61297 .36224 .61502 .36156 .61409 .3639 Mtetra
.308 0 .104 r
.61409 .3639 .61502 .36156 .61707 .36088 .61615 .36322 Mtetra
.61615 .36322 .61707 .36088 .61913 .3602 .6182 .36254 Mtetra
.307 0 .103 r
.6182 .36254 .61913 .3602 .62118 .35952 .62026 .36185 Mtetra
.62026 .36185 .62118 .35952 .62324 .35884 .62232 .36117 Mtetra
.306 0 .103 r
.62232 .36117 .62324 .35884 .62529 .35814 .62438 .36048 Mtetra
.62438 .36048 .62529 .35814 .62735 .35744 .62644 .35979 Mtetra
.306 0 .104 r
.62644 .35979 .62735 .35744 .62941 .35673 .6285 .35909 Mtetra
.307 0 .107 r
.6285 .35909 .62941 .35673 .63147 .356 .63057 .35838 Mtetra
.307 0 .11 r
.63057 .35838 .63147 .356 .63353 .35518 .63263 .35767 Mtetra
.315 0 .125 r
.63263 .35767 .63353 .35518 .63558 .35424 .6347 .35695 Mtetra
.33 0 .154 r
.6347 .35695 .63558 .35424 .63765 .35353 .63677 .35622 Mtetra
.324 0 .149 r
.63677 .35622 .63765 .35353 .63974 .35349 .63883 .35546 Mtetra
.245 0 .028 r
.63883 .35546 .63974 .35349 .64186 .35416 .6409 .35467 Mtetra
0 0 0 r
.6409 .35467 .64186 .35416 .64397 .35463 .64297 .35389 Mtetra
.643 .869 .983 r
.64297 .35389 .64397 .35463 .64607 .35462 .64505 .35311 Mtetra
.657 .724 .898 r
.64505 .35311 .64607 .35462 .64815 .354 .64712 .35236 Mtetra
.653 .703 .884 r
.64712 .35236 .64815 .354 .65022 .35319 .6492 .35163 Mtetra
.647 .713 .896 r
.6492 .35163 .65022 .35319 .65229 .3523 .65128 .35093 Mtetra
.637 .741 .924 r
.65128 .35093 .65229 .3523 .65437 .35145 .65336 .35029 Mtetra
.646 .784 .947 r
.65336 .35029 .65437 .35145 .65644 .35062 .65544 .34959 Mtetra
.682 .823 .951 r
.65544 .34959 .65644 .35062 .65853 .34991 .65752 .34872 Mtetra
.74 .811 .908 r
.65752 .34872 .65853 .34991 .66062 .34938 .65958 .34756 Mtetra
.721 .706 .836 r
.65958 .34756 .66062 .34938 .66271 .34889 .66165 .34633 Mtetra
.652 .601 .785 r
.66165 .34633 .66271 .34889 .66482 .34852 .66373 .34543 Mtetra
.548 .505 .76 r
.66373 .34543 .66482 .34852 .66693 .34838 .66584 .34527 Mtetra
.605 .538 .752 r
.66584 .34527 .66693 .34838 .66902 .34769 .66794 .34465 Mtetra
.747 .618 .716 r
.66794 .34465 .66902 .34769 .67105 .34555 .66996 .34246 Mtetra
.94 .694 .538 r
.66996 .34246 .67105 .34555 .67277 .33697 .67158 .33162 Mtetra
.976 .673 .362 r
.67158 .33162 .67277 .33697 .66474 .12313 .6638 .12174 Mtetra
.933 .785 .674 r
.6638 .12174 .66474 .12313 .66651 .11859 .66559 .11766 Mtetra
.744 .85 .929 r
.66559 .11766 .66651 .11859 .66844 .11756 .66752 .11657 Mtetra
.598 .787 .971 r
.66752 .11657 .66844 .11756 .6704 .1172 .66948 .11606 Mtetra
.562 .739 .959 r
.66948 .11606 .6704 .1172 .67238 .11703 .67144 .11571 Mtetra
.682 .753 .905 r
.67144 .11571 .67238 .11703 .67433 .11633 .67339 .1149 Mtetra
.672 .729 .893 r
.67339 .1149 .67433 .11633 .67628 .11557 .67534 .11412 Mtetra
.666 .724 .893 r
.67534 .11412 .67628 .11557 .67822 .11464 .67729 .11338 Mtetra
.683 .765 .913 r
.67729 .11338 .67822 .11464 .68014 .11327 .67924 .11256 Mtetra
.508 .811 .999 r
.67924 .11256 .68014 .11327 .68209 .11238 .68122 .1122 Mtetra
.353 0 0 r
.68122 .1122 .68209 .11238 .6841 .11266 .68326 .11307 Mtetra
.927 .542 .227 r
.68326 .11307 .6841 .11266 .68644 .11886 .68581 .12315 Mtetra
.972 .659 .337 r
.68581 .12315 .68644 .11886 .7003 .33214 .69933 .33125 Mtetra
.683 .192 0 r
.69933 .33125 .7003 .33214 .70268 .33609 .70167 .33447 Mtetra
.403 .579 .911 r
.70167 .33447 .70268 .33609 .70484 .33618 .70384 .33476 Mtetra
.664 .747 .912 r
.70384 .33476 .70484 .33618 .70694 .3352 .70596 .33397 Mtetra
.859 .832 .819 r
.70596 .33397 .70694 .3352 .70898 .33306 .708 .33177 Mtetra
.979 .774 .558 r
.708 .33177 .70898 .33306 .71085 .32809 .70971 .32411 Mtetra
.976 .671 .341 r
.70971 .32411 .71085 .32809 .70052 .11892 .69911 .10941 Mtetra
.697 .47 .574 r
.69911 .10941 .70052 .11892 .70193 .10864 .70082 .10425 Mtetra
.63 .489 .672 r
.70082 .10425 .70193 .10864 .70379 .10623 .70276 .10306 Mtetra
.59 .513 .736 r
.70276 .10306 .70379 .10623 .70572 .10474 .70475 .10256 Mtetra
.556 .572 .825 r
.70475 .10256 .70572 .10474 .70767 .1037 .70676 .10235 Mtetra
.67 .747 .908 r
.70676 .10235 .70767 .1037 .70964 .10287 .70873 .10159 Mtetra
.664 .755 .918 r
.70873 .10159 .70964 .10287 .71162 .10219 .71071 .10085 Mtetra
.652 .741 .915 r
.71071 .10085 .71162 .10219 .7136 .10149 .71269 .10017 Mtetra
.681 .756 .908 r
.71269 .10017 .7136 .10149 .71555 .10023 .71466 .09934 Mtetra
.55 .793 .989 r
.71466 .09934 .71555 .10023 .71751 .09929 .71667 .09894 Mtetra
0 .443 .75 r
.71667 .09894 .71751 .09929 .71953 .09905 .71873 .09951 Mtetra
.907 .499 .183 r
.71873 .09951 .71953 .09905 .72174 .10176 .7213 .10741 Mtetra
.971 .654 .322 r
.7213 .10741 .72174 .10176 .73769 .30637 .7376 .318 Mtetra
.606 .306 .433 r
.7376 .318 .73769 .30637 .74077 .31938 .74004 .32161 Mtetra
.408 0 .125 r
.74004 .32161 .74077 .31938 .74305 .3207 .74223 .3215 Mtetra
0 0 0 r
.74223 .3215 .74305 .3207 .74527 .32094 .74437 .32064 Mtetra
.707 .972 .928 r
.74437 .32064 .74527 .32094 .74745 .32067 .74648 .31934 Mtetra
.632 .754 .935 r
.74648 .31934 .74745 .32067 .74965 .32066 .74864 .31869 Mtetra
.697 .685 .835 r
.74864 .31869 .74965 .32066 .75182 .32012 .75076 .31759 Mtetra
.763 .662 .75 r
.75076 .31759 .75182 .32012 .75393 .31882 .75282 .31555 Mtetra
.928 .688 .556 r
.75282 .31555 .75393 .31882 .75581 .31444 .75439 .30672 Mtetra
.973 .663 .328 r
.75439 .30672 .75581 .31444 .7565 .29398 .74083 .09382 Mtetra
.525 .293 .505 r
.74083 .09382 .7565 .29398 .74366 .09353 .74251 .08888 Mtetra
.685 .681 .841 r
.10364 .32486 .10475 .32634 .1064 .32527 .10524 .3241 Mtetra
.593 .703 .92 r
.10524 .3241 .1064 .32527 .10796 .32483 .10679 .32377 Mtetra
.503 .693 .954 r
.10679 .32377 .10796 .32483 .10947 .32473 .10831 .32366 Mtetra
.701 .753 .892 r
.10831 .32366 .10947 .32473 .11106 .3241 .10991 .3229 Mtetra
.676 .723 .885 r
.10991 .3229 .11106 .3241 .11265 .32349 .1115 .32224 Mtetra
.605 .693 .905 r
.1115 .32224 .11265 .32349 .11422 .32296 .11306 .32187 Mtetra
.017 .424 .863 r
.11306 .32187 .11422 .32296 .11582 .32226 .11448 .32249 Mtetra
.766 .307 .158 r
.11448 .32249 .11582 .32226 .11737 .32193 .11577 .32425 Mtetra
.824 .502 .444 r
.11577 .32425 .11737 .32193 .11883 .32233 .11654 .32992 Mtetra
.928 .67 .528 r
.11654 .32992 .11883 .32233 .11961 .32806 .09242 .52859 Mtetra
.523 .287 .499 r
.09242 .52859 .11961 .32806 .09516 .53069 .0935 .53276 Mtetra
.669 .286 .311 r
.0935 .53276 .09516 .53069 .09623 .5349 .09491 .53439 Mtetra
.46 .811 .998 r
.09491 .53439 .09623 .5349 .09783 .53506 .09656 .53413 Mtetra
.704 .794 .92 r
.09656 .53413 .09783 .53506 .09954 .53438 .09829 .53332 Mtetra
.74 .776 .881 r
.09829 .53332 .09954 .53438 .1013 .53331 .10004 .53228 Mtetra
.545 .734 .963 r
.10004 .53228 .1013 .53331 .10299 .53279 .1017 .53203 Mtetra
.537 .788 .99 r
.1017 .53203 .10299 .53279 .10467 .53231 .10336 .53172 Mtetra
.655 .858 .977 r
.10336 .53172 .10467 .53231 .10637 .53172 .10507 .53107 Mtetra
.848 .835 .834 r
.10507 .53107 .10637 .53172 .10806 .53121 .10693 .52921 Mtetra
.826 .684 .706 r
.10693 .52921 .10806 .53121 .1098 .53032 .10895 .52605 Mtetra
.825 .617 .622 r
.10895 .52605 .1098 .53032 .11164 .52863 .11143 .51914 Mtetra
.93 .676 .532 r
.11143 .51914 .11164 .52863 .11411 .52179 .13778 .31853 Mtetra
.528 .296 .507 r
.13778 .31853 .11411 .52179 .14073 .31755 .13995 .31337 Mtetra
.722 .548 .654 r
.13995 .31337 .14073 .31755 .14289 .31239 .1418 .31076 Mtetra
.705 .672 .816 r
.1418 .31076 .14289 .31239 .14459 .31101 .14344 .30982 Mtetra
.603 .708 .918 r
.14344 .30982 .14459 .31101 .14618 .31051 .14502 .30945 Mtetra
.503 .698 .956 r
.14502 .30945 .14618 .31051 .14772 .31038 .14657 .30933 Mtetra
.621 .741 .933 r
.14657 .30933 .14772 .31038 .14931 .30993 .14815 .30889 Mtetra
.657 .753 .92 r
.14815 .30889 .14931 .30993 .15091 .30939 .14976 .30832 Mtetra
.674 .752 .909 r
.14976 .30832 .15091 .30939 .15252 .30881 .15137 .30768 Mtetra
.733 .751 .867 r
.15137 .30768 .15252 .30881 .15414 .30809 .15302 .30671 Mtetra
.709 .707 .846 r
.15302 .30671 .15414 .30809 .15577 .30736 .15467 .30581 Mtetra
.649 .664 .851 r
.15467 .30581 .15577 .30736 .15738 .30671 .15628 .30523 Mtetra
.301 .511 .893 r
.15628 .30523 .15738 .30671 .159 .30602 .15777 .30566 Mtetra
.741 .22 0 r
.15777 .30566 .159 .30602 .16059 .30563 .15913 .30723 Mtetra
.825 .479 .401 r
.15913 .30723 .16059 .30563 .1621 .30591 .16016 .31169 Mtetra
.935 .674 .518 r
.16016 .31169 .1621 .30591 .16318 .30995 .13859 .51121 Mtetra
.525 .289 .499 r
.13859 .51121 .16318 .30995 .14131 .51369 .13963 .51644 Mtetra
.672 .309 .35 r
.13963 .51644 .14131 .51369 .14235 .51906 .14106 .51839 Mtetra
0 .475 .826 r
.14106 .51839 .14235 .51906 .14392 .51981 .14266 .51886 Mtetra
.546 .753 .973 r
.14266 .51886 .14392 .51981 .14562 .51937 .14435 .51858 Mtetra
.713 .828 .936 r
.14435 .51858 .14562 .51937 .14739 .51842 .14611 .51772 Mtetra
.838 .838 .846 r
.14611 .51772 .14739 .51842 .14912 .51779 .14797 .51598 Mtetra
.83 .701 .722 r
.14797 .51598 .14912 .51779 .15088 .51697 .14996 .51308 Mtetra
.817 .618 .634 r
.14996 .51308 .15088 .51697 .15271 .51543 .15225 .50748 Mtetra
.936 .679 .523 r
.15225 .50748 .15271 .51543 .15496 .51018 .17629 .30657 Mtetra
.531 .298 .508 r
.17629 .30657 .15496 .51018 .17929 .30504 .17858 .3 Mtetra
.713 .527 .636 r
.17858 .3 .17929 .30504 .18157 .29856 .18047 .29705 Mtetra
.754 .703 .804 r
.18047 .29705 .18157 .29856 .18333 .29671 .18218 .29573 Mtetra
.677 .773 .923 r
.18218 .29573 .18333 .29671 .18497 .29604 .18381 .29507 Mtetra
.613 .76 .949 r
.18381 .29507 .18497 .29604 .18656 .29575 .18542 .29464 Mtetra
.746 .761 .865 r
.18542 .29464 .18656 .29575 .18822 .29485 .1871 .29359 Mtetra
.736 .733 .849 r
.1871 .29359 .18822 .29485 .18989 .29393 .18878 .29255 Mtetra
.623 .681 .884 r
.18878 .29255 .18989 .29393 .19149 .29359 .19039 .2921 Mtetra
.712 .262 0 r
.19039 .2921 .19149 .29359 .19281 .2959 .19172 .29435 Mtetra
.947 .685 .506 r
.19172 .29435 .19281 .2959 .17308 .49686 .17188 .49561 Mtetra
.952 .642 .409 r
.17188 .49561 .17308 .49686 .1736 .5078 .17234 .50706 Mtetra
.466 0 0 r
.17234 .50706 .1736 .5078 .17516 .50898 .17391 .50817 Mtetra
.7 .825 .942 r
.17391 .50817 .17516 .50898 .17691 .50832 .17567 .50736 Mtetra
.799 .802 .854 r
.17567 .50736 .17691 .50832 .17873 .50703 .17751 .50588 Mtetra
.759 .769 .861 r
.17751 .50588 .17873 .50703 .18053 .50592 .17933 .50466 Mtetra
.708 .744 .88 r
.17933 .50466 .18053 .50592 .18231 .50502 .18111 .50377 Mtetra
.694 .742 .889 r
.18111 .50377 .18231 .50502 .18409 .50415 .18288 .50296 Mtetra
.66 .743 .911 r
.18288 .50296 .18409 .50415 .18585 .50344 .18463 .50232 Mtetra
.624 .748 .936 r
.18463 .50232 .18585 .50344 .1876 .50286 .18638 .50183 Mtetra
.595 .755 .955 r
.18638 .50183 .1876 .50286 .18934 .50238 .18811 .50142 Mtetra
.483 .728 .979 r
.18811 .50142 .18934 .50238 .19107 .50208 .18982 .50128 Mtetra
.46 .755 .993 r
.18982 .50128 .19107 .50208 .19279 .50183 .19153 .50113 Mtetra
.604 .827 .985 r
.19153 .50113 .19279 .50183 .19452 .50149 .19328 .50062 Mtetra
.803 .82 .864 r
.19328 .50062 .19452 .50149 .19625 .50116 .19512 .49915 Mtetra
.818 .687 .719 r
.19512 .49915 .19625 .50116 .19801 .50056 .1971 .49633 Mtetra
.813 .61 .628 r
.1971 .49633 .19801 .50056 .19984 .49922 .19937 .49051 Mtetra
.94 .679 .514 r
.19937 .49051 .19984 .49922 .20201 .49443 .22075 .28915 Mtetra
.529 .297 .507 r
.22075 .28915 .20201 .49443 .22363 .28878 .22295 .28302 Mtetra
.696 .505 .625 r
.22295 .28302 .22363 .28878 .22587 .28212 .22483 .28008 Mtetra
.729 .645 .765 r
.22483 .28008 .22587 .28212 .22766 .28 .22656 .27872 Mtetra
.634 .705 .898 r
.22656 .27872 .22766 .28 .22933 .27934 .2282 .27822 Mtetra
.539 .703 .946 r
.2282 .27822 .22933 .27934 .23095 .2791 .22982 .27802 Mtetra
.63 .743 .929 r
.22982 .27802 .23095 .2791 .23258 .27871 .23147 .27753 Mtetra
.687 .741 .893 r
.23147 .27753 .23258 .27871 .23424 .27808 .23314 .2768 Mtetra
.638 .709 .898 r
.23314 .2768 .23424 .27808 .2359 .2775 .23479 .27628 Mtetra
.399 .62 .941 r
.23479 .27628 .2359 .2775 .23756 .27685 .23638 .27643 Mtetra
.597 .026 0 r
.23638 .27643 .23756 .27685 .23922 .27633 .23787 .27761 Mtetra
.798 .415 .331 r
.23787 .27761 .23922 .27633 .24082 .27636 .23919 .2808 Mtetra
.945 .677 .499 r
.23919 .2808 .24082 .27636 .24221 .27883 .22251 .48056 Mtetra
.53 .292 .5 r
.22251 .48056 .24221 .27883 .22538 .4823 .22354 .48811 Mtetra
.635 .318 .417 r
.22354 .48811 .22538 .4823 .22637 .49037 .22505 .49053 Mtetra
.426 0 0 r
.22505 .49053 .22637 .49037 .22796 .49188 .22672 .4911 Mtetra
.592 .81 .983 r
.22672 .4911 .22796 .49188 .22972 .49151 .22849 .49063 Mtetra
.695 .817 .94 r
.22849 .49063 .22972 .49151 .23153 .49061 .23029 .48983 Mtetra
.646 .825 .969 r
.23029 .48983 .23153 .49061 .23333 .48981 .23208 .4892 Mtetra
.549 .833 .998 r
.23208 .4892 .23333 .48981 .23511 .48927 .23385 .48878 Mtetra
.641 .884 .985 r
.23385 .48878 .23511 .48927 .23689 .48865 .23564 .48809 Mtetra
.809 .884 .899 r
.23564 .48809 .23689 .48865 .23868 .48804 .2375 .48668 Mtetra
.848 .751 .756 r
.2375 .48668 .23868 .48804 .24048 .4873 .23946 .4841 Mtetra
.821 .637 .653 r
.23946 .4841 .24048 .4873 .24233 .48597 .24159 .47955 Mtetra
.947 .683 .503 r
.24159 .47955 .24233 .48597 .24439 .48224 .2604 .27926 Mtetra
.539 .305 .509 r
.2604 .27926 .24439 .48224 .26337 .27787 .2629 .26907 Mtetra
.665 .456 .593 r
.2629 .26907 .26337 .27787 .26583 .26792 .26482 .26558 Mtetra
.746 .632 .733 r
.26482 .26558 .26583 .26792 .26769 .26522 .2666 .26383 Mtetra
.683 .706 .865 r
.2666 .26383 .26769 .26522 .26938 .2644 .26829 .26308 Mtetra
.61 .693 .902 r
.26829 .26308 .26938 .2644 .27104 .26407 .26996 .26266 Mtetra
.59 .672 .896 r
.26996 .26266 .27104 .26407 .2727 .26376 .27162 .26233 Mtetra
.612 .676 .886 r
.27162 .26233 .2727 .26376 .27438 .26323 .27328 .26191 Mtetra
.617 .698 .902 r
.27328 .26191 .27438 .26323 .27606 .26268 .27496 .26147 Mtetra
.653 .729 .905 r
.27496 .26147 .27606 .26268 .27774 .2621 .27664 .26089 Mtetra
.693 .741 .888 r
.27664 .26089 .27774 .2621 .27943 .26145 .27834 .26012 Mtetra
.694 .72 .869 r
.27834 .26012 .27943 .26145 .28112 .26079 .28004 .25931 Mtetra
.695 .698 .849 r
.28004 .25931 .28112 .26079 .28282 .26011 .28175 .25846 Mtetra
.685 .672 .832 r
.28175 .25846 .28282 .26011 .28451 .25941 .28346 .25764 Mtetra
.638 .637 .833 r
.28346 .25764 .28451 .25941 .28621 .25878 .28515 .25706 Mtetra
.461 .561 .87 r
.28515 .25706 .28621 .25878 .28789 .25833 .28678 .25721 Mtetra
0 .023 .527 r
.28678 .25721 .28789 .25833 .28955 .25814 .28831 .2587 Mtetra
.83 .419 .264 r
.28831 .2587 .28955 .25814 .29121 .258 .28972 .26187 Mtetra
.763 .431 .424 r
.28972 .26187 .29121 .258 .29289 .25749 .29101 .26671 Mtetra
.427 .153 .394 r
.29101 .26671 .29289 .25749 .29462 .25647 .29276 .26541 Mtetra
.439 .162 .395 r
.29276 .26541 .29462 .25647 .29632 .25593 .2945 .26434 Mtetra
.945 .671 .488 r
.2945 .26434 .29632 .25593 .29787 .25728 .28201 .45529 Mtetra
.538 .299 .501 r
.28201 .45529 .29787 .25728 .28488 .45738 .2829 .46721 Mtetra
.62 .327 .451 r
.2829 .46721 .28488 .45738 .28573 .47008 .28444 .47043 Mtetra
.639 .111 0 r
.28444 .47043 .28573 .47008 .28734 .47235 .28613 .47165 Mtetra
.363 .736 .988 r
.28613 .47165 .28734 .47235 .28913 .47219 .28791 .47161 Mtetra
.623 .866 .988 r
.28791 .47161 .28913 .47219 .29096 .47141 .28973 .47097 Mtetra
.81 .914 .91 r
.28973 .47097 .29096 .47141 .29282 .47034 .29162 .46955 Mtetra
.894 .823 .77 r
.29162 .46955 .29282 .47034 .29468 .46924 .29359 .4668 Mtetra
.847 .677 .671 r
.29359 .4668 .29468 .46924 .29655 .46805 .29567 .46258 Mtetra
.777 .569 .618 r
.29567 .46258 .29655 .46805 .29839 .46716 .29783 .45718 Mtetra
.545 .362 .584 r
.29783 .45718 .29839 .46716 .30019 .46693 .29964 .4567 Mtetra
.534 .352 .581 r
.29964 .4567 .30019 .46693 .30203 .46626 .30144 .45647 Mtetra
.72 .496 .586 r
.30144 .45647 .30203 .46626 .30397 .46392 .30365 .45014 Mtetra
.945 .674 .494 r
.30365 .45014 .30397 .46392 .3066 .45144 .31885 .25011 Mtetra
.526 .294 .506 r
.31885 .25011 .3066 .45144 .32181 .24834 .32084 .24548 Mtetra
.756 .611 .697 r
.32084 .24548 .32181 .24834 .32373 .24468 .32266 .24319 Mtetra
.672 .692 .861 r
.32266 .24319 .32373 .24468 .32547 .2437 .32439 .24247 Mtetra
.592 .708 .924 r
.32439 .24247 .32547 .2437 .32717 .24327 .32609 .24211 Mtetra
.589 .72 .935 r
.32609 .24211 .32717 .24327 .32887 .24297 .32779 .24175 Mtetra
.695 .744 .89 r
.32779 .24175 .32887 .24297 .3306 .24229 .32952 .24095 Mtetra
.697 .725 .872 r
.32952 .24095 .3306 .24229 .33232 .2416 .33126 .24012 Mtetra
.694 .702 .853 r
.33126 .24012 .33232 .2416 .33405 .2409 .33299 .23927 Mtetra
.692 .681 .835 r
.33299 .23927 .33405 .2409 .33578 .24017 .33473 .2384 Mtetra
.65 .646 .833 r
.33473 .2384 .33578 .24017 .33751 .2395 .33646 .23775 Mtetra
.553 .605 .859 r
.33646 .23775 .33751 .2395 .33923 .23888 .33816 .23757 Mtetra
.027 .38 .844 r
.33816 .23757 .33923 .23888 .34096 .23826 .3398 .23844 Mtetra
.789 .317 .112 r
.3398 .23844 .34096 .23826 .34266 .23809 .34135 .2407 Mtetra
.887 .565 .434 r
.34135 .2407 .34266 .23809 .34429 .2392 .34237 .25212 Mtetra
.944 .664 .479 r
.34237 .25212 .34429 .2392 .34529 .25093 .33242 .45024 Mtetra
.52 .284 .497 r
.33242 .45024 .34529 .25093 .33532 .45262 .33404 .45357 Mtetra
.627 .145 .089 r
.33404 .45357 .33532 .45262 .33698 .45552 .33579 .45476 Mtetra
.516 .794 .996 r
.33579 .45476 .33698 .45552 .3388 .45536 .33763 .45444 Mtetra
.673 .814 .951 r
.33763 .45444 .3388 .45536 .34067 .45456 .3395 .45371 Mtetra
.698 .833 .947 r
.3395 .45371 .34067 .45456 .34255 .45354 .34137 .45286 Mtetra
.546 .824 .997 r
.34137 .45286 .34255 .45354 .34441 .45298 .34322 .45244 Mtetra
.61 .874 .991 r
.34322 .45244 .34441 .45298 .34627 .45236 .34508 .4518 Mtetra
.759 .9 .94 r
.34508 .4518 .34627 .45236 .34814 .45161 .34697 .45065 Mtetra
.886 .813 .771 r
.34697 .45065 .34814 .45161 .35003 .45052 .34895 .44796 Mtetra
.842 .673 .672 r
.34895 .44796 .35003 .45052 .35192 .44934 .351 .44386 Mtetra
.801 .584 .608 r
.351 .44386 .35192 .44934 .35381 .44832 .35317 .43736 Mtetra
.538 .352 .577 r
.35317 .43736 .35381 .44832 .35565 .44818 .35502 .437 Mtetra
.516 .334 .573 r
.35502 .437 .35565 .44818 .35751 .44764 .35684 .43716 Mtetra
.641 .432 .584 r
.35684 .43716 .35751 .44764 .35944 .44591 .35884 .43384 Mtetra
.952 .677 .479 r
.35884 .43384 .35944 .44591 .36175 .43634 .37088 .23157 Mtetra
.526 .294 .506 r
.37088 .23157 .36175 .43634 .37382 .22962 .37285 .22645 Mtetra
.764 .604 .679 r
.37285 .22645 .37382 .22962 .37576 .22526 .3747 .22375 Mtetra
.708 .705 .845 r
.3747 .22375 .37576 .22526 .37753 .22415 .37647 .22279 Mtetra
.637 .706 .896 r
.37647 .22279 .37753 .22415 .37927 .22364 .37822 .22225 Mtetra
.582 .677 .905 r
.37822 .22225 .37927 .22364 .38101 .22343 .37996 .22193 Mtetra
.617 .674 .882 r
.37996 .22193 .38101 .22343 .38276 .22285 .3817 .22147 Mtetra
.612 .691 .899 r
.3817 .22147 .38276 .22285 .38451 .22229 .38345 .22103 Mtetra
.617 .715 .915 r
.38345 .22103 .38451 .22229 .38626 .22173 .3852 .22057 Mtetra
.647 .746 .921 r
.3852 .22057 .38626 .22173 .38802 .22113 .38696 .21998 Mtetra
.664 .754 .917 r
.38696 .21998 .38802 .22113 .38978 .22051 .38872 .21933 Mtetra
.679 .753 .907 r
.38872 .21933 .38978 .22051 .39154 .21985 .39048 .2186 Mtetra
.7 .745 .887 r
.39048 .2186 .39154 .21985 .39331 .21915 .39225 .21776 Mtetra
.698 .722 .868 r
.39225 .21776 .39331 .21915 .39507 .21843 .39403 .2169 Mtetra
.689 .698 .853 r
.39403 .2169 .39507 .21843 .39684 .2177 .3958 .21606 Mtetra
.699 .686 .834 r
.3958 .21606 .39684 .2177 .39861 .21694 .39758 .21513 Mtetra
.66 .649 .828 r
.39758 .21513 .39861 .21694 .40038 .21623 .39935 .2144 Mtetra
.595 .617 .843 r
.39935 .2144 .40038 .21623 .40214 .21562 .4011 .21403 Mtetra
.046 .335 .815 r
.4011 .21403 .40214 .21562 .4039 .21536 .4028 .2151 Mtetra
.785 .284 0 r
.4028 .2151 .4039 .21536 .40565 .21517 .40446 .21741 Mtetra
.83 .47 .373 r
.40446 .21741 .40565 .21517 .4074 .21497 .40599 .22297 Mtetra
.609 .306 .431 r
.40599 .22297 .4074 .21497 .40918 .21434 .40765 .22544 Mtetra
.426 .163 .409 r
.40765 .22544 .40918 .21434 .41095 .2136 .40947 .22371 Mtetra
.338 .085 .376 r
.40947 .22371 .41095 .2136 .41273 .21281 .41134 .22065 Mtetra
.321 .055 .346 r
.41134 .22065 .41273 .21281 .41453 .21163 .4132 .2181 Mtetra
.412 .119 .354 r
.4132 .2181 .41453 .21163 .41631 .21084 .41499 .21703 Mtetra
.581 .266 .4 r
.41499 .21703 .41631 .21084 .41807 .21085 .4167 .21851 Mtetra
.957 .671 .452 r
.4167 .21851 .41807 .21085 .41963 .21637 .41137 .42113 Mtetra
.523 .287 .498 r
.41137 .42113 .41963 .21637 .41431 .4245 .41308 .4262 Mtetra
.697 .275 .239 r
.41308 .4262 .41431 .4245 .41604 .42893 .4149 .42825 Mtetra
.401 .762 .994 r
.4149 .42825 .41604 .42893 .41793 .4291 .4168 .42811 Mtetra
.65 .8 .955 r
.4168 .42811 .41793 .4291 .41984 .42842 .41871 .42745 Mtetra
.702 .817 .937 r
.41871 .42745 .41984 .42842 .42177 .42735 .42063 .42656 Mtetra
.578 .817 .989 r
.42063 .42656 .42177 .42735 .42369 .42672 .42254 .42608 Mtetra
.545 .836 .999 r
.42254 .42608 .42369 .42672 .4256 .42612 .42446 .42562 Mtetra
.541 .862 .996 r
.42446 .42562 .4256 .42612 .42752 .42551 .42637 .4251 Mtetra
.524 .873 .988 r
.42637 .4251 .42752 .42551 .42944 .4249 .42829 .42457 Mtetra
.597 .913 .978 r
.42829 .42457 .42944 .4249 .43136 .42423 .43021 .42382 Mtetra
.728 .934 .956 r
.43021 .42382 .43136 .42423 .43328 .42347 .43215 .42273 Mtetra
.891 .861 .804 r
.43215 .42273 .43328 .42347 .43522 .4224 .43413 .4203 Mtetra
.859 .707 .692 r
.43413 .4203 .43522 .4224 .43716 .42121 .43613 .41659 Mtetra
.823 .608 .613 r
.43613 .41659 .43716 .42121 .4391 .42003 .43821 .41033 Mtetra
.604 .408 .589 r
.43821 .41033 .4391 .42003 .44101 .41977 .44017 .40836 Mtetra
.514 .332 .573 r
.44017 .40836 .44101 .41977 .44294 .41935 .44207 .4086 Mtetra
.571 .378 .581 r
.44207 .4086 .44294 .41935 .44488 .41816 .44401 .40737 Mtetra
.96 .678 .454 r
.44401 .40737 .44488 .41816 .44694 .41196 .45089 .20389 Mtetra
.529 .296 .506 r
.45089 .20389 .44694 .41196 .45379 .20192 .45284 .19744 Mtetra
.739 .553 .642 r
.45284 .19744 .45379 .20192 .45572 .19606 .4547 .19426 Mtetra
.718 .678 .81 r
.4547 .19426 .45572 .19606 .45755 .19446 .45652 .19312 Mtetra
.622 .708 .907 r
.45652 .19312 .45755 .19446 .45935 .19383 .45832 .19262 Mtetra
.546 .701 .942 r
.45832 .19262 .45935 .19383 .46115 .19359 .46012 .19238 Mtetra
.631 .737 .924 r
.46012 .19238 .46115 .19359 .46295 .19304 .46192 .19185 Mtetra
.663 .75 .915 r
.46192 .19185 .46295 .19304 .46476 .1924 .46373 .19118 Mtetra
.676 .751 .907 r
.46373 .19118 .46476 .1924 .46657 .19172 .46555 .19044 Mtetra
.73 .756 .873 r
.46555 .19044 .46657 .19172 .46839 .19093 .46737 .1894 Mtetra
.709 .711 .85 r
.46737 .1894 .46839 .19093 .4702 .19013 .46918 .18843 Mtetra
.651 .664 .85 r
.46918 .18843 .4702 .19013 .47202 .18941 .471 .18776 Mtetra
.408 .551 .887 r
.471 .18776 .47202 .18941 .47383 .18866 .4728 .18805 Mtetra
.504 0 0 r
.4728 .18805 .47383 .18866 .47565 .18819 .47458 .18943 Mtetra
.82 .412 .274 r
.47458 .18943 .47565 .18819 .47745 .18838 .47633 .19329 Mtetra
.965 .674 .428 r
.47633 .19329 .47745 .18838 .4792 .19215 .47496 .39829 Mtetra
.525 .288 .498 r
.47496 .39829 .4792 .19215 .47798 .40103 .47681 .40434 Mtetra
.65 .276 .323 r
.47681 .40434 .47798 .40103 .47984 .40684 .47873 .40639 Mtetra
.16 .663 .908 r
.47873 .40639 .47984 .40684 .48178 .4075 .48068 .40649 Mtetra
.658 .804 .953 r
.48068 .40649 .48178 .4075 .48373 .40681 .48263 .40578 Mtetra
.737 .82 .916 r
.48263 .40578 .48373 .40681 .4857 .40562 .4846 .40469 Mtetra
.729 .84 .933 r
.4846 .40469 .4857 .40562 .48766 .40465 .48657 .40365 Mtetra
.724 .824 .927 r
.48657 .40365 .48766 .40465 .48963 .40381 .48853 .40264 Mtetra
.722 .791 .906 r
.48853 .40264 .48963 .40381 .49159 .40296 .4905 .40161 Mtetra
.695 .752 .896 r
.4905 .40161 .49159 .40296 .49356 .40213 .49247 .40072 Mtetra
.673 .735 .896 r
.49247 .40072 .49356 .40213 .49553 .40132 .49444 .39993 Mtetra
.658 .733 .904 r
.49444 .39993 .49553 .40132 .49749 .40056 .4964 .39922 Mtetra
.642 .736 .917 r
.4964 .39922 .49749 .40056 .49946 .39988 .49837 .39858 Mtetra
.628 .738 .926 r
.49837 .39858 .49946 .39988 .50143 .39928 .50034 .39801 Mtetra
.619 .741 .933 r
.50034 .39801 .50143 .39928 .5034 .3987 .50231 .39747 Mtetra
.539 .714 .953 r
.50231 .39747 .5034 .3987 .50537 .39856 .50428 .39721 Mtetra
.569 .705 .934 r
.50428 .39721 .50537 .39856 .50734 .3983 .50626 .39688 Mtetra
.672 .734 .897 r
.50626 .39688 .50734 .3983 .50932 .39734 .50824 .39609 Mtetra
.87 .799 .778 r
.50824 .39609 .50932 .39734 .51131 .39324 .51022 .39354 Mtetra
.992 .874 .605 r
.51022 .39354 .51131 .39324 .51404 .18515 .51222 .38799 Mtetra
0 0 .286 r
.51222 .38799 .51404 .18515 .51591 .17515 .51487 .18401 Mtetra
.125 0 .302 r
.51487 .18401 .51591 .17515 .51776 .17284 .51674 .17842 Mtetra
.436 .128 .343 r
.51674 .17842 .51776 .17284 .51961 .17212 .51859 .17778 Mtetra
.53 .211 .371 r
.51859 .17778 .51961 .17212 .52146 .17188 .52044 .17839 Mtetra
.505 .199 .381 r
.52044 .17839 .52146 .17188 .52331 .17146 .5223 .17861 Mtetra
.467 .173 .382 r
.5223 .17861 .52331 .17146 .52516 .17083 .52415 .17817 Mtetra
.467 .175 .385 r
.52415 .17817 .52516 .17083 .52701 .1702 .52601 .17771 Mtetra
.384 .108 .365 r
.52601 .17771 .52701 .1702 .52886 .16921 .52787 .17597 Mtetra
.387 .102 .354 r
.52787 .17597 .52886 .16921 .53071 .16825 .52973 .17446 Mtetra
.515 .204 .377 r
.52973 .17446 .53071 .16825 .53257 .16793 .53159 .17483 Mtetra
.966 .668 .411 r
.53159 .17483 .53257 .16793 .53444 .17058 .53403 .37582 Mtetra
.529 .291 .498 r
.53403 .37582 .53444 .17058 .5371 .37957 .53605 .3839 Mtetra
.663 .308 .359 r
.53605 .3839 .5371 .37957 .53912 .38691 .53806 .38662 Mtetra
0 .419 .692 r
.53806 .38662 .53912 .38691 .54113 .38815 .54006 .38714 Mtetra
.614 .792 .967 r
.54006 .38714 .54113 .38815 .54313 .38765 .54207 .38657 Mtetra
.697 .807 .933 r
.54207 .38657 .54313 .38765 .54513 .38664 .54407 .38567 Mtetra
.679 .823 .953 r
.54407 .38567 .54513 .38664 .54714 .38574 .54607 .38484 Mtetra
.638 .826 .973 r
.54607 .38484 .54714 .38574 .54914 .38506 .54808 .38416 Mtetra
.637 .827 .973 r
.54808 .38416 .54914 .38506 .55115 .38437 .55009 .38349 Mtetra
.636 .829 .975 r
.55009 .38349 .55115 .38437 .55316 .38369 .55209 .38281 Mtetra
.632 .828 .976 r
.55209 .38281 .55316 .38369 .55517 .38303 .55411 .38214 Mtetra
.621 .824 .978 r
.55411 .38214 .55517 .38303 .55718 .38238 .55612 .38152 Mtetra
.589 .817 .986 r
.55612 .38152 .55718 .38238 .55919 .38177 .55813 .38098 Mtetra
.554 .82 .995 r
.55813 .38098 .55919 .38177 .5612 .38118 .56015 .38052 Mtetra
.534 .837 .999 r
.56015 .38052 .5612 .38118 .56322 .3806 .56217 .38005 Mtetra
.541 .864 .995 r
.56217 .38005 .56322 .3806 .56524 .37998 .56419 .3795 Mtetra
.559 .883 .99 r
.56419 .3795 .56524 .37998 .56726 .37934 .56621 .37887 Mtetra
.567 .889 .988 r
.56621 .37887 .56726 .37934 .56928 .37868 .56823 .37821 Mtetra
.569 .889 .989 r
.56823 .37821 .56928 .37868 .5713 .37802 .57025 .37755 Mtetra
.567 .888 .989 r
.57025 .37755 .5713 .37802 .57332 .37736 .57228 .37689 Mtetra
.568 .889 .989 r
.57228 .37689 .57332 .37736 .57535 .3767 .5743 .37623 Mtetra
.569 .889 .988 r
.5743 .37623 .57535 .3767 .57737 .37604 .57633 .37557 Mtetra
.569 .89 .988 r
.57633 .37557 .57737 .37604 .5794 .37537 .57836 .3749 Mtetra
.57 .89 .988 r
.57836 .3749 .5794 .37537 .58143 .3747 .58039 .37423 Mtetra
.58039 .37423 .58143 .3747 .58346 .37403 .58242 .37356 Mtetra
.58242 .37356 .58346 .37403 .58549 .37336 .58446 .37289 Mtetra
.571 .89 .988 r
.58446 .37289 .58549 .37336 .58752 .37269 .58649 .37222 Mtetra
.571 .891 .988 r
.58649 .37222 .58752 .37269 .58956 .37202 .58853 .37154 Mtetra
.58853 .37154 .58956 .37202 .59159 .37134 .59056 .37087 Mtetra
.59056 .37087 .59159 .37134 .59363 .37067 .5926 .37019 Mtetra
.5926 .37019 .59363 .37067 .59567 .37 .59464 .36952 Mtetra
.59464 .36952 .59567 .37 .59771 .36932 .59669 .36884 Mtetra
.572 .891 .988 r
.59669 .36884 .59771 .36932 .59975 .36864 .59873 .36816 Mtetra
.59873 .36816 .59975 .36864 .6018 .36797 .60078 .36749 Mtetra
.60078 .36749 .6018 .36797 .60384 .36729 .60282 .36681 Mtetra
.60282 .36681 .60384 .36729 .60589 .36661 .60487 .36613 Mtetra
.60487 .36613 .60589 .36661 .60794 .36594 .60692 .36545 Mtetra
.572 .89 .988 r
.60692 .36545 .60794 .36594 .60999 .36526 .60897 .36477 Mtetra
.60897 .36477 .60999 .36526 .61204 .36458 .61102 .36409 Mtetra
.573 .89 .988 r
.61102 .36409 .61204 .36458 .61409 .3639 .61308 .36341 Mtetra
.61308 .36341 .61409 .3639 .61615 .36322 .61513 .36273 Mtetra
.574 .89 .988 r
.61513 .36273 .61615 .36322 .6182 .36254 .61719 .36204 Mtetra
.574 .891 .988 r
.61719 .36204 .6182 .36254 .62026 .36185 .61925 .36136 Mtetra
.575 .891 .988 r
.61925 .36136 .62026 .36185 .62232 .36117 .62131 .36067 Mtetra
.62131 .36067 .62232 .36117 .62438 .36048 .62337 .35998 Mtetra
.576 .891 .988 r
.62337 .35998 .62438 .36048 .62644 .35979 .62544 .35929 Mtetra
.577 .892 .988 r
.62544 .35929 .62644 .35979 .6285 .35909 .6275 .3586 Mtetra
.578 .893 .988 r
.6275 .3586 .6285 .35909 .63057 .35838 .62957 .3579 Mtetra
.576 .893 .987 r
.62957 .3579 .63057 .35838 .63263 .35767 .63163 .3572 Mtetra
.572 .894 .986 r
.63163 .3572 .63263 .35767 .6347 .35695 .6337 .3565 Mtetra
.578 .9 .984 r
.6337 .3565 .6347 .35695 .63677 .35622 .63577 .35577 Mtetra
.602 .911 .98 r
.63577 .35577 .63677 .35622 .63883 .35546 .63784 .35497 Mtetra
.646 .92 .977 r
.63784 .35497 .63883 .35546 .6409 .35467 .63991 .35407 Mtetra
.668 .906 .978 r
.63991 .35407 .6409 .35467 .64297 .35389 .64197 .35316 Mtetra
.665 .88 .978 r
.64197 .35316 .64297 .35389 .64505 .35311 .64404 .3523 Mtetra
.639 .854 .982 r
.64404 .3523 .64505 .35311 .64712 .35236 .64612 .35156 Mtetra
.627 .851 .985 r
.64612 .35156 .64712 .35236 .6492 .35163 .6482 .35085 Mtetra
.596 .845 .992 r
.6482 .35085 .6492 .35163 .65128 .35093 .65028 .35024 Mtetra
.541 .839 .999 r
.65028 .35024 .65128 .35093 .65336 .35029 .65237 .34974 Mtetra
.598 .892 .989 r
.65237 .34974 .65336 .35029 .65544 .34959 .65446 .349 Mtetra
.783 .935 .93 r
.65446 .349 .65544 .34959 .65752 .34872 .65651 .34759 Mtetra
.909 .835 .761 r
.65651 .34759 .65752 .34872 .65958 .34756 .6585 .34464 Mtetra
.858 .675 .654 r
.6585 .34464 .65958 .34756 .66165 .34633 .66043 .34015 Mtetra
.785 .56 .596 r
.66043 .34015 .66165 .34633 .66373 .34543 .66228 .33409 Mtetra
.525 .343 .577 r
.66228 .33409 .66373 .34543 .66584 .34527 .66439 .33404 Mtetra
.515 .336 .577 r
.66439 .33404 .66584 .34527 .66794 .34465 .66652 .33428 Mtetra
.666 .448 .578 r
.66652 .33428 .66794 .34465 .66996 .34246 .66844 .32992 Mtetra
.971 .667 .378 r
.66844 .32992 .66996 .34246 .67158 .33162 .66106 .12423 Mtetra
.525 .293 .505 r
.66106 .12423 .67158 .33162 .6638 .12174 .6628 .11903 Mtetra
.79 .647 .703 r
.6628 .11903 .6638 .12174 .66559 .11766 .66465 .11642 Mtetra
.711 .778 .904 r
.66465 .11642 .66559 .11766 .66752 .11657 .66659 .11547 Mtetra
.625 .773 .951 r
.66659 .11547 .66752 .11657 .66948 .11606 .66855 .11489 Mtetra
.616 .755 .944 r
.66855 .11489 .66948 .11606 .67144 .11571 .67051 .11436 Mtetra
.711 .757 .888 r
.67051 .11436 .67144 .11571 .67339 .1149 .67245 .11338 Mtetra
.67 .714 .881 r
.67245 .11338 .67339 .1149 .67534 .11412 .6744 .1126 Mtetra
.572 .668 .904 r
.6744 .1126 .67534 .11412 .67729 .11338 .67637 .11228 Mtetra
.103 .473 .894 r
.67637 .11228 .67729 .11338 .67924 .11256 .67841 .11304 Mtetra
.718 .201 0 r
.67841 .11304 .67924 .11256 .68122 .1122 .68052 .11521 Mtetra
.89 .522 .336 r
.68052 .11521 .68122 .1122 .68326 .11307 .68311 .12627 Mtetra
.966 .65 .36 r
.68311 .12627 .68326 .11307 .68581 .12315 .69611 .32842 Mtetra
.52 .283 .496 r
.69611 .32842 .68581 .12315 .69933 .33125 .69845 .33184 Mtetra
.59 .042 0 r
.69845 .33184 .69933 .33125 .70167 .33447 .70068 .33319 Mtetra
.354 .618 .951 r
.70068 .33319 .70167 .33447 .70384 .33476 .70285 .33346 Mtetra
.625 .754 .939 r
.70285 .33346 .70384 .33476 .70596 .33397 .70498 .33285 Mtetra
.845 .849 .847 r
.70498 .33285 .70596 .33397 .708 .33177 .70703 .33089 Mtetra
.989 .792 .547 r
.70703 .33089 .708 .33177 .70971 .32411 .70875 .32321 Mtetra
.976 .673 .334 r
.70875 .32321 .70971 .32411 .69911 .10941 .69817 .10772 Mtetra
.941 .758 .627 r
.69817 .10772 .69911 .10941 .70082 .10425 .69988 .10256 Mtetra
.714 .709 .844 r
.69988 .10256 .70082 .10425 .70276 .10306 .70183 .10147 Mtetra
.585 .665 .894 r
.70183 .10147 .70276 .10306 .70475 .10256 .70382 .1011 Mtetra
.507 .647 .919 r
.70382 .1011 .70475 .10256 .70676 .10235 .70584 .10101 Mtetra
.697 .757 .898 r
.70584 .10101 .70676 .10235 .70873 .10159 .7078 .1001 Mtetra
.666 .721 .89 r
.7078 .1001 .70873 .10159 .71071 .10085 .70978 .09934 Mtetra
.587 .681 .905 r
.70978 .09934 .71071 .10085 .71269 .10017 .71178 .09895 Mtetra
.195 .51 .912 r
.71178 .09895 .71269 .10017 .71466 .09934 .71385 .09961 Mtetra
.679 .136 0 r
.71385 .09961 .71466 .09934 .71667 .09894 .71601 .10158 Mtetra
.868 .481 .306 r
.71601 .10158 .71667 .09894 .71873 .09951 .71859 .1098 Mtetra
.968 .65 .336 r
.71859 .1098 .71873 .09951 .7213 .10741 .73438 .31572 Mtetra
.52 .283 .496 r
.73438 .31572 .7213 .10741 .7376 .318 .73682 .31939 Mtetra
.603 .116 .07 r
.73682 .31939 .7376 .318 .74004 .32161 .7391 .32075 Mtetra
.487 .784 .997 r
.7391 .32075 .74004 .32161 .74223 .3215 .74128 .32045 Mtetra
.696 .832 .948 r
.74128 .32045 .74223 .3215 .74437 .32064 .74342 .31949 Mtetra
.799 .844 .885 r
.74342 .31949 .74437 .32064 .74648 .31934 .74551 .31792 Mtetra
.855 .809 .804 r
.74551 .31792 .74648 .31934 .74864 .31869 .74755 .31563 Mtetra
.824 .657 .676 r
.74755 .31563 .74864 .31869 .75076 .31759 .7495 .31202 Mtetra
.851 .607 .569 r
.7495 .31202 .75076 .31759 .75282 .31555 .7511 .30369 Mtetra
.972 .66 .34 r
.7511 .30369 .75282 .31555 .75439 .30672 .73803 .09475 Mtetra
.524 .292 .505 r
.73803 .09475 .75439 .30672 .74083 .09382 .73972 .08978 Mtetra
.735 .563 .66 r
.73972 .08978 .74083 .09382 .74251 .08888 .74158 .08709 Mtetra
.669 .778 .931 r
.10245 .32395 .10364 .32486 .10524 .3241 .10403 .32334 Mtetra
.601 .796 .974 r
.10403 .32334 .10524 .3241 .10679 .32377 .10559 .32292 Mtetra
.575 .769 .971 r
.10559 .32292 .10679 .32377 .10831 .32366 .10714 .32259 Mtetra
.733 .759 .874 r
.10714 .32259 .10831 .32366 .10991 .3229 .10876 .32165 Mtetra
.683 .719 .876 r
.10876 .32165 .10991 .3229 .1115 .32224 .11036 .32095 Mtetra
.543 .664 .916 r
.11036 .32095 .1115 .32224 .11306 .32187 .11189 .32078 Mtetra
.859 .409 .032 r
.11189 .32078 .11306 .32187 .11448 .32249 .11307 .32332 Mtetra
.936 .68 .525 r
.11307 .32332 .11448 .32249 .11577 .32425 .08952 .51542 Mtetra
.549 .309 .505 r
.08952 .51542 .11577 .32425 .11654 .32992 .08909 .53115 Mtetra
.517 .282 .497 r
.08909 .53115 .11654 .32992 .09242 .52859 .09048 .53285 Mtetra
.529 .193 .342 r
.09048 .53285 .09242 .52859 .0935 .53276 .09203 .53333 Mtetra
.18 0 0 r
.09203 .53333 .0935 .53276 .09491 .53439 .09366 .53324 Mtetra
.633 .737 .923 r
.09366 .53324 .09491 .53439 .09656 .53413 .09535 .53273 Mtetra
.676 .708 .872 r
.09535 .53273 .09656 .53413 .09829 .53332 .09706 .53201 Mtetra
.693 .726 .876 r
.09706 .53201 .09829 .53332 .10004 .53228 .09879 .53121 Mtetra
.485 .702 .965 r
.09879 .53121 .10004 .53228 .1017 .53203 .10042 .53111 Mtetra
.555 .761 .974 r
.10042 .53111 .1017 .53203 .10336 .53172 .10209 .53081 Mtetra
.72 .8 .914 r
.10209 .53081 .10336 .53172 .10507 .53107 .10383 .52992 Mtetra
.881 .749 .712 r
.10383 .52992 .10507 .53107 .10693 .52921 .10591 .52629 Mtetra
.895 .673 .594 r
.10591 .52629 .10693 .52921 .10895 .52605 .10911 .5137 Mtetra
.927 .673 .533 r
.10911 .5137 .10895 .52605 .11143 .51914 .13536 .31527 Mtetra
.522 .291 .505 r
.13536 .31527 .11143 .51914 .13778 .31853 .13726 .31233 Mtetra
.629 .451 .622 r
.13726 .31233 .13778 .31853 .13995 .31337 .13898 .31074 Mtetra
.671 .572 .735 r
.13898 .31074 .13995 .31337 .1418 .31076 .14063 .30971 Mtetra
.675 .755 .911 r
.14063 .30971 .1418 .31076 .14344 .30982 .14224 .30907 Mtetra
.6 .801 .977 r
.14224 .30907 .14344 .30982 .14502 .30945 .14383 .30865 Mtetra
.566 .778 .978 r
.14383 .30865 .14502 .30945 .14657 .30933 .1454 .30832 Mtetra
.644 .755 .929 r
.1454 .30832 .14657 .30933 .14815 .30889 .147 .3078 Mtetra
.666 .744 .908 r
.147 .3078 .14815 .30889 .14976 .30832 .14861 .30719 Mtetra
.676 .739 .898 r
.14861 .30719 .14976 .30832 .15137 .30768 .15022 .30653 Mtetra
.745 .751 .856 r
.15022 .30653 .15137 .30768 .15302 .30671 .15189 .30546 Mtetra
.716 .73 .862 r
.15189 .30546 .15302 .30671 .15467 .30581 .15353 .30457 Mtetra
.607 .699 .909 r
.15353 .30457 .15467 .30581 .15628 .30523 .15512 .30419 Mtetra
.725 .223 0 r
.15512 .30419 .15628 .30523 .15777 .30566 .15644 .30603 Mtetra
.91 .593 .432 r
.15644 .30603 .15777 .30566 .15913 .30723 .15699 .31453 Mtetra
.933 .672 .519 r
.15699 .31453 .15913 .30723 .16016 .31169 .13514 .51491 Mtetra
.518 .283 .497 r
.13514 .51491 .16016 .31169 .13859 .51121 .13652 .51722 Mtetra
.53 .219 .384 r
.13652 .51722 .13859 .51121 .13963 .51644 .13811 .51776 Mtetra
.355 0 0 r
.13811 .51776 .13963 .51644 .14106 .51839 .13978 .51771 Mtetra
.298 .7 .976 r
.13978 .51771 .14106 .51839 .14266 .51886 .14143 .51776 Mtetra
.558 .726 .953 r
.14143 .51776 .14266 .51886 .14435 .51858 .14312 .51748 Mtetra
.719 .77 .893 r
.14312 .51748 .14435 .51858 .14611 .51772 .14488 .51656 Mtetra
.872 .757 .733 r
.14488 .51656 .14611 .51772 .14797 .51598 .1469 .51344 Mtetra
.888 .679 .614 r
.1469 .51344 .14797 .51598 .14996 .51308 .14954 .50473 Mtetra
.936 .679 .524 r
.14954 .50473 .14996 .51308 .15225 .50748 .17399 .30184 Mtetra
.523 .292 .505 r
.17399 .30184 .15225 .50748 .17629 .30657 .17594 .2983 Mtetra
.608 .416 .597 r
.17594 .2983 .17629 .30657 .17858 .3 .17769 .29664 Mtetra
.652 .527 .699 r
.17769 .29664 .17858 .3 .18047 .29705 .17937 .29556 Mtetra
.691 .688 .843 r
.17937 .29556 .18047 .29705 .18218 .29573 .18102 .29475 Mtetra
.674 .771 .923 r
.18102 .29475 .18218 .29573 .18381 .29507 .18265 .2941 Mtetra
.654 .768 .933 r
.18265 .2941 .18381 .29507 .18542 .29464 .18428 .29353 Mtetra
.749 .761 .862 r
.18428 .29353 .18542 .29464 .1871 .29359 .18596 .29245 Mtetra
.738 .756 .867 r
.18596 .29245 .1871 .29359 .18878 .29255 .18764 .29144 Mtetra
.618 .732 .928 r
.18764 .29144 .18878 .29255 .19039 .2921 .18925 .29101 Mtetra
.773 .289 0 r
.18925 .29101 .19039 .2921 .19172 .29435 .19059 .29316 Mtetra
.947 .684 .506 r
.19059 .29316 .19172 .29435 .17188 .49561 .17092 .49204 Mtetra
.979 .685 .372 r
.17092 .49204 .17188 .49561 .17234 .50706 .17116 .50557 Mtetra
0 .218 .734 r
.17116 .50557 .17234 .50706 .17391 .50817 .17271 .50677 Mtetra
.678 .714 .875 r
.17271 .50677 .17391 .50817 .17567 .50736 .17447 .50602 Mtetra
.771 .743 .827 r
.17447 .50602 .17567 .50736 .17751 .50588 .17631 .5046 Mtetra
.745 .748 .854 r
.17631 .5046 .17751 .50588 .17933 .50466 .17812 .50344 Mtetra
.701 .748 .888 r
.17812 .50344 .17933 .50466 .18111 .50377 .17989 .50259 Mtetra
.687 .752 .902 r
.17989 .50259 .18111 .50377 .18288 .50296 .18166 .50183 Mtetra
.643 .75 .926 r
.18166 .50183 .18288 .50296 .18463 .50232 .18341 .50126 Mtetra
.598 .751 .95 r
.18341 .50126 .18463 .50232 .18638 .50183 .18514 .50085 Mtetra
.571 .759 .966 r
.18514 .50085 .18638 .50183 .18811 .50142 .18687 .5005 Mtetra
.401 .701 .982 r
.18687 .5005 .18811 .50142 .18982 .50128 .18857 .5005 Mtetra
.414 .739 .992 r
.18857 .5005 .18982 .50128 .19153 .50113 .19027 .50042 Mtetra
.66 .841 .97 r
.19027 .50042 .19153 .50113 .19328 .50062 .19204 .49974 Mtetra
.885 .796 .756 r
.19204 .49974 .19328 .50062 .19512 .49915 .19402 .49688 Mtetra
.905 .691 .602 r
.19402 .49688 .19512 .49915 .1971 .49633 .1967 .48705 Mtetra
.939 .679 .515 r
.1967 .48705 .1971 .49633 .19937 .49051 .21831 .28518 Mtetra
.523 .292 .505 r
.21831 .28518 .19937 .49051 .22075 .28915 .22026 .28149 Mtetra
.616 .427 .603 r
.22026 .28149 .22075 .28915 .22295 .28302 .22203 .27978 Mtetra
.66 .538 .705 r
.22203 .27978 .22295 .28302 .22483 .28008 .22373 .27865 Mtetra
.682 .698 .859 r
.22373 .27865 .22483 .28008 .22656 .27872 .2254 .27791 Mtetra
.624 .8 .967 r
.2254 .27791 .22656 .27872 .2282 .27822 .22705 .27741 Mtetra
.578 .786 .978 r
.22705 .27741 .2282 .27822 .22982 .27802 .22868 .27704 Mtetra
.685 .778 .922 r
.22868 .27704 .22982 .27802 .23147 .27753 .23035 .27633 Mtetra
.707 .742 .879 r
.23035 .27633 .23147 .27753 .23314 .2768 .23203 .27549 Mtetra
.619 .696 .899 r
.23203 .27549 .23314 .2768 .23479 .27628 .23367 .27505 Mtetra
0 .204 .711 r
.23367 .27505 .23479 .27628 .23638 .27643 .23517 .27618 Mtetra
.915 .551 .328 r
.23517 .27618 .23638 .27643 .23787 .27761 .23627 .28165 Mtetra
.945 .677 .499 r
.23627 .28165 .23787 .27761 .23919 .2808 .21906 .48525 Mtetra
.521 .285 .498 r
.21906 .48525 .23919 .2808 .22251 .48056 .22043 .48897 Mtetra
.541 .248 .418 r
.22043 .48897 .22251 .48056 .22354 .48811 .22208 .48983 Mtetra
.438 0 .096 r
.22208 .48983 .22354 .48811 .22505 .49053 .22379 .48996 Mtetra
.465 .807 .999 r
.22379 .48996 .22505 .49053 .22672 .4911 .22554 .48969 Mtetra
.629 .699 .896 r
.22554 .48969 .22672 .4911 .22849 .49063 .22732 .48917 Mtetra
.659 .702 .878 r
.22732 .48917 .22849 .49063 .23029 .48983 .22911 .4885 Mtetra
.608 .707 .914 r
.22911 .4885 .23029 .48983 .23208 .4892 .23088 .48807 Mtetra
.564 .728 .951 r
.23088 .48807 .23208 .4892 .23385 .48878 .23264 .48776 Mtetra
.684 .787 .928 r
.23264 .48776 .23385 .48878 .23564 .48809 .23444 .48701 Mtetra
.851 .786 .787 r
.23444 .48701 .23564 .48809 .2375 .48668 .23637 .48473 Mtetra
.893 .705 .642 r
.23637 .48473 .2375 .48668 .23946 .4841 .23863 .47867 Mtetra
.948 .684 .503 r
.23863 .47867 .23946 .4841 .24159 .47955 .2581 .27289 Mtetra
.528 .295 .506 r
.2581 .27289 .24159 .47955 .2604 .27926 .26021 .2673 Mtetra
.594 .387 .571 r
.26021 .2673 .2604 .27926 .2629 .26907 .26201 .26525 Mtetra
.657 .516 .68 r
.26201 .26525 .2629 .26907 .26482 .26558 .26375 .26394 Mtetra
.697 .676 .826 r
.26375 .26394 .26482 .26558 .2666 .26383 .26546 .26303 Mtetra
.67 .818 .954 r
.26546 .26303 .2666 .26383 .26829 .26308 .26714 .26237 Mtetra
.612 .824 .982 r
.26714 .26237 .26829 .26308 .26996 .26266 .26882 .26187 Mtetra
.607 .802 .975 r
.26882 .26187 .26996 .26266 .27162 .26233 .27049 .26141 Mtetra
.628 .779 .953 r
.27049 .26141 .27162 .26233 .27328 .26191 .27217 .2609 Mtetra
.638 .764 .939 r
.27217 .2609 .27328 .26191 .27496 .26147 .27384 .26037 Mtetra
.666 .753 .915 r
.27384 .26037 .27496 .26147 .27664 .26089 .27553 .25973 Mtetra
.692 .75 .896 r
.27553 .25973 .27664 .26089 .27834 .26012 .27723 .25897 Mtetra
.696 .753 .896 r
.27723 .25897 .27834 .26012 .28004 .25931 .27894 .25819 Mtetra
.717 .763 .889 r
.27894 .25819 .28004 .25931 .28175 .25846 .28065 .2573 Mtetra
.722 .757 .88 r
.28065 .2573 .28175 .25846 .28346 .25764 .28237 .25637 Mtetra
.639 .714 .902 r
.28237 .25637 .28346 .25764 .28515 .25706 .28405 .25584 Mtetra
.056 .417 .865 r
.28405 .25584 .28515 .25706 .28678 .25721 .28564 .25657 Mtetra
.912 .517 .23 r
.28564 .25657 .28678 .25721 .28831 .2587 .28694 .26107 Mtetra
.952 .68 .484 r
.28694 .26107 .28831 .2587 .28972 .26187 .27288 .46605 Mtetra
.522 .286 .498 r
.27288 .46605 .28972 .26187 .29101 .26671 .27433 .47027 Mtetra
.512 .278 .496 r
.27433 .47027 .29101 .26671 .29276 .26541 .27612 .46999 Mtetra
.511 .277 .495 r
.27612 .46999 .29276 .26541 .2945 .26434 .27795 .46907 Mtetra
.512 .278 .496 r
.27795 .46907 .2945 .26434 .28201 .45529 .27975 .46869 Mtetra
.528 .256 .445 r
.27975 .46869 .28201 .45529 .2829 .46721 .28147 .46945 Mtetra
.529 .121 .211 r
.28147 .46945 .2829 .46721 .28444 .47043 .2832 .47 Mtetra
.014 .561 .833 r
.2832 .47 .28444 .47043 .28613 .47165 .28496 .47027 Mtetra
.504 .657 .929 r
.28496 .47027 .28613 .47165 .28791 .47161 .28675 .47019 Mtetra
.65 .71 .891 r
.28675 .47019 .28791 .47161 .28973 .47097 .28857 .46956 Mtetra
.806 .749 .799 r
.28857 .46956 .28973 .47097 .29162 .46955 .29049 .46769 Mtetra
.891 .714 .657 r
.29049 .46769 .29162 .46955 .29359 .4668 .29264 .46248 Mtetra
.954 .686 .489 r
.29264 .46248 .29359 .4668 .29567 .46258 .30885 .25674 Mtetra
.532 .299 .507 r
.30885 .25674 .29567 .46258 .29783 .45718 .31104 .24932 Mtetra
.517 .286 .504 r
.31104 .24932 .29783 .45718 .29964 .4567 .31278 .24828 Mtetra
.515 .285 .504 r
.31278 .24828 .29964 .4567 .30144 .45647 .31448 .24795 Mtetra
.516 .286 .504 r
.31448 .24795 .30144 .45647 .30365 .45014 .3162 .24722 Mtetra
.519 .288 .504 r
.3162 .24722 .30365 .45014 .31885 .25011 .31801 .24525 Mtetra
.659 .492 .648 r
.31801 .24525 .31885 .25011 .32084 .24548 .3198 .24351 Mtetra
.724 .654 .78 r
.3198 .24351 .32084 .24548 .32266 .24319 .32156 .24224 Mtetra
.663 .788 .941 r
.32156 .24224 .32266 .24319 .32439 .24247 .32328 .2416 Mtetra
.617 .793 .966 r
.32328 .2416 .32439 .24247 .32609 .24211 .32499 .24111 Mtetra
.635 .769 .944 r
.32499 .24111 .32609 .24211 .32779 .24175 .3267 .24057 Mtetra
.693 .752 .897 r
.3267 .24057 .32779 .24175 .32952 .24095 .32844 .23979 Mtetra
.698 .756 .897 r
.32844 .23979 .32952 .24095 .33126 .24012 .33017 .23899 Mtetra
.71 .764 .894 r
.33017 .23899 .33126 .24012 .33299 .23927 .33191 .23812 Mtetra
.732 .766 .88 r
.33191 .23812 .33299 .23927 .33473 .2384 .33366 .23713 Mtetra
.661 .726 .897 r
.33366 .23713 .33473 .2384 .33646 .23775 .33538 .23649 Mtetra
.363 .595 .935 r
.33538 .23649 .33646 .23775 .33816 .23757 .33706 .23673 Mtetra
.853 .398 .024 r
.33706 .23673 .33816 .23757 .3398 .23844 .33856 .23985 Mtetra
.958 .681 .468 r
.33856 .23985 .3398 .23844 .34135 .2407 .328 .44303 Mtetra
.531 .293 .499 r
.328 .44303 .34135 .2407 .34237 .25212 .32928 .4518 Mtetra
.516 .281 .496 r
.32928 .4518 .34237 .25212 .33242 .45024 .33102 .45316 Mtetra
.502 .122 .251 r
.33102 .45316 .33242 .45024 .33404 .45357 .33281 .45351 Mtetra
.164 .701 .817 r
.33281 .45351 .33404 .45357 .33579 .45476 .33464 .45333 Mtetra
.615 .7 .904 r
.33464 .45333 .33579 .45476 .33763 .45444 .33649 .45285 Mtetra
.654 .689 .87 r
.33649 .45285 .33763 .45444 .3395 .45371 .33836 .45218 Mtetra
.653 .698 .879 r
.33836 .45218 .3395 .45371 .34137 .45286 .34022 .45152 Mtetra
.548 .688 .931 r
.34022 .45152 .34137 .45286 .34322 .45244 .34206 .45128 Mtetra
.642 .757 .932 r
.34206 .45128 .34322 .45244 .34508 .4518 .34392 .45068 Mtetra
.793 .796 .854 r
.34392 .45068 .34508 .4518 .34697 .45065 .34583 .44918 Mtetra
.909 .744 .665 r
.34583 .44918 .34697 .45065 .34895 .44796 .34793 .44423 Mtetra
.96 .687 .474 r
.34793 .44423 .34895 .44796 .351 .44386 .36076 .23895 Mtetra
.535 .301 .507 r
.36076 .23895 .351 .44386 .35317 .43736 .36296 .22986 Mtetra
.517 .286 .504 r
.36296 .22986 .35317 .43736 .35502 .437 .36474 .22872 Mtetra
.515 .285 .504 r
.36474 .22872 .35502 .437 .35684 .43716 .36647 .22834 Mtetra
.36647 .22834 .35684 .43716 .35884 .43384 .36821 .22795 Mtetra
.519 .288 .504 r
.36821 .22795 .35884 .43384 .37088 .23157 .37003 .22601 Mtetra
.646 .472 .634 r
.37003 .22601 .37088 .23157 .37285 .22645 .37183 .22425 Mtetra
.727 .638 .76 r
.37183 .22425 .37285 .22645 .3747 .22375 .37362 .22283 Mtetra
.691 .807 .937 r
.37362 .22283 .3747 .22375 .37647 .22279 .37538 .22207 Mtetra
.63 .833 .979 r
.37538 .22207 .37647 .22279 .37822 .22225 .37713 .22149 Mtetra
.598 .815 .983 r
.37713 .22149 .37822 .22225 .37996 .22193 .37888 .22101 Mtetra
.627 .789 .96 r
.37888 .22101 .37996 .22193 .3817 .22147 .38063 .22048 Mtetra
.629 .775 .951 r
.38063 .22048 .3817 .22147 .38345 .22103 .38238 .21995 Mtetra
.638 .759 .936 r
.38238 .21995 .38345 .22103 .3852 .22057 .38414 .2194 Mtetra
.659 .748 .916 r
.38414 .2194 .3852 .22057 .38696 .21998 .3859 .21877 Mtetra
.669 .743 .906 r
.3859 .21877 .38696 .21998 .38872 .21933 .38766 .21809 Mtetra
.679 .741 .897 r
.38766 .21809 .38872 .21933 .39048 .2186 .38942 .21735 Mtetra
.696 .745 .889 r
.38942 .21735 .39048 .2186 .39225 .21776 .3912 .21653 Mtetra
.698 .749 .891 r
.3912 .21653 .39225 .21776 .39403 .2169 .39297 .2157 Mtetra
.697 .754 .896 r
.39297 .2157 .39403 .2169 .3958 .21606 .39474 .21488 Mtetra
.741 .77 .876 r
.39474 .21488 .3958 .21606 .39758 .21513 .39652 .21381 Mtetra
.68 .729 .887 r
.39652 .21381 .39758 .21513 .39935 .2144 .3983 .21306 Mtetra
.533 .667 .923 r
.3983 .21306 .39935 .2144 .4011 .21403 .40004 .2129 Mtetra
.766 .297 0 r
.40004 .2129 .4011 .21403 .4028 .2151 .40168 .21568 Mtetra
.965 .682 .447 r
.40168 .21568 .4028 .2151 .40446 .21741 .39542 .4158 Mtetra
.54 .3 .5 r
.39542 .4158 .40446 .21741 .40599 .22297 .39677 .42887 Mtetra
.514 .279 .496 r
.39677 .42887 .40599 .22297 .40765 .22544 .39863 .42923 Mtetra
.511 .277 .495 r
.39863 .42923 .40765 .22544 .40947 .22371 .40054 .42845 Mtetra
.51 .276 .495 r
.40054 .42845 .40947 .22371 .41134 .22065 .40247 .42708 Mtetra
.511 .277 .495 r
.40247 .42708 .41134 .22065 .4132 .2181 .40438 .42614 Mtetra
.512 .277 .495 r
.40438 .42614 .4132 .2181 .41499 .21703 .40629 .42539 Mtetra
.512 .278 .496 r
.40629 .42539 .41499 .21703 .4167 .21851 .40818 .42503 Mtetra
.515 .279 .496 r
.40818 .42503 .4167 .21851 .41137 .42113 .41004 .42583 Mtetra
.538 .2 .343 r
.41004 .42583 .41137 .42113 .41308 .4262 .4119 .42653 Mtetra
.34 0 0 r
.4119 .42653 .41308 .4262 .4149 .42825 .41378 .4269 Mtetra
.597 .712 .924 r
.41378 .4269 .4149 .42825 .4168 .42811 .41568 .42648 Mtetra
.646 .684 .872 r
.41568 .42648 .4168 .42811 .41871 .42745 .4176 .42583 Mtetra
.66 .693 .869 r
.4176 .42583 .41871 .42745 .42063 .42656 .41952 .4251 Mtetra
.615 .699 .904 r
.41952 .4251 .42063 .42656 .42254 .42608 .42143 .4246 Mtetra
.611 .696 .904 r
.42143 .4246 .42254 .42608 .42446 .42562 .42334 .42412 Mtetra
.621 .697 .898 r
.42334 .42412 .42446 .42562 .42637 .4251 .42526 .4236 Mtetra
.577 .677 .908 r
.42526 .4236 .42637 .4251 .42829 .42457 .42717 .42326 Mtetra
.644 .738 .918 r
.42717 .42326 .42829 .42457 .43021 .42382 .42909 .42264 Mtetra
.753 .79 .883 r
.42909 .42264 .43021 .42382 .43215 .42273 .43103 .42142 Mtetra
.91 .773 .697 r
.43103 .42142 .43215 .42273 .43413 .4203 .43305 .41742 Mtetra
.935 .691 .545 r
.43305 .41742 .43413 .4203 .43613 .41659 .43536 .40299 Mtetra
.957 .674 .459 r
.43536 .40299 .43613 .41659 .43821 .41033 .44275 .20089 Mtetra
.518 .288 .504 r
.44275 .20089 .43821 .41033 .44017 .40836 .44459 .19899 Mtetra
.515 .285 .504 r
.44459 .19899 .44017 .40836 .44207 .4086 .44638 .19844 Mtetra
.44638 .19844 .44207 .4086 .44401 .40737 .44818 .1982 Mtetra
.518 .287 .504 r
.44818 .1982 .44401 .40737 .45089 .20389 .45001 .19645 Mtetra
.621 .432 .606 r
.45001 .19645 .45089 .20389 .45284 .19744 .45184 .19461 Mtetra
.708 .591 .723 r
.45184 .19461 .45284 .19744 .4547 .19426 .45367 .19306 Mtetra
.697 .759 .9 r
.45367 .19306 .4547 .19426 .45652 .19312 .45548 .19223 Mtetra
.625 .801 .967 r
.45548 .19223 .45652 .19312 .45832 .19262 .45728 .19167 Mtetra
.597 .779 .967 r
.45728 .19167 .45832 .19262 .46012 .19238 .45908 .19122 Mtetra
.652 .753 .924 r
.45908 .19122 .46012 .19238 .46192 .19185 .46089 .1906 Mtetra
.669 .743 .906 r
.46089 .1906 .46192 .19185 .46373 .19118 .4627 .1899 Mtetra
.677 .74 .898 r
.4627 .1899 .46373 .19118 .46555 .19044 .46452 .18915 Mtetra
.744 .758 .864 r
.46452 .18915 .46555 .19044 .46737 .1894 .46634 .18801 Mtetra
.717 .735 .866 r
.46634 .18801 .46737 .1894 .46918 .18843 .46816 .18703 Mtetra
.62 .698 .9 r
.46816 .18703 .46918 .18843 .471 .18776 .46997 .18654 Mtetra
0 .112 .634 r
.46997 .18654 .471 .18776 .4728 .18805 .47175 .18812 Mtetra
.915 .53 .267 r
.47175 .18812 .4728 .18805 .47458 .18943 .47344 .1947 Mtetra
.965 .673 .429 r
.47344 .1947 .47458 .18943 .47633 .19329 .47185 .40178 Mtetra
.519 .283 .497 r
.47185 .40178 .47633 .19329 .47496 .39829 .47375 .40462 Mtetra
.531 .215 .378 r
.47375 .40462 .47496 .39829 .47681 .40434 .47568 .40529 Mtetra
.291 0 0 r
.47568 .40529 .47681 .40434 .47873 .40639 .47763 .40523 Mtetra
.603 .753 .95 r
.47763 .40523 .47873 .40639 .48068 .40649 .47958 .40474 Mtetra
.662 .68 .857 r
.47958 .40474 .48068 .40649 .48263 .40578 .48154 .40398 Mtetra
.688 .684 .841 r
.48154 .40398 .48263 .40578 .4846 .40469 .48351 .40302 Mtetra
.692 .703 .855 r
.48351 .40302 .4846 .40469 .48657 .40365 .48547 .40208 Mtetra
.695 .717 .866 r
.48547 .40208 .48657 .40365 .48853 .40264 .48744 .40114 Mtetra
.696 .729 .876 r
.48744 .40114 .48853 .40264 .4905 .40161 .48941 .40021 Mtetra
.681 .738 .894 r
.48941 .40021 .4905 .40161 .49247 .40072 .49138 .39938 Mtetra
.665 .744 .909 r
.49138 .39938 .49247 .40072 .49444 .39993 .49334 .39864 Mtetra
.651 .748 .921 r
.49334 .39864 .49444 .39993 .4964 .39922 .49531 .39796 Mtetra
.635 .749 .931 r
.49531 .39796 .4964 .39922 .49837 .39858 .49728 .39736 Mtetra
.622 .75 .938 r
.49728 .39736 .49837 .39858 .50034 .39801 .49925 .3968 Mtetra
.612 .75 .943 r
.49925 .3968 .50034 .39801 .50231 .39747 .50123 .39628 Mtetra
.577 .74 .953 r
.50123 .39628 .50231 .39747 .50428 .39721 .5032 .39589 Mtetra
.59 .719 .933 r
.5032 .39589 .50428 .39721 .50626 .39688 .50517 .39547 Mtetra
.636 .723 .911 r
.50517 .39547 .50626 .39688 .50824 .39609 .50715 .39486 Mtetra
.755 .792 .883 r
.50715 .39486 .50824 .39609 .51022 .39354 .50913 .39361 Mtetra
.8 .998 .853 r
.50913 .39361 .51022 .39354 .51222 .38799 .51112 .39186 Mtetra
.202 0 .186 r
.51112 .39186 .51222 .38799 .51487 .18401 .5131 .38992 Mtetra
.511 .276 .495 r
.5131 .38992 .51487 .18401 .51674 .17842 .51508 .3887 Mtetra
.512 .277 .496 r
.51508 .3887 .51674 .17842 .51859 .17778 .51707 .38817 Mtetra
.512 .278 .496 r
.51707 .38817 .51859 .17778 .52044 .17839 .51905 .38786 Mtetra
.512 .277 .496 r
.51905 .38786 .52044 .17839 .5223 .17861 .52104 .38741 Mtetra
.512 .277 .495 r
.52104 .38741 .5223 .17861 .52415 .17817 .52302 .38682 Mtetra
.52302 .38682 .52415 .17817 .52601 .17771 .52501 .3862 Mtetra
.52501 .3862 .52601 .17771 .52787 .17597 .527 .38539 Mtetra
.511 .277 .495 r
.527 .38539 .52787 .17597 .52973 .17446 .52899 .38457 Mtetra
.512 .277 .496 r
.52899 .38457 .52973 .17446 .53159 .17483 .53099 .38405 Mtetra
.514 .279 .496 r
.53099 .38405 .53159 .17483 .53403 .37582 .53298 .38446 Mtetra
.53 .233 .408 r
.53298 .38446 .53403 .37582 .53605 .3839 .53498 .38519 Mtetra
.471 0 .014 r
.53498 .38519 .53605 .3839 .53806 .38662 .53699 .38565 Mtetra
.48 .744 .986 r
.53699 .38565 .53806 .38662 .54006 .38714 .53899 .38546 Mtetra
.639 .684 .876 r
.53899 .38546 .54006 .38714 .54207 .38657 .54099 .38481 Mtetra
.663 .684 .86 r
.54099 .38481 .54207 .38657 .54407 .38567 .543 .38403 Mtetra
.659 .698 .875 r
.543 .38403 .54407 .38567 .54607 .38484 .545 .38328 Mtetra
.647 .705 .889 r
.545 .38328 .54607 .38484 .54808 .38416 .54701 .3826 Mtetra
.645 .705 .89 r
.54701 .3826 .54808 .38416 .55009 .38349 .54902 .38194 Mtetra
.644 .706 .892 r
.54902 .38194 .55009 .38349 .55209 .38281 .55103 .38127 Mtetra
.642 .708 .895 r
.55103 .38127 .55209 .38281 .55411 .38214 .55304 .38062 Mtetra
.636 .708 .898 r
.55304 .38062 .55411 .38214 .55612 .38152 .55505 .38 Mtetra
.621 .702 .903 r
.55505 .38 .55612 .38152 .55813 .38098 .55707 .37945 Mtetra
.609 .695 .904 r
.55707 .37945 .55813 .38098 .56015 .38052 .55908 .37896 Mtetra
.61 .691 .9 r
.55908 .37896 .56015 .38052 .56217 .38005 .5611 .37846 Mtetra
.623 .692 .893 r
.5611 .37846 .56217 .38005 .56419 .3795 .56312 .3779 Mtetra
.636 .696 .889 r
.56312 .3779 .56419 .3795 .56621 .37887 .56515 .37728 Mtetra
.64 .699 .888 r
.56515 .37728 .56621 .37887 .56823 .37821 .56717 .37663 Mtetra
.641 .701 .89 r
.56717 .37663 .56823 .37821 .57025 .37755 .56919 .37597 Mtetra
.641 .703 .891 r
.56919 .37597 .57025 .37755 .57228 .37689 .57122 .37532 Mtetra
.642 .704 .891 r
.57122 .37532 .57228 .37689 .5743 .37623 .57324 .37466 Mtetra
.643 .705 .892 r
.57324 .37466 .5743 .37623 .57633 .37557 .57527 .374 Mtetra
.644 .706 .892 r
.57527 .374 .57633 .37557 .57836 .3749 .5773 .37333 Mtetra
.5773 .37333 .57836 .3749 .58039 .37423 .57933 .37267 Mtetra
.57933 .37267 .58039 .37423 .58242 .37356 .58137 .372 Mtetra
.645 .707 .892 r
.58137 .372 .58242 .37356 .58446 .37289 .5834 .37132 Mtetra
.5834 .37132 .58446 .37289 .58649 .37222 .58544 .37065 Mtetra
.58544 .37065 .58649 .37222 .58853 .37154 .58747 .36998 Mtetra
.58747 .36998 .58853 .37154 .59056 .37087 .58951 .3693 Mtetra
.58951 .3693 .59056 .37087 .5926 .37019 .59155 .36863 Mtetra
.59155 .36863 .5926 .37019 .59464 .36952 .59359 .36795 Mtetra
.59359 .36795 .59464 .36952 .59669 .36884 .59564 .36727 Mtetra
.59564 .36727 .59669 .36884 .59873 .36816 .59768 .36659 Mtetra
.59768 .36659 .59873 .36816 .60078 .36749 .59973 .36591 Mtetra
.59973 .36591 .60078 .36749 .60282 .36681 .60177 .36524 Mtetra
.60177 .36524 .60282 .36681 .60487 .36613 .60382 .36456 Mtetra
.60382 .36456 .60487 .36613 .60692 .36545 .60587 .36388 Mtetra
.60587 .36388 .60692 .36545 .60897 .36477 .60793 .36319 Mtetra
.60793 .36319 .60897 .36477 .61102 .36409 .60998 .36251 Mtetra
.60998 .36251 .61102 .36409 .61308 .36341 .61203 .36183 Mtetra
.61203 .36183 .61308 .36341 .61513 .36273 .61409 .36115 Mtetra
.646 .707 .892 r
.61409 .36115 .61513 .36273 .61719 .36204 .61615 .36046 Mtetra
.61615 .36046 .61719 .36204 .61925 .36136 .61821 .35978 Mtetra
.61821 .35978 .61925 .36136 .62131 .36067 .62027 .35909 Mtetra
.62027 .35909 .62131 .36067 .62337 .35998 .62233 .3584 Mtetra
.647 .707 .891 r
.62233 .3584 .62337 .35998 .62544 .35929 .6244 .35771 Mtetra
.647 .708 .891 r
.6244 .35771 .62544 .35929 .6275 .3586 .62646 .35701 Mtetra
.648 .708 .891 r
.62646 .35701 .6275 .3586 .62957 .3579 .62853 .35631 Mtetra
.648 .708 .892 r
.62853 .35631 .62957 .3579 .63163 .3572 .6306 .35561 Mtetra
.648 .709 .892 r
.6306 .35561 .63163 .3572 .6337 .3565 .63267 .35491 Mtetra
.651 .71 .891 r
.63267 .35491 .6337 .3565 .63577 .35577 .63474 .35419 Mtetra
.66 .715 .889 r
.63474 .35419 .63577 .35577 .63784 .35497 .63681 .35343 Mtetra
.672 .726 .89 r
.63681 .35343 .63784 .35497 .63991 .35407 .63888 .3526 Mtetra
.675 .738 .898 r
.63888 .3526 .63991 .35407 .64197 .35316 .64095 .35176 Mtetra
.668 .749 .911 r
.64095 .35176 .64197 .35316 .64404 .3523 .64302 .35097 Mtetra
.652 .754 .925 r
.64302 .35097 .64404 .3523 .64612 .35156 .6451 .35025 Mtetra
.647 .757 .929 r
.6451 .35025 .64612 .35156 .6482 .35085 .64718 .34956 Mtetra
.616 .746 .939 r
.64718 .34956 .6482 .35085 .65028 .35024 .64927 .34899 Mtetra
.562 .733 .955 r
.64927 .34899 .65028 .35024 .65237 .34974 .65136 .34863 Mtetra
.659 .8 .951 r
.65136 .34863 .65237 .34974 .65446 .349 .65345 .34787 Mtetra
.84 .839 .844 r
.65345 .34787 .65446 .349 .65651 .34759 .65548 .34593 Mtetra
.944 .762 .627 r
.65548 .34593 .65651 .34759 .6585 .34464 .65736 .3403 Mtetra
.976 .675 .365 r
.65736 .3403 .6585 .34464 .66043 .34015 .6505 .12922 Mtetra
.529 .295 .505 r
.6505 .12922 .66043 .34015 .66228 .33409 .65217 .12215 Mtetra
.516 .286 .504 r
.65217 .12215 .66228 .33409 .66439 .33404 .65409 .12108 Mtetra
.515 .285 .504 r
.65409 .12108 .66439 .33404 .66652 .33428 .65606 .12075 Mtetra
.65606 .12075 .66652 .33428 .66844 .32992 .65801 .12019 Mtetra
.518 .287 .504 r
.65801 .12019 .66844 .32992 .66106 .12423 .6599 .1183 Mtetra
.635 .46 .629 r
.6599 .1183 .66106 .12423 .6628 .11903 .6618 .11656 Mtetra
.709 .623 .759 r
.6618 .11656 .6628 .11903 .66465 .11642 .66372 .11518 Mtetra
.682 .768 .916 r
.66372 .11518 .66465 .11642 .66659 .11547 .66566 .11438 Mtetra
.647 .785 .947 r
.66566 .11438 .66659 .11547 .66855 .11489 .66762 .11371 Mtetra
.665 .774 .93 r
.66762 .11371 .66855 .11489 .67051 .11436 .66957 .11298 Mtetra
.736 .763 .874 r
.66957 .11298 .67051 .11436 .67245 .11338 .6715 .11185 Mtetra
.669 .712 .88 r
.6715 .11185 .67245 .11338 .6744 .1126 .67345 .11107 Mtetra
.447 .601 .911 r
.67345 .11107 .6744 .1126 .67637 .11228 .67545 .11121 Mtetra
.696 .234 0 r
.67545 .11121 .67637 .11228 .67841 .11304 .67763 .11464 Mtetra
.973 .662 .333 r
.67763 .11464 .67841 .11304 .68052 .11521 .69064 .32363 Mtetra
.526 .288 .497 r
.69064 .32363 .68052 .11521 .68311 .12627 .69316 .33082 Mtetra
.515 .279 .496 r
.69316 .33082 .68311 .12627 .69611 .32842 .69537 .3319 Mtetra
.478 .107 .257 r
.69537 .3319 .69611 .32842 .69845 .33184 .69754 .33206 Mtetra
.006 0 0 r
.69754 .33206 .69845 .33184 .70068 .33319 .69969 .33187 Mtetra
.439 .656 .952 r
.69969 .33187 .70068 .33319 .70285 .33346 .70185 .33192 Mtetra
.624 .71 .908 r
.70185 .33192 .70285 .33346 .70498 .33285 .70398 .33133 Mtetra
.807 .78 .828 r
.70398 .33133 .70498 .33285 .70703 .33089 .70604 .32949 Mtetra
.974 .77 .566 r
.70604 .32949 .70703 .33089 .70875 .32321 .70777 .32205 Mtetra
.976 .672 .335 r
.70777 .32205 .70875 .32321 .69817 .10772 .69727 .10675 Mtetra
.976 .81 .612 r
.69727 .10675 .69817 .10772 .69988 .10256 .69897 .10146 Mtetra
.751 .82 .906 r
.69897 .10146 .69988 .10256 .70183 .10147 .70092 .10029 Mtetra
.591 .745 .95 r
.70092 .10029 .70183 .10147 .70382 .1011 .70291 .09985 Mtetra
.518 .695 .949 r
.70291 .09985 .70382 .1011 .70584 .10101 .70492 .09966 Mtetra
.728 .768 .885 r
.70492 .09966 .70584 .10101 .7078 .1001 .70688 .09858 Mtetra
.668 .715 .884 r
.70688 .09858 .7078 .1001 .70978 .09934 .70885 .0978 Mtetra
.504 .632 .91 r
.70885 .0978 .70978 .09934 .71178 .09895 .71087 .09774 Mtetra
.578 .128 0 r
.71087 .09774 .71178 .09895 .71385 .09961 .7131 .10077 Mtetra
.972 .658 .312 r
.7131 .10077 .71385 .09961 .71601 .10158 .72865 .30854 Mtetra
.529 .29 .497 r
.72865 .30854 .71601 .10158 .71859 .1098 .73145 .31783 Mtetra
.515 .28 .496 r
.73145 .31783 .71859 .1098 .73438 .31572 .73373 .31919 Mtetra
.491 .117 .258 r
.73373 .31919 .73438 .31572 .73682 .31939 .73594 .31948 Mtetra
.084 .642 .705 r
.73594 .31948 .73682 .31939 .7391 .32075 .73812 .31923 Mtetra
.554 .683 .924 r
.73812 .31923 .7391 .32075 .74128 .32045 .7403 .31893 Mtetra
.668 .737 .902 r
.7403 .31893 .74128 .32045 .74342 .31949 .74244 .3181 Mtetra
.793 .802 .859 r
.74244 .3181 .74342 .31949 .74551 .31792 .74453 .31648 Mtetra
.95 .797 .657 r
.74453 .31648 .74551 .31792 .74755 .31563 .7464 .31179 Mtetra
.974 .666 .323 r
.7464 .31179 .74755 .31563 .7495 .31202 .73385 .10502 Mtetra
.542 .305 .505 r
.73385 .10502 .7495 .31202 .7511 .30369 .73493 .0914 Mtetra
.52 .288 .504 r
.73493 .0914 .7511 .30369 .73803 .09475 .73679 .08871 Mtetra
.628 .454 .627 r
.73679 .08871 .73803 .09475 .73972 .08978 .73872 .08704 Mtetra
.673 .588 .753 r
.73872 .08704 .73972 .08978 .74158 .08709 .74069 .08589 Mtetra
.646 .803 .958 r
.10124 .32317 .10245 .32395 .10403 .32334 .10281 .32263 Mtetra
.648 .819 .965 r
.10281 .32263 .10403 .32334 .10559 .32292 .10439 .32208 Mtetra
.66 .791 .944 r
.10439 .32208 .10559 .32292 .10714 .32259 .10597 .3215 Mtetra
.757 .758 .853 r
.10597 .3215 .10714 .32259 .10876 .32165 .10762 .32038 Mtetra
.695 .717 .866 r
.10762 .32038 .10876 .32165 .11036 .32095 .10923 .3196 Mtetra
.512 .64 .912 r
.10923 .3196 .11036 .32095 .11189 .32078 .11075 .31953 Mtetra
.934 .561 .256 r
.11075 .31953 .11189 .32078 .11307 .32332 .11169 .32385 Mtetra
.936 .68 .525 r
.11169 .32385 .11307 .32332 .08952 .51542 .08645 .52829 Mtetra
.651 .372 .485 r
.08645 .52829 .08952 .51542 .08909 .53115 .08737 .5336 Mtetra
.481 .087 .216 r
.08737 .5336 .08909 .53115 .09048 .53285 .08896 .5338 Mtetra
0 0 0 r
.08896 .5338 .09048 .53285 .09203 .53333 .09067 .53308 Mtetra
.769 .929 .938 r
.09067 .53308 .09203 .53333 .09366 .53324 .09244 .53194 Mtetra
.638 .713 .901 r
.09244 .53194 .09366 .53324 .09535 .53273 .09413 .53141 Mtetra
.633 .707 .9 r
.09413 .53141 .09535 .53273 .09706 .53201 .09581 .5309 Mtetra
.656 .751 .92 r
.09581 .5309 .09706 .53201 .09879 .53121 .09751 .5303 Mtetra
.624 .783 .958 r
.09751 .5303 .09879 .53121 .10042 .53111 .0992 .5298 Mtetra
.706 .729 .868 r
.0992 .5298 .10042 .53111 .10209 .53081 .10094 .52892 Mtetra
.762 .675 .766 r
.10094 .52892 .10209 .53081 .10383 .52992 .10278 .52723 Mtetra
.867 .668 .631 r
.10278 .52723 .10383 .52992 .10591 .52629 .10528 .52024 Mtetra
.934 .681 .531 r
.10528 .52024 .10591 .52629 .10911 .5137 .13246 .31592 Mtetra
.527 .295 .506 r
.13246 .31592 .10911 .5137 .13536 .31527 .13462 .31082 Mtetra
.647 .491 .658 r
.13462 .31082 .13536 .31527 .13726 .31233 .13632 .30946 Mtetra
.604 .521 .734 r
.13632 .30946 .13726 .31233 .13898 .31074 .13791 .30896 Mtetra
.546 .587 .847 r
.13791 .30896 .13898 .31074 .14063 .30971 .13945 .30883 Mtetra
.621 .775 .955 r
.13945 .30883 .14063 .30971 .14224 .30907 .14104 .30837 Mtetra
.638 .821 .971 r
.14104 .30837 .14224 .30907 .14383 .30865 .14264 .30783 Mtetra
.652 .8 .954 r
.14264 .30783 .14383 .30865 .1454 .30832 .14424 .30727 Mtetra
.688 .758 .905 r
.14424 .30727 .1454 .30832 .147 .3078 .14586 .30656 Mtetra
.684 .724 .88 r
.14586 .30656 .147 .3078 .14861 .30719 .14748 .30585 Mtetra
.665 .702 .875 r
.14748 .30585 .14861 .30719 .15022 .30653 .14909 .30523 Mtetra
.676 .711 .874 r
.14909 .30523 .15022 .30653 .15189 .30546 .15071 .30454 Mtetra
.592 .76 .959 r
.15071 .30454 .15189 .30546 .15353 .30457 .1523 .30417 Mtetra
0 .494 .778 r
.1523 .30417 .15353 .30457 .15512 .30419 .1538 .30449 Mtetra
.878 .515 .355 r
.1538 .30449 .15512 .30419 .15644 .30603 .15482 .30896 Mtetra
.938 .678 .517 r
.15482 .30896 .15644 .30603 .15699 .31453 .13235 .51297 Mtetra
.524 .288 .498 r
.13235 .51297 .15699 .31453 .13514 .51491 .13342 .51792 Mtetra
.547 .178 .292 r
.13342 .51792 .13514 .51491 .13652 .51722 .135 .51856 Mtetra
.165 0 0 r
.135 .51856 .13652 .51722 .13811 .51776 .13671 .51805 Mtetra
.608 .955 .878 r
.13671 .51805 .13811 .51776 .13978 .51771 .13849 .51704 Mtetra
.656 .845 .973 r
.13849 .51704 .13978 .51771 .14143 .51776 .14022 .51639 Mtetra
.696 .72 .868 r
.14022 .51639 .14143 .51776 .14312 .51748 .14198 .51555 Mtetra
.75 .67 .772 r
.14198 .51555 .14312 .51748 .14488 .51656 .14382 .51398 Mtetra
.855 .668 .649 r
.14382 .51398 .14488 .51656 .1469 .51344 .1461 .50849 Mtetra
.939 .683 .522 r
.1461 .50849 .1469 .51344 .14954 .50473 .17102 .30302 Mtetra
.529 .297 .507 r
.17102 .30302 .14954 .50473 .17399 .30184 .17328 .29682 Mtetra
.658 .489 .643 r
.17328 .29682 .17399 .30184 .17594 .2983 .17504 .29506 Mtetra
.61 .507 .712 r
.17504 .29506 .17594 .2983 .17769 .29664 .17667 .29444 Mtetra
.571 .554 .797 r
.17667 .29444 .17769 .29664 .17937 .29556 .17825 .29421 Mtetra
.652 .698 .88 r
.17825 .29421 .17937 .29556 .18102 .29475 .17988 .29364 Mtetra
.689 .75 .898 r
.17988 .29364 .18102 .29475 .18265 .2941 .18152 .29291 Mtetra
.674 .732 .894 r
.18152 .29291 .18265 .2941 .18428 .29353 .18316 .29225 Mtetra
.683 .719 .876 r
.18316 .29225 .18428 .29353 .18596 .29245 .1848 .29153 Mtetra
.635 .774 .947 r
.1848 .29153 .18596 .29245 .18764 .29144 .18642 .29102 Mtetra
.195 .683 .926 r
.18642 .29102 .18764 .29144 .18925 .29101 .18798 .29107 Mtetra
.838 .411 .22 r
.18798 .29107 .18925 .29101 .19059 .29316 .18926 .29378 Mtetra
.945 .682 .507 r
.18926 .29378 .19059 .29316 .17092 .49204 .16919 .49571 Mtetra
.83 .518 .46 r
.16919 .49571 .17092 .49204 .17116 .50557 .16996 .50416 Mtetra
0 .289 .784 r
.16996 .50416 .17116 .50557 .17271 .50677 .17153 .50519 Mtetra
.659 .681 .86 r
.17153 .50519 .17271 .50677 .17447 .50602 .17329 .50452 Mtetra
.744 .717 .827 r
.17329 .50452 .17447 .50602 .17631 .5046 .17511 .50327 Mtetra
.726 .737 .86 r
.17511 .50327 .17631 .5046 .17812 .50344 .1769 .50224 Mtetra
.689 .749 .897 r
.1769 .50224 .17812 .50344 .17989 .50259 .17867 .50146 Mtetra
.674 .758 .913 r
.17867 .50146 .17989 .50259 .18166 .50183 .18043 .50075 Mtetra
.624 .756 .941 r
.18043 .50075 .18166 .50183 .18341 .50126 .18218 .50025 Mtetra
.574 .754 .963 r
.18218 .50025 .18341 .50126 .18514 .50085 .1839 .4999 Mtetra
.549 .758 .975 r
.1839 .4999 .18514 .50085 .18687 .5005 .18563 .4996 Mtetra
.315 .665 .974 r
.18563 .4996 .18687 .5005 .18857 .5005 .18731 .49974 Mtetra
.354 .713 .986 r
.18731 .49974 .18857 .5005 .19027 .50042 .18901 .49975 Mtetra
.676 .851 .966 r
.18901 .49975 .19027 .50042 .19204 .49974 .19078 .49901 Mtetra
.915 .792 .71 r
.19078 .49901 .19204 .49974 .19402 .49688 .19287 .49512 Mtetra
.948 .688 .511 r
.19287 .49512 .19402 .49688 .1967 .48705 .21503 .28957 Mtetra
.536 .303 .508 r
.21503 .28957 .1967 .48705 .21831 .28518 .21752 .28059 Mtetra
.695 .522 .649 r
.21752 .28059 .21831 .28518 .22026 .28149 .21934 .2783 Mtetra
.614 .512 .716 r
.21934 .2783 .22026 .28149 .22203 .27978 .221 .27766 Mtetra
.557 .556 .808 r
.221 .27766 .22203 .27978 .22373 .27865 .22261 .27749 Mtetra
.58 .709 .931 r
.22261 .27749 .22373 .27865 .2254 .27791 .22423 .27717 Mtetra
.639 .821 .97 r
.22423 .27717 .2254 .27791 .22705 .27741 .22589 .27661 Mtetra
.65 .811 .961 r
.22589 .27661 .22705 .27741 .22868 .27704 .22754 .27603 Mtetra
.73 .783 .895 r
.22754 .27603 .22868 .27704 .23035 .27633 .22923 .2751 Mtetra
.727 .742 .864 r
.22923 .2751 .23035 .27633 .23203 .27549 .23093 .27413 Mtetra
.616 .687 .894 r
.23093 .27413 .23203 .27549 .23367 .27505 .23257 .2737 Mtetra
.584 .116 0 r
.23257 .2737 .23367 .27505 .23517 .27618 .234 .27554 Mtetra
.951 .684 .495 r
.234 .27554 .23517 .27618 .23627 .28165 .21698 .47501 Mtetra
.543 .303 .502 r
.21698 .47501 .23627 .28165 .21906 .48525 .21742 .48874 Mtetra
.638 .285 .356 r
.21742 .48874 .21906 .48525 .22043 .48897 .21898 .49051 Mtetra
.261 0 0 r
.21898 .49051 .22043 .48897 .22208 .48983 .22074 .49011 Mtetra
.588 .947 .862 r
.22074 .49011 .22208 .48983 .22379 .48996 .22256 .48908 Mtetra
.761 .825 .902 r
.22256 .48908 .22379 .48996 .22554 .48969 .22439 .48794 Mtetra
.707 .68 .821 r
.22439 .48794 .22554 .48969 .22732 .48917 .22622 .48689 Mtetra
.688 .621 .776 r
.22622 .48689 .22732 .48917 .22911 .4885 .22804 .48582 Mtetra
.611 .552 .764 r
.22804 .48582 .22911 .4885 .23088 .48807 .22982 .48527 Mtetra
.56 .515 .763 r
.22982 .48527 .23088 .48807 .23264 .48776 .23157 .48506 Mtetra
.639 .566 .757 r
.23157 .48506 .23264 .48776 .23444 .48701 .23337 .48429 Mtetra
.805 .646 .686 r
.23337 .48429 .23444 .48701 .23637 .48473 .2354 .48098 Mtetra
.95 .686 .502 r
.2354 .48098 .23637 .48473 .23863 .47867 .25483 .27785 Mtetra
.541 .307 .509 r
.25483 .27785 .23863 .47867 .2581 .27289 .25744 .2665 Mtetra
.676 .483 .617 r
.25744 .2665 .2581 .27289 .26021 .2673 .2593 .26376 Mtetra
.621 .503 .698 r
.2593 .26376 .26021 .2673 .26201 .26525 .261 .26296 Mtetra
.582 .555 .79 r
.261 .26296 .26201 .26525 .26375 .26394 .26265 .26265 Mtetra
.583 .69 .915 r
.26265 .26265 .26375 .26394 .26546 .26303 .26431 .26234 Mtetra
.64 .834 .975 r
.26431 .26234 .26546 .26303 .26714 .26237 .26599 .26176 Mtetra
.637 .851 .982 r
.26599 .26176 .26714 .26237 .26882 .26187 .26767 .26116 Mtetra
.667 .838 .965 r
.26767 .26116 .26882 .26187 .27049 .26141 .26936 .2605 Mtetra
.689 .799 .933 r
.26936 .2605 .27049 .26141 .27217 .2609 .27105 .25977 Mtetra
.674 .75 .908 r
.27105 .25977 .27217 .2609 .27384 .26037 .27275 .25909 Mtetra
.626 .708 .905 r
.27275 .25909 .27384 .26037 .27553 .25973 .27442 .25861 Mtetra
.545 .709 .947 r
.27442 .25861 .27553 .25973 .27723 .25897 .27608 .25839 Mtetra
.423 .779 .996 r
.27608 .25839 .27723 .25897 .27894 .25819 .27774 .25822 Mtetra
.435 .872 .898 r
.27774 .25822 .27894 .25819 .28065 .2573 .27942 .25766 Mtetra
.557 .931 .818 r
.27942 .25766 .28065 .2573 .28237 .25637 .28115 .25665 Mtetra
.268 .77 .743 r
.28115 .25665 .28237 .25637 .28405 .25584 .28283 .25612 Mtetra
.699 .194 .033 r
.28283 .25612 .28405 .25584 .28564 .25657 .28437 .25758 Mtetra
.954 .682 .483 r
.28437 .25758 .28564 .25657 .28694 .26107 .27046 .4581 Mtetra
.539 .3 .501 r
.27046 .4581 .28694 .26107 .27288 .46605 .27127 .47041 Mtetra
.642 .303 .382 r
.27127 .47041 .27288 .46605 .27433 .47027 .27288 .47255 Mtetra
.385 0 .133 r
.27288 .47255 .27433 .47027 .27612 .46999 .27467 .47232 Mtetra
.249 0 .064 r
.27467 .47232 .27612 .46999 .27795 .46907 .2765 .47152 Mtetra
.244 0 .076 r
.2765 .47152 .27795 .46907 .27975 .46869 .27833 .47066 Mtetra
.264 0 .023 r
.27833 .47066 .27975 .46869 .28147 .46945 .28015 .47007 Mtetra
0 0 0 r
.28015 .47007 .28147 .46945 .2832 .47 .28198 .46941 Mtetra
.638 .867 .985 r
.28198 .46941 .2832 .47 .28496 .47027 .2838 .46874 Mtetra
.656 .695 .874 r
.2838 .46874 .28496 .47027 .28675 .47019 .28563 .46807 Mtetra
.706 .646 .787 r
.28563 .46807 .28675 .47019 .28857 .46956 .2875 .46688 Mtetra
.794 .646 .698 r
.2875 .46688 .28857 .46956 .29049 .46769 .28949 .46397 Mtetra
.912 .671 .56 r
.28949 .46397 .29049 .46769 .29264 .46248 .29244 .44752 Mtetra
.942 .672 .497 r
.29244 .44752 .29264 .46248 .30885 .25674 .30827 .24827 Mtetra
.667 .459 .594 r
.30827 .24827 .30885 .25674 .31104 .24932 .31018 .24485 Mtetra
.617 .473 .663 r
.31018 .24485 .31104 .24932 .31278 .24828 .31192 .24387 Mtetra
.572 .444 .668 r
.31192 .24387 .31278 .24828 .31448 .24795 .31361 .24344 Mtetra
.558 .432 .665 r
.31361 .24344 .31448 .24795 .3162 .24722 .31531 .24315 Mtetra
.59 .466 .68 r
.31531 .24315 .3162 .24722 .31801 .24525 .31702 .24257 Mtetra
.616 .546 .752 r
.31702 .24257 .31801 .24525 .3198 .24351 .31873 .24198 Mtetra
.655 .68 .862 r
.31873 .24198 .3198 .24351 .32156 .24224 .32045 .24134 Mtetra
.687 .806 .938 r
.32045 .24134 .32156 .24224 .32328 .2416 .32218 .24061 Mtetra
.678 .784 .93 r
.32218 .24061 .32328 .2416 .32499 .24111 .3239 .23991 Mtetra
.642 .733 .914 r
.3239 .23991 .32499 .24111 .3267 .24057 .32562 .23936 Mtetra
.562 .699 .933 r
.32562 .23936 .3267 .24057 .32844 .23979 .32732 .23909 Mtetra
.471 .777 .997 r
.32732 .23909 .32844 .23979 .33017 .23899 .32901 .23888 Mtetra
.397 .845 .921 r
.32901 .23888 .33017 .23899 .33191 .23812 .33073 .23845 Mtetra
.584 .943 .825 r
.33073 .23845 .33191 .23812 .33366 .23713 .33248 .23738 Mtetra
.375 .839 .794 r
.33248 .23738 .33366 .23713 .33538 .23649 .33421 .23671 Mtetra
.479 0 0 r
.33421 .23671 .33538 .23649 .33706 .23673 .33586 .23738 Mtetra
.919 .584 .39 r
.33586 .23738 .33706 .23673 .33856 .23985 .33696 .24696 Mtetra
.951 .673 .474 r
.33696 .24696 .33856 .23985 .328 .44303 .3263 .45081 Mtetra
.633 .326 .433 r
.3263 .45081 .328 .44303 .32928 .4518 .32792 .45387 Mtetra
.393 0 .11 r
.32792 .45387 .32928 .4518 .33102 .45316 .32975 .45373 Mtetra
0 0 0 r
.32975 .45373 .33102 .45316 .33281 .45351 .33161 .45295 Mtetra
.722 .896 .958 r
.33161 .45295 .33281 .45351 .33464 .45333 .33349 .45197 Mtetra
.631 .716 .908 r
.33349 .45197 .33464 .45333 .33649 .45285 .33535 .45142 Mtetra
.645 .71 .894 r
.33535 .45142 .33649 .45285 .33836 .45218 .33721 .4508 Mtetra
.659 .724 .897 r
.33721 .4508 .33836 .45218 .34022 .45152 .33907 .45012 Mtetra
.646 .717 .9 r
.33907 .45012 .34022 .45152 .34206 .45128 .34093 .4495 Mtetra
.712 .687 .824 r
.34093 .4495 .34206 .45128 .34392 .45068 .34282 .4484 Mtetra
.789 .669 .731 r
.34282 .4484 .34392 .45068 .34583 .44918 .34478 .44603 Mtetra
.907 .677 .579 r
.34478 .44603 .34583 .44918 .34793 .44423 .34721 .43503 Mtetra
.954 .68 .479 r
.34721 .43503 .34793 .44423 .36076 .23895 .36013 .22958 Mtetra
.673 .459 .586 r
.36013 .22958 .36076 .23895 .36296 .22986 .36206 .22551 Mtetra
.626 .483 .667 r
.36206 .22551 .36296 .22986 .36474 .22872 .36383 .22443 Mtetra
.577 .452 .673 r
.36383 .22443 .36474 .22872 .36647 .22834 .36557 .22394 Mtetra
.551 .432 .67 r
.36557 .22394 .36647 .22834 .36821 .22795 .36729 .22373 Mtetra
.586 .46 .675 r
.36729 .22373 .36821 .22795 .37003 .22601 .36904 .22316 Mtetra
.608 .532 .743 r
.36904 .22316 .37003 .22601 .37183 .22425 .37079 .22259 Mtetra
.637 .658 .854 r
.37079 .22259 .37183 .22425 .37362 .22283 .37253 .22203 Mtetra
.641 .82 .969 r
.37253 .22203 .37362 .22283 .37538 .22207 .37429 .22143 Mtetra
.634 .855 .983 r
.37429 .22143 .37538 .22207 .37713 .22149 .37604 .22081 Mtetra
.648 .85 .978 r
.37604 .22081 .37713 .22149 .37888 .22101 .3778 .22017 Mtetra
.672 .819 .954 r
.3778 .22017 .37888 .22101 .38063 .22048 .37955 .21947 Mtetra
.678 .786 .931 r
.37955 .21947 .38063 .22048 .38238 .21995 .38132 .21876 Mtetra
.678 .749 .905 r
.38132 .21876 .38238 .21995 .38414 .2194 .38308 .21803 Mtetra
.68 .72 .879 r
.38308 .21803 .38414 .2194 .3859 .21877 .38484 .21728 Mtetra
.667 .696 .867 r
.38484 .21728 .3859 .21877 .38766 .21809 .38661 .21657 Mtetra
.647 .685 .871 r
.38661 .21657 .38766 .21809 .38942 .21735 .38837 .21597 Mtetra
.576 .677 .909 r
.38837 .21597 .38942 .21735 .3912 .21653 .39012 .21566 Mtetra
.507 .757 .986 r
.39012 .21566 .3912 .21653 .39297 .2157 .39187 .21544 Mtetra
.339 .797 .941 r
.39187 .21544 .39297 .2157 .39474 .21488 .39361 .21518 Mtetra
.602 .95 .825 r
.39361 .21518 .39474 .21488 .39652 .21381 .3954 .21404 Mtetra
.448 .88 .816 r
.3954 .21404 .39652 .21381 .3983 .21306 .39718 .21324 Mtetra
.085 0 0 r
.39718 .21324 .3983 .21306 .40004 .2129 .39892 .21323 Mtetra
.904 .528 .307 r
.39892 .21323 .40004 .2129 .40168 .21568 .40042 .21938 Mtetra
.961 .678 .451 r
.40042 .21938 .40168 .21568 .39542 .4158 .39379 .42709 Mtetra
.631 .338 .454 r
.39379 .42709 .39542 .4158 .39677 .42887 .39549 .43127 Mtetra
.44 .034 .171 r
.39549 .43127 .39677 .42887 .39863 .42923 .39737 .43129 Mtetra
.25 0 .033 r
.39737 .43129 .39863 .42923 .40054 .42845 .39927 .43057 Mtetra
.152 0 0 r
.39927 .43057 .40054 .42845 .40247 .42708 .4012 .42949 Mtetra
.314 0 .11 r
.4012 .42949 .40247 .42708 .40438 .42614 .4031 .42888 Mtetra
.34 0 .155 r
.4031 .42888 .40438 .42614 .40629 .42539 .40501 .42827 Mtetra
.346 0 .17 r
.40501 .42827 .40629 .42539 .40818 .42503 .40691 .42764 Mtetra
.317 0 .132 r
.40691 .42764 .40818 .42503 .41004 .42583 .40883 .42697 Mtetra
.067 0 0 r
.40883 .42697 .41004 .42583 .4119 .42653 .41074 .42628 Mtetra
.551 .907 .968 r
.41074 .42628 .4119 .42653 .41378 .4269 .41265 .42559 Mtetra
.636 .734 .919 r
.41265 .42559 .41378 .4269 .41568 .42648 .41456 .425 Mtetra
.641 .708 .895 r
.41456 .425 .41568 .42648 .4176 .42583 .41648 .42439 Mtetra
.658 .72 .894 r
.41648 .42439 .4176 .42583 .41952 .4251 .4184 .42369 Mtetra
.716 .744 .874 r
.4184 .42369 .41952 .4251 .42143 .4246 .42033 .42266 Mtetra
.707 .672 .813 r
.42033 .42266 .42143 .4246 .42334 .42412 .42226 .42153 Mtetra
.68 .602 .762 r
.42226 .42153 .42334 .42412 .42526 .4236 .4242 .42039 Mtetra
.558 .496 .742 r
.4242 .42039 .42526 .4236 .42717 .42326 .4261 .42016 Mtetra
.588 .52 .746 r
.4261 .42016 .42717 .42326 .42909 .42264 .42802 .41971 Mtetra
.678 .58 .739 r
.42802 .41971 .42909 .42264 .43103 .42142 .42996 .41847 Mtetra
.881 .674 .619 r
.42996 .41847 .43103 .42142 .43305 .41742 .43206 .41188 Mtetra
.965 .684 .451 r
.43206 .41188 .43305 .41742 .43536 .40299 .43987 .20182 Mtetra
.527 .294 .505 r
.43987 .20182 .43536 .40299 .44275 .20089 .44181 .19619 Mtetra
.65 .491 .655 r
.44181 .19619 .44275 .20089 .44459 .19899 .44363 .19465 Mtetra
.59 .461 .673 r
.44363 .19465 .44459 .19899 .44638 .19844 .44543 .194 Mtetra
.555 .435 .671 r
.44543 .194 .44638 .19844 .44818 .1982 .44722 .19374 Mtetra
.58 .451 .669 r
.44722 .19374 .44818 .1982 .45001 .19645 .44902 .1932 Mtetra
.603 .51 .721 r
.44902 .1932 .45001 .19645 .45184 .19461 .45082 .19261 Mtetra
.633 .619 .818 r
.45082 .19261 .45184 .19461 .45367 .19306 .45263 .192 Mtetra
.665 .779 .934 r
.45263 .192 .45367 .19306 .45548 .19223 .45443 .19132 Mtetra
.672 .814 .951 r
.45443 .19132 .45548 .19223 .45728 .19167 .45624 .19061 Mtetra
.677 .781 .928 r
.45624 .19061 .45728 .19167 .45908 .19122 .45805 .18988 Mtetra
.682 .731 .887 r
.45805 .18988 .45908 .19122 .46089 .1906 .45987 .1891 Mtetra
.673 .702 .869 r
.45987 .1891 .46089 .1906 .4627 .1899 .46168 .18835 Mtetra
.656 .689 .869 r
.46168 .18835 .4627 .1899 .46452 .18915 .46349 .18768 Mtetra
.675 .708 .873 r
.46349 .18768 .46452 .18915 .46634 .18801 .46531 .18692 Mtetra
.613 .755 .946 r
.46531 .18692 .46634 .18801 .46816 .18703 .46712 .18644 Mtetra
.197 .655 .943 r
.46712 .18644 .46816 .18703 .46997 .18654 .46892 .1866 Mtetra
.859 .418 .156 r
.46892 .1866 .46997 .18654 .47175 .18812 .47066 .19035 Mtetra
.968 .678 .425 r
.47066 .19035 .47175 .18812 .47344 .1947 .46883 .39925 Mtetra
.524 .287 .497 r
.46883 .39925 .47344 .1947 .47185 .40178 .47067 .40513 Mtetra
.53 .158 .279 r
.47067 .40513 .47185 .40178 .47375 .40462 .47261 .40575 Mtetra
.065 0 0 r
.47261 .40575 .47375 .40462 .47568 .40529 .47456 .40503 Mtetra
.734 .962 .94 r
.47456 .40503 .47568 .40529 .47763 .40523 .47653 .40381 Mtetra
.701 .743 .884 r
.47653 .40381 .47763 .40523 .47958 .40474 .47849 .40287 Mtetra
.665 .665 .84 r
.47849 .40287 .47958 .40474 .48154 .40398 .48045 .40206 Mtetra
.664 .66 .836 r
.48045 .40206 .48154 .40398 .48351 .40302 .48242 .40124 Mtetra
.666 .677 .851 r
.48242 .40124 .48351 .40302 .48547 .40208 .48438 .40043 Mtetra
.668 .697 .868 r
.48438 .40043 .48547 .40208 .48744 .40114 .48635 .39964 Mtetra
.667 .72 .888 r
.48635 .39964 .48744 .40114 .48941 .40021 .48831 .39888 Mtetra
.663 .746 .912 r
.48831 .39888 .48941 .40021 .49138 .39938 .49028 .39815 Mtetra
.654 .761 .928 r
.49028 .39815 .49138 .39938 .49334 .39864 .49225 .39746 Mtetra
.641 .766 .939 r
.49225 .39746 .49334 .39864 .49531 .39796 .49422 .39682 Mtetra
.615 .765 .951 r
.49422 .39682 .49531 .39796 .49728 .39736 .49619 .39628 Mtetra
.595 .77 .963 r
.49619 .39628 .49728 .39736 .49925 .3968 .49816 .3958 Mtetra
.583 .781 .974 r
.49816 .3958 .49925 .3968 .50123 .39628 .50013 .39534 Mtetra
.584 .794 .979 r
.50013 .39534 .50123 .39628 .5032 .39589 .50211 .39486 Mtetra
.595 .781 .969 r
.50211 .39486 .5032 .39589 .50517 .39547 .50408 .39437 Mtetra
.6 .768 .96 r
.50408 .39437 .50517 .39547 .50715 .39486 .50606 .39388 Mtetra
.59 .788 .974 r
.50606 .39388 .50715 .39486 .50913 .39361 .50804 .39339 Mtetra
.419 .851 .941 r
.50804 .39339 .50913 .39361 .51112 .39186 .51002 .3929 Mtetra
.135 0 0 r
.51002 .3929 .51112 .39186 .5131 .38992 .512 .39239 Mtetra
.341 0 .13 r
.512 .39239 .5131 .38992 .51508 .3887 .51399 .39186 Mtetra
.377 .009 .206 r
.51399 .39186 .51508 .3887 .51707 .38817 .51597 .39129 Mtetra
.372 .003 .201 r
.51597 .39129 .51707 .38817 .51905 .38786 .51796 .39071 Mtetra
.353 0 .172 r
.51796 .39071 .51905 .38786 .52104 .38741 .51995 .39011 Mtetra
.34 0 .153 r
.51995 .39011 .52104 .38741 .52302 .38682 .52194 .38948 Mtetra
.334 0 .147 r
.52194 .38948 .52302 .38682 .52501 .3862 .52393 .38883 Mtetra
.329 0 .142 r
.52393 .38883 .52501 .3862 .527 .38539 .52593 .38817 Mtetra
.337 0 .159 r
.52593 .38817 .527 .38539 .52899 .38457 .52792 .3875 Mtetra
.344 0 .175 r
.52792 .3875 .52899 .38457 .53099 .38405 .52992 .3868 Mtetra
.327 0 .153 r
.52992 .3868 .53099 .38405 .53298 .38446 .53191 .38608 Mtetra
.189 0 0 r
.53191 .38608 .53298 .38446 .53498 .38519 .53391 .38534 Mtetra
.376 .84 .808 r
.53391 .38534 .53498 .38519 .53699 .38565 .53591 .3846 Mtetra
.657 .802 .952 r
.53591 .3846 .53699 .38565 .53899 .38546 .53792 .38388 Mtetra
.652 .704 .885 r
.53792 .38388 .53899 .38546 .54099 .38481 .53992 .38317 Mtetra
.649 .694 .878 r
.53992 .38317 .54099 .38481 .543 .38403 .54192 .38248 Mtetra
.648 .708 .891 r
.54192 .38248 .543 .38403 .545 .38328 .54393 .3818 Mtetra
.646 .719 .901 r
.54393 .3818 .545 .38328 .54701 .3826 .54594 .38113 Mtetra
.644 .719 .902 r
.54594 .38113 .54701 .3826 .54902 .38194 .54795 .38047 Mtetra
.633 .716 .907 r
.54795 .38047 .54902 .38194 .55103 .38127 .54996 .37987 Mtetra
.63 .725 .915 r
.54996 .37987 .55103 .38127 .55304 .38062 .55197 .37927 Mtetra
.646 .741 .918 r
.55197 .37927 .55304 .38062 .55505 .38 .55398 .3786 Mtetra
.693 .751 .896 r
.55398 .3786 .55505 .38 .55707 .37945 .556 .37769 Mtetra
.714 .705 .841 r
.556 .37769 .55707 .37945 .55908 .37896 .55801 .37656 Mtetra
.689 .628 .783 r
.55801 .37656 .55908 .37896 .5611 .37846 .56002 .37539 Mtetra
.641 .557 .744 r
.56002 .37539 .5611 .37846 .56312 .3779 .56204 .37446 Mtetra
.604 .516 .728 r
.56204 .37446 .56312 .3779 .56515 .37728 .56406 .3738 Mtetra
.594 .509 .728 r
.56406 .3738 .56515 .37728 .56717 .37663 .56608 .37324 Mtetra
.598 .515 .732 r
.56608 .37324 .56717 .37663 .56919 .37597 .56811 .37265 Mtetra
.604 .522 .735 r
.56811 .37265 .56919 .37597 .57122 .37532 .57013 .37201 Mtetra
.605 .523 .735 r
.57013 .37201 .57122 .37532 .57324 .37466 .57216 .37136 Mtetra
.606 .525 .736 r
.57216 .37136 .57324 .37466 .57527 .374 .57418 .37071 Mtetra
.607 .525 .737 r
.57418 .37071 .57527 .374 .5773 .37333 .57621 .37005 Mtetra
.608 .526 .737 r
.57621 .37005 .5773 .37333 .57933 .37267 .57825 .36938 Mtetra
.608 .527 .737 r
.57825 .36938 .57933 .37267 .58137 .372 .58028 .36871 Mtetra
.58028 .36871 .58137 .372 .5834 .37132 .58231 .36804 Mtetra
.58231 .36804 .5834 .37132 .58544 .37065 .58435 .36737 Mtetra
.609 .527 .738 r
.58435 .36737 .58544 .37065 .58747 .36998 .58638 .3667 Mtetra
.609 .528 .738 r
.58638 .3667 .58747 .36998 .58951 .3693 .58842 .36602 Mtetra
.58842 .36602 .58951 .3693 .59155 .36863 .59046 .36534 Mtetra
.59046 .36534 .59155 .36863 .59359 .36795 .5925 .36467 Mtetra
.5925 .36467 .59359 .36795 .59564 .36727 .59455 .36399 Mtetra
.59455 .36399 .59564 .36727 .59768 .36659 .59659 .36331 Mtetra
.59659 .36331 .59768 .36659 .59973 .36591 .59864 .36263 Mtetra
.59864 .36263 .59973 .36591 .60177 .36524 .60068 .36195 Mtetra
.60068 .36195 .60177 .36524 .60382 .36456 .60273 .36127 Mtetra
.60273 .36127 .60382 .36456 .60587 .36388 .60478 .36059 Mtetra
.60478 .36059 .60587 .36388 .60793 .36319 .60683 .35991 Mtetra
.60683 .35991 .60793 .36319 .60998 .36251 .60889 .35922 Mtetra
.60889 .35922 .60998 .36251 .61203 .36183 .61094 .35854 Mtetra
.61094 .35854 .61203 .36183 .61409 .36115 .613 .35785 Mtetra
.613 .35785 .61409 .36115 .61615 .36046 .61505 .35717 Mtetra
.61505 .35717 .61615 .36046 .61821 .35978 .61711 .35648 Mtetra
.61 .528 .738 r
.61711 .35648 .61821 .35978 .62027 .35909 .61917 .35579 Mtetra
.61 .528 .737 r
.61917 .35579 .62027 .35909 .62233 .3584 .62124 .3551 Mtetra
.62124 .3551 .62233 .3584 .6244 .35771 .6233 .3544 Mtetra
.6233 .3544 .6244 .35771 .62646 .35701 .62537 .3537 Mtetra
.62537 .3537 .62646 .35701 .62853 .35631 .62743 .353 Mtetra
.611 .529 .737 r
.62743 .353 .62853 .35631 .6306 .35561 .6295 .35229 Mtetra
.611 .528 .737 r
.6295 .35229 .6306 .35561 .63267 .35491 .63157 .35158 Mtetra
.611 .528 .736 r
.63157 .35158 .63267 .35491 .63474 .35419 .63364 .35087 Mtetra
.612 .529 .736 r
.63364 .35087 .63474 .35419 .63681 .35343 .63571 .35015 Mtetra
.613 .532 .739 r
.63571 .35015 .63681 .35343 .63888 .3526 .63778 .34942 Mtetra
.615 .539 .745 r
.63778 .34942 .63888 .3526 .64095 .35176 .63986 .3487 Mtetra
.616 .546 .753 r
.63986 .3487 .64095 .35176 .64302 .35097 .64194 .34799 Mtetra
.616 .551 .759 r
.64194 .34799 .64302 .35097 .6451 .35025 .64401 .3473 Mtetra
.616 .553 .761 r
.64401 .3473 .6451 .35025 .64718 .34956 .6461 .34661 Mtetra
.594 .541 .765 r
.6461 .34661 .64718 .34956 .64927 .34899 .64818 .3461 Mtetra
.556 .523 .774 r
.64818 .3461 .64927 .34899 .65136 .34863 .65029 .34589 Mtetra
.632 .576 .774 r
.65029 .34589 .65136 .34863 .65345 .34787 .65237 .3451 Mtetra
.782 .651 .717 r
.65237 .3451 .65345 .34787 .65548 .34593 .65438 .34257 Mtetra
.946 .688 .515 r
.65438 .34257 .65548 .34593 .65736 .3403 .65593 .32896 Mtetra
.972 .669 .379 r
.65593 .32896 .65736 .3403 .6505 .12922 .64927 .12142 Mtetra
.685 .473 .593 r
.64927 .12142 .6505 .12922 .65217 .12215 .65108 .11764 Mtetra
.618 .477 .668 r
.65108 .11764 .65217 .12215 .65409 .12108 .65301 .11658 Mtetra
.572 .448 .673 r
.65301 .11658 .65409 .12108 .65606 .12075 .65496 .1161 Mtetra
.555 .433 .669 r
.65496 .1161 .65606 .12075 .65801 .12019 .65693 .1158 Mtetra
.585 .46 .676 r
.65693 .1158 .65801 .12019 .6599 .1183 .65888 .11519 Mtetra
.605 .524 .737 r
.65888 .11519 .6599 .1183 .6618 .11656 .66083 .11458 Mtetra
.634 .633 .832 r
.66083 .11458 .6618 .11656 .66372 .11518 .66278 .11393 Mtetra
.66 .758 .922 r
.66278 .11393 .66372 .11518 .66566 .11438 .66473 .11323 Mtetra
.668 .781 .934 r
.66473 .11323 .66566 .11438 .66762 .11371 .66668 .11248 Mtetra
.701 .777 .911 r
.66668 .11248 .66762 .11371 .66957 .11298 .66863 .11158 Mtetra
.757 .766 .86 r
.66863 .11158 .66957 .11298 .6715 .11185 .67055 .11029 Mtetra
.677 .711 .874 r
.67055 .11029 .6715 .11185 .67345 .11107 .6725 .10947 Mtetra
.371 .545 .896 r
.6725 .10947 .67345 .11107 .67545 .11121 .67452 .10987 Mtetra
.861 .462 0 r
.67452 .10987 .67545 .11121 .67763 .11464 .67686 .11661 Mtetra
.973 .662 .334 r
.67686 .11661 .67763 .11464 .69064 .32363 .69 .32916 Mtetra
.675 .325 .372 r
.69 .32916 .69064 .32363 .69316 .33082 .69234 .33282 Mtetra
.381 0 .083 r
.69234 .33282 .69316 .33082 .69537 .3319 .69449 .33265 Mtetra
0 0 0 r
.69449 .33265 .69537 .3319 .69754 .33206 .6966 .3317 Mtetra
.717 .964 .94 r
.6966 .3317 .69754 .33206 .69969 .33187 .69869 .33044 Mtetra
.634 .733 .92 r
.69869 .33044 .69969 .33187 .70185 .33192 .70081 .32979 Mtetra
.692 .663 .817 r
.70081 .32979 .70185 .33192 .70398 .33133 .70291 .32868 Mtetra
.776 .658 .732 r
.70291 .32868 .70398 .33133 .70604 .32949 .70494 .32636 Mtetra
.934 .693 .549 r
.70494 .32636 .70604 .32949 .70777 .32205 .70656 .31677 Mtetra
.975 .67 .344 r
.70656 .31677 .70777 .32205 .69727 .10675 .69632 .10497 Mtetra
.924 .753 .652 r
.69632 .10497 .69727 .10675 .69897 .10146 .69807 .10046 Mtetra
.762 .846 .914 r
.69807 .10046 .69897 .10146 .70092 .10029 .70001 .09925 Mtetra
.619 .788 .963 r
.70001 .09925 .70092 .10029 .70291 .09985 .702 .09868 Mtetra
.567 .737 .956 r
.702 .09868 .70291 .09985 .70492 .09966 .704 .09831 Mtetra
.749 .776 .875 r
.704 .09831 .70492 .09966 .70688 .09858 .70595 .09709 Mtetra
.672 .724 .888 r
.70595 .09709 .70688 .09858 .70885 .0978 .70792 .0963 Mtetra
.435 .6 .915 r
.70792 .0963 .70885 .0978 .71087 .09774 .70996 .09646 Mtetra
.817 .404 0 r
.70996 .09646 .71087 .09774 .7131 .10077 .71236 .10229 Mtetra
.972 .658 .314 r
.71236 .10229 .7131 .10077 .72865 .30854 .72823 .3157 Mtetra
.667 .332 .395 r
.72823 .3157 .72865 .30854 .73145 .31783 .73069 .31994 Mtetra
.391 0 .101 r
.73069 .31994 .73145 .31783 .73373 .31919 .73288 .31978 Mtetra
0 0 0 r
.73288 .31978 .73373 .31919 .73594 .31948 .73501 .31885 Mtetra
.748 .931 .948 r
.73501 .31885 .73594 .31948 .73812 .31923 .73712 .31757 Mtetra
.529 .648 .91 r
.73712 .31757 .73812 .31923 .7403 .31893 .73931 .3174 Mtetra
.625 .716 .912 r
.73931 .3174 .7403 .31893 .74244 .3181 .74147 .31679 Mtetra
.786 .813 .874 r
.74147 .31679 .74244 .3181 .74453 .31648 .74357 .31526 Mtetra
.982 .787 .566 r
.74357 .31526 .74453 .31648 .7464 .31179 .74528 .30823 Mtetra
.974 .666 .321 r
.74528 .30823 .7464 .31179 .73385 .10502 .73216 .09266 Mtetra
.676 .442 .559 r
.73216 .09266 .73385 .10502 .73493 .0914 .73379 .08686 Mtetra
.633 .487 .667 r
.73379 .08686 .73493 .0914 .73679 .08871 .73575 .08557 Mtetra
.597 .521 .739 r
.73575 .08557 .73679 .08871 .73872 .08704 .73777 .08501 Mtetra
.546 .585 .845 r
.73777 .08501 .73872 .08704 .74069 .08589 .73981 .08484 Mtetra
.646 .743 .92 r
.10006 .32211 .10124 .32317 .10281 .32263 .10163 .32159 Mtetra
.662 .751 .916 r
.10163 .32159 .10281 .32263 .10439 .32208 .10321 .32101 Mtetra
.676 .749 .905 r
.10321 .32101 .10439 .32208 .10597 .3215 .1048 .32036 Mtetra
.771 .752 .835 r
.1048 .32036 .10597 .3215 .10762 .32038 .10648 .3191 Mtetra
.714 .721 .855 r
.10648 .3191 .10762 .32038 .10923 .3196 .1081 .31821 Mtetra
.548 .647 .899 r
.1081 .31821 .10923 .3196 .11075 .31953 .10963 .31804 Mtetra
.937 .563 .225 r
.10963 .31804 .11075 .31953 .11169 .32385 .11058 .3223 Mtetra
.939 .683 .524 r
.11058 .3223 .11169 .32385 .08645 .52829 .08515 .52754 Mtetra
.925 .571 .34 r
.08515 .52754 .08645 .52829 .08737 .5336 .08606 .53294 Mtetra
.254 .679 .964 r
.08606 .53294 .08737 .5336 .08896 .5338 .08766 .53304 Mtetra
.711 .829 .938 r
.08766 .53304 .08896 .5338 .09067 .53308 .08939 .5322 Mtetra
.779 .808 .876 r
.08939 .5322 .09067 .53308 .09244 .53194 .09117 .53094 Mtetra
.552 .741 .964 r
.09117 .53094 .09244 .53194 .09413 .53141 .09283 .53066 Mtetra
.547 .794 .99 r
.09283 .53066 .09413 .53141 .09581 .5309 .09449 .53033 Mtetra
.662 .861 .975 r
.09449 .53033 .09581 .5309 .09751 .5303 .0962 .52965 Mtetra
.848 .835 .833 r
.0962 .52965 .09751 .5303 .0992 .5298 .09807 .52777 Mtetra
.825 .682 .706 r
.09807 .52777 .0992 .5298 .10094 .52892 .10009 .52463 Mtetra
.824 .617 .622 r
.10009 .52463 .10094 .52892 .10278 .52723 .10259 .51775 Mtetra
.93 .676 .533 r
.10259 .51775 .10278 .52723 .10528 .52024 .1295 .31696 Mtetra
.527 .295 .506 r
.1295 .31696 .10528 .52024 .13246 .31592 .13167 .3118 Mtetra
.723 .55 .656 r
.13167 .3118 .13246 .31592 .13462 .31082 .13353 .30919 Mtetra
.704 .672 .816 r
.13353 .30919 .13462 .31082 .13632 .30946 .13517 .30825 Mtetra
.605 .705 .914 r
.13517 .30825 .13632 .30946 .13791 .30896 .13674 .30788 Mtetra
.509 .694 .952 r
.13674 .30788 .13791 .30896 .13945 .30883 .13829 .30775 Mtetra
.622 .736 .928 r
.13829 .30775 .13945 .30883 .14104 .30837 .13988 .30731 Mtetra
.654 .747 .918 r
.13988 .30731 .14104 .30837 .14264 .30783 .14148 .30675 Mtetra
.67 .747 .908 r
.14148 .30675 .14264 .30783 .14424 .30727 .14309 .30612 Mtetra
.73 .748 .867 r
.14309 .30612 .14424 .30727 .14586 .30656 .14474 .30516 Mtetra
.705 .703 .845 r
.14474 .30516 .14586 .30656 .14748 .30585 .14638 .30429 Mtetra
.644 .66 .85 r
.14638 .30429 .14748 .30585 .14909 .30523 .14798 .30373 Mtetra
.296 .506 .891 r
.14798 .30373 .14909 .30523 .15071 .30454 .14947 .30417 Mtetra
.746 .228 0 r
.14947 .30417 .15071 .30454 .1523 .30417 .15082 .30577 Mtetra
.831 .489 .407 r
.15082 .30577 .1523 .30417 .1538 .30449 .1518 .31051 Mtetra
.934 .673 .519 r
.1518 .31051 .1538 .30449 .15482 .30896 .12958 .51088 Mtetra
.523 .287 .498 r
.12958 .51088 .15482 .30896 .13235 .51297 .13065 .51577 Mtetra
.664 .302 .348 r
.13065 .51577 .13235 .51297 .13342 .51792 .13209 .51763 Mtetra
0 .491 .731 r
.13209 .51763 .13342 .51792 .135 .51856 .13371 .51791 Mtetra
.592 .833 .99 r
.13371 .51791 .135 .51856 .13671 .51805 .13542 .51743 Mtetra
.754 .864 .929 r
.13542 .51743 .13671 .51805 .13849 .51704 .1372 .51638 Mtetra
.844 .841 .841 r
.1372 .51638 .13849 .51704 .14022 .51639 .13906 .51457 Mtetra
.828 .699 .722 r
.13906 .51457 .14022 .51639 .14198 .51555 .14106 .51167 Mtetra
.817 .619 .635 r
.14106 .51167 .14198 .51555 .14382 .51398 .14336 .50608 Mtetra
.936 .679 .524 r
.14336 .50608 .14382 .51398 .1461 .50849 .16805 .30423 Mtetra
.529 .297 .507 r
.16805 .30423 .1461 .50849 .17102 .30302 .17033 .29787 Mtetra
.709 .522 .635 r
.17033 .29787 .17102 .30302 .17328 .29682 .17222 .29496 Mtetra
.719 .655 .785 r
.17222 .29496 .17328 .29682 .17504 .29506 .17391 .29379 Mtetra
.629 .704 .899 r
.17391 .29379 .17504 .29506 .17667 .29444 .17552 .29332 Mtetra
.552 .705 .942 r
.17552 .29332 .17667 .29444 .17825 .29421 .17711 .29309 Mtetra
.699 .751 .892 r
.17711 .29309 .17825 .29421 .17988 .29364 .17875 .29231 Mtetra
.715 .72 .854 r
.17875 .29231 .17988 .29364 .18152 .29291 .18042 .2914 Mtetra
.664 .677 .852 r
.18042 .2914 .18152 .29291 .18316 .29225 .18206 .29074 Mtetra
.423 .572 .897 r
.18206 .29074 .18316 .29225 .1848 .29153 .1836 .29093 Mtetra
.566 0 0 r
.1836 .29093 .1848 .29153 .18642 .29102 .18504 .29208 Mtetra
.795 .406 .318 r
.18504 .29208 .18642 .29102 .18798 .29107 .1863 .29495 Mtetra
.94 .677 .51 r
.1863 .29495 .18798 .29107 .18926 .29378 .16668 .49101 Mtetra
.535 .297 .5 r
.16668 .49101 .18926 .29378 .16919 .49571 .16726 .50111 Mtetra
.646 .327 .417 r
.16726 .50111 .16919 .49571 .16996 .50416 .16867 .50361 Mtetra
.09 .598 .892 r
.16867 .50361 .16996 .50416 .17153 .50519 .17033 .50384 Mtetra
.68 .723 .882 r
.17033 .50384 .17153 .50519 .17329 .50452 .1721 .5031 Mtetra
.734 .725 .842 r
.1721 .5031 .17329 .50452 .17511 .50327 .1739 .50197 Mtetra
.711 .737 .872 r
.1739 .50197 .17511 .50327 .1769 .50224 .17568 .50104 Mtetra
.673 .746 .906 r
.17568 .50104 .1769 .50224 .17867 .50146 .17745 .50034 Mtetra
.652 .756 .926 r
.17745 .50034 .17867 .50146 .18043 .50075 .1792 .49974 Mtetra
.604 .762 .955 r
.1792 .49974 .18043 .50075 .18218 .50025 .18094 .4993 Mtetra
.556 .759 .972 r
.18094 .4993 .18218 .50025 .1839 .4999 .18266 .49898 Mtetra
.528 .756 .98 r
.18266 .49898 .1839 .4999 .18563 .4996 .18438 .49872 Mtetra
.235 .624 .957 r
.18438 .49872 .18563 .4996 .18731 .49974 .18605 .49897 Mtetra
.277 .672 .97 r
.18605 .49897 .18731 .49974 .18901 .49975 .18774 .49909 Mtetra
.645 .85 .978 r
.18774 .49909 .18901 .49975 .19078 .49901 .1895 .49845 Mtetra
.922 .81 .717 r
.1895 .49845 .19078 .49901 .19287 .49512 .19158 .49467 Mtetra
.949 .69 .51 r
.19158 .49467 .19287 .49512 .21503 .28957 .21387 .28875 Mtetra
.94 .733 .596 r
.21387 .28875 .21503 .28957 .21752 .28059 .21641 .27919 Mtetra
.831 .733 .757 r
.21641 .27919 .21752 .28059 .21934 .2783 .21823 .27693 Mtetra
.644 .694 .881 r
.21823 .27693 .21934 .2783 .221 .27766 .21988 .27638 Mtetra
.49 .65 .93 r
.21988 .27638 .221 .27766 .22261 .27749 .22148 .27634 Mtetra
.553 .703 .94 r
.22148 .27634 .22261 .27749 .22423 .27717 .2231 .2761 Mtetra
.652 .752 .923 r
.2231 .2761 .22423 .27717 .22589 .27661 .22475 .27553 Mtetra
.667 .754 .915 r
.22475 .27553 .22589 .27661 .22754 .27603 .22641 .2749 Mtetra
.743 .761 .867 r
.22641 .2749 .22754 .27603 .22923 .2751 .22812 .27385 Mtetra
.744 .742 .85 r
.22812 .27385 .22923 .2751 .23093 .27413 .22982 .27275 Mtetra
.64 .692 .882 r
.22982 .27275 .23093 .27413 .23257 .2737 .23148 .27221 Mtetra
0 0 .481 r
.23148 .27221 .23257 .2737 .234 .27554 .23291 .27401 Mtetra
.952 .685 .495 r
.23291 .27401 .234 .27554 .21698 .47501 .21577 .47396 Mtetra
.952 .646 .417 r
.21577 .47396 .21698 .47501 .21742 .48874 .21617 .48804 Mtetra
.712 .181 0 r
.21617 .48804 .21742 .48874 .21898 .49051 .21773 .48985 Mtetra
.559 .825 .995 r
.21773 .48985 .21898 .49051 .22074 .49011 .21949 .48943 Mtetra
.781 .86 .909 r
.21949 .48943 .22074 .49011 .22256 .48908 .22133 .48818 Mtetra
.849 .812 .814 r
.22133 .48818 .22256 .48908 .22439 .48794 .22324 .48614 Mtetra
.84 .71 .72 r
.22324 .48614 .22439 .48794 .22622 .48689 .22525 .48311 Mtetra
.804 .614 .644 r
.22525 .48311 .22622 .48689 .22804 .48582 .2274 .47844 Mtetra
.704 .499 .608 r
.2274 .47844 .22804 .48582 .22982 .48527 .22949 .47434 Mtetra
.508 .328 .571 r
.22949 .47434 .22982 .48527 .23157 .48506 .23119 .47465 Mtetra
.538 .353 .579 r
.23119 .47465 .23157 .48506 .23337 .48429 .23295 .47431 Mtetra
.942 .678 .507 r
.23295 .47431 .23337 .48429 .2354 .48098 .25164 .28172 Mtetra
.546 .311 .51 r
.25164 .28172 .2354 .48098 .25483 .27785 .25446 .26813 Mtetra
.666 .453 .586 r
.25446 .26813 .25483 .27785 .25744 .2665 .25643 .26421 Mtetra
.752 .638 .734 r
.25643 .26421 .25744 .2665 .2593 .26376 .25821 .2624 Mtetra
.653 .702 .882 r
.25821 .2624 .2593 .26376 .261 .26296 .25989 .2618 Mtetra
.559 .706 .939 r
.25989 .2618 .261 .26296 .26265 .26265 .26154 .26155 Mtetra
.576 .723 .943 r
.26154 .26155 .26265 .26265 .26431 .26234 .26319 .26123 Mtetra
.653 .749 .92 r
.26319 .26123 .26431 .26234 .26599 .26176 .26487 .26064 Mtetra
.667 .752 .914 r
.26487 .26064 .26599 .26176 .26767 .26116 .26656 .26 Mtetra
.706 .753 .889 r
.26656 .26 .26767 .26116 .26936 .2605 .26826 .25916 Mtetra
.72 .728 .856 r
.26826 .25916 .26936 .2605 .27105 .25977 .26998 .2582 Mtetra
.671 .677 .848 r
.26998 .2582 .27105 .25977 .27275 .25909 .27167 .25748 Mtetra
.476 .585 .884 r
.27167 .25748 .27275 .25909 .27442 .25861 .27331 .25755 Mtetra
.491 0 0 r
.27331 .25755 .27442 .25861 .27608 .25839 .27483 .25901 Mtetra
.825 .415 .268 r
.27483 .25901 .27608 .25839 .27774 .25822 .27622 .26211 Mtetra
.742 .408 .417 r
.27622 .26211 .27774 .25822 .27942 .25766 .27753 .26625 Mtetra
.416 .139 .382 r
.27753 .26625 .27942 .25766 .28115 .25665 .27929 .26491 Mtetra
.437 .155 .386 r
.27929 .26491 .28115 .25665 .28283 .25612 .28102 .26393 Mtetra
.944 .671 .49 r
.28102 .26393 .28283 .25612 .28437 .25758 .26769 .45486 Mtetra
.539 .3 .501 r
.26769 .45486 .28437 .25758 .27046 .4581 .26846 .46747 Mtetra
.624 .329 .448 r
.26846 .46747 .27046 .4581 .27127 .47041 .26997 .4707 Mtetra
.613 .074 0 r
.26997 .4707 .27127 .47041 .27288 .47255 .27166 .47181 Mtetra
.47 .778 .998 r
.27166 .47181 .27288 .47255 .27467 .47232 .27344 .47159 Mtetra
.627 .838 .981 r
.27344 .47159 .27467 .47232 .2765 .47152 .27526 .471 Mtetra
.632 .879 .987 r
.27526 .471 .2765 .47152 .27833 .47066 .27709 .47032 Mtetra
.55 .887 .986 r
.27709 .47032 .27833 .47066 .28015 .47007 .2789 .46975 Mtetra
.66 .922 .975 r
.2789 .46975 .28015 .47007 .28198 .46941 .28074 .46891 Mtetra
.802 .904 .913 r
.28074 .46891 .28198 .46941 .2838 .46874 .28262 .46754 Mtetra
.851 .777 .779 r
.28262 .46754 .2838 .46874 .28563 .46807 .28458 .46517 Mtetra
.818 .647 .67 r
.28458 .46517 .28563 .46807 .2875 .46688 .28664 .4613 Mtetra
.869 .63 .574 r
.28664 .4613 .2875 .46688 .28949 .46397 .28937 .44801 Mtetra
.941 .671 .498 r
.28937 .44801 .28949 .46397 .29244 .44752 .30533 .24953 Mtetra
.524 .292 .505 r
.30533 .24953 .29244 .44752 .30827 .24827 .30729 .24543 Mtetra
.745 .606 .703 r
.30729 .24543 .30827 .24827 .31018 .24485 .30911 .24333 Mtetra
.696 .697 .846 r
.30911 .24333 .31018 .24485 .31192 .24387 .31084 .24246 Mtetra
.627 .689 .888 r
.31084 .24246 .31192 .24387 .31361 .24344 .31254 .24197 Mtetra
.594 .665 .888 r
.31254 .24197 .31361 .24344 .31531 .24315 .31424 .24162 Mtetra
.619 .665 .873 r
.31424 .24162 .31531 .24315 .31702 .24257 .31594 .24115 Mtetra
.621 .686 .89 r
.31594 .24115 .31702 .24257 .31873 .24198 .31765 .24069 Mtetra
.661 .721 .893 r
.31765 .24069 .31873 .24198 .32045 .24134 .31937 .24005 Mtetra
.722 .738 .864 r
.31937 .24005 .32045 .24134 .32218 .24061 .32111 .23907 Mtetra
.683 .69 .851 r
.32111 .23907 .32218 .24061 .3239 .23991 .32284 .23828 Mtetra
.557 .624 .874 r
.32284 .23828 .3239 .23991 .32562 .23936 .32454 .23808 Mtetra
0 .208 .719 r
.32454 .23808 .32562 .23936 .32732 .23909 .32614 .2393 Mtetra
.812 .358 .157 r
.32614 .2393 .32732 .23909 .32901 .23888 .32766 .24187 Mtetra
.771 .421 .392 r
.32766 .24187 .32901 .23888 .33073 .23845 .32907 .24613 Mtetra
.42 .136 .373 r
.32907 .24613 .33073 .23845 .33248 .23738 .33084 .24499 Mtetra
.411 .128 .37 r
.33084 .24499 .33248 .23738 .33421 .23671 .33261 .24373 Mtetra
.679 .369 .442 r
.33261 .24373 .33421 .23671 .33586 .23738 .33405 .24787 Mtetra
.947 .668 .478 r
.33405 .24787 .33586 .23738 .33696 .24696 .32344 .44769 Mtetra
.521 .284 .497 r
.32344 .44769 .33696 .24696 .3263 .45081 .325 .45167 Mtetra
.669 .192 .111 r
.325 .45167 .3263 .45081 .32792 .45387 .32673 .45314 Mtetra
.508 .8 .998 r
.32673 .45314 .32792 .45387 .32975 .45373 .32857 .45283 Mtetra
.672 .816 .953 r
.32857 .45283 .32975 .45373 .33161 .45295 .33043 .45209 Mtetra
.693 .83 .949 r
.33043 .45209 .33161 .45295 .33349 .45197 .3323 .45126 Mtetra
.539 .817 .997 r
.3323 .45126 .33349 .45197 .33535 .45142 .33415 .45087 Mtetra
.602 .871 .992 r
.33415 .45087 .33535 .45142 .33721 .4508 .33601 .45026 Mtetra
.745 .902 .948 r
.33601 .45026 .33721 .4508 .33907 .45012 .33789 .44917 Mtetra
.863 .819 .804 r
.33789 .44917 .33907 .45012 .34093 .4495 .33985 .44693 Mtetra
.828 .666 .682 r
.33985 .44693 .34093 .4495 .34282 .4484 .34188 .44326 Mtetra
.855 .623 .587 r
.34188 .44326 .34282 .4484 .34478 .44603 .34426 .4334 Mtetra
.95 .676 .482 r
.34426 .4334 .34478 .44603 .34721 .43503 .35721 .23082 Mtetra
.524 .292 .505 r
.35721 .23082 .34721 .43503 .36013 .22958 .35916 .22635 Mtetra
.745 .59 .684 r
.35916 .22635 .36013 .22958 .36206 .22551 .361 .22398 Mtetra
.704 .701 .845 r
.361 .22398 .36206 .22551 .36383 .22443 .36276 .22305 Mtetra
.631 .699 .894 r
.36276 .22305 .36383 .22443 .36557 .22394 .36451 .22253 Mtetra
.58 .671 .902 r
.36451 .22253 .36557 .22394 .36729 .22373 .36624 .22222 Mtetra
.615 .671 .88 r
.36624 .22222 .36729 .22373 .36904 .22316 .36798 .22176 Mtetra
.611 .689 .898 r
.36798 .22176 .36904 .22316 .37079 .22259 .36972 .22133 Mtetra
.617 .714 .915 r
.36972 .22133 .37079 .22259 .37253 .22203 .37146 .22087 Mtetra
.646 .745 .921 r
.37146 .22087 .37253 .22203 .37429 .22143 .37321 .22029 Mtetra
.663 .754 .918 r
.37321 .22029 .37429 .22143 .37604 .22081 .37497 .21964 Mtetra
.679 .752 .907 r
.37497 .21964 .37604 .22081 .3778 .22017 .37673 .21891 Mtetra
.699 .744 .887 r
.37673 .21891 .3778 .22017 .37955 .21947 .3785 .21808 Mtetra
.697 .721 .868 r
.3785 .21808 .37955 .21947 .38132 .21876 .38027 .21722 Mtetra
.689 .697 .852 r
.38027 .21722 .38132 .21876 .38308 .21803 .38203 .21638 Mtetra
.697 .684 .833 r
.38203 .21638 .38308 .21803 .38484 .21728 .38381 .21545 Mtetra
.658 .647 .827 r
.38381 .21545 .38484 .21728 .38661 .21657 .38557 .21473 Mtetra
.588 .613 .845 r
.38557 .21473 .38661 .21657 .38837 .21597 .38732 .2144 Mtetra
.033 .332 .815 r
.38732 .2144 .38837 .21597 .39012 .21566 .38901 .21546 Mtetra
.784 .284 0 r
.38901 .21546 .39012 .21566 .39187 .21544 .39065 .21773 Mtetra
.817 .455 .371 r
.39065 .21773 .39187 .21544 .39361 .21518 .39217 .2228 Mtetra
.444 .156 .381 r
.39217 .2228 .39361 .21518 .3954 .21404 .39395 .22198 Mtetra
.401 .122 .372 r
.39395 .22198 .3954 .21404 .39718 .21324 .39576 .22048 Mtetra
.522 .222 .399 r
.39576 .22048 .39718 .21324 .39892 .21323 .39749 .22096 Mtetra
.956 .672 .457 r
.39749 .22096 .39892 .21323 .40042 .21938 .39087 .42372 Mtetra
.522 .285 .497 r
.39087 .42372 .40042 .21938 .39379 .42709 .39254 .42856 Mtetra
.7 .266 .216 r
.39254 .42856 .39379 .42709 .39549 .43127 .39434 .43053 Mtetra
.459 .78 .998 r
.39434 .43053 .39549 .43127 .39737 .43129 .39622 .43031 Mtetra
.656 .803 .953 r
.39622 .43031 .39737 .43129 .39927 .43057 .39813 .42962 Mtetra
.705 .821 .936 r
.39813 .42962 .39927 .43057 .4012 .42949 .40004 .42872 Mtetra
.572 .819 .992 r
.40004 .42872 .4012 .42949 .4031 .42888 .40194 .42825 Mtetra
.548 .841 .998 r
.40194 .42825 .4031 .42888 .40501 .42827 .40385 .42778 Mtetra
.542 .866 .995 r
.40385 .42778 .40501 .42827 .40691 .42764 .40575 .42725 Mtetra
.615 .909 .983 r
.40575 .42725 .40691 .42764 .40883 .42697 .40767 .4265 Mtetra
.651 .907 .981 r
.40767 .4265 .40883 .42697 .41074 .42628 .40958 .42569 Mtetra
.67 .888 .978 r
.40958 .42569 .41074 .42628 .41265 .42559 .4115 .42487 Mtetra
.559 .825 .995 r
.4115 .42487 .41265 .42559 .41456 .425 .41341 .42441 Mtetra
.583 .861 .995 r
.41341 .42441 .41456 .425 .41648 .42439 .41533 .42384 Mtetra
.689 .9 .972 r
.41533 .42384 .41648 .42439 .4184 .42369 .41725 .42293 Mtetra
.888 .859 .806 r
.41725 .42293 .4184 .42369 .42033 .42266 .41923 .42055 Mtetra
.856 .705 .694 r
.41923 .42055 .42033 .42266 .42226 .42153 .42124 .41689 Mtetra
.819 .606 .615 r
.42124 .41689 .42226 .42153 .4242 .42039 .42333 .41079 Mtetra
.59 .398 .59 r
.42333 .41079 .4242 .42039 .4261 .42016 .42528 .40923 Mtetra
.519 .338 .576 r
.42528 .40923 .4261 .42016 .42802 .41971 .42717 .40932 Mtetra
.58 .386 .583 r
.42717 .40932 .42802 .41971 .42996 .41847 .42912 .40789 Mtetra
.96 .678 .457 r
.42912 .40789 .42996 .41847 .43206 .41188 .43694 .20397 Mtetra
.528 .295 .505 r
.43694 .20397 .43206 .41188 .43987 .20182 .43891 .19761 Mtetra
.748 .565 .647 r
.43891 .19761 .43987 .20182 .44181 .19619 .44078 .19444 Mtetra
.732 .689 .809 r
.44078 .19444 .44181 .19619 .44363 .19465 .44259 .1932 Mtetra
.656 .703 .881 r
.44259 .1932 .44363 .19465 .44543 .194 .4444 .19254 Mtetra
.596 .676 .897 r
.4444 .19254 .44543 .194 .44722 .19374 .44619 .19216 Mtetra
.613 .664 .876 r
.44619 .19216 .44722 .19374 .44902 .1932 .44799 .1917 Mtetra
.616 .678 .886 r
.44799 .1917 .44902 .1932 .45082 .19261 .44979 .19123 Mtetra
.626 .704 .901 r
.44979 .19123 .45082 .19261 .45263 .192 .45159 .19072 Mtetra
.68 .74 .896 r
.45159 .19072 .45263 .192 .45443 .19132 .4534 .18996 Mtetra
.696 .732 .879 r
.4534 .18996 .45443 .19132 .45624 .19061 .45521 .18911 Mtetra
.693 .709 .861 r
.45521 .18911 .45624 .19061 .45805 .18988 .45703 .18824 Mtetra
.699 .692 .84 r
.45703 .18824 .45805 .18988 .45987 .1891 .45884 .18729 Mtetra
.671 .659 .829 r
.45884 .18729 .45987 .1891 .46168 .18835 .46066 .18648 Mtetra
.618 .628 .838 r
.46066 .18648 .46168 .18835 .46349 .18768 .46247 .18598 Mtetra
.392 .534 .879 r
.46247 .18598 .46349 .18768 .46531 .18692 .46426 .18633 Mtetra
.508 0 0 r
.46426 .18633 .46531 .18692 .46712 .18644 .46604 .1877 Mtetra
.815 .407 .273 r
.46604 .1877 .46712 .18644 .46892 .1866 .46777 .19145 Mtetra
.965 .674 .43 r
.46777 .19145 .46892 .1866 .47066 .19035 .46582 .39658 Mtetra
.524 .287 .497 r
.46582 .39658 .47066 .19035 .46883 .39925 .46765 .4027 Mtetra
.645 .275 .327 r
.46765 .4027 .46883 .39925 .47067 .40513 .46955 .40474 Mtetra
.236 .722 .928 r
.46955 .40474 .47067 .40513 .47261 .40575 .4715 .40468 Mtetra
.701 .805 .93 r
.4715 .40468 .47261 .40575 .47456 .40503 .47346 .40378 Mtetra
.756 .784 .876 r
.47346 .40378 .47456 .40503 .47653 .40381 .47543 .40252 Mtetra
.707 .765 .897 r
.47543 .40252 .47653 .40381 .47849 .40287 .47739 .40156 Mtetra
.676 .753 .909 r
.47739 .40156 .47849 .40287 .48045 .40206 .47936 .40076 Mtetra
.67 .754 .914 r
.47936 .40076 .48045 .40206 .48242 .40124 .48132 .4 Mtetra
.671 .765 .921 r
.48132 .4 .48242 .40124 .48438 .40043 .48328 .39924 Mtetra
.668 .772 .927 r
.48328 .39924 .48438 .40043 .48635 .39964 .48525 .39848 Mtetra
.662 .777 .934 r
.48525 .39848 .48635 .39964 .48831 .39888 .48722 .39776 Mtetra
.656 .783 .941 r
.48722 .39776 .48831 .39888 .49028 .39815 .48919 .39705 Mtetra
.644 .784 .949 r
.48919 .39705 .49028 .39815 .49225 .39746 .49115 .3964 Mtetra
.623 .784 .958 r
.49115 .3964 .49225 .39746 .49422 .39682 .49312 .39582 Mtetra
.571 .775 .975 r
.49312 .39582 .49422 .39682 .49619 .39628 .49509 .3954 Mtetra
.528 .783 .991 r
.49509 .3954 .49619 .39628 .49816 .3958 .49706 .39506 Mtetra
.505 .804 .999 r
.49706 .39506 .49816 .3958 .50013 .39534 .49904 .39471 Mtetra
.532 .84 .999 r
.49904 .39471 .50013 .39534 .50211 .39486 .50101 .39425 Mtetra
.553 .852 .998 r
.50101 .39425 .50211 .39486 .50408 .39437 .50299 .39373 Mtetra
.555 .847 .998 r
.50299 .39373 .50408 .39437 .50606 .39388 .50497 .39321 Mtetra
.515 .826 1 r
.50497 .39321 .50606 .39388 .50804 .39339 .50695 .3928 Mtetra
.474 .824 .997 r
.50695 .3928 .50804 .39339 .51002 .3929 .50893 .39244 Mtetra
.45 .836 .985 r
.50893 .39244 .51002 .3929 .512 .39239 .51091 .39205 Mtetra
.467 .862 .971 r
.51091 .39205 .512 .39239 .51399 .39186 .5129 .39155 Mtetra
.496 .88 .968 r
.5129 .39155 .51399 .39186 .51597 .39129 .51489 .39096 Mtetra
.521 .889 .974 r
.51489 .39096 .51597 .39129 .51796 .39071 .51687 .39034 Mtetra
.536 .89 .98 r
.51687 .39034 .51796 .39071 .51995 .39011 .51886 .38971 Mtetra
.546 .89 .983 r
.51886 .38971 .51995 .39011 .52194 .38948 .52086 .38908 Mtetra
.555 .892 .984 r
.52086 .38908 .52194 .38948 .52393 .38883 .52285 .38842 Mtetra
.556 .892 .984 r
.52285 .38842 .52393 .38883 .52593 .38817 .52485 .38777 Mtetra
.558 .895 .983 r
.52485 .38777 .52593 .38817 .52792 .3875 .52684 .38711 Mtetra
.57 .901 .981 r
.52684 .38711 .52792 .3875 .52992 .3868 .52884 .38641 Mtetra
.611 .916 .978 r
.52884 .38641 .52992 .3868 .53191 .38608 .53084 .38561 Mtetra
.652 .916 .979 r
.53084 .38561 .53191 .38608 .53391 .38534 .53284 .38474 Mtetra
.671 .897 .978 r
.53284 .38474 .53391 .38534 .53591 .3846 .53484 .38386 Mtetra
.658 .866 .978 r
.53484 .38386 .53591 .3846 .53792 .38388 .53684 .38307 Mtetra
.638 .846 .98 r
.53684 .38307 .53792 .38388 .53992 .38317 .53885 .38237 Mtetra
.627 .842 .982 r
.53885 .38237 .53992 .38317 .54192 .38248 .54085 .3817 Mtetra
.622 .846 .985 r
.54085 .3817 .54192 .38248 .54393 .3818 .54286 .38104 Mtetra
.62 .849 .986 r
.54286 .38104 .54393 .3818 .54594 .38113 .54487 .38038 Mtetra
.617 .85 .987 r
.54487 .38038 .54594 .38113 .54795 .38047 .54688 .37972 Mtetra
.565 .831 .996 r
.54688 .37972 .54795 .38047 .54996 .37987 .54889 .37922 Mtetra
.542 .843 .999 r
.54889 .37922 .54996 .37987 .55197 .37927 .55091 .37872 Mtetra
.629 .896 .986 r
.55091 .37872 .55197 .37927 .55398 .3786 .55292 .37794 Mtetra
.843 .909 .881 r
.55292 .37794 .55398 .3786 .556 .37769 .55493 .37618 Mtetra
.884 .773 .734 r
.55493 .37618 .556 .37769 .55801 .37656 .55692 .37302 Mtetra
.835 .639 .639 r
.55692 .37302 .55801 .37656 .56002 .37539 .55889 .36815 Mtetra
.744 .524 .596 r
.55889 .36815 .56002 .37539 .56204 .37446 .56086 .36272 Mtetra
.57 .373 .574 r
.56086 .36272 .56204 .37446 .56406 .3738 .56286 .36134 Mtetra
.492 .313 .566 r
.56286 .36134 .56406 .3738 .56608 .37324 .5649 .36218 Mtetra
.51 .333 .576 r
.5649 .36218 .56608 .37324 .56811 .37265 .56693 .36249 Mtetra
.544 .362 .585 r
.56693 .36249 .56811 .37265 .57013 .37201 .56895 .36198 Mtetra
.545 .363 .586 r
.56895 .36198 .57013 .37201 .57216 .37136 .57097 .36147 Mtetra
.547 .366 .587 r
.57097 .36147 .57216 .37136 .57418 .37071 .573 .36092 Mtetra
.549 .368 .588 r
.573 .36092 .57418 .37071 .57621 .37005 .57503 .36032 Mtetra
.55 .369 .589 r
.57503 .36032 .57621 .37005 .57825 .36938 .57705 .3597 Mtetra
.551 .37 .589 r
.57705 .3597 .57825 .36938 .58028 .36871 .57908 .35906 Mtetra
.552 .371 .589 r
.57908 .35906 .58028 .36871 .58231 .36804 .58111 .35841 Mtetra
.58111 .35841 .58231 .36804 .58435 .36737 .58314 .35776 Mtetra
.552 .371 .59 r
.58314 .35776 .58435 .36737 .58638 .3667 .58517 .3571 Mtetra
.553 .372 .59 r
.58517 .3571 .58638 .3667 .58842 .36602 .58721 .35643 Mtetra
.58721 .35643 .58842 .36602 .59046 .36534 .58924 .35576 Mtetra
.58924 .35576 .59046 .36534 .5925 .36467 .59128 .35509 Mtetra
.59128 .35509 .5925 .36467 .59455 .36399 .59332 .35441 Mtetra
.59332 .35441 .59455 .36399 .59659 .36331 .59536 .35374 Mtetra
.59536 .35374 .59659 .36331 .59864 .36263 .5974 .35306 Mtetra
.5974 .35306 .59864 .36263 .60068 .36195 .59944 .35238 Mtetra
.59944 .35238 .60068 .36195 .60273 .36127 .60149 .3517 Mtetra
.60149 .3517 .60273 .36127 .60478 .36059 .60353 .35102 Mtetra
.60353 .35102 .60478 .36059 .60683 .35991 .60558 .35033 Mtetra
.553 .373 .59 r
.60558 .35033 .60683 .35991 .60889 .35922 .60763 .34965 Mtetra
.60763 .34965 .60889 .35922 .61094 .35854 .60968 .34896 Mtetra
.554 .373 .59 r
.60968 .34896 .61094 .35854 .613 .35785 .61173 .34827 Mtetra
.61173 .34827 .613 .35785 .61505 .35717 .61378 .34757 Mtetra
.61378 .34757 .61505 .35717 .61711 .35648 .61584 .34688 Mtetra
.61584 .34688 .61711 .35648 .61917 .35579 .6179 .34617 Mtetra
.6179 .34617 .61917 .35579 .62124 .3551 .61995 .34546 Mtetra
.61995 .34546 .62124 .3551 .6233 .3544 .62201 .34474 Mtetra
.555 .373 .59 r
.62201 .34474 .6233 .3544 .62537 .3537 .62407 .34401 Mtetra
.555 .373 .589 r
.62407 .34401 .62537 .3537 .62743 .353 .62613 .34327 Mtetra
.62613 .34327 .62743 .353 .6295 .35229 .62819 .34252 Mtetra
.556 .373 .589 r
.62819 .34252 .6295 .35229 .63157 .35158 .63026 .34176 Mtetra
.556 .373 .588 r
.63026 .34176 .63157 .35158 .63364 .35087 .63232 .34098 Mtetra
.63232 .34098 .63364 .35087 .63571 .35015 .63438 .34019 Mtetra
.557 .373 .587 r
.63438 .34019 .63571 .35015 .63778 .34942 .63645 .33937 Mtetra
.556 .372 .586 r
.63645 .33937 .63778 .34942 .63986 .3487 .63852 .33856 Mtetra
.554 .369 .586 r
.63852 .33856 .63986 .3487 .64194 .34799 .64059 .33781 Mtetra
.55 .367 .585 r
.64059 .33781 .64194 .34799 .64401 .3473 .64266 .33713 Mtetra
.55 .366 .585 r
.64266 .33713 .64401 .3473 .6461 .34661 .64474 .33648 Mtetra
.528 .351 .585 r
.64474 .33648 .6461 .34661 .64818 .3461 .64684 .33637 Mtetra
.497 .332 .588 r
.64684 .33637 .64818 .3461 .65029 .34589 .64897 .33697 Mtetra
.562 .384 .597 r
.64897 .33697 .65029 .34589 .65237 .3451 .65104 .33613 Mtetra
.742 .508 .576 r
.65104 .33613 .65237 .3451 .65438 .34257 .65288 .32942 Mtetra
.971 .667 .384 r
.65288 .32942 .65438 .34257 .65593 .32896 .64649 .1235 Mtetra
.524 .292 .504 r
.64649 .1235 .65593 .32896 .64927 .12142 .64826 .11855 Mtetra
.776 .631 .7 r
.64826 .11855 .64927 .12142 .65108 .11764 .65012 .11604 Mtetra
.697 .712 .86 r
.65012 .11604 .65108 .11764 .65301 .11658 .65206 .11509 Mtetra
.623 .699 .899 r
.65206 .11509 .65301 .11658 .65496 .1161 .65401 .11455 Mtetra
.585 .67 .898 r
.65401 .11455 .65496 .1161 .65693 .1158 .65597 .11418 Mtetra
.612 .67 .882 r
.65597 .11418 .65693 .1158 .65888 .11519 .65793 .11369 Mtetra
.609 .689 .9 r
.65793 .11369 .65888 .11519 .66083 .11458 .65988 .1132 Mtetra
.623 .719 .915 r
.65988 .1132 .66083 .11458 .66278 .11393 .66184 .11266 Mtetra
.66 .753 .919 r
.66184 .11266 .66278 .11393 .66473 .11323 .66379 .11195 Mtetra
.678 .76 .913 r
.66379 .11195 .66473 .11323 .66668 .11248 .66574 .11115 Mtetra
.717 .765 .891 r
.66574 .11115 .66668 .11248 .66863 .11158 .66768 .11015 Mtetra
.775 .767 .846 r
.66768 .11015 .66863 .11158 .67055 .11029 .6696 .10871 Mtetra
.696 .716 .865 r
.6696 .10871 .67055 .11029 .6725 .10947 .67155 .10777 Mtetra
.409 .552 .887 r
.67155 .10777 .6725 .10947 .67452 .10987 .67356 .10809 Mtetra
.819 .435 0 r
.67356 .10809 .67452 .10987 .67686 .11661 .67589 .1147 Mtetra
.974 .665 .323 r
.67589 .1147 .67686 .11661 .69 .32916 .68902 .3282 Mtetra
.731 .257 0 r
.68902 .3282 .69 .32916 .69234 .33282 .69137 .33192 Mtetra
.442 .75 .994 r
.69137 .33192 .69234 .33282 .69449 .33265 .69351 .33176 Mtetra
.724 .872 .95 r
.69351 .33176 .69449 .33265 .6966 .3317 .69561 .33067 Mtetra
.835 .865 .867 r
.69561 .33067 .6966 .3317 .69869 .33044 .69768 .32885 Mtetra
.845 .779 .788 r
.69768 .32885 .69869 .33044 .70081 .32979 .69971 .32651 Mtetra
.813 .641 .669 r
.69971 .32651 .70081 .32979 .70291 .32868 .70167 .32286 Mtetra
.847 .603 .569 r
.70167 .32286 .70291 .32868 .70494 .32636 .70334 .31418 Mtetra
.972 .664 .36 r
.70334 .31418 .70494 .32636 .70656 .31677 .69354 .10656 Mtetra
.524 .291 .504 r
.69354 .10656 .70656 .31677 .69632 .10497 .69528 .10167 Mtetra
.758 .602 .685 r
.69528 .10167 .69632 .10497 .69807 .10046 .69714 .09911 Mtetra
.718 .766 .89 r
.69714 .09911 .69807 .10046 .70001 .09925 .6991 .09809 Mtetra
.635 .768 .944 r
.6991 .09809 .70001 .09925 .702 .09868 .70108 .09747 Mtetra
.61 .749 .944 r
.70108 .09747 .702 .09868 .704 .09831 .70308 .09696 Mtetra
.755 .777 .872 r
.70308 .09696 .704 .09831 .70595 .09709 .70502 .0957 Mtetra
.679 .743 .899 r
.70502 .0957 .70595 .09709 .70792 .0963 .707 .09488 Mtetra
.421 .609 .927 r
.707 .09488 .70792 .0963 .70996 .09646 .70904 .09506 Mtetra
.825 .423 0 r
.70904 .09506 .70996 .09646 .71236 .10229 .71147 .1014 Mtetra
.972 .659 .307 r
.71147 .1014 .71236 .10229 .72823 .3157 .72729 .31501 Mtetra
.769 .289 0 r
.72729 .31501 .72823 .3157 .73069 .31994 .72974 .31902 Mtetra
.497 .777 .994 r
.72974 .31902 .73069 .31994 .73288 .31978 .73192 .31872 Mtetra
.72 .84 .938 r
.73192 .31872 .73288 .31978 .73501 .31885 .73404 .31765 Mtetra
.77 .828 .898 r
.73404 .31765 .73501 .31885 .73712 .31757 .73615 .31627 Mtetra
.46 .674 .957 r
.73615 .31627 .73712 .31757 .73931 .3174 .73835 .31624 Mtetra
.576 .763 .967 r
.73835 .31624 .73931 .3174 .74147 .31679 .74052 .31578 Mtetra
.778 .865 .914 r
.74052 .31578 .74147 .31679 .74357 .31526 .74263 .31438 Mtetra
.991 .805 .557 r
.74263 .31438 .74357 .31526 .74528 .30823 .74434 .30738 Mtetra
.975 .668 .314 r
.74434 .30738 .74528 .30823 .73216 .09266 .73122 .09098 Mtetra
.956 .76 .599 r
.73122 .09098 .73216 .09266 .73379 .08686 .73286 .08514 Mtetra
.726 .714 .839 r
.73286 .08514 .73379 .08686 .73575 .08557 .73483 .08395 Mtetra
.597 .67 .891 r
.73483 .08395 .73575 .08557 .73777 .08501 .73685 .08352 Mtetra
.489 .635 .918 r
.73685 .08352 .73777 .08501 .73981 .08484 .73891 .08349 Mtetra
.658 .749 .917 r
.09888 .32107 .10006 .32211 .10163 .32159 .10046 .3205 Mtetra
.668 .743 .906 r
.10046 .3205 .10163 .32159 .10321 .32101 .10205 .31989 Mtetra
.678 .739 .897 r
.10205 .31989 .10321 .32101 .1048 .32036 .10364 .31923 Mtetra
.767 .752 .839 r
.10364 .31923 .1048 .32036 .10648 .3191 .10531 .318 Mtetra
.717 .752 .88 r
.10531 .318 .10648 .3191 .1081 .31821 .10693 .31714 Mtetra
.52 .701 .952 r
.10693 .31714 .1081 .31821 .10963 .31804 .10846 .31699 Mtetra
.926 .547 .26 r
.10846 .31699 .10963 .31804 .11058 .3223 .10942 .32109 Mtetra
.939 .683 .524 r
.10942 .32109 .11058 .3223 .08515 .52754 .08395 .52602 Mtetra
.947 .596 .302 r
.08395 .52602 .08515 .52754 .08606 .53294 .08483 .53163 Mtetra
.383 .608 .937 r
.08483 .53163 .08606 .53294 .08766 .53304 .08642 .53182 Mtetra
.686 .739 .891 r
.08642 .53182 .08766 .53304 .08939 .5322 .08813 .53107 Mtetra
.756 .765 .86 r
.08813 .53107 .08939 .5322 .09117 .53094 .08991 .52989 Mtetra
.497 .712 .967 r
.08991 .52989 .09117 .53094 .09283 .53066 .09155 .52976 Mtetra
.564 .767 .974 r
.09155 .52976 .09283 .53066 .09449 .53033 .09321 .52943 Mtetra
.726 .803 .912 r
.09321 .52943 .09449 .53033 .0962 .52965 .09495 .52851 Mtetra
.882 .749 .711 r
.09495 .52851 .0962 .52965 .09807 .52777 .09705 .52483 Mtetra
.895 .673 .594 r
.09705 .52483 .09807 .52777 .10009 .52463 .1003 .51204 Mtetra
.926 .672 .534 r
.1003 .51204 .10009 .52463 .10259 .51775 .12707 .31374 Mtetra
.521 .289 .504 r
.12707 .31374 .10259 .51775 .1295 .31696 .12897 .3108 Mtetra
.631 .452 .623 r
.12897 .3108 .1295 .31696 .13167 .3118 .1307 .30919 Mtetra
.674 .575 .736 r
.1307 .30919 .13167 .3118 .13353 .30919 .13236 .30814 Mtetra
.677 .755 .91 r
.13236 .30814 .13353 .30919 .13517 .30825 .13397 .30748 Mtetra
.606 .798 .973 r
.13397 .30748 .13517 .30825 .13674 .30788 .13555 .30704 Mtetra
.571 .774 .974 r
.13555 .30704 .13674 .30788 .13829 .30775 .13712 .30671 Mtetra
.644 .749 .926 r
.13712 .30671 .13829 .30775 .13988 .30731 .13872 .30619 Mtetra
.662 .739 .907 r
.13872 .30619 .13988 .30731 .14148 .30675 .14032 .30559 Mtetra
.672 .735 .898 r
.14032 .30559 .14148 .30675 .14309 .30612 .14194 .30495 Mtetra
.743 .747 .856 r
.14194 .30495 .14309 .30612 .14474 .30516 .1436 .3039 Mtetra
.711 .726 .862 r
.1436 .3039 .14474 .30516 .14638 .30429 .14524 .30303 Mtetra
.6 .694 .908 r
.14524 .30303 .14638 .30429 .14798 .30373 .14682 .30267 Mtetra
.737 .239 0 r
.14682 .30267 .14798 .30373 .14947 .30417 .14813 .30456 Mtetra
.911 .596 .436 r
.14813 .30456 .14947 .30417 .15082 .30577 .14862 .31335 Mtetra
.932 .671 .52 r
.14862 .31335 .15082 .30577 .1518 .31051 .12624 .51358 Mtetra
.518 .282 .496 r
.12624 .51358 .1518 .31051 .12958 .51088 .1276 .51598 Mtetra
.541 .217 .369 r
.1276 .51598 .12958 .51088 .13065 .51577 .12918 .51665 Mtetra
.323 0 0 r
.12918 .51665 .13065 .51577 .13209 .51763 .13082 .51668 Mtetra
.425 .704 .98 r
.13082 .51668 .13209 .51763 .13371 .51791 .13248 .51665 Mtetra
.605 .712 .92 r
.13248 .51665 .13371 .51791 .13542 .51743 .13419 .51624 Mtetra
.735 .758 .871 r
.13419 .51624 .13542 .51743 .1372 .51638 .13596 .5152 Mtetra
.872 .755 .73 r
.13596 .5152 .1372 .51638 .13906 .51457 .13799 .51202 Mtetra
.887 .679 .615 r
.13799 .51202 .13906 .51457 .14106 .51167 .14064 .50342 Mtetra
.935 .679 .525 r
.14064 .50342 .14106 .51167 .14336 .50608 .16566 .30035 Mtetra
.523 .291 .505 r
.16566 .30035 .14336 .50608 .16805 .30423 .16764 .29667 Mtetra
.621 .431 .604 r
.16764 .29667 .16805 .30423 .17033 .29787 .1694 .29488 Mtetra
.671 .555 .715 r
.1694 .29488 .17033 .29787 .17222 .29496 .17109 .29372 Mtetra
.69 .727 .878 r
.17109 .29372 .17222 .29496 .17391 .29379 .17273 .29297 Mtetra
.635 .797 .96 r
.17273 .29297 .17391 .29379 .17552 .29332 .17435 .29245 Mtetra
.607 .779 .963 r
.17435 .29245 .17552 .29332 .17711 .29309 .17595 .29202 Mtetra
.731 .767 .881 r
.17595 .29202 .17711 .29309 .17875 .29231 .17762 .29108 Mtetra
.724 .737 .862 r
.17762 .29108 .17875 .29231 .18042 .2914 .17929 .29013 Mtetra
.639 .708 .897 r
.17929 .29013 .18042 .2914 .18206 .29074 .18091 .28962 Mtetra
0 .064 .562 r
.18091 .28962 .18206 .29074 .1836 .29093 .18234 .2909 Mtetra
.9 .538 .345 r
.18234 .2909 .1836 .29093 .18504 .29208 .18336 .2959 Mtetra
.94 .677 .51 r
.18336 .2959 .18504 .29208 .1863 .29495 .16281 .49882 Mtetra
.52 .284 .497 r
.16281 .49882 .1863 .29495 .16668 .49101 .1641 .50237 Mtetra
.53 .251 .437 r
.1641 .50237 .16668 .49101 .16726 .50111 .1657 .50308 Mtetra
.402 0 .11 r
.1657 .50308 .16726 .50111 .16867 .50361 .16739 .50301 Mtetra
.604 .849 .99 r
.16739 .50301 .16867 .50361 .17033 .50384 .16913 .50247 Mtetra
.692 .721 .872 r
.16913 .50247 .17033 .50384 .1721 .5031 .1709 .50164 Mtetra
.712 .716 .852 r
.1709 .50164 .1721 .5031 .1739 .50197 .17269 .50067 Mtetra
.688 .733 .885 r
.17269 .50067 .1739 .50197 .17568 .50104 .17446 .49988 Mtetra
.652 .748 .92 r
.17446 .49988 .17568 .50104 .17745 .50034 .17621 .49927 Mtetra
.625 .758 .942 r
.17621 .49927 .17745 .50034 .1792 .49974 .17796 .49877 Mtetra
.579 .764 .966 r
.17796 .49877 .1792 .49974 .18094 .4993 .17969 .49839 Mtetra
.54 .764 .98 r
.17969 .49839 .18094 .4993 .18266 .49898 .18141 .4981 Mtetra
.523 .763 .985 r
.18141 .4981 .18266 .49898 .18438 .49872 .18313 .49784 Mtetra
.282 .65 .968 r
.18313 .49784 .18438 .49872 .18605 .49897 .18481 .49802 Mtetra
.378 .685 .979 r
.18481 .49802 .18605 .49897 .18774 .49909 .1865 .49807 Mtetra
.67 .78 .932 r
.1865 .49807 .18774 .49909 .1895 .49845 .18827 .49739 Mtetra
.894 .767 .713 r
.18827 .49739 .1895 .49845 .19158 .49467 .19035 .4937 Mtetra
.948 .689 .51 r
.19035 .4937 .19158 .49467 .21387 .28875 .2126 .28891 Mtetra
.962 .759 .582 r
.2126 .28891 .21387 .28875 .21641 .27919 .21525 .27837 Mtetra
.873 .803 .778 r
.21525 .27837 .21641 .27919 .21823 .27693 .21708 .27602 Mtetra
.662 .788 .942 r
.21708 .27602 .21823 .27693 .21988 .27638 .21873 .27541 Mtetra
.484 .714 .972 r
.21873 .27541 .21988 .27638 .22148 .27634 .22034 .27529 Mtetra
.568 .731 .951 r
.22034 .27529 .22148 .27634 .2231 .2761 .22197 .27499 Mtetra
.66 .748 .915 r
.22197 .27499 .2231 .2761 .22475 .27553 .22363 .27439 Mtetra
.67 .744 .905 r
.22363 .27439 .22475 .27553 .22641 .2749 .22529 .27374 Mtetra
.739 .756 .866 r
.22529 .27374 .22641 .2749 .22812 .27385 .22699 .2727 Mtetra
.745 .76 .865 r
.22699 .2727 .22812 .27385 .22982 .27275 .2287 .27163 Mtetra
.636 .74 .923 r
.2287 .27163 .22982 .27275 .23148 .27221 .23035 .27112 Mtetra
.639 .135 0 r
.23035 .27112 .23148 .27221 .23291 .27401 .23179 .27288 Mtetra
.951 .685 .495 r
.23179 .27288 .23291 .27401 .21577 .47396 .21476 .47078 Mtetra
.976 .68 .387 r
.21476 .47078 .21577 .47396 .21617 .48804 .21498 .48667 Mtetra
.605 .127 0 r
.21498 .48667 .21617 .48804 .21773 .48985 .21652 .48864 Mtetra
.552 .708 .944 r
.21652 .48864 .21773 .48985 .21949 .48943 .21827 .48838 Mtetra
.767 .795 .876 r
.21827 .48838 .21949 .48943 .22133 .48818 .22011 .48714 Mtetra
.879 .782 .751 r
.22011 .48714 .22133 .48818 .22324 .48614 .22211 .48424 Mtetra
.905 .706 .623 r
.22211 .48424 .22324 .48614 .22525 .48311 .22451 .47681 Mtetra
.946 .683 .506 r
.22451 .47681 .22525 .48311 .2274 .47844 .24478 .27194 Mtetra
.523 .291 .505 r
.24478 .27194 .2274 .47844 .22949 .47434 .24674 .26813 Mtetra
.515 .285 .503 r
.24674 .26813 .22949 .47434 .23119 .47465 .24843 .26742 Mtetra
.514 .283 .503 r
.24843 .26742 .23119 .47465 .23295 .47431 .25007 .2672 Mtetra
.516 .285 .503 r
.25007 .2672 .23295 .47431 .25164 .28172 .25179 .26615 Mtetra
.572 .361 .555 r
.25179 .26615 .25164 .28172 .25446 .26813 .25358 .26426 Mtetra
.678 .528 .675 r
.25358 .26426 .25446 .26813 .25643 .26421 .25535 .26262 Mtetra
.722 .692 .821 r
.25535 .26262 .25643 .26421 .25821 .2624 .25707 .26155 Mtetra
.642 .799 .958 r
.25707 .26155 .25821 .2624 .25989 .2618 .25874 .26099 Mtetra
.591 .792 .976 r
.25874 .26099 .25989 .2618 .26154 .26155 .26041 .26057 Mtetra
.621 .766 .949 r
.26041 .26057 .26154 .26155 .26319 .26123 .26208 .26009 Mtetra
.663 .746 .912 r
.26208 .26009 .26319 .26123 .26487 .26064 .26376 .25947 Mtetra
.671 .741 .903 r
.26376 .25947 .26487 .26064 .26656 .26 .26545 .2588 Mtetra
.716 .749 .878 r
.26545 .2588 .26656 .26 .26826 .25916 .26716 .2579 Mtetra
.733 .742 .859 r
.26716 .2579 .26826 .25916 .26998 .2582 .26888 .25687 Mtetra
.659 .711 .886 r
.26888 .25687 .26998 .2582 .27167 .25748 .27057 .25624 Mtetra
.049 .413 .862 r
.27057 .25624 .27167 .25748 .27331 .25755 .27215 .25698 Mtetra
.913 .523 .249 r
.27215 .25698 .27331 .25755 .27483 .25901 .27341 .2616 Mtetra
.951 .68 .487 r
.27341 .2616 .27483 .25901 .27622 .26211 .25846 .46649 Mtetra
.521 .284 .497 r
.25846 .46649 .27622 .26211 .27753 .26625 .2599 .47046 Mtetra
.511 .276 .495 r
.2599 .47046 .27753 .26625 .27929 .26491 .26168 .47012 Mtetra
.51 .275 .494 r
.26168 .47012 .27929 .26491 .28102 .26393 .26352 .46917 Mtetra
.512 .276 .495 r
.26352 .46917 .28102 .26393 .26769 .45486 .26531 .46887 Mtetra
.528 .257 .447 r
.26531 .46887 .26769 .45486 .26846 .46747 .26701 .46966 Mtetra
.532 .121 .208 r
.26701 .46966 .26846 .46747 .26997 .4707 .26873 .47024 Mtetra
.14 .646 .903 r
.26873 .47024 .26997 .4707 .27166 .47181 .27049 .47037 Mtetra
.589 .683 .906 r
.27049 .47037 .27166 .47181 .27344 .47159 .27229 .47001 Mtetra
.629 .676 .876 r
.27229 .47001 .27344 .47159 .27526 .471 .2741 .46947 Mtetra
.622 .683 .886 r
.2741 .46947 .27526 .471 .27709 .47032 .27591 .46896 Mtetra
.596 .701 .917 r
.27591 .46896 .27709 .47032 .2789 .46975 .27772 .46857 Mtetra
.689 .763 .908 r
.27772 .46857 .2789 .46975 .28074 .46891 .27956 .46776 Mtetra
.83 .787 .811 r
.27956 .46776 .28074 .46891 .28262 .46754 .28148 .46582 Mtetra
.895 .723 .661 r
.28148 .46582 .28262 .46754 .28458 .46517 .28363 .46073 Mtetra
.954 .686 .49 r
.28363 .46073 .28458 .46517 .28664 .4613 .30038 .25545 Mtetra
.533 .299 .506 r
.30038 .25545 .28664 .4613 .28937 .44801 .30264 .2473 Mtetra
.519 .288 .504 r
.30264 .2473 .28937 .44801 .30533 .24953 .30448 .24493 Mtetra
.649 .491 .656 r
.30448 .24493 .30533 .24953 .30729 .24543 .30625 .24345 Mtetra
.695 .641 .791 r
.30625 .24345 .30729 .24543 .30911 .24333 .30799 .24243 Mtetra
.688 .803 .936 r
.30799 .24243 .30911 .24333 .31084 .24246 .30971 .24169 Mtetra
.634 .819 .971 r
.30971 .24169 .31084 .24246 .31254 .24197 .31142 .24113 Mtetra
.617 .798 .969 r
.31142 .24113 .31254 .24197 .31424 .24162 .31313 .24063 Mtetra
.637 .773 .945 r
.31313 .24063 .31424 .24162 .31594 .24115 .31484 .24009 Mtetra
.642 .758 .933 r
.31484 .24009 .31594 .24115 .31765 .24069 .31655 .23953 Mtetra
.684 .753 .904 r
.31655 .23953 .31765 .24069 .31937 .24005 .31828 .23879 Mtetra
.739 .75 .861 r
.31828 .23879 .31937 .24005 .32111 .23907 .32003 .23772 Mtetra
.678 .717 .879 r
.32003 .23772 .32111 .23907 .32284 .23828 .32176 .23699 Mtetra
.355 .586 .931 r
.32176 .23699 .32284 .23828 .32454 .23808 .32342 .23726 Mtetra
.881 .447 .098 r
.32342 .23726 .32454 .23808 .32614 .2393 .32487 .24081 Mtetra
.957 .681 .472 r
.32487 .24081 .32614 .2393 .32766 .24187 .31332 .44534 Mtetra
.526 .288 .497 r
.31332 .44534 .32766 .24187 .32907 .24613 .31471 .45178 Mtetra
.512 .277 .495 r
.31471 .45178 .32907 .24613 .33084 .24499 .31652 .4516 Mtetra
.51 .275 .494 r
.31652 .4516 .33084 .24499 .33261 .24373 .31839 .45065 Mtetra
.511 .276 .495 r
.31839 .45065 .33261 .24373 .33405 .24787 .32024 .45 Mtetra
.514 .278 .495 r
.32024 .45 .33405 .24787 .32344 .44769 .322 .45088 Mtetra
.54 .168 .284 r
.322 .45088 .32344 .44769 .325 .45167 .32377 .45154 Mtetra
.094 0 0 r
.32377 .45154 .325 .45167 .32673 .45314 .32557 .45176 Mtetra
.608 .705 .913 r
.32557 .45176 .32673 .45314 .32857 .45283 .32742 .45131 Mtetra
.649 .698 .882 r
.32742 .45131 .32857 .45283 .33043 .45209 .32928 .45067 Mtetra
.647 .712 .895 r
.32928 .45067 .33043 .45209 .3323 .45126 .33114 .45004 Mtetra
.541 .708 .948 r
.33114 .45004 .3323 .45126 .33415 .45087 .33297 .4498 Mtetra
.642 .775 .944 r
.33297 .4498 .33415 .45087 .33601 .45026 .33483 .44919 Mtetra
.796 .806 .86 r
.33483 .44919 .33601 .45026 .33789 .44917 .33675 .44769 Mtetra
.903 .746 .676 r
.33675 .44769 .33789 .44917 .33985 .44693 .33884 .44312 Mtetra
.959 .687 .476 r
.33884 .44312 .33985 .44693 .34188 .44326 .35211 .24023 Mtetra
.541 .306 .508 r
.35211 .24023 .34188 .44326 .34426 .4334 .3545 .2282 Mtetra
.519 .288 .504 r
.3545 .2282 .34426 .4334 .35721 .23082 .35635 .22566 Mtetra
.642 .476 .643 r
.35635 .22566 .35721 .23082 .35916 .22635 .35814 .2241 Mtetra
.687 .617 .772 r
.35814 .2241 .35916 .22635 .361 .22398 .35991 .22305 Mtetra
.688 .803 .936 r
.35991 .22305 .361 .22398 .36276 .22305 .36167 .22229 Mtetra
.625 .826 .978 r
.36167 .22229 .36276 .22305 .36451 .22253 .36341 .22174 Mtetra
.593 .807 .982 r
.36341 .22174 .36451 .22253 .36624 .22222 .36515 .22128 Mtetra
.624 .784 .958 r
.36515 .22128 .36624 .22222 .36798 .22176 .36689 .22076 Mtetra
.626 .771 .95 r
.36689 .22076 .36798 .22176 .36972 .22133 .36864 .22024 Mtetra
.636 .757 .935 r
.36864 .22024 .36972 .22133 .37146 .22087 .37039 .2197 Mtetra
.657 .747 .917 r
.37039 .2197 .37146 .22087 .37321 .22029 .37214 .21907 Mtetra
.668 .742 .906 r
.37214 .21907 .37321 .22029 .37497 .21964 .3739 .21839 Mtetra
.679 .741 .898 r
.3739 .21839 .37497 .21964 .37673 .21891 .37566 .21766 Mtetra
.696 .745 .889 r
.37566 .21766 .37673 .21891 .3785 .21808 .37743 .21685 Mtetra
.698 .749 .891 r
.37743 .21685 .3785 .21808 .38027 .21722 .3792 .21602 Mtetra
.698 .754 .895 r
.3792 .21602 .38027 .21722 .38203 .21638 .38097 .21519 Mtetra
.739 .767 .875 r
.38097 .21519 .38203 .21638 .38381 .21545 .38275 .21413 Mtetra
.677 .727 .887 r
.38275 .21413 .38381 .21545 .38557 .21473 .38451 .2134 Mtetra
.511 .656 .925 r
.38451 .2134 .38557 .21473 .38732 .2144 .38625 .2133 Mtetra
.786 .319 0 r
.38625 .2133 .38732 .2144 .38901 .21546 .38786 .21615 Mtetra
.964 .682 .451 r
.38786 .21615 .38901 .21546 .39065 .21773 .38065 .41724 Mtetra
.536 .297 .499 r
.38065 .41724 .39065 .21773 .39217 .2228 .38198 .4291 Mtetra
.512 .277 .495 r
.38198 .4291 .39217 .2228 .39395 .22198 .38384 .42916 Mtetra
.51 .276 .494 r
.38384 .42916 .39395 .22198 .39576 .22048 .38575 .42828 Mtetra
.51 .275 .494 r
.38575 .42828 .39576 .22048 .39749 .22096 .38766 .4272 Mtetra
.514 .278 .495 r
.38766 .4272 .39749 .22096 .39087 .42372 .3895 .42807 Mtetra
.538 .194 .332 r
.3895 .42807 .39087 .42372 .39254 .42856 .39134 .42877 Mtetra
.305 0 0 r
.39134 .42877 .39254 .42856 .39434 .43053 .3932 .42913 Mtetra
.607 .706 .914 r
.3932 .42913 .39434 .43053 .39622 .43031 .3951 .42867 Mtetra
.648 .684 .871 r
.3951 .42867 .39622 .43031 .39813 .42962 .39701 .42801 Mtetra
.662 .694 .869 r
.39701 .42801 .39813 .42962 .40004 .42872 .39892 .42727 Mtetra
.615 .701 .906 r
.39892 .42727 .40004 .42872 .40194 .42825 .40082 .42677 Mtetra
.614 .697 .903 r
.40082 .42677 .40194 .42825 .40385 .42778 .40272 .42628 Mtetra
.622 .697 .898 r
.40272 .42628 .40385 .42778 .40575 .42725 .40463 .42576 Mtetra
.654 .709 .888 r
.40463 .42576 .40575 .42725 .40767 .4265 .40654 .42507 Mtetra
.665 .724 .893 r
.40654 .42507 .40767 .4265 .40958 .42569 .40846 .42434 Mtetra
.669 .739 .903 r
.40846 .42434 .40958 .42569 .4115 .42487 .41037 .4236 Mtetra
.553 .709 .944 r
.41037 .4236 .4115 .42487 .41341 .42441 .41228 .42331 Mtetra
.617 .769 .953 r
.41228 .42331 .41341 .42441 .41533 .42384 .41419 .42278 Mtetra
.743 .811 .906 r
.41419 .42278 .41533 .42384 .41725 .42293 .41612 .42167 Mtetra
.913 .775 .695 r
.41612 .42167 .41725 .42293 .41923 .42055 .41816 .4176 Mtetra
.935 .689 .543 r
.41816 .4176 .41923 .42055 .42124 .41689 .42055 .40238 Mtetra
.955 .673 .464 r
.42055 .40238 .42124 .41689 .42333 .41079 .42883 .20117 Mtetra
.517 .286 .503 r
.42883 .20117 .42333 .41079 .42528 .40923 .43066 .1994 Mtetra
.515 .284 .503 r
.43066 .1994 .42528 .40923 .42717 .40932 .43245 .19886 Mtetra
.514 .284 .503 r
.43245 .19886 .42717 .40932 .42912 .40789 .43424 .19859 Mtetra
.518 .286 .503 r
.43424 .19859 .42912 .40789 .43694 .20397 .43607 .19675 Mtetra
.625 .437 .608 r
.43607 .19675 .43694 .20397 .43891 .19761 .43791 .19487 Mtetra
.715 .599 .726 r
.43791 .19487 .43891 .19761 .44078 .19444 .43973 .19328 Mtetra
.714 .773 .898 r
.43973 .19328 .44078 .19444 .44259 .1932 .44154 .19237 Mtetra
.654 .824 .965 r
.44154 .19237 .44259 .1932 .4444 .19254 .44334 .19171 Mtetra
.616 .811 .975 r
.44334 .19171 .4444 .19254 .44619 .19216 .44514 .19117 Mtetra
.629 .782 .955 r
.44514 .19117 .44619 .19216 .44799 .1917 .44694 .19062 Mtetra
.634 .765 .941 r
.44694 .19062 .44799 .1917 .44979 .19123 .44875 .19007 Mtetra
.646 .751 .926 r
.44875 .19007 .44979 .19123 .45159 .19072 .45055 .18947 Mtetra
.683 .748 .9 r
.45055 .18947 .45159 .19072 .4534 .18996 .45236 .1887 Mtetra
.696 .749 .893 r
.45236 .1887 .4534 .18996 .45521 .18911 .45418 .18786 Mtetra
.697 .753 .895 r
.45418 .18786 .45521 .18911 .45703 .18824 .45599 .18702 Mtetra
.736 .769 .879 r
.45599 .18702 .45703 .18824 .45884 .18729 .45781 .18596 Mtetra
.697 .739 .883 r
.45781 .18596 .45884 .18729 .46066 .18648 .45963 .18511 Mtetra
.589 .689 .911 r
.45963 .18511 .46066 .18648 .46247 .18598 .46144 .18474 Mtetra
0 .084 .61 r
.46144 .18474 .46247 .18598 .46426 .18633 .4632 .18639 Mtetra
.915 .532 .269 r
.4632 .18639 .46426 .18633 .46604 .1877 .46488 .19299 Mtetra
.964 .674 .431 r
.46488 .19299 .46604 .1877 .46777 .19145 .46269 .40011 Mtetra
.518 .281 .496 r
.46269 .40011 .46777 .19145 .46582 .39658 .46457 .40297 Mtetra
.532 .217 .378 r
.46457 .40297 .46582 .39658 .46765 .4027 .4665 .40367 Mtetra
.296 0 0 r
.4665 .40367 .46765 .4027 .46955 .40474 .46844 .40362 Mtetra
.622 .77 .951 r
.46844 .40362 .46955 .40474 .4715 .40468 .4704 .40306 Mtetra
.682 .706 .865 r
.4704 .40306 .4715 .40468 .47346 .40378 .47236 .40218 Mtetra
.708 .719 .858 r
.47236 .40218 .47346 .40378 .47543 .40252 .47433 .40115 Mtetra
.687 .747 .897 r
.47433 .40115 .47543 .40252 .47739 .40156 .47629 .40029 Mtetra
.669 .759 .918 r
.47629 .40029 .47739 .40156 .47936 .40076 .47825 .39953 Mtetra
.663 .764 .925 r
.47825 .39953 .47936 .40076 .48132 .4 .48022 .39881 Mtetra
.661 .77 .93 r
.48022 .39881 .48132 .4 .48328 .39924 .48218 .39808 Mtetra
.657 .777 .937 r
.48218 .39808 .48328 .39924 .48525 .39848 .48415 .39738 Mtetra
.65 .784 .945 r
.48415 .39738 .48525 .39848 .48722 .39776 .48612 .3967 Mtetra
.643 .791 .953 r
.48612 .3967 .48722 .39776 .48919 .39705 .48809 .39604 Mtetra
.631 .797 .962 r
.48809 .39604 .48919 .39705 .49115 .3964 .49005 .39543 Mtetra
.615 .799 .97 r
.49005 .39543 .49115 .3964 .49312 .39582 .49203 .39486 Mtetra
.582 .79 .978 r
.49203 .39486 .49312 .39582 .49509 .3954 .494 .39439 Mtetra
.57 .775 .975 r
.494 .39439 .49509 .3954 .49706 .39506 .49597 .39397 Mtetra
.577 .761 .966 r
.49597 .39397 .49706 .39506 .49904 .39471 .49794 .39355 Mtetra
.603 .756 .951 r
.49794 .39355 .49904 .39471 .50101 .39425 .49992 .39305 Mtetra
.615 .754 .945 r
.49992 .39305 .50101 .39425 .50299 .39373 .5019 .39252 Mtetra
.615 .752 .943 r
.5019 .39252 .50299 .39373 .50497 .39321 .50388 .39198 Mtetra
.599 .742 .945 r
.50388 .39198 .50497 .39321 .50695 .3928 .50586 .39151 Mtetra
.594 .729 .938 r
.50586 .39151 .50695 .3928 .50893 .39244 .50784 .39107 Mtetra
.602 .716 .925 r
.50784 .39107 .50893 .39244 .51091 .39205 .50983 .3906 Mtetra
.621 .711 .91 r
.50983 .3906 .51091 .39205 .5129 .39155 .51181 .39006 Mtetra
.633 .709 .902 r
.51181 .39006 .5129 .39155 .51489 .39096 .5138 .38945 Mtetra
.639 .709 .898 r
.5138 .38945 .51489 .39096 .51687 .39034 .51579 .38883 Mtetra
.64 .709 .897 r
.51579 .38883 .51687 .39034 .51886 .38971 .51778 .38819 Mtetra
.641 .708 .895 r
.51778 .38819 .51886 .38971 .52086 .38908 .51977 .38755 Mtetra
.643 .708 .894 r
.51977 .38755 .52086 .38908 .52285 .38842 .52177 .38689 Mtetra
.52177 .38689 .52285 .38842 .52485 .38777 .52376 .38624 Mtetra
.645 .708 .893 r
.52376 .38624 .52485 .38777 .52684 .38711 .52576 .38557 Mtetra
.65 .71 .892 r
.52576 .38557 .52684 .38711 .52884 .38641 .52776 .38488 Mtetra
.663 .717 .889 r
.52776 .38488 .52884 .38641 .53084 .38561 .52976 .38412 Mtetra
.673 .728 .891 r
.52976 .38412 .53084 .38561 .53284 .38474 .53176 .38332 Mtetra
.674 .739 .9 r
.53176 .38332 .53284 .38474 .53484 .38386 .53376 .38251 Mtetra
.664 .748 .913 r
.53376 .38251 .53484 .38386 .53684 .38307 .53577 .38176 Mtetra
.652 .751 .922 r
.53577 .38176 .53684 .38307 .53885 .38237 .53777 .38107 Mtetra
.646 .751 .926 r
.53777 .38107 .53885 .38237 .54085 .3817 .53978 .38041 Mtetra
.643 .751 .927 r
.53978 .38041 .54085 .3817 .54286 .38104 .54179 .37975 Mtetra
.642 .751 .928 r
.54179 .37975 .54286 .38104 .54487 .38038 .5438 .3791 Mtetra
.642 .753 .929 r
.5438 .3791 .54487 .38038 .54688 .37972 .54581 .37845 Mtetra
.582 .729 .944 r
.54581 .37845 .54688 .37972 .54889 .37922 .54782 .37804 Mtetra
.574 .745 .957 r
.54782 .37804 .54889 .37922 .55091 .37872 .54984 .37763 Mtetra
.691 .806 .937 r
.54984 .37763 .55091 .37872 .55292 .37794 .55186 .37675 Mtetra
.884 .815 .776 r
.55186 .37675 .55292 .37794 .55493 .37618 .55385 .37409 Mtetra
.932 .725 .601 r
.55385 .37409 .55493 .37618 .55692 .37302 .55581 .36696 Mtetra
.972 .68 .408 r
.55581 .36696 .55692 .37302 .55889 .36815 .55566 .15649 Mtetra
.523 .29 .504 r
.55566 .15649 .55889 .36815 .56086 .36272 .5575 .15217 Mtetra
.516 .285 .503 r
.5575 .15217 .56086 .36272 .56286 .36134 .55938 .1512 Mtetra
.514 .284 .503 r
.55938 .1512 .56286 .36134 .5649 .36218 .56127 .15098 Mtetra
.56127 .15098 .5649 .36218 .56693 .36249 .56316 .1507 Mtetra
.515 .284 .503 r
.56316 .1507 .56693 .36249 .56895 .36198 .56505 .15005 Mtetra
.56505 .15005 .56895 .36198 .57097 .36147 .56694 .14942 Mtetra
.56694 .14942 .57097 .36147 .573 .36092 .56883 .14877 Mtetra
.56883 .14877 .573 .36092 .57503 .36032 .57072 .1481 Mtetra
.57072 .1481 .57503 .36032 .57705 .3597 .57261 .14742 Mtetra
.57261 .14742 .57705 .3597 .57908 .35906 .5745 .14673 Mtetra
.5745 .14673 .57908 .35906 .58111 .35841 .5764 .14604 Mtetra
.5764 .14604 .58111 .35841 .58314 .35776 .57829 .14534 Mtetra
.57829 .14534 .58314 .35776 .58517 .3571 .58019 .14464 Mtetra
.58019 .14464 .58517 .3571 .58721 .35643 .58209 .14394 Mtetra
.58209 .14394 .58721 .35643 .58924 .35576 .58399 .14323 Mtetra
.58399 .14323 .58924 .35576 .59128 .35509 .58589 .14253 Mtetra
.58589 .14253 .59128 .35509 .59332 .35441 .58779 .14182 Mtetra
.58779 .14182 .59332 .35441 .59536 .35374 .58969 .14111 Mtetra
.58969 .14111 .59536 .35374 .5974 .35306 .5916 .14041 Mtetra
.5916 .14041 .5974 .35306 .59944 .35238 .5935 .1397 Mtetra
.5935 .1397 .59944 .35238 .60149 .3517 .59541 .13899 Mtetra
.59541 .13899 .60149 .3517 .60353 .35102 .59732 .13827 Mtetra
.59732 .13827 .60353 .35102 .60558 .35033 .59923 .13756 Mtetra
.59923 .13756 .60558 .35033 .60763 .34965 .60114 .13685 Mtetra
.60114 .13685 .60763 .34965 .60968 .34896 .60305 .13613 Mtetra
.60305 .13613 .60968 .34896 .61173 .34827 .60497 .13542 Mtetra
.60497 .13542 .61173 .34827 .61378 .34757 .60688 .1347 Mtetra
.60688 .1347 .61378 .34757 .61584 .34688 .6088 .13398 Mtetra
.6088 .13398 .61584 .34688 .6179 .34617 .61072 .13326 Mtetra
.61072 .13326 .6179 .34617 .61995 .34546 .61264 .13253 Mtetra
.61264 .13253 .61995 .34546 .62201 .34474 .61456 .13181 Mtetra
.61456 .13181 .62201 .34474 .62407 .34401 .61648 .13108 Mtetra
.61648 .13108 .62407 .34401 .62613 .34327 .6184 .13034 Mtetra
.6184 .13034 .62613 .34327 .62819 .34252 .62032 .1296 Mtetra
.62032 .1296 .62819 .34252 .63026 .34176 .62225 .12886 Mtetra
.62225 .12886 .63026 .34176 .63232 .34098 .62417 .12812 Mtetra
.62417 .12812 .63232 .34098 .63438 .34019 .6261 .12737 Mtetra
.6261 .12737 .63438 .34019 .63645 .33937 .62803 .12662 Mtetra
.62803 .12662 .63645 .33937 .63852 .33856 .62996 .12588 Mtetra
.62996 .12588 .63852 .33856 .64059 .33781 .63189 .12514 Mtetra
.63189 .12514 .64059 .33781 .64266 .33713 .63383 .12443 Mtetra
.63383 .12443 .64266 .33713 .64474 .33648 .63576 .12372 Mtetra
.63576 .12372 .64474 .33648 .64684 .33637 .6377 .12312 Mtetra
.514 .284 .503 r
.6377 .12312 .64684 .33637 .64897 .33697 .63965 .12267 Mtetra
.515 .284 .503 r
.63965 .12267 .64897 .33697 .65104 .33613 .64159 .12197 Mtetra
.516 .285 .503 r
.64159 .12197 .65104 .33613 .65288 .32942 .6435 .12059 Mtetra
.518 .287 .503 r
.6435 .12059 .65288 .32942 .64649 .1235 .64539 .11842 Mtetra
.661 .492 .645 r
.64539 .11842 .64649 .1235 .64826 .11855 .64728 .11651 Mtetra
.738 .675 .789 r
.64728 .11651 .64826 .11855 .65012 .11604 .64919 .11507 Mtetra
.679 .823 .952 r
.64919 .11507 .65012 .11604 .65206 .11509 .65113 .11428 Mtetra
.617 .833 .983 r
.65113 .11428 .65206 .11509 .65401 .11455 .65308 .11367 Mtetra
.597 .81 .981 r
.65308 .11367 .65401 .11455 .65597 .11418 .65504 .11314 Mtetra
.621 .785 .96 r
.65504 .11314 .65597 .11418 .65793 .11369 .65699 .11256 Mtetra
.627 .771 .949 r
.65699 .11256 .65793 .11369 .65988 .1132 .65895 .11198 Mtetra
.644 .757 .932 r
.65895 .11198 .65988 .1132 .66184 .11266 .6609 .11134 Mtetra
.671 .751 .91 r
.6609 .11134 .66184 .11266 .66379 .11195 .66285 .11058 Mtetra
.682 .745 .899 r
.66285 .11058 .66379 .11195 .66574 .11115 .6648 .10976 Mtetra
.714 .752 .882 r
.6648 .10976 .66574 .11115 .66768 .11015 .66674 .10875 Mtetra
.772 .772 .853 r
.66674 .10875 .66768 .11015 .6696 .10871 .66866 .10736 Mtetra
.698 .754 .895 r
.66866 .10736 .6696 .10871 .67155 .10777 .67061 .10645 Mtetra
.355 .589 .933 r
.67061 .10645 .67155 .10777 .67356 .10809 .67262 .10677 Mtetra
.848 .442 0 r
.67262 .10677 .67356 .10809 .67589 .1147 .67494 .11302 Mtetra
.974 .665 .324 r
.67494 .11302 .67589 .1147 .68902 .3282 .688 .3265 Mtetra
0 0 .37 r
.688 .3265 .68902 .3282 .69137 .33192 .69036 .33039 Mtetra
.462 .63 .926 r
.69036 .33039 .69137 .33192 .69351 .33176 .69252 .33044 Mtetra
.707 .782 .91 r
.69252 .33044 .69351 .33176 .69561 .33067 .69462 .32943 Mtetra
.857 .83 .82 r
.69462 .32943 .69561 .33067 .69768 .32885 .69666 .32724 Mtetra
.941 .775 .647 r
.69666 .32724 .69768 .32885 .69971 .32651 .69855 .32224 Mtetra
.976 .671 .345 r
.69855 .32224 .69971 .32651 .70167 .32286 .68901 .11295 Mtetra
.534 .299 .504 r
.68901 .11295 .70167 .32286 .70334 .31418 .69046 .10281 Mtetra
.518 .287 .503 r
.69046 .10281 .70334 .31418 .69354 .10656 .69233 .10036 Mtetra
.618 .445 .625 r
.69233 .10036 .69354 .10656 .69528 .10167 .69426 .09884 Mtetra
.661 .574 .747 r
.69426 .09884 .69528 .10167 .69714 .09911 .69622 .09777 Mtetra
.682 .753 .905 r
.69622 .09777 .69714 .09911 .6991 .09809 .69819 .09694 Mtetra
.647 .777 .943 r
.69819 .09694 .6991 .09809 .70108 .09747 .70017 .09627 Mtetra
.65 .768 .935 r
.70017 .09627 .70108 .09747 .70308 .09696 .70215 .0956 Mtetra
.756 .777 .87 r
.70215 .0956 .70308 .09696 .70502 .0957 .7041 .09433 Mtetra
.683 .749 .901 r
.7041 .09433 .70502 .0957 .707 .09488 .70608 .09349 Mtetra
.431 .621 .931 r
.70608 .09349 .707 .09488 .70904 .09506 .70811 .09362 Mtetra
.802 .397 0 r
.70811 .09362 .70904 .09506 .71147 .1014 .71052 .09948 Mtetra
.972 .66 .304 r
.71052 .09948 .71147 .1014 .72729 .31501 .72628 .31323 Mtetra
0 0 .369 r
.72628 .31323 .72729 .31501 .72974 .31902 .72875 .31745 Mtetra
.537 .665 .919 r
.72875 .31745 .72974 .31902 .73192 .31872 .73093 .31723 Mtetra
.698 .753 .894 r
.73093 .31723 .73192 .31872 .73404 .31765 .73306 .31623 Mtetra
.75 .785 .882 r
.73306 .31623 .73404 .31765 .73615 .31627 .73517 .31493 Mtetra
.47 .673 .953 r
.73517 .31493 .73615 .31627 .73835 .31624 .73737 .31488 Mtetra
.593 .732 .94 r
.73737 .31488 .73835 .31624 .74052 .31578 .73954 .31439 Mtetra
.766 .795 .877 r
.73954 .31439 .74052 .31578 .74263 .31438 .74165 .31298 Mtetra
.975 .78 .578 r
.74165 .31298 .74263 .31438 .74434 .30738 .74339 .3062 Mtetra
.975 .668 .315 r
.74339 .3062 .74434 .30738 .73122 .09098 .73034 .09004 Mtetra
.986 .806 .577 r
.73034 .09004 .73122 .09098 .73286 .08514 .73197 .08402 Mtetra
.765 .827 .9 r
.73197 .08402 .73286 .08514 .73483 .08395 .73394 .08277 Mtetra
.603 .753 .949 r
.73394 .08277 .73483 .08395 .73685 .08352 .73595 .08226 Mtetra
.491 .683 .952 r
.73595 .08226 .73685 .08352 .73891 .08349 .73801 .08215 Mtetra
.693 .753 .898 r
.0977 .32 .09888 .32107 .10046 .3205 .0993 .31928 Mtetra
.682 .723 .881 r
.0993 .31928 .10046 .3205 .10205 .31989 .1009 .31859 Mtetra
.663 .705 .879 r
.1009 .31859 .10205 .31989 .10364 .31923 .10249 .31798 Mtetra
.686 .72 .875 r
.10249 .31798 .10364 .31923 .10531 .318 .10409 .31726 Mtetra
.569 .793 .984 r
.10409 .31726 .10531 .318 .10693 .31714 .10564 .31692 Mtetra
.232 0 0 r
.10564 .31692 .10693 .31714 .10846 .31699 .1071 .3173 Mtetra
.888 .547 .395 r
.1071 .3173 .10846 .31699 .10942 .32109 .1079 .32263 Mtetra
.935 .679 .525 r
.1079 .32263 .10942 .32109 .08395 .52602 .08258 .5258 Mtetra
.895 .525 .33 r
.08258 .5258 .08395 .52602 .08483 .53163 .0836 .53026 Mtetra
.335 .568 .924 r
.0836 .53026 .08483 .53163 .08642 .53182 .08518 .53056 Mtetra
.644 .721 .904 r
.08518 .53056 .08642 .53182 .08813 .53107 .08687 .53 Mtetra
.739 .774 .882 r
.08687 .53 .08813 .53107 .08991 .52989 .08863 .52898 Mtetra
.631 .784 .955 r
.08863 .52898 .08991 .52989 .09155 .52976 .09031 .52845 Mtetra
.707 .73 .869 r
.09031 .52845 .09155 .52976 .09321 .52943 .09205 .52756 Mtetra
.764 .678 .768 r
.09205 .52756 .09321 .52943 .09495 .52851 .0939 .52586 Mtetra
.869 .67 .631 r
.0939 .52586 .09495 .52851 .09705 .52483 .09643 .51878 Mtetra
.933 .681 .532 r
.09643 .51878 .09705 .52483 .1003 .51204 .12417 .31432 Mtetra
.526 .294 .506 r
.12417 .31432 .1003 .51204 .12707 .31374 .12634 .30924 Mtetra
.644 .488 .657 r
.12634 .30924 .12707 .31374 .12897 .3108 .12803 .30791 Mtetra
.604 .52 .733 r
.12803 .30791 .12897 .3108 .1307 .30919 .12962 .3074 Mtetra
.552 .59 .846 r
.12962 .3074 .1307 .30919 .13236 .30814 .13117 .30725 Mtetra
.643 .78 .947 r
.13117 .30725 .13236 .30814 .13397 .30748 .13276 .30672 Mtetra
.661 .813 .956 r
.13276 .30672 .13397 .30748 .13555 .30704 .13437 .30612 Mtetra
.667 .778 .933 r
.13437 .30612 .13555 .30704 .13712 .30671 .13597 .30551 Mtetra
.677 .728 .888 r
.13597 .30551 .13712 .30671 .13872 .30619 .13759 .30484 Mtetra
.668 .7 .871 r
.13759 .30484 .13872 .30619 .14032 .30559 .1392 .30419 Mtetra
.65 .687 .871 r
.1392 .30419 .14032 .30559 .14194 .30495 .1408 .30363 Mtetra
.673 .706 .873 r
.1408 .30363 .14194 .30495 .1436 .3039 .14242 .30296 Mtetra
.592 .756 .957 r
.14242 .30296 .1436 .3039 .14524 .30303 .144 .30259 Mtetra
0 .504 .797 r
.144 .30259 .14524 .30303 .14682 .30267 .1455 .30291 Mtetra
.882 .521 .357 r
.1455 .30291 .14682 .30267 .14813 .30456 .14649 .30747 Mtetra
.938 .678 .518 r
.14649 .30747 .14813 .30456 .14862 .31335 .12345 .51164 Mtetra
.523 .286 .497 r
.12345 .51164 .14862 .31335 .12624 .51358 .12451 .51654 Mtetra
.542 .17 .285 r
.12451 .51654 .12624 .51358 .1276 .51598 .12609 .51715 Mtetra
.116 0 0 r
.12609 .51715 .1276 .51598 .12918 .51665 .1278 .51664 Mtetra
.691 .961 .943 r
.1278 .51664 .12918 .51665 .13082 .51668 .12957 .51564 Mtetra
.659 .769 .931 r
.12957 .51564 .13082 .51668 .13248 .51665 .1313 .51501 Mtetra
.683 .68 .84 r
.1313 .51501 .13248 .51665 .13419 .51624 .13305 .51418 Mtetra
.743 .657 .766 r
.13305 .51418 .13419 .51624 .13596 .5152 .13489 .51263 Mtetra
.856 .669 .649 r
.13489 .51263 .13596 .5152 .13799 .51202 .13719 .50716 Mtetra
.939 .683 .523 r
.13719 .50716 .13799 .51202 .14064 .50342 .16268 .30155 Mtetra
.529 .296 .506 r
.16268 .30155 .14064 .50342 .16566 .30035 .16496 .29529 Mtetra
.656 .486 .642 r
.16496 .29529 .16566 .30035 .16764 .29667 .16672 .29355 Mtetra
.612 .513 .718 r
.16672 .29355 .16764 .29667 .1694 .29488 .16834 .29293 Mtetra
.568 .579 .824 r
.16834 .29293 .1694 .29488 .17109 .29372 .16993 .29271 Mtetra
.643 .758 .932 r
.16993 .29271 .17109 .29372 .17273 .29297 .17154 .29218 Mtetra
.674 .812 .95 r
.17154 .29218 .17273 .29297 .17435 .29245 .17318 .29153 Mtetra
.661 .781 .938 r
.17318 .29153 .17435 .29245 .17595 .29202 .1748 .29093 Mtetra
.691 .755 .9 r
.1748 .29093 .17595 .29202 .17762 .29108 .17645 .2902 Mtetra
.643 .786 .95 r
.17645 .2902 .17762 .29108 .17929 .29013 .17807 .28966 Mtetra
.228 .695 .944 r
.17807 .28966 .17929 .29013 .18091 .28962 .17963 .2897 Mtetra
.849 .435 .247 r
.17963 .2897 .18091 .28962 .18234 .2909 .18087 .29268 Mtetra
.943 .68 .509 r
.18087 .29268 .18234 .2909 .18336 .2959 .1601 .49588 Mtetra
.528 .29 .498 r
.1601 .49588 .18336 .2959 .16281 .49882 .16098 .50313 Mtetra
.564 .226 .354 r
.16098 .50313 .16281 .49882 .1641 .50237 .16256 .50405 Mtetra
.174 0 0 r
.16256 .50405 .1641 .50237 .1657 .50308 .16431 .50339 Mtetra
.69 .98 .879 r
.16431 .50339 .1657 .50308 .16739 .50301 .16613 .50216 Mtetra
.748 .824 .911 r
.16613 .50216 .16739 .50301 .16913 .50247 .16793 .50111 Mtetra
.699 .726 .871 r
.16793 .50111 .16913 .50247 .1709 .50164 .1697 .50024 Mtetra
.69 .718 .871 r
.1697 .50024 .1709 .50164 .17269 .50067 .17148 .49943 Mtetra
.664 .736 .904 r
.17148 .49943 .17269 .50067 .17446 .49988 .17323 .49876 Mtetra
.628 .75 .935 r
.17323 .49876 .17446 .49988 .17621 .49927 .17498 .49825 Mtetra
.594 .758 .956 r
.17498 .49825 .17621 .49927 .17796 .49877 .17671 .49784 Mtetra
.519 .751 .98 r
.17671 .49784 .17796 .49877 .17969 .49839 .17843 .4976 Mtetra
.475 .765 .994 r
.17843 .4976 .17969 .49839 .18141 .4981 .18014 .49741 Mtetra
.509 .8 .998 r
.18014 .49741 .18141 .4981 .18313 .49784 .18187 .49711 Mtetra
.519 .795 .996 r
.18187 .49711 .18313 .49784 .18481 .49802 .18359 .49681 Mtetra
.647 .739 .916 r
.18359 .49681 .18481 .49802 .1865 .49807 .18535 .49622 Mtetra
.731 .675 .796 r
.18535 .49622 .1865 .49807 .18827 .49739 .18719 .49492 Mtetra
.845 .671 .666 r
.18719 .49492 .18827 .49739 .19035 .4937 .18934 .49044 Mtetra
.946 .686 .512 r
.18934 .49044 .19035 .4937 .2126 .28891 .21175 .28491 Mtetra
.844 .629 .611 r
.21175 .28491 .2126 .28891 .21525 .27837 .2141 .27743 Mtetra
.858 .791 .785 r
.2141 .27743 .21525 .27837 .21708 .27602 .21591 .27524 Mtetra
.682 .822 .95 r
.21591 .27524 .21708 .27602 .21873 .27541 .21758 .27455 Mtetra
.539 .762 .98 r
.21758 .27455 .21873 .27541 .22034 .27529 .2192 .27428 Mtetra
.625 .756 .941 r
.2192 .27428 .22034 .27529 .22197 .27499 .22084 .2738 Mtetra
.684 .738 .892 r
.22084 .2738 .22197 .27499 .22363 .27439 .22251 .27308 Mtetra
.669 .714 .882 r
.22251 .27308 .22363 .27439 .22529 .27374 .22418 .27241 Mtetra
.677 .714 .877 r
.22418 .27241 .22529 .27374 .22699 .2727 .22585 .27171 Mtetra
.645 .767 .937 r
.22585 .27171 .22699 .2727 .2287 .27163 .2275 .27116 Mtetra
.253 .711 .952 r
.2275 .27116 .2287 .27163 .23035 .27112 .22911 .27117 Mtetra
.818 .367 .163 r
.22911 .27117 .23035 .27112 .23179 .27288 .23048 .27359 Mtetra
.949 .682 .497 r
.23048 .27359 .23179 .27288 .21476 .47078 .21286 .47692 Mtetra
.786 .479 .469 r
.21286 .47692 .21476 .47078 .21498 .48667 .21377 .48548 Mtetra
.61 .106 0 r
.21377 .48548 .21498 .48667 .21652 .48864 .21533 .4873 Mtetra
.49 .657 .935 r
.21533 .4873 .21652 .48864 .21827 .48838 .21706 .48725 Mtetra
.742 .776 .88 r
.21706 .48725 .21827 .48838 .22011 .48714 .21889 .48615 Mtetra
.896 .781 .726 r
.21889 .48615 .22011 .48714 .22211 .48424 .22093 .48272 Mtetra
.951 .689 .504 r
.22093 .48272 .22211 .48424 .22451 .47681 .24008 .29216 Mtetra
.576 .336 .515 r
.24008 .29216 .22451 .47681 .24478 .27194 .24403 .26668 Mtetra
.704 .517 .633 r
.24403 .26668 .24478 .27194 .24674 .26813 .24591 .26381 Mtetra
.606 .469 .668 r
.24591 .26381 .24674 .26813 .24843 .26742 .2476 .263 Mtetra
.557 .433 .667 r
.2476 .263 .24843 .26742 .25007 .2672 .24925 .26273 Mtetra
.558 .432 .665 r
.24925 .26273 .25007 .2672 .25179 .26615 .25089 .26244 Mtetra
.592 .478 .693 r
.25089 .26244 .25179 .26615 .25358 .26426 .25257 .26189 Mtetra
.619 .568 .775 r
.25257 .26189 .25358 .26426 .25535 .26262 .25424 .26135 Mtetra
.653 .717 .895 r
.25424 .26135 .25535 .26262 .25707 .26155 .25592 .26075 Mtetra
.665 .818 .957 r
.25592 .26075 .25707 .26155 .25874 .26099 .2576 .26011 Mtetra
.673 .801 .944 r
.2576 .26011 .25874 .26099 .26041 .26057 .25929 .25944 Mtetra
.68 .753 .907 r
.25929 .25944 .26041 .26057 .26208 .26009 .26098 .25874 Mtetra
.676 .713 .876 r
.26098 .25874 .26208 .26009 .26376 .25947 .26267 .25803 Mtetra
.66 .694 .87 r
.26267 .25803 .26376 .25947 .26545 .2588 .26436 .25739 Mtetra
.663 .698 .873 r
.26436 .25739 .26545 .2588 .26716 .2579 .26605 .25673 Mtetra
.649 .737 .914 r
.26605 .25673 .26716 .2579 .26888 .25687 .26773 .25617 Mtetra
.379 .731 .99 r
.26773 .25617 .26888 .25687 .27057 .25624 .26937 .25612 Mtetra
.775 .28 .035 r
.26937 .25612 .27057 .25624 .27215 .25698 .27085 .25809 Mtetra
.953 .682 .486 r
.27085 .25809 .27215 .25698 .27341 .2616 .25591 .46053 Mtetra
.534 .295 .499 r
.25591 .46053 .27341 .2616 .25846 .46649 .25681 .47089 Mtetra
.631 .292 .378 r
.25681 .47089 .25846 .46649 .2599 .47046 .25841 .47284 Mtetra
.382 0 .141 r
.25841 .47284 .2599 .47046 .26168 .47012 .2602 .47257 Mtetra
.252 0 .077 r
.2602 .47257 .26168 .47012 .26352 .46917 .26203 .47175 Mtetra
.253 0 .091 r
.26203 .47175 .26352 .46917 .26531 .46887 .26386 .47088 Mtetra
.262 0 .026 r
.26386 .47088 .26531 .46887 .26701 .46966 .26568 .47028 Mtetra
0 0 0 r
.26568 .47028 .26701 .46966 .26873 .47024 .2675 .4696 Mtetra
.692 .87 .966 r
.2675 .4696 .26873 .47024 .27049 .47037 .26933 .46877 Mtetra
.712 .704 .84 r
.26933 .46877 .27049 .47037 .27229 .47001 .27118 .46773 Mtetra
.688 .624 .779 r
.27118 .46773 .27229 .47001 .2741 .46947 .27304 .46665 Mtetra
.629 .555 .753 r
.27304 .46665 .2741 .46947 .27591 .46896 .27487 .46592 Mtetra
.557 .501 .748 r
.27487 .46592 .27591 .46896 .27772 .46857 .27666 .46572 Mtetra
.624 .551 .752 r
.27666 .46572 .27772 .46857 .27956 .46776 .27848 .46503 Mtetra
.774 .634 .706 r
.27848 .46503 .27956 .46776 .28148 .46582 .28045 .46249 Mtetra
.912 .676 .567 r
.28045 .46249 .28148 .46582 .28363 .46073 .2833 .44795 Mtetra
.944 .675 .497 r
.2833 .44795 .28363 .46073 .30038 .25545 .29983 .24676 Mtetra
.665 .456 .592 r
.29983 .24676 .30038 .25545 .30264 .2473 .30175 .24331 Mtetra
.624 .49 .679 r
.30175 .24331 .30264 .2473 .30448 .24493 .30348 .24236 Mtetra
.593 .54 .765 r
.30348 .24236 .30448 .24493 .30625 .24345 .30518 .24195 Mtetra
.585 .656 .886 r
.30518 .24195 .30625 .24345 .30799 .24243 .30687 .24163 Mtetra
.669 .822 .957 r
.30687 .24163 .30799 .24243 .30971 .24169 .30859 .24095 Mtetra
.667 .837 .964 r
.30859 .24095 .30971 .24169 .31142 .24113 .3103 .24028 Mtetra
.676 .813 .949 r
.3103 .24028 .31142 .24113 .31313 .24063 .31203 .23958 Mtetra
.684 .774 .919 r
.31203 .23958 .31313 .24063 .31484 .24009 .31375 .23885 Mtetra
.668 .734 .9 r
.31375 .23885 .31484 .24009 .31655 .23953 .31547 .23819 Mtetra
.66 .712 .887 r
.31547 .23819 .31655 .23953 .31828 .23879 .31719 .23755 Mtetra
.663 .73 .9 r
.31719 .23755 .31828 .23879 .32003 .23772 .31891 .2369 Mtetra
.485 .755 .99 r
.31891 .2369 .32003 .23772 .32176 .23699 .32061 .23672 Mtetra
.602 .03 0 r
.32061 .23672 .32176 .23699 .32342 .23726 .32221 .23794 Mtetra
.931 .614 .417 r
.32221 .23794 .32342 .23726 .32487 .24081 .32299 .25162 Mtetra
.945 .668 .481 r
.32299 .25162 .32487 .24081 .31332 .44534 .31167 .45154 Mtetra
.639 .32 .415 r
.31167 .45154 .31332 .44534 .31471 .45178 .3133 .45427 Mtetra
.401 .001 .16 r
.3133 .45427 .31471 .45178 .31652 .4516 .31512 .45406 Mtetra
.258 0 .083 r
.31512 .45406 .31652 .4516 .31839 .45065 .31698 .45323 Mtetra
.228 0 .081 r
.31698 .45323 .31839 .45065 .32024 .45 .31886 .45223 Mtetra
.302 0 .079 r
.31886 .45223 .32024 .45 .322 .45088 .32071 .45167 Mtetra
0 0 0 r
.32071 .45167 .322 .45088 .32377 .45154 .32256 .45105 Mtetra
.648 .895 .983 r
.32256 .45105 .32377 .45154 .32557 .45176 .32442 .4503 Mtetra
.719 .729 .859 r
.32442 .4503 .32557 .45176 .32742 .45131 .3263 .44925 Mtetra
.7 .652 .798 r
.3263 .44925 .32742 .45131 .32928 .45067 .32819 .44814 Mtetra
.658 .593 .77 r
.32819 .44814 .32928 .45067 .33114 .45004 .33007 .44722 Mtetra
.548 .512 .768 r
.33007 .44722 .33114 .45004 .33297 .4498 .3319 .44708 Mtetra
.611 .554 .766 r
.3319 .44708 .33297 .4498 .33483 .44919 .33376 .44651 Mtetra
.739 .622 .729 r
.33376 .44651 .33483 .44919 .33675 .44769 .33569 .44462 Mtetra
.901 .676 .589 r
.33569 .44462 .33675 .44769 .33884 .44312 .33808 .43478 Mtetra
.955 .681 .479 r
.33808 .43478 .33884 .44312 .35211 .24023 .35164 .2282 Mtetra
.649 .429 .572 r
.35164 .2282 .35211 .24023 .3545 .2282 .35359 .22398 Mtetra
.628 .487 .672 r
.35359 .22398 .3545 .2282 .35635 .22566 .35535 .22292 Mtetra
.597 .532 .753 r
.35535 .22292 .35635 .22566 .35814 .2241 .35709 .22246 Mtetra
.557 .624 .874 r
.35709 .22246 .35814 .2241 .35991 .22305 .35881 .22225 Mtetra
.64 .82 .969 r
.35881 .22225 .35991 .22305 .36167 .22229 .36056 .22165 Mtetra
.629 .852 .984 r
.36056 .22165 .36167 .22229 .36341 .22174 .36231 .22105 Mtetra
.641 .846 .979 r
.36231 .22105 .36341 .22174 .36515 .22128 .36406 .22043 Mtetra
.668 .817 .955 r
.36406 .22043 .36515 .22128 .36689 .22076 .36581 .21975 Mtetra
.675 .784 .932 r
.36581 .21975 .36689 .22076 .36864 .22024 .36757 .21905 Mtetra
.676 .748 .906 r
.36757 .21905 .36864 .22024 .37039 .2197 .36932 .21834 Mtetra
.678 .72 .881 r
.36932 .21834 .37039 .2197 .37214 .21907 .37109 .21759 Mtetra
.665 .697 .869 r
.37109 .21759 .37214 .21907 .3739 .21839 .37284 .2169 Mtetra
.645 .686 .874 r
.37284 .2169 .3739 .21839 .37566 .21766 .3746 .2163 Mtetra
.577 .682 .912 r
.3746 .2163 .37566 .21766 .37743 .21685 .37634 .21599 Mtetra
.511 .763 .987 r
.37634 .21599 .37743 .21685 .3792 .21602 .37808 .21575 Mtetra
.374 .816 .951 r
.37808 .21575 .3792 .21602 .38097 .21519 .37983 .21545 Mtetra
.62 .959 .844 r
.37983 .21545 .38097 .21519 .38275 .21413 .38161 .21432 Mtetra
.461 .888 .838 r
.38161 .21432 .38275 .21413 .38451 .2134 .38338 .21354 Mtetra
.143 0 0 r
.38338 .21354 .38451 .2134 .38625 .2133 .38512 .21364 Mtetra
.908 .539 .32 r
.38512 .21364 .38625 .2133 .38786 .21615 .38655 .22021 Mtetra
.96 .677 .455 r
.38655 .22021 .38786 .21615 .38065 .41724 .37899 .42763 Mtetra
.633 .336 .449 r
.37899 .42763 .38065 .41724 .38198 .4291 .38067 .4316 Mtetra
.432 .03 .175 r
.38067 .4316 .38198 .4291 .38384 .42916 .38254 .43155 Mtetra
.276 0 .087 r
.38254 .43155 .38384 .42916 .38575 .42828 .38445 .4308 Mtetra
.198 0 .063 r
.38445 .4308 .38575 .42828 .38766 .4272 .38637 .42968 Mtetra
.31 0 .113 r
.38637 .42968 .38766 .4272 .3895 .42807 .38827 .42904 Mtetra
.025 0 0 r
.38827 .42904 .3895 .42807 .39134 .42877 .39017 .42839 Mtetra
.571 .895 .986 r
.39017 .42839 .39134 .42877 .3932 .42913 .39207 .42774 Mtetra
.634 .719 .909 r
.39207 .42774 .3932 .42913 .3951 .42867 .39397 .42717 Mtetra
.642 .703 .891 r
.39397 .42717 .3951 .42867 .39701 .42801 .39588 .42655 Mtetra
.66 .716 .89 r
.39588 .42655 .39701 .42801 .39892 .42727 .39779 .42584 Mtetra
.718 .74 .869 r
.39779 .42584 .39892 .42727 .40082 .42677 .39971 .42479 Mtetra
.705 .666 .809 r
.39971 .42479 .40082 .42677 .40272 .42628 .40164 .42366 Mtetra
.676 .598 .761 r
.40164 .42366 .40272 .42628 .40463 .42576 .40356 .42255 Mtetra
.616 .53 .734 r
.40356 .42255 .40463 .42576 .40654 .42507 .40548 .42184 Mtetra
.601 .52 .735 r
.40548 .42184 .40654 .42507 .40846 .42434 .40739 .42125 Mtetra
.598 .527 .745 r
.40739 .42125 .40846 .42434 .41037 .4236 .4093 .42072 Mtetra
.536 .504 .767 r
.4093 .42072 .41037 .4236 .41228 .42331 .41119 .42065 Mtetra
.599 .555 .776 r
.41119 .42065 .41228 .42331 .41419 .42278 .41311 .42016 Mtetra
.699 .61 .754 r
.41311 .42016 .41419 .42278 .41612 .42167 .41505 .41882 Mtetra
.888 .68 .616 r
.41505 .41882 .41612 .42167 .41816 .4176 .41717 .41196 Mtetra
.964 .684 .454 r
.41717 .41196 .41816 .4176 .42055 .40238 .42594 .20193 Mtetra
.526 .293 .505 r
.42594 .20193 .42055 .40238 .42883 .20117 .42789 .19643 Mtetra
.644 .486 .654 r
.42789 .19643 .42883 .20117 .43066 .1994 .42971 .19496 Mtetra
.588 .456 .669 r
.42971 .19496 .43066 .1994 .43245 .19886 .43151 .19433 Mtetra
.553 .431 .668 r
.43151 .19433 .43245 .19886 .43424 .19859 .43329 .19407 Mtetra
.581 .45 .667 r
.43329 .19407 .43424 .19859 .43607 .19675 .43509 .1935 Mtetra
.604 .511 .721 r
.43509 .1935 .43607 .19675 .43791 .19487 .43688 .19289 Mtetra
.636 .623 .82 r
.43688 .19289 .43791 .19487 .43973 .19328 .43868 .19227 Mtetra
.667 .789 .94 r
.43868 .19227 .43973 .19328 .44154 .19237 .44049 .19159 Mtetra
.667 .839 .966 r
.44049 .19159 .44154 .19237 .44334 .19171 .44229 .19087 Mtetra
.672 .829 .959 r
.44229 .19087 .44334 .19171 .44514 .19117 .4441 .19015 Mtetra
.681 .792 .933 r
.4441 .19015 .44514 .19117 .44694 .19062 .4459 .18941 Mtetra
.672 .75 .909 r
.4459 .18941 .44694 .19062 .44875 .19007 .44771 .1887 Mtetra
.654 .716 .894 r
.44771 .1887 .44875 .19007 .45055 .18947 .44952 .18806 Mtetra
.595 .685 .905 r
.44952 .18806 .45055 .18947 .45236 .1887 .45132 .18767 Mtetra
.544 .741 .967 r
.45132 .18767 .45236 .1887 .45418 .18786 .45312 .18739 Mtetra
.429 .814 .989 r
.45312 .18739 .45418 .18786 .45599 .18702 .45492 .18711 Mtetra
.606 .954 .884 r
.45492 .18711 .45599 .18702 .45781 .18596 .45674 .18609 Mtetra
.541 .927 .863 r
.45674 .18609 .45781 .18596 .45963 .18511 .45856 .18517 Mtetra
.169 .707 .77 r
.45856 .18517 .45963 .18511 .46144 .18474 .46037 .18488 Mtetra
.849 .404 .155 r
.46037 .18488 .46144 .18474 .4632 .18639 .4621 .18841 Mtetra
.968 .678 .427 r
.4621 .18841 .4632 .18639 .46488 .19299 .45967 .39741 Mtetra
.524 .286 .496 r
.45967 .39741 .46488 .19299 .46269 .40011 .46149 .40353 Mtetra
.529 .158 .281 r
.46149 .40353 .46269 .40011 .46457 .40297 .46342 .40413 Mtetra
.083 0 0 r
.46342 .40413 .46457 .40297 .4665 .40367 .46537 .40344 Mtetra
.718 .963 .942 r
.46537 .40344 .4665 .40367 .46844 .40362 .46734 .40226 Mtetra
.686 .748 .898 r
.46734 .40226 .46844 .40362 .4704 .40306 .4693 .40141 Mtetra
.653 .691 .873 r
.4693 .40141 .4704 .40306 .47236 .40218 .47126 .4007 Mtetra
.656 .718 .894 r
.47126 .4007 .47236 .40218 .47433 .40115 .47322 .4 Mtetra
.66 .777 .936 r
.47322 .4 .47433 .40115 .47629 .40029 .47518 .39928 Mtetra
.657 .805 .954 r
.47518 .39928 .47629 .40029 .47825 .39953 .47715 .39857 Mtetra
.652 .813 .96 r
.47715 .39857 .47825 .39953 .48022 .39881 .47911 .39787 Mtetra
.645 .816 .965 r
.47911 .39787 .48022 .39881 .48218 .39808 .48108 .39718 Mtetra
.637 .822 .971 r
.48108 .39718 .48218 .39808 .48415 .39738 .48304 .39652 Mtetra
.629 .828 .977 r
.48304 .39652 .48415 .39738 .48612 .3967 .48501 .39588 Mtetra
.6 .826 .986 r
.48501 .39588 .48612 .3967 .48809 .39604 .48698 .39532 Mtetra
.589 .842 .993 r
.48698 .39532 .48809 .39604 .49005 .39543 .48895 .39475 Mtetra
.611 .861 .991 r
.48895 .39475 .49005 .39543 .49203 .39486 .49092 .39411 Mtetra
.71 .873 .958 r
.49092 .39411 .49203 .39486 .494 .39439 .4929 .39313 Mtetra
.741 .784 .888 r
.4929 .39313 .494 .39439 .49597 .39397 .49488 .39197 Mtetra
.708 .671 .812 r
.49488 .39197 .49597 .39397 .49794 .39355 .49686 .3908 Mtetra
.637 .573 .766 r
.49686 .3908 .49794 .39355 .49992 .39305 .49884 .38999 Mtetra
.598 .531 .751 r
.49884 .38999 .49992 .39305 .5019 .39252 .50082 .38945 Mtetra
.587 .525 .752 r
.50082 .38945 .5019 .39252 .50388 .39198 .5028 .389 Mtetra
.596 .535 .756 r
.5028 .389 .50388 .39198 .50586 .39151 .50478 .38849 Mtetra
.601 .535 .753 r
.50478 .38849 .50586 .39151 .50784 .39107 .50676 .38793 Mtetra
.6 .529 .746 r
.50676 .38793 .50784 .39107 .50983 .3906 .50875 .38736 Mtetra
.601 .523 .739 r
.50875 .38736 .50983 .3906 .51181 .39006 .51073 .38677 Mtetra
.602 .521 .736 r
.51073 .38677 .51181 .39006 .5138 .38945 .51272 .38617 Mtetra
.603 .522 .736 r
.51272 .38617 .5138 .38945 .51579 .38883 .51471 .38555 Mtetra
.605 .523 .736 r
.51471 .38555 .51579 .38883 .51778 .38819 .5167 .38492 Mtetra
.606 .524 .736 r
.5167 .38492 .51778 .38819 .51977 .38755 .51869 .38427 Mtetra
.607 .525 .736 r
.51869 .38427 .51977 .38755 .52177 .38689 .52069 .38362 Mtetra
.608 .526 .736 r
.52069 .38362 .52177 .38689 .52376 .38624 .52268 .38296 Mtetra
.609 .526 .736 r
.52268 .38296 .52376 .38624 .52576 .38557 .52468 .38229 Mtetra
.609 .526 .735 r
.52468 .38229 .52576 .38557 .52776 .38488 .52668 .38161 Mtetra
.611 .528 .736 r
.52668 .38161 .52776 .38488 .52976 .38412 .52868 .38092 Mtetra
.613 .532 .74 r
.52868 .38092 .52976 .38412 .53176 .38332 .53068 .38023 Mtetra
.615 .54 .747 r
.53068 .38023 .53176 .38332 .53376 .38251 .53268 .37954 Mtetra
.617 .548 .755 r
.53268 .37954 .53376 .38251 .53577 .38176 .53468 .37885 Mtetra
.617 .552 .759 r
.53468 .37885 .53577 .38176 .53777 .38107 .53669 .37817 Mtetra
.616 .553 .76 r
.53669 .37817 .53777 .38107 .53978 .38041 .5387 .3775 Mtetra
.614 .551 .76 r
.5387 .3775 .53978 .38041 .54179 .37975 .54071 .37684 Mtetra
.612 .55 .761 r
.54071 .37684 .54179 .37975 .5438 .3791 .54272 .3762 Mtetra
.613 .552 .762 r
.54272 .3762 .5438 .3791 .54581 .37845 .54473 .37556 Mtetra
.568 .527 .769 r
.54473 .37556 .54581 .37845 .54782 .37804 .54674 .37526 Mtetra
.568 .535 .778 r
.54674 .37526 .54782 .37804 .54984 .37763 .54876 .37497 Mtetra
.657 .592 .77 r
.54876 .37497 .54984 .37763 .55186 .37675 .55077 .374 Mtetra
.837 .67 .676 r
.55077 .374 .55186 .37675 .55385 .37409 .55276 .3702 Mtetra
.974 .682 .406 r
.55276 .3702 .55385 .37409 .55581 .36696 .55283 .16071 Mtetra
.535 .3 .505 r
.55283 .16071 .55581 .36696 .55566 .15649 .55462 .15043 Mtetra
.678 .487 .62 r
.55462 .15043 .55566 .15649 .5575 .15217 .55648 .14775 Mtetra
.607 .471 .671 r
.55648 .14775 .5575 .15217 .55938 .1512 .55835 .14686 Mtetra
.567 .448 .677 r
.55835 .14686 .55938 .1512 .56127 .15098 .56024 .14646 Mtetra
.569 .445 .671 r
.56024 .14646 .56127 .15098 .56316 .1507 .56213 .14602 Mtetra
.586 .451 .664 r
.56213 .14602 .56316 .1507 .56505 .15005 .56401 .14535 Mtetra
.585 .45 .663 r
.56401 .14535 .56505 .15005 .56694 .14942 .5659 .14468 Mtetra
.586 .45 .662 r
.5659 .14468 .56694 .14942 .56883 .14877 .56779 .14401 Mtetra
.586 .449 .662 r
.56779 .14401 .56883 .14877 .57072 .1481 .56968 .14332 Mtetra
.586 .449 .661 r
.56968 .14332 .57072 .1481 .57261 .14742 .57157 .14263 Mtetra
.587 .449 .661 r
.57157 .14263 .57261 .14742 .5745 .14673 .57346 .14193 Mtetra
.57346 .14193 .5745 .14673 .5764 .14604 .57535 .14123 Mtetra
.587 .449 .66 r
.57535 .14123 .5764 .14604 .57829 .14534 .57725 .14053 Mtetra
.57725 .14053 .57829 .14534 .58019 .14464 .57914 .13983 Mtetra
.57914 .13983 .58019 .14464 .58209 .14394 .58104 .13912 Mtetra
.58104 .13912 .58209 .14394 .58399 .14323 .58294 .13841 Mtetra
.58294 .13841 .58399 .14323 .58589 .14253 .58484 .1377 Mtetra
.58484 .1377 .58589 .14253 .58779 .14182 .58674 .13699 Mtetra
.58674 .13699 .58779 .14182 .58969 .14111 .58864 .13628 Mtetra
.58864 .13628 .58969 .14111 .5916 .14041 .59054 .13557 Mtetra
.59054 .13557 .5916 .14041 .5935 .1397 .59245 .13486 Mtetra
.59245 .13486 .5935 .1397 .59541 .13899 .59435 .13415 Mtetra
.59435 .13415 .59541 .13899 .59732 .13827 .59626 .13344 Mtetra
.59626 .13344 .59732 .13827 .59923 .13756 .59817 .13272 Mtetra
.59817 .13272 .59923 .13756 .60114 .13685 .60008 .13201 Mtetra
.60008 .13201 .60114 .13685 .60305 .13613 .60199 .13129 Mtetra
.60199 .13129 .60305 .13613 .60497 .13542 .6039 .13058 Mtetra
.6039 .13058 .60497 .13542 .60688 .1347 .60581 .12986 Mtetra
.60581 .12986 .60688 .1347 .6088 .13398 .60773 .12914 Mtetra
.60773 .12914 .6088 .13398 .61072 .13326 .60965 .12842 Mtetra
.60965 .12842 .61072 .13326 .61264 .13253 .61156 .1277 Mtetra
.588 .449 .66 r
.61156 .1277 .61264 .13253 .61456 .13181 .61348 .12697 Mtetra
.61348 .12697 .61456 .13181 .61648 .13108 .6154 .12625 Mtetra
.588 .45 .66 r
.6154 .12625 .61648 .13108 .6184 .13034 .61732 .12552 Mtetra
.588 .45 .661 r
.61732 .12552 .6184 .13034 .62032 .1296 .61925 .12479 Mtetra
.61925 .12479 .62032 .1296 .62225 .12886 .62117 .12406 Mtetra
.589 .451 .661 r
.62117 .12406 .62225 .12886 .62417 .12812 .6231 .12333 Mtetra
.589 .451 .662 r
.6231 .12333 .62417 .12812 .6261 .12737 .62502 .1226 Mtetra
.589 .452 .662 r
.62502 .1226 .6261 .12737 .62803 .12662 .62695 .12187 Mtetra
.589 .452 .663 r
.62695 .12187 .62803 .12662 .62996 .12588 .62888 .12114 Mtetra
.589 .453 .663 r
.62888 .12114 .62996 .12588 .63189 .12514 .63081 .12041 Mtetra
.589 .453 .664 r
.63081 .12041 .63189 .12514 .63383 .12443 .63274 .11969 Mtetra
.588 .452 .664 r
.63274 .11969 .63383 .12443 .63576 .12372 .63468 .11898 Mtetra
.587 .451 .664 r
.63468 .11898 .63576 .12372 .6377 .12312 .63661 .11828 Mtetra
.585 .448 .661 r
.63661 .11828 .6377 .12312 .63965 .12267 .63855 .11759 Mtetra
.581 .44 .654 r
.63855 .11759 .63965 .12267 .64159 .12197 .64049 .11691 Mtetra
.64049 .11691 .64159 .12197 .6435 .12059 .64243 .11623 Mtetra
.589 .463 .677 r
.64243 .11623 .6435 .12059 .64539 .11842 .64437 .11557 Mtetra
.615 .546 .754 r
.64437 .11557 .64539 .11842 .64728 .11651 .64632 .11491 Mtetra
.646 .691 .877 r
.64632 .11491 .64728 .11651 .64919 .11507 .64826 .11425 Mtetra
.636 .84 .979 r
.64826 .11425 .64919 .11507 .65113 .11428 .65021 .11358 Mtetra
.625 .865 .988 r
.65021 .11358 .65113 .11428 .65308 .11367 .65216 .1129 Mtetra
.638 .854 .982 r
.65216 .1129 .65308 .11367 .65504 .11314 .65411 .1122 Mtetra
.655 .822 .964 r
.65411 .1122 .65504 .11314 .65699 .11256 .65606 .11149 Mtetra
.665 .796 .945 r
.65606 .11149 .65699 .11256 .65895 .11198 .65801 .11075 Mtetra
.676 .768 .92 r
.65801 .11075 .65895 .11198 .6609 .11134 .65995 .10997 Mtetra
.69 .747 .895 r
.65995 .10997 .6609 .11134 .66285 .11058 .6619 .1091 Mtetra
.68 .726 .884 r
.6619 .1091 .66285 .11058 .6648 .10976 .66385 .10827 Mtetra
.676 .723 .885 r
.66385 .10827 .6648 .10976 .66674 .10875 .6658 .10746 Mtetra
.694 .764 .905 r
.6658 .10746 .66674 .10875 .66866 .10736 .66775 .10658 Mtetra
.541 .812 .996 r
.66775 .10658 .66866 .10736 .67061 .10645 .66972 .10617 Mtetra
.302 0 0 r
.66972 .10617 .67061 .10645 .67262 .10677 .67176 .107 Mtetra
.924 .535 .213 r
.67176 .107 .67262 .10677 .67494 .11302 .67424 .11641 Mtetra
.972 .661 .337 r
.67424 .11641 .67494 .11302 .688 .3265 .68701 .32547 Mtetra
.663 .182 0 r
.68701 .32547 .688 .3265 .69036 .33039 .68933 .3287 Mtetra
.426 .585 .907 r
.68933 .3287 .69036 .33039 .69252 .33044 .6915 .32893 Mtetra
.677 .739 .897 r
.6915 .32893 .69252 .33044 .69462 .32943 .69362 .32806 Mtetra
.86 .812 .8 r
.69362 .32806 .69462 .32943 .69666 .32724 .69565 .32572 Mtetra
.974 .758 .551 r
.69565 .32572 .69666 .32724 .69855 .32224 .69736 .31744 Mtetra
.976 .671 .346 r
.69736 .31744 .69855 .32224 .68901 .11295 .68761 .10314 Mtetra
.686 .459 .573 r
.68761 .10314 .68901 .11295 .69046 .10281 .68935 .09827 Mtetra
.624 .481 .667 r
.68935 .09827 .69046 .10281 .69233 .10036 .6913 .09712 Mtetra
.586 .507 .733 r
.6913 .09712 .69233 .10036 .69426 .09884 .69328 .09664 Mtetra
.553 .569 .824 r
.69328 .09664 .69426 .09884 .69622 .09777 .69529 .09644 Mtetra
.653 .743 .915 r
.69529 .09644 .69622 .09777 .69819 .09694 .69727 .09575 Mtetra
.659 .773 .933 r
.69727 .09575 .69819 .09694 .70017 .09627 .69925 .09503 Mtetra
.68 .772 .92 r
.69925 .09503 .70017 .09627 .70215 .0956 .70123 .09422 Mtetra
.761 .775 .865 r
.70123 .09422 .70215 .0956 .7041 .09433 .70317 .09291 Mtetra
.693 .743 .89 r
.70317 .09291 .7041 .09433 .70608 .09349 .70514 .09201 Mtetra
.471 .625 .919 r
.70514 .09201 .70608 .09349 .70811 .09362 .70718 .09204 Mtetra
.738 .335 0 r
.70718 .09204 .70811 .09362 .71052 .09948 .70953 .09715 Mtetra
.972 .66 .302 r
.70953 .09715 .71052 .09948 .72628 .31323 .72525 .31104 Mtetra
0 0 .378 r
.72525 .31104 .72628 .31323 .72875 .31745 .72774 .31573 Mtetra
.494 .619 .904 r
.72774 .31573 .72875 .31745 .73093 .31723 .72993 .31571 Mtetra
.673 .739 .9 r
.72993 .31571 .73093 .31723 .73306 .31623 .73208 .31485 Mtetra
.751 .79 .885 r
.73208 .31485 .73306 .31623 .73517 .31493 .73419 .31355 Mtetra
.617 .739 .933 r
.73419 .31355 .73517 .31493 .73737 .31488 .73635 .31296 Mtetra
.69 .689 .845 r
.73635 .31296 .73737 .31488 .73954 .31439 .73849 .31193 Mtetra
.763 .667 .757 r
.73849 .31193 .73954 .31439 .74165 .31298 .74056 .30994 Mtetra
.93 .696 .564 r
.74056 .30994 .74165 .31298 .74339 .3062 .74219 .30162 Mtetra
.974 .666 .324 r
.74219 .30162 .74339 .3062 .73034 .09004 .72939 .0881 Mtetra
.932 .744 .627 r
.72939 .0881 .73034 .09004 .73197 .08402 .73109 .08301 Mtetra
.773 .851 .909 r
.73109 .08301 .73197 .08402 .73394 .08277 .73305 .08172 Mtetra
.629 .796 .962 r
.73305 .08172 .73394 .08277 .73595 .08226 .73506 .0811 Mtetra
.542 .729 .961 r
.73506 .0811 .73595 .08226 .73801 .08215 .7371 .0808 Mtetra
.739 .753 .864 r
.09653 .31889 .0977 .32 .0993 .31928 .09817 .31789 Mtetra
.701 .701 .847 r
.09817 .31789 .0993 .31928 .1009 .31859 .09978 .31706 Mtetra
.635 .659 .856 r
.09978 .31706 .1009 .31859 .10249 .31798 .10136 .31656 Mtetra
.171 .447 .876 r
.10136 .31656 .10249 .31798 .10409 .31726 .10278 .31716 Mtetra
.771 .286 .078 r
.10278 .31716 .10409 .31726 .10564 .31692 .10406 .31885 Mtetra
.824 .493 .429 r
.10406 .31885 .10564 .31692 .1071 .3173 .1049 .32388 Mtetra
.929 .672 .528 r
.1049 .32388 .1071 .3173 .1079 .32263 .07994 .52296 Mtetra
.522 .286 .497 r
.07994 .52296 .1079 .32263 .08258 .5258 .08093 .52759 Mtetra
.691 .3 .302 r
.08093 .52759 .08258 .5258 .0836 .53026 .08231 .52937 Mtetra
.2 .6 .946 r
.08231 .52937 .0836 .53026 .08518 .53056 .08389 .52965 Mtetra
.584 .772 .969 r
.08389 .52965 .08518 .53056 .08687 .53 .08556 .52927 Mtetra
.738 .836 .925 r
.08556 .52927 .08687 .53 .08863 .52898 .08731 .5283 Mtetra
.848 .831 .83 r
.08731 .5283 .08863 .52898 .09031 .52845 .08918 .52641 Mtetra
.823 .681 .706 r
.08918 .52641 .09031 .52845 .09205 .52756 .09121 .52329 Mtetra
.823 .616 .623 r
.09121 .52329 .09205 .52756 .0939 .52586 .0937 .51653 Mtetra
.93 .676 .533 r
.0937 .51653 .0939 .52586 .09643 .51878 .12119 .31546 Mtetra
.526 .294 .505 r
.12119 .31546 .09643 .51878 .12417 .31432 .12338 .31024 Mtetra
.725 .553 .656 r
.12338 .31024 .12417 .31432 .12634 .30924 .12524 .30761 Mtetra
.701 .672 .818 r
.12524 .30761 .12634 .30924 .12803 .30791 .12688 .3067 Mtetra
.608 .705 .912 r
.12688 .3067 .12803 .30791 .12962 .3074 .12846 .30631 Mtetra
.528 .701 .949 r
.12846 .30631 .12962 .3074 .13117 .30725 .13001 .30614 Mtetra
.67 .743 .905 r
.13001 .30614 .13117 .30725 .13276 .30672 .13161 .30551 Mtetra
.691 .73 .88 r
.13161 .30551 .13276 .30672 .13437 .30612 .13323 .30476 Mtetra
.688 .706 .861 r
.13323 .30476 .13437 .30612 .13597 .30551 .13486 .30401 Mtetra
.697 .688 .837 r
.13486 .30401 .13597 .30551 .13759 .30484 .1365 .30317 Mtetra
.666 .654 .829 r
.1365 .30317 .13759 .30484 .1392 .30419 .13812 .30247 Mtetra
.606 .624 .843 r
.13812 .30247 .1392 .30419 .1408 .30363 .1397 .30208 Mtetra
.274 .485 .881 r
.1397 .30208 .1408 .30363 .14242 .30296 .14117 .30258 Mtetra
.744 .224 0 r
.14117 .30258 .14242 .30296 .144 .30259 .14252 .30416 Mtetra
.828 .484 .404 r
.14252 .30416 .144 .30259 .1455 .30291 .1435 .30872 Mtetra
.934 .674 .52 r
.1435 .30872 .1455 .30291 .14649 .30747 .12071 .50933 Mtetra
.523 .286 .497 r
.12071 .50933 .14649 .30747 .12345 .51164 .12175 .51433 Mtetra
.669 .304 .344 r
.12175 .51433 .12345 .51164 .12451 .51654 .12317 .51622 Mtetra
0 .507 .755 r
.12317 .51622 .12451 .51654 .12609 .51715 .12479 .51649 Mtetra
.593 .832 .99 r
.12479 .51649 .12609 .51715 .1278 .51664 .1265 .51601 Mtetra
.753 .863 .929 r
.1265 .51601 .1278 .51664 .12957 .51564 .12827 .51496 Mtetra
.842 .84 .843 r
.12827 .51496 .12957 .51564 .1313 .51501 .13014 .51317 Mtetra
.825 .698 .723 r
.13014 .51317 .1313 .51501 .13305 .51418 .13213 .51034 Mtetra
.814 .617 .637 r
.13213 .51034 .13305 .51418 .13489 .51263 .13442 .50494 Mtetra
.936 .68 .525 r
.13442 .50494 .13489 .51263 .13719 .50716 .15967 .303 Mtetra
.529 .296 .506 r
.15967 .303 .13719 .50716 .16268 .30155 .162 .2964 Mtetra
.71 .523 .634 r
.162 .2964 .16268 .30155 .16496 .29529 .16389 .29345 Mtetra
.721 .657 .786 r
.16389 .29345 .16496 .29529 .16672 .29355 .16558 .29228 Mtetra
.628 .704 .9 r
.16558 .29228 .16672 .29355 .16834 .29293 .16719 .29181 Mtetra
.538 .701 .945 r
.16719 .29181 .16834 .29293 .16993 .29271 .16877 .29161 Mtetra
.67 .749 .909 r
.16877 .29161 .16993 .29271 .17154 .29218 .1704 .29097 Mtetra
.688 .733 .885 r
.1704 .29097 .17154 .29218 .17318 .29153 .17205 .29024 Mtetra
.635 .703 .896 r
.17205 .29024 .17318 .29153 .1748 .29093 .17366 .28974 Mtetra
.342 .596 .941 r
.17366 .28974 .1748 .29093 .17645 .2902 .1752 .28998 Mtetra
.638 .079 0 r
.1752 .28998 .17645 .2902 .17807 .28966 .17663 .29113 Mtetra
.783 .408 .347 r
.17663 .29113 .17807 .28966 .17963 .2897 .17786 .29415 Mtetra
.939 .676 .511 r
.17786 .29415 .17963 .2897 .18087 .29268 .15736 .49328 Mtetra
.528 .29 .498 r
.15736 .49328 .18087 .29268 .1601 .49588 .15821 .50077 Mtetra
.644 .318 .405 r
.15821 .50077 .1601 .49588 .16098 .50313 .15963 .50305 Mtetra
0 .551 .711 r
.15963 .50305 .16098 .50313 .16256 .50405 .1613 .50314 Mtetra
.721 .809 .92 r
.1613 .50314 .16256 .50405 .16431 .50339 .16309 .50223 Mtetra
.771 .77 .852 r
.16309 .50223 .16431 .50339 .16613 .50216 .16491 .50091 Mtetra
.736 .751 .864 r
.16491 .50091 .16613 .50216 .16793 .50111 .16671 .49983 Mtetra
.695 .738 .884 r
.16671 .49983 .16793 .50111 .1697 .50024 .16849 .499 Mtetra
.676 .74 .898 r
.16849 .499 .1697 .50024 .17148 .49943 .17025 .49828 Mtetra
.644 .748 .925 r
.17025 .49828 .17148 .49943 .17323 .49876 .172 .4977 Mtetra
.604 .754 .95 r
.172 .4977 .17323 .49876 .17498 .49825 .17373 .49727 Mtetra
.562 .756 .969 r
.17373 .49727 .17498 .49825 .17671 .49784 .17546 .49694 Mtetra
.381 .698 .983 r
.17546 .49694 .17671 .49784 .17843 .4976 .17715 .49696 Mtetra
.304 .714 .976 r
.17715 .49696 .17843 .4976 .18014 .49741 .17884 .49698 Mtetra
.482 .84 .994 r
.17884 .49698 .18014 .49741 .18187 .49711 .18058 .49661 Mtetra
.809 .89 .902 r
.18058 .49661 .18187 .49711 .18359 .49681 .18242 .49522 Mtetra
.837 .723 .739 r
.18242 .49522 .18359 .49681 .18535 .49622 .18439 .49251 Mtetra
.816 .621 .64 r
.18439 .49251 .18535 .49622 .18719 .49492 .18662 .48737 Mtetra
.941 .681 .514 r
.18662 .48737 .18719 .49492 .18934 .49044 .20876 .28628 Mtetra
.531 .298 .506 r
.20876 .28628 .18934 .49044 .21175 .28491 .21111 .27888 Mtetra
.698 .503 .621 r
.21111 .27888 .21175 .28491 .2141 .27743 .21302 .27573 Mtetra
.758 .688 .784 r
.21302 .27573 .2141 .27743 .21591 .27524 .21476 .27426 Mtetra
.672 .776 .928 r
.21476 .27426 .21591 .27524 .21758 .27455 .21642 .27361 Mtetra
.594 .764 .96 r
.21642 .27361 .21758 .27455 .2192 .27428 .21806 .27322 Mtetra
.69 .765 .909 r
.21806 .27322 .2192 .27428 .22084 .2738 .21973 .27248 Mtetra
.718 .727 .857 r
.21973 .27248 .22084 .2738 .22251 .27308 .22142 .27154 Mtetra
.666 .678 .852 r
.22142 .27154 .22251 .27308 .22418 .27241 .22309 .27086 Mtetra
.468 .59 .892 r
.22309 .27086 .22418 .27241 .22585 .27171 .22468 .27094 Mtetra
.487 0 0 r
.22468 .27094 .22585 .27171 .2275 .27116 .22617 .2721 Mtetra
.807 .412 .304 r
.22617 .2721 .2275 .27116 .22911 .27117 .22749 .27514 Mtetra
.945 .677 .499 r
.22749 .27514 .22911 .27117 .23048 .27359 .21012 .47387 Mtetra
.531 .292 .499 r
.21012 .47387 .23048 .27359 .21286 .47692 .211 .48269 Mtetra
.641 .322 .416 r
.211 .48269 .21286 .47692 .21377 .48548 .21248 .48524 Mtetra
.526 0 0 r
.21248 .48524 .21377 .48548 .21533 .4873 .21411 .48621 Mtetra
.425 .679 .969 r
.21411 .48621 .21533 .4873 .21706 .48725 .21583 .48623 Mtetra
.71 .793 .916 r
.21583 .48623 .21706 .48725 .21889 .48615 .21764 .48535 Mtetra
.903 .802 .738 r
.21764 .48535 .21889 .48615 .22093 .48272 .21967 .48209 Mtetra
.952 .712 .539 r
.21967 .48209 .22093 .48272 .24008 .29216 .22361 .45809 Mtetra
0 0 .009 r
.22361 .45809 .24008 .29216 .24403 .26668 .24293 .26523 Mtetra
.857 .732 .725 r
.24293 .26523 .24403 .26668 .24591 .26381 .24482 .26232 Mtetra
.692 .694 .848 r
.24482 .26232 .24591 .26381 .2476 .263 .24651 .26149 Mtetra
.577 .648 .884 r
.24651 .26149 .2476 .263 .24925 .26273 .24816 .26121 Mtetra
.563 .641 .886 r
.24816 .26121 .24925 .26273 .25089 .26244 .2498 .26098 Mtetra
.611 .672 .884 r
.2498 .26098 .25089 .26244 .25257 .26189 .25146 .26057 Mtetra
.615 .695 .901 r
.25146 .26057 .25257 .26189 .25424 .26135 .25312 .26013 Mtetra
.655 .729 .904 r
.25312 .26013 .25424 .26135 .25592 .26075 .2548 .25954 Mtetra
.693 .74 .887 r
.2548 .25954 .25592 .26075 .2576 .26011 .2565 .25876 Mtetra
.695 .718 .867 r
.2565 .25876 .2576 .26011 .25929 .25944 .2582 .25795 Mtetra
.697 .697 .846 r
.2582 .25795 .25929 .25944 .26098 .25874 .2599 .25708 Mtetra
.684 .671 .83 r
.2599 .25708 .26098 .25874 .26267 .25803 .26161 .25625 Mtetra
.638 .637 .833 r
.26161 .25625 .26267 .25803 .26436 .25739 .26329 .25568 Mtetra
.494 .579 .87 r
.26329 .25568 .26436 .25739 .26605 .25673 .26492 .25571 Mtetra
0 .212 .69 r
.26492 .25571 .26605 .25673 .26773 .25617 .26647 .25677 Mtetra
.81 .39 .247 r
.26647 .25677 .26773 .25617 .26937 .25612 .26788 .25955 Mtetra
.949 .678 .489 r
.26788 .25955 .26937 .25612 .27085 .25809 .25308 .45791 Mtetra
.534 .295 .499 r
.25308 .45791 .27085 .25809 .25591 .46053 .25396 .46847 Mtetra
.622 .319 .435 r
.25396 .46847 .25591 .46053 .25681 .47089 .25549 .47124 Mtetra
.557 .008 0 r
.25549 .47124 .25681 .47089 .25841 .47284 .25718 .47212 Mtetra
.477 .785 .998 r
.25718 .47212 .25841 .47284 .2602 .47257 .25896 .47188 Mtetra
.632 .845 .982 r
.25896 .47188 .2602 .47257 .26203 .47175 .26078 .47126 Mtetra
.631 .885 .987 r
.26078 .47126 .26203 .47175 .26386 .47088 .2626 .47057 Mtetra
.554 .893 .983 r
.2626 .47057 .26386 .47088 .26568 .47028 .26441 .46997 Mtetra
.665 .927 .973 r
.26441 .46997 .26568 .47028 .2675 .4696 .26625 .46912 Mtetra
.825 .902 .894 r
.26625 .46912 .2675 .4696 .26933 .46877 .26814 .46758 Mtetra
.87 .774 .754 r
.26814 .46758 .26933 .46877 .27118 .46773 .27013 .46478 Mtetra
.823 .647 .665 r
.27013 .46478 .27118 .46773 .27304 .46665 .27222 .46066 Mtetra
.743 .539 .619 r
.27222 .46066 .27304 .46665 .27487 .46592 .27433 .45615 Mtetra
.532 .352 .583 r
.27433 .45615 .27487 .46592 .27666 .46572 .27612 .45596 Mtetra
.537 .357 .584 r
.27612 .45596 .27666 .46572 .27848 .46503 .27791 .45565 Mtetra
.743 .516 .586 r
.27791 .45565 .27848 .46503 .28045 .46249 .28024 .44833 Mtetra
.943 .673 .498 r
.28024 .44833 .28045 .46249 .2833 .44795 .29684 .24857 Mtetra
.524 .292 .504 r
.29684 .24857 .2833 .44795 .29983 .24676 .29884 .24402 Mtetra
.756 .616 .704 r
.29884 .24402 .29983 .24676 .30175 .24331 .30067 .24182 Mtetra
.668 .691 .863 r
.30067 .24182 .30175 .24331 .30348 .24236 .30239 .24112 Mtetra
.586 .705 .925 r
.30239 .24112 .30348 .24236 .30518 .24195 .30408 .24078 Mtetra
.594 .721 .933 r
.30408 .24078 .30518 .24195 .30687 .24163 .30577 .2404 Mtetra
.694 .743 .889 r
.30577 .2404 .30687 .24163 .30859 .24095 .3075 .23961 Mtetra
.696 .723 .871 r
.3075 .23961 .30859 .24095 .3103 .24028 .30923 .23878 Mtetra
.694 .7 .852 r
.30923 .23878 .3103 .24028 .31203 .23958 .31096 .23793 Mtetra
.689 .677 .834 r
.31096 .23793 .31203 .23958 .31375 .23885 .3127 .23707 Mtetra
.647 .643 .832 r
.3127 .23707 .31375 .23885 .31547 .23819 .31442 .23643 Mtetra
.544 .6 .86 r
.31442 .23643 .31547 .23819 .31719 .23755 .3161 .23629 Mtetra
.001 .375 .839 r
.3161 .23629 .31719 .23755 .31891 .2369 .31772 .23714 Mtetra
.786 .318 .127 r
.31772 .23714 .31891 .2369 .32061 .23672 .31925 .23938 Mtetra
.887 .567 .438 r
.31925 .23938 .32061 .23672 .32221 .23794 .32016 .25107 Mtetra
.942 .664 .483 r
.32016 .25107 .32221 .23794 .32299 .25162 .30877 .44906 Mtetra
.519 .282 .495 r
.30877 .44906 .32299 .25162 .31167 .45154 .31036 .45238 Mtetra
.618 .125 .059 r
.31036 .45238 .31167 .45154 .3133 .45427 .31209 .45351 Mtetra
.524 .8 .996 r
.31209 .45351 .3133 .45427 .31512 .45406 .31392 .45317 Mtetra
.677 .82 .952 r
.31392 .45317 .31512 .45406 .31698 .45323 .31578 .45242 Mtetra
.693 .839 .953 r
.31578 .45242 .31698 .45323 .31886 .45223 .31765 .45159 Mtetra
.546 .831 .998 r
.31765 .45159 .31886 .45223 .32071 .45167 .31949 .45115 Mtetra
.613 .879 .99 r
.31949 .45115 .32071 .45167 .32256 .45105 .32135 .4505 Mtetra
.771 .901 .933 r
.32135 .4505 .32256 .45105 .32442 .4503 .32324 .44929 Mtetra
.881 .805 .77 r
.32324 .44929 .32442 .4503 .3263 .44925 .32522 .44661 Mtetra
.836 .666 .672 r
.32522 .44661 .3263 .44925 .32819 .44814 .32729 .44259 Mtetra
.783 .571 .614 r
.32729 .44259 .32819 .44814 .33007 .44722 .32945 .4369 Mtetra
.533 .35 .58 r
.32945 .4369 .33007 .44722 .3319 .44708 .33128 .43666 Mtetra
.521 .341 .578 r
.33128 .43666 .3319 .44708 .33376 .44651 .3331 .43668 Mtetra
.661 .45 .588 r
.3331 .43668 .33376 .44651 .33569 .44462 .33514 .43287 Mtetra
.951 .677 .483 r
.33514 .43287 .33569 .44462 .33808 .43478 .34867 .23011 Mtetra
.525 .292 .504 r
.34867 .23011 .33808 .43478 .35164 .2282 .35067 .22502 Mtetra
.758 .6 .682 r
.35067 .22502 .35164 .2282 .35359 .22398 .35252 .22244 Mtetra
.679 .691 .854 r
.35252 .22244 .35359 .22398 .35535 .22292 .35428 .22166 Mtetra
.59 .705 .923 r
.35428 .22166 .35535 .22292 .35709 .22246 .35601 .22129 Mtetra
.536 .703 .947 r
.35601 .22129 .35709 .22246 .35881 .22225 .35773 .22108 Mtetra
.645 .744 .922 r
.35773 .22108 .35881 .22225 .36056 .22165 .35948 .22051 Mtetra
.659 .753 .919 r
.35948 .22051 .36056 .22165 .36231 .22105 .36123 .21988 Mtetra
.675 .751 .908 r
.36123 .21988 .36231 .22105 .36406 .22043 .36298 .21917 Mtetra
.696 .743 .887 r
.36298 .21917 .36406 .22043 .36581 .21975 .36475 .21835 Mtetra
.694 .719 .868 r
.36475 .21835 .36581 .21975 .36757 .21905 .36651 .21751 Mtetra
.688 .696 .852 r
.36651 .21751 .36757 .21905 .36932 .21834 .36827 .21667 Mtetra
.694 .681 .833 r
.36827 .21667 .36932 .21834 .37109 .21759 .37004 .21576 Mtetra
.655 .645 .827 r
.37004 .21576 .37109 .21759 .37284 .2169 .3718 .21506 Mtetra
.578 .608 .847 r
.3718 .21506 .37284 .2169 .3746 .2163 .37354 .21477 Mtetra
0 .317 .806 r
.37354 .21477 .3746 .2163 .37634 .21599 .37522 .21585 Mtetra
.79 .297 .025 r
.37522 .21585 .37634 .21599 .37808 .21575 .37684 .21816 Mtetra
.808 .447 .373 r
.37684 .21816 .37808 .21575 .37983 .21545 .37833 .22304 Mtetra
.439 .151 .378 r
.37833 .22304 .37983 .21545 .38161 .21432 .38011 .22219 Mtetra
.403 .123 .37 r
.38011 .22219 .38161 .21432 .38338 .21354 .38192 .22076 Mtetra
.55 .247 .406 r
.38192 .22076 .38338 .21354 .38512 .21364 .38361 .22178 Mtetra
.955 .671 .461 r
.38361 .22178 .38512 .21364 .38655 .22021 .37607 .42436 Mtetra
.521 .284 .496 r
.37607 .42436 .38655 .22021 .37899 .42763 .37772 .429 Mtetra
.695 .254 .201 r
.37772 .429 .37899 .42763 .38067 .4316 .3795 .43088 Mtetra
.469 .787 .999 r
.3795 .43088 .38067 .4316 .38254 .43155 .38138 .43063 Mtetra
.662 .814 .956 r
.38138 .43063 .38254 .43155 .38445 .4308 .38329 .42991 Mtetra
.717 .835 .937 r
.38329 .42991 .38445 .4308 .38637 .42968 .3852 .42895 Mtetra
.631 .848 .983 r
.3852 .42895 .38637 .42968 .38827 .42904 .3871 .4283 Mtetra
.632 .847 .982 r
.3871 .4283 .38827 .42904 .39017 .42839 .389 .42764 Mtetra
.633 .845 .981 r
.389 .42764 .39017 .42839 .39207 .42774 .39091 .42699 Mtetra
.543 .812 .996 r
.39091 .42699 .39207 .42774 .39397 .42717 .3928 .42658 Mtetra
.585 .864 .995 r
.3928 .42658 .39397 .42717 .39588 .42655 .39471 .426 Mtetra
.699 .903 .969 r
.39471 .426 .39588 .42655 .39779 .42584 .39663 .42507 Mtetra
.891 .852 .798 r
.39663 .42507 .39779 .42584 .39971 .42479 .39861 .42259 Mtetra
.853 .698 .689 r
.39861 .42259 .39971 .42479 .40164 .42366 .40064 .41885 Mtetra
.817 .602 .612 r
.40064 .41885 .40164 .42366 .40356 .42255 .40276 .41256 Mtetra
.644 .436 .586 r
.40276 .41256 .40356 .42255 .40548 .42184 .40476 .40925 Mtetra
.527 .336 .566 r
.40476 .40925 .40548 .42184 .40739 .42125 .40665 .40909 Mtetra
.474 .299 .562 r
.40665 .40909 .40739 .42125 .4093 .42072 .4085 .41027 Mtetra
.468 .303 .573 r
.4085 .41027 .4093 .42072 .41119 .42065 .41034 .41142 Mtetra
.531 .357 .59 r
.41034 .41142 .41119 .42065 .41311 .42016 .41224 .41126 Mtetra
.629 .431 .595 r
.41224 .41126 .41311 .42016 .41505 .41882 .41422 .40881 Mtetra
.959 .679 .46 r
.41422 .40881 .41505 .41882 .41717 .41196 .423 .20427 Mtetra
.527 .294 .504 r
.423 .20427 .41717 .41196 .42594 .20193 .42498 .19787 Mtetra
.753 .571 .65 r
.42498 .19787 .42594 .20193 .42789 .19643 .42686 .1947 Mtetra
.729 .691 .814 r
.42686 .1947 .42789 .19643 .42971 .19496 .42867 .1935 Mtetra
.655 .701 .88 r
.42867 .1935 .42971 .19496 .43151 .19433 .43047 .19285 Mtetra
.595 .673 .895 r
.43047 .19285 .43151 .19433 .43329 .19407 .43226 .19247 Mtetra
.615 .663 .873 r
.43226 .19247 .43329 .19407 .43509 .1935 .43405 .192 Mtetra
.617 .679 .886 r
.43405 .192 .43509 .1935 .43688 .19289 .43584 .19152 Mtetra
.628 .705 .902 r
.43584 .19152 .43688 .19289 .43868 .19227 .43764 .191 Mtetra
.683 .743 .897 r
.43764 .191 .43868 .19227 .44049 .19159 .43945 .19023 Mtetra
.696 .733 .879 r
.43945 .19023 .44049 .19159 .44229 .19087 .44125 .18937 Mtetra
.692 .709 .861 r
.44125 .18937 .44229 .19087 .4441 .19015 .44306 .18851 Mtetra
.695 .69 .841 r
.44306 .18851 .4441 .19015 .4459 .18941 .44488 .18759 Mtetra
.665 .655 .831 r
.44488 .18759 .4459 .18941 .44771 .1887 .44669 .18682 Mtetra
.61 .624 .84 r
.44669 .18682 .44771 .1887 .44952 .18806 .44849 .18636 Mtetra
.255 .455 .863 r
.44849 .18636 .44952 .18806 .45132 .18767 .45026 .18706 Mtetra
.645 .103 0 r
.45026 .18706 .45132 .18767 .45312 .18739 .45202 .18887 Mtetra
.804 .401 .288 r
.45202 .18887 .45312 .18739 .45492 .18711 .45373 .19255 Mtetra
.522 .2 .363 r
.45373 .19255 .45492 .18711 .45674 .18609 .45552 .19305 Mtetra
.389 .103 .354 r
.45552 .19305 .45674 .18609 .45856 .18517 .45736 .19159 Mtetra
.463 .16 .366 r
.45736 .19159 .45856 .18517 .46037 .18488 .45917 .19121 Mtetra
.963 .672 .434 r
.45917 .19121 .46037 .18488 .4621 .18841 .45669 .39345 Mtetra
.526 .287 .496 r
.45669 .39345 .4621 .18841 .45967 .39741 .45847 .40066 Mtetra
.676 .301 .329 r
.45847 .40066 .45967 .39741 .46149 .40353 .46036 .40312 Mtetra
.212 .704 .922 r
.46036 .40312 .46149 .40353 .46342 .40413 .4623 .40311 Mtetra
.695 .811 .937 r
.4623 .40311 .46342 .40413 .46537 .40344 .46426 .40223 Mtetra
.746 .791 .889 r
.46426 .40223 .46537 .40344 .46734 .40226 .46623 .40105 Mtetra
.666 .769 .927 r
.46623 .40105 .46734 .40226 .4693 .40141 .46819 .40031 Mtetra
.613 .771 .956 r
.46819 .40031 .4693 .40141 .47126 .4007 .47015 .39978 Mtetra
.597 .801 .978 r
.47015 .39978 .47126 .4007 .47322 .4 .47211 .39926 Mtetra
.61 .846 .988 r
.47211 .39926 .47322 .4 .47518 .39928 .47407 .39864 Mtetra
.616 .868 .99 r
.47407 .39864 .47518 .39928 .47715 .39857 .47603 .39797 Mtetra
.613 .876 .991 r
.47603 .39797 .47715 .39857 .47911 .39787 .478 .39729 Mtetra
.599 .876 .993 r
.478 .39729 .47911 .39787 .48108 .39718 .47996 .39664 Mtetra
.587 .877 .993 r
.47996 .39664 .48108 .39718 .48304 .39652 .48193 .396 Mtetra
.58 .879 .993 r
.48193 .396 .48304 .39652 .48501 .39588 .4839 .39537 Mtetra
.487 .843 .994 r
.4839 .39537 .48501 .39588 .48698 .39532 .48587 .39494 Mtetra
.479 .862 .979 r
.48587 .39494 .48698 .39532 .48895 .39475 .48784 .39445 Mtetra
.609 .925 .97 r
.48784 .39445 .48895 .39475 .49092 .39411 .48982 .39362 Mtetra
.884 .921 .843 r
.48982 .39362 .49092 .39411 .4929 .39313 .49181 .39148 Mtetra
.889 .752 .705 r
.49181 .39148 .4929 .39313 .49488 .39197 .49381 .38781 Mtetra
.845 .629 .61 r
.49381 .38781 .49488 .39197 .49686 .3908 .49584 .38133 Mtetra
.753 .517 .575 r
.49584 .38133 .49686 .3908 .49884 .38999 .49787 .37353 Mtetra
.531 .329 .551 r
.49787 .37353 .49884 .38999 .50082 .38945 .49984 .37307 Mtetra
.427 .252 .539 r
.49984 .37307 .50082 .38945 .5028 .389 .50179 .37613 Mtetra
.495 .313 .563 r
.50179 .37613 .5028 .389 .50478 .38849 .50376 .37686 Mtetra
.528 .342 .572 r
.50376 .37686 .50478 .38849 .50676 .38793 .50573 .3767 Mtetra
.531 .346 .575 r
.50573 .3767 .50676 .38793 .50875 .38736 .50771 .37647 Mtetra
.536 .351 .578 r
.50771 .37647 .50875 .38736 .51073 .38677 .50969 .37612 Mtetra
.54 .356 .58 r
.50969 .37612 .51073 .38677 .51272 .38617 .51167 .37567 Mtetra
.543 .359 .581 r
.51167 .37567 .51272 .38617 .51471 .38555 .51365 .37516 Mtetra
.545 .361 .582 r
.51365 .37516 .51471 .38555 .5167 .38492 .51564 .37461 Mtetra
.547 .362 .583 r
.51564 .37461 .5167 .38492 .51869 .38427 .51763 .37402 Mtetra
.548 .364 .583 r
.51763 .37402 .51869 .38427 .52069 .38362 .51962 .3734 Mtetra
.55 .365 .584 r
.51962 .3734 .52069 .38362 .52268 .38296 .52161 .37275 Mtetra
.551 .366 .584 r
.52161 .37275 .52268 .38296 .52468 .38229 .5236 .37207 Mtetra
.552 .367 .584 r
.5236 .37207 .52468 .38229 .52668 .38161 .52559 .37137 Mtetra
.553 .367 .584 r
.52559 .37137 .52668 .38161 .52868 .38092 .52759 .37063 Mtetra
.554 .368 .583 r
.52759 .37063 .52868 .38092 .53068 .38023 .52958 .36986 Mtetra
.553 .367 .583 r
.52958 .36986 .53068 .38023 .53268 .37954 .53158 .36909 Mtetra
.552 .366 .582 r
.53158 .36909 .53268 .37954 .53468 .37885 .53358 .36836 Mtetra
.55 .364 .582 r
.53358 .36836 .53468 .37885 .53669 .37817 .53558 .36767 Mtetra
.549 .363 .582 r
.53558 .36767 .53669 .37817 .5387 .3775 .53758 .36701 Mtetra
.546 .361 .582 r
.53758 .36701 .5387 .3775 .54071 .37684 .53959 .36643 Mtetra
.544 .36 .582 r
.53959 .36643 .54071 .37684 .54272 .3762 .54159 .3659 Mtetra
.544 .361 .583 r
.54159 .3659 .54272 .3762 .54473 .37556 .5436 .36537 Mtetra
.502 .331 .582 r
.5436 .36537 .54473 .37556 .54674 .37526 .54562 .36583 Mtetra
.506 .339 .589 r
.54562 .36583 .54674 .37526 .54876 .37497 .54763 .36618 Mtetra
.584 .399 .597 r
.54763 .36618 .54876 .37497 .55077 .374 .54964 .36487 Mtetra
.969 .676 .416 r
.54964 .36487 .55077 .374 .55276 .3702 .55 .16692 Mtetra
.545 .307 .506 r
.55 .16692 .55276 .3702 .55283 .16071 .55176 .15224 Mtetra
.684 .469 .588 r
.55176 .15224 .55283 .16071 .55462 .15043 .55361 .14815 Mtetra
.766 .659 .745 r
.55361 .14815 .55462 .15043 .55648 .14775 .55548 .14623 Mtetra
.678 .711 .873 r
.55548 .14623 .55648 .14775 .55835 .14686 .55736 .14543 Mtetra
.614 .697 .903 r
.55736 .14543 .55835 .14686 .56024 .14646 .55925 .14494 Mtetra
.621 .686 .889 r
.55925 .14494 .56024 .14646 .56213 .14602 .56113 .14442 Mtetra
.651 .688 .871 r
.56113 .14442 .56213 .14602 .56401 .14535 .56302 .14375 Mtetra
.651 .687 .871 r
.56302 .14375 .56401 .14535 .5659 .14468 .56491 .14308 Mtetra
.652 .687 .87 r
.56491 .14308 .5659 .14468 .56779 .14401 .56679 .1424 Mtetra
.654 .688 .869 r
.56679 .1424 .56779 .14401 .56968 .14332 .56868 .14171 Mtetra
.655 .688 .869 r
.56868 .14171 .56968 .14332 .57157 .14263 .57058 .14102 Mtetra
.57058 .14102 .57157 .14263 .57346 .14193 .57247 .14032 Mtetra
.656 .688 .869 r
.57247 .14032 .57346 .14193 .57535 .14123 .57436 .13962 Mtetra
.656 .688 .868 r
.57436 .13962 .57535 .14123 .57725 .14053 .57626 .13892 Mtetra
.57626 .13892 .57725 .14053 .57914 .13983 .57815 .13821 Mtetra
.657 .689 .868 r
.57815 .13821 .57914 .13983 .58104 .13912 .58005 .13751 Mtetra
.58005 .13751 .58104 .13912 .58294 .13841 .58195 .1368 Mtetra
.58195 .1368 .58294 .13841 .58484 .1377 .58385 .13609 Mtetra
.58385 .13609 .58484 .1377 .58674 .13699 .58575 .13538 Mtetra
.58575 .13538 .58674 .13699 .58864 .13628 .58765 .13467 Mtetra
.58765 .13467 .58864 .13628 .59054 .13557 .58956 .13396 Mtetra
.58956 .13396 .59054 .13557 .59245 .13486 .59146 .13324 Mtetra
.59146 .13324 .59245 .13486 .59435 .13415 .59337 .13253 Mtetra
.59337 .13253 .59435 .13415 .59626 .13344 .59528 .13181 Mtetra
.59528 .13181 .59626 .13344 .59817 .13272 .59719 .1311 Mtetra
.59719 .1311 .59817 .13272 .60008 .13201 .5991 .13038 Mtetra
.5991 .13038 .60008 .13201 .60199 .13129 .60101 .12967 Mtetra
.60101 .12967 .60199 .13129 .6039 .13058 .60292 .12895 Mtetra
.658 .689 .868 r
.60292 .12895 .6039 .13058 .60581 .12986 .60484 .12823 Mtetra
.60484 .12823 .60581 .12986 .60773 .12914 .60675 .12751 Mtetra
.60675 .12751 .60773 .12914 .60965 .12842 .60867 .12679 Mtetra
.60867 .12679 .60965 .12842 .61156 .1277 .61059 .12607 Mtetra
.61059 .12607 .61156 .1277 .61348 .12697 .61251 .12535 Mtetra
.658 .69 .868 r
.61251 .12535 .61348 .12697 .6154 .12625 .61443 .12462 Mtetra
.61443 .12462 .6154 .12625 .61732 .12552 .61635 .1239 Mtetra
.659 .69 .868 r
.61635 .1239 .61732 .12552 .61925 .12479 .61827 .12317 Mtetra
.61827 .12317 .61925 .12479 .62117 .12406 .6202 .12244 Mtetra
.659 .691 .869 r
.6202 .12244 .62117 .12406 .6231 .12333 .62212 .12171 Mtetra
.62212 .12171 .6231 .12333 .62502 .1226 .62405 .12098 Mtetra
.659 .692 .869 r
.62405 .12098 .62502 .1226 .62695 .12187 .62598 .12025 Mtetra
.659 .692 .87 r
.62598 .12025 .62695 .12187 .62888 .12114 .62791 .11952 Mtetra
.658 .692 .87 r
.62791 .11952 .62888 .12114 .63081 .12041 .62984 .1188 Mtetra
.658 .692 .871 r
.62984 .1188 .63081 .12041 .63274 .11969 .63177 .11807 Mtetra
.656 .691 .871 r
.63177 .11807 .63274 .11969 .63468 .11898 .63371 .11736 Mtetra
.63371 .11736 .63468 .11898 .63661 .11828 .63564 .11664 Mtetra
.656 .689 .869 r
.63564 .11664 .63661 .11828 .63855 .11759 .63758 .11593 Mtetra
.65 .683 .867 r
.63758 .11593 .63855 .11759 .64049 .11691 .63952 .11524 Mtetra
.638 .676 .87 r
.63952 .11524 .64049 .11691 .64243 .11623 .64146 .11461 Mtetra
.618 .674 .881 r
.64146 .11461 .64243 .11623 .64437 .11557 .64341 .11409 Mtetra
.615 .695 .901 r
.64341 .11409 .64437 .11557 .64632 .11491 .64536 .11358 Mtetra
.625 .727 .92 r
.64536 .11358 .64632 .11491 .64826 .11425 .64732 .11302 Mtetra
.653 .759 .927 r
.64732 .11302 .64826 .11425 .65021 .11358 .64926 .11234 Mtetra
.664 .761 .923 r
.64926 .11234 .65021 .11358 .65216 .1129 .65121 .11161 Mtetra
.668 .755 .915 r
.65121 .11161 .65216 .1129 .65411 .1122 .65316 .11086 Mtetra
.667 .744 .908 r
.65316 .11086 .65411 .1122 .65606 .11149 .65511 .11012 Mtetra
.67 .739 .902 r
.65511 .11012 .65606 .11149 .65801 .11075 .65706 .10935 Mtetra
.684 .741 .894 r
.65706 .10935 .65801 .11075 .65995 .10997 .659 .10851 Mtetra
.713 .742 .875 r
.659 .10851 .65995 .10997 .6619 .1091 .66094 .1075 Mtetra
.673 .703 .87 r
.66094 .1075 .6619 .1091 .66385 .10827 .66289 .10669 Mtetra
.58 .663 .895 r
.66289 .10669 .66385 .10827 .6658 .10746 .66487 .10633 Mtetra
.15 .502 .909 r
.66487 .10633 .6658 .10746 .66775 .10658 .66689 .107 Mtetra
.694 .165 0 r
.66689 .107 .66775 .10658 .66972 .10617 .66899 .10897 Mtetra
.866 .487 .325 r
.66899 .10897 .66972 .10617 .67176 .107 .6714 .11737 Mtetra
.968 .654 .356 r
.6714 .11737 .67176 .107 .67424 .11641 .68377 .32239 Mtetra
.518 .281 .494 r
.68377 .32239 .67424 .11641 .68701 .32547 .68611 .32602 Mtetra
.586 .034 0 r
.68611 .32602 .68701 .32547 .68933 .3287 .68833 .32736 Mtetra
.425 .647 .95 r
.68833 .32736 .68933 .3287 .6915 .32893 .69049 .32746 Mtetra
.667 .741 .906 r
.69049 .32746 .6915 .32893 .69362 .32806 .69261 .32665 Mtetra
.851 .804 .805 r
.69261 .32665 .69362 .32806 .69565 .32572 .69466 .32439 Mtetra
.981 .761 .532 r
.69466 .32439 .69565 .32572 .69736 .31744 .69633 .31534 Mtetra
.976 .673 .34 r
.69633 .31534 .69736 .31744 .68761 .10314 .68664 .10115 Mtetra
.913 .735 .647 r
.68664 .10115 .68761 .10314 .68935 .09827 .68839 .09653 Mtetra
.701 .698 .844 r
.68839 .09653 .68935 .09827 .6913 .09712 .69035 .09551 Mtetra
.576 .659 .894 r
.69035 .09551 .6913 .09712 .69328 .09664 .69235 .09517 Mtetra
.497 .643 .921 r
.69235 .09517 .69328 .09664 .69529 .09644 .69436 .09511 Mtetra
.648 .742 .918 r
.69436 .09511 .69529 .09644 .69727 .09575 .69635 .09444 Mtetra
.665 .753 .916 r
.69635 .09444 .69727 .09575 .69925 .09503 .69833 .0937 Mtetra
.694 .76 .902 r
.69833 .0937 .69925 .09503 .70123 .09422 .7003 .09281 Mtetra
.777 .776 .851 r
.7003 .09281 .70123 .09422 .70317 .09291 .70224 .09137 Mtetra
.708 .731 .868 r
.70224 .09137 .70317 .09291 .70514 .09201 .7042 .09035 Mtetra
.516 .62 .894 r
.7042 .09035 .70514 .09201 .70718 .09204 .70623 .09026 Mtetra
.661 .274 0 r
.70623 .09026 .70718 .09204 .70953 .09715 .70855 .09491 Mtetra
.972 .66 .303 r
.70855 .09491 .70953 .09715 .72525 .31104 .72424 .30928 Mtetra
.696 .296 0 r
.72424 .30928 .72525 .31104 .72774 .31573 .72676 .31439 Mtetra
.4 .635 .95 r
.72676 .31439 .72774 .31573 .72993 .31571 .72896 .31455 Mtetra
.669 .804 .947 r
.72896 .31455 .72993 .31571 .73208 .31485 .73111 .31372 Mtetra
.804 .849 .884 r
.73111 .31372 .73208 .31485 .73419 .31355 .73321 .31212 Mtetra
.847 .807 .811 r
.73321 .31212 .73419 .31355 .73635 .31296 .73526 .30992 Mtetra
.818 .656 .681 r
.73526 .30992 .73635 .31296 .73849 .31193 .73723 .30646 Mtetra
.838 .601 .58 r
.73723 .30646 .73849 .31193 .74056 .30994 .73893 .29905 Mtetra
.973 .661 .34 r
.73893 .29905 .74056 .30994 .74219 .30162 .72663 .08976 Mtetra
.524 .29 .503 r
.72663 .08976 .74219 .30162 .72939 .0881 .72831 .0844 Mtetra
.754 .586 .667 r
.72831 .0844 .72939 .0881 .73109 .08301 .73017 .0816 Mtetra
.722 .761 .883 r
.73017 .0816 .73109 .08301 .73305 .08172 .73215 .08053 Mtetra
.642 .77 .94 r
.73215 .08053 .73305 .08172 .73506 .0811 .73416 .07987 Mtetra
.598 .744 .946 r
.73416 .07987 .73506 .0811 .7371 .0808 .73619 .07939 Mtetra
.753 .753 .853 r
.09536 .31777 .09653 .31889 .09817 .31789 .09701 .31667 Mtetra
.705 .728 .868 r
.09701 .31667 .09817 .31789 .09978 .31706 .09862 .31585 Mtetra
.574 .692 .921 r
.09862 .31585 .09978 .31706 .10136 .31656 .10017 .31558 Mtetra
.846 .385 .02 r
.10017 .31558 .10136 .31656 .10278 .31716 .10135 .31793 Mtetra
.913 .623 .481 r
.10135 .31793 .10278 .31716 .10406 .31885 .101 .33176 Mtetra
.92 .662 .531 r
.101 .33176 .10406 .31885 .1049 .32388 .07647 .52629 Mtetra
.515 .279 .495 r
.07647 .52629 .1049 .32388 .07994 .52296 .07785 .52803 Mtetra
.527 .204 .363 r
.07785 .52803 .07994 .52296 .08093 .52759 .0794 .52853 Mtetra
.289 0 0 r
.0794 .52853 .08093 .52759 .08231 .52937 .08103 .52846 Mtetra
.336 .672 .976 r
.08103 .52846 .08231 .52937 .08389 .52965 .08263 .52856 Mtetra
.589 .738 .946 r
.08263 .52856 .08389 .52965 .08556 .52927 .0843 .5282 Mtetra
.742 .774 .879 r
.0843 .5282 .08556 .52927 .08731 .5283 .08606 .52714 Mtetra
.881 .747 .71 r
.08606 .52714 .08731 .5283 .08918 .52641 .08816 .52344 Mtetra
.893 .672 .595 r
.08816 .52344 .08918 .52641 .09121 .52329 .09141 .51095 Mtetra
.926 .673 .535 r
.09141 .51095 .09121 .52329 .0937 .51653 .11877 .31226 Mtetra
.52 .288 .504 r
.11877 .31226 .0937 .51653 .12119 .31546 .12067 .30929 Mtetra
.632 .453 .622 r
.12067 .30929 .12119 .31546 .12338 .31024 .12241 .30765 Mtetra
.678 .578 .736 r
.12241 .30765 .12338 .31024 .12524 .30761 .12407 .30656 Mtetra
.679 .756 .909 r
.12407 .30656 .12524 .30761 .12688 .3067 .12568 .3059 Mtetra
.615 .794 .968 r
.12568 .3059 .12688 .3067 .12846 .30631 .12726 .30544 Mtetra
.591 .773 .966 r
.12726 .30544 .12846 .30631 .13001 .30614 .12884 .30506 Mtetra
.678 .752 .907 r
.12884 .30506 .13001 .30614 .13161 .30551 .13045 .3044 Mtetra
.693 .749 .895 r
.13045 .3044 .13161 .30551 .13323 .30476 .13207 .30367 Mtetra
.693 .751 .896 r
.13207 .30367 .13323 .30476 .13486 .30401 .13369 .30293 Mtetra
.734 .762 .875 r
.13369 .30293 .13486 .30401 .1365 .30317 .13534 .30197 Mtetra
.691 .733 .883 r
.13534 .30197 .1365 .30317 .13812 .30247 .13697 .30123 Mtetra
.561 .684 .922 r
.13697 .30123 .13812 .30247 .1397 .30208 .13853 .30099 Mtetra
.743 .249 0 r
.13853 .30099 .1397 .30208 .14117 .30258 .13983 .30291 Mtetra
.91 .593 .432 r
.13983 .30291 .14117 .30258 .14252 .30416 .14034 .31128 Mtetra
.932 .672 .521 r
.14034 .31128 .14252 .30416 .1435 .30872 .11736 .512 Mtetra
.517 .281 .495 r
.11736 .512 .1435 .30872 .12071 .50933 .1187 .51446 Mtetra
.544 .22 .37 r
.1187 .51446 .12071 .50933 .12175 .51433 .12026 .51517 Mtetra
.33 0 0 r
.12026 .51517 .12175 .51433 .12317 .51622 .1219 .51524 Mtetra
.42 .695 .977 r
.1219 .51524 .12317 .51622 .12479 .51649 .12356 .51523 Mtetra
.604 .711 .92 r
.12356 .51523 .12479 .51649 .1265 .51601 .12526 .51482 Mtetra
.734 .757 .871 r
.12526 .51482 .1265 .51601 .12827 .51496 .12704 .51378 Mtetra
.871 .754 .731 r
.12704 .51378 .12827 .51496 .13014 .51317 .12907 .5106 Mtetra
.885 .678 .617 r
.12907 .5106 .13014 .51317 .13213 .51034 .13171 .50223 Mtetra
.935 .679 .526 r
.13171 .50223 .13213 .51034 .13442 .50494 .1573 .29898 Mtetra
.522 .29 .504 r
.1573 .29898 .13442 .50494 .15967 .303 .15929 .29524 Mtetra
.62 .429 .602 r
.15929 .29524 .15967 .303 .162 .2964 .16106 .29342 Mtetra
.673 .556 .715 r
.16106 .29342 .162 .2964 .16389 .29345 .16275 .29223 Mtetra
.692 .732 .881 r
.16275 .29223 .16389 .29345 .16558 .29228 .16439 .29148 Mtetra
.629 .801 .965 r
.16439 .29148 .16558 .29228 .16719 .29181 .16601 .29097 Mtetra
.59 .781 .971 r
.16601 .29097 .16719 .29181 .16877 .29161 .16761 .29058 Mtetra
.715 .771 .897 r
.16761 .29058 .16877 .29161 .1704 .29097 .16926 .28974 Mtetra
.703 .732 .873 r
.16926 .28974 .1704 .29097 .17205 .29024 .17092 .28892 Mtetra
.604 .687 .901 r
.17092 .28892 .17205 .29024 .17366 .28974 .17252 .28854 Mtetra
.524 .032 0 r
.17252 .28854 .17366 .28974 .1752 .28998 .17392 .29003 Mtetra
.908 .564 .38 r
.17392 .29003 .1752 .28998 .17663 .29113 .1748 .29614 Mtetra
.938 .675 .512 r
.1748 .29614 .17663 .29113 .17786 .29415 .15377 .4983 Mtetra
.518 .282 .496 r
.15377 .4983 .17786 .29415 .15736 .49328 .1551 .50141 Mtetra
.537 .242 .414 r
.1551 .50141 .15736 .49328 .15821 .50077 .15669 .50218 Mtetra
.38 0 .004 r
.15669 .50218 .15821 .50077 .15963 .50305 .15837 .50219 Mtetra
.639 .802 .961 r
.15837 .50219 .15963 .50305 .1613 .50314 .16011 .50161 Mtetra
.704 .704 .847 r
.16011 .50161 .1613 .50314 .16309 .50223 .1619 .50067 Mtetra
.728 .706 .83 r
.1619 .50067 .16309 .50223 .16491 .50091 .1637 .49953 Mtetra
.711 .727 .863 r
.1637 .49953 .16491 .50091 .16671 .49983 .16549 .49859 Mtetra
.683 .742 .896 r
.16549 .49859 .16671 .49983 .16849 .499 .16726 .49783 Mtetra
.66 .748 .916 r
.16726 .49783 .16849 .499 .17025 .49828 .16901 .49719 Mtetra
.618 .752 .942 r
.16901 .49719 .17025 .49828 .172 .4977 .17075 .49671 Mtetra
.574 .757 .965 r
.17075 .49671 .172 .4977 .17373 .49727 .17248 .49635 Mtetra
.541 .763 .979 r
.17248 .49635 .17373 .49727 .17546 .49694 .1742 .49606 Mtetra
.329 .676 .977 r
.1742 .49606 .17546 .49694 .17715 .49696 .17589 .49616 Mtetra
.363 .711 .986 r
.17589 .49616 .17715 .49696 .17884 .49698 .17758 .49617 Mtetra
.636 .815 .969 r
.17758 .49617 .17884 .49698 .18058 .49661 .17934 .49559 Mtetra
.87 .782 .762 r
.17934 .49559 .18058 .49661 .18242 .49522 .18131 .4929 Mtetra
.893 .688 .618 r
.18131 .4929 .18242 .49522 .18439 .49251 .18383 .48492 Mtetra
.941 .681 .515 r
.18383 .48492 .18439 .49251 .18662 .48737 .20646 .28092 Mtetra
.522 .29 .504 r
.20646 .28092 .18662 .48737 .20876 .28628 .20846 .27693 Mtetra
.6 .403 .587 r
.20846 .27693 .20876 .28628 .21111 .27888 .21023 .2752 Mtetra
.647 .514 .687 r
.21023 .2752 .21111 .27888 .21302 .27573 .21194 .27408 Mtetra
.681 .667 .829 r
.21194 .27408 .21302 .27573 .21476 .27426 .21361 .27328 Mtetra
.662 .773 .931 r
.21361 .27328 .21476 .27426 .21642 .27361 .21527 .27266 Mtetra
.635 .774 .947 r
.21527 .27266 .21642 .27361 .21806 .27322 .21692 .27214 Mtetra
.719 .768 .891 r
.21692 .27214 .21806 .27322 .21973 .27248 .2186 .27126 Mtetra
.729 .744 .863 r
.2186 .27126 .21973 .27248 .22142 .27154 .2203 .27027 Mtetra
.647 .713 .896 r
.2203 .27027 .22142 .27154 .22309 .27086 .22196 .26971 Mtetra
0 .24 .731 r
.22196 .26971 .22309 .27086 .22468 .27094 .22346 .27073 Mtetra
.906 .533 .312 r
.22346 .27073 .22468 .27094 .22617 .2721 .22459 .27563 Mtetra
.945 .678 .499 r
.22459 .27563 .22617 .2721 .22749 .27514 .2065 .47992 Mtetra
.52 .283 .496 r
.2065 .47992 .22749 .27514 .21012 .47387 .20783 .48393 Mtetra
.536 .251 .429 r
.20783 .48393 .21012 .47387 .211 .48269 .20947 .48479 Mtetra
.45 .031 .151 r
.20947 .48479 .211 .48269 .21248 .48524 .21118 .48491 Mtetra
.098 .635 .858 r
.21118 .48491 .21248 .48524 .21411 .48621 .2129 .485 Mtetra
.484 .68 .952 r
.2129 .485 .21411 .48621 .21583 .48623 .21463 .48492 Mtetra
.688 .736 .888 r
.21463 .48492 .21583 .48623 .21764 .48535 .21644 .48412 Mtetra
.875 .761 .734 r
.21644 .48412 .21764 .48535 .21967 .48209 .21846 .48099 Mtetra
.945 .713 .556 r
.21846 .48099 .21967 .48209 .22361 .45809 .22181 .46342 Mtetra
.959 .698 .498 r
.22181 .46342 .22361 .45809 .24293 .26523 .24178 .2644 Mtetra
.896 .795 .741 r
.24178 .2644 .24293 .26523 .24482 .26232 .24367 .26143 Mtetra
.713 .806 .923 r
.24367 .26143 .24482 .26232 .24651 .26149 .24537 .26059 Mtetra
.548 .759 .975 r
.24537 .26059 .24651 .26149 .24816 .26121 .24701 .2603 Mtetra
.541 .755 .975 r
.24701 .2603 .24816 .26121 .2498 .26098 .24866 .26003 Mtetra
.626 .774 .952 r
.24866 .26003 .2498 .26098 .25146 .26057 .25033 .25954 Mtetra
.634 .759 .938 r
.25033 .25954 .25146 .26057 .25312 .26013 .252 .25902 Mtetra
.667 .752 .914 r
.252 .25902 .25312 .26013 .2548 .25954 .25368 .25838 Mtetra
.694 .75 .895 r
.25368 .25838 .2548 .25954 .2565 .25876 .25538 .2576 Mtetra
.698 .752 .894 r
.25538 .2576 .2565 .25876 .2582 .25795 .25708 .25681 Mtetra
.721 .761 .884 r
.25708 .25681 .2582 .25795 .2599 .25708 .25879 .25589 Mtetra
.72 .751 .877 r
.25879 .25589 .2599 .25708 .26161 .25625 .2605 .25496 Mtetra
.636 .71 .9 r
.2605 .25496 .26161 .25625 .26329 .25568 .26218 .25444 Mtetra
.046 .41 .861 r
.26218 .25444 .26329 .25568 .26492 .25571 .26375 .25518 Mtetra
.901 .497 .221 r
.26375 .25518 .26492 .25571 .26647 .25677 .26505 .25925 Mtetra
.951 .68 .488 r
.26505 .25925 .26647 .25677 .26788 .25955 .24952 .46408 Mtetra
.523 .285 .496 r
.24952 .46408 .26788 .25955 .25308 .45791 .25083 .46941 Mtetra
.542 .261 .438 r
.25083 .46941 .25308 .45791 .25396 .46847 .2525 .47053 Mtetra
.479 .057 .161 r
.2525 .47053 .25396 .46847 .25549 .47124 .25423 .47081 Mtetra
.322 .764 .964 r
.25423 .47081 .25549 .47124 .25718 .47212 .25601 .47067 Mtetra
.59 .683 .906 r
.25601 .47067 .25718 .47212 .25896 .47188 .2578 .4703 Mtetra
.633 .68 .877 r
.2578 .4703 .25896 .47188 .26078 .47126 .25961 .46975 Mtetra
.623 .687 .889 r
.25961 .46975 .26078 .47126 .2626 .47057 .26141 .46924 Mtetra
.601 .708 .92 r
.26141 .46924 .2626 .47057 .26441 .46997 .26322 .46882 Mtetra
.696 .77 .909 r
.26322 .46882 .26441 .46997 .26625 .46912 .26505 .46799 Mtetra
.841 .788 .801 r
.26505 .46799 .26625 .46912 .26814 .46758 .26699 .46589 Mtetra
.902 .722 .65 r
.26699 .46589 .26814 .46758 .27013 .46478 .2692 .46024 Mtetra
.953 .686 .493 r
.2692 .46024 .27013 .46478 .27222 .46066 .28691 .25419 Mtetra
.527 .294 .505 r
.28691 .25419 .27222 .46066 .27433 .45615 .28904 .24806 Mtetra
.515 .284 .502 r
.28904 .24806 .27433 .45615 .27612 .45596 .29077 .24711 Mtetra
.513 .282 .502 r
.29077 .24711 .27612 .45596 .27791 .45565 .29245 .2468 Mtetra
.515 .284 .502 r
.29245 .2468 .27791 .45565 .28024 .44833 .29418 .24594 Mtetra
.518 .286 .503 r
.29418 .24594 .28024 .44833 .29684 .24857 .296 .2439 Mtetra
.665 .5 .652 r
.296 .2439 .29684 .24857 .29884 .24402 .29779 .24213 Mtetra
.726 .663 .787 r
.29779 .24213 .29884 .24402 .30067 .24182 .29955 .24087 Mtetra
.66 .788 .943 r
.29955 .24087 .30067 .24182 .30239 .24112 .30126 .24025 Mtetra
.613 .79 .966 r
.30126 .24025 .30239 .24112 .30408 .24078 .30296 .23977 Mtetra
.637 .768 .942 r
.30296 .23977 .30408 .24078 .30577 .2404 .30467 .23923 Mtetra
.694 .752 .896 r
.30467 .23923 .30577 .2404 .3075 .23961 .3064 .23844 Mtetra
.698 .755 .895 r
.3064 .23844 .3075 .23961 .30923 .23878 .30813 .23763 Mtetra
.712 .762 .891 r
.30813 .23763 .30923 .23878 .31096 .23793 .30986 .23675 Mtetra
.728 .76 .878 r
.30986 .23675 .31096 .23793 .3127 .23707 .31161 .23577 Mtetra
.655 .72 .896 r
.31161 .23577 .3127 .23707 .31442 .23643 .31333 .23516 Mtetra
.315 .567 .928 r
.31333 .23516 .31442 .23643 .3161 .23629 .31498 .23549 Mtetra
.864 .416 .06 r
.31498 .23549 .3161 .23629 .31772 .23714 .31644 .2387 Mtetra
.957 .681 .473 r
.31644 .2387 .31772 .23714 .31925 .23938 .30437 .44227 Mtetra
.528 .29 .497 r
.30437 .44227 .31925 .23938 .32016 .25107 .30562 .45049 Mtetra
.514 .278 .494 r
.30562 .45049 .32016 .25107 .30877 .44906 .30733 .45187 Mtetra
.504 .117 .241 r
.30733 .45187 .30877 .44906 .31036 .45238 .30911 .45224 Mtetra
.191 .717 .854 r
.30911 .45224 .31036 .45238 .31209 .45351 .31093 .45209 Mtetra
.617 .701 .904 r
.31093 .45209 .31209 .45351 .31392 .45317 .31277 .4516 Mtetra
.656 .692 .872 r
.31277 .4516 .31392 .45317 .31578 .45242 .31463 .45091 Mtetra
.649 .701 .884 r
.31463 .45091 .31578 .45242 .31765 .45159 .31648 .45027 Mtetra
.551 .695 .935 r
.31648 .45027 .31765 .45159 .31949 .45115 .31831 .45001 Mtetra
.648 .764 .934 r
.31831 .45001 .31949 .45115 .32135 .4505 .32017 .44939 Mtetra
.805 .798 .845 r
.32017 .44939 .32135 .4505 .32324 .44929 .32209 .44777 Mtetra
.907 .74 .662 r
.32209 .44777 .32324 .44929 .32522 .44661 .32422 .44271 Mtetra
.958 .687 .479 r
.32422 .44271 .32522 .44661 .32729 .44259 .33856 .23707 Mtetra
.532 .298 .505 r
.33856 .23707 .32729 .44259 .32945 .4369 .34078 .22865 Mtetra
.515 .284 .502 r
.34078 .22865 .32945 .4369 .33128 .43666 .34254 .22756 Mtetra
.513 .283 .502 r
.34254 .22756 .33128 .43666 .3331 .43668 .34427 .22721 Mtetra
.514 .283 .502 r
.34427 .22721 .3331 .43668 .33514 .43287 .346 .2267 Mtetra
.517 .286 .503 r
.346 .2267 .33514 .43287 .34867 .23011 .34783 .22466 Mtetra
.65 .476 .635 r
.34783 .22466 .34867 .23011 .35067 .22502 .34964 .22285 Mtetra
.725 .64 .763 r
.34964 .22285 .35067 .22502 .35252 .22244 .35143 .22146 Mtetra
.664 .788 .94 r
.35143 .22146 .35252 .22244 .35428 .22166 .35318 .2208 Mtetra
.603 .796 .973 r
.35318 .2208 .35428 .22166 .35601 .22129 .35492 .22033 Mtetra
.593 .769 .963 r
.35492 .22033 .35601 .22129 .35773 .22108 .35665 .21991 Mtetra
.654 .746 .917 r
.35665 .21991 .35773 .22108 .35948 .22051 .3584 .2193 Mtetra
.665 .742 .908 r
.3584 .2193 .35948 .22051 .36123 .21988 .36015 .21864 Mtetra
.676 .741 .899 r
.36015 .21864 .36123 .21988 .36298 .21917 .36191 .21792 Mtetra
.694 .744 .89 r
.36191 .21792 .36298 .21917 .36475 .21835 .36367 .21711 Mtetra
.696 .747 .891 r
.36367 .21711 .36475 .21835 .36651 .21751 .36543 .21629 Mtetra
.699 .752 .893 r
.36543 .21629 .36651 .21751 .36827 .21667 .3672 .21547 Mtetra
.735 .763 .875 r
.3672 .21547 .36827 .21667 .37004 .21576 .36898 .21442 Mtetra
.672 .723 .887 r
.36898 .21442 .37004 .21576 .3718 .21506 .37074 .21371 Mtetra
.482 .642 .927 r
.37074 .21371 .3718 .21506 .37354 .21477 .37246 .2137 Mtetra
.809 .346 0 r
.37246 .2137 .37354 .21477 .37522 .21585 .37404 .21667 Mtetra
.963 .682 .455 r
.37404 .21667 .37522 .21585 .37684 .21816 .36584 .41911 Mtetra
.533 .293 .498 r
.36584 .41911 .37684 .21816 .37833 .22304 .36719 .42944 Mtetra
.511 .276 .494 r
.36719 .42944 .37833 .22304 .38011 .22219 .36905 .42947 Mtetra
.51 .274 .494 r
.36905 .42947 .38011 .22219 .38192 .22076 .37095 .42859 Mtetra
.509 .274 .493 r
.37095 .42859 .38192 .22076 .38361 .22178 .37286 .4276 Mtetra
.513 .277 .494 r
.37286 .4276 .38361 .22178 .37607 .42436 .37468 .42847 Mtetra
.538 .187 .322 r
.37468 .42847 .37607 .42436 .37772 .429 .37651 .42916 Mtetra
.273 0 0 r
.37651 .42916 .37772 .429 .3795 .43088 .37836 .42949 Mtetra
.611 .71 .915 r
.37836 .42949 .3795 .43088 .38138 .43063 .38025 .42901 Mtetra
.652 .69 .872 r
.38025 .42901 .38138 .43063 .38329 .42991 .38216 .42833 Mtetra
.67 .702 .871 r
.38216 .42833 .38329 .42991 .3852 .42895 .38406 .42755 Mtetra
.641 .719 .905 r
.38406 .42755 .3852 .42895 .3871 .4283 .38596 .42694 Mtetra
.64 .726 .911 r
.38596 .42694 .3871 .4283 .389 .42764 .38786 .42633 Mtetra
.642 .735 .917 r
.38786 .42633 .389 .42764 .39091 .42699 .38977 .42572 Mtetra
.536 .701 .946 r
.38977 .42572 .39091 .42699 .3928 .42658 .39166 .42549 Mtetra
.621 .769 .951 r
.39166 .42549 .3928 .42658 .39471 .426 .39356 .42494 Mtetra
.75 .81 .9 r
.39356 .42494 .39471 .426 .39663 .42507 .39549 .42379 Mtetra
.915 .77 .687 r
.39549 .42379 .39663 .42507 .39861 .42259 .39754 .41949 Mtetra
.943 .688 .522 r
.39754 .41949 .39861 .42259 .40064 .41885 .40026 .39792 Mtetra
.945 .664 .475 r
.40026 .39792 .40064 .41885 .40276 .41256 .40956 .20325 Mtetra
.517 .285 .502 r
.40956 .20325 .40276 .41256 .40476 .40925 .41138 .20152 Mtetra
.514 .283 .502 r
.41138 .20152 .40476 .40925 .40665 .40909 .41317 .20095 Mtetra
.513 .282 .502 r
.41317 .20095 .40665 .40909 .4085 .41027 .41493 .20094 Mtetra
.513 .283 .502 r
.41493 .20094 .4085 .41027 .41034 .41142 .41671 .2006 Mtetra
.514 .283 .502 r
.41671 .2006 .41034 .41142 .41224 .41126 .4185 .20007 Mtetra
.515 .284 .502 r
.4185 .20007 .41224 .41126 .41422 .40881 .4203 .19916 Mtetra
.517 .286 .502 r
.4203 .19916 .41422 .40881 .423 .20427 .42214 .19713 Mtetra
.628 .44 .609 r
.42214 .19713 .423 .20427 .42498 .19787 .42398 .19519 Mtetra
.721 .606 .728 r
.42398 .19519 .42498 .19787 .42686 .1947 .42581 .19357 Mtetra
.714 .778 .903 r
.42581 .19357 .42686 .1947 .42867 .1935 .42761 .19267 Mtetra
.655 .823 .964 r
.42761 .19267 .42867 .1935 .43047 .19285 .42941 .19201 Mtetra
.617 .809 .974 r
.42941 .19201 .43047 .19285 .43226 .19247 .4312 .19147 Mtetra
.631 .78 .953 r
.4312 .19147 .43226 .19247 .43405 .192 .433 .19092 Mtetra
.635 .764 .94 r
.433 .19092 .43405 .192 .43584 .19152 .43479 .19035 Mtetra
.646 .751 .925 r
.43479 .19035 .43584 .19152 .43764 .191 .43659 .18975 Mtetra
.686 .749 .899 r
.43659 .18975 .43764 .191 .43945 .19023 .4384 .18897 Mtetra
.696 .75 .893 r
.4384 .18897 .43945 .19023 .44125 .18937 .44021 .18813 Mtetra
.696 .753 .896 r
.44021 .18813 .44125 .18937 .44306 .18851 .44202 .1873 Mtetra
.734 .769 .881 r
.44202 .1873 .44306 .18851 .44488 .18759 .44384 .18625 Mtetra
.69 .735 .885 r
.44384 .18625 .44488 .18759 .44669 .18682 .44565 .18543 Mtetra
.575 .681 .912 r
.44565 .18543 .44669 .18682 .44849 .18636 .44745 .18512 Mtetra
0 0 .489 r
.44745 .18512 .44849 .18636 .45026 .18706 .44919 .18709 Mtetra
.932 .571 .311 r
.44919 .18709 .45026 .18706 .45202 .18887 .45077 .19582 Mtetra
.962 .672 .437 r
.45077 .19582 .45202 .18887 .45373 .19255 .44766 .40103 Mtetra
.513 .277 .494 r
.44766 .40103 .45373 .19255 .45552 .19305 .44956 .40208 Mtetra
.51 .275 .494 r
.44956 .40208 .45552 .19305 .45736 .19159 .45151 .40129 Mtetra
.509 .274 .493 r
.45151 .40129 .45736 .19159 .45917 .19121 .45347 .40012 Mtetra
.513 .277 .494 r
.45347 .40012 .45917 .19121 .45669 .39345 .45539 .40072 Mtetra
.536 .228 .392 r
.45539 .40072 .45669 .39345 .45847 .40066 .45731 .40154 Mtetra
.442 0 0 r
.45731 .40154 .45847 .40066 .46036 .40312 .45924 .40198 Mtetra
.587 .753 .957 r
.45924 .40198 .46036 .40312 .4623 .40311 .4612 .40154 Mtetra
.675 .712 .876 r
.4612 .40154 .4623 .40311 .46426 .40223 .46316 .40072 Mtetra
.697 .728 .874 r
.46316 .40072 .46426 .40223 .46623 .40105 .46512 .39978 Mtetra
.651 .752 .924 r
.46512 .39978 .46623 .40105 .46819 .40031 .46708 .39911 Mtetra
.62 .754 .942 r
.46708 .39911 .46819 .40031 .47015 .39978 .46904 .39856 Mtetra
.616 .75 .941 r
.46904 .39856 .47015 .39978 .47211 .39926 .471 .39803 Mtetra
.634 .754 .934 r
.471 .39803 .47211 .39926 .47407 .39864 .47296 .39742 Mtetra
.642 .76 .934 r
.47296 .39742 .47407 .39864 .47603 .39797 .47492 .39678 Mtetra
.644 .766 .937 r
.47492 .39678 .47603 .39797 .478 .39729 .47689 .39613 Mtetra
.638 .77 .943 r
.47689 .39613 .478 .39729 .47996 .39664 .47886 .39551 Mtetra
.635 .775 .948 r
.47886 .39551 .47996 .39664 .48193 .396 .48083 .39489 Mtetra
.636 .779 .949 r
.48083 .39489 .48193 .396 .4839 .39537 .4828 .39426 Mtetra
.542 .743 .969 r
.4828 .39426 .4839 .39537 .48587 .39494 .48476 .39396 Mtetra
.573 .781 .977 r
.48476 .39396 .48587 .39494 .48784 .39445 .48674 .39352 Mtetra
.717 .84 .94 r
.48674 .39352 .48784 .39445 .48982 .39362 .48871 .39253 Mtetra
.915 .811 .73 r
.48871 .39253 .48982 .39362 .49181 .39148 .49072 .38913 Mtetra
.94 .707 .558 r
.49072 .38913 .49181 .39148 .49381 .38781 .4928 .37827 Mtetra
.966 .678 .434 r
.4928 .37827 .49381 .38781 .49584 .38133 .49671 .17145 Mtetra
.519 .287 .503 r
.49671 .17145 .49584 .38133 .49787 .37353 .49858 .16863 Mtetra
.514 .283 .502 r
.49858 .16863 .49787 .37353 .49984 .37307 .50042 .16786 Mtetra
.513 .282 .502 r
.50042 .16786 .49984 .37307 .50179 .37613 .50227 .16771 Mtetra
.513 .283 .502 r
.50227 .16771 .50179 .37613 .50376 .37686 .50411 .16733 Mtetra
.514 .283 .502 r
.50411 .16733 .50376 .37686 .50573 .3767 .50596 .16672 Mtetra
.50596 .16672 .50573 .3767 .50771 .37647 .50781 .16611 Mtetra
.50781 .16611 .50771 .37647 .50969 .37612 .50967 .16548 Mtetra
.50967 .16548 .50969 .37612 .51167 .37567 .51152 .16483 Mtetra
.51152 .16483 .51167 .37567 .51365 .37516 .51338 .16417 Mtetra
.51338 .16417 .51365 .37516 .51564 .37461 .51523 .16351 Mtetra
.51523 .16351 .51564 .37461 .51763 .37402 .51709 .16283 Mtetra
.51709 .16283 .51763 .37402 .51962 .3734 .51895 .16215 Mtetra
.51895 .16215 .51962 .3734 .52161 .37275 .52081 .16145 Mtetra
.52081 .16145 .52161 .37275 .5236 .37207 .52267 .16076 Mtetra
.52267 .16076 .5236 .37207 .52559 .37137 .52454 .16005 Mtetra
.52454 .16005 .52559 .37137 .52759 .37063 .5264 .15934 Mtetra
.5264 .15934 .52759 .37063 .52958 .36986 .52827 .15863 Mtetra
.52827 .15863 .52958 .36986 .53158 .36909 .53013 .15791 Mtetra
.53013 .15791 .53158 .36909 .53358 .36836 .532 .15721 Mtetra
.532 .15721 .53358 .36836 .53558 .36767 .53387 .15651 Mtetra
.53387 .15651 .53558 .36767 .53758 .36701 .53574 .15582 Mtetra
.53574 .15582 .53758 .36701 .53959 .36643 .53762 .15514 Mtetra
.53762 .15514 .53959 .36643 .54159 .3659 .53949 .15448 Mtetra
.53949 .15448 .54159 .3659 .5436 .36537 .54136 .15382 Mtetra
.54136 .15382 .5436 .36537 .54562 .36583 .54324 .15334 Mtetra
.54324 .15334 .54562 .36583 .54763 .36618 .54512 .15289 Mtetra
.54512 .15289 .54763 .36618 .54964 .36487 .547 .15212 Mtetra
.516 .285 .502 r
.547 .15212 .54964 .36487 .55 .16692 .54887 .15044 Mtetra
.57 .356 .55 r
.54887 .15044 .55 .16692 .55176 .15224 .55074 .14835 Mtetra
.687 .537 .678 r
.55074 .14835 .55176 .15224 .55361 .14815 .55261 .14655 Mtetra
.735 .719 .836 r
.55261 .14655 .55361 .14815 .55548 .14623 .55449 .14535 Mtetra
.663 .826 .962 r
.55449 .14535 .55548 .14623 .55736 .14543 .55637 .14463 Mtetra
.611 .828 .983 r
.55637 .14463 .55736 .14543 .55925 .14494 .55826 .14406 Mtetra
.625 .814 .973 r
.55826 .14406 .55925 .14494 .56113 .14442 .56014 .14346 Mtetra
.651 .808 .958 r
.56014 .14346 .56113 .14442 .56302 .14375 .56203 .1428 Mtetra
.652 .808 .958 r
.56203 .1428 .56302 .14375 .56491 .14308 .56392 .14212 Mtetra
.654 .809 .957 r
.56392 .14212 .56491 .14308 .56679 .1424 .56581 .14144 Mtetra
.656 .809 .957 r
.56581 .14144 .56679 .1424 .56868 .14171 .5677 .14075 Mtetra
.657 .81 .956 r
.5677 .14075 .56868 .14171 .57058 .14102 .56959 .14006 Mtetra
.658 .81 .956 r
.56959 .14006 .57058 .14102 .57247 .14032 .57149 .13936 Mtetra
.659 .81 .956 r
.57149 .13936 .57247 .14032 .57436 .13962 .57338 .13866 Mtetra
.66 .811 .956 r
.57338 .13866 .57436 .13962 .57626 .13892 .57528 .13796 Mtetra
.57528 .13796 .57626 .13892 .57815 .13821 .57717 .13725 Mtetra
.57717 .13725 .57815 .13821 .58005 .13751 .57907 .13654 Mtetra
.661 .811 .956 r
.57907 .13654 .58005 .13751 .58195 .1368 .58097 .13583 Mtetra
.58097 .13583 .58195 .1368 .58385 .13609 .58287 .13512 Mtetra
.58287 .13512 .58385 .13609 .58575 .13538 .58478 .13441 Mtetra
.661 .812 .956 r
.58478 .13441 .58575 .13538 .58765 .13467 .58668 .1337 Mtetra
.58668 .1337 .58765 .13467 .58956 .13396 .58859 .13299 Mtetra
.58859 .13299 .58956 .13396 .59146 .13324 .59049 .13227 Mtetra
.59049 .13227 .59146 .13324 .59337 .13253 .5924 .13156 Mtetra
.5924 .13156 .59337 .13253 .59528 .13181 .59431 .13085 Mtetra
.661 .812 .955 r
.59431 .13085 .59528 .13181 .59719 .1311 .59622 .13013 Mtetra
.59622 .13013 .59719 .1311 .5991 .13038 .59813 .12941 Mtetra
.59813 .12941 .5991 .13038 .60101 .12967 .60004 .1287 Mtetra
.662 .812 .955 r
.60004 .1287 .60101 .12967 .60292 .12895 .60196 .12798 Mtetra
.60196 .12798 .60292 .12895 .60484 .12823 .60387 .12726 Mtetra
.60387 .12726 .60484 .12823 .60675 .12751 .60579 .12654 Mtetra
.60579 .12654 .60675 .12751 .60867 .12679 .60771 .12582 Mtetra
.60771 .12582 .60867 .12679 .61059 .12607 .60963 .12509 Mtetra
.60963 .12509 .61059 .12607 .61251 .12535 .61155 .12437 Mtetra
.663 .812 .955 r
.61155 .12437 .61251 .12535 .61443 .12462 .61347 .12365 Mtetra
.61347 .12365 .61443 .12462 .61635 .1239 .61539 .12292 Mtetra
.663 .813 .955 r
.61539 .12292 .61635 .1239 .61827 .12317 .61732 .12219 Mtetra
.61732 .12219 .61827 .12317 .6202 .12244 .61924 .12146 Mtetra
.61924 .12146 .6202 .12244 .62212 .12171 .62117 .12073 Mtetra
.663 .813 .956 r
.62117 .12073 .62212 .12171 .62405 .12098 .6231 .12 Mtetra
.663 .814 .956 r
.6231 .12 .62405 .12098 .62598 .12025 .62503 .11927 Mtetra
.662 .814 .956 r
.62503 .11927 .62598 .12025 .62791 .11952 .62696 .11855 Mtetra
.62696 .11855 .62791 .11952 .62984 .1188 .62889 .11782 Mtetra
.661 .813 .956 r
.62889 .11782 .62984 .1188 .63177 .11807 .63083 .11709 Mtetra
.66 .813 .957 r
.63083 .11709 .63177 .11807 .63371 .11736 .63276 .11637 Mtetra
.66 .812 .956 r
.63276 .11637 .63371 .11736 .63564 .11664 .6347 .11565 Mtetra
.66 .811 .956 r
.6347 .11565 .63564 .11664 .63758 .11593 .63664 .11493 Mtetra
.655 .809 .957 r
.63664 .11493 .63758 .11593 .63952 .11524 .63858 .11423 Mtetra
.644 .802 .958 r
.63858 .11423 .63952 .11524 .64146 .11461 .64052 .11357 Mtetra
.627 .787 .959 r
.64052 .11357 .64146 .11461 .64341 .11409 .64247 .11298 Mtetra
.628 .773 .95 r
.64247 .11298 .64341 .11409 .64536 .11358 .64442 .11239 Mtetra
.641 .762 .936 r
.64442 .11239 .64536 .11358 .64732 .11302 .64637 .11176 Mtetra
.662 .757 .92 r
.64637 .11176 .64732 .11302 .64926 .11234 .64831 .11104 Mtetra
.669 .752 .912 r
.64831 .11104 .64926 .11234 .65121 .11161 .65026 .11028 Mtetra
.673 .748 .907 r
.65026 .11028 .65121 .11161 .65316 .11086 .65221 .1095 Mtetra
.674 .744 .903 r
.65221 .1095 .65316 .11086 .65511 .11012 .65415 .10872 Mtetra
.675 .738 .898 r
.65415 .10872 .65511 .11012 .65706 .10935 .6561 .10793 Mtetra
.694 .74 .887 r
.6561 .10793 .65706 .10935 .659 .10851 .65805 .10703 Mtetra
.733 .746 .862 r
.65805 .10703 .659 .10851 .66094 .1075 .65998 .10588 Mtetra
.668 .699 .87 r
.65998 .10588 .66094 .1075 .66289 .10669 .66194 .1051 Mtetra
.451 .594 .903 r
.66194 .1051 .66289 .10669 .66487 .10633 .66394 .10523 Mtetra
.672 .209 0 r
.66394 .10523 .66487 .10633 .66689 .107 .66609 .10848 Mtetra
.973 .663 .335 r
.66609 .10848 .66689 .107 .66899 .10897 .67827 .31687 Mtetra
.526 .286 .495 r
.67827 .31687 .66899 .10897 .6714 .11737 .6808 .32478 Mtetra
.514 .277 .494 r
.6808 .32478 .6714 .11737 .68377 .32239 .68301 .32598 Mtetra
.483 .113 .262 r
.68301 .32598 .68377 .32239 .68611 .32602 .68518 .3262 Mtetra
0 0 0 r
.68518 .3262 .68611 .32602 .68833 .32736 .68733 .32601 Mtetra
.481 .675 .95 r
.68733 .32601 .68833 .32736 .69049 .32746 .68948 .32593 Mtetra
.652 .727 .904 r
.68948 .32593 .69049 .32746 .69261 .32665 .6916 .32519 Mtetra
.833 .796 .816 r
.6916 .32519 .69261 .32665 .69466 .32439 .69366 .32312 Mtetra
.981 .767 .54 r
.69366 .32312 .69466 .32439 .69633 .31534 .69536 .31455 Mtetra
.977 .674 .337 r
.69536 .31455 .69633 .31534 .68664 .10115 .68572 .10014 Mtetra
.969 .817 .637 r
.68572 .10014 .68664 .10115 .68839 .09653 .68747 .09538 Mtetra
.735 .808 .91 r
.68747 .09538 .68839 .09653 .69035 .09551 .68943 .0943 Mtetra
.578 .734 .949 r
.68943 .0943 .69035 .09551 .69235 .09517 .69142 .0939 Mtetra
.5 .683 .948 r
.69142 .0939 .69235 .09517 .69436 .09511 .69344 .09377 Mtetra
.656 .744 .915 r
.69344 .09377 .69436 .09511 .69635 .09444 .69542 .09307 Mtetra
.668 .743 .906 r
.69542 .09307 .69635 .09444 .69833 .0937 .6974 .09231 Mtetra
.692 .749 .895 r
.6974 .09231 .69833 .0937 .7003 .09281 .69937 .09142 Mtetra
.774 .778 .856 r
.69937 .09142 .7003 .09281 .70224 .09137 .70131 .09001 Mtetra
.71 .762 .893 r
.70131 .09001 .70224 .09137 .7042 .09035 .70328 .08903 Mtetra
.482 .663 .942 r
.70328 .08903 .7042 .09035 .70623 .09026 .70531 .08897 Mtetra
.754 .328 0 r
.70531 .08897 .70623 .09026 .70855 .09491 .70764 .09368 Mtetra
.972 .659 .306 r
.70764 .09368 .70855 .09491 .72424 .30928 .72326 .30799 Mtetra
.765 .333 0 r
.72326 .30799 .72424 .30928 .72676 .31439 .72577 .31305 Mtetra
.345 .602 .943 r
.72577 .31305 .72676 .31439 .72896 .31455 .72799 .31337 Mtetra
.663 .797 .946 r
.72799 .31337 .72896 .31455 .73111 .31372 .73014 .31257 Mtetra
.837 .85 .855 r
.73014 .31257 .73111 .31372 .73321 .31212 .73222 .31067 Mtetra
.947 .798 .662 r
.73222 .31067 .73321 .31212 .73526 .30992 .73412 .30608 Mtetra
.975 .667 .326 r
.73412 .30608 .73526 .30992 .73723 .30646 .72249 .10144 Mtetra
.545 .306 .504 r
.72249 .10144 .73723 .30646 .73893 .29905 .72347 .08562 Mtetra
.518 .286 .502 r
.72347 .08562 .73893 .29905 .72663 .08976 .72534 .08297 Mtetra
.615 .435 .615 r
.72534 .08297 .72663 .08976 .72831 .0844 .72728 .08133 Mtetra
.66 .561 .733 r
.72728 .08133 .72831 .0844 .73017 .0816 .72926 .08019 Mtetra
.685 .747 .898 r
.72926 .08019 .73017 .0816 .73215 .08053 .73125 .07933 Mtetra
.653 .772 .937 r
.73125 .07933 .73215 .08053 .73416 .07987 .73326 .07863 Mtetra
.64 .758 .934 r
.73326 .07863 .73416 .07987 .73619 .07939 .73528 .07798 Mtetra
.695 .747 .891 r
.09418 .31667 .09536 .31777 .09701 .31667 .09578 .31593 Mtetra
.578 .795 .981 r
.09578 .31593 .09701 .31667 .09862 .31585 .09734 .31556 Mtetra
.203 0 0 r
.09734 .31556 .09862 .31585 .10017 .31558 .09879 .31594 Mtetra
.892 .559 .41 r
.09879 .31594 .10017 .31558 .10135 .31793 .0995 .32187 Mtetra
.932 .676 .527 r
.0995 .32187 .10135 .31793 .101 .33176 .07364 .52491 Mtetra
.521 .284 .496 r
.07364 .52491 .101 .33176 .07647 .52629 .07469 .52908 Mtetra
.487 .106 .243 r
.07469 .52908 .07647 .52629 .07785 .52803 .07627 .52929 Mtetra
.082 0 0 r
.07627 .52929 .07785 .52803 .0794 .52853 .07797 .52869 Mtetra
.686 .972 .919 r
.07797 .52869 .0794 .52853 .08103 .52846 .07973 .52763 Mtetra
.625 .8 .967 r
.07973 .52763 .08103 .52846 .08263 .52856 .08141 .52712 Mtetra
.701 .708 .853 r
.08141 .52712 .08263 .52856 .0843 .5282 .08315 .52623 Mtetra
.758 .668 .762 r
.08315 .52623 .0843 .5282 .08606 .52714 .08499 .52453 Mtetra
.87 .671 .631 r
.08499 .52453 .08606 .52714 .08816 .52344 .08754 .51744 Mtetra
.933 .681 .533 r
.08754 .51744 .08816 .52344 .09141 .51095 .11586 .31279 Mtetra
.526 .293 .505 r
.11586 .31279 .09141 .51095 .11877 .31226 .11804 .30769 Mtetra
.641 .485 .656 r
.11804 .30769 .11877 .31226 .12067 .30929 .11974 .30638 Mtetra
.605 .519 .731 r
.11974 .30638 .12067 .30929 .12241 .30765 .12133 .30585 Mtetra
.557 .592 .845 r
.12133 .30585 .12241 .30765 .12407 .30656 .12287 .30568 Mtetra
.666 .787 .939 r
.12287 .30568 .12407 .30656 .12568 .3059 .12447 .30507 Mtetra
.673 .801 .943 r
.12447 .30507 .12568 .3059 .12726 .30544 .12608 .30443 Mtetra
.656 .759 .926 r
.12608 .30443 .12726 .30544 .12884 .30506 .12768 .30386 Mtetra
.584 .699 .922 r
.12768 .30386 .12884 .30506 .13045 .3044 .12925 .30355 Mtetra
.518 .751 .981 r
.12925 .30355 .13045 .3044 .13207 .30367 .13081 .30334 Mtetra
.372 .799 .97 r
.13081 .30334 .13207 .30367 .13369 .30293 .13236 .30313 Mtetra
.646 .965 .906 r
.13236 .30313 .13369 .30293 .13534 .30197 .13401 .30218 Mtetra
.554 .932 .889 r
.13401 .30218 .13534 .30197 .13697 .30123 .13565 .30138 Mtetra
0 0 0 r
.13565 .30138 .13697 .30123 .13853 .30099 .1372 .30125 Mtetra
.874 .505 .344 r
.1372 .30125 .13853 .30099 .13983 .30291 .13822 .30541 Mtetra
.938 .678 .519 r
.13822 .30541 .13983 .30291 .14034 .31128 .1146 .5098 Mtetra
.523 .286 .497 r
.1146 .5098 .14034 .31128 .11736 .512 .1156 .51503 Mtetra
.542 .172 .289 r
.1156 .51503 .11736 .512 .1187 .51446 .11717 .51565 Mtetra
.124 0 0 r
.11717 .51565 .1187 .51446 .12026 .51517 .11888 .51515 Mtetra
.691 .959 .946 r
.11888 .51515 .12026 .51517 .1219 .51524 .12065 .51415 Mtetra
.649 .759 .93 r
.12065 .51415 .1219 .51524 .12356 .51523 .12237 .51357 Mtetra
.679 .676 .84 r
.12237 .51357 .12356 .51523 .12526 .51482 .12412 .51277 Mtetra
.741 .657 .767 r
.12412 .51277 .12526 .51482 .12704 .51378 .12596 .51125 Mtetra
.856 .67 .65 r
.12596 .51125 .12704 .51378 .12907 .5106 .12826 .50578 Mtetra
.938 .683 .524 r
.12826 .50578 .12907 .5106 .13171 .50223 .15432 .3001 Mtetra
.528 .295 .505 r
.15432 .3001 .13171 .50223 .1573 .29898 .15662 .29378 Mtetra
.652 .481 .64 r
.15662 .29378 .1573 .29898 .15929 .29524 .15838 .29206 Mtetra
.609 .509 .716 r
.15838 .29206 .15929 .29524 .16106 .29342 .16 .29146 Mtetra
.564 .577 .825 r
.16 .29146 .16106 .29342 .16275 .29223 .16158 .29125 Mtetra
.628 .76 .942 r
.16158 .29125 .16275 .29223 .16439 .29148 .16319 .29077 Mtetra
.658 .828 .965 r
.16319 .29077 .16439 .29148 .16601 .29097 .16482 .29016 Mtetra
.667 .807 .95 r
.16482 .29016 .16601 .29097 .16761 .29058 .16645 .28953 Mtetra
.749 .773 .872 r
.16645 .28953 .16761 .29058 .16926 .28974 .16813 .28847 Mtetra
.718 .731 .861 r
.16813 .28847 .16926 .28974 .17092 .28892 .16979 .28755 Mtetra
.592 .675 .898 r
.16979 .28755 .17092 .28892 .17252 .28854 .17139 .28722 Mtetra
.811 .357 0 r
.17139 .28722 .17252 .28854 .17392 .29003 .17267 .28974 Mtetra
.945 .683 .509 r
.17267 .28974 .17392 .29003 .1748 .29614 .1514 .49246 Mtetra
.532 .294 .499 r
.1514 .49246 .1748 .29614 .15377 .4983 .15201 .50188 Mtetra
.58 .227 .334 r
.15201 .50188 .15377 .4983 .1551 .50141 .15357 .50291 Mtetra
.131 0 0 r
.15357 .50291 .1551 .50141 .15669 .50218 .15532 .50225 Mtetra
.756 .978 .918 r
.15532 .50225 .15669 .50218 .15837 .50219 .15714 .50099 Mtetra
.737 .76 .872 r
.15714 .50099 .15837 .50219 .16011 .50161 .15894 .49992 Mtetra
.69 .679 .834 r
.15894 .49992 .16011 .50161 .1619 .50067 .16072 .49903 Mtetra
.69 .685 .841 r
.16072 .49903 .1619 .50067 .1637 .49953 .1625 .49815 Mtetra
.682 .72 .877 r
.1625 .49815 .1637 .49953 .16549 .49859 .16427 .49738 Mtetra
.664 .744 .909 r
.16427 .49738 .16549 .49859 .16726 .49783 .16602 .49672 Mtetra
.64 .754 .931 r
.16602 .49672 .16726 .49783 .16901 .49719 .16777 .49616 Mtetra
.574 .75 .96 r
.16777 .49616 .16901 .49719 .17075 .49671 .1695 .49581 Mtetra
.531 .762 .982 r
.1695 .49581 .17075 .49671 .17248 .49635 .17122 .49553 Mtetra
.55 .788 .987 r
.17122 .49553 .17248 .49635 .1742 .49606 .17294 .49519 Mtetra
.526 .768 .986 r
.17294 .49519 .1742 .49606 .17589 .49616 .17467 .49492 Mtetra
.635 .729 .916 r
.17467 .49492 .17589 .49616 .17758 .49617 .17642 .49438 Mtetra
.732 .682 .802 r
.17642 .49438 .17758 .49617 .17934 .49559 .17825 .4931 Mtetra
.851 .672 .659 r
.17825 .4931 .17934 .49559 .18131 .4929 .18045 .48825 Mtetra
.944 .684 .513 r
.18045 .48825 .18131 .4929 .18383 .48492 .20348 .28223 Mtetra
.529 .296 .505 r
.20348 .28223 .18383 .48492 .20646 .28092 .20576 .27555 Mtetra
.666 .488 .635 r
.20576 .27555 .20646 .28092 .20846 .27693 .20756 .27349 Mtetra
.608 .498 .704 r
.20756 .27349 .20846 .27693 .21023 .2752 .20922 .27284 Mtetra
.565 .539 .785 r
.20922 .27284 .21023 .2752 .21194 .27408 .21083 .27263 Mtetra
.61 .67 .883 r
.21083 .27263 .21194 .27408 .21361 .27328 .21247 .27222 Mtetra
.666 .76 .921 r
.21247 .27222 .21361 .27328 .21527 .27266 .21413 .27159 Mtetra
.654 .754 .923 r
.21413 .27159 .21527 .27266 .21692 .27214 .21578 .27101 Mtetra
.679 .749 .904 r
.21578 .27101 .21692 .27214 .2186 .27126 .21745 .27032 Mtetra
.652 .78 .942 r
.21745 .27032 .2186 .27126 .2203 .27027 .21911 .26974 Mtetra
.293 .723 .969 r
.21911 .26974 .2203 .27027 .22196 .26971 .22071 .26973 Mtetra
.829 .385 .178 r
.22071 .26973 .22196 .26971 .22346 .27073 .22206 .2723 Mtetra
.948 .681 .498 r
.22206 .2723 .22346 .27073 .22459 .27563 .2038 .47646 Mtetra
.528 .29 .497 r
.2038 .47646 .22459 .27563 .2065 .47992 .20476 .48423 Mtetra
.602 .262 .367 r
.20476 .48423 .2065 .47992 .20783 .48393 .20634 .48569 Mtetra
.304 0 .011 r
.20634 .48569 .20783 .48393 .20947 .48479 .20809 .48534 Mtetra
.396 .838 .72 r
.20809 .48534 .20947 .48479 .21118 .48491 .2099 .48443 Mtetra
.667 .893 .979 r
.2099 .48443 .21118 .48491 .2129 .485 .2117 .48366 Mtetra
.662 .724 .895 r
.2117 .48366 .2129 .485 .21463 .48492 .21349 .48299 Mtetra
.723 .667 .794 r
.21349 .48299 .21463 .48492 .21644 .48412 .21534 .48172 Mtetra
.83 .671 .685 r
.21534 .48172 .21644 .48412 .21846 .48099 .21741 .47804 Mtetra
.949 .687 .504 r
.21741 .47804 .21846 .48099 .22181 .46342 .23797 .27478 Mtetra
.542 .306 .508 r
.23797 .27478 .22181 .46342 .24178 .2644 .24064 .26339 Mtetra
.876 .78 .752 r
.24064 .26339 .24178 .2644 .24367 .26143 .24251 .26071 Mtetra
.708 .843 .947 r
.24251 .26071 .24367 .26143 .24537 .26059 .2442 .2599 Mtetra
.538 .803 .995 r
.2442 .2599 .24537 .26059 .24701 .2603 .24585 .25957 Mtetra
.585 .809 .985 r
.24585 .25957 .24701 .2603 .24866 .26003 .24751 .25914 Mtetra
.685 .802 .937 r
.24751 .25914 .24866 .26003 .25033 .25954 .2492 .25843 Mtetra
.671 .754 .913 r
.2492 .25843 .25033 .25954 .252 .25902 .25089 .25776 Mtetra
.626 .713 .908 r
.25089 .25776 .252 .25902 .25368 .25838 .25256 .25728 Mtetra
.561 .721 .948 r
.25256 .25728 .25368 .25838 .25538 .2576 .25421 .257 Mtetra
.469 .798 .999 r
.25421 .257 .25538 .2576 .25708 .25681 .25586 .25676 Mtetra
.534 .914 .939 r
.25586 .25676 .25708 .25681 .25879 .25589 .25755 .25611 Mtetra
.622 .959 .879 r
.25755 .25611 .25879 .25589 .2605 .25496 .25927 .2551 Mtetra
.342 .822 .832 r
.25927 .2551 .2605 .25496 .26218 .25444 .26095 .25459 Mtetra
.721 .216 .028 r
.26095 .25459 .26218 .25444 .26375 .25518 .26245 .25617 Mtetra
.952 .682 .487 r
.26245 .25617 .26375 .25518 .26505 .25925 .2471 .45671 Mtetra
.538 .298 .499 r
.2471 .45671 .26505 .25925 .24952 .46408 .2478 .46916 Mtetra
.625 .296 .393 r
.2478 .46916 .24952 .46408 .25083 .46941 .24938 .4712 Mtetra
.339 0 .038 r
.24938 .4712 .25083 .46941 .2525 .47053 .25116 .47095 Mtetra
.409 .853 .762 r
.25116 .47095 .2525 .47053 .25423 .47081 .253 .4701 Mtetra
.748 .861 .932 r
.253 .4701 .25423 .47081 .25601 .47067 .25484 .46903 Mtetra
.707 .696 .838 r
.25484 .46903 .25601 .47067 .2578 .4703 .25669 .46802 Mtetra
.686 .622 .779 r
.25669 .46802 .2578 .4703 .25961 .46975 .25854 .46695 Mtetra
.625 .554 .755 r
.25854 .46695 .25961 .46975 .26141 .46924 .26036 .46626 Mtetra
.559 .505 .752 r
.26036 .46626 .26141 .46924 .26322 .46882 .26215 .46604 Mtetra
.63 .558 .755 r
.26215 .46604 .26322 .46882 .26505 .46799 .26397 .46532 Mtetra
.785 .642 .703 r
.26397 .46532 .26505 .46799 .26699 .46589 .26596 .4626 Mtetra
.922 .68 .554 r
.26596 .4626 .26699 .46589 .2692 .46024 .26917 .44419 Mtetra
.939 .671 .501 r
.26917 .44419 .2692 .46024 .28691 .25419 .28628 .24678 Mtetra
.678 .475 .604 r
.28628 .24678 .28691 .25419 .28904 .24806 .28819 .24349 Mtetra
.612 .467 .66 r
.28819 .24349 .28904 .24806 .29077 .24711 .28992 .24254 Mtetra
.567 .437 .663 r
.28992 .24254 .29077 .24711 .29245 .2468 .29161 .24214 Mtetra
.557 .427 .66 r
.29161 .24214 .29245 .2468 .29418 .24594 .2933 .24183 Mtetra
.59 .465 .678 r
.2933 .24183 .29418 .24594 .296 .2439 .295 .24124 Mtetra
.617 .548 .754 r
.295 .24124 .296 .2439 .29779 .24213 .29671 .24064 Mtetra
.657 .689 .868 r
.29671 .24064 .29779 .24213 .29955 .24087 .29842 .24 Mtetra
.684 .81 .943 r
.29842 .24 .29955 .24087 .30126 .24025 .30014 .23928 Mtetra
.675 .787 .934 r
.30014 .23928 .30126 .24025 .30296 .23977 .30186 .23859 Mtetra
.64 .736 .918 r
.30186 .23859 .30296 .23977 .30467 .23923 .30357 .23804 Mtetra
.571 .71 .936 r
.30357 .23804 .30467 .23923 .3064 .23844 .30526 .23774 Mtetra
.496 .787 .997 r
.30526 .23774 .3064 .23844 .30813 .23763 .30695 .23748 Mtetra
.478 .881 .951 r
.30695 .23748 .30813 .23763 .30986 .23675 .30867 .23696 Mtetra
.632 .963 .873 r
.30867 .23696 .30986 .23675 .31161 .23577 .31042 .2359 Mtetra
.421 .868 .857 r
.31042 .2359 .31161 .23577 .31333 .23516 .31214 .23527 Mtetra
.53 0 0 r
.31214 .23527 .31333 .23516 .31498 .23549 .31376 .23611 Mtetra
.924 .597 .403 r
.31376 .23611 .31498 .23549 .31644 .2387 .3147 .24688 Mtetra
.949 .672 .48 r
.3147 .24688 .31644 .2387 .30437 .44227 .30261 .44976 Mtetra
.628 .319 .428 r
.30261 .44976 .30437 .44227 .30562 .45049 .30422 .45261 Mtetra
.386 0 .111 r
.30422 .45261 .30562 .45049 .30733 .45187 .30604 .45244 Mtetra
0 0 0 r
.30604 .45244 .30733 .45187 .30911 .45224 .3079 .45164 Mtetra
.719 .886 .957 r
.3079 .45164 .30911 .45224 .31093 .45209 .30977 .45068 Mtetra
.632 .709 .902 r
.30977 .45068 .31093 .45209 .31277 .4516 .31162 .45012 Mtetra
.646 .703 .888 r
.31162 .45012 .31277 .4516 .31463 .45091 .31347 .44949 Mtetra
.654 .716 .894 r
.31347 .44949 .31463 .45091 .31648 .45027 .31532 .44884 Mtetra
.639 .708 .897 r
.31532 .44884 .31648 .45027 .31831 .45001 .31718 .44824 Mtetra
.71 .687 .826 r
.31718 .44824 .31831 .45001 .32017 .44939 .31906 .44715 Mtetra
.798 .675 .728 r
.31906 .44715 .32017 .44939 .32209 .44777 .32104 .44466 Mtetra
.911 .679 .575 r
.32104 .44466 .32209 .44777 .32422 .44271 .32359 .43277 Mtetra
.952 .679 .484 r
.32359 .43277 .32422 .44271 .33856 .23707 .33795 .22802 Mtetra
.672 .459 .588 r
.33795 .22802 .33856 .23707 .34078 .22865 .33989 .22412 Mtetra
.62 .474 .662 r
.33989 .22412 .34078 .22865 .34254 .22756 .34165 .22307 Mtetra
.573 .444 .666 r
.34165 .22307 .34254 .22756 .34427 .22721 .34338 .22261 Mtetra
.551 .426 .663 r
.34338 .22261 .34427 .22721 .346 .2267 .3451 .22237 Mtetra
.585 .456 .671 r
.3451 .22237 .346 .2267 .34783 .22466 .34684 .22178 Mtetra
.61 .532 .741 r
.34684 .22178 .34783 .22466 .34964 .22285 .34858 .2212 Mtetra
.644 .663 .854 r
.34858 .2212 .34964 .22285 .35143 .22146 .35033 .2206 Mtetra
.663 .812 .955 r
.35033 .2206 .35143 .22146 .35318 .2208 .35208 .21994 Mtetra
.668 .813 .953 r
.35208 .21994 .35318 .2208 .35492 .22033 .35383 .21926 Mtetra
.673 .77 .923 r
.35383 .21926 .35492 .22033 .35665 .21991 .35558 .21856 Mtetra
.675 .72 .884 r
.35558 .21856 .35665 .21991 .3584 .2193 .35733 .21784 Mtetra
.663 .699 .873 r
.35733 .21784 .3584 .2193 .36015 .21864 .35909 .21716 Mtetra
.642 .688 .878 r
.35909 .21716 .36015 .21864 .36191 .21792 .36084 .21658 Mtetra
.578 .686 .915 r
.36084 .21658 .36191 .21792 .36367 .21711 .36257 .21626 Mtetra
.516 .766 .987 r
.36257 .21626 .36367 .21711 .36543 .21629 .36431 .21601 Mtetra
.412 .834 .964 r
.36431 .21601 .36543 .21629 .3672 .21547 .36605 .21566 Mtetra
.638 .966 .868 r
.36605 .21566 .3672 .21547 .36898 .21442 .36783 .21455 Mtetra
.473 .895 .864 r
.36783 .21455 .36898 .21442 .37074 .21371 .3696 .21381 Mtetra
.207 0 0 r
.3696 .21381 .37074 .21371 .37246 .2137 .37131 .21404 Mtetra
.913 .551 .334 r
.37131 .21404 .37246 .2137 .37404 .21667 .37269 .22115 Mtetra
.958 .677 .459 r
.37269 .22115 .37404 .21667 .36584 .41911 .36418 .42824 Mtetra
.639 .336 .442 r
.36418 .42824 .36584 .41911 .36719 .42944 .36586 .43199 Mtetra
.436 .037 .181 r
.36586 .43199 .36719 .42944 .36905 .42947 .36772 .43198 Mtetra
.294 0 .106 r
.36772 .43198 .36905 .42947 .37095 .42859 .36961 .43126 Mtetra
.229 0 .092 r
.36961 .43126 .37095 .42859 .37286 .4276 .37153 .4302 Mtetra
.309 0 .123 r
.37153 .4302 .37286 .4276 .37468 .42847 .37342 .42952 Mtetra
.018 0 0 r
.37342 .42952 .37468 .42847 .37651 .42916 .37532 .42881 Mtetra
.592 .907 .982 r
.37532 .42881 .37651 .42916 .37836 .42949 .37722 .4281 Mtetra
.64 .722 .907 r
.37722 .4281 .37836 .42949 .38025 .42901 .37912 .4275 Mtetra
.646 .703 .888 r
.37912 .4275 .38025 .42901 .38216 .42833 .38102 .42686 Mtetra
.662 .715 .888 r
.38102 .42686 .38216 .42833 .38406 .42755 .38292 .42614 Mtetra
.716 .742 .872 r
.38292 .42614 .38406 .42755 .38596 .42694 .38484 .42511 Mtetra
.708 .683 .824 r
.38484 .42511 .38596 .42694 .38786 .42633 .38676 .42401 Mtetra
.685 .625 .783 r
.38676 .42401 .38786 .42633 .38977 .42572 .38869 .42292 Mtetra
.546 .515 .772 r
.38869 .42292 .38977 .42572 .39166 .42549 .39057 .42278 Mtetra
.599 .551 .773 r
.39057 .42278 .39166 .42549 .39356 .42494 .39247 .42229 Mtetra
.696 .606 .752 r
.39247 .42229 .39356 .42494 .39549 .42379 .39441 .42096 Mtetra
.894 .682 .608 r
.39441 .42096 .39549 .42379 .39754 .41949 .39659 .41349 Mtetra
.963 .684 .46 r
.39659 .41349 .39754 .41949 .40026 .39792 .40666 .2038 Mtetra
.525 .292 .504 r
.40666 .2038 .40026 .39792 .40956 .20325 .40863 .19859 Mtetra
.637 .483 .657 r
.40863 .19859 .40956 .20325 .41138 .20152 .41044 .19725 Mtetra
.588 .461 .675 r
.41044 .19725 .41138 .20152 .41317 .20095 .41222 .19663 Mtetra
.554 .438 .675 r
.41222 .19663 .41317 .20095 .41493 .20094 .414 .19637 Mtetra
.584 .451 .665 r
.414 .19637 .41493 .20094 .41671 .2006 .41578 .19576 Mtetra
.582 .443 .656 r
.41578 .19576 .41671 .2006 .4185 .20007 .41757 .19512 Mtetra
.58 .439 .653 r
.41757 .19512 .4185 .20007 .4203 .19916 .41936 .1945 Mtetra
.583 .448 .662 r
.41936 .1945 .4203 .19916 .42214 .19713 .42116 .19388 Mtetra
.606 .511 .72 r
.42116 .19388 .42214 .19713 .42398 .19519 .42295 .19325 Mtetra
.641 .628 .822 r
.42295 .19325 .42398 .19519 .42581 .19357 .42474 .1926 Mtetra
.67 .797 .943 r
.42474 .1926 .42581 .19357 .42761 .19267 .42654 .1919 Mtetra
.668 .842 .966 r
.42654 .1919 .42761 .19267 .42941 .19201 .42834 .19118 Mtetra
.672 .831 .96 r
.42834 .19118 .42941 .19201 .4312 .19147 .43014 .19046 Mtetra
.682 .793 .934 r
.43014 .19046 .4312 .19147 .433 .19092 .43195 .18971 Mtetra
.672 .752 .911 r
.43195 .18971 .433 .19092 .43479 .19035 .43375 .189 Mtetra
.654 .718 .895 r
.43375 .189 .43479 .19035 .43659 .18975 .43555 .18836 Mtetra
.597 .689 .906 r
.43555 .18836 .43659 .18975 .4384 .18897 .43735 .18796 Mtetra
.55 .747 .968 r
.43735 .18796 .4384 .18897 .44021 .18813 .43914 .18766 Mtetra
.442 .819 .991 r
.43914 .18766 .44021 .18813 .44202 .1873 .44094 .18735 Mtetra
.627 .96 .896 r
.44094 .18735 .44202 .1873 .44384 .18625 .44276 .18632 Mtetra
.55 .931 .886 r
.44276 .18632 .44384 .18625 .44565 .18543 .44457 .18544 Mtetra
.156 .698 .786 r
.44457 .18544 .44565 .18543 .44745 .18512 .44637 .18522 Mtetra
.865 .432 .179 r
.44637 .18522 .44745 .18512 .44919 .18709 .44806 .18913 Mtetra
.967 .678 .431 r
.44806 .18913 .44919 .18709 .45077 .19582 .44465 .39853 Mtetra
.522 .284 .495 r
.44465 .39853 .45077 .19582 .44766 .40103 .44644 .40417 Mtetra
.518 .138 .26 r
.44644 .40417 .44766 .40103 .44956 .40208 .44836 .40468 Mtetra
.319 0 .129 r
.44836 .40468 .44956 .40208 .45151 .40129 .45031 .40402 Mtetra
.233 0 .104 r
.45031 .40402 .45151 .40129 .45347 .40012 .45227 .40291 Mtetra
.309 0 .143 r
.45227 .40291 .45347 .40012 .45539 .40072 .45422 .40212 Mtetra
.15 0 0 r
.45422 .40212 .45539 .40072 .45731 .40154 .45617 .40145 Mtetra
.478 .891 .921 r
.45617 .40145 .45731 .40154 .45924 .40198 .45813 .40076 Mtetra
.643 .759 .933 r
.45813 .40076 .45924 .40198 .4612 .40154 .46009 .40012 Mtetra
.648 .725 .905 r
.46009 .40012 .4612 .40154 .46316 .40072 .46204 .39946 Mtetra
.667 .759 .919 r
.46204 .39946 .46316 .40072 .46512 .39978 .464 .39871 Mtetra
.728 .812 .917 r
.464 .39871 .46512 .39978 .46708 .39911 .46597 .39767 Mtetra
.738 .752 .864 r
.46597 .39767 .46708 .39911 .46904 .39856 .46794 .39648 Mtetra
.707 .662 .802 r
.46794 .39648 .46904 .39856 .471 .39803 .46991 .39527 Mtetra
.642 .575 .764 r
.46991 .39527 .471 .39803 .47296 .39742 .47188 .39442 Mtetra
.61 .541 .752 r
.47188 .39442 .47296 .39742 .47492 .39678 .47384 .39379 Mtetra
.599 .536 .755 r
.47384 .39379 .47492 .39678 .47689 .39613 .47581 .39325 Mtetra
.605 .546 .762 r
.47581 .39325 .47689 .39613 .47886 .39551 .47777 .39268 Mtetra
.609 .552 .766 r
.47777 .39268 .47886 .39551 .48083 .39489 .47974 .39209 Mtetra
.611 .555 .767 r
.47974 .39209 .48083 .39489 .4828 .39426 .48171 .39148 Mtetra
.548 .521 .777 r
.48171 .39148 .4828 .39426 .48476 .39396 .48368 .39132 Mtetra
.579 .55 .786 r
.48368 .39132 .48476 .39396 .48674 .39352 .48565 .39096 Mtetra
.681 .61 .769 r
.48565 .39096 .48674 .39352 .48871 .39253 .48763 .38982 Mtetra
.873 .683 .642 r
.48763 .38982 .48871 .39253 .49072 .38913 .48966 .38459 Mtetra
.97 .684 .428 r
.48966 .38459 .49072 .38913 .4928 .37827 .49382 .17325 Mtetra
.527 .293 .504 r
.49382 .17325 .4928 .37827 .49671 .17145 .49572 .16654 Mtetra
.673 .502 .646 r
.49572 .16654 .49671 .17145 .49858 .16863 .49758 .16449 Mtetra
.602 .476 .681 r
.49758 .16449 .49858 .16863 .50042 .16786 .49943 .16373 Mtetra
.564 .452 .684 r
.49943 .16373 .50042 .16786 .50227 .16771 .50127 .16338 Mtetra
.578 .454 .675 r
.50127 .16338 .50227 .16771 .50411 .16733 .50312 .16286 Mtetra
.588 .457 .67 r
.50312 .16286 .50411 .16733 .50596 .16672 .50497 .1622 Mtetra
.587 .455 .668 r
.50497 .1622 .50596 .16672 .50781 .16611 .50682 .16154 Mtetra
.587 .454 .666 r
.50682 .16154 .50781 .16611 .50967 .16548 .50867 .16087 Mtetra
.588 .453 .665 r
.50867 .16087 .50967 .16548 .51152 .16483 .51052 .16019 Mtetra
.588 .452 .664 r
.51052 .16019 .51152 .16483 .51338 .16417 .51238 .15951 Mtetra
.588 .452 .663 r
.51238 .15951 .51338 .16417 .51523 .16351 .51423 .15882 Mtetra
.588 .451 .663 r
.51423 .15882 .51523 .16351 .51709 .16283 .51609 .15813 Mtetra
.51609 .15813 .51709 .16283 .51895 .16215 .51795 .15744 Mtetra
.588 .451 .662 r
.51795 .15744 .51895 .16215 .52081 .16145 .51981 .15674 Mtetra
.51981 .15674 .52081 .16145 .52267 .16076 .52167 .15605 Mtetra
.52167 .15605 .52267 .16076 .52454 .16005 .52353 .15535 Mtetra
.52353 .15535 .52454 .16005 .5264 .15934 .52539 .15464 Mtetra
.588 .452 .663 r
.52539 .15464 .5264 .15934 .52827 .15863 .52726 .15394 Mtetra
.52726 .15394 .52827 .15863 .53013 .15791 .52912 .15324 Mtetra
.588 .452 .664 r
.52912 .15324 .53013 .15791 .532 .15721 .53099 .15254 Mtetra
.588 .453 .664 r
.53099 .15254 .532 .15721 .53387 .15651 .53286 .15184 Mtetra
.53286 .15184 .53387 .15651 .53574 .15582 .53473 .15115 Mtetra
.588 .452 .664 r
.53473 .15115 .53574 .15582 .53762 .15514 .5366 .15046 Mtetra
.587 .451 .664 r
.5366 .15046 .53762 .15514 .53949 .15448 .53847 .14977 Mtetra
.586 .45 .663 r
.53847 .14977 .53949 .15448 .54136 .15382 .54034 .1491 Mtetra
.585 .449 .662 r
.54034 .1491 .54136 .15382 .54324 .15334 .54222 .14843 Mtetra
.582 .443 .657 r
.54222 .14843 .54324 .15334 .54512 .15289 .5441 .14777 Mtetra
.579 .436 .651 r
.5441 .14777 .54512 .15289 .547 .15212 .54597 .14713 Mtetra
.579 .439 .655 r
.54597 .14713 .547 .15212 .54887 .15044 .54785 .14649 Mtetra
.592 .477 .691 r
.54785 .14649 .54887 .15044 .55074 .14835 .54973 .14586 Mtetra
.621 .573 .779 r
.54973 .14586 .55074 .14835 .55261 .14655 .55161 .14523 Mtetra
.647 .732 .911 r
.55161 .14523 .55261 .14655 .55449 .14535 .5535 .14459 Mtetra
.63 .846 .983 r
.5535 .14459 .55449 .14535 .55637 .14463 .55538 .14395 Mtetra
.623 .861 .988 r
.55538 .14395 .55637 .14463 .55826 .14406 .55727 .14331 Mtetra
.635 .848 .982 r
.55727 .14331 .55826 .14406 .56014 .14346 .55916 .14265 Mtetra
.643 .836 .975 r
.55916 .14265 .56014 .14346 .56203 .1428 .56104 .14198 Mtetra
.645 .837 .974 r
.56104 .14198 .56203 .1428 .56392 .14212 .56293 .1413 Mtetra
.647 .838 .974 r
.56293 .1413 .56392 .14212 .56581 .14144 .56482 .14062 Mtetra
.649 .838 .973 r
.56482 .14062 .56581 .14144 .5677 .14075 .56672 .13993 Mtetra
.65 .839 .973 r
.56672 .13993 .5677 .14075 .56959 .14006 .56861 .13924 Mtetra
.651 .839 .972 r
.56861 .13924 .56959 .14006 .57149 .13936 .57051 .13854 Mtetra
.652 .839 .972 r
.57051 .13854 .57149 .13936 .57338 .13866 .5724 .13784 Mtetra
.653 .84 .972 r
.5724 .13784 .57338 .13866 .57528 .13796 .5743 .13713 Mtetra
.5743 .13713 .57528 .13796 .57717 .13725 .5762 .13643 Mtetra
.654 .84 .972 r
.5762 .13643 .57717 .13725 .57907 .13654 .5781 .13572 Mtetra
.5781 .13572 .57907 .13654 .58097 .13583 .58 .13501 Mtetra
.58 .13501 .58097 .13583 .58287 .13512 .5819 .1343 Mtetra
.5819 .1343 .58287 .13512 .58478 .13441 .5838 .13359 Mtetra
.5838 .13359 .58478 .13441 .58668 .1337 .58571 .13287 Mtetra
.58571 .13287 .58668 .1337 .58859 .13299 .58761 .13216 Mtetra
.655 .841 .972 r
.58761 .13216 .58859 .13299 .59049 .13227 .58952 .13145 Mtetra
.58952 .13145 .59049 .13227 .5924 .13156 .59143 .13073 Mtetra
.59143 .13073 .5924 .13156 .59431 .13085 .59334 .13001 Mtetra
.59334 .13001 .59431 .13085 .59622 .13013 .59525 .1293 Mtetra
.59525 .1293 .59622 .13013 .59813 .12941 .59717 .12858 Mtetra
.59717 .12858 .59813 .12941 .60004 .1287 .59908 .12786 Mtetra
.59908 .12786 .60004 .1287 .60196 .12798 .60099 .12714 Mtetra
.655 .841 .971 r
.60099 .12714 .60196 .12798 .60387 .12726 .60291 .12642 Mtetra
.60291 .12642 .60387 .12726 .60579 .12654 .60483 .1257 Mtetra
.60483 .1257 .60579 .12654 .60771 .12582 .60675 .12498 Mtetra
.656 .841 .971 r
.60675 .12498 .60771 .12582 .60963 .12509 .60867 .12426 Mtetra
.60867 .12426 .60963 .12509 .61155 .12437 .61059 .12353 Mtetra
.61059 .12353 .61155 .12437 .61347 .12365 .61251 .12281 Mtetra
.61251 .12281 .61347 .12365 .61539 .12292 .61444 .12208 Mtetra
.61444 .12208 .61539 .12292 .61732 .12219 .61636 .12135 Mtetra
.656 .842 .971 r
.61636 .12135 .61732 .12219 .61924 .12146 .61829 .12062 Mtetra
.61829 .12062 .61924 .12146 .62117 .12073 .62022 .11989 Mtetra
.62022 .11989 .62117 .12073 .6231 .12 .62215 .11916 Mtetra
.62215 .11916 .6231 .12 .62503 .11927 .62408 .11843 Mtetra
.656 .842 .972 r
.62408 .11843 .62503 .11927 .62696 .11855 .62601 .1177 Mtetra
.62601 .1177 .62696 .11855 .62889 .11782 .62795 .11698 Mtetra
.655 .841 .972 r
.62795 .11698 .62889 .11782 .63083 .11709 .62988 .11625 Mtetra
.62988 .11625 .63083 .11709 .63276 .11637 .63182 .11552 Mtetra
.654 .84 .971 r
.63182 .11552 .63276 .11637 .6347 .11565 .63376 .1148 Mtetra
.654 .839 .971 r
.63376 .1148 .6347 .11565 .63664 .11493 .6357 .11408 Mtetra
.6357 .11408 .63664 .11493 .63858 .11423 .63764 .11335 Mtetra
.654 .835 .97 r
.63764 .11335 .63858 .11423 .64052 .11357 .63958 .11263 Mtetra
.657 .823 .963 r
.63958 .11263 .64052 .11357 .64247 .11298 .64152 .11191 Mtetra
.664 .798 .946 r
.64152 .11191 .64247 .11298 .64442 .11239 .64347 .11118 Mtetra
.672 .771 .924 r
.64347 .11118 .64442 .11239 .64637 .11176 .64541 .11041 Mtetra
.679 .748 .903 r
.64541 .11041 .64637 .11176 .64831 .11104 .64736 .10961 Mtetra
.68 .733 .891 r
.64736 .10961 .64831 .11104 .65026 .11028 .6493 .10878 Mtetra
.679 .722 .882 r
.6493 .10878 .65026 .11028 .65221 .1095 .65125 .10796 Mtetra
.676 .713 .876 r
.65125 .10796 .65221 .1095 .65415 .10872 .65319 .10714 Mtetra
.673 .707 .873 r
.65319 .10714 .65415 .10872 .6561 .10793 .65514 .10633 Mtetra
.693 .712 .863 r
.65514 .10633 .6561 .10793 .65805 .10703 .65709 .1054 Mtetra
.736 .725 .841 r
.65709 .1054 .65805 .10703 .65998 .10588 .65902 .10417 Mtetra
.662 .683 .86 r
.65902 .10417 .65998 .10588 .66194 .1051 .66098 .10341 Mtetra
.36 .525 .884 r
.66098 .10341 .66194 .1051 .66394 .10523 .66299 .10387 Mtetra
.856 .455 0 r
.66299 .10387 .66394 .10523 .66609 .10848 .6653 .11038 Mtetra
.973 .663 .337 r
.6653 .11038 .66609 .10848 .67827 .31687 .67763 .32327 Mtetra
.661 .321 .386 r
.67763 .32327 .67827 .31687 .6808 .32478 .67996 .32695 Mtetra
.38 0 .104 r
.67996 .32695 .6808 .32478 .68301 .32598 .68211 .32673 Mtetra
0 0 0 r
.68211 .32673 .68301 .32598 .68518 .3262 .68422 .32576 Mtetra
.684 .946 .96 r
.68422 .32576 .68518 .3262 .68733 .32601 .68632 .32467 Mtetra
.504 .69 .951 r
.68632 .32467 .68733 .32601 .68948 .32593 .68847 .32451 Mtetra
.631 .735 .923 r
.68847 .32451 .68948 .32593 .6916 .32519 .6906 .32387 Mtetra
.822 .815 .843 r
.6906 .32387 .6916 .32519 .69366 .32312 .69267 .32202 Mtetra
.984 .783 .555 r
.69267 .32202 .69366 .32312 .69536 .31455 .69442 .31434 Mtetra
.977 .674 .336 r
.69442 .31434 .69536 .31455 .68572 .10014 .68483 .09953 Mtetra
.987 .839 .609 r
.68483 .09953 .68572 .10014 .68747 .09538 .68656 .09438 Mtetra
.761 .846 .915 r
.68656 .09438 .68747 .09538 .68943 .0943 .68851 .09318 Mtetra
.604 .765 .957 r
.68851 .09318 .68943 .0943 .69142 .0939 .6905 .09267 Mtetra
.533 .708 .951 r
.6905 .09267 .69142 .0939 .69344 .09377 .6925 .09242 Mtetra
.676 .75 .906 r
.6925 .09242 .69344 .09377 .69542 .09307 .69448 .09162 Mtetra
.669 .73 .895 r
.69448 .09162 .69542 .09307 .6974 .09231 .69646 .09084 Mtetra
.663 .725 .895 r
.69646 .09084 .6974 .09231 .69937 .09142 .69844 .09009 Mtetra
.7 .765 .902 r
.69844 .09009 .69937 .09142 .70131 .09001 .70042 .08917 Mtetra
.577 .818 .99 r
.70042 .08917 .70131 .09001 .70328 .08903 .70242 .08866 Mtetra
0 .488 .783 r
.70242 .08866 .70328 .08903 .70531 .08897 .70448 .08913 Mtetra
.898 .478 .142 r
.70448 .08913 .70531 .08897 .70764 .09368 .70695 .09607 Mtetra
.972 .657 .316 r
.70695 .09607 .70764 .09368 .72326 .30799 .72235 .30788 Mtetra
.801 .31 0 r
.72235 .30788 .72326 .30799 .72577 .31305 .72479 .31173 Mtetra
.31 .586 .941 r
.72479 .31173 .72577 .31305 .72799 .31337 .72701 .31214 Mtetra
.645 .78 .945 r
.72701 .31214 .72799 .31337 .73014 .31257 .72917 .31141 Mtetra
.846 .851 .847 r
.72917 .31141 .73014 .31257 .73222 .31067 .73124 .30942 Mtetra
.981 .785 .567 r
.73124 .30942 .73222 .31067 .73412 .30608 .73298 .30235 Mtetra
.975 .667 .325 r
.73298 .30235 .73412 .30608 .72249 .10144 .72066 .08661 Mtetra
.652 .417 .55 r
.72066 .08661 .72249 .10144 .72347 .08562 .72232 .08086 Mtetra
.628 .478 .66 r
.72232 .08086 .72347 .08562 .72534 .08297 .72429 .07957 Mtetra
.593 .504 .724 r
.72429 .07957 .72534 .08297 .72728 .08133 .7263 .079 Mtetra
.553 .556 .812 r
.7263 .079 .72728 .08133 .72926 .08019 .72834 .0788 Mtetra
.669 .742 .905 r
.72834 .0788 .72926 .08019 .73125 .07933 .73035 .07802 Mtetra
.664 .756 .919 r
.73035 .07802 .73125 .07933 .73326 .07863 .73235 .07727 Mtetra
.649 .741 .916 r
.73235 .07727 .73326 .07863 .73528 .07798 .73436 .07658 Mtetra
.024 .433 .867 r
.093 .31559 .09418 .31667 .09578 .31593 .09442 .31619 Mtetra
.755 .293 .151 r
.09442 .31619 .09578 .31593 .09734 .31556 .09569 .31786 Mtetra
.817 .493 .439 r
.09569 .31786 .09734 .31556 .09879 .31594 .09648 .32317 Mtetra
.927 .671 .529 r
.09648 .32317 .09879 .31594 .0995 .32187 .07093 .52259 Mtetra
.521 .284 .496 r
.07093 .52259 .0995 .32187 .07364 .52491 .07195 .52689 Mtetra
.677 .291 .308 r
.07195 .52689 .07364 .52491 .07469 .52908 .07334 .52859 Mtetra
.191 .675 .928 r
.07334 .52859 .07469 .52908 .07627 .52929 .07494 .52867 Mtetra
.63 .845 .982 r
.07494 .52867 .07627 .52929 .07797 .52869 .07663 .52809 Mtetra
.773 .862 .916 r
.07663 .52809 .07797 .52869 .07973 .52763 .0784 .52694 Mtetra
.849 .827 .826 r
.0784 .52694 .07973 .52763 .08141 .52712 .08028 .52501 Mtetra
.819 .676 .706 r
.08028 .52501 .08141 .52712 .08315 .52623 .08231 .52193 Mtetra
.818 .613 .625 r
.08231 .52193 .08315 .52623 .08499 .52453 .08478 .51543 Mtetra
.929 .677 .534 r
.08478 .51543 .08499 .52453 .08754 .51744 .11285 .31405 Mtetra
.526 .293 .504 r
.11285 .31405 .08754 .51744 .11586 .31279 .11507 .30872 Mtetra
.727 .554 .656 r
.11507 .30872 .11586 .31279 .11804 .30769 .11694 .30607 Mtetra
.701 .672 .818 r
.11694 .30607 .11804 .30769 .11974 .30638 .11858 .30515 Mtetra
.612 .704 .909 r
.11858 .30515 .11974 .30638 .12133 .30585 .12016 .30475 Mtetra
.536 .7 .946 r
.12016 .30475 .12133 .30585 .12287 .30568 .1217 .30456 Mtetra
.712 .75 .882 r
.1217 .30456 .12287 .30568 .12447 .30507 .12334 .30372 Mtetra
.697 .708 .857 r
.12334 .30372 .12447 .30507 .12608 .30443 .12497 .30291 Mtetra
.638 .664 .859 r
.12497 .30291 .12608 .30443 .12768 .30386 .12656 .30239 Mtetra
.078 .381 .843 r
.12656 .30239 .12768 .30386 .12925 .30355 .12799 .30315 Mtetra
.793 .302 .03 r
.12799 .30315 .12925 .30355 .13081 .30334 .12928 .30503 Mtetra
.805 .454 .392 r
.12928 .30503 .13081 .30334 .13236 .30313 .13033 .3089 Mtetra
.516 .206 .379 r
.13033 .3089 .13236 .30313 .13401 .30218 .13182 .30925 Mtetra
.389 .1 .348 r
.13182 .30925 .13401 .30218 .13565 .30138 .13352 .30799 Mtetra
.492 .191 .384 r
.13352 .30799 .13565 .30138 .1372 .30125 .13505 .30801 Mtetra
.932 .672 .521 r
.13505 .30801 .1372 .30125 .13822 .30541 .11201 .50624 Mtetra
.525 .287 .497 r
.11201 .50624 .13822 .30541 .1146 .5098 .11289 .51235 Mtetra
.701 .338 .357 r
.11289 .51235 .1146 .5098 .1156 .51503 .11425 .51467 Mtetra
0 .484 .749 r
.11425 .51467 .1156 .51503 .11717 .51565 .11586 .51499 Mtetra
.59 .832 .99 r
.11586 .51499 .11717 .51565 .11888 .51515 .11757 .51452 Mtetra
.752 .862 .93 r
.11757 .51452 .11888 .51515 .12065 .51415 .11934 .51347 Mtetra
.84 .839 .844 r
.11934 .51347 .12065 .51415 .12237 .51357 .12121 .5117 Mtetra
.822 .695 .724 r
.12121 .5117 .12237 .51357 .12412 .51277 .1232 .50891 Mtetra
.811 .616 .638 r
.1232 .50891 .12412 .51277 .12596 .51125 .12548 .50366 Mtetra
.935 .68 .526 r
.12548 .50366 .12596 .51125 .12826 .50578 .15129 .30168 Mtetra
.529 .296 .505 r
.15129 .30168 .12826 .50578 .15432 .3001 .15365 .29491 Mtetra
.71 .523 .633 r
.15365 .29491 .15432 .3001 .15662 .29378 .15555 .29194 Mtetra
.718 .657 .788 r
.15555 .29194 .15662 .29378 .15838 .29206 .15724 .29079 Mtetra
.623 .702 .902 r
.15724 .29079 .15838 .29206 .16 .29146 .15884 .29034 Mtetra
.529 .699 .947 r
.15884 .29034 .16 .29146 .16158 .29125 .16042 .29017 Mtetra
.625 .739 .929 r
.16042 .29017 .16158 .29125 .16319 .29077 .16203 .2897 Mtetra
.669 .755 .915 r
.16203 .2897 .16319 .29077 .16482 .29016 .16366 .28907 Mtetra
.683 .754 .906 r
.16366 .28907 .16482 .29016 .16645 .28953 .1653 .28838 Mtetra
.762 .757 .848 r
.1653 .28838 .16645 .28953 .16813 .28847 .16699 .28719 Mtetra
.736 .731 .847 r
.16699 .28719 .16813 .28847 .16979 .28755 .16867 .28614 Mtetra
.618 .677 .883 r
.16867 .28614 .16979 .28755 .17139 .28722 .17029 .2857 Mtetra
.769 .325 0 r
.17029 .2857 .17139 .28722 .17267 .28974 .17157 .28817 Mtetra
.946 .685 .508 r
.17157 .28817 .17267 .28974 .1514 .49246 .15015 .49144 Mtetra
.946 .628 .399 r
.15015 .49144 .1514 .49246 .15201 .50188 .15072 .50117 Mtetra
.392 0 0 r
.15072 .50117 .15201 .50188 .15357 .50291 .15229 .50211 Mtetra
.702 .829 .943 r
.15229 .50211 .15357 .50291 .15532 .50225 .15406 .50129 Mtetra
.798 .804 .856 r
.15406 .50129 .15532 .50225 .15714 .50099 .15591 .49982 Mtetra
.753 .768 .865 r
.15591 .49982 .15714 .50099 .15894 .49992 .15772 .49865 Mtetra
.708 .742 .878 r
.15772 .49865 .15894 .49992 .16072 .49903 .1595 .49775 Mtetra
.696 .738 .883 r
.1595 .49775 .16072 .49903 .1625 .49815 .16127 .49691 Mtetra
.67 .738 .901 r
.16127 .49691 .1625 .49815 .16427 .49738 .16303 .49622 Mtetra
.642 .745 .924 r
.16303 .49622 .16427 .49738 .16602 .49672 .16478 .49565 Mtetra
.615 .756 .946 r
.16478 .49565 .16602 .49672 .16777 .49616 .16652 .49518 Mtetra
.494 .731 .978 r
.16652 .49518 .16777 .49616 .1695 .49581 .16823 .49501 Mtetra
.465 .76 .994 r
.16823 .49501 .1695 .49581 .17122 .49553 .16994 .49484 Mtetra
.603 .831 .987 r
.16994 .49484 .17122 .49553 .17294 .49519 .17168 .49433 Mtetra
.802 .822 .867 r
.17168 .49433 .17294 .49519 .17467 .49492 .17353 .49287 Mtetra
.813 .684 .722 r
.17353 .49287 .17467 .49492 .17642 .49438 .17551 .49015 Mtetra
.807 .607 .631 r
.17551 .49015 .17642 .49438 .17825 .4931 .17778 .48468 Mtetra
.94 .68 .516 r
.17778 .48468 .17825 .4931 .18045 .48825 .20055 .28292 Mtetra
.528 .294 .505 r
.20055 .28292 .18045 .48825 .20348 .28223 .20281 .27651 Mtetra
.699 .508 .625 r
.20281 .27651 .20348 .28223 .20576 .27555 .20471 .27351 Mtetra
.726 .644 .767 r
.20471 .27351 .20576 .27555 .20756 .27349 .20644 .27217 Mtetra
.626 .699 .897 r
.20644 .27217 .20756 .27349 .20922 .27284 .20808 .2717 Mtetra
.527 .695 .945 r
.20808 .2717 .20922 .27284 .21083 .27263 .20969 .27153 Mtetra
.631 .742 .927 r
.20969 .27153 .21083 .27263 .21247 .27222 .21133 .27103 Mtetra
.686 .74 .893 r
.21133 .27103 .21247 .27222 .21413 .27159 .213 .2703 Mtetra
.637 .708 .898 r
.213 .2703 .21413 .27159 .21578 .27101 .21465 .26978 Mtetra
.4 .621 .941 r
.21465 .26978 .21578 .27101 .21745 .27032 .21624 .26992 Mtetra
.586 .011 0 r
.21624 .26992 .21745 .27032 .21911 .26974 .21773 .27105 Mtetra
.791 .407 .328 r
.21773 .27105 .21911 .26974 .22071 .26973 .21903 .27411 Mtetra
.944 .677 .501 r
.21903 .27411 .22071 .26973 .22206 .2723 .20097 .47423 Mtetra
.528 .289 .497 r
.20097 .47423 .22206 .2723 .2038 .47646 .20193 .48192 Mtetra
.641 .318 .41 r
.20193 .48192 .2038 .47646 .20476 .48423 .20341 .48437 Mtetra
.464 0 0 r
.20341 .48437 .20476 .48423 .20634 .48569 .20507 .48503 Mtetra
.521 .813 .999 r
.20507 .48503 .20634 .48569 .20809 .48534 .20682 .48468 Mtetra
.719 .864 .95 r
.20682 .48468 .20809 .48534 .2099 .48443 .20864 .48376 Mtetra
.825 .859 .873 r
.20864 .48376 .2099 .48443 .2117 .48366 .21051 .48218 Mtetra
.836 .738 .756 r
.21051 .48218 .2117 .48366 .21349 .48299 .21248 .4797 Mtetra
.809 .629 .658 r
.21248 .4797 .21349 .48299 .21534 .48172 .2146 .47549 Mtetra
.945 .683 .507 r
.2146 .47549 .21534 .48172 .21741 .47804 .23452 .281 Mtetra
.551 .314 .509 r
.23452 .281 .21741 .47804 .23797 .27478 .23762 .26513 Mtetra
.66 .448 .586 r
.23762 .26513 .23797 .27478 .24064 .26339 .23959 .26144 Mtetra
.766 .669 .755 r
.23959 .26144 .24064 .26339 .24251 .26071 .24137 .25969 Mtetra
.69 .775 .916 r
.24137 .25969 .24251 .26071 .2442 .2599 .24306 .25895 Mtetra
.608 .768 .956 r
.24306 .25895 .2442 .2599 .24585 .25957 .24472 .25851 Mtetra
.676 .764 .918 r
.24472 .25851 .24585 .25957 .24751 .25914 .2464 .25783 Mtetra
.719 .731 .86 r
.2464 .25783 .24751 .25914 .2492 .25843 .24811 .25687 Mtetra
.669 .679 .851 r
.24811 .25687 .2492 .25843 .25089 .25776 .2498 .25616 Mtetra
.458 .579 .888 r
.2498 .25616 .25089 .25776 .25256 .25728 .25142 .25628 Mtetra
.503 0 0 r
.25142 .25628 .25256 .25728 .25421 .257 .25293 .25768 Mtetra
.812 .399 .264 r
.25293 .25768 .25421 .257 .25586 .25676 .2543 .26057 Mtetra
.696 .357 .397 r
.2543 .26057 .25586 .25676 .25755 .25611 .25568 .26349 Mtetra
.393 .108 .356 r
.25568 .26349 .25755 .25611 .25927 .2551 .25744 .26214 Mtetra
.427 .135 .364 r
.25744 .26214 .25927 .2551 .26095 .25459 .25915 .26126 Mtetra
.944 .673 .493 r
.25915 .26126 .26095 .25459 .26245 .25617 .24464 .44987 Mtetra
.546 .305 .501 r
.24464 .44987 .26245 .25617 .2471 .45671 .245 .46615 Mtetra
.625 .33 .448 r
.245 .46615 .2471 .45671 .2478 .46916 .24647 .46946 Mtetra
.604 .064 0 r
.24647 .46946 .2478 .46916 .24938 .4712 .24814 .47052 Mtetra
.479 .794 .999 r
.24814 .47052 .24938 .4712 .25116 .47095 .24992 .47026 Mtetra
.7 .859 .958 r
.24992 .47026 .25116 .47095 .253 .4701 .25175 .46941 Mtetra
.829 .861 .87 r
.25175 .46941 .253 .4701 .25484 .46903 .25365 .46778 Mtetra
.865 .767 .753 r
.25365 .46778 .25484 .46903 .25669 .46802 .25564 .46501 Mtetra
.82 .644 .664 r
.25564 .46501 .25669 .46802 .25854 .46695 .25774 .46089 Mtetra
.734 .532 .62 r
.25774 .46089 .25854 .46695 .26036 .46626 .25985 .45663 Mtetra
.529 .351 .584 r
.25985 .45663 .26036 .46626 .26215 .46604 .26162 .45649 Mtetra
.54 .36 .585 r
.26162 .45649 .26215 .46604 .26397 .46532 .26342 .45612 Mtetra
.759 .529 .585 r
.26342 .45612 .26397 .46532 .26596 .4626 .26583 .44799 Mtetra
.941 .673 .501 r
.26583 .44799 .26596 .4626 .26917 .44419 .28327 .24871 Mtetra
.523 .291 .504 r
.28327 .24871 .26917 .44419 .28628 .24678 .28528 .2442 Mtetra
.764 .628 .71 r
.28528 .2442 .28628 .24678 .28819 .24349 .28711 .24198 Mtetra
.694 .698 .85 r
.28711 .24198 .28819 .24349 .28992 .24254 .28883 .24113 Mtetra
.625 .687 .889 r
.28883 .24113 .28992 .24254 .29161 .24214 .29053 .24065 Mtetra
.596 .663 .886 r
.29053 .24065 .29161 .24214 .2933 .24183 .29222 .24028 Mtetra
.618 .664 .872 r
.29222 .24028 .2933 .24183 .295 .24124 .29391 .23982 Mtetra
.621 .686 .89 r
.29391 .23982 .295 .24124 .29671 .24064 .29561 .23936 Mtetra
.666 .724 .892 r
.29561 .23936 .29671 .24064 .29842 .24 .29733 .23869 Mtetra
.72 .736 .864 r
.29733 .23869 .29842 .24 .30014 .23928 .29907 .23773 Mtetra
.68 .688 .851 r
.29907 .23773 .30014 .23928 .30186 .23859 .30079 .23695 Mtetra
.541 .617 .877 r
.30079 .23695 .30186 .23859 .30357 .23804 .30247 .2368 Mtetra
0 .193 .702 r
.30247 .2368 .30357 .23804 .30526 .23774 .30406 .23802 Mtetra
.805 .353 .167 r
.30406 .23802 .30526 .23774 .30695 .23748 .30555 .24052 Mtetra
.743 .39 .383 r
.30555 .24052 .30695 .23748 .30867 .23696 .30698 .24404 Mtetra
.404 .115 .357 r
.30698 .24404 .30867 .23696 .31042 .2359 .30874 .24286 Mtetra
.409 .118 .357 r
.30874 .24286 .31042 .2359 .31214 .23527 .3105 .24176 Mtetra
.703 .389 .442 r
.3105 .24176 .31214 .23527 .31376 .23611 .31186 .24644 Mtetra
.945 .668 .482 r
.31186 .24644 .31376 .23611 .3147 .24688 .29977 .44656 Mtetra
.519 .282 .495 r
.29977 .44656 .3147 .24688 .30261 .44976 .30129 .45052 Mtetra
.66 .172 .081 r
.30129 .45052 .30261 .44976 .30422 .45261 .303 .4519 Mtetra
.517 .806 .998 r
.303 .4519 .30422 .45261 .30604 .45244 .30483 .45156 Mtetra
.676 .822 .953 r
.30483 .45156 .30604 .45244 .3079 .45164 .30669 .4508 Mtetra
.688 .833 .953 r
.30669 .4508 .3079 .45164 .30977 .45068 .30856 .44999 Mtetra
.541 .822 .998 r
.30856 .44999 .30977 .45068 .31162 .45012 .31039 .44958 Mtetra
.607 .875 .992 r
.31039 .44958 .31162 .45012 .31347 .44949 .31225 .44895 Mtetra
.754 .903 .943 r
.31225 .44895 .31347 .44949 .31532 .44884 .31413 .44783 Mtetra
.858 .81 .802 r
.31413 .44783 .31532 .44884 .31718 .44824 .31609 .4456 Mtetra
.824 .661 .681 r
.31609 .4456 .31718 .44824 .31906 .44715 .31814 .44195 Mtetra
.854 .622 .587 r
.31814 .44195 .31906 .44715 .32104 .44466 .32058 .43196 Mtetra
.949 .676 .486 r
.32058 .43196 .32104 .44466 .32359 .43277 .335 .22934 Mtetra
.523 .29 .503 r
.335 .22934 .32359 .43277 .33795 .22802 .33698 .22489 Mtetra
.746 .596 .689 r
.33698 .22489 .33795 .22802 .33989 .22412 .33882 .22257 Mtetra
.701 .698 .844 r
.33882 .22257 .33989 .22412 .34165 .22307 .34058 .22165 Mtetra
.63 .692 .889 r
.34058 .22165 .34165 .22307 .34338 .22261 .34231 .22114 Mtetra
.584 .665 .894 r
.34231 .22114 .34338 .22261 .3451 .22237 .34404 .22081 Mtetra
.615 .664 .875 r
.34404 .22081 .3451 .22237 .34684 .22178 .34577 .22035 Mtetra
.616 .686 .893 r
.34577 .22035 .34684 .22178 .34858 .2212 .34751 .2199 Mtetra
.637 .715 .904 r
.34751 .2199 .34858 .2212 .35033 .2206 .34925 .21935 Mtetra
.689 .744 .893 r
.34925 .21935 .35033 .2206 .35208 .21994 .351 .21857 Mtetra
.694 .725 .873 r
.351 .21857 .35208 .21994 .35383 .21926 .35276 .21774 Mtetra
.69 .7 .854 r
.35276 .21774 .35383 .21926 .35558 .21856 .35452 .2169 Mtetra
.691 .68 .834 r
.35452 .2169 .35558 .21856 .35733 .21784 .35629 .21601 Mtetra
.652 .643 .828 r
.35629 .21601 .35733 .21784 .35909 .21716 .35804 .21532 Mtetra
.569 .604 .849 r
.35804 .21532 .35909 .21716 .36084 .21658 .35977 .21507 Mtetra
0 .31 .802 r
.35977 .21507 .36084 .21658 .36257 .21626 .36143 .21616 Mtetra
.789 .298 .035 r
.36143 .21616 .36257 .21626 .36431 .21601 .36304 .21844 Mtetra
.795 .432 .37 r
.36304 .21844 .36431 .21601 .36605 .21566 .36453 .2229 Mtetra
.435 .144 .37 r
.36453 .2229 .36605 .21566 .36783 .21455 .3663 .22205 Mtetra
.409 .123 .365 r
.3663 .22205 .36783 .21455 .3696 .21381 .3681 .2208 Mtetra
.581 .272 .411 r
.3681 .2208 .3696 .21381 .37131 .21404 .36975 .22242 Mtetra
.953 .671 .464 r
.36975 .22242 .37131 .21404 .37269 .22115 .36128 .42491 Mtetra
.52 .283 .495 r
.36128 .42491 .37269 .22115 .36418 .42824 .36291 .42945 Mtetra
.697 .249 .183 r
.36291 .42945 .36418 .42824 .36586 .43199 .36467 .4313 Mtetra
.378 .749 .991 r
.36467 .4313 .36586 .43199 .36772 .43198 .36654 .43121 Mtetra
.602 .83 .987 r
.36654 .43121 .36772 .43198 .36961 .43126 .36843 .43066 Mtetra
.671 .883 .977 r
.36843 .43066 .36961 .43126 .37153 .4302 .37033 .42984 Mtetra
.622 .915 .98 r
.37033 .42984 .37153 .4302 .37342 .42952 .37223 .42907 Mtetra
.66 .91 .979 r
.37223 .42907 .37342 .42952 .37532 .42881 .37414 .42823 Mtetra
.675 .889 .976 r
.37414 .42823 .37532 .42881 .37722 .4281 .37605 .42739 Mtetra
.559 .827 .996 r
.37605 .42739 .37722 .4281 .37912 .4275 .37794 .42693 Mtetra
.592 .869 .994 r
.37794 .42693 .37912 .4275 .38102 .42686 .37984 .42633 Mtetra
.702 .905 .968 r
.37984 .42633 .38102 .42686 .38292 .42614 .38175 .42538 Mtetra
.892 .851 .796 r
.38175 .42538 .38292 .42614 .38484 .42511 .38374 .42288 Mtetra
.85 .695 .69 r
.38374 .42288 .38484 .42511 .38676 .42401 .38577 .41918 Mtetra
.812 .599 .614 r
.38577 .41918 .38676 .42401 .38869 .42292 .38791 .41309 Mtetra
.552 .368 .585 r
.38791 .41309 .38869 .42292 .39057 .42278 .38981 .41241 Mtetra
.52 .341 .579 r
.38981 .41241 .39057 .42278 .39247 .42229 .39168 .41245 Mtetra
.589 .395 .587 r
.39168 .41245 .39247 .42229 .39441 .42096 .39363 .41084 Mtetra
.958 .679 .465 r
.39363 .41084 .39441 .42096 .39659 .41349 .4037 .20609 Mtetra
.526 .292 .503 r
.4037 .20609 .39659 .41349 .40666 .2038 .4057 .20001 Mtetra
.758 .582 .657 r
.4057 .20001 .40666 .2038 .40863 .19859 .40758 .19693 Mtetra
.72 .695 .825 r
.40758 .19693 .40863 .19859 .41044 .19725 .40939 .19583 Mtetra
.65 .705 .887 r
.40939 .19583 .41044 .19725 .41222 .19663 .41117 .1952 Mtetra
.598 .682 .9 r
.41117 .1952 .41222 .19663 .414 .19637 .41295 .19481 Mtetra
.654 .683 .865 r
.41295 .19481 .414 .19637 .41578 .19576 .41474 .19415 Mtetra
.653 .677 .86 r
.41474 .19415 .41578 .19576 .41757 .19512 .41653 .19349 Mtetra
.646 .671 .859 r
.41653 .19349 .41757 .19512 .41936 .1945 .41832 .19286 Mtetra
.622 .66 .866 r
.41832 .19286 .41936 .1945 .42116 .19388 .42011 .19236 Mtetra
.621 .678 .883 r
.42011 .19236 .42116 .19388 .42295 .19325 .4219 .19187 Mtetra
.633 .706 .899 r
.4219 .19187 .42295 .19325 .42474 .1926 .42369 .19132 Mtetra
.687 .744 .895 r
.42369 .19132 .42474 .1926 .42654 .1919 .42549 .19053 Mtetra
.697 .732 .877 r
.42549 .19053 .42654 .1919 .42834 .19118 .4273 .18967 Mtetra
.692 .707 .86 r
.4273 .18967 .42834 .19118 .43014 .19046 .42911 .18881 Mtetra
.695 .689 .84 r
.42911 .18881 .43014 .19046 .43195 .18971 .43091 .18788 Mtetra
.663 .653 .83 r
.43091 .18788 .43195 .18971 .43375 .189 .43272 .18712 Mtetra
.608 .622 .84 r
.43272 .18712 .43375 .189 .43555 .18836 .43452 .18667 Mtetra
.24 .447 .862 r
.43452 .18667 .43555 .18836 .43735 .18796 .43628 .18739 Mtetra
.652 .107 0 r
.43628 .18739 .43735 .18796 .43914 .18766 .43801 .18917 Mtetra
.798 .395 .289 r
.43801 .18917 .43914 .18766 .44094 .18735 .4397 .19272 Mtetra
.5 .179 .354 r
.4397 .19272 .44094 .18735 .44276 .18632 .44149 .19294 Mtetra
.391 .1 .347 r
.44149 .19294 .44276 .18632 .44457 .18544 .44332 .19162 Mtetra
.474 .167 .364 r
.44332 .19162 .44457 .18544 .44637 .18522 .44513 .19144 Mtetra
.962 .673 .437 r
.44513 .19144 .44637 .18522 .44806 .18913 .44168 .39432 Mtetra
.524 .286 .495 r
.44168 .39432 .44806 .18913 .44465 .39853 .44343 .40122 Mtetra
.69 .301 .305 r
.44343 .40122 .44465 .39853 .44644 .40417 .4453 .40366 Mtetra
.183 .67 .925 r
.4453 .40366 .44644 .40417 .44836 .40468 .44723 .40376 Mtetra
.639 .816 .968 r
.44723 .40376 .44836 .40468 .45031 .40402 .44918 .4031 Mtetra
.713 .837 .941 r
.44918 .4031 .45031 .40402 .45227 .40291 .45114 .40214 Mtetra
.654 .854 .976 r
.45114 .40214 .45227 .40291 .45422 .40212 .45309 .4014 Mtetra
.632 .855 .984 r
.45309 .4014 .45422 .40212 .45617 .40145 .45505 .40071 Mtetra
.634 .855 .983 r
.45505 .40071 .45617 .40145 .45813 .40076 .457 .40002 Mtetra
.563 .828 .995 r
.457 .40002 .45813 .40076 .46009 .40012 .45896 .39954 Mtetra
.572 .863 .996 r
.45896 .39954 .46009 .40012 .46204 .39946 .46091 .39896 Mtetra
.674 .912 .976 r
.46091 .39896 .46204 .39946 .464 .39871 .46288 .39806 Mtetra
.886 .888 .828 r
.46288 .39806 .464 .39871 .46597 .39767 .46487 .39582 Mtetra
.876 .733 .7 r
.46487 .39582 .46597 .39767 .46794 .39648 .46689 .39214 Mtetra
.836 .621 .612 r
.46689 .39214 .46794 .39648 .46991 .39527 .46895 .38578 Mtetra
.726 .498 .58 r
.46895 .38578 .46991 .39527 .47188 .39442 .471 .37938 Mtetra
.542 .34 .556 r
.471 .37938 .47188 .39442 .47384 .39379 .47296 .37857 Mtetra
.448 .269 .545 r
.47296 .37857 .47384 .39379 .47581 .39325 .47488 .38078 Mtetra
.509 .324 .565 r
.47488 .38078 .47581 .39325 .47777 .39268 .47682 .38108 Mtetra
.532 .345 .572 r
.47682 .38108 .47777 .39268 .47974 .39209 .47878 .38077 Mtetra
.534 .348 .574 r
.47878 .38077 .47974 .39209 .48171 .39148 .48074 .38043 Mtetra
.476 .306 .571 r
.48074 .38043 .48171 .39148 .48368 .39132 .48269 .38148 Mtetra
.51 .338 .584 r
.48269 .38148 .48368 .39132 .48565 .39096 .48464 .38173 Mtetra
.605 .411 .592 r
.48464 .38173 .48565 .39096 .48763 .38982 .48663 .3798 Mtetra
.965 .678 .437 r
.48663 .3798 .48763 .38982 .48966 .38459 .49091 .176 Mtetra
.529 .295 .504 r
.49091 .176 .48966 .38459 .49382 .17325 .49283 .16813 Mtetra
.735 .539 .627 r
.49283 .16813 .49382 .17325 .49572 .16654 .49471 .16461 Mtetra
.755 .684 .782 r
.49471 .16461 .49572 .16654 .49758 .16449 .49656 .16305 Mtetra
.668 .715 .883 r
.49656 .16305 .49758 .16449 .49943 .16373 .49841 .16232 Mtetra
.609 .697 .906 r
.49841 .16232 .49943 .16373 .50127 .16338 .50025 .16186 Mtetra
.636 .69 .883 r
.50025 .16186 .50127 .16338 .50312 .16286 .5021 .16128 Mtetra
.654 .688 .87 r
.5021 .16128 .50312 .16286 .50497 .1622 .50395 .16061 Mtetra
.654 .686 .868 r
.50395 .16061 .50497 .1622 .50682 .16154 .5058 .15993 Mtetra
.654 .684 .865 r
.5058 .15993 .50682 .16154 .50867 .16087 .50765 .15924 Mtetra
.655 .682 .864 r
.50765 .15924 .50867 .16087 .51052 .16019 .50951 .15856 Mtetra
.655 .681 .862 r
.50951 .15856 .51052 .16019 .51238 .15951 .51136 .15787 Mtetra
.655 .68 .861 r
.51136 .15787 .51238 .15951 .51423 .15882 .51322 .15717 Mtetra
.655 .679 .861 r
.51322 .15717 .51423 .15882 .51609 .15813 .51508 .15648 Mtetra
.655 .679 .86 r
.51508 .15648 .51609 .15813 .51795 .15744 .51693 .15578 Mtetra
.655 .678 .86 r
.51693 .15578 .51795 .15744 .51981 .15674 .51879 .15509 Mtetra
.51879 .15509 .51981 .15674 .52167 .15605 .52066 .15439 Mtetra
.52066 .15439 .52167 .15605 .52353 .15535 .52252 .15369 Mtetra
.656 .679 .86 r
.52252 .15369 .52353 .15535 .52539 .15464 .52438 .15299 Mtetra
.52438 .15299 .52539 .15464 .52726 .15394 .52625 .15229 Mtetra
.52625 .15229 .52726 .15394 .52912 .15324 .52811 .15159 Mtetra
.655 .679 .861 r
.52811 .15159 .52912 .15324 .53099 .15254 .52998 .15089 Mtetra
.655 .68 .861 r
.52998 .15089 .53099 .15254 .53286 .15184 .53185 .15019 Mtetra
.654 .68 .862 r
.53185 .15019 .53286 .15184 .53473 .15115 .53372 .1495 Mtetra
.53372 .1495 .53473 .15115 .5366 .15046 .53559 .14881 Mtetra
.653 .679 .862 r
.53559 .14881 .5366 .15046 .53847 .14977 .53746 .14812 Mtetra
.652 .678 .862 r
.53746 .14812 .53847 .14977 .54034 .1491 .53934 .14744 Mtetra
.53934 .14744 .54034 .1491 .54222 .14843 .54121 .14675 Mtetra
.65 .675 .86 r
.54121 .14675 .54222 .14843 .5441 .14777 .54309 .14607 Mtetra
.644 .669 .859 r
.54309 .14607 .5441 .14777 .54597 .14713 .54497 .14543 Mtetra
.627 .662 .864 r
.54497 .14543 .54597 .14713 .54785 .14649 .54685 .14487 Mtetra
.612 .667 .878 r
.54685 .14487 .54785 .14649 .54973 .14586 .54873 .14439 Mtetra
.61 .69 .899 r
.54873 .14439 .54973 .14586 .55161 .14523 .55062 .14391 Mtetra
.627 .725 .918 r
.55062 .14391 .55161 .14523 .5535 .14459 .5525 .14337 Mtetra
.648 .75 .924 r
.5525 .14337 .5535 .14459 .55538 .14395 .55439 .14273 Mtetra
.656 .754 .922 r
.55439 .14273 .55538 .14395 .55727 .14331 .55627 .14206 Mtetra
.657 .75 .919 r
.55627 .14206 .55727 .14331 .55916 .14265 .55816 .14138 Mtetra
.656 .747 .917 r
.55816 .14138 .55916 .14265 .56104 .14198 .56005 .14071 Mtetra
.658 .746 .916 r
.56005 .14071 .56104 .14198 .56293 .1413 .56194 .14003 Mtetra
.659 .746 .915 r
.56194 .14003 .56293 .1413 .56482 .14062 .56383 .13934 Mtetra
.66 .746 .914 r
.56383 .13934 .56482 .14062 .56672 .13993 .56573 .13865 Mtetra
.661 .746 .913 r
.56573 .13865 .56672 .13993 .56861 .13924 .56762 .13795 Mtetra
.56762 .13795 .56861 .13924 .57051 .13854 .56952 .13725 Mtetra
.662 .746 .912 r
.56952 .13725 .57051 .13854 .5724 .13784 .57141 .13655 Mtetra
.57141 .13655 .5724 .13784 .5743 .13713 .57331 .13584 Mtetra
.663 .746 .912 r
.57331 .13584 .5743 .13713 .5762 .13643 .57521 .13514 Mtetra
.57521 .13514 .5762 .13643 .5781 .13572 .57711 .13443 Mtetra
.57711 .13443 .5781 .13572 .58 .13501 .57901 .13372 Mtetra
.57901 .13372 .58 .13501 .5819 .1343 .58092 .133 Mtetra
.58092 .133 .5819 .1343 .5838 .13359 .58282 .13229 Mtetra
.58282 .13229 .5838 .13359 .58571 .13287 .58473 .13158 Mtetra
.58473 .13158 .58571 .13287 .58761 .13216 .58663 .13086 Mtetra
.58663 .13086 .58761 .13216 .58952 .13145 .58854 .13015 Mtetra
.664 .746 .912 r
.58854 .13015 .58952 .13145 .59143 .13073 .59045 .12943 Mtetra
.59045 .12943 .59143 .13073 .59334 .13001 .59236 .12871 Mtetra
.664 .746 .911 r
.59236 .12871 .59334 .13001 .59525 .1293 .59427 .128 Mtetra
.59427 .128 .59525 .1293 .59717 .12858 .59619 .12728 Mtetra
.59619 .12728 .59717 .12858 .59908 .12786 .5981 .12656 Mtetra
.5981 .12656 .59908 .12786 .60099 .12714 .60002 .12584 Mtetra
.60002 .12584 .60099 .12714 .60291 .12642 .60194 .12512 Mtetra
.60194 .12512 .60291 .12642 .60483 .1257 .60386 .1244 Mtetra
.60386 .1244 .60483 .1257 .60675 .12498 .60578 .12367 Mtetra
.60578 .12367 .60675 .12498 .60867 .12426 .6077 .12295 Mtetra
.664 .747 .911 r
.6077 .12295 .60867 .12426 .61059 .12353 .60962 .12223 Mtetra
.60962 .12223 .61059 .12353 .61251 .12281 .61154 .1215 Mtetra
.665 .747 .912 r
.61154 .1215 .61251 .12281 .61444 .12208 .61347 .12077 Mtetra
.61347 .12077 .61444 .12208 .61636 .12135 .6154 .12005 Mtetra
.6154 .12005 .61636 .12135 .61829 .12062 .61732 .11932 Mtetra
.61732 .11932 .61829 .12062 .62022 .11989 .61925 .11859 Mtetra
.665 .748 .912 r
.61925 .11859 .62022 .11989 .62215 .11916 .62118 .11786 Mtetra
.62118 .11786 .62215 .11916 .62408 .11843 .62312 .11713 Mtetra
.62312 .11713 .62408 .11843 .62601 .1177 .62505 .1164 Mtetra
.62505 .1164 .62601 .1177 .62795 .11698 .62698 .11566 Mtetra
.665 .747 .912 r
.62698 .11566 .62795 .11698 .62988 .11625 .62892 .11493 Mtetra
.665 .747 .911 r
.62892 .11493 .62988 .11625 .63182 .11552 .63086 .1142 Mtetra
.665 .746 .911 r
.63086 .1142 .63182 .11552 .63376 .1148 .6328 .11347 Mtetra
.665 .744 .909 r
.6328 .11347 .63376 .1148 .6357 .11408 .63474 .11273 Mtetra
.665 .742 .908 r
.63474 .11273 .6357 .11408 .63764 .11335 .63668 .112 Mtetra
.664 .74 .906 r
.63668 .112 .63764 .11335 .63958 .11263 .63862 .11126 Mtetra
.662 .737 .905 r
.63862 .11126 .63958 .11263 .64152 .11191 .64056 .11054 Mtetra
.669 .738 .902 r
.64056 .11054 .64152 .11191 .64347 .11118 .64251 .10978 Mtetra
.683 .74 .894 r
.64251 .10978 .64347 .11118 .64541 .11041 .64445 .10894 Mtetra
.702 .735 .877 r
.64445 .10894 .64541 .11041 .64736 .10961 .64639 .10799 Mtetra
.698 .712 .859 r
.64639 .10799 .64736 .10961 .6493 .10878 .64833 .10703 Mtetra
.686 .687 .845 r
.64833 .10703 .6493 .10878 .65125 .10796 .65027 .1061 Mtetra
.669 .667 .838 r
.65027 .1061 .65125 .10796 .65319 .10714 .65222 .10526 Mtetra
.664 .661 .837 r
.65222 .10526 .65319 .10714 .65514 .10633 .65417 .10445 Mtetra
.679 .669 .832 r
.65417 .10445 .65514 .10633 .65709 .1054 .65612 .10353 Mtetra
.721 .689 .818 r
.65612 .10353 .65709 .1054 .65902 .10417 .65805 .10232 Mtetra
.656 .661 .843 r
.65805 .10232 .65902 .10417 .66098 .10341 .66 .10156 Mtetra
.379 .513 .866 r
.66 .10156 .66098 .10341 .66299 .10387 .66202 .10202 Mtetra
.807 .425 0 r
.66202 .10202 .66299 .10387 .6653 .11038 .66432 .10841 Mtetra
.974 .666 .326 r
.66432 .10841 .6653 .11038 .67763 .32327 .67664 .32231 Mtetra
.734 .259 0 r
.67664 .32231 .67763 .32327 .67996 .32695 .67897 .32602 Mtetra
.519 .783 .993 r
.67897 .32602 .67996 .32695 .68211 .32673 .68111 .32567 Mtetra
.729 .84 .933 r
.68111 .32567 .68211 .32673 .68422 .32576 .68321 .32456 Mtetra
.741 .815 .91 r
.68321 .32456 .68422 .32576 .68632 .32467 .68531 .32336 Mtetra
.457 .673 .957 r
.68531 .32336 .68632 .32467 .68847 .32451 .68747 .32334 Mtetra
.585 .764 .964 r
.68747 .32334 .68847 .32451 .6906 .32387 .68961 .32286 Mtetra
.819 .867 .882 r
.68961 .32286 .6906 .32387 .69267 .32202 .69169 .32117 Mtetra
.989 .801 .563 r
.69169 .32117 .69267 .32202 .69442 .31434 .69348 .31406 Mtetra
.977 .674 .336 r
.69348 .31406 .69442 .31434 .68483 .09953 .68391 .09856 Mtetra
.978 .808 .605 r
.68391 .09856 .68483 .09953 .68656 .09438 .68563 .09306 Mtetra
.754 .783 .877 r
.68563 .09306 .68656 .09438 .68851 .09318 .68757 .09182 Mtetra
.614 .722 .923 r
.68757 .09182 .68851 .09318 .6905 .09267 .68956 .0913 Mtetra
.547 .689 .932 r
.68956 .0913 .6905 .09267 .6925 .09242 .69157 .09104 Mtetra
.704 .756 .892 r
.69157 .09104 .6925 .09242 .69448 .09162 .69354 .09008 Mtetra
.668 .715 .884 r
.69354 .09008 .69448 .09162 .69646 .09084 .69552 .0893 Mtetra
.59 .678 .902 r
.69552 .0893 .69646 .09084 .69844 .09009 .69752 .08889 Mtetra
.225 .535 .923 r
.69752 .08889 .69844 .09009 .70042 .08917 .69959 .08945 Mtetra
.647 .094 0 r
.69959 .08945 .70042 .08917 .70242 .08866 .70172 .09119 Mtetra
.834 .435 .292 r
.70172 .09119 .70242 .08866 .70448 .08913 .70414 .09735 Mtetra
.97 .652 .333 r
.70414 .09735 .70448 .08913 .70695 .09607 .71906 .30473 Mtetra
.518 .28 .494 r
.71906 .30473 .70695 .09607 .72235 .30788 .72151 .30888 Mtetra
.628 .114 .005 r
.72151 .30888 .72235 .30788 .72479 .31173 .72381 .31047 Mtetra
.316 .6 .947 r
.72381 .31047 .72479 .31173 .72701 .31214 .72603 .31082 Mtetra
.607 .748 .945 r
.72603 .31082 .72701 .31214 .72917 .31141 .7282 .31027 Mtetra
.818 .85 .872 r
.7282 .31027 .72917 .31141 .73124 .30942 .73029 .30854 Mtetra
.991 .804 .556 r
.73029 .30854 .73124 .30942 .73298 .30235 .73203 .30145 Mtetra
.975 .669 .318 r
.73203 .30145 .73298 .30235 .72066 .08661 .71972 .08485 Mtetra
.95 .755 .604 r
.71972 .08485 .72066 .08661 .72232 .08086 .72138 .07909 Mtetra
.723 .707 .835 r
.72138 .07909 .72232 .08086 .72429 .07957 .72335 .07791 Mtetra
.596 .664 .886 r
.72335 .07791 .72429 .07957 .7263 .079 .72538 .07747 Mtetra
.495 .634 .915 r
.72538 .07747 .7263 .079 .72834 .0788 .72743 .07742 Mtetra
.697 .758 .899 r
.72743 .07742 .72834 .0788 .73035 .07802 .72942 .0765 Mtetra
.67 .722 .888 r
.72942 .0765 .73035 .07802 .73235 .07727 .73143 .07571 Mtetra
.608 .686 .898 r
.73143 .07571 .73235 .07727 .73436 .07658 .73345 .07521 Mtetra
.867 .422 .058 r
.09181 .31452 .093 .31559 .09442 .31619 .09296 .31711 Mtetra
.935 .679 .527 r
.09296 .31711 .09442 .31619 .09569 .31786 .06807 .50964 Mtetra
.546 .306 .502 r
.06807 .50964 .09569 .31786 .09648 .32317 .06756 .52511 Mtetra
.515 .278 .494 r
.06756 .52511 .09648 .32317 .07093 .52259 .06893 .52686 Mtetra
.536 .198 .342 r
.06893 .52686 .07093 .52259 .07195 .52689 .07046 .52744 Mtetra
.23 0 0 r
.07046 .52744 .07195 .52689 .07334 .52859 .07207 .52744 Mtetra
.454 .673 .958 r
.07207 .52744 .07334 .52859 .07494 .52867 .07369 .52743 Mtetra
.63 .722 .913 r
.07369 .52743 .07494 .52867 .07663 .52809 .07537 .52693 Mtetra
.754 .761 .858 r
.07537 .52693 .07663 .52809 .0784 .52694 .07715 .52575 Mtetra
.88 .744 .708 r
.07715 .52575 .0784 .52694 .08028 .52501 .07927 .52201 Mtetra
.892 .671 .597 r
.07927 .52201 .08028 .52501 .08231 .52193 .08252 .50967 Mtetra
.926 .673 .536 r
.08252 .50967 .08231 .52193 .08478 .51543 .11044 .3108 Mtetra
.519 .287 .503 r
.11044 .3108 .08478 .51543 .11285 .31405 .11235 .30782 Mtetra
.633 .453 .621 r
.11235 .30782 .11285 .31405 .11507 .30872 .11409 .30614 Mtetra
.681 .58 .736 r
.11409 .30614 .11507 .30872 .11694 .30607 .11576 .30503 Mtetra
.684 .759 .908 r
.11576 .30503 .11694 .30607 .11858 .30515 .11737 .30434 Mtetra
.622 .794 .964 r
.11737 .30434 .11858 .30515 .12016 .30475 .11895 .30387 Mtetra
.596 .771 .963 r
.11895 .30387 .12016 .30475 .1217 .30456 .12053 .30347 Mtetra
.738 .761 .871 r
.12053 .30347 .1217 .30456 .12334 .30372 .12218 .30248 Mtetra
.705 .73 .869 r
.12218 .30248 .12334 .30372 .12497 .30291 .12381 .30165 Mtetra
.591 .692 .912 r
.12381 .30165 .12497 .30291 .12656 .30239 .12538 .30132 Mtetra
.798 .318 0 r
.12538 .30132 .12656 .30239 .12799 .30315 .12664 .30346 Mtetra
.916 .61 .45 r
.12664 .30346 .12799 .30315 .12928 .30503 .12688 .31365 Mtetra
.929 .669 .523 r
.12688 .31365 .12928 .30503 .13033 .3089 .10331 .51229 Mtetra
.512 .276 .494 r
.10331 .51229 .13033 .3089 .13182 .30925 .10484 .51313 Mtetra
.509 .273 .493 r
.10484 .51313 .13182 .30925 .13352 .30799 .10656 .51244 Mtetra
.508 .273 .492 r
.10656 .51244 .13352 .30799 .13505 .30801 .10833 .51146 Mtetra
.512 .276 .493 r
.10833 .51146 .13505 .30801 .11201 .50624 .10987 .51223 Mtetra
.551 .238 .39 r
.10987 .51223 .11201 .50624 .11289 .51235 .11141 .51311 Mtetra
.498 0 0 r
.11141 .51311 .11289 .51235 .11425 .51467 .11299 .51364 Mtetra
.377 .665 .971 r
.11299 .51364 .11425 .51467 .11586 .51499 .11462 .51373 Mtetra
.602 .71 .921 r
.11462 .51373 .11586 .51499 .11757 .51452 .11632 .51332 Mtetra
.733 .757 .872 r
.11632 .51332 .11757 .51452 .11934 .51347 .1181 .51229 Mtetra
.871 .754 .73 r
.1181 .51229 .11934 .51347 .12121 .5117 .12014 .5091 Mtetra
.883 .676 .618 r
.12014 .5091 .12121 .5117 .1232 .50891 .1228 .50077 Mtetra
.935 .679 .526 r
.1228 .50077 .1232 .50891 .12548 .50366 .14894 .29751 Mtetra
.521 .289 .503 r
.14894 .29751 .12548 .50366 .15129 .30168 .15094 .29377 Mtetra
.619 .427 .6 r
.15094 .29377 .15129 .30168 .15365 .29491 .15271 .29192 Mtetra
.674 .557 .714 r
.15271 .29192 .15365 .29491 .15555 .29194 .1544 .29073 Mtetra
.688 .733 .885 r
.1544 .29073 .15555 .29194 .15724 .29079 .15604 .28999 Mtetra
.62 .799 .968 r
.15604 .28999 .15724 .29079 .15884 .29034 .15765 .28951 Mtetra
.58 .781 .975 r
.15765 .28951 .15884 .29034 .16042 .29017 .15925 .28914 Mtetra
.649 .759 .929 r
.15925 .28914 .16042 .29017 .16203 .2897 .16087 .28859 Mtetra
.676 .748 .905 r
.16087 .28859 .16203 .2897 .16366 .28907 .1625 .28792 Mtetra
.686 .743 .895 r
.1625 .28792 .16366 .28907 .1653 .28838 .16415 .28721 Mtetra
.758 .753 .848 r
.16415 .28721 .1653 .28838 .16699 .28719 .16584 .28603 Mtetra
.739 .753 .864 r
.16584 .28603 .16699 .28719 .16867 .28614 .16752 .28501 Mtetra
.615 .727 .925 r
.16752 .28501 .16867 .28614 .17029 .2857 .16913 .28458 Mtetra
.81 .34 0 r
.16913 .28458 .17029 .2857 .17157 .28817 .17043 .28693 Mtetra
.946 .684 .508 r
.17043 .28693 .17157 .28817 .15015 .49144 .14909 .4887 Mtetra
.973 .667 .366 r
.14909 .4887 .15015 .49144 .15072 .50117 .14952 .4997 Mtetra
0 .29 .786 r
.14952 .4997 .15072 .50117 .15229 .50211 .15108 .50073 Mtetra
.683 .718 .876 r
.15108 .50073 .15229 .50211 .15406 .50129 .15285 .49995 Mtetra
.772 .744 .828 r
.15285 .49995 .15406 .50129 .15591 .49982 .15469 .49853 Mtetra
.742 .746 .855 r
.15469 .49853 .15591 .49982 .15772 .49865 .15649 .49738 Mtetra
.704 .743 .883 r
.15649 .49738 .15772 .49865 .1595 .49775 .15827 .49651 Mtetra
.691 .745 .893 r
.15827 .49651 .1595 .49775 .16127 .49691 .16004 .49571 Mtetra
.653 .742 .915 r
.16004 .49571 .16127 .49691 .16303 .49622 .1618 .4951 Mtetra
.615 .746 .939 r
.1618 .4951 .16303 .49622 .16478 .49565 .16353 .49463 Mtetra
.588 .757 .958 r
.16353 .49463 .16478 .49565 .16652 .49518 .16526 .49423 Mtetra
.406 .7 .981 r
.16526 .49423 .16652 .49518 .16823 .49501 .16695 .49423 Mtetra
.42 .743 .993 r
.16695 .49423 .16823 .49501 .16994 .49484 .16866 .49413 Mtetra
.663 .843 .969 r
.16866 .49413 .16994 .49484 .17168 .49433 .17042 .49344 Mtetra
.886 .794 .753 r
.17042 .49344 .17168 .49433 .17353 .49287 .17243 .49051 Mtetra
.903 .688 .603 r
.17243 .49051 .17353 .49287 .17551 .49015 .17516 .48069 Mtetra
.938 .678 .517 r
.17516 .48069 .17551 .49015 .17778 .48468 .19813 .27875 Mtetra
.521 .288 .503 r
.19813 .27875 .17778 .48468 .20055 .28292 .20011 .27505 Mtetra
.615 .424 .6 r
.20011 .27505 .20055 .28292 .20281 .27651 .20188 .27327 Mtetra
.664 .541 .705 r
.20188 .27327 .20281 .27651 .20471 .27351 .20359 .2721 Mtetra
.683 .702 .862 r
.20359 .2721 .20471 .27351 .20644 .27217 .20526 .27134 Mtetra
.616 .795 .967 r
.20526 .27134 .20644 .27217 .20808 .2717 .20691 .27087 Mtetra
.567 .779 .978 r
.20691 .27087 .20808 .2717 .20969 .27153 .20853 .27052 Mtetra
.686 .775 .919 r
.20853 .27052 .20969 .27153 .21133 .27103 .2102 .26981 Mtetra
.705 .739 .878 r
.2102 .26981 .21133 .27103 .213 .2703 .21188 .26897 Mtetra
.615 .693 .899 r
.21188 .26897 .213 .2703 .21465 .26978 .21352 .26854 Mtetra
0 .162 .673 r
.21352 .26854 .21465 .26978 .21624 .26992 .215 .26973 Mtetra
.913 .553 .339 r
.215 .26973 .21624 .26992 .21773 .27105 .21605 .27534 Mtetra
.944 .677 .501 r
.21605 .27534 .21773 .27105 .21903 .27411 .19746 .47897 Mtetra
.519 .281 .495 r
.19746 .47897 .21903 .27411 .20097 .47423 .19881 .48264 Mtetra
.543 .247 .416 r
.19881 .48264 .20097 .47423 .20193 .48192 .20044 .48357 Mtetra
.446 0 .086 r
.20044 .48357 .20193 .48192 .20341 .48437 .20214 .48376 Mtetra
.319 .73 .978 r
.20214 .48376 .20341 .48437 .20507 .48503 .20386 .48373 Mtetra
.566 .698 .93 r
.20386 .48373 .20507 .48503 .20682 .48468 .20561 .48344 Mtetra
.702 .751 .89 r
.20561 .48344 .20682 .48468 .20864 .48376 .20742 .48257 Mtetra
.851 .77 .773 r
.20742 .48257 .20864 .48376 .21051 .48218 .20938 .48015 Mtetra
.888 .701 .643 r
.20938 .48015 .21051 .48218 .21248 .4797 .21167 .47416 Mtetra
.946 .684 .507 r
.21167 .47416 .21248 .4797 .2146 .47549 .23283 .26849 Mtetra
.525 .292 .504 r
.23283 .26849 .2146 .47549 .23452 .281 .23498 .26289 Mtetra
.567 .351 .547 r
.23498 .26289 .23452 .281 .23762 .26513 .23679 .26085 Mtetra
.644 .495 .666 r
.23679 .26085 .23762 .26513 .23959 .26144 .23852 .25956 Mtetra
.685 .646 .805 r
.23852 .25956 .23959 .26144 .24137 .25969 .24023 .25866 Mtetra
.675 .771 .923 r
.24023 .25866 .24137 .25969 .24306 .25895 .24191 .25799 Mtetra
.643 .777 .945 r
.24191 .25799 .24306 .25895 .24472 .25851 .24358 .25743 Mtetra
.71 .77 .9 r
.24358 .25743 .24472 .25851 .2464 .25783 .24528 .25659 Mtetra
.734 .747 .862 r
.24528 .25659 .2464 .25783 .24811 .25687 .247 .25556 Mtetra
.658 .714 .889 r
.247 .25556 .24811 .25687 .2498 .25616 .24868 .25494 Mtetra
0 .363 .83 r
.24868 .25494 .2498 .25616 .25142 .25628 .25024 .25577 Mtetra
.913 .527 .266 r
.25024 .25577 .25142 .25628 .25293 .25768 .25145 .26045 Mtetra
.949 .679 .491 r
.25145 .26045 .25293 .25768 .2543 .26057 .23504 .46517 Mtetra
.519 .281 .495 r
.23504 .46517 .2543 .26057 .25568 .26349 .23646 .46888 Mtetra
.51 .274 .493 r
.23646 .46888 .25568 .26349 .25744 .26214 .23824 .46847 Mtetra
.508 .273 .492 r
.23824 .46847 .25744 .26214 .25915 .26126 .24008 .46746 Mtetra
.51 .274 .493 r
.24008 .46746 .25915 .26126 .24464 .44987 .24184 .46734 Mtetra
.528 .262 .456 r
.24184 .46734 .24464 .44987 .245 .46615 .24351 .4683 Mtetra
.542 .129 .208 r
.24351 .4683 .245 .46615 .24647 .46946 .24521 .46895 Mtetra
.066 .589 .874 r
.24521 .46895 .24647 .46946 .24814 .47052 .24695 .4692 Mtetra
.544 .687 .932 r
.24695 .4692 .24814 .47052 .24992 .47026 .24873 .46897 Mtetra
.684 .743 .896 r
.24873 .46897 .24992 .47026 .25175 .46941 .25055 .46818 Mtetra
.838 .774 .79 r
.25055 .46818 .25175 .46941 .25365 .46778 .2525 .46601 Mtetra
.899 .717 .647 r
.2525 .46601 .25365 .46778 .25564 .46501 .25473 .46024 Mtetra
.951 .685 .496 r
.25473 .46024 .25564 .46501 .25774 .46089 .27335 .25412 Mtetra
.525 .292 .504 r
.27335 .25412 .25774 .46089 .25985 .45663 .27547 .24839 Mtetra
.514 .282 .501 r
.27547 .24839 .25985 .45663 .26162 .45649 .27719 .24749 Mtetra
.512 .281 .501 r
.27719 .24749 .26162 .45649 .26342 .45612 .27887 .24721 Mtetra
.514 .283 .501 r
.27887 .24721 .26342 .45612 .26583 .44799 .2806 .24626 Mtetra
.517 .285 .502 r
.2806 .24626 .26583 .44799 .28327 .24871 .28242 .24419 Mtetra
.671 .508 .656 r
.28242 .24419 .28327 .24871 .28528 .2442 .28422 .24239 Mtetra
.735 .675 .792 r
.28422 .24239 .28528 .2442 .28711 .24198 .28597 .2411 Mtetra
.687 .808 .94 r
.28597 .2411 .28711 .24198 .28883 .24113 .28769 .24036 Mtetra
.634 .82 .972 r
.28769 .24036 .28883 .24113 .29053 .24065 .28939 .2398 Mtetra
.62 .798 .967 r
.28939 .2398 .29053 .24065 .29222 .24028 .29109 .23929 Mtetra
.637 .772 .945 r
.29109 .23929 .29222 .24028 .29391 .23982 .2928 .23875 Mtetra
.641 .757 .932 r
.2928 .23875 .29391 .23982 .29561 .23936 .2945 .2382 Mtetra
.69 .754 .901 r
.2945 .2382 .29561 .23936 .29733 .23869 .29623 .23743 Mtetra
.737 .748 .861 r
.29623 .23743 .29733 .23869 .29907 .23773 .29797 .23637 Mtetra
.674 .715 .879 r
.29797 .23637 .29907 .23773 .30079 .23695 .2997 .23566 Mtetra
.299 .555 .924 r
.2997 .23566 .30079 .23695 .30247 .2368 .30134 .23603 Mtetra
.889 .462 .129 r
.30134 .23603 .30247 .2368 .30406 .23802 .30274 .2397 Mtetra
.956 .681 .476 r
.30274 .2397 .30406 .23802 .30555 .24052 .28968 .4444 Mtetra
.523 .285 .495 r
.28968 .4444 .30555 .24052 .30698 .24404 .29105 .45034 Mtetra
.51 .274 .493 r
.29105 .45034 .30698 .24404 .30874 .24286 .29286 .4501 Mtetra
.508 .273 .493 r
.29286 .4501 .30874 .24286 .3105 .24176 .29472 .44912 Mtetra
.509 .274 .493 r
.29472 .44912 .3105 .24176 .31186 .24644 .29656 .44862 Mtetra
.513 .276 .493 r
.29656 .44862 .31186 .24644 .29977 .44656 .29829 .4496 Mtetra
.545 .167 .276 r
.29829 .4496 .29977 .44656 .30129 .45052 .30004 .45031 Mtetra
0 .527 .739 r
.30004 .45031 .30129 .45052 .303 .4519 .30183 .45052 Mtetra
.61 .707 .913 r
.30183 .45052 .303 .4519 .30483 .45156 .30367 .45006 Mtetra
.651 .702 .884 r
.30367 .45006 .30483 .45156 .30669 .4508 .30552 .44941 Mtetra
.642 .717 .902 r
.30552 .44941 .30669 .4508 .30856 .44999 .30737 .44881 Mtetra
.544 .717 .953 r
.30737 .44881 .30856 .44999 .31039 .44958 .3092 .44854 Mtetra
.648 .783 .946 r
.3092 .44854 .31039 .44958 .31225 .44895 .31106 .44791 Mtetra
.807 .809 .852 r
.31106 .44791 .31225 .44895 .31413 .44783 .31298 .4463 Mtetra
.901 .741 .674 r
.31298 .4463 .31413 .44783 .31609 .4456 .31509 .44164 Mtetra
.958 .687 .48 r
.31509 .44164 .31609 .4456 .31814 .44195 .32989 .23796 Mtetra
.538 .302 .506 r
.32989 .23796 .31814 .44195 .32058 .43196 .33229 .22687 Mtetra
.518 .286 .502 r
.33229 .22687 .32058 .43196 .335 .22934 .33415 .2243 Mtetra
.646 .48 .645 r
.33415 .2243 .335 .22934 .33698 .22489 .33595 .22271 Mtetra
.693 .626 .776 r
.33595 .22271 .33698 .22489 .33882 .22257 .33772 .22163 Mtetra
.69 .801 .934 r
.33772 .22163 .33882 .22257 .34058 .22165 .33947 .22087 Mtetra
.63 .82 .973 r
.33947 .22087 .34058 .22165 .34231 .22114 .3412 .2203 Mtetra
.604 .8 .975 r
.3412 .2203 .34231 .22114 .34404 .22081 .34294 .21982 Mtetra
.629 .776 .951 r
.34294 .21982 .34404 .22081 .34577 .22035 .34468 .21929 Mtetra
.635 .762 .939 r
.34468 .21929 .34577 .22035 .34751 .2199 .34642 .21875 Mtetra
.654 .751 .921 r
.34642 .21875 .34751 .2199 .34925 .21935 .34816 .21813 Mtetra
.691 .748 .895 r
.34816 .21813 .34925 .21935 .351 .21857 .34992 .21734 Mtetra
.697 .749 .892 r
.34992 .21734 .351 .21857 .35276 .21774 .35168 .21653 Mtetra
.702 .753 .891 r
.35168 .21653 .35276 .21774 .35452 .2169 .35344 .21568 Mtetra
.732 .76 .875 r
.35344 .21568 .35452 .2169 .35629 .21601 .35521 .21465 Mtetra
.667 .718 .887 r
.35521 .21465 .35629 .21601 .35804 .21532 .35697 .21396 Mtetra
.458 .628 .927 r
.35697 .21396 .35804 .21532 .35977 .21507 .35868 .21401 Mtetra
.82 .359 0 r
.35868 .21401 .35977 .21507 .36143 .21616 .36024 .21703 Mtetra
.962 .682 .458 r
.36024 .21703 .36143 .21616 .36304 .21844 .3511 .41969 Mtetra
.531 .291 .497 r
.3511 .41969 .36304 .21844 .36453 .2229 .35242 .42964 Mtetra
.511 .275 .493 r
.35242 .42964 .36453 .2229 .3663 .22205 .35426 .42965 Mtetra
.509 .273 .493 r
.35426 .42965 .3663 .22205 .3681 .2208 .35616 .42879 Mtetra
.35616 .42879 .3681 .2208 .36975 .22242 .35806 .42792 Mtetra
.512 .276 .493 r
.35806 .42792 .36975 .22242 .36128 .42491 .35986 .42884 Mtetra
.541 .186 .315 r
.35986 .42884 .36128 .42491 .36291 .42945 .36168 .42956 Mtetra
.277 0 0 r
.36168 .42956 .36291 .42945 .36467 .4313 .36352 .42993 Mtetra
.571 .696 .926 r
.36352 .42993 .36467 .4313 .36654 .43121 .3654 .4296 Mtetra
.624 .679 .882 r
.3654 .4296 .36654 .43121 .36843 .43066 .36729 .42907 Mtetra
.65 .693 .876 r
.36729 .42907 .36843 .43066 .37033 .42984 .36919 .42839 Mtetra
.661 .719 .892 r
.36919 .42839 .37033 .42984 .37223 .42907 .37109 .42768 Mtetra
.671 .733 .896 r
.37109 .42768 .37223 .42907 .37414 .42823 .37299 .42693 Mtetra
.672 .747 .907 r
.37299 .42693 .37414 .42823 .37605 .42739 .37489 .42617 Mtetra
.55 .717 .95 r
.37489 .42617 .37605 .42739 .37794 .42693 .37678 .42588 Mtetra
.629 .781 .955 r
.37678 .42588 .37794 .42693 .37984 .42633 .37868 .4253 Mtetra
.757 .818 .9 r
.37868 .4253 .37984 .42633 .38175 .42538 .3806 .42411 Mtetra
.916 .769 .685 r
.3806 .42411 .38175 .42538 .38374 .42288 .38267 .41975 Mtetra
.943 .688 .522 r
.38267 .41975 .38374 .42288 .38577 .41918 .38553 .39711 Mtetra
.943 .663 .478 r
.38553 .39711 .38577 .41918 .38791 .41309 .39566 .2036 Mtetra
.515 .283 .501 r
.39566 .2036 .38791 .41309 .38981 .41241 .39747 .2022 Mtetra
.513 .282 .501 r
.39747 .2022 .38981 .41241 .39168 .41245 .39924 .20173 Mtetra
.512 .281 .501 r
.39924 .20173 .39168 .41245 .39363 .41084 .40101 .20146 Mtetra
.516 .285 .502 r
.40101 .20146 .39363 .41084 .4037 .20609 .40286 .19939 Mtetra
.634 .448 .614 r
.40286 .19939 .4037 .20609 .4057 .20001 .40469 .19746 Mtetra
.725 .616 .736 r
.40469 .19746 .4057 .20001 .40758 .19693 .40652 .19587 Mtetra
.705 .788 .916 r
.40652 .19587 .40758 .19693 .40939 .19583 .40831 .19502 Mtetra
.647 .826 .969 r
.40831 .19502 .40939 .19583 .41117 .1952 .4101 .19438 Mtetra
.616 .813 .976 r
.4101 .19438 .41117 .1952 .41295 .19481 .41188 .19384 Mtetra
.663 .797 .946 r
.41188 .19384 .41295 .19481 .41474 .19415 .41367 .19317 Mtetra
.664 .794 .944 r
.41367 .19317 .41474 .19415 .41653 .19349 .41547 .19249 Mtetra
.66 .789 .943 r
.41547 .19249 .41653 .19349 .41832 .19286 .41726 .19183 Mtetra
.638 .775 .946 r
.41726 .19183 .41832 .19286 .42011 .19236 .41905 .19126 Mtetra
.639 .761 .936 r
.41905 .19126 .42011 .19236 .4219 .19187 .42084 .19068 Mtetra
.65 .749 .922 r
.42084 .19068 .4219 .19187 .42369 .19132 .42264 .19007 Mtetra
.689 .748 .896 r
.42264 .19007 .42369 .19132 .42549 .19053 .42444 .18927 Mtetra
.698 .749 .891 r
.42444 .18927 .42549 .19053 .4273 .18967 .42625 .18842 Mtetra
.697 .751 .894 r
.42625 .18842 .4273 .18967 .42911 .18881 .42805 .18758 Mtetra
.734 .766 .878 r
.42805 .18758 .42911 .18881 .43091 .18788 .42987 .18653 Mtetra
.688 .73 .883 r
.42987 .18653 .43091 .18788 .43272 .18712 .43167 .18572 Mtetra
.571 .677 .911 r
.43167 .18572 .43272 .18712 .43452 .18667 .43347 .18542 Mtetra
0 0 .458 r
.43347 .18542 .43452 .18667 .43628 .18739 .43519 .18746 Mtetra
.932 .574 .32 r
.43519 .18746 .43628 .18739 .43801 .18917 .43672 .19634 Mtetra
.961 .672 .441 r
.43672 .19634 .43801 .18917 .4397 .19272 .43265 .40131 Mtetra
.512 .276 .493 r
.43265 .40131 .4397 .19272 .44149 .19294 .43454 .40223 Mtetra
.509 .273 .493 r
.43454 .40223 .44149 .19294 .44332 .19162 .43649 .40144 Mtetra
.508 .273 .493 r
.43649 .40144 .44332 .19162 .44513 .19144 .43844 .40032 Mtetra
.512 .276 .493 r
.43844 .40032 .44513 .19144 .44168 .39432 .44035 .40107 Mtetra
.54 .226 .385 r
.44035 .40107 .44168 .39432 .44343 .40122 .44225 .40194 Mtetra
.443 0 0 r
.44225 .40194 .44343 .40122 .4453 .40366 .44417 .40244 Mtetra
.557 .725 .952 r
.44417 .40244 .4453 .40366 .44723 .40376 .44611 .40212 Mtetra
.644 .689 .877 r
.44611 .40212 .44723 .40376 .44918 .4031 .44807 .40146 Mtetra
.667 .698 .869 r
.44807 .40146 .44918 .4031 .45114 .40214 .45002 .40067 Mtetra
.648 .716 .898 r
.45002 .40067 .45114 .40214 .45309 .4014 .45197 .40001 Mtetra
.641 .727 .911 r
.45197 .40001 .45309 .4014 .45505 .40071 .45393 .39938 Mtetra
.643 .737 .917 r
.45393 .39938 .45505 .40071 .457 .40002 .45589 .39874 Mtetra
.559 .713 .944 r
.45589 .39874 .457 .40002 .45896 .39954 .45784 .39842 Mtetra
.601 .763 .957 r
.45784 .39842 .45896 .39954 .46091 .39896 .45979 .39793 Mtetra
.73 .819 .92 r
.45979 .39793 .46091 .39896 .46288 .39806 .46176 .39687 Mtetra
.912 .795 .717 r
.46176 .39687 .46288 .39806 .46487 .39582 .46378 .39326 Mtetra
.937 .7 .555 r
.46378 .39326 .46487 .39582 .46689 .39214 .46595 .38151 Mtetra
.963 .677 .443 r
.46595 .38151 .46689 .39214 .46895 .38578 .47155 .17572 Mtetra
.517 .285 .502 r
.47155 .17572 .46895 .38578 .471 .37938 .47342 .17315 Mtetra
.513 .282 .501 r
.47342 .17315 .471 .37938 .47296 .37857 .47525 .1724 Mtetra
.512 .281 .501 r
.47525 .1724 .47296 .37857 .47488 .38078 .47708 .17226 Mtetra
.513 .282 .501 r
.47708 .17226 .47488 .38078 .47682 .38108 .47891 .17181 Mtetra
.47891 .17181 .47682 .38108 .47878 .38077 .48075 .17118 Mtetra
.48075 .17118 .47878 .38077 .48074 .38043 .48259 .17057 Mtetra
.48259 .17057 .48074 .38043 .48269 .38148 .48442 .17014 Mtetra
.48442 .17014 .48269 .38148 .48464 .38173 .48626 .16965 Mtetra
.514 .282 .501 r
.48626 .16965 .48464 .38173 .48663 .3798 .48811 .16881 Mtetra
.516 .284 .501 r
.48811 .16881 .48663 .3798 .49091 .176 .48997 .16698 Mtetra
.609 .411 .588 r
.48997 .16698 .49091 .176 .49283 .16813 .49183 .16498 Mtetra
.707 .577 .706 r
.49183 .16498 .49283 .16813 .49471 .16461 .49368 .16327 Mtetra
.729 .752 .871 r
.49368 .16327 .49471 .16461 .49656 .16305 .49553 .16221 Mtetra
.658 .829 .965 r
.49553 .16221 .49656 .16305 .49841 .16232 .49738 .16151 Mtetra
.617 .824 .98 r
.49738 .16151 .49841 .16232 .50025 .16186 .49923 .16094 Mtetra
.645 .809 .962 r
.49923 .16094 .50025 .16186 .5021 .16128 .50108 .16031 Mtetra
.661 .802 .95 r
.50108 .16031 .5021 .16128 .50395 .16061 .50293 .15962 Mtetra
.662 .8 .949 r
.50293 .15962 .50395 .16061 .5058 .15993 .50478 .15892 Mtetra
.663 .797 .947 r
.50478 .15892 .5058 .15993 .50765 .15924 .50663 .15823 Mtetra
.663 .795 .945 r
.50663 .15823 .50765 .15924 .50951 .15856 .50849 .15753 Mtetra
.663 .794 .944 r
.50849 .15753 .50951 .15856 .51136 .15787 .51034 .15684 Mtetra
.664 .793 .943 r
.51034 .15684 .51136 .15787 .51322 .15717 .5122 .15614 Mtetra
.664 .792 .943 r
.5122 .15614 .51322 .15717 .51508 .15648 .51406 .15544 Mtetra
.664 .791 .942 r
.51406 .15544 .51508 .15648 .51693 .15578 .51592 .15474 Mtetra
.664 .79 .942 r
.51592 .15474 .51693 .15578 .51879 .15509 .51778 .15404 Mtetra
.51778 .15404 .51879 .15509 .52066 .15439 .51964 .15334 Mtetra
.663 .79 .942 r
.51964 .15334 .52066 .15439 .52252 .15369 .52151 .15264 Mtetra
.52151 .15264 .52252 .15369 .52438 .15299 .52337 .15195 Mtetra
.663 .791 .942 r
.52337 .15195 .52438 .15299 .52625 .15229 .52524 .15125 Mtetra
.663 .791 .943 r
.52524 .15125 .52625 .15229 .52811 .15159 .5271 .15055 Mtetra
.5271 .15055 .52811 .15159 .52998 .15089 .52897 .14985 Mtetra
.662 .792 .944 r
.52897 .14985 .52998 .15089 .53185 .15019 .53084 .14915 Mtetra
.661 .792 .944 r
.53084 .14915 .53185 .15019 .53372 .1495 .53271 .14846 Mtetra
.661 .792 .945 r
.53271 .14846 .53372 .1495 .53559 .14881 .53459 .14777 Mtetra
.66 .792 .945 r
.53459 .14777 .53559 .14881 .53746 .14812 .53646 .14708 Mtetra
.659 .791 .945 r
.53646 .14708 .53746 .14812 .53934 .14744 .53834 .14639 Mtetra
.53834 .14639 .53934 .14744 .54121 .14675 .54021 .14571 Mtetra
.657 .79 .945 r
.54021 .14571 .54121 .14675 .54309 .14607 .54209 .14503 Mtetra
.652 .788 .947 r
.54209 .14503 .54309 .14607 .54497 .14543 .54397 .14437 Mtetra
.635 .779 .95 r
.54397 .14437 .54497 .14543 .54685 .14487 .54585 .14377 Mtetra
.621 .767 .949 r
.54585 .14377 .54685 .14487 .54873 .14439 .54773 .14323 Mtetra
.622 .754 .941 r
.54773 .14323 .54873 .14439 .55062 .14391 .54962 .14269 Mtetra
.637 .747 .928 r
.54962 .14269 .55062 .14391 .5525 .14337 .5515 .1421 Mtetra
.651 .745 .918 r
.5515 .1421 .5525 .14337 .55439 .14273 .55339 .14145 Mtetra
.656 .744 .914 r
.55339 .14145 .55439 .14273 .55627 .14206 .55528 .14077 Mtetra
.657 .743 .913 r
.55528 .14077 .55627 .14206 .55816 .14138 .55717 .14009 Mtetra
.55717 .14009 .55816 .14138 .56005 .14071 .55906 .13941 Mtetra
.658 .742 .912 r
.55906 .13941 .56005 .14071 .56194 .14003 .56095 .13873 Mtetra
.659 .742 .911 r
.56095 .13873 .56194 .14003 .56383 .13934 .56284 .13804 Mtetra
.66 .741 .91 r
.56284 .13804 .56383 .13934 .56573 .13865 .56473 .13734 Mtetra
.661 .741 .91 r
.56473 .13734 .56573 .13865 .56762 .13795 .56663 .13664 Mtetra
.661 .741 .909 r
.56663 .13664 .56762 .13795 .56952 .13725 .56852 .13594 Mtetra
.662 .741 .909 r
.56852 .13594 .56952 .13725 .57141 .13655 .57042 .13523 Mtetra
.662 .741 .908 r
.57042 .13523 .57141 .13655 .57331 .13584 .57232 .13453 Mtetra
.57232 .13453 .57331 .13584 .57521 .13514 .57422 .13382 Mtetra
.663 .741 .908 r
.57422 .13382 .57521 .13514 .57711 .13443 .57612 .13311 Mtetra
.57612 .13311 .57711 .13443 .57901 .13372 .57803 .13239 Mtetra
.57803 .13239 .57901 .13372 .58092 .133 .57993 .13168 Mtetra
.57993 .13168 .58092 .133 .58282 .13229 .58183 .13097 Mtetra
.58183 .13097 .58282 .13229 .58473 .13158 .58374 .13025 Mtetra
.58374 .13025 .58473 .13158 .58663 .13086 .58565 .12954 Mtetra
.58565 .12954 .58663 .13086 .58854 .13015 .58756 .12882 Mtetra
.58756 .12882 .58854 .13015 .59045 .12943 .58947 .1281 Mtetra
.58947 .1281 .59045 .12943 .59236 .12871 .59138 .12739 Mtetra
.59138 .12739 .59236 .12871 .59427 .128 .59329 .12667 Mtetra
.59329 .12667 .59427 .128 .59619 .12728 .59521 .12595 Mtetra
.59521 .12595 .59619 .12728 .5981 .12656 .59712 .12523 Mtetra
.59712 .12523 .5981 .12656 .60002 .12584 .59904 .12451 Mtetra
.664 .741 .908 r
.59904 .12451 .60002 .12584 .60194 .12512 .60096 .12379 Mtetra
.60096 .12379 .60194 .12512 .60386 .1244 .60288 .12306 Mtetra
.60288 .12306 .60386 .1244 .60578 .12367 .6048 .12234 Mtetra
.6048 .12234 .60578 .12367 .6077 .12295 .60672 .12162 Mtetra
.60672 .12162 .6077 .12295 .60962 .12223 .60865 .12089 Mtetra
.60865 .12089 .60962 .12223 .61154 .1215 .61057 .12017 Mtetra
.664 .742 .908 r
.61057 .12017 .61154 .1215 .61347 .12077 .6125 .11944 Mtetra
.6125 .11944 .61347 .12077 .6154 .12005 .61443 .11871 Mtetra
.61443 .11871 .6154 .12005 .61732 .11932 .61636 .11798 Mtetra
.61636 .11798 .61732 .11932 .61925 .11859 .61829 .11725 Mtetra
.665 .742 .908 r
.61829 .11725 .61925 .11859 .62118 .11786 .62022 .11652 Mtetra
.62022 .11652 .62118 .11786 .62312 .11713 .62215 .11579 Mtetra
.62215 .11579 .62312 .11713 .62505 .1164 .62408 .11506 Mtetra
.62408 .11506 .62505 .1164 .62698 .11566 .62602 .11432 Mtetra
.665 .742 .907 r
.62602 .11432 .62698 .11566 .62892 .11493 .62796 .11359 Mtetra
.62796 .11359 .62892 .11493 .63086 .1142 .62989 .11285 Mtetra
.666 .741 .906 r
.62989 .11285 .63086 .1142 .6328 .11347 .63183 .11211 Mtetra
.666 .74 .905 r
.63183 .11211 .6328 .11347 .63474 .11273 .63377 .11136 Mtetra
.667 .738 .903 r
.63377 .11136 .63474 .11273 .63668 .112 .63572 .11061 Mtetra
.668 .736 .901 r
.63572 .11061 .63668 .112 .63862 .11126 .63766 .10986 Mtetra
.667 .733 .899 r
.63766 .10986 .63862 .11126 .64056 .11054 .6396 .1091 Mtetra
.672 .73 .893 r
.6396 .1091 .64056 .11054 .64251 .10978 .64155 .10832 Mtetra
.682 .73 .887 r
.64155 .10832 .64251 .10978 .64445 .10894 .64349 .10748 Mtetra
.697 .736 .881 r
.64349 .10748 .64445 .10894 .64639 .10799 .64543 .10656 Mtetra
.7 .742 .884 r
.64543 .10656 .64639 .10799 .64833 .10703 .64737 .10563 Mtetra
.696 .747 .89 r
.64737 .10563 .64833 .10703 .65027 .1061 .64932 .10473 Mtetra
.686 .746 .898 r
.64932 .10473 .65027 .1061 .65222 .10526 .65127 .10388 Mtetra
.68 .744 .899 r
.65127 .10388 .65222 .10526 .65417 .10445 .65322 .10306 Mtetra
.699 .75 .891 r
.65322 .10306 .65417 .10445 .65612 .10353 .65516 .10214 Mtetra
.745 .765 .869 r
.65516 .10214 .65612 .10353 .65805 .10232 .6571 .10094 Mtetra
.667 .739 .904 r
.6571 .10094 .65805 .10232 .66 .10156 .65906 .10018 Mtetra
.318 .557 .921 r
.65906 .10018 .66 .10156 .66202 .10202 .66107 .10061 Mtetra
.831 .425 0 r
.66107 .10061 .66202 .10202 .66432 .10841 .66334 .10651 Mtetra
.974 .666 .327 r
.66334 .10651 .66432 .10841 .67664 .32231 .67561 .3205 Mtetra
0 0 .377 r
.67561 .3205 .67664 .32231 .67897 .32602 .67795 .32443 Mtetra
.547 .667 .916 r
.67795 .32443 .67897 .32602 .68111 .32567 .68009 .32417 Mtetra
.703 .752 .89 r
.68009 .32417 .68111 .32567 .68321 .32456 .6822 .32315 Mtetra
.722 .773 .893 r
.6822 .32315 .68321 .32456 .68531 .32336 .6843 .32203 Mtetra
.463 .67 .953 r
.6843 .32203 .68531 .32336 .68747 .32334 .68647 .322 Mtetra
.599 .736 .941 r
.68647 .322 .68747 .32334 .68961 .32286 .6886 .32149 Mtetra
.804 .804 .852 r
.6886 .32149 .68961 .32286 .69169 .32117 .69068 .31978 Mtetra
.973 .774 .576 r
.69068 .31978 .69169 .32117 .69348 .31406 .69247 .31267 Mtetra
.977 .673 .338 r
.69247 .31267 .69348 .31406 .68391 .09856 .68297 .09725 Mtetra
.964 .784 .612 r
.68297 .09725 .68391 .09856 .68563 .09306 .68469 .09175 Mtetra
.757 .786 .877 r
.68469 .09175 .68563 .09306 .68757 .09182 .68664 .09049 Mtetra
.618 .729 .926 r
.68664 .09049 .68757 .09182 .68956 .0913 .68863 .08995 Mtetra
.557 .697 .934 r
.68863 .08995 .68956 .0913 .69157 .09104 .69064 .08965 Mtetra
.731 .764 .88 r
.69064 .08965 .69157 .09104 .69354 .09008 .6926 .08854 Mtetra
.669 .714 .882 r
.6926 .08854 .69354 .09008 .69552 .0893 .69458 .08774 Mtetra
.499 .63 .91 r
.69458 .08774 .69552 .0893 .69752 .08889 .6966 .08769 Mtetra
.576 .122 0 r
.6966 .08769 .69752 .08889 .69959 .08945 .69881 .09064 Mtetra
.972 .658 .316 r
.69881 .09064 .69959 .08945 .70172 .09119 .71336 .29786 Mtetra
.528 .287 .494 r
.71336 .29786 .70172 .09119 .70414 .09735 .71615 .30773 Mtetra
.513 .276 .493 r
.71615 .30773 .70414 .09735 .71906 .30473 .71842 .30906 Mtetra
.494 .141 .297 r
.71842 .30906 .71906 .30473 .72151 .30888 .72063 .30935 Mtetra
.115 0 0 r
.72063 .30935 .72151 .30888 .72381 .31047 .72282 .30918 Mtetra
.41 .652 .958 r
.72282 .30918 .72381 .31047 .72603 .31082 .72503 .30929 Mtetra
.609 .709 .916 r
.72503 .30929 .72603 .31082 .7282 .31027 .7272 .30874 Mtetra
.781 .779 .851 r
.7272 .30874 .7282 .31027 .73029 .30854 .7293 .30715 Mtetra
.976 .779 .576 r
.7293 .30715 .73029 .30854 .73203 .30145 .73105 .30026 Mtetra
.975 .668 .319 r
.73105 .30026 .73203 .30145 .71972 .08485 .71882 .08385 Mtetra
.983 .804 .584 r
.71882 .08385 .71972 .08485 .72138 .07909 .72048 .07794 Mtetra
.763 .82 .897 r
.72048 .07794 .72138 .07909 .72335 .07791 .72244 .07668 Mtetra
.604 .747 .945 r
.72244 .07668 .72335 .07791 .72538 .07747 .72446 .07618 Mtetra
.499 .681 .947 r
.72446 .07618 .72538 .07747 .72743 .07742 .72651 .07605 Mtetra
.729 .77 .886 r
.72651 .07605 .72743 .07742 .72942 .0765 .7285 .07495 Mtetra
.675 .718 .881 r
.7285 .07495 .72942 .0765 .73143 .07571 .7305 .07411 Mtetra
.556 .656 .902 r
.7305 .07411 .73143 .07571 .73345 .07521 .73254 .07384 Mtetra
.938 .575 .29 r
.09065 .3133 .09181 .31452 .09296 .31711 .09151 .31796 Mtetra
.935 .68 .527 r
.09151 .31796 .09296 .31711 .06807 .50964 .06485 .52273 Mtetra
.643 .364 .481 r
.06485 .52273 .06807 .50964 .06756 .52511 .06577 .52775 Mtetra
.477 .09 .225 r
.06577 .52775 .06756 .52511 .06893 .52686 .06736 .52793 Mtetra
0 0 0 r
.06736 .52793 .06893 .52686 .07046 .52744 .06907 .52725 Mtetra
.772 .938 .936 r
.06907 .52725 .07046 .52744 .07207 .52744 .07084 .52608 Mtetra
.622 .697 .899 r
.07084 .52608 .07207 .52744 .07369 .52743 .07252 .52561 Mtetra
.678 .655 .819 r
.07252 .52561 .07369 .52743 .07537 .52693 .07425 .52477 Mtetra
.745 .649 .754 r
.07425 .52477 .07537 .52693 .07715 .52575 .07608 .52313 Mtetra
.869 .67 .631 r
.07608 .52313 .07715 .52575 .07927 .52201 .07865 .516 Mtetra
.933 .681 .534 r
.07865 .516 .07927 .52201 .08252 .50967 .10754 .31125 Mtetra
.525 .292 .504 r
.10754 .31125 .08252 .50967 .11044 .3108 .10973 .30616 Mtetra
.637 .481 .654 r
.10973 .30616 .11044 .3108 .11235 .30782 .11142 .30487 Mtetra
.604 .517 .729 r
.11142 .30487 .11235 .30782 .11409 .30614 .11301 .30434 Mtetra
.558 .593 .845 r
.11301 .30434 .11409 .30614 .11576 .30503 .11455 .30416 Mtetra
.674 .793 .938 r
.11455 .30416 .11576 .30503 .11737 .30434 .11616 .30352 Mtetra
.679 .804 .942 r
.11616 .30352 .11737 .30434 .11895 .30387 .11777 .30286 Mtetra
.66 .762 .926 r
.11777 .30286 .11895 .30387 .12053 .30347 .11937 .30228 Mtetra
.685 .732 .886 r
.11937 .30228 .12053 .30347 .12218 .30248 .12099 .30157 Mtetra
.599 .764 .958 r
.12099 .30157 .12218 .30248 .12381 .30165 .12256 .30117 Mtetra
0 .533 .832 r
.12256 .30117 .12381 .30165 .12538 .30132 .12405 .30147 Mtetra
.887 .527 .359 r
.12405 .30147 .12538 .30132 .12664 .30346 .12499 .30608 Mtetra
.936 .678 .521 r
.12499 .30608 .12664 .30346 .12688 .31365 .1005 .51044 Mtetra
.522 .284 .496 r
.1005 .51044 .12688 .31365 .10331 .51229 .10152 .51535 Mtetra
.518 .148 .277 r
.10152 .51535 .10331 .51229 .10484 .51313 .1031 .51578 Mtetra
.317 0 .127 r
.1031 .51578 .10484 .51313 .10656 .51244 .10482 .5152 Mtetra
.216 0 .078 r
.10482 .5152 .10656 .51244 .10833 .51146 .10658 .5142 Mtetra
.328 0 .143 r
.10658 .5142 .10833 .51146 .10987 .51223 .1083 .51363 Mtetra
.166 0 0 r
.1083 .51363 .10987 .51223 .11141 .51311 .11001 .51311 Mtetra
.488 .894 .93 r
.11001 .51311 .11141 .51311 .11299 .51364 .11173 .51251 Mtetra
.616 .742 .936 r
.11173 .51251 .11299 .51364 .11462 .51373 .11344 .51205 Mtetra
.673 .672 .841 r
.11344 .51205 .11462 .51373 .11632 .51332 .11518 .51128 Mtetra
.738 .657 .769 r
.11518 .51128 .11632 .51332 .1181 .51229 .11701 .50979 Mtetra
.858 .672 .65 r
.11701 .50979 .1181 .51229 .12014 .5091 .11934 .50426 Mtetra
.938 .683 .525 r
.11934 .50426 .12014 .5091 .1228 .50077 .14597 .2985 Mtetra
.527 .294 .504 r
.14597 .2985 .1228 .50077 .14894 .29751 .14828 .29222 Mtetra
.648 .477 .638 r
.14828 .29222 .14894 .29751 .15094 .29377 .15003 .29055 Mtetra
.607 .506 .714 r
.15003 .29055 .15094 .29377 .15271 .29192 .15165 .28995 Mtetra
.56 .574 .824 r
.15165 .28995 .15271 .29192 .1544 .29073 .15322 .28976 Mtetra
.622 .762 .946 r
.15322 .28976 .1544 .29073 .15604 .28999 .15483 .2893 Mtetra
.649 .829 .969 r
.15483 .2893 .15604 .28999 .15765 .28951 .15645 .28871 Mtetra
.662 .809 .953 r
.15645 .28871 .15765 .28951 .15925 .28914 .15808 .2881 Mtetra
.693 .764 .907 r
.15808 .2881 .15925 .28914 .16087 .28859 .15972 .28736 Mtetra
.692 .731 .881 r
.15972 .28736 .16087 .28859 .1625 .28792 .16137 .2866 Mtetra
.678 .712 .874 r
.16137 .2866 .1625 .28792 .16415 .28721 .16301 .2859 Mtetra
.696 .719 .867 r
.16301 .2859 .16415 .28721 .16584 .28603 .16466 .2851 Mtetra
.652 .779 .941 r
.16466 .2851 .16584 .28603 .16752 .28501 .16629 .28453 Mtetra
.253 .71 .952 r
.16629 .28453 .16752 .28501 .16913 .28458 .16785 .28454 Mtetra
.849 .426 .224 r
.16785 .28454 .16913 .28458 .17043 .28693 .16909 .28739 Mtetra
.944 .682 .51 r
.16909 .28739 .17043 .28693 .14909 .4887 .14754 .4903 Mtetra
.874 .55 .434 r
.14754 .4903 .14909 .4887 .14952 .4997 .14832 .49822 Mtetra
0 .346 .824 r
.14832 .49822 .14952 .4997 .15108 .50073 .14989 .49913 Mtetra
.661 .681 .858 r
.14989 .49913 .15108 .50073 .15285 .49995 .15165 .49844 Mtetra
.745 .717 .825 r
.15165 .49844 .15285 .49995 .15469 .49853 .15347 .49718 Mtetra
.725 .735 .859 r
.15347 .49718 .15469 .49853 .15649 .49738 .15527 .49614 Mtetra
.695 .745 .89 r
.15527 .49614 .15649 .49738 .15827 .49651 .15704 .49532 Mtetra
.683 .751 .903 r
.15704 .49532 .15827 .49651 .16004 .49571 .15881 .49457 Mtetra
.635 .747 .929 r
.15881 .49457 .16004 .49571 .1618 .4951 .16055 .49402 Mtetra
.589 .747 .952 r
.16055 .49402 .1618 .4951 .16353 .49463 .16228 .49363 Mtetra
.563 .754 .968 r
.16228 .49363 .16353 .49463 .16526 .49423 .164 .4933 Mtetra
.314 .658 .972 r
.164 .4933 .16526 .49423 .16695 .49423 .16568 .49345 Mtetra
.366 .717 .987 r
.16568 .49345 .16695 .49423 .16866 .49413 .16737 .49344 Mtetra
.685 .849 .961 r
.16737 .49344 .16866 .49413 .17042 .49344 .16915 .49267 Mtetra
.915 .784 .702 r
.16915 .49267 .17042 .49344 .17243 .49051 .17128 .48855 Mtetra
.946 .688 .513 r
.17128 .48855 .17243 .49051 .17516 .48069 .1949 .28227 Mtetra
.533 .298 .505 r
.1949 .28227 .17516 .48069 .19813 .27875 .19737 .27392 Mtetra
.684 .51 .645 r
.19737 .27392 .19813 .27875 .20011 .27505 .19919 .27175 Mtetra
.609 .505 .711 r
.19919 .27175 .20011 .27505 .20188 .27327 .20085 .27112 Mtetra
.554 .552 .807 r
.20085 .27112 .20188 .27327 .20359 .2721 .20245 .27095 Mtetra
.581 .717 .936 r
.20245 .27095 .20359 .2721 .20526 .27134 .20408 .27063 Mtetra
.633 .825 .974 r
.20408 .27063 .20526 .27134 .20691 .27087 .20573 .27008 Mtetra
.645 .812 .964 r
.20573 .27008 .20691 .27087 .20853 .27052 .20738 .26951 Mtetra
.732 .782 .893 r
.20738 .26951 .20853 .27052 .2102 .26981 .20907 .26856 Mtetra
.724 .74 .865 r
.20907 .26856 .2102 .26981 .21188 .26897 .21077 .26761 Mtetra
.608 .684 .897 r
.21077 .26761 .21188 .26897 .21352 .26854 .2124 .26721 Mtetra
.669 .197 0 r
.2124 .26721 .21352 .26854 .215 .26973 .2138 .26924 Mtetra
.95 .684 .498 r
.2138 .26924 .215 .26973 .21605 .27534 .19517 .47132 Mtetra
.535 .295 .498 r
.19517 .47132 .21605 .27534 .19746 .47897 .19575 .48265 Mtetra
.623 .271 .354 r
.19575 .48265 .19746 .47897 .19881 .48264 .19731 .48426 Mtetra
.264 0 0 r
.19731 .48426 .19881 .48264 .20044 .48357 .19907 .48386 Mtetra
.584 .946 .864 r
.19907 .48386 .20044 .48357 .20214 .48376 .20089 .48284 Mtetra
.695 .809 .936 r
.20089 .48284 .20214 .48376 .20386 .48373 .20269 .48204 Mtetra
.649 .666 .853 r
.20269 .48204 .20386 .48373 .20561 .48344 .20448 .48139 Mtetra
.715 .653 .787 r
.20448 .48139 .20561 .48344 .20742 .48257 .20632 .48015 Mtetra
.832 .671 .682 r
.20632 .48015 .20742 .48257 .20938 .48015 .20841 .47638 Mtetra
.948 .686 .506 r
.20841 .47638 .20938 .48015 .21167 .47416 .22962 .27213 Mtetra
.537 .302 .506 r
.22962 .27213 .21167 .47416 .23283 .26849 .23224 .26164 Mtetra
.662 .468 .612 r
.23224 .26164 .23283 .26849 .23498 .26289 .2341 .25905 Mtetra
.612 .487 .685 r
.2341 .25905 .23498 .26289 .23679 .26085 .23579 .25827 Mtetra
.575 .528 .765 r
.23579 .25827 .23679 .26085 .23852 .25956 .23743 .25797 Mtetra
.604 .649 .867 r
.23743 .25797 .23852 .25956 .24023 .25866 .23909 .25758 Mtetra
.673 .76 .916 r
.23909 .25758 .24023 .25866 .24191 .25799 .24077 .25691 Mtetra
.661 .758 .922 r
.24077 .25691 .24191 .25799 .24358 .25743 .24245 .25629 Mtetra
.68 .751 .905 r
.24245 .25629 .24358 .25743 .24528 .25659 .24414 .25559 Mtetra
.669 .775 .929 r
.24414 .25559 .24528 .25659 .247 .25556 .24583 .25494 Mtetra
.4 .76 .994 r
.24583 .25494 .247 .25556 .24868 .25494 .24746 .25482 Mtetra
.787 .301 .06 r
.24746 .25482 .24868 .25494 .25024 .25577 .24891 .25687 Mtetra
.951 .682 .49 r
.24891 .25687 .25024 .25577 .25145 .26045 .23246 .45987 Mtetra
.532 .292 .497 r
.23246 .45987 .25145 .26045 .23504 .46517 .23333 .4697 Mtetra
.618 .28 .376 r
.23333 .4697 .23504 .46517 .23646 .46888 .23492 .47148 Mtetra
.371 0 .153 r
.23492 .47148 .23646 .46888 .23824 .46847 .2367 .47112 Mtetra
.247 0 .091 r
.2367 .47112 .23824 .46847 .24008 .46746 .23853 .47021 Mtetra
.268 0 .112 r
.23853 .47021 .24008 .46746 .24184 .46734 .24036 .46935 Mtetra
.276 0 .031 r
.24036 .46935 .24184 .46734 .24351 .4683 .24216 .46881 Mtetra
0 0 0 r
.24216 .46881 .24351 .4683 .24521 .46895 .24397 .46821 Mtetra
.619 .832 .982 r
.24397 .46821 .24521 .46895 .24695 .4692 .24577 .46764 Mtetra
.647 .688 .875 r
.24577 .46764 .24695 .4692 .24873 .46897 .24759 .46701 Mtetra
.713 .663 .799 r
.24759 .46701 .24873 .46897 .25055 .46818 .24945 .46583 Mtetra
.82 .672 .699 r
.24945 .46583 .25055 .46818 .2525 .46601 .25148 .46261 Mtetra
.953 .687 .496 r
.25148 .46261 .2525 .46601 .25473 .46024 .26964 .26424 Mtetra
.554 .316 .509 r
.26964 .26424 .25473 .46024 .27335 .25412 .27273 .24683 Mtetra
.673 .472 .605 r
.27273 .24683 .27335 .25412 .27547 .24839 .27463 .24375 Mtetra
.608 .462 .658 r
.27463 .24375 .27547 .24839 .27719 .24749 .27636 .24284 Mtetra
.563 .432 .66 r
.27636 .24284 .27719 .24749 .27887 .24721 .27804 .24247 Mtetra
.556 .425 .657 r
.27804 .24247 .27887 .24721 .2806 .24626 .27972 .24216 Mtetra
.589 .464 .678 r
.27972 .24216 .2806 .24626 .28242 .24419 .28142 .24157 Mtetra
.618 .551 .756 r
.28142 .24157 .28242 .24419 .28422 .24239 .28312 .24097 Mtetra
.656 .698 .877 r
.28312 .24097 .28422 .24239 .28597 .2411 .28483 .24034 Mtetra
.668 .832 .962 r
.28483 .24034 .28597 .2411 .28769 .24036 .28654 .23967 Mtetra
.669 .846 .968 r
.28654 .23967 .28769 .24036 .28939 .2398 .28826 .23898 Mtetra
.679 .821 .952 r
.28826 .23898 .28939 .2398 .29109 .23929 .28997 .23827 Mtetra
.684 .78 .923 r
.28997 .23827 .29109 .23929 .2928 .23875 .29169 .23755 Mtetra
.668 .74 .904 r
.29169 .23755 .2928 .23875 .2945 .2382 .29341 .23688 Mtetra
.666 .719 .888 r
.29341 .23688 .2945 .2382 .29623 .23743 .29512 .23621 Mtetra
.669 .737 .901 r
.29512 .23621 .29623 .23743 .29797 .23637 .29684 .23554 Mtetra
.492 .756 .989 r
.29684 .23554 .29797 .23637 .2997 .23566 .29852 .23534 Mtetra
.638 .076 0 r
.29852 .23534 .2997 .23566 .30134 .23603 .3001 .23668 Mtetra
.938 .632 .435 r
.3001 .23668 .30134 .23603 .30274 .2397 .30047 .25446 Mtetra
.939 .662 .488 r
.30047 .25446 .30274 .2397 .28968 .4444 .28797 .45047 Mtetra
.633 .312 .41 r
.28797 .45047 .28968 .4444 .29105 .45034 .28958 .45301 Mtetra
.4 .007 .174 r
.28958 .45301 .29105 .45034 .29286 .4501 .2914 .45277 Mtetra
.268 0 .105 r
.2914 .45277 .29286 .4501 .29472 .44912 .29326 .45191 Mtetra
.25 0 .108 r
.29326 .45191 .29472 .44912 .29656 .44862 .29513 .45094 Mtetra
.305 0 .087 r
.29513 .45094 .29656 .44862 .29829 .4496 .29697 .45037 Mtetra
0 0 0 r
.29697 .45037 .29829 .4496 .30004 .45031 .29881 .44976 Mtetra
.655 .884 .982 r
.29881 .44976 .30004 .45031 .30183 .45052 .30067 .449 Mtetra
.71 .719 .856 r
.30067 .449 .30183 .45052 .30367 .45006 .30255 .448 Mtetra
.693 .649 .801 r
.30255 .448 .30367 .45006 .30552 .44941 .30443 .44694 Mtetra
.649 .593 .778 r
.30443 .44694 .30552 .44941 .30737 .44881 .30629 .44612 Mtetra
.55 .523 .779 r
.30629 .44612 .30737 .44881 .3092 .44854 .30811 .44596 Mtetra
.619 .569 .776 r
.30811 .44596 .3092 .44854 .31106 .44791 .30997 .44535 Mtetra
.758 .639 .729 r
.30997 .44535 .31106 .44791 .31298 .4463 .31192 .44327 Mtetra
.905 .679 .585 r
.31192 .44327 .31298 .4463 .31509 .44164 .31441 .43277 Mtetra
.953 .681 .484 r
.31441 .43277 .31509 .44164 .32989 .23796 .32944 .22662 Mtetra
.65 .432 .574 r
.32944 .22662 .32989 .23796 .33229 .22687 .33139 .22259 Mtetra
.625 .484 .67 r
.33139 .22259 .33229 .22687 .33415 .2243 .33316 .22155 Mtetra
.595 .531 .753 r
.33316 .22155 .33415 .2243 .33595 .22271 .33488 .22109 Mtetra
.566 .633 .877 r
.33488 .22109 .33595 .22271 .33772 .22163 .3366 .22084 Mtetra
.647 .824 .968 r
.3366 .22084 .33772 .22163 .33947 .22087 .33834 .22022 Mtetra
.638 .854 .982 r
.33834 .22022 .33947 .22087 .3412 .2203 .34008 .2196 Mtetra
.654 .846 .974 r
.34008 .2196 .3412 .2203 .34294 .21982 .34183 .21894 Mtetra
.687 .814 .943 r
.34183 .21894 .34294 .21982 .34468 .21929 .34358 .21819 Mtetra
.68 .767 .917 r
.34358 .21819 .34468 .21929 .34642 .21875 .34533 .21747 Mtetra
.654 .725 .901 r
.34533 .21747 .34642 .21875 .34816 .21813 .34708 .21685 Mtetra
.586 .7 .921 r
.34708 .21685 .34816 .21813 .34992 .21734 .34881 .21649 Mtetra
.532 .772 .986 r
.34881 .21649 .34992 .21734 .35168 .21653 .35054 .2162 Mtetra
.466 .854 .979 r
.35054 .2162 .35168 .21653 .35344 .21568 .35228 .21579 Mtetra
.665 .972 .894 r
.35228 .21579 .35344 .21568 .35521 .21465 .35406 .21469 Mtetra
.504 .908 .901 r
.35406 .21469 .35521 .21465 .35697 .21396 .35582 .21397 Mtetra
.236 0 0 r
.35582 .21397 .35697 .21396 .35868 .21401 .35752 .2143 Mtetra
.915 .556 .338 r
.35752 .2143 .35868 .21401 .36024 .21703 .35885 .22155 Mtetra
.957 .677 .462 r
.35885 .22155 .36024 .21703 .3511 .41969 .3494 .42863 Mtetra
.638 .334 .44 r
.3494 .42863 .3511 .41969 .35242 .42964 .35105 .43228 Mtetra
.437 .041 .189 r
.35105 .43228 .35242 .42964 .35426 .42965 .3529 .43226 Mtetra
.3 0 .117 r
.3529 .43226 .35426 .42965 .35616 .42879 .35479 .43155 Mtetra
.243 0 .104 r
.35479 .43155 .35616 .42879 .35806 .42792 .3567 .43052 Mtetra
.324 0 .129 r
.3567 .43052 .35806 .42792 .35986 .42884 .35859 .42992 Mtetra
.045 0 0 r
.35859 .42992 .35986 .42884 .36168 .42956 .36048 .42925 Mtetra
.611 .918 .977 r
.36048 .42925 .36168 .42956 .36352 .42993 .36238 .42848 Mtetra
.715 .736 .867 r
.36238 .42848 .36352 .42993 .3654 .4296 .36429 .42745 Mtetra
.692 .644 .797 r
.36429 .42745 .3654 .4296 .36729 .42907 .3662 .42637 Mtetra
.667 .588 .758 r
.3662 .42637 .36729 .42907 .36919 .42839 .36812 .42532 Mtetra
.618 .538 .743 r
.36812 .42532 .36919 .42839 .37109 .42768 .37002 .42462 Mtetra
.606 .533 .745 r
.37002 .42462 .37109 .42768 .37299 .42693 .37191 .42402 Mtetra
.603 .54 .757 r
.37191 .42402 .37299 .42693 .37489 .42617 .37381 .42347 Mtetra
.537 .517 .782 r
.37381 .42347 .37489 .42617 .37678 .42588 .37568 .42338 Mtetra
.611 .574 .788 r
.37568 .42338 .37678 .42588 .37868 .4253 .37758 .42283 Mtetra
.715 .628 .759 r
.37758 .42283 .37868 .4253 .3806 .42411 .37952 .42137 Mtetra
.897 .686 .608 r
.37952 .42137 .3806 .42411 .38267 .41975 .38173 .41377 Mtetra
.962 .684 .463 r
.38173 .41377 .38267 .41975 .38553 .39711 .39276 .20405 Mtetra
.524 .291 .503 r
.39276 .20405 .38553 .39711 .39566 .2036 .39474 .19887 Mtetra
.631 .477 .656 r
.39474 .19887 .39566 .2036 .39747 .2022 .39654 .19761 Mtetra
.581 .447 .664 r
.39654 .19761 .39747 .2022 .39924 .20173 .39832 .19703 Mtetra
.548 .423 .661 r
.39832 .19703 .39924 .20173 .40101 .20146 .40009 .1968 Mtetra
.582 .446 .662 r
.40009 .1968 .40101 .20146 .40286 .19939 .40187 .19619 Mtetra
.605 .513 .724 r
.40187 .19619 .40286 .19939 .40469 .19746 .40365 .19558 Mtetra
.637 .634 .831 r
.40365 .19558 .40469 .19746 .40652 .19587 .40544 .19497 Mtetra
.651 .808 .959 r
.40544 .19497 .40652 .19587 .40831 .19502 .40723 .19434 Mtetra
.643 .854 .98 r
.40723 .19434 .40831 .19502 .4101 .19438 .40902 .19368 Mtetra
.651 .853 .977 r
.40902 .19368 .4101 .19438 .41188 .19384 .41081 .19301 Mtetra
.672 .828 .958 r
.41081 .19301 .41188 .19384 .41367 .19317 .4126 .19229 Mtetra
.678 .819 .951 r
.4126 .19229 .41367 .19317 .41547 .19249 .4144 .19155 Mtetra
.68 .807 .943 r
.4144 .19155 .41547 .19249 .41726 .19183 .41619 .19081 Mtetra
.685 .792 .931 r
.41619 .19081 .41726 .19183 .41905 .19126 .41799 .19005 Mtetra
.675 .752 .909 r
.41799 .19005 .41905 .19126 .42084 .19068 .41979 .18932 Mtetra
.657 .719 .894 r
.41979 .18932 .42084 .19068 .42264 .19007 .42159 .18867 Mtetra
.602 .691 .906 r
.42159 .18867 .42264 .19007 .42444 .18927 .42338 .18825 Mtetra
.561 .752 .967 r
.42338 .18825 .42444 .18927 .42625 .18842 .42517 .18792 Mtetra
.471 .828 .995 r
.42517 .18792 .42625 .18842 .42805 .18758 .42696 .18758 Mtetra
.662 .968 .912 r
.42696 .18758 .42805 .18758 .42987 .18653 .42877 .18651 Mtetra
.579 .939 .914 r
.42877 .18651 .42987 .18653 .43167 .18572 .43058 .18565 Mtetra
.185 .716 .828 r
.43058 .18565 .43167 .18572 .43347 .18542 .43237 .18545 Mtetra
.871 .443 .184 r
.43237 .18545 .43347 .18542 .43519 .18746 .43404 .18948 Mtetra
.966 .679 .435 r
.43404 .18948 .43519 .18746 .43672 .19634 .42964 .39893 Mtetra
.521 .283 .494 r
.42964 .39893 .43672 .19634 .43265 .40131 .43139 .4045 Mtetra
.509 .131 .258 r
.43139 .4045 .43265 .40131 .43454 .40223 .4333 .40494 Mtetra
.324 0 .14 r
.4333 .40494 .43454 .40223 .43649 .40144 .43525 .40428 Mtetra
.243 0 .115 r
.43525 .40428 .43649 .40144 .43844 .40032 .43721 .40317 Mtetra
.321 0 .152 r
.43721 .40317 .43844 .40032 .44035 .40107 .43915 .40243 Mtetra
.149 0 0 r
.43915 .40243 .44035 .40107 .44225 .40194 .4411 .40179 Mtetra
.488 .891 .94 r
.4411 .40179 .44225 .40194 .44417 .40244 .44305 .40114 Mtetra
.636 .74 .924 r
.44305 .40114 .44417 .40244 .44611 .40212 .445 .40053 Mtetra
.64 .695 .885 r
.445 .40053 .44611 .40212 .44807 .40146 .44695 .3999 Mtetra
.655 .705 .884 r
.44695 .3999 .44807 .40146 .45002 .40067 .4489 .39919 Mtetra
.703 .735 .875 r
.4489 .39919 .45002 .40067 .45197 .40001 .45087 .39822 Mtetra
.708 .694 .834 r
.45087 .39822 .45197 .40001 .45393 .39938 .45283 .39712 Mtetra
.689 .637 .792 r
.45283 .39712 .45393 .39938 .45589 .39874 .4548 .39601 Mtetra
.572 .539 .779 r
.4548 .39601 .45589 .39874 .45784 .39842 .45675 .39569 Mtetra
.585 .546 .777 r
.45675 .39569 .45784 .39842 .45979 .39793 .4587 .39528 Mtetra
.679 .602 .762 r
.4587 .39528 .45979 .39793 .46176 .39687 .46067 .39412 Mtetra
.879 .683 .634 r
.46067 .39412 .46176 .39687 .46378 .39326 .46273 .38845 Mtetra
.969 .684 .437 r
.46273 .38845 .46378 .39326 .46595 .38151 .46864 .17711 Mtetra
.526 .292 .503 r
.46864 .17711 .46595 .38151 .47155 .17572 .47058 .1708 Mtetra
.663 .496 .647 r
.47058 .1708 .47155 .17572 .47342 .17315 .47243 .16893 Mtetra
.598 .471 .678 r
.47243 .16893 .47342 .17315 .47525 .1724 .47427 .1682 Mtetra
.562 .447 .681 r
.47427 .1682 .47525 .1724 .47708 .17226 .4761 .16786 Mtetra
.579 .453 .672 r
.4761 .16786 .47708 .17226 .47891 .17181 .47793 .1673 Mtetra
.587 .456 .668 r
.47793 .1673 .47891 .17181 .48075 .17118 .47977 .16664 Mtetra
.586 .454 .667 r
.47977 .16664 .48075 .17118 .48259 .17057 .4816 .16599 Mtetra
.586 .452 .666 r
.4816 .16599 .48259 .17057 .48442 .17014 .48344 .16534 Mtetra
.583 .445 .659 r
.48344 .16534 .48442 .17014 .48626 .16965 .48528 .16469 Mtetra
.581 .44 .655 r
.48528 .16469 .48626 .16965 .48811 .16881 .48712 .16405 Mtetra
.582 .445 .66 r
.48712 .16405 .48811 .16881 .48997 .16698 .48897 .16341 Mtetra
.599 .495 .707 r
.48897 .16341 .48997 .16698 .49183 .16498 .49081 .16278 Mtetra
.631 .601 .802 r
.49081 .16278 .49183 .16498 .49368 .16327 .49266 .16214 Mtetra
.653 .767 .933 r
.49266 .16214 .49368 .16327 .49553 .16221 .4945 .16149 Mtetra
.638 .853 .981 r
.4945 .16149 .49553 .16221 .49738 .16151 .49635 .16083 Mtetra
.641 .861 .983 r
.49635 .16083 .49738 .16151 .49923 .16094 .4982 .16015 Mtetra
.661 .843 .97 r
.4982 .16015 .49923 .16094 .50108 .16031 .50005 .15943 Mtetra
.671 .828 .959 r
.50005 .15943 .50108 .16031 .50293 .15962 .5019 .15869 Mtetra
.674 .818 .952 r
.5019 .15869 .50293 .15962 .50478 .15892 .50376 .15795 Mtetra
.67 .805 .948 r
.50376 .15795 .50478 .15892 .50663 .15823 .50561 .15722 Mtetra
.666 .798 .945 r
.50561 .15722 .50663 .15823 .50849 .15753 .50747 .15651 Mtetra
.665 .795 .944 r
.50747 .15651 .50849 .15753 .51034 .15684 .50932 .15581 Mtetra
.665 .794 .944 r
.50932 .15581 .51034 .15684 .5122 .15614 .51118 .15511 Mtetra
.665 .793 .943 r
.51118 .15511 .5122 .15614 .51406 .15544 .51304 .1544 Mtetra
.664 .792 .943 r
.51304 .1544 .51406 .15544 .51592 .15474 .5149 .1537 Mtetra
.664 .791 .943 r
.5149 .1537 .51592 .15474 .51778 .15404 .51676 .153 Mtetra
.664 .791 .942 r
.51676 .153 .51778 .15404 .51964 .15334 .51863 .1523 Mtetra
.663 .791 .943 r
.51863 .1523 .51964 .15334 .52151 .15264 .52049 .1516 Mtetra
.52049 .1516 .52151 .15264 .52337 .15195 .52236 .1509 Mtetra
.52236 .1509 .52337 .15195 .52524 .15125 .52423 .15021 Mtetra
.662 .791 .944 r
.52423 .15021 .52524 .15125 .5271 .15055 .52609 .14951 Mtetra
.662 .792 .944 r
.52609 .14951 .5271 .15055 .52897 .14985 .52796 .14881 Mtetra
.52796 .14881 .52897 .14985 .53084 .14915 .52983 .14812 Mtetra
.661 .792 .945 r
.52983 .14812 .53084 .14915 .53271 .14846 .53171 .14742 Mtetra
.66 .792 .945 r
.53171 .14742 .53271 .14846 .53459 .14777 .53358 .14673 Mtetra
.53358 .14673 .53459 .14777 .53646 .14708 .53545 .14604 Mtetra
.659 .792 .946 r
.53545 .14604 .53646 .14708 .53834 .14639 .53733 .14535 Mtetra
.658 .791 .946 r
.53733 .14535 .53834 .14639 .54021 .14571 .53921 .14467 Mtetra
.657 .792 .947 r
.53921 .14467 .54021 .14571 .54209 .14503 .54109 .14399 Mtetra
.655 .792 .947 r
.54109 .14399 .54209 .14503 .54397 .14437 .54297 .14332 Mtetra
.654 .788 .946 r
.54297 .14332 .54397 .14437 .54585 .14377 .54485 .14265 Mtetra
.654 .773 .936 r
.54485 .14265 .54585 .14377 .54773 .14323 .54673 .14198 Mtetra
.654 .749 .919 r
.54673 .14198 .54773 .14323 .54962 .14269 .54862 .14131 Mtetra
.654 .725 .901 r
.54862 .14131 .54962 .14269 .5515 .1421 .5505 .14065 Mtetra
.654 .712 .891 r
.5505 .14065 .5515 .1421 .55339 .14145 .55239 .13997 Mtetra
.654 .709 .888 r
.55239 .13997 .55339 .14145 .55528 .14077 .55428 .1393 Mtetra
.655 .709 .887 r
.55428 .1393 .55528 .14077 .55717 .14009 .55617 .13861 Mtetra
.656 .709 .887 r
.55617 .13861 .55717 .14009 .55906 .13941 .55806 .13793 Mtetra
.656 .708 .886 r
.55806 .13793 .55906 .13941 .56095 .13873 .55995 .13723 Mtetra
.657 .708 .885 r
.55995 .13723 .56095 .13873 .56284 .13804 .56184 .13654 Mtetra
.658 .707 .884 r
.56184 .13654 .56284 .13804 .56473 .13734 .56374 .13584 Mtetra
.56374 .13584 .56473 .13734 .56663 .13664 .56563 .13514 Mtetra
.658 .707 .883 r
.56563 .13514 .56663 .13664 .56852 .13594 .56753 .13443 Mtetra
.659 .707 .883 r
.56753 .13443 .56852 .13594 .57042 .13523 .56943 .13372 Mtetra
.56943 .13372 .57042 .13523 .57232 .13453 .57133 .13301 Mtetra
.659 .707 .882 r
.57133 .13301 .57232 .13453 .57422 .13382 .57323 .1323 Mtetra
.57323 .1323 .57422 .13382 .57612 .13311 .57513 .13159 Mtetra
.57513 .13159 .57612 .13311 .57803 .13239 .57703 .13088 Mtetra
.659 .706 .882 r
.57703 .13088 .57803 .13239 .57993 .13168 .57894 .13016 Mtetra
.66 .706 .882 r
.57894 .13016 .57993 .13168 .58183 .13097 .58084 .12945 Mtetra
.58084 .12945 .58183 .13097 .58374 .13025 .58275 .12873 Mtetra
.58275 .12873 .58374 .13025 .58565 .12954 .58466 .12802 Mtetra
.58466 .12802 .58565 .12954 .58756 .12882 .58657 .1273 Mtetra
.58657 .1273 .58756 .12882 .58947 .1281 .58848 .12658 Mtetra
.58848 .12658 .58947 .1281 .59138 .12739 .59039 .12586 Mtetra
.59039 .12586 .59138 .12739 .59329 .12667 .59231 .12514 Mtetra
.59231 .12514 .59329 .12667 .59521 .12595 .59422 .12442 Mtetra
.59422 .12442 .59521 .12595 .59712 .12523 .59614 .1237 Mtetra
.66 .707 .882 r
.59614 .1237 .59712 .12523 .59904 .12451 .59806 .12298 Mtetra
.59806 .12298 .59904 .12451 .60096 .12379 .59998 .12226 Mtetra
.59998 .12226 .60096 .12379 .60288 .12306 .6019 .12154 Mtetra
.6019 .12154 .60288 .12306 .6048 .12234 .60382 .12081 Mtetra
.60382 .12081 .6048 .12234 .60672 .12162 .60574 .12009 Mtetra
.60574 .12009 .60672 .12162 .60865 .12089 .60767 .11936 Mtetra
.60767 .11936 .60865 .12089 .61057 .12017 .60959 .11864 Mtetra
.60959 .11864 .61057 .12017 .6125 .11944 .61152 .11791 Mtetra
.661 .707 .882 r
.61152 .11791 .6125 .11944 .61443 .11871 .61345 .11718 Mtetra
.61345 .11718 .61443 .11871 .61636 .11798 .61538 .11645 Mtetra
.661 .708 .882 r
.61538 .11645 .61636 .11798 .61829 .11725 .61731 .11572 Mtetra
.61731 .11572 .61829 .11725 .62022 .11652 .61924 .11499 Mtetra
.61924 .11499 .62022 .11652 .62215 .11579 .62118 .11426 Mtetra
.62118 .11426 .62215 .11579 .62408 .11506 .62311 .11352 Mtetra
.662 .708 .882 r
.62311 .11352 .62408 .11506 .62602 .11432 .62505 .11278 Mtetra
.62505 .11278 .62602 .11432 .62796 .11359 .62698 .11204 Mtetra
.662 .708 .881 r
.62698 .11204 .62796 .11359 .62989 .11285 .62892 .1113 Mtetra
.663 .707 .88 r
.62892 .1113 .62989 .11285 .63183 .11211 .63086 .11055 Mtetra
.664 .707 .879 r
.63086 .11055 .63183 .11211 .63377 .11136 .6328 .1098 Mtetra
.665 .706 .878 r
.6328 .1098 .63377 .11136 .63572 .11061 .63475 .10904 Mtetra
.669 .706 .875 r
.63475 .10904 .63572 .11061 .63766 .10986 .63669 .10825 Mtetra
.675 .704 .869 r
.63669 .10825 .63766 .10986 .6396 .1091 .63863 .10743 Mtetra
.665 .689 .863 r
.63863 .10743 .6396 .1091 .64155 .10832 .64058 .10665 Mtetra
.64 .678 .87 r
.64058 .10665 .64155 .10832 .64349 .10748 .64253 .106 Mtetra
.588 .685 .909 r
.64253 .106 .64349 .10748 .64543 .10656 .64449 .10561 Mtetra
.545 .773 .983 r
.64449 .10561 .64543 .10656 .64737 .10563 .64646 .10525 Mtetra
.464 .857 .975 r
.64646 .10525 .64737 .10563 .64932 .10473 .64842 .10477 Mtetra
.437 .876 .841 r
.64842 .10477 .64932 .10473 .65127 .10388 .65037 .10398 Mtetra
.452 .883 .821 r
.65037 .10398 .65127 .10388 .65322 .10306 .65232 .1031 Mtetra
.544 .928 .855 r
.65232 .1031 .65322 .10306 .65516 .10214 .65427 .10209 Mtetra
.674 .976 .883 r
.65427 .10209 .65516 .10214 .6571 .10094 .6562 .10084 Mtetra
.491 .902 .902 r
.6562 .10084 .6571 .10094 .65906 .10018 .65816 .10007 Mtetra
.221 0 0 r
.65816 .10007 .65906 .10018 .66107 .10061 .66018 .10058 Mtetra
.907 .498 .159 r
.66018 .10058 .66107 .10061 .66334 .10651 .66252 .10783 Mtetra
.973 .663 .335 r
.66252 .10783 .66334 .10651 .67561 .3205 .6746 .31919 Mtetra
.643 .19 0 r
.6746 .31919 .67561 .3205 .67795 .32443 .67692 .32268 Mtetra
.52 .627 .898 r
.67692 .32268 .67795 .32443 .68009 .32417 .67907 .32256 Mtetra
.672 .722 .887 r
.67907 .32256 .68009 .32417 .6822 .32315 .68118 .3217 Mtetra
.718 .767 .891 r
.68118 .3217 .6822 .32315 .6843 .32203 .68329 .3206 Mtetra
.605 .724 .928 r
.68329 .3206 .6843 .32203 .68647 .322 .68543 .32007 Mtetra
.687 .686 .844 r
.68543 .32007 .68647 .322 .6886 .32149 .68754 .31906 Mtetra
.785 .678 .746 r
.68754 .31906 .6886 .32149 .69068 .31978 .68959 .31678 Mtetra
.936 .698 .552 r
.68959 .31678 .69068 .31978 .69247 .31267 .69126 .30743 Mtetra
.975 .67 .347 r
.69126 .30743 .69247 .31267 .68297 .09725 .68198 .09498 Mtetra
.897 .715 .647 r
.68198 .09498 .68297 .09725 .68469 .09175 .68376 .09043 Mtetra
.749 .782 .88 r
.68376 .09043 .68469 .09175 .68664 .09049 .68571 .08922 Mtetra
.625 .744 .932 r
.68571 .08922 .68664 .09049 .68863 .08995 .6877 .08865 Mtetra
.578 .716 .937 r
.6877 .08865 .68863 .08995 .69064 .08965 .6897 .08826 Mtetra
.749 .771 .871 r
.6897 .08826 .69064 .08965 .6926 .08854 .69165 .08703 Mtetra
.672 .722 .887 r
.69165 .08703 .6926 .08854 .69458 .08774 .69364 .08623 Mtetra
.42 .592 .915 r
.69364 .08623 .69458 .08774 .6966 .08769 .69568 .08643 Mtetra
.829 .417 0 r
.69568 .08643 .6966 .08769 .69881 .09064 .69806 .09242 Mtetra
.972 .658 .317 r
.69806 .09242 .69881 .09064 .71336 .29786 .71294 .30603 Mtetra
.65 .322 .404 r
.71294 .30603 .71336 .29786 .71615 .30773 .71538 .31017 Mtetra
.411 0 .143 r
.71538 .31017 .71615 .30773 .71842 .30906 .71757 .31005 Mtetra
0 0 0 r
.71757 .31005 .71842 .30906 .72063 .30935 .71971 .30914 Mtetra
.692 .975 .913 r
.71971 .30914 .72063 .30935 .72282 .30918 .72183 .30782 Mtetra
.614 .743 .938 r
.72183 .30782 .72282 .30918 .72503 .30929 .724 .30724 Mtetra
.682 .672 .834 r
.724 .30724 .72503 .30929 .7272 .30874 .72614 .30622 Mtetra
.761 .663 .754 r
.72614 .30622 .7272 .30874 .7293 .30715 .72821 .30421 Mtetra
.933 .701 .564 r
.72821 .30421 .7293 .30715 .73105 .30026 .72987 .29591 Mtetra
.975 .667 .326 r
.72987 .29591 .73105 .30026 .71882 .08385 .71787 .08201 Mtetra
.937 .752 .628 r
.71787 .08201 .71882 .08385 .72048 .07794 .71958 .07692 Mtetra
.775 .852 .908 r
.71958 .07692 .72048 .07794 .72244 .07668 .72155 .07562 Mtetra
.632 .794 .96 r
.72155 .07562 .72244 .07668 .72446 .07618 .72356 .07498 Mtetra
.549 .728 .958 r
.72356 .07498 .72446 .07618 .72651 .07605 .7256 .07466 Mtetra
.757 .778 .87 r
.7256 .07466 .72651 .07605 .7285 .07495 .72757 .07337 Mtetra
.686 .721 .876 r
.72757 .07337 .7285 .07495 .7305 .07411 .72956 .07248 Mtetra
.528 .633 .899 r
.72956 .07248 .7305 .07411 .73254 .07384 .73162 .07233 Mtetra
.943 .581 .263 r
.08952 .31179 .09065 .3133 .09151 .31796 .09038 .31643 Mtetra
.938 .683 .526 r
.09038 .31643 .09151 .31796 .06485 .52273 .06352 .52206 Mtetra
.919 .56 .335 r
.06352 .52206 .06485 .52273 .06577 .52775 .06444 .52712 Mtetra
.155 .628 .927 r
.06444 .52712 .06577 .52775 .06736 .52793 .06602 .52731 Mtetra
.697 .858 .959 r
.06602 .52731 .06736 .52793 .06907 .52725 .06774 .52652 Mtetra
.817 .831 .86 r
.06774 .52652 .06907 .52725 .07084 .52608 .06957 .52498 Mtetra
.823 .77 .802 r
.06957 .52498 .07084 .52608 .07252 .52561 .07144 .52306 Mtetra
.795 .646 .696 r
.07144 .52306 .07252 .52561 .07425 .52477 .07346 .52007 Mtetra
.804 .599 .624 r
.07346 .52007 .07425 .52477 .07608 .52313 .07591 .51384 Mtetra
.929 .676 .535 r
.07591 .51384 .07608 .52313 .07865 .516 .10452 .31254 Mtetra
.525 .292 .504 r
.10452 .31254 .07865 .516 .10754 .31125 .10675 .3072 Mtetra
.728 .555 .656 r
.10675 .3072 .10754 .31125 .10973 .30616 .10863 .30453 Mtetra
.697 .67 .82 r
.10863 .30453 .10973 .30616 .11142 .30487 .11026 .30363 Mtetra
.609 .702 .91 r
.11026 .30363 .11142 .30487 .11301 .30434 .11183 .30324 Mtetra
.533 .701 .947 r
.11183 .30324 .11301 .30434 .11455 .30416 .11338 .30305 Mtetra
.718 .754 .88 r
.11338 .30305 .11455 .30416 .11616 .30352 .11501 .30218 Mtetra
.701 .712 .857 r
.11501 .30218 .11616 .30352 .11777 .30286 .11665 .30135 Mtetra
.641 .668 .86 r
.11665 .30135 .11777 .30286 .11937 .30228 .11824 .30082 Mtetra
.286 .508 .895 r
.11824 .30082 .11937 .30228 .12099 .30157 .11971 .30125 Mtetra
.725 .199 0 r
.11971 .30125 .12099 .30157 .12256 .30117 .12105 .30271 Mtetra
.818 .469 .395 r
.12105 .30271 .12256 .30117 .12405 .30147 .12205 .30683 Mtetra
.933 .674 .522 r
.12205 .30683 .12405 .30147 .12499 .30608 .09783 .50762 Mtetra
.522 .284 .496 r
.09783 .50762 .12499 .30608 .1005 .51044 .09878 .51298 Mtetra
.678 .31 .341 r
.09878 .51298 .1005 .51044 .10152 .51535 .10017 .51494 Mtetra
.169 .672 .909 r
.10017 .51494 .10152 .51535 .1031 .51578 .1018 .51499 Mtetra
.636 .816 .969 r
.1018 .51499 .1031 .51578 .10482 .5152 .10351 .51442 Mtetra
.71 .831 .939 r
.10351 .51442 .10482 .5152 .10658 .5142 .10526 .51358 Mtetra
.563 .829 .996 r
.10526 .51358 .10658 .5142 .1083 .51363 .10696 .51315 Mtetra
.566 .86 .997 r
.10696 .51315 .1083 .51363 .11001 .51311 .10867 .51266 Mtetra
.685 .893 .973 r
.10867 .51266 .11001 .51311 .11173 .51251 .11041 .51186 Mtetra
.837 .846 .852 r
.11041 .51186 .11173 .51251 .11344 .51205 .11227 .51015 Mtetra
.82 .693 .724 r
.11227 .51015 .11344 .51205 .11518 .51128 .11427 .50738 Mtetra
.809 .614 .639 r
.11427 .50738 .11518 .51128 .11701 .50979 .11655 .50218 Mtetra
.935 .679 .527 r
.11655 .50218 .11701 .50979 .11934 .50426 .14292 .30012 Mtetra
.528 .295 .504 r
.14292 .30012 .11934 .50426 .14597 .2985 .14529 .29336 Mtetra
.711 .524 .634 r
.14529 .29336 .14597 .2985 .14828 .29222 .1472 .29038 Mtetra
.715 .656 .79 r
.1472 .29038 .14828 .29222 .15003 .29055 .14889 .28926 Mtetra
.618 .699 .902 r
.14889 .28926 .15003 .29055 .15165 .28995 .15049 .28883 Mtetra
.521 .695 .948 r
.15049 .28883 .15165 .28995 .15322 .28976 .15206 .28868 Mtetra
.62 .738 .931 r
.15206 .28868 .15322 .28976 .15483 .2893 .15366 .28823 Mtetra
.663 .753 .917 r
.15366 .28823 .15483 .2893 .15645 .28871 .15529 .28762 Mtetra
.68 .753 .906 r
.15529 .28762 .15645 .28871 .15808 .2881 .15692 .28694 Mtetra
.732 .751 .868 r
.15692 .28694 .15808 .2881 .15972 .28736 .1586 .28596 Mtetra
.715 .709 .844 r
.1586 .28596 .15972 .28736 .16137 .2866 .16026 .28501 Mtetra
.662 .667 .844 r
.16026 .28501 .16137 .2866 .16301 .2859 .1619 .28435 Mtetra
.427 .569 .893 r
.1619 .28435 .16301 .2859 .16466 .2851 .16344 .28453 Mtetra
.556 0 0 r
.16344 .28453 .16466 .2851 .16629 .28453 .16487 .28563 Mtetra
.789 .399 .317 r
.16487 .28563 .16629 .28453 .16785 .28454 .16612 .28842 Mtetra
.939 .677 .512 r
.16612 .28842 .16785 .28454 .16909 .28739 .1451 .48506 Mtetra
.532 .293 .498 r
.1451 .48506 .16909 .28739 .14754 .4903 .14563 .49508 Mtetra
.656 .329 .406 r
.14563 .49508 .14754 .4903 .14832 .49822 .14702 .49759 Mtetra
.159 .631 .929 r
.14702 .49759 .14832 .49822 .14989 .49913 .14867 .49778 Mtetra
.682 .724 .882 r
.14867 .49778 .14989 .49913 .15165 .49844 .15044 .49702 Mtetra
.737 .727 .842 r
.15044 .49702 .15165 .49844 .15347 .49718 .15225 .49587 Mtetra
.715 .739 .871 r
.15225 .49587 .15347 .49718 .15527 .49614 .15403 .49491 Mtetra
.684 .746 .898 r
.15403 .49491 .15527 .49614 .15704 .49532 .1558 .49415 Mtetra
.666 .752 .915 r
.1558 .49415 .15704 .49532 .15881 .49457 .15756 .49348 Mtetra
.619 .754 .943 r
.15756 .49348 .15881 .49457 .16055 .49402 .1593 .493 Mtetra
.571 .75 .962 r
.1593 .493 .16055 .49402 .16228 .49363 .16102 .49265 Mtetra
.539 .749 .973 r
.16102 .49265 .16228 .49363 .164 .4933 .16274 .49238 Mtetra
.22 .607 .951 r
.16274 .49238 .164 .4933 .16568 .49345 .1644 .49266 Mtetra
.278 .67 .971 r
.1644 .49266 .16568 .49345 .16737 .49344 .16608 .49278 Mtetra
.65 .851 .977 r
.16608 .49278 .16737 .49344 .16915 .49267 .16785 .49212 Mtetra
.925 .805 .709 r
.16785 .49212 .16915 .49267 .17128 .48855 .16997 .48811 Mtetra
.948 .69 .512 r
.16997 .48811 .17128 .48855 .1949 .28227 .19374 .28125 Mtetra
.932 .729 .606 r
.19374 .28125 .1949 .28227 .19737 .27392 .19626 .27248 Mtetra
.821 .728 .762 r
.19626 .27248 .19737 .27392 .19919 .27175 .19807 .27034 Mtetra
.636 .687 .881 r
.19807 .27034 .19919 .27175 .20085 .27112 .19972 .26982 Mtetra
.48 .644 .929 r
.19972 .26982 .20085 .27112 .20245 .27095 .20131 .26981 Mtetra
.553 .705 .941 r
.20131 .26981 .20245 .27095 .20408 .27063 .20293 .26956 Mtetra
.647 .753 .927 r
.20293 .26956 .20408 .27063 .20573 .27008 .20458 .26901 Mtetra
.664 .757 .919 r
.20458 .26901 .20573 .27008 .20738 .26951 .20624 .26838 Mtetra
.747 .764 .867 r
.20624 .26838 .20738 .26951 .20907 .26856 .20794 .26731 Mtetra
.744 .742 .851 r
.20794 .26731 .20907 .26856 .21077 .26761 .20965 .26621 Mtetra
.635 .689 .883 r
.20965 .26621 .21077 .26761 .2124 .26721 .2113 .26569 Mtetra
.594 .148 0 r
.2113 .26569 .2124 .26721 .2138 .26924 .2127 .26768 Mtetra
.951 .685 .497 r
.2127 .26768 .2138 .26924 .19517 .47132 .19392 .4705 Mtetra
.946 .631 .406 r
.19392 .4705 .19517 .47132 .19575 .48265 .19448 .48198 Mtetra
.679 .136 0 r
.19448 .48198 .19575 .48265 .19731 .48426 .19603 .48362 Mtetra
.566 .832 .995 r
.19603 .48362 .19731 .48426 .19907 .48386 .1978 .48317 Mtetra
.782 .86 .908 r
.1978 .48317 .19907 .48386 .20089 .48284 .19964 .48192 Mtetra
.828 .814 .836 r
.19964 .48192 .20089 .48284 .20269 .48204 .20154 .48015 Mtetra
.809 .697 .741 r
.20154 .48015 .20269 .48204 .20448 .48139 .2035 .47773 Mtetra
.794 .611 .653 r
.2035 .47773 .20448 .48139 .20632 .48015 .20562 .47359 Mtetra
.945 .682 .508 r
.20562 .47359 .20632 .48015 .20841 .47638 .22651 .27467 Mtetra
.54 .304 .506 r
.22651 .27467 .20841 .47638 .22962 .27213 .22926 .26284 Mtetra
.661 .451 .588 r
.22926 .26284 .22962 .27213 .23224 .26164 .23122 .25926 Mtetra
.734 .624 .736 r
.23122 .25926 .23224 .26164 .2341 .25905 .23299 .25763 Mtetra
.645 .691 .879 r
.23299 .25763 .2341 .25905 .23579 .25827 .23466 .25706 Mtetra
.549 .694 .936 r
.23466 .25706 .23579 .25827 .23743 .25797 .2363 .25684 Mtetra
.62 .734 .929 r
.2363 .25684 .23743 .25797 .23909 .25758 .23796 .25638 Mtetra
.693 .743 .89 r
.23796 .25638 .23909 .25758 .24077 .25691 .23966 .2556 Mtetra
.649 .711 .893 r
.23966 .2556 .24077 .25691 .24245 .25629 .24133 .25502 Mtetra
.465 .644 .935 r
.24133 .25502 .24245 .25629 .24414 .25559 .24296 .25503 Mtetra
.449 0 0 r
.24296 .25503 .24414 .25559 .24583 .25494 .2445 .256 Mtetra
.78 .373 .28 r
.2445 .256 .24583 .25494 .24746 .25482 .24589 .25863 Mtetra
.948 .678 .493 r
.24589 .25863 .24746 .25482 .24891 .25687 .22966 .45696 Mtetra
.532 .292 .497 r
.22966 .45696 .24891 .25687 .23246 .45987 .23048 .46723 Mtetra
.627 .319 .43 r
.23048 .46723 .23246 .45987 .23333 .4697 .23199 .46997 Mtetra
.503 0 0 r
.23199 .46997 .23333 .4697 .23492 .47148 .23367 .4707 Mtetra
.574 .81 .988 r
.23367 .4707 .23492 .47148 .2367 .47112 .23546 .47027 Mtetra
.691 .826 .947 r
.23546 .47027 .2367 .47112 .23853 .47021 .23728 .46946 Mtetra
.659 .84 .97 r
.23728 .46946 .23853 .47021 .24036 .46935 .2391 .46877 Mtetra
.546 .841 .999 r
.2391 .46877 .24036 .46935 .24216 .46881 .24089 .46833 Mtetra
.632 .886 .987 r
.24089 .46833 .24216 .46881 .24397 .46821 .24271 .46764 Mtetra
.791 .888 .915 r
.24271 .46764 .24397 .46821 .24577 .46764 .24458 .46633 Mtetra
.842 .762 .774 r
.24458 .46633 .24577 .46764 .24759 .46701 .24654 .46398 Mtetra
.813 .64 .667 r
.24654 .46398 .24759 .46701 .24945 .46583 .24863 .46004 Mtetra
.887 .641 .562 r
.24863 .46004 .24945 .46583 .25148 .46261 .25188 .44225 Mtetra
.933 .665 .507 r
.25188 .44225 .25148 .46261 .26964 .26424 .26976 .24816 Mtetra
.615 .394 .557 r
.26976 .24816 .26964 .26424 .27273 .24683 .27173 .24421 Mtetra
.747 .618 .715 r
.27173 .24421 .27273 .24683 .27463 .24375 .27354 .24224 Mtetra
.688 .696 .852 r
.27354 .24224 .27463 .24375 .27636 .24284 .27526 .24143 Mtetra
.616 .684 .891 r
.27526 .24143 .27636 .24284 .27804 .24247 .27695 .24098 Mtetra
.59 .662 .888 r
.27695 .24098 .27804 .24247 .27972 .24216 .27863 .24064 Mtetra
.616 .668 .877 r
.27863 .24064 .27972 .24216 .28142 .24157 .28032 .24019 Mtetra
.621 .693 .895 r
.28032 .24019 .28142 .24157 .28312 .24097 .28202 .23972 Mtetra
.653 .727 .903 r
.28202 .23972 .28312 .24097 .28483 .24034 .28372 .23912 Mtetra
.696 .744 .888 r
.28372 .23912 .28483 .24034 .28654 .23967 .28544 .23831 Mtetra
.698 .722 .869 r
.28544 .23831 .28654 .23967 .28826 .23898 .28717 .23747 Mtetra
.696 .699 .849 r
.28717 .23747 .28826 .23898 .28997 .23827 .2889 .2366 Mtetra
.687 .675 .832 r
.2889 .2366 .28997 .23827 .29169 .23755 .29063 .23575 Mtetra
.645 .641 .832 r
.29063 .23575 .29169 .23755 .29341 .23688 .29234 .23512 Mtetra
.536 .597 .862 r
.29234 .23512 .29341 .23688 .29512 .23621 .29402 .235 Mtetra
0 .37 .834 r
.29402 .235 .29512 .23621 .29684 .23554 .29562 .23584 Mtetra
.783 .319 .14 r
.29562 .23584 .29684 .23554 .29852 .23534 .29713 .23806 Mtetra
.888 .571 .444 r
.29713 .23806 .29852 .23534 .3001 .23668 .2979 .25023 Mtetra
.94 .664 .487 r
.2979 .25023 .3001 .23668 .30047 .25446 .28509 .4479 Mtetra
.517 .28 .494 r
.28509 .4479 .30047 .25446 .28797 .45047 .28664 .4512 Mtetra
.607 .102 .026 r
.28664 .4512 .28797 .45047 .28958 .45301 .28836 .45227 Mtetra
.53 .807 .997 r
.28836 .45227 .28958 .45301 .2914 .45277 .29018 .45191 Mtetra
.68 .828 .954 r
.29018 .45191 .2914 .45277 .29326 .45191 .29204 .45114 Mtetra
.687 .845 .959 r
.29204 .45114 .29326 .45191 .29513 .45094 .2939 .45033 Mtetra
.544 .838 .999 r
.2939 .45033 .29513 .45094 .29697 .45037 .29573 .44988 Mtetra
.615 .885 .99 r
.29573 .44988 .29697 .45037 .29881 .44976 .29758 .44921 Mtetra
.78 .902 .927 r
.29758 .44921 .29881 .44976 .30067 .449 .29948 .44795 Mtetra
.876 .798 .77 r
.29948 .44795 .30067 .449 .30255 .448 .30146 .4453 Mtetra
.829 .661 .674 r
.30146 .4453 .30255 .448 .30443 .44694 .30354 .44138 Mtetra
.764 .559 .62 r
.30354 .44138 .30443 .44694 .30629 .44612 .30568 .43645 Mtetra
.53 .352 .584 r
.30568 .43645 .30629 .44612 .30811 .44596 .3075 .43627 Mtetra
.528 .35 .583 r
.3075 .43627 .30811 .44596 .30997 .44535 .30931 .43612 Mtetra
.681 .468 .591 r
.30931 .43612 .30997 .44535 .31192 .44327 .31141 .43183 Mtetra
.95 .677 .487 r
.31141 .43183 .31192 .44327 .31441 .43277 .32643 .22865 Mtetra
.523 .29 .503 r
.32643 .22865 .31441 .43277 .32944 .22662 .32846 .22356 Mtetra
.759 .605 .687 r
.32846 .22356 .32944 .22662 .33139 .22259 .33032 .22104 Mtetra
.677 .689 .854 r
.33032 .22104 .33139 .22259 .33316 .22155 .33207 .22027 Mtetra
.589 .703 .922 r
.33207 .22027 .33316 .22155 .33488 .22109 .33379 .21991 Mtetra
.548 .705 .943 r
.33379 .21991 .33488 .22109 .3366 .22084 .33551 .21967 Mtetra
.652 .745 .918 r
.33551 .21967 .3366 .22084 .33834 .22022 .33725 .21906 Mtetra
.665 .751 .914 r
.33725 .21906 .33834 .22022 .34008 .2196 .33899 .2184 Mtetra
.688 .75 .899 r
.33899 .2184 .34008 .2196 .34183 .21894 .34075 .21763 Mtetra
.728 .742 .863 r
.34075 .21763 .34183 .21894 .34358 .21819 .34251 .2166 Mtetra
.687 .688 .846 r
.34251 .2166 .34358 .21819 .34533 .21747 .34427 .21576 Mtetra
.593 .633 .86 r
.34427 .21576 .34533 .21747 .34708 .21685 .34601 .21539 Mtetra
0 .326 .812 r
.34601 .21539 .34708 .21685 .34881 .21649 .34766 .21642 Mtetra
.779 .284 .029 r
.34766 .21642 .34881 .21649 .35054 .2162 .34925 .21858 Mtetra
.775 .406 .358 r
.34925 .21858 .35054 .2162 .35228 .21579 .35075 .22239 Mtetra
.415 .119 .352 r
.35075 .22239 .35228 .21579 .35406 .21469 .35252 .22142 Mtetra
.401 .109 .349 r
.35252 .22142 .35406 .21469 .35582 .21397 .35431 .22027 Mtetra
.591 .275 .403 r
.35431 .22027 .35582 .21397 .35752 .2143 .35594 .22196 Mtetra
.953 .672 .466 r
.35594 .22196 .35752 .2143 .35885 .22155 .34651 .42505 Mtetra
.52 .282 .494 r
.34651 .42505 .35885 .22155 .3494 .42863 .3481 .42975 Mtetra
.7 .247 .173 r
.3481 .42975 .3494 .42863 .35105 .43228 .34985 .43159 Mtetra
.37 .745 .989 r
.34985 .43159 .35105 .43228 .3529 .43226 .35171 .43151 Mtetra
.596 .832 .989 r
.35171 .43151 .3529 .43226 .35479 .43155 .35359 .43097 Mtetra
.658 .885 .981 r
.35359 .43097 .35479 .43155 .3567 .43052 .35549 .43019 Mtetra
.522 .882 .981 r
.35549 .43019 .3567 .43052 .35859 .42992 .35738 .42962 Mtetra
.616 .922 .974 r
.35738 .42962 .35859 .42992 .36048 .42925 .35927 .42883 Mtetra
.757 .931 .944 r
.35927 .42883 .36048 .42925 .36238 .42848 .3612 .42763 Mtetra
.887 .836 .79 r
.3612 .42763 .36238 .42848 .36429 .42745 .36318 .42511 Mtetra
.841 .685 .689 r
.36318 .42511 .36429 .42745 .3662 .42637 .36523 .42147 Mtetra
.797 .589 .62 r
.36523 .42147 .3662 .42637 .36812 .42532 .36736 .41598 Mtetra
.62 .421 .591 r
.36736 .41598 .36812 .42532 .37002 .42462 .36933 .41362 Mtetra
.531 .345 .574 r
.36933 .41362 .37002 .42462 .37191 .42402 .3712 .41337 Mtetra
.488 .316 .573 r
.3712 .41337 .37191 .42402 .37381 .42347 .37304 .41407 Mtetra
.479 .317 .582 r
.37304 .41407 .37381 .42347 .37568 .42338 .37486 .41487 Mtetra
.542 .369 .597 r
.37486 .41487 .37568 .42338 .37758 .42283 .37675 .4145 Mtetra
.64 .443 .6 r
.37675 .4145 .37758 .42283 .37952 .42137 .37874 .41191 Mtetra
.958 .68 .467 r
.37874 .41191 .37952 .42137 .38173 .41377 .38977 .20661 Mtetra
.526 .292 .503 r
.38977 .20661 .38173 .41377 .39276 .20405 .3918 .20033 Mtetra
.762 .586 .659 r
.3918 .20033 .39276 .20405 .39474 .19887 .39369 .19722 Mtetra
.717 .695 .828 r
.39369 .19722 .39474 .19887 .39654 .19761 .39549 .19615 Mtetra
.648 .697 .881 r
.39549 .19615 .39654 .19761 .39832 .19703 .39727 .19553 Mtetra
.588 .667 .894 r
.39727 .19553 .39832 .19703 .40009 .1968 .39904 .19518 Mtetra
.619 .661 .869 r
.39904 .19518 .40009 .1968 .40187 .19619 .40082 .19469 Mtetra
.615 .678 .887 r
.40082 .19469 .40187 .19619 .40365 .19558 .40259 .19422 Mtetra
.618 .704 .906 r
.40259 .19422 .40365 .19558 .40544 .19497 .40437 .19374 Mtetra
.647 .739 .916 r
.40437 .19374 .40544 .19497 .40723 .19434 .40616 .19314 Mtetra
.664 .751 .915 r
.40616 .19314 .40723 .19434 .40902 .19368 .40795 .19247 Mtetra
.678 .752 .907 r
.40795 .19247 .40902 .19368 .41081 .19301 .40975 .19173 Mtetra
.699 .747 .888 r
.40975 .19173 .41081 .19301 .4126 .19229 .41155 .19087 Mtetra
.698 .724 .87 r
.41155 .19087 .4126 .19229 .4144 .19155 .41335 .18999 Mtetra
.689 .699 .854 r
.41335 .18999 .4144 .19155 .41619 .19081 .41515 .18913 Mtetra
.696 .685 .836 r
.41515 .18913 .41619 .19081 .41799 .19005 .41695 .1882 Mtetra
.663 .65 .828 r
.41695 .1882 .41799 .19005 .41979 .18932 .41876 .18744 Mtetra
.608 .621 .838 r
.41876 .18744 .41979 .18932 .42159 .18867 .42055 .18698 Mtetra
.232 .443 .86 r
.42055 .18698 .42159 .18867 .42338 .18825 .4223 .18771 Mtetra
.649 .102 0 r
.4223 .18771 .42338 .18825 .42517 .18792 .42402 .18944 Mtetra
.788 .383 .285 r
.42402 .18944 .42517 .18792 .42696 .18758 .42569 .19278 Mtetra
.469 .148 .339 r
.42569 .19278 .42696 .18758 .42877 .18651 .42748 .19263 Mtetra
.382 .085 .332 r
.42748 .19263 .42877 .18651 .43058 .18565 .42931 .19136 Mtetra
.47 .157 .352 r
.42931 .19136 .43058 .18565 .43237 .18545 .4311 .19118 Mtetra
.962 .673 .44 r
.4311 .19118 .43237 .18545 .43404 .18948 .4267 .39427 Mtetra
.524 .285 .495 r
.4267 .39427 .43404 .18948 .42964 .39893 .4284 .40146 Mtetra
.697 .304 .299 r
.4284 .40146 .42964 .39893 .43139 .4045 .43024 .40393 Mtetra
.228 .69 .947 r
.43024 .40393 .43139 .4045 .4333 .40494 .43217 .404 Mtetra
.638 .812 .967 r
.43217 .404 .4333 .40494 .43525 .40428 .43411 .40335 Mtetra
.71 .835 .942 r
.43411 .40335 .43525 .40428 .43721 .40317 .43606 .40241 Mtetra
.644 .851 .979 r
.43606 .40241 .43721 .40317 .43915 .40243 .43801 .4017 Mtetra
.626 .85 .985 r
.43801 .4017 .43915 .40243 .4411 .40179 .43996 .40103 Mtetra
.629 .848 .984 r
.43996 .40103 .4411 .40179 .44305 .40114 .44191 .40037 Mtetra
.554 .819 .995 r
.44191 .40037 .44305 .40114 .445 .40053 .44386 .39992 Mtetra
.568 .856 .997 r
.44386 .39992 .445 .40053 .44695 .3999 .44581 .39936 Mtetra
.671 .905 .977 r
.44581 .39936 .44695 .3999 .4489 .39919 .44777 .39849 Mtetra
.879 .88 .83 r
.44777 .39849 .4489 .39919 .45087 .39822 .44976 .3963 Mtetra
.865 .725 .707 r
.44976 .3963 .45087 .39822 .45283 .39712 .45178 .39282 Mtetra
.821 .613 .622 r
.45178 .39282 .45283 .39712 .4548 .39601 .45384 .38724 Mtetra
.624 .428 .596 r
.45384 .38724 .4548 .39601 .45675 .39569 .45583 .3849 Mtetra
.515 .336 .576 r
.45583 .3849 .45675 .39569 .4587 .39528 .45777 .38503 Mtetra
.569 .378 .583 r
.45777 .38503 .4587 .39528 .46067 .39412 .45974 .38386 Mtetra
.963 .678 .444 r
.45974 .38386 .46067 .39412 .46273 .38845 .46571 .17972 Mtetra
.528 .293 .503 r
.46571 .17972 .46273 .38845 .46864 .17711 .46767 .17235 Mtetra
.741 .549 .634 r
.46767 .17235 .46864 .17711 .47058 .1708 .46956 .16892 Mtetra
.747 .685 .791 r
.46956 .16892 .47058 .1708 .47243 .16893 .4714 .16748 Mtetra
.665 .71 .881 r
.4714 .16748 .47243 .16893 .47427 .1682 .47324 .16676 Mtetra
.608 .691 .901 r
.47324 .16676 .47427 .1682 .4761 .16786 .47507 .16631 Mtetra
.639 .686 .877 r
.47507 .16631 .4761 .16786 .47793 .1673 .4769 .16571 Mtetra
.652 .684 .867 r
.4769 .16571 .47793 .1673 .47977 .16664 .47874 .16504 Mtetra
.651 .683 .867 r
.47874 .16504 .47977 .16664 .4816 .16599 .48058 .16438 Mtetra
.653 .682 .865 r
.48058 .16438 .4816 .16599 .48344 .16534 .48242 .1637 Mtetra
.651 .678 .862 r
.48242 .1637 .48344 .16534 .48528 .16469 .48426 .16303 Mtetra
.645 .673 .862 r
.48426 .16303 .48528 .16469 .48712 .16405 .4861 .16239 Mtetra
.626 .665 .868 r
.4861 .16239 .48712 .16405 .48897 .16341 .48794 .16185 Mtetra
.616 .675 .883 r
.48794 .16185 .48897 .16341 .49081 .16278 .48978 .16136 Mtetra
.617 .7 .904 r
.48978 .16136 .49081 .16278 .49266 .16214 .49163 .16087 Mtetra
.638 .734 .918 r
.49163 .16087 .49266 .16214 .4945 .16149 .49347 .16029 Mtetra
.657 .754 .922 r
.49347 .16029 .4945 .16149 .49635 .16083 .49532 .15962 Mtetra
.672 .759 .916 r
.49532 .15962 .49635 .16083 .4982 .16015 .49717 .15889 Mtetra
.691 .756 .901 r
.49717 .15889 .4982 .16015 .50005 .15943 .49903 .15806 Mtetra
.697 .738 .883 r
.49903 .15806 .50005 .15943 .5019 .15869 .50088 .15718 Mtetra
.691 .714 .866 r
.50088 .15718 .5019 .15869 .50376 .15795 .50274 .15631 Mtetra
.672 .688 .856 r
.50274 .15631 .50376 .15795 .50561 .15722 .50459 .15552 Mtetra
.659 .673 .853 r
.50459 .15552 .50561 .15722 .50747 .15651 .50645 .15479 Mtetra
.654 .669 .852 r
.50645 .15479 .50747 .15651 .50932 .15581 .50831 .15409 Mtetra
.655 .67 .852 r
.50831 .15409 .50932 .15581 .51118 .15511 .51017 .15339 Mtetra
.51017 .15339 .51118 .15511 .51304 .1544 .51203 .15268 Mtetra
.654 .669 .852 r
.51203 .15268 .51304 .1544 .5149 .1537 .51389 .15197 Mtetra
.654 .668 .852 r
.51389 .15197 .5149 .1537 .51676 .153 .51575 .15127 Mtetra
.653 .668 .852 r
.51575 .15127 .51676 .153 .51863 .1523 .51761 .15057 Mtetra
.51761 .15057 .51863 .1523 .52049 .1516 .51948 .14987 Mtetra
.51948 .14987 .52049 .1516 .52236 .1509 .52135 .14917 Mtetra
.52135 .14917 .52236 .1509 .52423 .15021 .52321 .14848 Mtetra
.652 .668 .852 r
.52321 .14848 .52423 .15021 .52609 .14951 .52508 .14778 Mtetra
.652 .668 .853 r
.52508 .14778 .52609 .14951 .52796 .14881 .52695 .14708 Mtetra
.52695 .14708 .52796 .14881 .52983 .14812 .52882 .14639 Mtetra
.52882 .14639 .52983 .14812 .53171 .14742 .5307 .14569 Mtetra
.5307 .14569 .53171 .14742 .53358 .14673 .53257 .145 Mtetra
.651 .668 .853 r
.53257 .145 .53358 .14673 .53545 .14604 .53445 .14431 Mtetra
.53445 .14431 .53545 .14604 .53733 .14535 .53632 .14362 Mtetra
.65 .667 .853 r
.53632 .14362 .53733 .14535 .53921 .14467 .5382 .14293 Mtetra
.65 .666 .853 r
.5382 .14293 .53921 .14467 .54109 .14399 .54008 .14224 Mtetra
.649 .665 .852 r
.54008 .14224 .54109 .14399 .54297 .14332 .54196 .14156 Mtetra
.648 .664 .851 r
.54196 .14156 .54297 .14332 .54485 .14265 .54384 .14088 Mtetra
.647 .662 .851 r
.54384 .14088 .54485 .14265 .54673 .14198 .54573 .14021 Mtetra
.647 .661 .85 r
.54573 .14021 .54673 .14198 .54862 .14131 .54761 .13953 Mtetra
.647 .66 .849 r
.54761 .13953 .54862 .14131 .5505 .14065 .5495 .13885 Mtetra
.648 .659 .848 r
.5495 .13885 .5505 .14065 .55239 .13997 .55138 .13817 Mtetra
.648 .658 .846 r
.55138 .13817 .55239 .13997 .55428 .1393 .55327 .13748 Mtetra
.648 .657 .845 r
.55327 .13748 .55428 .1393 .55617 .13861 .55516 .13679 Mtetra
.649 .656 .844 r
.55516 .13679 .55617 .13861 .55806 .13793 .55705 .1361 Mtetra
.649 .655 .843 r
.55705 .1361 .55806 .13793 .55995 .13723 .55895 .1354 Mtetra
.649 .655 .842 r
.55895 .1354 .55995 .13723 .56184 .13654 .56084 .1347 Mtetra
.56084 .1347 .56184 .13654 .56374 .13584 .56273 .13399 Mtetra
.65 .654 .841 r
.56273 .13399 .56374 .13584 .56563 .13514 .56463 .13329 Mtetra
.56463 .13329 .56563 .13514 .56753 .13443 .56653 .13258 Mtetra
.56653 .13258 .56753 .13443 .56943 .13372 .56843 .13187 Mtetra
.65 .654 .84 r
.56843 .13187 .56943 .13372 .57133 .13301 .57033 .13116 Mtetra
.57033 .13116 .57133 .13301 .57323 .1323 .57223 .13045 Mtetra
.57223 .13045 .57323 .1323 .57513 .13159 .57413 .12973 Mtetra
.57413 .12973 .57513 .13159 .57703 .13088 .57604 .12902 Mtetra
.65 .653 .84 r
.57604 .12902 .57703 .13088 .57894 .13016 .57794 .1283 Mtetra
.57794 .1283 .57894 .13016 .58084 .12945 .57985 .12759 Mtetra
.57985 .12759 .58084 .12945 .58275 .12873 .58176 .12687 Mtetra
.58176 .12687 .58275 .12873 .58466 .12802 .58366 .12615 Mtetra
.58366 .12615 .58466 .12802 .58657 .1273 .58557 .12543 Mtetra
.58557 .12543 .58657 .1273 .58848 .12658 .58749 .12471 Mtetra
.651 .653 .84 r
.58749 .12471 .58848 .12658 .59039 .12586 .5894 .12399 Mtetra
.5894 .12399 .59039 .12586 .59231 .12514 .59131 .12327 Mtetra
.59131 .12327 .59231 .12514 .59422 .12442 .59323 .12255 Mtetra
.59323 .12255 .59422 .12442 .59614 .1237 .59515 .12183 Mtetra
.59515 .12183 .59614 .1237 .59806 .12298 .59707 .12111 Mtetra
.59707 .12111 .59806 .12298 .59998 .12226 .59899 .12039 Mtetra
.651 .654 .84 r
.59899 .12039 .59998 .12226 .6019 .12154 .60091 .11966 Mtetra
.60091 .11966 .6019 .12154 .60382 .12081 .60283 .11894 Mtetra
.60283 .11894 .60382 .12081 .60574 .12009 .60475 .11821 Mtetra
.60475 .11821 .60574 .12009 .60767 .11936 .60668 .11749 Mtetra
.60668 .11749 .60767 .11936 .60959 .11864 .6086 .11676 Mtetra
.6086 .11676 .60959 .11864 .61152 .11791 .61053 .11603 Mtetra
.61053 .11603 .61152 .11791 .61345 .11718 .61246 .1153 Mtetra
.61246 .1153 .61345 .11718 .61538 .11645 .61439 .11457 Mtetra
.61439 .11457 .61538 .11645 .61731 .11572 .61632 .11384 Mtetra
.61632 .11384 .61731 .11572 .61924 .11499 .61826 .11311 Mtetra
.652 .655 .84 r
.61826 .11311 .61924 .11499 .62118 .11426 .62019 .11238 Mtetra
.62019 .11238 .62118 .11426 .62311 .11352 .62213 .11164 Mtetra
.62213 .11164 .62311 .11352 .62505 .11278 .62406 .1109 Mtetra
.653 .655 .84 r
.62406 .1109 .62505 .11278 .62698 .11204 .626 .11016 Mtetra
.626 .11016 .62698 .11204 .62892 .1113 .62794 .10942 Mtetra
.654 .656 .839 r
.62794 .10942 .62892 .1113 .63086 .11055 .62988 .10867 Mtetra
.656 .656 .838 r
.62988 .10867 .63086 .11055 .6328 .1098 .63182 .1079 Mtetra
.656 .655 .838 r
.63182 .1079 .6328 .1098 .63475 .10904 .63376 .10714 Mtetra
.666 .66 .834 r
.63376 .10714 .63475 .10904 .63669 .10825 .6357 .10631 Mtetra
.682 .662 .824 r
.6357 .10631 .63669 .10825 .63863 .10743 .63764 .10536 Mtetra
.646 .631 .821 r
.63764 .10536 .63863 .10743 .64058 .10665 .63959 .10462 Mtetra
.544 .583 .844 r
.63959 .10462 .64058 .10665 .64253 .106 .64156 .10446 Mtetra
.062 .357 .829 r
.64156 .10446 .64253 .106 .64449 .10561 .64359 .10563 Mtetra
.74 .216 0 r
.64359 .10563 .64449 .10561 .64646 .10525 .64567 .1081 Mtetra
.769 .375 .308 r
.64567 .1081 .64646 .10525 .64842 .10477 .64784 .11236 Mtetra
.51 .208 .389 r
.64784 .11236 .64842 .10477 .65037 .10398 .64985 .11274 Mtetra
.387 .119 .38 r
.64985 .11274 .65037 .10398 .65232 .1031 .65176 .11068 Mtetra
.332 .066 .353 r
.65176 .11068 .65232 .1031 .65427 .10209 .65364 .10812 Mtetra
.323 .041 .322 r
.65364 .10812 .65427 .10209 .6562 .10084 .65554 .10603 Mtetra
.404 .092 .319 r
.65554 .10603 .6562 .10084 .65816 .10007 .6575 .10512 Mtetra
.628 .279 .36 r
.6575 .10512 .65816 .10007 .66018 .10058 .65961 .10747 Mtetra
.971 .658 .35 r
.65961 .10747 .66018 .10058 .66252 .10783 .67128 .31456 Mtetra
.519 .281 .493 r
.67128 .31456 .66252 .10783 .6746 .31919 .67366 .31961 Mtetra
.642 .095 0 r
.67366 .31961 .6746 .31919 .67692 .32268 .6759 .32135 Mtetra
.497 .69 .954 r
.6759 .32135 .67692 .32268 .67907 .32256 .67805 .3212 Mtetra
.664 .762 .923 r
.67805 .3212 .67907 .32256 .68118 .3217 .68017 .32041 Mtetra
.77 .808 .883 r
.68017 .32041 .68118 .3217 .68329 .3206 .68227 .319 Mtetra
.834 .777 .798 r
.68227 .319 .68329 .3206 .68543 .32007 .68432 .3168 Mtetra
.806 .639 .675 r
.68432 .3168 .68543 .32007 .68754 .31906 .68631 .31334 Mtetra
.837 .598 .577 r
.68631 .31334 .68754 .31906 .68959 .31678 .68806 .30547 Mtetra
.973 .665 .361 r
.68806 .30547 .68959 .31678 .69126 .30743 .67919 .09683 Mtetra
.522 .288 .501 r
.67919 .09683 .69126 .30743 .68198 .09498 .68094 .09169 Mtetra
.762 .606 .684 r
.68094 .09169 .68198 .09498 .68376 .09043 .68282 .08907 Mtetra
.719 .766 .89 r
.68282 .08907 .68376 .09043 .68571 .08922 .68478 .08804 Mtetra
.634 .767 .943 r
.68478 .08804 .68571 .08922 .6877 .08865 .68677 .08742 Mtetra
.615 .749 .941 r
.68677 .08742 .6877 .08865 .6897 .08826 .68876 .08688 Mtetra
.755 .775 .869 r
.68876 .08688 .6897 .08826 .69165 .08703 .69072 .08561 Mtetra
.678 .74 .898 r
.69072 .08561 .69165 .08703 .69364 .08623 .6927 .08479 Mtetra
.402 .598 .925 r
.6927 .08479 .69364 .08623 .69568 .08643 .69474 .08501 Mtetra
.84 .44 0 r
.69474 .08501 .69568 .08643 .69806 .09242 .69717 .09167 Mtetra
.972 .66 .31 r
.69717 .09167 .69806 .09242 .71294 .30603 .71199 .30543 Mtetra
.772 .286 0 r
.71199 .30543 .71294 .30603 .71538 .31017 .71442 .30931 Mtetra
.414 .748 .994 r
.71442 .30931 .71538 .31017 .71757 .31005 .71661 .30918 Mtetra
.711 .876 .958 r
.71661 .30918 .71757 .31005 .71971 .30914 .71874 .30812 Mtetra
.831 .874 .875 r
.71874 .30812 .71971 .30914 .72183 .30782 .72083 .30633 Mtetra
.844 .798 .807 r
.72083 .30633 .72183 .30782 .724 .30724 .72289 .30412 Mtetra
.811 .649 .682 r
.72289 .30412 .724 .30724 .72614 .30622 .72488 .30074 Mtetra
.829 .596 .586 r
.72488 .30074 .72614 .30622 .72821 .30421 .72663 .29376 Mtetra
.973 .662 .342 r
.72663 .29376 .72821 .30421 .72987 .29591 .7151 .08388 Mtetra
.522 .288 .501 r
.7151 .08388 .72987 .29591 .71787 .08201 .71679 .07834 Mtetra
.758 .589 .668 r
.71679 .07834 .71787 .08201 .71958 .07692 .71866 .07551 Mtetra
.724 .762 .882 r
.71866 .07551 .71958 .07692 .72155 .07562 .72064 .07442 Mtetra
.644 .77 .94 r
.72064 .07442 .72155 .07562 .72356 .07498 .72265 .07375 Mtetra
.603 .745 .945 r
.72265 .07375 .72356 .07498 .7256 .07466 .72468 .07325 Mtetra
.777 .78 .855 r
.72468 .07325 .7256 .07466 .72757 .07337 .72664 .0718 Mtetra
.708 .73 .868 r
.72664 .0718 .72757 .07337 .72956 .07248 .72863 .07077 Mtetra
.557 .638 .887 r
.72863 .07077 .72956 .07248 .73162 .07233 .73067 .07051 Mtetra
.932 .564 .289 r
.08833 .31072 .08952 .31179 .09038 .31643 .08922 .31518 Mtetra
.938 .683 .526 r
.08922 .31518 .09038 .31643 .06352 .52206 .0623 .5206 Mtetra
.943 .586 .291 r
.0623 .5206 .06352 .52206 .06444 .52712 .06319 .52583 Mtetra
.249 .542 .925 r
.06319 .52583 .06444 .52712 .06602 .52731 .06474 .52623 Mtetra
.677 .763 .915 r
.06474 .52623 .06602 .52731 .06774 .52652 .06645 .52553 Mtetra
.814 .787 .827 r
.06645 .52553 .06774 .52652 .06957 .52498 .0683 .52384 Mtetra
.886 .747 .702 r
.0683 .52384 .06957 .52498 .07144 .52306 .07045 .51987 Mtetra
.901 .672 .583 r
.07045 .51987 .07144 .52306 .07346 .52007 .07432 .50321 Mtetra
.92 .666 .538 r
.07432 .50321 .07346 .52007 .07591 .51384 .10213 .30914 Mtetra
.518 .286 .502 r
.10213 .30914 .07591 .51384 .10452 .31254 .10403 .30627 Mtetra
.632 .451 .621 r
.10403 .30627 .10452 .31254 .10675 .3072 .10577 .3046 Mtetra
.681 .58 .736 r
.10577 .3046 .10675 .3072 .10863 .30453 .10744 .30349 Mtetra
.68 .759 .911 r
.10744 .30349 .10863 .30453 .11026 .30363 .10905 .30282 Mtetra
.617 .792 .966 r
.10905 .30282 .11026 .30363 .11183 .30324 .11063 .30236 Mtetra
.593 .771 .964 r
.11063 .30236 .11183 .30324 .11338 .30305 .1122 .30198 Mtetra
.743 .763 .869 r
.1122 .30198 .11338 .30305 .11501 .30218 .11385 .30096 Mtetra
.709 .732 .869 r
.11385 .30096 .11501 .30218 .11665 .30135 .11549 .30011 Mtetra
.597 .697 .913 r
.11549 .30011 .11665 .30135 .11824 .30082 .11706 .29976 Mtetra
.758 .263 0 r
.11706 .29976 .11824 .30082 .11971 .30125 .11833 .30168 Mtetra
.904 .586 .433 r
.11833 .30168 .11971 .30125 .12105 .30271 .11884 .30958 Mtetra
.931 .672 .523 r
.11884 .30958 .12105 .30271 .12205 .30683 .09442 .51051 Mtetra
.515 .278 .494 r
.09442 .51051 .12205 .30683 .09783 .50762 .09574 .51297 Mtetra
.545 .224 .374 r
.09574 .51297 .09783 .50762 .09878 .51298 .09728 .51374 Mtetra
.331 0 0 r
.09728 .51374 .09878 .51298 .10017 .51494 .0989 .51384 Mtetra
.57 .732 .951 r
.0989 .51384 .10017 .51494 .1018 .51499 .10058 .51352 Mtetra
.641 .689 .879 r
.10058 .51352 .1018 .51499 .10351 .51442 .1023 .51296 Mtetra
.666 .698 .871 r
.1023 .51296 .10351 .51442 .10526 .51358 .10403 .51227 Mtetra
.549 .684 .928 r
.10403 .51227 .10526 .51358 .10696 .51315 .1057 .51204 Mtetra
.595 .739 .944 r
.1057 .51204 .10696 .51315 .10867 .51266 .10739 .51165 Mtetra
.723 .786 .902 r
.10739 .51165 .10867 .51266 .11041 .51186 .10916 .51072 Mtetra
.874 .757 .73 r
.10916 .51072 .11041 .51186 .11227 .51015 .1112 .50751 Mtetra
.883 .675 .617 r
.1112 .50751 .11227 .51015 .11427 .50738 .11391 .49901 Mtetra
.934 .678 .528 r
.11391 .49901 .11427 .50738 .11655 .50218 .14058 .29593 Mtetra
.52 .287 .502 r
.14058 .29593 .11655 .50218 .14292 .30012 .14258 .29224 Mtetra
.619 .427 .6 r
.14258 .29224 .14292 .30012 .14529 .29336 .14435 .29039 Mtetra
.675 .558 .715 r
.14435 .29039 .14529 .29336 .1472 .29038 .14605 .28919 Mtetra
.686 .734 .887 r
.14605 .28919 .1472 .29038 .14889 .28926 .14768 .28846 Mtetra
.614 .797 .969 r
.14768 .28846 .14889 .28926 .15049 .28883 .14929 .288 Mtetra
.572 .777 .976 r
.14929 .288 .15049 .28883 .15206 .28868 .15088 .28765 Mtetra
.645 .757 .93 r
.15088 .28765 .15206 .28868 .15366 .28823 .1525 .28711 Mtetra
.672 .746 .906 r
.1525 .28711 .15366 .28823 .15529 .28762 .15413 .28646 Mtetra
.683 .741 .895 r
.15413 .28646 .15529 .28762 .15692 .28694 .15577 .28576 Mtetra
.746 .75 .855 r
.15577 .28576 .15692 .28694 .1586 .28596 .15745 .28467 Mtetra
.725 .73 .855 r
.15745 .28467 .1586 .28596 .16026 .28501 .15913 .2837 Mtetra
.636 .701 .893 r
.15913 .2837 .16026 .28501 .1619 .28435 .16074 .28319 Mtetra
0 .025 .525 r
.16074 .28319 .1619 .28435 .16344 .28453 .16215 .28454 Mtetra
.9 .542 .355 r
.16215 .28454 .16344 .28453 .16487 .28563 .16311 .2897 Mtetra
.939 .677 .513 r
.16311 .2897 .16487 .28563 .16612 .28842 .14117 .49277 Mtetra
.517 .28 .494 r
.14117 .49277 .16612 .28842 .1451 .48506 .14245 .4962 Mtetra
.53 .249 .433 r
.14245 .4962 .1451 .48506 .14563 .49508 .14403 .49697 Mtetra
.405 0 .095 r
.14403 .49697 .14563 .49508 .14702 .49759 .14571 .49694 Mtetra
.603 .84 .989 r
.14571 .49694 .14702 .49759 .14867 .49778 .14745 .49642 Mtetra
.694 .725 .874 r
.14745 .49642 .14867 .49778 .15044 .49702 .14923 .49558 Mtetra
.716 .72 .852 r
.14923 .49558 .15044 .49702 .15225 .49587 .15102 .49458 Mtetra
.698 .738 .882 r
.15102 .49458 .15225 .49587 .15403 .49491 .1528 .49373 Mtetra
.67 .75 .91 r
.1528 .49373 .15403 .49491 .1558 .49415 .15456 .49304 Mtetra
.647 .757 .929 r
.15456 .49304 .1558 .49415 .15756 .49348 .15631 .49245 Mtetra
.597 .758 .956 r
.15631 .49245 .15756 .49348 .1593 .493 .15804 .49203 Mtetra
.551 .756 .973 r
.15804 .49203 .1593 .493 .16102 .49265 .15976 .49172 Mtetra
.526 .756 .98 r
.15976 .49172 .16102 .49265 .16274 .49238 .16148 .49146 Mtetra
.251 .627 .96 r
.16148 .49146 .16274 .49238 .1644 .49266 .16314 .49169 Mtetra
.368 .679 .977 r
.16314 .49169 .1644 .49266 .16608 .49278 .16483 .49176 Mtetra
.671 .782 .933 r
.16483 .49176 .16608 .49278 .16785 .49212 .1666 .49107 Mtetra
.898 .765 .706 r
.1666 .49107 .16785 .49212 .16997 .48811 .16871 .48718 Mtetra
.947 .689 .512 r
.16871 .48718 .16997 .48811 .19374 .28125 .19247 .28116 Mtetra
.956 .757 .594 r
.19247 .28116 .19374 .28125 .19626 .27248 .19508 .27162 Mtetra
.864 .801 .787 r
.19508 .27162 .19626 .27248 .19807 .27034 .1969 .26941 Mtetra
.65 .782 .944 r
.1969 .26941 .19807 .27034 .19972 .26982 .19855 .26884 Mtetra
.466 .705 .972 r
.19855 .26884 .19972 .26982 .20131 .26981 .20015 .26876 Mtetra
.566 .731 .953 r
.20015 .26876 .20131 .26981 .20293 .26956 .20178 .26846 Mtetra
.656 .749 .918 r
.20178 .26846 .20293 .26956 .20458 .26901 .20343 .26787 Mtetra
.668 .746 .908 r
.20343 .26787 .20458 .26901 .20624 .26838 .20509 .26722 Mtetra
.744 .758 .864 r
.20509 .26722 .20624 .26838 .20794 .26731 .2068 .26616 Mtetra
.746 .76 .864 r
.2068 .26616 .20794 .26731 .20965 .26621 .20851 .26507 Mtetra
.633 .737 .923 r
.20851 .26507 .20965 .26621 .2113 .26569 .21016 .26457 Mtetra
.698 .201 0 r
.21016 .26457 .2113 .26569 .2127 .26768 .21156 .26651 Mtetra
.95 .685 .498 r
.21156 .26651 .2127 .26768 .19392 .4705 .19281 .46814 Mtetra
.969 .662 .378 r
.19281 .46814 .19392 .4705 .19448 .48198 .19327 .48062 Mtetra
.557 .075 0 r
.19327 .48062 .19448 .48198 .19603 .48362 .19481 .48242 Mtetra
.563 .717 .944 r
.19481 .48242 .19603 .48362 .1978 .48317 .19656 .48212 Mtetra
.769 .795 .874 r
.19656 .48212 .1978 .48317 .19964 .48192 .1984 .48086 Mtetra
.873 .782 .758 r
.1984 .48086 .19964 .48192 .20154 .48015 .2004 .47808 Mtetra
.891 .699 .637 r
.2004 .47808 .20154 .48015 .2035 .47773 .20275 .47166 Mtetra
.945 .683 .508 r
.20275 .47166 .2035 .47773 .20562 .47359 .22445 .2663 Mtetra
.524 .29 .503 r
.22445 .2663 .20562 .47359 .22651 .27467 .22657 .2611 Mtetra
.585 .375 .562 r
.22657 .2611 .22651 .27467 .22926 .26284 .22839 .25898 Mtetra
.66 .517 .678 r
.22839 .25898 .22926 .26284 .23122 .25926 .23013 .25761 Mtetra
.691 .676 .83 r
.23013 .25761 .23122 .25926 .23299 .25763 .23183 .25675 Mtetra
.636 .791 .957 r
.23183 .25675 .23299 .25763 .23466 .25706 .2335 .25621 Mtetra
.58 .781 .975 r
.2335 .25621 .23466 .25706 .2363 .25684 .23515 .25582 Mtetra
.676 .775 .925 r
.23515 .25582 .2363 .25684 .23796 .25638 .23684 .25514 Mtetra
.714 .743 .874 r
.23684 .25514 .23796 .25638 .23966 .2556 .23855 .25424 Mtetra
.634 .698 .892 r
.23855 .25424 .23966 .2556 .24133 .25502 .24022 .25373 Mtetra
0 .342 .819 r
.24022 .25373 .24133 .25502 .24296 .25503 .24176 .25461 Mtetra
.909 .524 .274 r
.24176 .25461 .24296 .25503 .2445 .256 .24296 .25926 Mtetra
.948 .679 .493 r
.24296 .25926 .2445 .256 .24589 .25863 .226 .46364 Mtetra
.519 .282 .494 r
.226 .46364 .24589 .25863 .22966 .45696 .22734 .46814 Mtetra
.54 .257 .434 r
.22734 .46814 .22966 .45696 .23048 .46723 .22899 .46921 Mtetra
.471 .043 .144 r
.22899 .46921 .23048 .46723 .23199 .46997 .23071 .46947 Mtetra
.405 .795 .989 r
.23071 .46947 .23199 .46997 .23367 .4707 .23248 .46925 Mtetra
.628 .697 .894 r
.23248 .46925 .23367 .4707 .23546 .47027 .23428 .46872 Mtetra
.66 .694 .871 r
.23428 .46872 .23546 .47027 .23728 .46946 .23609 .46802 Mtetra
.62 .696 .899 r
.23609 .46802 .23728 .46946 .2391 .46877 .23789 .46753 Mtetra
.56 .71 .941 r
.23789 .46753 .2391 .46877 .24089 .46833 .23967 .46723 Mtetra
.67 .775 .928 r
.23967 .46723 .24089 .46833 .24271 .46764 .24149 .46652 Mtetra
.837 .789 .806 r
.24149 .46652 .24271 .46764 .24458 .46633 .24343 .46448 Mtetra
.891 .713 .655 r
.24343 .46448 .24458 .46633 .24654 .46398 .24564 .45911 Mtetra
.951 .685 .497 r
.24564 .45911 .24654 .46398 .24863 .46004 .26481 .25327 Mtetra
.528 .294 .503 r
.26481 .25327 .24863 .46004 .25188 .44225 .26705 .24619 Mtetra
.517 .285 .501 r
.26705 .24619 .25188 .44225 .26976 .24816 .2689 .24386 Mtetra
.656 .503 .664 r
.2689 .24386 .26976 .24816 .27173 .24421 .27067 .24238 Mtetra
.701 .66 .806 r
.27067 .24238 .27173 .24421 .27354 .24224 .2724 .24137 Mtetra
.679 .808 .944 r
.2724 .24137 .27354 .24224 .27526 .24143 .27411 .24067 Mtetra
.621 .818 .976 r
.27411 .24067 .27526 .24143 .27695 .24098 .27581 .24014 Mtetra
.609 .796 .971 r
.27581 .24014 .27695 .24098 .27863 .24064 .2775 .23967 Mtetra
.631 .774 .949 r
.2775 .23967 .27863 .24064 .28032 .24019 .2792 .23914 Mtetra
.64 .762 .937 r
.2792 .23914 .28032 .24019 .28202 .23972 .2809 .23859 Mtetra
.667 .754 .915 r
.2809 .23859 .28202 .23972 .28372 .23912 .28261 .23794 Mtetra
.697 .752 .894 r
.28261 .23794 .28372 .23912 .28544 .23831 .28433 .23713 Mtetra
.701 .753 .892 r
.28433 .23713 .28544 .23831 .28717 .23747 .28606 .2363 Mtetra
.717 .759 .886 r
.28606 .2363 .28717 .23747 .2889 .2366 .28779 .23539 Mtetra
.725 .755 .876 r
.28779 .23539 .2889 .2366 .29063 .23575 .28953 .23443 Mtetra
.65 .714 .894 r
.28953 .23443 .29063 .23575 .29234 .23512 .29124 .23383 Mtetra
.265 .537 .919 r
.29124 .23383 .29234 .23512 .29402 .235 .29287 .23426 Mtetra
.873 .431 .093 r
.29287 .23426 .29402 .235 .29562 .23584 .29429 .23755 Mtetra
.955 .681 .478 r
.29429 .23755 .29562 .23584 .29713 .23806 .28071 .44145 Mtetra
.526 .287 .495 r
.28071 .44145 .29713 .23806 .2979 .25023 .28192 .44918 Mtetra
.513 .276 .493 r
.28192 .44918 .2979 .25023 .28509 .4479 .28361 .45059 Mtetra
.505 .112 .23 r
.28361 .45059 .28509 .4479 .28664 .4512 .28538 .45099 Mtetra
.217 .728 .885 r
.28538 .45099 .28664 .4512 .28836 .45227 .28718 .45085 Mtetra
.618 .702 .905 r
.28718 .45085 .28836 .45227 .29018 .45191 .28902 .45035 Mtetra
.657 .696 .874 r
.28902 .45035 .29018 .45191 .29204 .45114 .29087 .44966 Mtetra
.644 .704 .89 r
.29087 .44966 .29204 .45114 .2939 .45033 .29271 .44905 Mtetra
.553 .703 .939 r
.29271 .44905 .2939 .45033 .29573 .44988 .29454 .44877 Mtetra
.653 .771 .936 r
.29454 .44877 .29573 .44988 .29758 .44921 .29639 .44812 Mtetra
.816 .801 .838 r
.29639 .44812 .29758 .44921 .29948 .44795 .29831 .4464 Mtetra
.906 .736 .661 r
.29831 .4464 .29948 .44795 .30146 .4453 .30047 .44128 Mtetra
.957 .687 .483 r
.30047 .44128 .30146 .4453 .30354 .44138 .31631 .23559 Mtetra
.53 .295 .504 r
.31631 .23559 .30354 .44138 .30568 .43645 .31855 .22751 Mtetra
.513 .282 .5 r
.31855 .22751 .30568 .43645 .3075 .43627 .32031 .22647 Mtetra
.512 .28 .5 r
.32031 .22647 .3075 .43627 .30931 .43612 .32203 .22614 Mtetra
.512 .281 .5 r
.32203 .22614 .30931 .43612 .31141 .43183 .32376 .22549 Mtetra
.516 .284 .501 r
.32376 .22549 .31141 .43183 .32643 .22865 .3256 .22333 Mtetra
.656 .483 .638 r
.3256 .22333 .32643 .22865 .32846 .22356 .32742 .22146 Mtetra
.729 .648 .768 r
.32742 .22146 .32846 .22356 .33032 .22104 .32921 .22007 Mtetra
.665 .788 .939 r
.32921 .22007 .33032 .22104 .33207 .22027 .33095 .2194 Mtetra
.606 .794 .971 r
.33095 .2194 .33207 .22027 .33379 .21991 .33268 .21893 Mtetra
.603 .768 .958 r
.33268 .21893 .33379 .21991 .33551 .21967 .33441 .21848 Mtetra
.662 .746 .913 r
.33441 .21848 .33551 .21967 .33725 .21906 .33615 .21783 Mtetra
.671 .741 .903 r
.33615 .21783 .33725 .21906 .33899 .2184 .3379 .21714 Mtetra
.694 .743 .889 r
.3379 .21714 .33899 .2184 .34075 .21763 .33966 .21633 Mtetra
.745 .75 .856 r
.33966 .21633 .34075 .21763 .34251 .2166 .34144 .21519 Mtetra
.688 .716 .87 r
.34144 .21519 .34251 .2166 .34427 .21576 .34319 .21438 Mtetra
.48 .636 .923 r
.34319 .21438 .34427 .21576 .34601 .21539 .3449 .21437 Mtetra
.824 .362 0 r
.3449 .21437 .34601 .21539 .34766 .21642 .34644 .21735 Mtetra
.961 .682 .461 r
.34644 .21735 .34766 .21642 .34925 .21858 .3364 .41954 Mtetra
.531 .291 .496 r
.3364 .41954 .34925 .21858 .35075 .22239 .33765 .42966 Mtetra
.51 .273 .492 r
.33765 .42966 .35075 .22239 .35252 .22142 .3395 .42961 Mtetra
.508 .272 .492 r
.3395 .42961 .35252 .22142 .35431 .22027 .34139 .42871 Mtetra
.34139 .42871 .35431 .22027 .35594 .22196 .34328 .42791 Mtetra
.512 .275 .492 r
.34328 .42791 .35594 .22196 .34651 .42505 .34506 .42897 Mtetra
.549 .194 .317 r
.34506 .42897 .34651 .42505 .3481 .42975 .34687 .42979 Mtetra
.28 0 0 r
.34687 .42979 .3481 .42975 .34985 .43159 .3487 .4302 Mtetra
.562 .689 .925 r
.3487 .4302 .34985 .43159 .35171 .43151 .35056 .42991 Mtetra
.618 .678 .884 r
.35056 .42991 .35171 .43151 .35359 .43097 .35245 .4294 Mtetra
.641 .692 .882 r
.35245 .4294 .35359 .43097 .35549 .43019 .35433 .42877 Mtetra
.58 .694 .919 r
.35433 .42877 .35549 .43019 .35738 .42962 .35621 .42842 Mtetra
.663 .761 .923 r
.35621 .42842 .35738 .42962 .35927 .42883 .35811 .42771 Mtetra
.782 .802 .868 r
.35811 .42771 .35927 .42883 .3612 .42763 .36004 .4263 Mtetra
.912 .762 .682 r
.36004 .4263 .3612 .42763 .36318 .42511 .36212 .42186 Mtetra
.944 .687 .517 r
.36212 .42186 .36318 .42511 .36523 .42147 .3653 .39536 Mtetra
.936 .657 .486 r
.3653 .39536 .36523 .42147 .36736 .41598 .37643 .20608 Mtetra
.514 .282 .501 r
.37643 .20608 .36736 .41598 .36933 .41362 .37825 .2045 Mtetra
.512 .28 .5 r
.37825 .2045 .36933 .41362 .3712 .41337 .38001 .20398 Mtetra
.511 .279 .5 r
.38001 .20398 .3712 .41337 .37304 .41407 .38176 .20401 Mtetra
.512 .28 .5 r
.38176 .20401 .37304 .41407 .37486 .41487 .38352 .20365 Mtetra
.512 .281 .5 r
.38352 .20365 .37486 .41487 .37675 .4145 .38529 .2031 Mtetra
.513 .281 .5 r
.38529 .2031 .37675 .4145 .37874 .41191 .38709 .20209 Mtetra
.516 .284 .501 r
.38709 .20209 .37874 .41191 .38977 .20661 .38894 .19984 Mtetra
.637 .45 .613 r
.38894 .19984 .38977 .20661 .3918 .20033 .39078 .19783 Mtetra
.731 .622 .737 r
.39078 .19783 .3918 .20033 .39369 .19722 .39261 .19618 Mtetra
.707 .792 .917 r
.39261 .19618 .39369 .19722 .39549 .19615 .3944 .19532 Mtetra
.65 .823 .967 r
.3944 .19532 .39549 .19615 .39727 .19553 .39618 .19468 Mtetra
.61 .805 .975 r
.39618 .19468 .39727 .19553 .39904 .19518 .39796 .19417 Mtetra
.631 .777 .951 r
.39796 .19417 .39904 .19518 .40082 .19469 .39974 .19362 Mtetra
.63 .764 .943 r
.39974 .19362 .40082 .19469 .40259 .19422 .40152 .19308 Mtetra
.636 .751 .931 r
.40152 .19308 .40259 .19422 .40437 .19374 .40331 .19252 Mtetra
.657 .743 .913 r
.40331 .19252 .40437 .19374 .40616 .19314 .4051 .19188 Mtetra
.668 .739 .903 r
.4051 .19188 .40616 .19314 .40795 .19247 .40689 .19118 Mtetra
.678 .739 .896 r
.40689 .19118 .40795 .19247 .40975 .19173 .40869 .19043 Mtetra
.697 .743 .887 r
.40869 .19043 .40975 .19173 .41155 .19087 .41049 .18958 Mtetra
.7 .746 .887 r
.41049 .18958 .41155 .19087 .41335 .18999 .41229 .18872 Mtetra
.697 .748 .891 r
.41229 .18872 .41335 .18999 .41515 .18913 .41409 .18788 Mtetra
.735 .762 .874 r
.41409 .18788 .41515 .18913 .41695 .1882 .4159 .18682 Mtetra
.686 .725 .88 r
.4159 .18682 .41695 .1882 .41876 .18744 .4177 .18601 Mtetra
.569 .673 .909 r
.4177 .18601 .41876 .18744 .42055 .18698 .41949 .18572 Mtetra
.561 .09 0 r
.41949 .18572 .42055 .18698 .4223 .18771 .42119 .18782 Mtetra
.931 .574 .325 r
.42119 .18782 .4223 .18771 .42402 .18944 .42267 .19666 Mtetra
.96 .672 .445 r
.42267 .19666 .42402 .18944 .42569 .19278 .41765 .40148 Mtetra
.511 .275 .492 r
.41765 .40148 .42569 .19278 .42748 .19263 .41953 .40224 Mtetra
.508 .272 .492 r
.41953 .40224 .42748 .19263 .42931 .19136 .42148 .4014 Mtetra
.507 .271 .492 r
.42148 .4014 .42931 .19136 .4311 .19118 .42343 .40024 Mtetra
.511 .275 .492 r
.42343 .40024 .4311 .19118 .4267 .39427 .42532 .40116 Mtetra
.543 .23 .387 r
.42532 .40116 .4267 .39427 .4284 .40146 .42721 .40211 Mtetra
.448 0 0 r
.42721 .40211 .4284 .40146 .43024 .40393 .42911 .40265 Mtetra
.56 .714 .944 r
.42911 .40265 .43024 .40393 .43217 .404 .43105 .40233 Mtetra
.64 .683 .874 r
.43105 .40233 .43217 .404 .43411 .40335 .43299 .40169 Mtetra
.663 .694 .868 r
.43299 .40169 .43411 .40335 .43606 .40241 .43494 .40092 Mtetra
.642 .712 .898 r
.43494 .40092 .43606 .40241 .43801 .4017 .43689 .40029 Mtetra
.636 .723 .91 r
.43689 .40029 .43801 .4017 .43996 .40103 .43884 .39968 Mtetra
.637 .733 .917 r
.43884 .39968 .43996 .40103 .44191 .40037 .44079 .39907 Mtetra
.549 .707 .944 r
.44079 .39907 .44191 .40037 .44386 .39992 .44273 .39879 Mtetra
.598 .76 .956 r
.44273 .39879 .44386 .39992 .44581 .39936 .44468 .3983 Mtetra
.728 .814 .918 r
.44468 .3983 .44581 .39936 .44777 .39849 .44664 .39726 Mtetra
.909 .79 .717 r
.44664 .39726 .44777 .39849 .44976 .3963 .44867 .39365 Mtetra
.93 .697 .564 r
.44867 .39365 .44976 .3963 .45178 .39282 .45086 .38265 Mtetra
.963 .678 .446 r
.45086 .38265 .45178 .39282 .45384 .38724 .45744 .17632 Mtetra
.516 .284 .501 r
.45744 .17632 .45384 .38724 .45583 .3849 .45931 .17399 Mtetra
.512 .281 .5 r
.45931 .17399 .45583 .3849 .45777 .38503 .46113 .17338 Mtetra
.511 .28 .5 r
.46113 .17338 .45777 .38503 .45974 .38386 .46295 .1731 Mtetra
.515 .283 .501 r
.46295 .1731 .45974 .38386 .46571 .17972 .46481 .17134 Mtetra
.615 .42 .594 r
.46481 .17134 .46571 .17972 .46767 .17235 .46667 .16933 Mtetra
.712 .586 .713 r
.46667 .16933 .46767 .17235 .46956 .16892 .46852 .16764 Mtetra
.725 .759 .879 r
.46852 .16764 .46956 .16892 .4714 .16748 .47036 .16662 Mtetra
.659 .825 .963 r
.47036 .16662 .4714 .16748 .47324 .16676 .47219 .16593 Mtetra
.62 .819 .977 r
.47219 .16593 .47324 .16676 .47507 .16631 .47403 .16536 Mtetra
.648 .802 .957 r
.47403 .16536 .47507 .16631 .4769 .16571 .47586 .16472 Mtetra
.658 .797 .949 r
.47586 .16472 .4769 .16571 .47874 .16504 .4777 .16404 Mtetra
.658 .795 .948 r
.4777 .16404 .47874 .16504 .48058 .16438 .47954 .16337 Mtetra
.66 .794 .946 r
.47954 .16337 .48058 .16438 .48242 .1637 .48138 .16269 Mtetra
.659 .793 .946 r
.48138 .16269 .48242 .1637 .48426 .16303 .48322 .16201 Mtetra
.654 .79 .947 r
.48322 .16201 .48426 .16303 .4861 .16239 .48507 .16136 Mtetra
.636 .78 .95 r
.48507 .16136 .4861 .16239 .48794 .16185 .48691 .16077 Mtetra
.628 .767 .947 r
.48691 .16077 .48794 .16185 .48978 .16136 .48875 .16021 Mtetra
.631 .755 .937 r
.48875 .16021 .48978 .16136 .49163 .16087 .4906 .15965 Mtetra
.648 .748 .922 r
.4906 .15965 .49163 .16087 .49347 .16029 .49245 .15902 Mtetra
.662 .745 .911 r
.49245 .15902 .49347 .16029 .49532 .15962 .4943 .15833 Mtetra
.673 .744 .904 r
.4943 .15833 .49532 .15962 .49717 .15889 .49615 .15759 Mtetra
.688 .748 .897 r
.49615 .15759 .49717 .15889 .49903 .15806 .498 .15677 Mtetra
.696 .753 .895 r
.498 .15677 .49903 .15806 .50088 .15718 .49986 .15591 Mtetra
.696 .756 .899 r
.49986 .15591 .50088 .15718 .50274 .15631 .50171 .15506 Mtetra
.683 .756 .907 r
.50171 .15506 .50274 .15631 .50459 .15552 .50357 .15427 Mtetra
.672 .753 .911 r
.50357 .15427 .50459 .15552 .50645 .15479 .50543 .15354 Mtetra
.667 .749 .912 r
.50543 .15354 .50645 .15479 .50831 .15409 .50729 .15282 Mtetra
.667 .747 .91 r
.50729 .15282 .50831 .15409 .51017 .15339 .50915 .15211 Mtetra
.666 .745 .909 r
.50915 .15211 .51017 .15339 .51203 .15268 .51101 .1514 Mtetra
.665 .744 .909 r
.51101 .1514 .51203 .15268 .51389 .15197 .51287 .15069 Mtetra
.664 .744 .909 r
.51287 .15069 .51389 .15197 .51575 .15127 .51473 .14999 Mtetra
.663 .743 .909 r
.51473 .14999 .51575 .15127 .51761 .15057 .5166 .14928 Mtetra
.663 .743 .91 r
.5166 .14928 .51761 .15057 .51948 .14987 .51846 .14858 Mtetra
.662 .743 .91 r
.51846 .14858 .51948 .14987 .52135 .14917 .52033 .14789 Mtetra
.662 .743 .911 r
.52033 .14789 .52135 .14917 .52321 .14848 .5222 .14719 Mtetra
.661 .744 .911 r
.5222 .14719 .52321 .14848 .52508 .14778 .52407 .1465 Mtetra
.52407 .1465 .52508 .14778 .52695 .14708 .52594 .1458 Mtetra
.661 .744 .912 r
.52594 .1458 .52695 .14708 .52882 .14639 .52781 .14511 Mtetra
.661 .745 .912 r
.52781 .14511 .52882 .14639 .5307 .14569 .52969 .14442 Mtetra
.52969 .14442 .5307 .14569 .53257 .145 .53156 .14372 Mtetra
.661 .745 .913 r
.53156 .14372 .53257 .145 .53445 .14431 .53344 .14303 Mtetra
.53344 .14303 .53445 .14431 .53632 .14362 .53531 .14234 Mtetra
.66 .745 .913 r
.53531 .14234 .53632 .14362 .5382 .14293 .53719 .14164 Mtetra
.66 .744 .912 r
.53719 .14164 .5382 .14293 .54008 .14224 .53907 .14095 Mtetra
.659 .743 .912 r
.53907 .14095 .54008 .14224 .54196 .14156 .54095 .14027 Mtetra
.659 .742 .912 r
.54095 .14027 .54196 .14156 .54384 .14088 .54284 .13958 Mtetra
.658 .741 .911 r
.54284 .13958 .54384 .14088 .54573 .14021 .54472 .1389 Mtetra
.658 .739 .91 r
.54472 .1389 .54573 .14021 .54761 .13953 .54661 .13821 Mtetra
.658 .738 .909 r
.54661 .13821 .54761 .13953 .5495 .13885 .54849 .13752 Mtetra
.659 .737 .907 r
.54849 .13752 .5495 .13885 .55138 .13817 .55038 .13683 Mtetra
.659 .736 .906 r
.55038 .13683 .55138 .13817 .55327 .13748 .55227 .13614 Mtetra
.66 .735 .905 r
.55227 .13614 .55327 .13748 .55516 .13679 .55416 .13544 Mtetra
.66 .734 .904 r
.55416 .13544 .55516 .13679 .55705 .1361 .55605 .13474 Mtetra
.661 .734 .904 r
.55605 .13474 .55705 .1361 .55895 .1354 .55795 .13404 Mtetra
.661 .733 .903 r
.55795 .13404 .55895 .1354 .56084 .1347 .55984 .13334 Mtetra
.55984 .13334 .56084 .1347 .56273 .13399 .56174 .13263 Mtetra
.662 .733 .902 r
.56174 .13263 .56273 .13399 .56463 .13329 .56363 .13192 Mtetra
.662 .732 .902 r
.56363 .13192 .56463 .13329 .56653 .13258 .56553 .13121 Mtetra
.56553 .13121 .56653 .13258 .56843 .13187 .56743 .1305 Mtetra
.56743 .1305 .56843 .13187 .57033 .13116 .56933 .12979 Mtetra
.56933 .12979 .57033 .13116 .57223 .13045 .57124 .12907 Mtetra
.662 .732 .901 r
.57124 .12907 .57223 .13045 .57413 .12973 .57314 .12836 Mtetra
.57314 .12836 .57413 .12973 .57604 .12902 .57504 .12764 Mtetra
.57504 .12764 .57604 .12902 .57794 .1283 .57695 .12693 Mtetra
.57695 .12693 .57794 .1283 .57985 .12759 .57886 .12621 Mtetra
.663 .732 .901 r
.57886 .12621 .57985 .12759 .58176 .12687 .58077 .12549 Mtetra
.58077 .12549 .58176 .12687 .58366 .12615 .58268 .12477 Mtetra
.58268 .12477 .58366 .12615 .58557 .12543 .58459 .12405 Mtetra
.58459 .12405 .58557 .12543 .58749 .12471 .5865 .12333 Mtetra
.5865 .12333 .58749 .12471 .5894 .12399 .58841 .12261 Mtetra
.58841 .12261 .5894 .12399 .59131 .12327 .59033 .12189 Mtetra
.59033 .12189 .59131 .12327 .59323 .12255 .59225 .12117 Mtetra
.59225 .12117 .59323 .12255 .59515 .12183 .59416 .12045 Mtetra
.59416 .12045 .59515 .12183 .59707 .12111 .59608 .11972 Mtetra
.59608 .11972 .59707 .12111 .59899 .12039 .598 .119 Mtetra
.598 .119 .59899 .12039 .60091 .11966 .59993 .11827 Mtetra
.59993 .11827 .60091 .11966 .60283 .11894 .60185 .11755 Mtetra
.60185 .11755 .60283 .11894 .60475 .11821 .60377 .11682 Mtetra
.60377 .11682 .60475 .11821 .60668 .11749 .6057 .1161 Mtetra
.6057 .1161 .60668 .11749 .6086 .11676 .60763 .11537 Mtetra
.60763 .11537 .6086 .11676 .61053 .11603 .60956 .11464 Mtetra
.60956 .11464 .61053 .11603 .61246 .1153 .61149 .11391 Mtetra
.61149 .11391 .61246 .1153 .61439 .11457 .61342 .11318 Mtetra
.663 .733 .901 r
.61342 .11318 .61439 .11457 .61632 .11384 .61535 .11245 Mtetra
.664 .733 .901 r
.61535 .11245 .61632 .11384 .61826 .11311 .61728 .11172 Mtetra
.61728 .11172 .61826 .11311 .62019 .11238 .61922 .11098 Mtetra
.61922 .11098 .62019 .11238 .62213 .11164 .62115 .11025 Mtetra
.665 .733 .901 r
.62115 .11025 .62213 .11164 .62406 .1109 .62309 .10951 Mtetra
.62309 .10951 .62406 .1109 .626 .11016 .62503 .10876 Mtetra
.666 .733 .9 r
.62503 .10876 .626 .11016 .62794 .10942 .62697 .10802 Mtetra
.668 .734 .899 r
.62697 .10802 .62794 .10942 .62988 .10867 .62891 .10726 Mtetra
.67 .734 .898 r
.62891 .10726 .62988 .10867 .63182 .1079 .63085 .10649 Mtetra
.67 .733 .897 r
.63085 .10649 .63182 .1079 .63376 .10714 .6328 .10572 Mtetra
.689 .74 .89 r
.6328 .10572 .63376 .10714 .6357 .10631 .63474 .10485 Mtetra
.72 .745 .872 r
.63474 .10485 .6357 .10631 .63764 .10536 .63667 .1038 Mtetra
.654 .701 .881 r
.63667 .1038 .63764 .10536 .63959 .10462 .63862 .10309 Mtetra
.39 .571 .91 r
.63862 .10309 .63959 .10462 .64156 .10446 .64061 .10338 Mtetra
.728 .267 0 r
.64061 .10338 .64156 .10446 .64359 .10563 .64274 .10694 Mtetra
.974 .665 .344 r
.64274 .10694 .64359 .10563 .64567 .1081 .65329 .31636 Mtetra
.522 .282 .493 r
.65329 .31636 .64567 .1081 .64784 .11236 .6557 .32302 Mtetra
.509 .273 .492 r
.6557 .32302 .64784 .11236 .64985 .11274 .65783 .32293 Mtetra
.507 .272 .492 r
.65783 .32293 .64985 .11274 .65176 .11068 .65992 .3218 Mtetra
.507 .271 .492 r
.65992 .3218 .65176 .11068 .65364 .10812 .662 .32025 Mtetra
.508 .272 .492 r
.662 .32025 .65364 .10812 .65554 .10603 .66409 .31912 Mtetra
.66409 .31912 .65554 .10603 .6575 .10512 .6662 .31825 Mtetra
.509 .273 .492 r
.6662 .31825 .6575 .10512 .65961 .10747 .66834 .31811 Mtetra
.511 .274 .492 r
.66834 .31811 .65961 .10747 .67128 .31456 .67053 .31904 Mtetra
.526 .173 .311 r
.67053 .31904 .67128 .31456 .67366 .31961 .67272 .31973 Mtetra
.198 0 0 r
.67272 .31973 .67366 .31961 .6759 .32135 .67489 .32003 Mtetra
.505 .695 .955 r
.67489 .32003 .6759 .32135 .67805 .3212 .67704 .31985 Mtetra
.651 .758 .928 r
.67704 .31985 .67805 .3212 .68017 .32041 .67916 .31912 Mtetra
.812 .819 .856 r
.67916 .31912 .68017 .32041 .68227 .319 .68124 .31738 Mtetra
.939 .776 .651 r
.68124 .31738 .68227 .319 .68432 .3168 .68316 .31246 Mtetra
.976 .672 .348 r
.68316 .31246 .68432 .3168 .68631 .31334 .67463 .1036 Mtetra
.533 .296 .502 r
.67463 .1036 .68631 .31334 .68806 .30547 .6761 .09298 Mtetra
.516 .284 .501 r
.6761 .09298 .68806 .30547 .67919 .09683 .67799 .09043 Mtetra
.618 .442 .621 r
.67799 .09043 .67919 .09683 .68094 .09169 .67992 .08883 Mtetra
.666 .577 .746 r
.67992 .08883 .68094 .09169 .68282 .08907 .68188 .08771 Mtetra
.684 .753 .904 r
.68188 .08771 .68282 .08907 .68478 .08804 .68385 .08687 Mtetra
.647 .775 .941 r
.68385 .08687 .68478 .08804 .68677 .08742 .68584 .08619 Mtetra
.653 .766 .932 r
.68584 .08619 .68677 .08742 .68876 .08688 .68783 .0855 Mtetra
.756 .775 .869 r
.68783 .0855 .68876 .08688 .69072 .08561 .68978 .08422 Mtetra
.682 .747 .9 r
.68978 .08422 .69072 .08561 .6927 .08479 .69176 .08338 Mtetra
.412 .609 .929 r
.69176 .08338 .6927 .08479 .69474 .08501 .6938 .08356 Mtetra
.82 .417 0 r
.6938 .08356 .69474 .08501 .69717 .09167 .6962 .08974 Mtetra
.972 .661 .307 r
.6962 .08974 .69717 .09167 .71199 .30543 .71097 .30369 Mtetra
0 0 .37 r
.71097 .30369 .71199 .30543 .71442 .30931 .71341 .30777 Mtetra
.449 .627 .929 r
.71341 .30777 .71442 .30931 .71661 .30918 .71561 .30785 Mtetra
.698 .784 .918 r
.71561 .30785 .71661 .30918 .71874 .30812 .71775 .30687 Mtetra
.846 .836 .835 r
.71775 .30687 .71874 .30812 .72083 .30633 .71983 .30481 Mtetra
.944 .791 .661 r
.71983 .30481 .72083 .30633 .72289 .30412 .72174 .30018 Mtetra
.975 .668 .329 r
.72174 .30018 .72289 .30412 .72488 .30074 .71091 .0957 Mtetra
.544 .304 .502 r
.71091 .0957 .72488 .30074 .72663 .29376 .71194 .07968 Mtetra
.516 .284 .5 r
.71194 .07968 .72663 .29376 .7151 .08388 .71381 .07696 Mtetra
.615 .433 .612 r
.71381 .07696 .7151 .08388 .71679 .07834 .71576 .07527 Mtetra
.664 .564 .733 r
.71576 .07527 .71679 .07834 .71866 .07551 .71773 .07409 Mtetra
.687 .748 .897 r
.71773 .07409 .71866 .07551 .72064 .07442 .71973 .07321 Mtetra
.654 .774 .937 r
.71973 .07321 .72064 .07442 .72265 .07375 .72174 .0725 Mtetra
.644 .762 .934 r
.72174 .0725 .72265 .07375 .72468 .07325 .72375 .07183 Mtetra
.774 .78 .858 r
.72375 .07183 .72468 .07325 .72664 .0718 .72572 .07041 Mtetra
.713 .764 .892 r
.72572 .07041 .72664 .0718 .72863 .07077 .72771 .0694 Mtetra
.543 .69 .935 r
.72771 .0694 .72863 .07077 .73067 .07051 .72976 .06914 Mtetra
.895 .557 .399 r
.08697 .31091 .08833 .31072 .08922 .31518 .08769 .3165 Mtetra
.934 .679 .527 r
.08769 .3165 .08922 .31518 .0623 .5206 .06095 .52006 Mtetra
.906 .53 .307 r
.06095 .52006 .0623 .5206 .06319 .52583 .06196 .52438 Mtetra
.187 .474 .892 r
.06196 .52438 .06319 .52583 .06474 .52623 .06349 .52495 Mtetra
.642 .719 .904 r
.06349 .52495 .06474 .52623 .06645 .52553 .06518 .5244 Mtetra
.805 .767 .818 r
.06518 .5244 .06645 .52553 .0683 .52384 .06702 .52273 Mtetra
.908 .732 .652 r
.06702 .52273 .0683 .52384 .07045 .51987 .06948 .51654 Mtetra
.935 .684 .534 r
.06948 .51654 .07045 .51987 .07432 .50321 .09912 .31032 Mtetra
.526 .293 .504 r
.09912 .31032 .07432 .50321 .10213 .30914 .10142 .30453 Mtetra
.638 .482 .655 r
.10142 .30453 .10213 .30914 .10403 .30627 .10311 .30324 Mtetra
.598 .509 .725 r
.10311 .30324 .10403 .30627 .10577 .3046 .10469 .30275 Mtetra
.54 .576 .84 r
.10469 .30275 .10577 .3046 .10744 .30349 .10622 .30264 Mtetra
.659 .793 .947 r
.10622 .30264 .10744 .30349 .10905 .30282 .10782 .30205 Mtetra
.662 .812 .956 r
.10782 .30205 .10905 .30282 .11063 .30236 .10942 .30145 Mtetra
.649 .778 .943 r
.10942 .30145 .11063 .30236 .1122 .30198 .11101 .3009 Mtetra
.7 .756 .896 r
.11101 .3009 .1122 .30198 .11385 .30096 .11264 .30013 Mtetra
.617 .79 .964 r
.11264 .30013 .11385 .30096 .11549 .30011 .11422 .29967 Mtetra
.038 .575 .852 r
.11422 .29967 .11549 .30011 .11706 .29976 .11572 .29989 Mtetra
.886 .525 .356 r
.11572 .29989 .11706 .29976 .11833 .30168 .11665 .30441 Mtetra
.936 .678 .522 r
.11665 .30441 .11833 .30168 .11884 .30958 .0916 .50877 Mtetra
.521 .283 .495 r
.0916 .50877 .11884 .30958 .09442 .51051 .09259 .51378 Mtetra
.511 .146 .283 r
.09259 .51378 .09442 .51051 .09574 .51297 .09418 .51415 Mtetra
.047 0 0 r
.09418 .51415 .09574 .51297 .09728 .51374 .09589 .51354 Mtetra
.731 .939 .954 r
.09589 .51354 .09728 .51374 .0989 .51384 .09766 .51251 Mtetra
.64 .713 .9 r
.09766 .51251 .0989 .51384 .10058 .51352 .09937 .51196 Mtetra
.624 .671 .874 r
.09937 .51196 .10058 .51352 .1023 .51296 .10108 .51147 Mtetra
.642 .687 .877 r
.10108 .51147 .1023 .51296 .10403 .51227 .10279 .5109 Mtetra
.607 .695 .905 r
.10279 .5109 .10403 .51227 .1057 .51204 .10449 .51048 Mtetra
.671 .687 .856 r
.10449 .51048 .1057 .51204 .10739 .51165 .10623 .50974 Mtetra
.744 .671 .78 r
.10623 .50974 .10739 .51165 .10916 .51072 .10806 .50827 Mtetra
.861 .675 .649 r
.10806 .50827 .10916 .51072 .1112 .50751 .11041 .50262 Mtetra
.937 .683 .526 r
.11041 .50262 .1112 .50751 .11391 .49901 .13762 .29676 Mtetra
.526 .293 .503 r
.13762 .29676 .11391 .49901 .14058 .29593 .13993 .29062 Mtetra
.645 .474 .638 r
.13993 .29062 .14058 .29593 .14258 .29224 .14167 .289 Mtetra
.604 .503 .713 r
.14167 .289 .14258 .29224 .14435 .29039 .14329 .28841 Mtetra
.557 .572 .825 r
.14329 .28841 .14435 .29039 .14605 .28919 .14486 .28823 Mtetra
.621 .766 .949 r
.14486 .28823 .14605 .28919 .14768 .28846 .14646 .28777 Mtetra
.645 .83 .972 r
.14646 .28777 .14768 .28846 .14929 .288 .14808 .2872 Mtetra
.658 .809 .955 r
.14808 .2872 .14929 .288 .15088 .28765 .14971 .2866 Mtetra
.69 .763 .908 r
.14971 .2866 .15088 .28765 .1525 .28711 .15135 .28588 Mtetra
.689 .73 .882 r
.15135 .28588 .1525 .28711 .15413 .28646 .15299 .28513 Mtetra
.675 .71 .875 r
.15299 .28513 .15413 .28646 .15577 .28576 .15463 .28445 Mtetra
.695 .719 .867 r
.15463 .28445 .15577 .28576 .15745 .28467 .15628 .28365 Mtetra
.649 .759 .93 r
.15628 .28365 .15745 .28467 .15913 .2837 .1579 .2831 Mtetra
.275 .697 .969 r
.1579 .2831 .15913 .2837 .16074 .28319 .15946 .28315 Mtetra
.863 .453 .253 r
.15946 .28315 .16074 .28319 .16215 .28454 .16065 .28632 Mtetra
.942 .68 .512 r
.16065 .28632 .16215 .28454 .16311 .2897 .13841 .49036 Mtetra
.525 .286 .496 r
.13841 .49036 .16311 .2897 .14117 .49277 .13928 .49718 Mtetra
.553 .215 .35 r
.13928 .49718 .14117 .49277 .14245 .4962 .14086 .498 Mtetra
.188 0 0 r
.14086 .498 .14245 .4962 .14403 .49697 .14261 .49734 Mtetra
.668 .975 .864 r
.14261 .49734 .14403 .49697 .14571 .49694 .14443 .49612 Mtetra
.744 .83 .917 r
.14443 .49612 .14571 .49694 .14745 .49642 .14623 .49509 Mtetra
.703 .735 .875 r
.14623 .49509 .14745 .49642 .14923 .49558 .14801 .49421 Mtetra
.698 .726 .872 r
.14801 .49421 .14923 .49558 .15102 .49458 .14978 .49335 Mtetra
.68 .744 .9 r
.14978 .49335 .15102 .49458 .1528 .49373 .15155 .49261 Mtetra
.654 .757 .925 r
.15155 .49261 .1528 .49373 .15456 .49304 .1533 .49199 Mtetra
.626 .763 .944 r
.1533 .49199 .15456 .49304 .15631 .49245 .15505 .49147 Mtetra
.559 .756 .97 r
.15505 .49147 .15631 .49245 .15804 .49203 .15677 .49114 Mtetra
.521 .763 .985 r
.15677 .49114 .15804 .49203 .15976 .49172 .15848 .49088 Mtetra
.542 .782 .987 r
.15848 .49088 .15976 .49172 .16148 .49146 .16021 .49056 Mtetra
.502 .752 .985 r
.16021 .49056 .16148 .49146 .16314 .49169 .16192 .49035 Mtetra
.617 .706 .909 r
.16192 .49035 .16314 .49169 .16483 .49176 .16367 .48988 Mtetra
.718 .668 .8 r
.16367 .48988 .16483 .49176 .1666 .49107 .16549 .48868 Mtetra
.85 .676 .666 r
.16549 .48868 .1666 .49107 .16871 .48718 .16768 .48412 Mtetra
.945 .686 .514 r
.16768 .48412 .16871 .48718 .19247 .28116 .19153 .27809 Mtetra
.866 .657 .617 r
.19153 .27809 .19247 .28116 .19508 .27162 .1939 .27075 Mtetra
.857 .801 .795 r
.1939 .27075 .19508 .27162 .1969 .26941 .19572 .26864 Mtetra
.672 .823 .956 r
.19572 .26864 .1969 .26941 .19855 .26884 .19738 .26798 Mtetra
.519 .756 .982 r
.19738 .26798 .19855 .26884 .20015 .26876 .19899 .26774 Mtetra
.612 .755 .946 r
.19899 .26774 .20015 .26876 .20178 .26846 .20063 .2673 Mtetra
.671 .743 .905 r
.20063 .2673 .20178 .26846 .20343 .26787 .20229 .26664 Mtetra
.661 .728 .899 r
.20229 .26664 .20343 .26787 .20509 .26722 .20395 .26602 Mtetra
.691 .741 .889 r
.20395 .26602 .20509 .26722 .2068 .26616 .20563 .26527 Mtetra
.668 .796 .943 r
.20563 .26527 .2068 .26616 .20851 .26507 .20729 .26462 Mtetra
.31 .748 .967 r
.20729 .26462 .20851 .26507 .21016 .26457 .2089 .26454 Mtetra
.826 .377 .164 r
.2089 .26454 .21016 .26457 .21156 .26651 .21024 .26704 Mtetra
.948 .682 .499 r
.21024 .26704 .21156 .26651 .19281 .46814 .19117 .47114 Mtetra
.844 .522 .443 r
.19117 .47114 .19281 .46814 .19327 .48062 .19206 .47933 Mtetra
.55 .058 0 r
.19206 .47933 .19327 .48062 .19481 .48242 .1936 .48105 Mtetra
.505 .66 .931 r
.1936 .48105 .19481 .48242 .19656 .48212 .19533 .48096 Mtetra
.746 .773 .875 r
.19533 .48096 .19656 .48212 .1984 .48086 .19716 .47983 Mtetra
.895 .776 .723 r
.19716 .47983 .1984 .48086 .2004 .47808 .19923 .47632 Mtetra
.95 .689 .506 r
.19923 .47632 .2004 .47808 .20275 .47166 .2194 .28848 Mtetra
.581 .339 .515 r
.2194 .28848 .20275 .47166 .22445 .2663 .2238 .26012 Mtetra
.681 .489 .619 r
.2238 .26012 .22445 .2663 .22657 .2611 .22568 .25733 Mtetra
.613 .49 .689 r
.22568 .25733 .22657 .2611 .22839 .25898 .22737 .25656 Mtetra
.567 .537 .781 r
.22737 .25656 .22839 .25898 .23013 .25761 .22901 .25632 Mtetra
.58 .689 .916 r
.22901 .25632 .23013 .25761 .23183 .25675 .23066 .256 Mtetra
.644 .825 .97 r
.23066 .256 .23183 .25675 .2335 .25621 .23233 .25542 Mtetra
.652 .816 .962 r
.23233 .25542 .2335 .25621 .23515 .25582 .23401 .25481 Mtetra
.727 .786 .899 r
.23401 .25481 .23515 .25582 .23684 .25514 .23571 .25389 Mtetra
.733 .744 .86 r
.23571 .25389 .23684 .25514 .23855 .25424 .23743 .25286 Mtetra
.63 .692 .889 r
.23743 .25286 .23855 .25424 .24022 .25373 .2391 .25236 Mtetra
0 .019 .554 r
.2391 .25236 .24022 .25373 .24176 .25461 .24058 .25391 Mtetra
.953 .684 .49 r
.24058 .25391 .24176 .25461 .24296 .25926 .22451 .44653 Mtetra
.557 .313 .502 r
.22451 .44653 .24296 .25926 .226 .46364 .22429 .46793 Mtetra
.637 .295 .376 r
.22429 .46793 .226 .46364 .22734 .46814 .22585 .46995 Mtetra
.294 0 .009 r
.22585 .46995 .22734 .46814 .22899 .46921 .22763 .46956 Mtetra
.527 .919 .827 r
.22763 .46956 .22899 .46921 .23071 .46947 .22947 .46858 Mtetra
.715 .822 .931 r
.22947 .46858 .23071 .46947 .23248 .46925 .2313 .46767 Mtetra
.627 .677 .878 r
.2313 .46767 .23248 .46925 .23428 .46872 .2331 .46714 Mtetra
.638 .682 .875 r
.2331 .46714 .23428 .46872 .23609 .46802 .23491 .46655 Mtetra
.629 .696 .893 r
.23491 .46655 .23609 .46802 .23789 .46753 .23671 .46602 Mtetra
.64 .694 .884 r
.23671 .46602 .23789 .46753 .23967 .46723 .23852 .46543 Mtetra
.717 .681 .814 r
.23852 .46543 .23967 .46723 .24149 .46652 .24037 .46427 Mtetra
.826 .68 .702 r
.24037 .46427 .24149 .46652 .24343 .46448 .24241 .46105 Mtetra
.952 .687 .497 r
.24241 .46105 .24343 .46448 .24564 .45911 .26109 .26314 Mtetra
.554 .316 .509 r
.26109 .26314 .24564 .45911 .26481 .25327 .26426 .24526 Mtetra
.661 .457 .598 r
.26426 .24526 .26481 .25327 .26705 .24619 .26617 .24221 Mtetra
.617 .486 .68 r
.26617 .24221 .26705 .24619 .2689 .24386 .26789 .24133 Mtetra
.584 .539 .771 r
.26789 .24133 .2689 .24386 .27067 .24238 .26957 .24098 Mtetra
.579 .672 .903 r
.26957 .24098 .27067 .24238 .2724 .24137 .27124 .24068 Mtetra
.642 .839 .976 r
.27124 .24068 .2724 .24137 .27411 .24067 .27294 .24007 Mtetra
.637 .86 .984 r
.27294 .24007 .27411 .24067 .27581 .24014 .27465 .23946 Mtetra
.663 .847 .97 r
.27465 .23946 .27581 .24014 .2775 .23967 .27636 .23879 Mtetra
.688 .81 .94 r
.27636 .23879 .2775 .23967 .2792 .23914 .27807 .23804 Mtetra
.679 .763 .915 r
.27807 .23804 .2792 .23914 .2809 .23859 .27979 .23734 Mtetra
.644 .723 .906 r
.27979 .23734 .2809 .23859 .28261 .23794 .28149 .23677 Mtetra
.586 .72 .936 r
.28149 .23677 .28261 .23794 .28433 .23713 .28318 .23642 Mtetra
.526 .798 .995 r
.28318 .23642 .28433 .23713 .28606 .2363 .28486 .2361 Mtetra
.551 .905 .969 r
.28486 .2361 .28606 .2363 .28779 .23539 .28658 .23549 Mtetra
.671 .971 .908 r
.28658 .23549 .28779 .23539 .28953 .23443 .28832 .23444 Mtetra
.462 .886 .907 r
.28832 .23444 .28953 .23443 .29124 .23383 .29003 .23383 Mtetra
.578 .009 0 r
.29003 .23383 .29124 .23383 .29287 .23426 .29163 .23485 Mtetra
.929 .61 .417 r
.29163 .23485 .29287 .23426 .29429 .23755 .29235 .24735 Mtetra
.945 .669 .485 r
.29235 .24735 .29429 .23755 .28071 .44145 .27888 .44871 Mtetra
.623 .312 .423 r
.27888 .44871 .28071 .44145 .28192 .44918 .28048 .45136 Mtetra
.379 0 .111 r
.28048 .45136 .28192 .44918 .28361 .45059 .28229 .45115 Mtetra
.294 .769 .658 r
.28229 .45115 .28361 .45059 .28538 .45099 .28414 .45033 Mtetra
.715 .875 .956 r
.28414 .45033 .28538 .45099 .28718 .45085 .28601 .4494 Mtetra
.633 .703 .897 r
.28601 .4494 .28718 .45085 .28902 .45035 .28785 .44883 Mtetra
.645 .697 .884 r
.28785 .44883 .28902 .45035 .29087 .44966 .28969 .44821 Mtetra
.646 .708 .892 r
.28969 .44821 .29087 .44966 .29271 .44905 .29154 .44758 Mtetra
.632 .701 .896 r
.29154 .44758 .29271 .44905 .29454 .44877 .29338 .44702 Mtetra
.708 .689 .829 r
.29338 .44702 .29454 .44877 .29639 .44812 .29526 .44596 Mtetra
.806 .682 .728 r
.29526 .44596 .29639 .44812 .29831 .4464 .29725 .44337 Mtetra
.913 .681 .574 r
.29725 .44337 .29831 .4464 .30047 .44128 .29991 .43098 Mtetra
.95 .679 .488 r
.29991 .43098 .30047 .44128 .31631 .23559 .31574 .22656 Mtetra
.669 .456 .588 r
.31574 .22656 .31631 .23559 .31855 .22751 .31769 .22279 Mtetra
.614 .466 .656 r
.31769 .22279 .31855 .22751 .32031 .22647 .31945 .22177 Mtetra
.568 .435 .659 r
.31945 .22177 .32031 .22647 .32203 .22614 .32117 .22132 Mtetra
.55 .42 .656 r
.32117 .22132 .32203 .22614 .32376 .22549 .32288 .22106 Mtetra
.585 .453 .668 r
.32288 .22106 .32376 .22549 .3256 .22333 .32461 .22046 Mtetra
.612 .533 .741 r
.32461 .22046 .3256 .22333 .32742 .22146 .32635 .21985 Mtetra
.649 .671 .858 r
.32635 .21985 .32742 .22146 .32921 .22007 .32809 .21922 Mtetra
.667 .818 .956 r
.32809 .21922 .32921 .22007 .33095 .2194 .32983 .21855 Mtetra
.672 .816 .952 r
.32983 .21855 .33095 .2194 .33268 .21893 .33158 .21785 Mtetra
.678 .772 .921 r
.33158 .21785 .33268 .21893 .33441 .21848 .33332 .21714 Mtetra
.68 .723 .882 r
.33332 .21714 .33441 .21848 .33615 .21783 .33508 .21638 Mtetra
.668 .703 .873 r
.33508 .21638 .33615 .21783 .3379 .21714 .33682 .21567 Mtetra
.662 .698 .873 r
.33682 .21567 .3379 .21714 .33966 .21633 .33857 .215 Mtetra
.684 .728 .883 r
.33857 .215 .33966 .21633 .34144 .21519 .34033 .21423 Mtetra
.566 .76 .969 r
.34033 .21423 .34144 .21519 .34319 .21438 .34206 .21388 Mtetra
.291 0 0 r
.34206 .21388 .34319 .21438 .3449 .21437 .34373 .21462 Mtetra
.919 .565 .348 r
.34373 .21462 .3449 .21437 .34644 .21735 .34499 .22232 Mtetra
.956 .676 .466 r
.34499 .22232 .34644 .21735 .3364 .41954 .33461 .42899 Mtetra
.627 .326 .441 r
.33461 .42899 .3364 .41954 .33765 .42966 .33625 .43245 Mtetra
.428 .039 .196 r
.33625 .43245 .33765 .42966 .3395 .42961 .3381 .43235 Mtetra
.293 0 .124 r
.3381 .43235 .3395 .42961 .34139 .42871 .33999 .43157 Mtetra
.244 0 .112 r
.33999 .43157 .34139 .42871 .34328 .42791 .34189 .43052 Mtetra
.333 0 .131 r
.34189 .43052 .34328 .42791 .34506 .42897 .34377 .42996 Mtetra
.049 0 0 r
.34377 .42996 .34506 .42897 .34687 .42979 .34565 .42937 Mtetra
.603 .898 .987 r
.34565 .42937 .34687 .42979 .3487 .4302 .34754 .42868 Mtetra
.701 .721 .865 r
.34754 .42868 .3487 .4302 .35056 .42991 .34945 .42772 Mtetra
.682 .636 .797 r
.34945 .42772 .35056 .42991 .35245 .4294 .35136 .42671 Mtetra
.654 .582 .762 r
.35136 .42671 .35245 .4294 .35433 .42877 .35326 .42577 Mtetra
.546 .501 .757 r
.35326 .42577 .35433 .42877 .35621 .42842 .35513 .42563 Mtetra
.604 .549 .765 r
.35513 .42563 .35621 .42842 .35811 .42771 .35701 .42508 Mtetra
.715 .618 .747 r
.35701 .42508 .35811 .42771 .36004 .4263 .35895 .42355 Mtetra
.898 .685 .607 r
.35895 .42355 .36004 .4263 .36212 .42186 .36121 .41575 Mtetra
.96 .684 .468 r
.36121 .41575 .36212 .42186 .3653 .39536 .37354 .20623 Mtetra
.523 .29 .502 r
.37354 .20623 .3653 .39536 .37643 .20608 .37553 .20123 Mtetra
.626 .471 .652 r
.37553 .20123 .37643 .20608 .37825 .2045 .37733 .2 Mtetra
.581 .45 .667 r
.37733 .2 .37825 .2045 .38001 .20398 .3791 .19942 Mtetra
.55 .428 .666 r
.3791 .19942 .38001 .20398 .38176 .20401 .38085 .19917 Mtetra
.583 .443 .656 r
.38085 .19917 .38176 .20401 .38352 .20365 .38263 .19852 Mtetra
.578 .433 .648 r
.38263 .19852 .38352 .20365 .38529 .2031 .3844 .19789 Mtetra
.577 .431 .646 r
.3844 .19789 .38529 .2031 .38709 .20209 .38618 .19726 Mtetra
.582 .442 .656 r
.38618 .19726 .38709 .20209 .38894 .19984 .38796 .19662 Mtetra
.609 .514 .722 r
.38796 .19662 .38894 .19984 .39078 .19783 .38974 .19597 Mtetra
.646 .641 .831 r
.38974 .19597 .39078 .19783 .39261 .19618 .39152 .19531 Mtetra
.668 .817 .955 r
.39152 .19531 .39261 .19618 .3944 .19532 .39331 .19461 Mtetra
.663 .851 .972 r
.39331 .19461 .3944 .19532 .39618 .19468 .39509 .1939 Mtetra
.667 .838 .965 r
.39509 .1939 .39618 .19468 .39796 .19417 .39688 .1932 Mtetra
.667 .795 .944 r
.39688 .1932 .39796 .19417 .39974 .19362 .39867 .19251 Mtetra
.667 .768 .926 r
.39867 .19251 .39974 .19362 .40152 .19308 .40046 .19183 Mtetra
.666 .741 .906 r
.40046 .19183 .40152 .19308 .40331 .19252 .40225 .19114 Mtetra
.676 .722 .884 r
.40225 .19114 .40331 .19252 .4051 .19188 .40404 .19039 Mtetra
.668 .702 .872 r
.40404 .19039 .4051 .19188 .40689 .19118 .40584 .18967 Mtetra
.656 .693 .873 r
.40584 .18967 .40689 .19118 .40869 .19043 .40763 .189 Mtetra
.606 .687 .9 r
.40763 .189 .40869 .19043 .41049 .18958 .40941 .18857 Mtetra
.573 .756 .964 r
.40941 .18857 .41049 .18958 .41229 .18872 .4112 .1882 Mtetra
.497 .836 .998 r
.4112 .1882 .41229 .18872 .41409 .18788 .41298 .18782 Mtetra
.693 .972 .923 r
.41298 .18782 .41409 .18788 .4159 .18682 .4148 .18673 Mtetra
.605 .943 .937 r
.4148 .18673 .4159 .18682 .4177 .18601 .4166 .18586 Mtetra
.216 .733 .866 r
.4166 .18586 .4177 .18601 .41949 .18572 .41839 .18568 Mtetra
.877 .451 .187 r
.41839 .18568 .41949 .18572 .42119 .18782 .42002 .18981 Mtetra
.966 .679 .438 r
.42002 .18981 .42119 .18782 .42267 .19666 .41464 .39925 Mtetra
.521 .282 .493 r
.41464 .39925 .42267 .19666 .41765 .40148 .41636 .40477 Mtetra
.498 .123 .259 r
.41636 .40477 .41765 .40148 .41953 .40224 .41826 .40512 Mtetra
.326 0 .154 r
.41826 .40512 .41953 .40224 .42148 .4014 .4202 .40442 Mtetra
.248 0 .132 r
.4202 .40442 .42148 .4014 .42343 .40024 .42216 .40327 Mtetra
.325 0 .166 r
.42216 .40327 .42343 .40024 .42532 .40116 .4241 .4025 Mtetra
.123 0 0 r
.4241 .4025 .42532 .40116 .42721 .40211 .42604 .40182 Mtetra
.548 .902 .973 r
.42604 .40182 .42721 .40211 .42911 .40265 .42799 .40114 Mtetra
.626 .702 .899 r
.42799 .40114 .42911 .40265 .43105 .40233 .42993 .40058 Mtetra
.625 .665 .869 r
.42993 .40058 .43105 .40233 .43299 .40169 .43187 .40001 Mtetra
.639 .682 .874 r
.43187 .40001 .43299 .40169 .43494 .40092 .43382 .39938 Mtetra
.693 .721 .871 r
.43382 .39938 .43494 .40092 .43689 .40029 .43577 .39845 Mtetra
.699 .685 .833 r
.43577 .39845 .43689 .40029 .43884 .39968 .43773 .39741 Mtetra
.682 .632 .793 r
.43773 .39741 .43884 .39968 .44079 .39907 .43969 .39636 Mtetra
.562 .534 .782 r
.43969 .39636 .44079 .39907 .44273 .39879 .44164 .39611 Mtetra
.584 .549 .781 r
.44164 .39611 .44273 .39879 .44468 .3983 .44358 .39571 Mtetra
.681 .606 .766 r
.44358 .39571 .44468 .3983 .44664 .39726 .44555 .39455 Mtetra
.881 .685 .633 r
.44555 .39455 .44664 .39726 .44867 .39365 .44763 .38879 Mtetra
.968 .685 .44 r
.44763 .38879 .44867 .39365 .45086 .38265 .45453 .17745 Mtetra
.525 .291 .502 r
.45453 .17745 .45086 .38265 .45744 .17632 .45648 .17115 Mtetra
.653 .484 .642 r
.45648 .17115 .45744 .17632 .45931 .17399 .45834 .16936 Mtetra
.589 .453 .664 r
.45834 .16936 .45931 .17399 .46113 .17338 .46016 .16866 Mtetra
.553 .427 .662 r
.46016 .16866 .46113 .17338 .46295 .1731 .46199 .16836 Mtetra
.574 .44 .661 r
.46199 .16836 .46295 .1731 .46481 .17134 .46381 .16783 Mtetra
.6 .498 .709 r
.46381 .16783 .46481 .17134 .46667 .16933 .46564 .16719 Mtetra
.633 .608 .807 r
.46564 .16719 .46667 .16933 .46852 .16764 .46748 .16656 Mtetra
.662 .779 .935 r
.46748 .16656 .46852 .16764 .47036 .16662 .46931 .16587 Mtetra
.657 .85 .974 r
.46931 .16587 .47036 .16662 .47219 .16593 .47115 .16516 Mtetra
.66 .847 .972 r
.47115 .16516 .47219 .16593 .47403 .16536 .47298 .16445 Mtetra
.662 .816 .958 r
.47298 .16445 .47403 .16536 .47586 .16472 .47482 .16375 Mtetra
.66 .804 .952 r
.47482 .16375 .47586 .16472 .4777 .16404 .47666 .16307 Mtetra
.659 .801 .951 r
.47666 .16307 .4777 .16404 .47954 .16337 .4785 .16239 Mtetra
.66 .8 .95 r
.4785 .16239 .47954 .16337 .48138 .16269 .48034 .16171 Mtetra
.48034 .16171 .48138 .16269 .48322 .16201 .48219 .16103 Mtetra
.66 .799 .949 r
.48219 .16103 .48322 .16201 .48507 .16136 .48403 .16034 Mtetra
.66 .794 .946 r
.48403 .16034 .48507 .16136 .48691 .16077 .48588 .15966 Mtetra
.662 .775 .933 r
.48588 .15966 .48691 .16077 .48875 .16021 .48772 .15897 Mtetra
.663 .75 .915 r
.48772 .15897 .48875 .16021 .4906 .15965 .48957 .15828 Mtetra
.671 .73 .894 r
.48957 .15828 .4906 .15965 .49245 .15902 .49142 .15754 Mtetra
.668 .71 .879 r
.49142 .15754 .49245 .15902 .4943 .15833 .49327 .1568 Mtetra
.656 .698 .877 r
.49327 .1568 .4943 .15833 .49615 .15759 .49512 .15612 Mtetra
.613 .689 .897 r
.49512 .15612 .49615 .15759 .498 .15677 .49697 .15564 Mtetra
.568 .734 .953 r
.49697 .15564 .498 .15677 .49986 .15591 .49883 .15529 Mtetra
.494 .817 1 r
.49883 .15529 .49986 .15591 .50171 .15506 .50068 .15495 Mtetra
.428 .865 .916 r
.50068 .15495 .50171 .15506 .50357 .15427 .50254 .15439 Mtetra
.416 .864 .833 r
.50254 .15439 .50357 .15427 .50543 .15354 .5044 .15366 Mtetra
.445 .88 .837 r
.5044 .15366 .50543 .15354 .50729 .15282 .50626 .15288 Mtetra
.46 .888 .866 r
.50626 .15288 .50729 .15282 .50915 .15211 .50812 .15212 Mtetra
.46 .888 .879 r
.50812 .15212 .50915 .15211 .51101 .1514 .50998 .1514 Mtetra
.459 .887 .881 r
.50998 .1514 .51101 .1514 .51287 .15069 .51184 .15069 Mtetra
.458 .886 .883 r
.51184 .15069 .51287 .15069 .51473 .14999 .51371 .14998 Mtetra
.455 .885 .883 r
.51371 .14998 .51473 .14999 .5166 .14928 .51558 .14928 Mtetra
.451 .883 .882 r
.51558 .14928 .5166 .14928 .51846 .14858 .51744 .14859 Mtetra
.447 .881 .879 r
.51744 .14859 .51846 .14858 .52033 .14789 .51931 .1479 Mtetra
.442 .878 .876 r
.51931 .1479 .52033 .14789 .5222 .14719 .52118 .14721 Mtetra
.437 .876 .873 r
.52118 .14721 .5222 .14719 .52407 .1465 .52305 .14652 Mtetra
.433 .874 .869 r
.52305 .14652 .52407 .1465 .52594 .1458 .52493 .14583 Mtetra
.43 .872 .866 r
.52493 .14583 .52594 .1458 .52781 .14511 .5268 .14514 Mtetra
.427 .871 .863 r
.5268 .14514 .52781 .14511 .52969 .14442 .52868 .14445 Mtetra
.424 .869 .86 r
.52868 .14445 .52969 .14442 .53156 .14372 .53055 .14376 Mtetra
.422 .868 .858 r
.53055 .14376 .53156 .14372 .53344 .14303 .53243 .14307 Mtetra
.42 .867 .856 r
.53243 .14307 .53344 .14303 .53531 .14234 .53431 .14238 Mtetra
.418 .866 .855 r
.53431 .14238 .53531 .14234 .53719 .14164 .53619 .14169 Mtetra
.416 .865 .853 r
.53619 .14169 .53719 .14164 .53907 .14095 .53807 .141 Mtetra
.414 .864 .852 r
.53807 .141 .53907 .14095 .54095 .14027 .53995 .14032 Mtetra
.413 .863 .851 r
.53995 .14032 .54095 .14027 .54284 .13958 .54184 .13963 Mtetra
.414 .863 .852 r
.54184 .13963 .54284 .13958 .54472 .1389 .54372 .13894 Mtetra
.416 .865 .854 r
.54372 .13894 .54472 .1389 .54661 .13821 .54561 .13825 Mtetra
.419 .866 .857 r
.54561 .13825 .54661 .13821 .54849 .13752 .5475 .13756 Mtetra
.422 .868 .858 r
.5475 .13756 .54849 .13752 .55038 .13683 .54939 .13687 Mtetra
.423 .869 .859 r
.54939 .13687 .55038 .13683 .55227 .13614 .55128 .13617 Mtetra
.425 .869 .86 r
.55128 .13617 .55227 .13614 .55416 .13544 .55317 .13547 Mtetra
.426 .87 .86 r
.55317 .13547 .55416 .13544 .55605 .13474 .55507 .13477 Mtetra
.428 .871 .861 r
.55507 .13477 .55605 .13474 .55795 .13404 .55696 .13407 Mtetra
.429 .872 .861 r
.55696 .13407 .55795 .13404 .55984 .13334 .55886 .13336 Mtetra
.43 .872 .861 r
.55886 .13336 .55984 .13334 .56174 .13263 .56076 .13266 Mtetra
.431 .873 .862 r
.56076 .13266 .56174 .13263 .56363 .13192 .56265 .13195 Mtetra
.56265 .13195 .56363 .13192 .56553 .13121 .56455 .13124 Mtetra
.432 .873 .862 r
.56455 .13124 .56553 .13121 .56743 .1305 .56646 .13052 Mtetra
.56646 .13052 .56743 .1305 .56933 .12979 .56836 .12981 Mtetra
.433 .874 .862 r
.56836 .12981 .56933 .12979 .57124 .12907 .57026 .1291 Mtetra
.57026 .1291 .57124 .12907 .57314 .12836 .57217 .12838 Mtetra
.57217 .12838 .57314 .12836 .57504 .12764 .57407 .12766 Mtetra
.57407 .12766 .57504 .12764 .57695 .12693 .57598 .12695 Mtetra
.57598 .12695 .57695 .12693 .57886 .12621 .57789 .12623 Mtetra
.57789 .12623 .57886 .12621 .58077 .12549 .5798 .12551 Mtetra
.434 .874 .862 r
.5798 .12551 .58077 .12549 .58268 .12477 .58171 .12479 Mtetra
.58171 .12479 .58268 .12477 .58459 .12405 .58363 .12407 Mtetra
.58363 .12407 .58459 .12405 .5865 .12333 .58554 .12335 Mtetra
.58554 .12335 .5865 .12333 .58841 .12261 .58746 .12263 Mtetra
.58746 .12263 .58841 .12261 .59033 .12189 .58937 .1219 Mtetra
.58937 .1219 .59033 .12189 .59225 .12117 .59129 .12118 Mtetra
.59129 .12118 .59225 .12117 .59416 .12045 .59321 .12046 Mtetra
.59321 .12046 .59416 .12045 .59608 .11972 .59513 .11973 Mtetra
.434 .875 .862 r
.59513 .11973 .59608 .11972 .598 .119 .59706 .11901 Mtetra
.59706 .11901 .598 .119 .59993 .11827 .59898 .11828 Mtetra
.59898 .11828 .59993 .11827 .60185 .11755 .60091 .11756 Mtetra
.435 .875 .862 r
.60091 .11756 .60185 .11755 .60377 .11682 .60283 .11683 Mtetra
.435 .875 .863 r
.60283 .11683 .60377 .11682 .6057 .1161 .60476 .1161 Mtetra
.60476 .1161 .6057 .1161 .60763 .11537 .60669 .11538 Mtetra
.60669 .11538 .60763 .11537 .60956 .11464 .60862 .11465 Mtetra
.436 .875 .863 r
.60862 .11465 .60956 .11464 .61149 .11391 .61055 .11392 Mtetra
.436 .876 .863 r
.61055 .11392 .61149 .11391 .61342 .11318 .61248 .11318 Mtetra
.437 .876 .863 r
.61248 .11318 .61342 .11318 .61535 .11245 .61442 .11245 Mtetra
.438 .877 .864 r
.61442 .11245 .61535 .11245 .61728 .11172 .61635 .11172 Mtetra
.439 .877 .864 r
.61635 .11172 .61728 .11172 .61922 .11098 .61829 .11098 Mtetra
.441 .878 .865 r
.61829 .11098 .61922 .11098 .62115 .11025 .62023 .11024 Mtetra
.443 .879 .866 r
.62023 .11024 .62115 .11025 .62309 .10951 .62217 .1095 Mtetra
.446 .881 .868 r
.62217 .1095 .62309 .10951 .62503 .10876 .62411 .10875 Mtetra
.451 .883 .87 r
.62411 .10875 .62503 .10876 .62697 .10802 .62605 .108 Mtetra
.459 .887 .873 r
.62605 .108 .62697 .10802 .62891 .10726 .62799 .10723 Mtetra
.471 .893 .877 r
.62799 .10723 .62891 .10726 .63085 .10649 .62994 .10645 Mtetra
.474 .895 .882 r
.62994 .10645 .63085 .10649 .6328 .10572 .63188 .10568 Mtetra
.55 .93 .892 r
.63188 .10568 .6328 .10572 .63474 .10485 .63382 .10475 Mtetra
.673 .973 .903 r
.63382 .10475 .63474 .10485 .63667 .1038 .63575 .10356 Mtetra
.509 .899 .946 r
.63575 .10356 .63667 .1038 .63862 .10309 .6377 .10288 Mtetra
.335 0 0 r
.6377 .10288 .63862 .10309 .64061 .10338 .63972 .10371 Mtetra
.935 .561 .249 r
.63972 .10371 .64061 .10338 .64274 .10694 .64215 .115 Mtetra
.97 .658 .36 r
.64215 .115 .64274 .10694 .65329 .31636 .65258 .32273 Mtetra
.629 .292 .38 r
.65258 .32273 .65329 .31636 .6557 .32302 .65483 .32557 Mtetra
.387 0 .147 r
.65483 .32557 .6557 .32302 .65783 .32293 .65696 .32528 Mtetra
.249 0 .076 r
.65696 .32528 .65783 .32293 .65992 .3218 .65906 .32433 Mtetra
.225 0 .089 r
.65906 .32433 .65992 .3218 .662 .32025 .66116 .32316 Mtetra
.328 0 .162 r
.66116 .32316 .662 .32025 .66409 .31912 .66327 .32238 Mtetra
.347 0 .196 r
.66327 .32238 .66409 .31912 .6662 .31825 .66539 .32158 Mtetra
.352 0 .203 r
.66539 .32158 .6662 .31825 .66834 .31811 .6675 .3208 Mtetra
.319 0 .138 r
.6675 .3208 .66834 .31811 .67053 .31904 .66962 .32005 Mtetra
.055 0 0 r
.66962 .32005 .67053 .31904 .67272 .31973 .67174 .31931 Mtetra
.49 .871 .975 r
.67174 .31931 .67272 .31973 .67489 .32003 .67387 .31873 Mtetra
.494 .696 .959 r
.67387 .31873 .67489 .32003 .67704 .31985 .67602 .31858 Mtetra
.629 .764 .944 r
.67602 .31858 .67704 .31985 .67916 .31912 .67815 .31794 Mtetra
.839 .841 .846 r
.67815 .31794 .67916 .31912 .68124 .31738 .68022 .31599 Mtetra
.977 .764 .549 r
.68022 .31599 .68124 .31738 .68316 .31246 .68197 .30767 Mtetra
.976 .671 .349 r
.68197 .30767 .68316 .31246 .67463 .1036 .67322 .09306 Mtetra
.675 .448 .569 r
.67322 .09306 .67463 .1036 .6761 .09298 .67498 .08823 Mtetra
.619 .473 .661 r
.67498 .08823 .6761 .09298 .67799 .09043 .67694 .08707 Mtetra
.583 .5 .727 r
.67694 .08707 .67799 .09043 .67992 .08883 .67893 .08658 Mtetra
.555 .566 .82 r
.67893 .08658 .67992 .08883 .68188 .08771 .68094 .08636 Mtetra
.654 .742 .914 r
.68094 .08636 .68188 .08771 .68385 .08687 .68292 .08566 Mtetra
.66 .772 .932 r
.68292 .08566 .68385 .08687 .68584 .08619 .68491 .08493 Mtetra
.683 .771 .918 r
.68491 .08493 .68584 .08619 .68783 .0855 .68689 .0841 Mtetra
.76 .774 .864 r
.68689 .0841 .68783 .0855 .68978 .08422 .68884 .08278 Mtetra
.69 .743 .891 r
.68884 .08278 .68978 .08422 .69176 .08338 .69082 .08189 Mtetra
.451 .617 .921 r
.69082 .08189 .69176 .08338 .6938 .08356 .69285 .08198 Mtetra
.762 .359 0 r
.69285 .08198 .6938 .08356 .6962 .08974 .6952 .08733 Mtetra
.972 .661 .306 r
.6952 .08733 .6962 .08974 .71097 .30369 .70993 .30149 Mtetra
0 0 .391 r
.70993 .30149 .71097 .30369 .71341 .30777 .71239 .30602 Mtetra
.395 .561 .9 r
.71239 .30602 .71341 .30777 .71561 .30785 .71461 .30636 Mtetra
.669 .746 .908 r
.71461 .30636 .71561 .30785 .71775 .30687 .71676 .30552 Mtetra
.851 .821 .818 r
.71676 .30552 .71775 .30687 .71983 .30481 .71883 .30333 Mtetra
.975 .77 .563 r
.71883 .30333 .71983 .30481 .72174 .30018 .72056 .29586 Mtetra
.975 .667 .329 r
.72056 .29586 .72174 .30018 .71091 .0957 .70908 .08021 Mtetra
.642 .408 .548 r
.70908 .08021 .71091 .0957 .71194 .07968 .71078 .07474 Mtetra
.623 .471 .655 r
.71078 .07474 .71194 .07968 .71381 .07696 .71275 .07347 Mtetra
.59 .499 .72 r
.71275 .07347 .71381 .07696 .71576 .07527 .71477 .0729 Mtetra
.555 .555 .809 r
.71477 .0729 .71576 .07527 .71773 .07409 .71681 .07269 Mtetra
.667 .741 .905 r
.71681 .07269 .71773 .07409 .71973 .07321 .71881 .07191 Mtetra
.664 .759 .921 r
.71881 .07191 .71973 .07321 .72174 .0725 .72082 .07116 Mtetra
.653 .747 .918 r
.72082 .07116 .72174 .0725 .72375 .07183 .72283 .07045 Mtetra
.704 .76 .896 r
.72283 .07045 .72375 .07183 .72572 .07041 .72483 .06948 Mtetra
.607 .814 .98 r
.72483 .06948 .72572 .07041 .72771 .0694 .72685 .0689 Mtetra
.151 .644 .915 r
.72685 .0689 .72771 .0694 .72976 .06914 .72893 .06908 Mtetra
.928 .672 .53 r
.08472 .31735 .08697 .31091 .08769 .3165 .05835 .51687 Mtetra
.52 .282 .494 r
.05835 .51687 .08769 .3165 .06095 .52006 .0593 .52161 Mtetra
.699 .299 .286 r
.0593 .52161 .06095 .52006 .06196 .52438 .06066 .52339 Mtetra
.171 .563 .933 r
.06066 .52339 .06196 .52438 .06349 .52495 .06222 .52376 Mtetra
.634 .731 .918 r
.06222 .52376 .06349 .52495 .06518 .5244 .06391 .52324 Mtetra
.793 .763 .826 r
.06391 .52324 .06518 .5244 .06702 .52273 .06574 .52168 Mtetra
.913 .733 .645 r
.06574 .52168 .06702 .52273 .06948 .51654 .06826 .51503 Mtetra
.937 .686 .533 r
.06826 .51503 .06948 .51654 .09912 .31032 .09804 .30842 Mtetra
.874 .691 .652 r
.09804 .30842 .09912 .31032 .10142 .30453 .10029 .303 Mtetra
.736 .695 .811 r
.10029 .303 .10142 .30453 .10311 .30324 .10197 .30185 Mtetra
.6 .671 .89 r
.10197 .30185 .10311 .30324 .10469 .30275 .10353 .30149 Mtetra
.453 .636 .934 r
.10353 .30149 .10469 .30275 .10622 .30264 .10504 .30152 Mtetra
.684 .746 .899 r
.10504 .30152 .10622 .30264 .10782 .30205 .10665 .30083 Mtetra
.672 .724 .889 r
.10665 .30083 .10782 .30205 .10942 .30145 .10826 .30018 Mtetra
.609 .696 .906 r
.10826 .30018 .10942 .30145 .11101 .3009 .10983 .29978 Mtetra
.187 .529 .922 r
.10983 .29978 .11101 .3009 .11264 .30013 .1113 .3002 Mtetra
.71 .202 .024 r
.1113 .3002 .11264 .30013 .11422 .29967 .11265 .30155 Mtetra
.795 .447 .397 r
.11265 .30155 .11422 .29967 .11572 .29989 .11367 .30536 Mtetra
.932 .674 .523 r
.11367 .30536 .11572 .29989 .11665 .30441 .08892 .50603 Mtetra
.521 .283 .495 r
.08892 .50603 .11665 .30441 .0916 .50877 .08984 .51144 Mtetra
.674 .309 .346 r
.08984 .51144 .0916 .50877 .09259 .51378 .09123 .51339 Mtetra
.316 .765 .959 r
.09123 .51339 .09259 .51378 .09418 .51415 .09288 .51325 Mtetra
.696 .804 .932 r
.09288 .51325 .09418 .51415 .09589 .51354 .09462 .51247 Mtetra
.738 .779 .886 r
.09462 .51247 .09589 .51354 .09766 .51251 .09639 .51144 Mtetra
.56 .735 .957 r
.09639 .51144 .09766 .51251 .09937 .51196 .09807 .51114 Mtetra
.531 .779 .988 r
.09807 .51114 .09937 .51196 .10108 .51147 .09975 .51085 Mtetra
.637 .851 .982 r
.09975 .51085 .10108 .51147 .10279 .5109 .10147 .51024 Mtetra
.831 .846 .858 r
.10147 .51024 .10279 .5109 .10449 .51048 .10332 .50859 Mtetra
.819 .693 .725 r
.10332 .50859 .10449 .51048 .10623 .50974 .10532 .50583 Mtetra
.809 .614 .638 r
.10532 .50583 .10623 .50974 .10806 .50827 .10762 .50058 Mtetra
.934 .679 .528 r
.10762 .50058 .10806 .50827 .11041 .50262 .13456 .29839 Mtetra
.527 .293 .503 r
.13456 .29839 .11041 .50262 .13762 .29676 .13693 .29175 Mtetra
.714 .528 .636 r
.13693 .29175 .13762 .29676 .13993 .29062 .13884 .2888 Mtetra
.712 .657 .793 r
.13884 .2888 .13993 .29062 .14167 .289 .14052 .28771 Mtetra
.614 .697 .903 r
.14052 .28771 .14167 .289 .14329 .28841 .14212 .28729 Mtetra
.514 .692 .949 r
.14212 .28729 .14329 .28841 .14486 .28823 .14369 .28715 Mtetra
.619 .738 .931 r
.14369 .28715 .14486 .28823 .14646 .28777 .14529 .28671 Mtetra
.661 .753 .918 r
.14529 .28671 .14646 .28777 .14808 .2872 .14691 .28611 Mtetra
.677 .752 .907 r
.14691 .28611 .14808 .2872 .14971 .2866 .14855 .28543 Mtetra
.731 .75 .868 r
.14855 .28543 .14971 .2866 .15135 .28588 .15022 .28446 Mtetra
.712 .707 .843 r
.15022 .28446 .15135 .28588 .15299 .28513 .15188 .28353 Mtetra
.658 .663 .844 r
.15188 .28353 .15299 .28513 .15463 .28445 .15352 .28288 Mtetra
.415 .561 .892 r
.15352 .28288 .15463 .28445 .15628 .28365 .15505 .28309 Mtetra
.59 .022 0 r
.15505 .28309 .15628 .28365 .1579 .2831 .15647 .28426 Mtetra
.801 .42 .336 r
.15647 .28426 .1579 .2831 .15946 .28315 .15766 .28736 Mtetra
.938 .676 .513 r
.15766 .28736 .15946 .28315 .16065 .28632 .1357 .48742 Mtetra
.526 .287 .496 r
.1357 .48742 .16065 .28632 .13841 .49036 .1365 .49484 Mtetra
.649 .317 .396 r
.1365 .49484 .13841 .49036 .13928 .49718 .13791 .49711 Mtetra
0 .572 .729 r
.13791 .49711 .13928 .49718 .14086 .498 .13958 .49716 Mtetra
.717 .822 .931 r
.13958 .49716 .14086 .498 .14261 .49734 .14136 .49627 Mtetra
.773 .786 .864 r
.14136 .49627 .14261 .49734 .14443 .49612 .14318 .49497 Mtetra
.738 .769 .878 r
.14318 .49497 .14443 .49612 .14623 .49509 .14498 .49391 Mtetra
.706 .757 .892 r
.14498 .49391 .14623 .49509 .14801 .49421 .14676 .49303 Mtetra
.693 .757 .901 r
.14676 .49303 .14801 .49421 .14978 .49335 .14853 .49223 Mtetra
.667 .762 .921 r
.14853 .49223 .14978 .49335 .15155 .49261 .15029 .49156 Mtetra
.637 .767 .942 r
.15029 .49156 .15155 .49261 .1533 .49199 .15204 .491 Mtetra
.609 .772 .958 r
.15204 .491 .1533 .49199 .15505 .49147 .15378 .49053 Mtetra
.487 .739 .983 r
.15378 .49053 .15505 .49147 .15677 .49114 .15548 .49036 Mtetra
.465 .764 .995 r
.15548 .49036 .15677 .49114 .15848 .49088 .15719 .49018 Mtetra
.601 .829 .987 r
.15719 .49018 .15848 .49088 .16021 .49056 .15894 .48967 Mtetra
.796 .818 .87 r
.15894 .48967 .16021 .49056 .16192 .49035 .16079 .48826 Mtetra
.804 .679 .726 r
.16079 .48826 .16192 .49035 .16367 .48988 .16276 .48569 Mtetra
.794 .6 .638 r
.16276 .48569 .16367 .48988 .16549 .48868 .16498 .48088 Mtetra
.94 .68 .517 r
.16498 .48088 .16549 .48868 .16768 .48412 .18846 .27993 Mtetra
.529 .295 .504 r
.18846 .27993 .16768 .48412 .19153 .27809 .19087 .27231 Mtetra
.705 .511 .623 r
.19087 .27231 .19153 .27809 .1939 .27075 .19281 .26911 Mtetra
.76 .695 .79 r
.19281 .26911 .1939 .27075 .19572 .26864 .19455 .26766 Mtetra
.664 .774 .931 r
.19455 .26766 .19572 .26864 .19738 .26798 .19621 .26703 Mtetra
.574 .757 .965 r
.19621 .26703 .19738 .26798 .19899 .26774 .19783 .26669 Mtetra
.662 .761 .923 r
.19783 .26669 .19899 .26774 .20063 .2673 .19949 .26608 Mtetra
.691 .736 .885 r
.19949 .26608 .20063 .2673 .20229 .26664 .20116 .26531 Mtetra
.639 .702 .892 r
.20116 .26531 .20229 .26664 .20395 .26602 .20282 .26478 Mtetra
.411 .623 .94 r
.20282 .26478 .20395 .26602 .20563 .26527 .2044 .2649 Mtetra
.561 0 0 r
.2044 .2649 .20563 .26527 .20729 .26462 .20589 .26595 Mtetra
.777 .387 .316 r
.20589 .26595 .20729 .26462 .2089 .26454 .2072 .26873 Mtetra
.943 .677 .502 r
.2072 .26873 .2089 .26454 .21024 .26704 .18851 .46728 Mtetra
.529 .29 .496 r
.18851 .46728 .21024 .26704 .19117 .47114 .18929 .47636 Mtetra
.651 .326 .408 r
.18929 .47636 .19117 .47114 .19206 .47933 .19074 .47897 Mtetra
.503 0 0 r
.19074 .47897 .19206 .47933 .1936 .48105 .19236 .47994 Mtetra
.438 .683 .967 r
.19236 .47994 .1936 .48105 .19533 .48096 .19408 .47993 Mtetra
.715 .793 .913 r
.19408 .47993 .19533 .48096 .19716 .47983 .1959 .47902 Mtetra
.905 .799 .733 r
.1959 .47902 .19716 .47983 .19923 .47632 .19796 .47564 Mtetra
.951 .69 .505 r
.19796 .47564 .19923 .47632 .2194 .28848 .21871 .28266 Mtetra
.9 .651 .552 r
.21871 .28266 .2194 .28848 .2238 .26012 .2227 .25856 Mtetra
.842 .721 .73 r
.2227 .25856 .2238 .26012 .22568 .25733 .22458 .25584 Mtetra
.658 .685 .863 r
.22458 .25584 .22568 .25733 .22737 .25656 .22625 .2552 Mtetra
.508 .646 .918 r
.22625 .2552 .22737 .25656 .22901 .25632 .22788 .25511 Mtetra
.542 .691 .937 r
.22788 .25511 .22901 .25632 .23066 .256 .22951 .2549 Mtetra
.653 .751 .922 r
.22951 .2549 .23066 .256 .23233 .25542 .23119 .25432 Mtetra
.669 .756 .916 r
.23119 .25432 .23233 .25542 .23401 .25481 .23287 .25366 Mtetra
.741 .763 .871 r
.23287 .25366 .23401 .25481 .23571 .25389 .23459 .25261 Mtetra
.752 .745 .846 r
.23459 .25261 .23571 .25389 .23743 .25286 .23632 .25144 Mtetra
.655 .696 .876 r
.23632 .25144 .23743 .25286 .2391 .25236 .23801 .25082 Mtetra
0 .082 .628 r
.23801 .25082 .2391 .25236 .24058 .25391 .23949 .25231 Mtetra
.954 .686 .489 r
.23949 .25231 .24058 .25391 .22451 .44653 .22349 .44331 Mtetra
.972 .685 .423 r
.22349 .44331 .22451 .44653 .22429 .46793 .22303 .46723 Mtetra
.74 .219 0 r
.22303 .46723 .22429 .46793 .22585 .46995 .22459 .46921 Mtetra
.604 .827 .985 r
.22459 .46921 .22585 .46995 .22763 .46956 .22639 .46868 Mtetra
.757 .829 .908 r
.22639 .46868 .22763 .46956 .22947 .46858 .22824 .46755 Mtetra
.703 .794 .921 r
.22824 .46755 .22947 .46858 .2313 .46767 .23007 .46669 Mtetra
.532 .753 .977 r
.23007 .46669 .2313 .46767 .2331 .46714 .23184 .46641 Mtetra
.593 .828 .989 r
.23184 .46641 .2331 .46714 .23491 .46655 .23364 .46591 Mtetra
.771 .875 .923 r
.23364 .46591 .23491 .46655 .23671 .46602 .2355 .46472 Mtetra
.84 .763 .777 r
.2355 .46472 .23671 .46602 .23852 .46543 .23746 .46241 Mtetra
.813 .64 .668 r
.23746 .46241 .23852 .46543 .24037 .46427 .23956 .45851 Mtetra
.886 .641 .563 r
.23956 .45851 .24037 .46427 .24241 .46105 .24284 .44082 Mtetra
.933 .665 .508 r
.24284 .44082 .24241 .46105 .26109 .26314 .26128 .24653 Mtetra
.612 .39 .555 r
.26128 .24653 .26109 .26314 .26426 .24526 .26326 .24261 Mtetra
.738 .612 .717 r
.26326 .24261 .26426 .24526 .26617 .24221 .26507 .24074 Mtetra
.656 .691 .871 r
.26507 .24074 .26617 .24221 .26789 .24133 .26677 .24011 Mtetra
.56 .698 .933 r
.26677 .24011 .26789 .24133 .26957 .24098 .26844 .23985 Mtetra
.562 .717 .945 r
.26844 .23985 .26957 .24098 .27124 .24068 .27011 .23956 Mtetra
.655 .752 .921 r
.27011 .23956 .27124 .24068 .27294 .24007 .27182 .23895 Mtetra
.67 .756 .915 r
.27182 .23895 .27294 .24007 .27465 .23946 .27353 .23829 Mtetra
.704 .755 .892 r
.27353 .23829 .27465 .23946 .27636 .23879 .27525 .23745 Mtetra
.723 .732 .858 r
.27525 .23745 .27636 .23879 .27807 .23804 .27699 .23645 Mtetra
.677 .681 .846 r
.27699 .23645 .27807 .23804 .27979 .23734 .27871 .23567 Mtetra
.526 .606 .876 r
.27871 .23567 .27979 .23734 .28149 .23677 .28037 .23558 Mtetra
0 .183 .687 r
.28037 .23558 .28149 .23677 .28318 .23642 .28194 .23677 Mtetra
.798 .348 .176 r
.28194 .23677 .28318 .23642 .28486 .2361 .28341 .2392 Mtetra
.713 .357 .372 r
.28341 .2392 .28486 .2361 .28658 .23549 .28485 .24209 Mtetra
.387 .093 .339 r
.28485 .24209 .28658 .23549 .28832 .23444 .28662 .24086 Mtetra
.406 .108 .343 r
.28662 .24086 .28832 .23444 .29003 .23383 .28836 .23987 Mtetra
.725 .408 .443 r
.28836 .23987 .29003 .23383 .29163 .23485 .28964 .24507 Mtetra
.944 .669 .486 r
.28964 .24507 .29163 .23485 .29235 .24735 .27606 .44544 Mtetra
.518 .28 .493 r
.27606 .44544 .29235 .24735 .27888 .44871 .27755 .44936 Mtetra
.648 .148 .048 r
.27755 .44936 .27888 .44871 .28048 .45136 .27924 .45066 Mtetra
.524 .812 .998 r
.27924 .45066 .28048 .45136 .28229 .45115 .28106 .45029 Mtetra
.68 .827 .954 r
.28106 .45029 .28229 .45115 .28414 .45033 .28292 .44952 Mtetra
.681 .837 .958 r
.28292 .44952 .28414 .45033 .28601 .4494 .28477 .44874 Mtetra
.541 .827 .998 r
.28477 .44874 .28601 .4494 .28785 .44883 .2866 .44832 Mtetra
.609 .878 .991 r
.2866 .44832 .28785 .44883 .28969 .44821 .28845 .44768 Mtetra
.759 .903 .941 r
.28845 .44768 .28969 .44821 .29154 .44758 .29034 .44652 Mtetra
.852 .803 .802 r
.29034 .44652 .29154 .44758 .29338 .44702 .2923 .44434 Mtetra
.818 .657 .683 r
.2923 .44434 .29338 .44702 .29526 .44596 .29435 .4408 Mtetra
.849 .62 .591 r
.29435 .4408 .29526 .44596 .29725 .44337 .29682 .4313 Mtetra
.948 .677 .49 r
.29682 .4313 .29725 .44337 .29991 .43098 .31276 .22805 Mtetra
.521 .288 .502 r
.31276 .22805 .29991 .43098 .31574 .22656 .31476 .22353 Mtetra
.749 .601 .693 r
.31476 .22353 .31574 .22656 .31769 .22279 .31661 .22124 Mtetra
.698 .696 .844 r
.31661 .22124 .31769 .22279 .31945 .22177 .31836 .22033 Mtetra
.626 .688 .888 r
.31836 .22033 .31945 .22177 .32117 .22132 .32009 .21983 Mtetra
.586 .662 .891 r
.32009 .21983 .32117 .22132 .32288 .22106 .3218 .21949 Mtetra
.617 .664 .873 r
.3218 .21949 .32288 .22106 .32461 .22046 .32353 .21903 Mtetra
.62 .687 .892 r
.32353 .21903 .32461 .22046 .32635 .21985 .32526 .21855 Mtetra
.644 .719 .903 r
.32526 .21855 .32635 .21985 .32809 .21922 .32699 .21798 Mtetra
.693 .744 .891 r
.32699 .21798 .32809 .21922 .32983 .21855 .32874 .21717 Mtetra
.697 .724 .871 r
.32874 .21717 .32983 .21855 .33158 .21785 .3305 .21632 Mtetra
.694 .7 .851 r
.3305 .21632 .33158 .21785 .33332 .21714 .33226 .21545 Mtetra
.693 .678 .831 r
.33226 .21545 .33332 .21714 .33508 .21638 .33402 .21454 Mtetra
.655 .643 .827 r
.33402 .21454 .33508 .21638 .33682 .21567 .33577 .21384 Mtetra
.577 .609 .848 r
.33577 .21384 .33682 .21567 .33857 .215 .33749 .21355 Mtetra
.209 .472 .887 r
.33749 .21355 .33857 .215 .34033 .21423 .33916 .21417 Mtetra
.725 .202 0 r
.33916 .21417 .34033 .21423 .34206 .21388 .34077 .2159 Mtetra
.843 .487 .38 r
.34077 .2159 .34206 .21388 .34373 .21462 .34213 .22177 Mtetra
.953 .673 .469 r
.34213 .22177 .34373 .21462 .34499 .22232 .3317 .42603 Mtetra
.518 .28 .493 r
.3317 .42603 .34499 .22232 .33461 .42899 .33329 .43022 Mtetra
.658 .201 .156 r
.33329 .43022 .33461 .42899 .33625 .43245 .33505 .43171 Mtetra
.478 .787 .998 r
.33505 .43171 .33625 .43245 .3381 .43235 .33691 .43145 Mtetra
.663 .819 .958 r
.33691 .43145 .3381 .43235 .33999 .43157 .33879 .43073 Mtetra
.702 .841 .949 r
.33879 .43073 .33999 .43157 .34189 .43052 .34069 .42984 Mtetra
.537 .826 .999 r
.34069 .42984 .34189 .43052 .34377 .42996 .34256 .42942 Mtetra
.595 .873 .993 r
.34256 .42942 .34377 .42996 .34565 .42937 .34445 .4288 Mtetra
.732 .901 .954 r
.34445 .4288 .34565 .42937 .34754 .42868 .34636 .42775 Mtetra
.879 .826 .792 r
.34636 .42775 .34754 .42868 .34945 .42772 .34834 .42529 Mtetra
.834 .678 .69 r
.34834 .42529 .34945 .42772 .35136 .42671 .35039 .42174 Mtetra
.783 .579 .624 r
.35039 .42174 .35136 .42671 .35326 .42577 .35251 .41672 Mtetra
.539 .363 .591 r
.35251 .41672 .35326 .42577 .35513 .42563 .35438 .41636 Mtetra
.526 .351 .587 r
.35438 .41636 .35513 .42563 .35701 .42508 .35624 .41626 Mtetra
.614 .42 .595 r
.35624 .41626 .35701 .42508 .35895 .42355 .35821 .4142 Mtetra
.956 .68 .472 r
.35821 .4142 .35895 .42355 .36121 .41575 .37052 .20889 Mtetra
.525 .291 .502 r
.37052 .20889 .36121 .41575 .37354 .20623 .37258 .20264 Mtetra
.763 .59 .663 r
.37258 .20264 .37354 .20623 .37553 .20123 .37447 .1996 Mtetra
.712 .696 .833 r
.37447 .1996 .37553 .20123 .37733 .2 .37626 .19858 Mtetra
.645 .702 .888 r
.37626 .19858 .37733 .2 .3791 .19942 .37803 .19798 Mtetra
.596 .679 .899 r
.37803 .19798 .3791 .19942 .38085 .19917 .37979 .19759 Mtetra
.658 .683 .862 r
.37979 .19759 .38085 .19917 .38263 .19852 .38157 .19691 Mtetra
.654 .676 .859 r
.38157 .19691 .38263 .19852 .3844 .19789 .38335 .19625 Mtetra
.647 .669 .858 r
.38335 .19625 .3844 .19789 .38618 .19726 .38513 .19562 Mtetra
.621 .659 .865 r
.38513 .19562 .38618 .19726 .38796 .19662 .3869 .19511 Mtetra
.623 .681 .884 r
.3869 .19511 .38796 .19662 .38974 .19597 .38867 .19461 Mtetra
.636 .711 .901 r
.38867 .19461 .38974 .19597 .39152 .19531 .39045 .19406 Mtetra
.691 .749 .896 r
.39045 .19406 .39152 .19531 .39331 .19461 .39224 .19325 Mtetra
.697 .732 .878 r
.39224 .19325 .39331 .19461 .39509 .1939 .39403 .19239 Mtetra
.691 .706 .859 r
.39403 .19239 .39509 .1939 .39688 .1932 .39583 .19153 Mtetra
.664 .675 .85 r
.39583 .19153 .39688 .1932 .39867 .19251 .39762 .1908 Mtetra
.657 .665 .846 r
.39762 .1908 .39867 .19251 .40046 .19183 .39941 .1901 Mtetra
.654 .662 .845 r
.39941 .1901 .40046 .19183 .40225 .19114 .4012 .18941 Mtetra
.688 .676 .833 r
.4012 .18941 .40225 .19114 .40404 .19039 .403 .18852 Mtetra
.661 .647 .826 r
.403 .18852 .40404 .19039 .40584 .18967 .4048 .18776 Mtetra
.609 .62 .837 r
.4048 .18776 .40584 .18967 .40763 .189 .40658 .1873 Mtetra
.224 .437 .858 r
.40658 .1873 .40763 .189 .40941 .18857 .40832 .18805 Mtetra
.647 .097 0 r
.40832 .18805 .40941 .18857 .4112 .1882 .41003 .18973 Mtetra
.779 .372 .282 r
.41003 .18973 .4112 .1882 .41298 .18782 .41168 .19287 Mtetra
.438 .117 .323 r
.41168 .19287 .41298 .18782 .4148 .18673 .41348 .19243 Mtetra
.372 .07 .318 r
.41348 .19243 .4148 .18673 .4166 .18586 .4153 .19118 Mtetra
.465 .146 .339 r
.4153 .19118 .4166 .18586 .41839 .18568 .41709 .19099 Mtetra
.962 .674 .443 r
.41709 .19099 .41839 .18568 .42002 .18981 .41172 .39418 Mtetra
.524 .285 .494 r
.41172 .39418 .42002 .18981 .41464 .39925 .41337 .40167 Mtetra
.702 .306 .295 r
.41337 .40167 .41464 .39925 .41636 .40477 .4152 .40416 Mtetra
.281 .714 .967 r
.4152 .40416 .41636 .40477 .41826 .40512 .41711 .40417 Mtetra
.649 .814 .963 r
.41711 .40417 .41826 .40512 .4202 .40442 .41905 .40348 Mtetra
.724 .836 .934 r
.41905 .40348 .4202 .40442 .42216 .40327 .421 .40247 Mtetra
.692 .857 .961 r
.421 .40247 .42216 .40327 .4241 .4025 .42295 .4016 Mtetra
.689 .833 .952 r
.42295 .4016 .4241 .4025 .42604 .40182 .4249 .40075 Mtetra
.679 .798 .938 r
.4249 .40075 .42604 .40182 .42799 .40114 .42685 .39994 Mtetra
.55 .727 .957 r
.42685 .39994 .42799 .40114 .42993 .40058 .42878 .39964 Mtetra
.54 .776 .985 r
.42878 .39964 .42993 .40058 .43187 .40001 .43072 .39929 Mtetra
.633 .855 .984 r
.43072 .39929 .43187 .40001 .43382 .39938 .43267 .3986 Mtetra
.873 .867 .83 r
.43267 .3986 .43382 .39938 .43577 .39845 .43466 .39644 Mtetra
.858 .717 .705 r
.43466 .39644 .43577 .39845 .43773 .39741 .43669 .39299 Mtetra
.815 .608 .622 r
.43669 .39299 .43773 .39741 .43969 .39636 .43877 .38746 Mtetra
.604 .412 .595 r
.43877 .38746 .43969 .39636 .44164 .39611 .44075 .38562 Mtetra
.511 .334 .577 r
.44075 .38562 .44164 .39611 .44358 .39571 .44268 .38582 Mtetra
.569 .38 .585 r
.44268 .38582 .44358 .39571 .44555 .39455 .44464 .38468 Mtetra
.963 .679 .447 r
.44464 .38468 .44555 .39455 .44763 .38879 .45157 .18016 Mtetra
.527 .292 .502 r
.45157 .18016 .44763 .38879 .45453 .17745 .45356 .17267 Mtetra
.741 .549 .634 r
.45356 .17267 .45453 .17745 .45648 .17115 .45545 .16925 Mtetra
.742 .681 .791 r
.45545 .16925 .45648 .17115 .45834 .16936 .4573 .16784 Mtetra
.66 .699 .875 r
.4573 .16784 .45834 .16936 .46016 .16866 .45913 .16715 Mtetra
.598 .673 .893 r
.45913 .16715 .46016 .16866 .46199 .16836 .46095 .16674 Mtetra
.609 .661 .876 r
.46095 .16674 .46199 .16836 .46381 .16783 .46278 .16628 Mtetra
.615 .676 .885 r
.46278 .16628 .46381 .16783 .46564 .16719 .46461 .1658 Mtetra
.623 .705 .904 r
.46461 .1658 .46564 .16719 .46748 .16656 .46644 .16528 Mtetra
.672 .745 .905 r
.46644 .16528 .46748 .16656 .46931 .16587 .46827 .16455 Mtetra
.693 .743 .89 r
.46827 .16455 .46931 .16587 .47115 .16516 .47011 .1637 Mtetra
.691 .72 .872 r
.47011 .1637 .47115 .16516 .47298 .16445 .47195 .16284 Mtetra
.668 .69 .861 r
.47195 .16284 .47298 .16445 .47482 .16375 .47379 .16208 Mtetra
.656 .675 .856 r
.47379 .16208 .47482 .16375 .47666 .16307 .47563 .16138 Mtetra
.652 .671 .856 r
.47563 .16138 .47666 .16307 .4785 .16239 .47747 .1607 Mtetra
.653 .672 .855 r
.47747 .1607 .4785 .16239 .48034 .16171 .47931 .16001 Mtetra
.654 .671 .854 r
.47931 .16001 .48034 .16171 .48219 .16103 .48116 .15932 Mtetra
.653 .669 .853 r
.48116 .15932 .48219 .16103 .48403 .16034 .483 .15862 Mtetra
.653 .668 .852 r
.483 .15862 .48403 .16034 .48588 .15966 .48485 .15793 Mtetra
.653 .666 .85 r
.48485 .15793 .48588 .15966 .48772 .15897 .4867 .15723 Mtetra
.653 .665 .849 r
.4867 .15723 .48772 .15897 .48957 .15828 .48855 .15653 Mtetra
.678 .675 .84 r
.48855 .15653 .48957 .15828 .49142 .15754 .4904 .15568 Mtetra
.668 .656 .829 r
.4904 .15568 .49142 .15754 .49327 .1568 .49225 .15486 Mtetra
.623 .627 .834 r
.49225 .15486 .49327 .1568 .49512 .15612 .4941 .15431 Mtetra
.376 .513 .868 r
.4941 .15431 .49512 .15612 .49697 .15564 .49594 .15473 Mtetra
0 .073 .552 r
.49594 .15473 .49697 .15564 .49883 .15529 .49778 .15629 Mtetra
.794 .355 .205 r
.49778 .15629 .49883 .15529 .50068 .15495 .4996 .1594 Mtetra
.664 .313 .369 r
.4996 .1594 .50068 .15495 .50254 .15439 .50144 .16213 Mtetra
.465 .172 .383 r
.50144 .16213 .50254 .15439 .5044 .15366 .5033 .16169 Mtetra
.369 .095 .361 r
.5033 .16169 .5044 .15366 .50626 .15288 .50518 .15971 Mtetra
.399 .108 .351 r
.50518 .15971 .50626 .15288 .50812 .15212 .50705 .15843 Mtetra
.428 .127 .35 r
.50705 .15843 .50812 .15212 .50998 .1514 .50892 .15764 Mtetra
.429 .126 .349 r
.50892 .15764 .50998 .1514 .51184 .15069 .51079 .15687 Mtetra
.431 .128 .348 r
.51079 .15687 .51184 .15069 .51371 .14998 .51266 .15614 Mtetra
.434 .13 .349 r
.51266 .15614 .51371 .14998 .51558 .14928 .51453 .15546 Mtetra
.437 .133 .35 r
.51453 .15546 .51558 .14928 .51744 .14859 .5164 .15481 Mtetra
.44 .136 .351 r
.5164 .15481 .51744 .14859 .51931 .1479 .51828 .15418 Mtetra
.443 .139 .354 r
.51828 .15418 .51931 .1479 .52118 .14721 .52015 .15359 Mtetra
.445 .142 .356 r
.52015 .15359 .52118 .14721 .52305 .14652 .52203 .153 Mtetra
.445 .143 .358 r
.52203 .153 .52305 .14652 .52493 .14583 .52391 .1524 Mtetra
.445 .144 .359 r
.52391 .1524 .52493 .14583 .5268 .14514 .52579 .15179 Mtetra
.445 .145 .361 r
.52579 .15179 .5268 .14514 .52868 .14445 .52767 .15117 Mtetra
.446 .146 .362 r
.52767 .15117 .52868 .14445 .53055 .14376 .52955 .15055 Mtetra
.446 .148 .364 r
.52955 .15055 .53055 .14376 .53243 .14307 .53144 .14993 Mtetra
.447 .149 .365 r
.53144 .14993 .53243 .14307 .53431 .14238 .53332 .1493 Mtetra
.447 .15 .366 r
.53332 .1493 .53431 .14238 .53619 .14169 .53521 .14868 Mtetra
.448 .151 .367 r
.53521 .14868 .53619 .14169 .53807 .141 .5371 .14805 Mtetra
.449 .152 .369 r
.5371 .14805 .53807 .141 .53995 .14032 .53899 .14742 Mtetra
.449 .153 .37 r
.53899 .14742 .53995 .14032 .54184 .13963 .54088 .1468 Mtetra
.45 .155 .371 r
.54088 .1468 .54184 .13963 .54372 .13894 .54277 .14618 Mtetra
.451 .156 .372 r
.54277 .14618 .54372 .13894 .54561 .13825 .54466 .14555 Mtetra
.451 .156 .373 r
.54466 .14555 .54561 .13825 .5475 .13756 .54656 .14492 Mtetra
.451 .157 .374 r
.54656 .14492 .5475 .13756 .54939 .13687 .54846 .14428 Mtetra
.451 .157 .375 r
.54846 .14428 .54939 .13687 .55128 .13617 .55035 .14363 Mtetra
.451 .158 .375 r
.55035 .14363 .55128 .13617 .55317 .13547 .55225 .14298 Mtetra
.451 .158 .376 r
.55225 .14298 .55317 .13547 .55507 .13477 .55415 .14231 Mtetra
.55415 .14231 .55507 .13477 .55696 .13407 .55605 .14164 Mtetra
.45 .158 .377 r
.55605 .14164 .55696 .13407 .55886 .13336 .55796 .14097 Mtetra
.45 .159 .377 r
.55796 .14097 .55886 .13336 .56076 .13266 .55986 .14028 Mtetra
.45 .159 .378 r
.55986 .14028 .56076 .13266 .56265 .13195 .56177 .13959 Mtetra
.56177 .13959 .56265 .13195 .56455 .13124 .56367 .1389 Mtetra
.56367 .1389 .56455 .13124 .56646 .13052 .56558 .1382 Mtetra
.56558 .1382 .56646 .13052 .56836 .12981 .56749 .13749 Mtetra
.56749 .13749 .56836 .12981 .57026 .1291 .5694 .13679 Mtetra
.5694 .13679 .57026 .1291 .57217 .12838 .57132 .13608 Mtetra
.57132 .13608 .57217 .12838 .57407 .12766 .57323 .13537 Mtetra
.57323 .13537 .57407 .12766 .57598 .12695 .57514 .13465 Mtetra
.45 .159 .379 r
.57514 .13465 .57598 .12695 .57789 .12623 .57706 .13394 Mtetra
.449 .159 .379 r
.57706 .13394 .57789 .12623 .5798 .12551 .57898 .13322 Mtetra
.57898 .13322 .5798 .12551 .58171 .12479 .5809 .1325 Mtetra
.5809 .1325 .58171 .12479 .58363 .12407 .58282 .13179 Mtetra
.58282 .13179 .58363 .12407 .58554 .12335 .58474 .13107 Mtetra
.58474 .13107 .58554 .12335 .58746 .12263 .58666 .13034 Mtetra
.58666 .13034 .58746 .12263 .58937 .1219 .58858 .12962 Mtetra
.58858 .12962 .58937 .1219 .59129 .12118 .59051 .1289 Mtetra
.59051 .1289 .59129 .12118 .59321 .12046 .59244 .12817 Mtetra
.59244 .12817 .59321 .12046 .59513 .11973 .59436 .12745 Mtetra
.59436 .12745 .59513 .11973 .59706 .11901 .59629 .12672 Mtetra
.449 .159 .378 r
.59629 .12672 .59706 .11901 .59898 .11828 .59822 .12599 Mtetra
.449 .158 .378 r
.59822 .12599 .59898 .11828 .60091 .11756 .60015 .12526 Mtetra
.60015 .12526 .60091 .11756 .60283 .11683 .60209 .12453 Mtetra
.60209 .12453 .60283 .11683 .60476 .1161 .60402 .1238 Mtetra
.60402 .1238 .60476 .1161 .60669 .11538 .60596 .12306 Mtetra
.448 .158 .378 r
.60596 .12306 .60669 .11538 .60862 .11465 .6079 .12232 Mtetra
.6079 .12232 .60862 .11465 .61055 .11392 .60983 .12158 Mtetra
.448 .157 .378 r
.60983 .12158 .61055 .11392 .61248 .11318 .61177 .12084 Mtetra
.448 .157 .377 r
.61177 .12084 .61248 .11318 .61442 .11245 .61371 .12009 Mtetra
.447 .156 .377 r
.61371 .12009 .61442 .11245 .61635 .11172 .61566 .11933 Mtetra
.61566 .11933 .61635 .11172 .61829 .11098 .6176 .11857 Mtetra
.446 .155 .376 r
.6176 .11857 .61829 .11098 .62023 .11024 .61954 .11779 Mtetra
.444 .153 .375 r
.61954 .11779 .62023 .11024 .62217 .1095 .62149 .117 Mtetra
.443 .152 .374 r
.62149 .117 .62217 .1095 .62411 .10875 .62343 .1162 Mtetra
.441 .15 .373 r
.62343 .1162 .62411 .10875 .62605 .108 .62538 .11537 Mtetra
.437 .146 .371 r
.62538 .11537 .62605 .108 .62799 .10723 .62732 .11449 Mtetra
.432 .141 .368 r
.62732 .11449 .62799 .10723 .62994 .10645 .62927 .11355 Mtetra
.431 .138 .365 r
.62927 .11355 .62994 .10645 .63188 .10568 .63121 .11262 Mtetra
.396 .109 .355 r
.63121 .11262 .63188 .10568 .63382 .10475 .63314 .1112 Mtetra
.334 .054 .331 r
.63314 .1112 .63382 .10475 .63575 .10356 .63505 .10912 Mtetra
.431 .119 .334 r
.63505 .10912 .63575 .10356 .6377 .10288 .63701 .10847 Mtetra
.725 .376 .386 r
.63701 .10847 .6377 .10288 .63972 .10371 .63919 .11359 Mtetra
.968 .657 .365 r
.63919 .11359 .63972 .10371 .64215 .115 .64933 .31923 Mtetra
.517 .278 .492 r
.64933 .31923 .64215 .115 .65258 .32273 .65163 .3233 Mtetra
.593 .045 0 r
.65163 .3233 .65258 .32273 .65483 .32557 .65382 .32467 Mtetra
.547 .802 .992 r
.65382 .32467 .65483 .32557 .65696 .32528 .65594 .32422 Mtetra
.682 .824 .951 r
.65594 .32422 .65696 .32528 .65906 .32433 .65805 .32333 Mtetra
.709 .846 .947 r
.65805 .32333 .65906 .32433 .66116 .32316 .66015 .32232 Mtetra
.635 .852 .982 r
.66015 .32232 .66116 .32316 .66327 .32238 .66227 .32157 Mtetra
.637 .861 .984 r
.66227 .32157 .66327 .32238 .66539 .32158 .66439 .3208 Mtetra
.65 .871 .982 r
.66439 .3208 .66539 .32158 .6675 .3208 .6665 .31998 Mtetra
.68 .874 .972 r
.6665 .31998 .6675 .3208 .66962 .32005 .66861 .31906 Mtetra
.683 .84 .958 r
.66861 .31906 .66962 .32005 .67174 .31931 .67073 .31815 Mtetra
.63 .785 .956 r
.67073 .31815 .67174 .31931 .67387 .31873 .67286 .31749 Mtetra
.437 .677 .965 r
.67286 .31749 .67387 .31873 .67602 .31858 .67502 .31749 Mtetra
.58 .78 .974 r
.67502 .31749 .67602 .31858 .67815 .31794 .67716 .317 Mtetra
.839 .883 .873 r
.67716 .317 .67815 .31794 .68022 .31599 .67923 .31517 Mtetra
.991 .788 .535 r
.67923 .31517 .68022 .31599 .68197 .30767 .68099 .30687 Mtetra
.977 .674 .34 r
.68099 .30687 .68197 .30767 .67322 .09306 .67225 .09131 Mtetra
.932 .756 .64 r
.67225 .09131 .67322 .09306 .67498 .08823 .67402 .08647 Mtetra
.703 .699 .843 r
.67402 .08647 .67498 .08823 .67694 .08707 .67598 .08543 Mtetra
.574 .656 .893 r
.67598 .08543 .67694 .08707 .67893 .08658 .67798 .0851 Mtetra
.496 .641 .92 r
.67798 .0851 .67893 .08658 .68094 .08636 .68 .08503 Mtetra
.65 .745 .919 r
.68 .08503 .68094 .08636 .68292 .08566 .68198 .08435 Mtetra
.667 .755 .916 r
.68198 .08435 .68292 .08566 .68491 .08493 .68397 .08358 Mtetra
.698 .761 .901 r
.68397 .08358 .68491 .08493 .68689 .0841 .68594 .08266 Mtetra
.777 .774 .85 r
.68594 .08266 .68689 .0841 .68884 .08278 .68789 .08121 Mtetra
.707 .728 .867 r
.68789 .08121 .68884 .08278 .69082 .08189 .68986 .0802 Mtetra
.503 .61 .892 r
.68986 .0802 .69082 .08189 .69285 .08198 .69189 .08015 Mtetra
.677 .291 0 r
.69189 .08015 .69285 .08198 .6952 .08733 .6942 .08495 Mtetra
.972 .661 .306 r
.6942 .08495 .6952 .08733 .70993 .30149 .7089 .29968 Mtetra
.681 .283 0 r
.7089 .29968 .70993 .30149 .71239 .30602 .71139 .30464 Mtetra
.319 .58 .936 r
.71139 .30464 .71239 .30602 .71461 .30636 .71361 .30504 Mtetra
.669 .774 .929 r
.71361 .30504 .71461 .30636 .71676 .30552 .71576 .30421 Mtetra
.858 .827 .817 r
.71576 .30421 .71676 .30552 .71883 .30333 .71783 .30197 Mtetra
.981 .77 .544 r
.71783 .30197 .71883 .30333 .72056 .29586 .71953 .29381 Mtetra
.975 .669 .324 r
.71953 .29381 .72056 .29586 .70908 .08021 .7081 .07804 Mtetra
.92 .728 .627 r
.7081 .07804 .70908 .08021 .71078 .07474 .70983 .07291 Mtetra
.711 .695 .833 r
.70983 .07291 .71078 .07474 .71275 .07347 .7118 .07178 Mtetra
.591 .659 .885 r
.7118 .07178 .71275 .07347 .71477 .0729 .71383 .07136 Mtetra
.499 .635 .914 r
.71383 .07136 .71477 .0729 .71681 .07269 .71588 .0713 Mtetra
.692 .755 .9 r
.71588 .0713 .71681 .07269 .71881 .07191 .71788 .0704 Mtetra
.667 .723 .891 r
.71788 .0704 .71881 .07191 .72082 .07116 .71989 .06961 Mtetra
.606 .69 .902 r
.71989 .06961 .72082 .07116 .72283 .07045 .72192 .06912 Mtetra
.306 .563 .928 r
.72192 .06912 .72283 .07045 .72483 .06948 .72401 .06956 Mtetra
.564 0 0 r
.72401 .06956 .72483 .06948 .72685 .0689 .72618 .07102 Mtetra
.799 .376 .244 r
.72618 .07102 .72685 .0689 .72893 .06908 .72857 .07552 Mtetra
.513 .276 .492 r
.05484 .52028 .08472 .31735 .05835 .51687 .05621 .52194 Mtetra
.527 .201 .359 r
.05621 .52194 .05835 .51687 .0593 .52161 .05775 .52245 Mtetra
.27 0 0 r
.05775 .52245 .0593 .52161 .06066 .52339 .05936 .5224 Mtetra
.348 .66 .972 r
.05936 .5224 .06066 .52339 .06222 .52376 .06096 .52251 Mtetra
.625 .721 .915 r
.06096 .52251 .06222 .52376 .06391 .52324 .06264 .52203 Mtetra
.774 .756 .836 r
.06264 .52203 .06391 .52324 .06574 .52168 .06445 .52065 Mtetra
.912 .735 .649 r
.06445 .52065 .06574 .52168 .06826 .51503 .06694 .51424 Mtetra
.938 .687 .533 r
.06694 .51424 .06826 .51503 .09804 .30842 .09681 .30768 Mtetra
.919 .751 .657 r
.09681 .30768 .09804 .30842 .10029 .303 .09908 .30208 Mtetra
.778 .792 .865 r
.09908 .30208 .10029 .303 .10197 .30185 .10076 .30087 Mtetra
.607 .754 .948 r
.10076 .30087 .10197 .30185 .10353 .30149 .10234 .30046 Mtetra
.447 .683 .966 r
.10234 .30046 .10353 .30149 .10504 .30152 .10386 .30044 Mtetra
.717 .758 .885 r
.10386 .30044 .10504 .30152 .10665 .30083 .10549 .29958 Mtetra
.681 .721 .88 r
.10549 .29958 .10665 .30083 .10826 .30018 .10711 .29888 Mtetra
.554 .67 .915 r
.10711 .29888 .10826 .30018 .10983 .29978 .10865 .29866 Mtetra
.79 .31 0 r
.10865 .29866 .10983 .29978 .1113 .3002 .1099 .30076 Mtetra
.908 .601 .452 r
.1099 .30076 .1113 .3002 .11265 .30155 .11014 .31045 Mtetra
.928 .669 .525 r
.11014 .31045 .11265 .30155 .11367 .30536 .08546 .50918 Mtetra
.514 .277 .493 r
.08546 .50918 .11367 .30536 .08892 .50603 .08679 .51149 Mtetra
.543 .222 .374 r
.08679 .51149 .08892 .50603 .08984 .51144 .08833 .51223 Mtetra
.324 0 0 r
.08833 .51223 .08984 .51144 .09123 .51339 .08995 .51231 Mtetra
.614 .75 .942 r
.08995 .51231 .09123 .51339 .09288 .51325 .09165 .51185 Mtetra
.673 .71 .876 r
.09165 .51185 .09288 .51325 .09462 .51247 .09338 .51113 Mtetra
.692 .725 .875 r
.09338 .51113 .09462 .51247 .09639 .51144 .09512 .51032 Mtetra
.495 .7 .961 r
.09512 .51032 .09639 .51144 .09807 .51114 .09678 .51019 Mtetra
.534 .752 .976 r
.09678 .51019 .09807 .51114 .09975 .51085 .09846 .50993 Mtetra
.702 .802 .927 r
.09846 .50993 .09975 .51085 .10147 .51024 .1002 .50912 Mtetra
.875 .759 .731 r
.1002 .50912 .10147 .51024 .10332 .50859 .10226 .5059 Mtetra
.883 .674 .615 r
.10226 .5059 .10332 .50859 .10532 .50583 .10501 .49716 Mtetra
.933 .678 .529 r
.10501 .49716 .10532 .50583 .10762 .50058 .13221 .29429 Mtetra
.519 .286 .501 r
.13221 .29429 .10762 .50058 .13456 .29839 .13421 .29067 Mtetra
.62 .429 .602 r
.13421 .29067 .13456 .29839 .13693 .29175 .13598 .28882 Mtetra
.676 .561 .717 r
.13598 .28882 .13693 .29175 .13884 .2888 .13768 .28762 Mtetra
.685 .738 .891 r
.13768 .28762 .13884 .2888 .14052 .28771 .13931 .2869 Mtetra
.609 .795 .971 r
.13931 .2869 .14052 .28771 .14212 .28729 .14091 .28645 Mtetra
.566 .775 .977 r
.14091 .28645 .14212 .28729 .14369 .28715 .1425 .28612 Mtetra
.644 .756 .931 r
.1425 .28612 .14369 .28715 .14529 .28671 .14412 .28559 Mtetra
.67 .746 .907 r
.14412 .28559 .14529 .28671 .14691 .28611 .14575 .28494 Mtetra
.681 .741 .896 r
.14575 .28494 .14691 .28611 .14855 .28543 .14739 .28425 Mtetra
.746 .749 .855 r
.14739 .28425 .14855 .28543 .15022 .28446 .14907 .28316 Mtetra
.722 .728 .855 r
.14907 .28316 .15022 .28446 .15188 .28353 .15074 .2822 Mtetra
.629 .697 .894 r
.15074 .2822 .15188 .28353 .15352 .28288 .15235 .28172 Mtetra
.529 .027 0 r
.15235 .28172 .15352 .28288 .15505 .28309 .15374 .28316 Mtetra
.902 .554 .373 r
.15374 .28316 .15505 .28309 .15647 .28426 .15462 .28882 Mtetra
.938 .676 .514 r
.15462 .28882 .15647 .28426 .15766 .28736 .13212 .49195 Mtetra
.516 .279 .493 r
.13212 .49195 .15766 .28736 .1357 .48742 .13339 .49526 Mtetra
.542 .243 .41 r
.13339 .49526 .1357 .48742 .1365 .49484 .13496 .49615 Mtetra
.394 0 0 r
.13496 .49615 .1365 .49484 .13791 .49711 .13662 .49624 Mtetra
.62 .798 .968 r
.13662 .49624 .13791 .49711 .13958 .49716 .13836 .49572 Mtetra
.7 .716 .861 r
.13836 .49572 .13958 .49716 .14136 .49627 .14014 .49482 Mtetra
.728 .722 .845 r
.14014 .49482 .14136 .49627 .14318 .49497 .14194 .49373 Mtetra
.718 .75 .878 r
.14194 .49373 .14318 .49497 .14498 .49391 .14373 .49277 Mtetra
.699 .765 .903 r
.14373 .49277 .14498 .49391 .14676 .49303 .14551 .49194 Mtetra
.685 .77 .916 r
.14551 .49194 .14676 .49303 .14853 .49223 .14728 .49118 Mtetra
.653 .771 .936 r
.14728 .49118 .14853 .49223 .15029 .49156 .14903 .49057 Mtetra
.62 .774 .954 r
.14903 .49057 .15029 .49156 .15204 .491 .15077 .49006 Mtetra
.596 .777 .967 r
.15077 .49006 .15204 .491 .15378 .49053 .1525 .48962 Mtetra
.412 .712 .985 r
.1525 .48962 .15378 .49053 .15548 .49036 .1542 .48959 Mtetra
.431 .751 .994 r
.1542 .48959 .15548 .49036 .15719 .49018 .1559 .48947 Mtetra
.666 .842 .967 r
.1559 .48947 .15719 .49018 .15894 .48967 .15767 .48876 Mtetra
.884 .792 .754 r
.15767 .48876 .15894 .48967 .16079 .48826 .15968 .48585 Mtetra
.898 .687 .609 r
.15968 .48585 .16079 .48826 .16276 .48569 .16237 .47677 Mtetra
.938 .679 .518 r
.16237 .47677 .16276 .48569 .16498 .48088 .18622 .27412 Mtetra
.519 .286 .501 r
.18622 .27412 .16498 .48088 .18846 .27993 .18822 .27039 Mtetra
.598 .4 .584 r
.18822 .27039 .18846 .27993 .19087 .27231 .18999 .26864 Mtetra
.649 .516 .687 r
.18999 .26864 .19087 .27231 .19281 .26911 .19171 .26748 Mtetra
.682 .673 .834 r
.19171 .26748 .19281 .26911 .19455 .26766 .19338 .26668 Mtetra
.653 .774 .937 r
.19338 .26668 .19455 .26766 .19621 .26703 .19503 .2661 Mtetra
.617 .773 .955 r
.19503 .2661 .19621 .26703 .19783 .26669 .19667 .26563 Mtetra
.703 .768 .903 r
.19667 .26563 .19783 .26669 .19949 .26608 .19835 .26483 Mtetra
.708 .737 .874 r
.19835 .26483 .19949 .26608 .20116 .26531 .20004 .26397 Mtetra
.616 .692 .898 r
.20004 .26397 .20116 .26531 .20282 .26478 .20168 .26353 Mtetra
0 .151 .663 r
.20168 .26353 .20282 .26478 .2044 .2649 .20315 .26474 Mtetra
.911 .551 .34 r
.20315 .26474 .2044 .2649 .20589 .26595 .20418 .27025 Mtetra
.943 .677 .502 r
.20418 .27025 .20589 .26595 .2072 .26873 .18477 .47392 Mtetra
.517 .279 .493 r
.18477 .47392 .2072 .26873 .18851 .46728 .18611 .47754 Mtetra
.534 .248 .427 r
.18611 .47754 .18851 .46728 .18929 .47636 .18773 .47841 Mtetra
.454 .03 .143 r
.18773 .47841 .18929 .47636 .19074 .47897 .18943 .47857 Mtetra
.091 .622 .867 r
.18943 .47857 .19074 .47897 .19236 .47994 .19114 .47871 Mtetra
.487 .679 .95 r
.19114 .47871 .19236 .47994 .19408 .47993 .19287 .47862 Mtetra
.69 .738 .888 r
.19287 .47862 .19408 .47993 .1959 .47902 .19467 .47781 Mtetra
.878 .761 .729 r
.19467 .47781 .1959 .47902 .19796 .47564 .19672 .47455 Mtetra
.945 .71 .551 r
.19672 .47455 .19796 .47564 .21871 .28266 .20044 .4544 Mtetra
0 0 0 r
.20044 .4544 .21871 .28266 .2227 .25856 .22153 .25767 Mtetra
.887 .792 .75 r
.22153 .25767 .2227 .25856 .22458 .25584 .22342 .25487 Mtetra
.679 .785 .93 r
.22342 .25487 .22458 .25584 .22625 .2552 .2251 .25418 Mtetra
.496 .714 .968 r
.2251 .25418 .22625 .2552 .22788 .25511 .22673 .25404 Mtetra
.552 .724 .954 r
.22673 .25404 .22788 .25511 .22951 .2549 .22837 .25378 Mtetra
.662 .749 .915 r
.22837 .25378 .22951 .2549 .23119 .25432 .23005 .25315 Mtetra
.673 .745 .905 r
.23005 .25315 .23119 .25432 .23287 .25366 .23174 .25247 Mtetra
.739 .756 .867 r
.23174 .25247 .23287 .25366 .23459 .25261 .23346 .25143 Mtetra
.755 .76 .857 r
.23346 .25143 .23459 .25261 .23632 .25144 .23519 .25027 Mtetra
.657 .741 .912 r
.23519 .25027 .23632 .25144 .23801 .25082 .23687 .24966 Mtetra
0 .021 .525 r
.23687 .24966 .23801 .25082 .23949 .25231 .23836 .25111 Mtetra
.956 .658 .429 r
.23836 .25111 .23949 .25231 .22349 .44331 .23838 .26846 Mtetra
0 0 .047 r
.23838 .26846 .22349 .44331 .22303 .46723 .22183 .46582 Mtetra
.62 .145 0 r
.22183 .46582 .22303 .46723 .22459 .46921 .22338 .4679 Mtetra
.61 .714 .919 r
.22338 .4679 .22459 .46921 .22639 .46868 .22517 .46744 Mtetra
.732 .761 .876 r
.22517 .46744 .22639 .46868 .22824 .46755 .22702 .46638 Mtetra
.676 .761 .915 r
.22702 .46638 .22824 .46755 .23007 .46669 .22884 .46564 Mtetra
.501 .726 .973 r
.22884 .46564 .23007 .46669 .23184 .46641 .23061 .46546 Mtetra
.64 .794 .957 r
.23061 .46546 .23184 .46641 .23364 .46591 .23241 .46486 Mtetra
.839 .799 .813 r
.23241 .46486 .23364 .46591 .2355 .46472 .23435 .46286 Mtetra
.89 .713 .655 r
.23435 .46286 .2355 .46472 .23746 .46241 .23658 .45749 Mtetra
.95 .685 .499 r
.23658 .45749 .23746 .46241 .23956 .45851 .25632 .25161 Mtetra
.527 .292 .503 r
.25632 .25161 .23956 .45851 .24284 .44082 .25857 .2446 Mtetra
.516 .283 .5 r
.25857 .2446 .24284 .44082 .26128 .24653 .26042 .24225 Mtetra
.656 .503 .665 r
.26042 .24225 .26128 .24653 .26326 .24261 .26219 .24078 Mtetra
.693 .657 .81 r
.26219 .24078 .26326 .24261 .26507 .24074 .26392 .23983 Mtetra
.643 .791 .953 r
.26392 .23983 .26507 .24074 .26677 .24011 .26562 .23926 Mtetra
.581 .786 .977 r
.26562 .23926 .26677 .24011 .26844 .23985 .2673 .23886 Mtetra
.607 .765 .955 r
.2673 .23886 .26844 .23985 .27011 .23956 .26899 .23842 Mtetra
.665 .75 .914 r
.26899 .23842 .27011 .23956 .27182 .23895 .2707 .23777 Mtetra
.675 .745 .904 r
.2707 .23777 .27182 .23895 .27353 .23829 .27241 .23707 Mtetra
.715 .751 .88 r
.27241 .23707 .27353 .23829 .27525 .23745 .27414 .23616 Mtetra
.74 .745 .856 r
.27414 .23616 .27525 .23745 .27699 .23645 .27588 .23507 Mtetra
.672 .712 .878 r
.27588 .23507 .27699 .23645 .27871 .23567 .2776 .23437 Mtetra
.237 .518 .912 r
.2776 .23437 .27871 .23567 .28037 .23558 .27922 .23484 Mtetra
.896 .476 .16 r
.27922 .23484 .28037 .23558 .28194 .23677 .28058 .23866 Mtetra
.954 .681 .481 r
.28058 .23866 .28194 .23677 .28341 .2392 .26601 .44348 Mtetra
.52 .282 .493 r
.26601 .44348 .28341 .2392 .28485 .24209 .26736 .44889 Mtetra
.508 .272 .491 r
.26736 .44889 .28485 .24209 .28662 .24086 .26917 .44858 Mtetra
.507 .27 .491 r
.26917 .44858 .28662 .24086 .28836 .23987 .27103 .44758 Mtetra
.508 .271 .491 r
.27103 .44758 .28836 .23987 .28964 .24507 .27284 .44723 Mtetra
.511 .274 .491 r
.27284 .44723 .28964 .24507 .27606 .44544 .27455 .44831 Mtetra
.551 .167 .266 r
.27455 .44831 .27606 .44544 .27755 .44936 .27628 .44907 Mtetra
0 .554 .784 r
.27628 .44907 .27755 .44936 .27924 .45066 .27806 .44928 Mtetra
.61 .708 .914 r
.27806 .44928 .27924 .45066 .28106 .45029 .27989 .44882 Mtetra
.651 .707 .887 r
.27989 .44882 .28106 .45029 .28292 .44952 .28173 .44816 Mtetra
.636 .721 .909 r
.28173 .44816 .28292 .44952 .28477 .44874 .28357 .44759 Mtetra
.545 .726 .958 r
.28357 .44759 .28477 .44874 .2866 .44832 .28539 .44731 Mtetra
.653 .791 .948 r
.28539 .44731 .2866 .44832 .28845 .44768 .28724 .44665 Mtetra
.816 .812 .846 r
.28724 .44665 .28845 .44768 .29034 .44652 .28917 .44497 Mtetra
.898 .738 .674 r
.28917 .44497 .29034 .44652 .2923 .44434 .29131 .44032 Mtetra
.956 .687 .485 r
.29131 .44032 .2923 .44434 .29435 .4408 .30755 .2371 Mtetra
.537 .301 .504 r
.30755 .2371 .29435 .4408 .29682 .4313 .31004 .22572 Mtetra
.516 .284 .5 r
.31004 .22572 .29682 .4313 .31276 .22805 .31191 .22307 Mtetra
.65 .484 .646 r
.31191 .22307 .31276 .22805 .31476 .22353 .31372 .22143 Mtetra
.7 .636 .781 r
.31372 .22143 .31476 .22353 .31661 .22124 .31548 .22032 Mtetra
.69 .806 .937 r
.31548 .22032 .31661 .22124 .31836 .22033 .31723 .21955 Mtetra
.629 .821 .974 r
.31723 .21955 .31836 .22033 .32009 .21983 .31896 .21899 Mtetra
.606 .801 .974 r
.31896 .21899 .32009 .21983 .3218 .21949 .32069 .21851 Mtetra
.632 .777 .95 r
.32069 .21851 .3218 .21949 .32353 .21903 .32242 .21797 Mtetra
.64 .764 .938 r
.32242 .21797 .32353 .21903 .32526 .21855 .32415 .21741 Mtetra
.661 .753 .918 r
.32415 .21741 .32526 .21855 .32699 .21798 .32589 .21676 Mtetra
.697 .751 .893 r
.32589 .21676 .32699 .21798 .32874 .21717 .32765 .21594 Mtetra
.702 .749 .888 r
.32765 .21594 .32874 .21717 .3305 .21632 .3294 .21509 Mtetra
.71 .752 .885 r
.3294 .21509 .3305 .21632 .33226 .21545 .33116 .2142 Mtetra
.732 .754 .87 r
.33116 .2142 .33226 .21545 .33402 .21454 .33293 .21316 Mtetra
.669 .715 .883 r
.33293 .21316 .33402 .21454 .33577 .21384 .33468 .21246 Mtetra
.453 .623 .925 r
.33468 .21246 .33577 .21384 .33749 .21355 .33639 .21252 Mtetra
.776 .296 0 r
.33639 .21252 .33749 .21355 .33916 .21417 .33794 .21509 Mtetra
.96 .681 .463 r
.33794 .21509 .33916 .21417 .34077 .2159 .32806 .40511 Mtetra
.557 .312 .5 r
.32806 .40511 .34077 .2159 .34213 .22177 .32851 .42784 Mtetra
.513 .275 .492 r
.32851 .42784 .34213 .22177 .3317 .42603 .33024 .42968 Mtetra
.528 .166 .296 r
.33024 .42968 .3317 .42603 .33329 .43022 .33204 .43028 Mtetra
.01 0 0 r
.33204 .43028 .33329 .43022 .33505 .43171 .33389 .43025 Mtetra
.602 .695 .908 r
.33389 .43025 .33505 .43171 .33691 .43145 .33576 .42981 Mtetra
.647 .685 .872 r
.33576 .42981 .33691 .43145 .33879 .43073 .33764 .42915 Mtetra
.655 .698 .877 r
.33764 .42915 .33879 .43073 .34069 .42984 .33953 .42846 Mtetra
.539 .682 .931 r
.33953 .42846 .34069 .42984 .34256 .42942 .34139 .42824 Mtetra
.629 .754 .938 r
.34139 .42824 .34256 .42942 .34445 .4288 .34327 .42767 Mtetra
.773 .799 .874 r
.34327 .42767 .34445 .4288 .34636 .42775 .3452 .42633 Mtetra
.908 .754 .679 r
.3452 .42633 .34636 .42775 .34834 .42529 .3473 .42182 Mtetra
.962 .688 .469 r
.3473 .42182 .34834 .42529 .35039 .42174 .35992 .22306 Mtetra
.549 .31 .506 r
.35992 .22306 .35039 .42174 .35251 .41672 .36255 .20646 Mtetra
.513 .281 .5 r
.36255 .20646 .35251 .41672 .35438 .41636 .36435 .20524 Mtetra
.511 .279 .499 r
.36435 .20524 .35438 .41636 .35624 .41626 .3661 .20488 Mtetra
.3661 .20488 .35624 .41626 .35821 .4142 .36786 .20454 Mtetra
.515 .283 .5 r
.36786 .20454 .35821 .4142 .37052 .20889 .36971 .20226 Mtetra
.639 .453 .615 r
.36971 .20226 .37052 .20889 .37258 .20264 .37155 .20024 Mtetra
.734 .63 .743 r
.37155 .20024 .37258 .20264 .37447 .1996 .37338 .19863 Mtetra
.7 .802 .929 r
.37338 .19863 .37447 .1996 .37626 .19858 .37516 .19781 Mtetra
.641 .832 .974 r
.37516 .19781 .37626 .19858 .37803 .19798 .37693 .19718 Mtetra
.613 .818 .979 r
.37693 .19718 .37803 .19798 .37979 .19759 .3787 .19665 Mtetra
.669 .803 .947 r
.3787 .19665 .37979 .19759 .38157 .19691 .38048 .19596 Mtetra
.667 .801 .946 r
.38048 .19596 .38157 .19691 .38335 .19625 .38226 .19527 Mtetra
.663 .794 .945 r
.38226 .19527 .38335 .19625 .38513 .19562 .38404 .1946 Mtetra
.638 .778 .948 r
.38404 .1946 .38513 .19562 .3869 .19511 .38582 .19403 Mtetra
.642 .764 .937 r
.38582 .19403 .3869 .19511 .38867 .19461 .38759 .19344 Mtetra
.653 .752 .922 r
.38759 .19344 .38867 .19461 .39045 .19406 .38938 .19282 Mtetra
.693 .751 .896 r
.38938 .19282 .39045 .19406 .39224 .19325 .39117 .192 Mtetra
.7 .752 .892 r
.39117 .192 .39224 .19325 .39403 .19239 .39296 .19115 Mtetra
.699 .753 .893 r
.39296 .19115 .39403 .19239 .39583 .19153 .39476 .1903 Mtetra
.681 .749 .903 r
.39476 .1903 .39583 .19153 .39762 .1908 .39655 .18954 Mtetra
.674 .743 .903 r
.39655 .18954 .39762 .1908 .39941 .1901 .39834 .18882 Mtetra
.669 .737 .901 r
.39834 .18882 .39941 .1901 .4012 .18941 .40013 .18812 Mtetra
.728 .752 .872 r
.40013 .18812 .4012 .18941 .403 .18852 .40194 .18709 Mtetra
.681 .716 .875 r
.40194 .18709 .403 .18852 .4048 .18776 .40374 .1863 Mtetra
.568 .666 .904 r
.40374 .1863 .4048 .18776 .40658 .1873 .40551 .18602 Mtetra
.582 .112 0 r
.40551 .18602 .40658 .1873 .40832 .18805 .4072 .18817 Mtetra
.93 .575 .33 r
.4072 .18817 .40832 .18805 .41003 .18973 .40863 .19698 Mtetra
.959 .672 .448 r
.40863 .19698 .41003 .18973 .41168 .19287 .40265 .40167 Mtetra
.51 .273 .491 r
.40265 .40167 .41168 .19287 .41348 .19243 .40453 .40225 Mtetra
.507 .271 .491 r
.40453 .40225 .41348 .19243 .4153 .19118 .40647 .40135 Mtetra
.506 .27 .491 r
.40647 .40135 .4153 .19118 .41709 .19099 .40842 .40015 Mtetra
.511 .274 .491 r
.40842 .40015 .41709 .19099 .41172 .39418 .41029 .40123 Mtetra
.545 .233 .389 r
.41029 .40123 .41172 .39418 .41337 .40167 .41216 .40224 Mtetra
.446 0 0 r
.41216 .40224 .41337 .40167 .4152 .40416 .41406 .4028 Mtetra
.573 .706 .932 r
.41406 .4028 .4152 .40416 .41711 .40417 .41599 .40245 Mtetra
.647 .678 .866 r
.41599 .40245 .41711 .40417 .41905 .40348 .41793 .40177 Mtetra
.672 .69 .858 r
.41793 .40177 .41905 .40348 .421 .40247 .41987 .40094 Mtetra
.667 .714 .883 r
.41987 .40094 .421 .40247 .42295 .4016 .42182 .40017 Mtetra
.666 .73 .897 r
.42182 .40017 .42295 .4016 .4249 .40075 .42376 .39942 Mtetra
.659 .744 .913 r
.42376 .39942 .4249 .40075 .42685 .39994 .42571 .3987 Mtetra
.497 .695 .957 r
.42571 .3987 .42685 .39994 .42878 .39964 .42764 .39857 Mtetra
.543 .75 .972 r
.42764 .39857 .42878 .39964 .43072 .39929 .42958 .39824 Mtetra
.702 .811 .933 r
.42958 .39824 .43072 .39929 .43267 .3986 .43154 .39733 Mtetra
.909 .784 .711 r
.43154 .39733 .43267 .3986 .43466 .39644 .43357 .39362 Mtetra
.931 .693 .556 r
.43357 .39362 .43466 .39644 .43669 .39299 .43584 .38145 Mtetra
.961 .677 .451 r
.43584 .38145 .43669 .39299 .43877 .38746 .44334 .17646 Mtetra
.515 .282 .5 r
.44334 .17646 .43877 .38746 .44075 .38562 .44521 .17436 Mtetra
.511 .279 .499 r
.44521 .17436 .44075 .38562 .44268 .38582 .44703 .17381 Mtetra
.51 .279 .499 r
.44703 .17381 .44268 .38582 .44464 .38468 .44884 .17356 Mtetra
.514 .282 .5 r
.44884 .17356 .44464 .38468 .45157 .18016 .4507 .17171 Mtetra
.615 .419 .593 r
.4507 .17171 .45157 .18016 .45356 .17267 .45256 .16967 Mtetra
.713 .587 .713 r
.45256 .16967 .45356 .17267 .45545 .16925 .45441 .16797 Mtetra
.723 .759 .881 r
.45441 .16797 .45545 .16925 .4573 .16784 .45624 .16696 Mtetra
.658 .82 .961 r
.45624 .16696 .4573 .16784 .45913 .16715 .45807 .16628 Mtetra
.615 .809 .975 r
.45807 .16628 .45913 .16715 .46095 .16674 .4599 .16574 Mtetra
.623 .782 .958 r
.4599 .16574 .46095 .16674 .46278 .16628 .46173 .16519 Mtetra
.629 .766 .945 r
.46173 .16519 .46278 .16628 .46461 .1658 .46356 .16464 Mtetra
.639 .755 .932 r
.46356 .16464 .46461 .1658 .46644 .16528 .46539 .16405 Mtetra
.676 .754 .91 r
.46539 .16405 .46644 .16528 .46827 .16455 .46723 .1633 Mtetra
.693 .757 .901 r
.46723 .1633 .46827 .16455 .47011 .1637 .46907 .16247 Mtetra
.695 .76 .902 r
.46907 .16247 .47011 .1637 .47195 .16284 .47091 .16162 Mtetra
.679 .758 .911 r
.47091 .16162 .47195 .16284 .47379 .16208 .47275 .16086 Mtetra
.668 .754 .915 r
.47275 .16086 .47379 .16208 .47563 .16138 .47459 .16015 Mtetra
.664 .751 .915 r
.47459 .16015 .47563 .16138 .47747 .1607 .47644 .15945 Mtetra
.665 .749 .913 r
.47644 .15945 .47747 .1607 .47931 .16001 .47828 .15875 Mtetra
.665 .747 .911 r
.47828 .15875 .47931 .16001 .48116 .15932 .48012 .15805 Mtetra
.665 .745 .91 r
.48012 .15805 .48116 .15932 .483 .15862 .48197 .15735 Mtetra
.666 .744 .909 r
.48197 .15735 .483 .15862 .48485 .15793 .48382 .15664 Mtetra
.666 .742 .907 r
.48382 .15664 .48485 .15793 .4867 .15723 .48566 .15593 Mtetra
.665 .739 .906 r
.48566 .15593 .4867 .15723 .48855 .15653 .48751 .15522 Mtetra
.713 .754 .885 r
.48751 .15522 .48855 .15653 .4904 .15568 .48937 .15426 Mtetra
.696 .731 .878 r
.48937 .15426 .4904 .15568 .49225 .15486 .49122 .15338 Mtetra
.604 .684 .898 r
.49122 .15338 .49225 .15486 .4941 .15431 .49307 .15294 Mtetra
0 .213 .73 r
.49307 .15294 .4941 .15431 .49594 .15473 .49491 .15436 Mtetra
.914 .513 .197 r
.49491 .15436 .49594 .15473 .49778 .15629 .4967 .16046 Mtetra
.968 .673 .413 r
.4967 .16046 .49778 .15629 .4996 .1594 .49671 .3689 Mtetra
.513 .276 .492 r
.49671 .3689 .4996 .1594 .50144 .16213 .49868 .37127 Mtetra
.508 .271 .491 r
.49868 .37127 .50144 .16213 .5033 .16169 .50068 .37077 Mtetra
.506 .27 .491 r
.50068 .37077 .5033 .16169 .50518 .15971 .50268 .36948 Mtetra
.507 .27 .491 r
.50268 .36948 .50518 .15971 .50705 .15843 .50468 .36845 Mtetra
.507 .271 .491 r
.50468 .36845 .50705 .15843 .50892 .15764 .50669 .36774 Mtetra
.50669 .36774 .50892 .15764 .51079 .15687 .50869 .36703 Mtetra
.50869 .36703 .51079 .15687 .51266 .15614 .51069 .36634 Mtetra
.51069 .36634 .51266 .15614 .51453 .15546 .5127 .36568 Mtetra
.5127 .36568 .51453 .15546 .5164 .15481 .5147 .36504 Mtetra
.5147 .36504 .5164 .15481 .51828 .15418 .51671 .36441 Mtetra
.51671 .36441 .51828 .15418 .52015 .15359 .51872 .36378 Mtetra
.51872 .36378 .52015 .15359 .52203 .153 .52073 .36317 Mtetra
.52073 .36317 .52203 .153 .52391 .1524 .52275 .36254 Mtetra
.52275 .36254 .52391 .1524 .52579 .15179 .52476 .3619 Mtetra
.52476 .3619 .52579 .15179 .52767 .15117 .52678 .36126 Mtetra
.52678 .36126 .52767 .15117 .52955 .15055 .52879 .36062 Mtetra
.52879 .36062 .52955 .15055 .53144 .14993 .53081 .35997 Mtetra
.53081 .35997 .53144 .14993 .53332 .1493 .53283 .35931 Mtetra
.53283 .35931 .53332 .1493 .53521 .14868 .53486 .35866 Mtetra
.53486 .35866 .53521 .14868 .5371 .14805 .53688 .358 Mtetra
.53688 .358 .5371 .14805 .53899 .14742 .5389 .35734 Mtetra
.5389 .35734 .53899 .14742 .54088 .1468 .54093 .35668 Mtetra
.54093 .35668 .54088 .1468 .54277 .14618 .54296 .35602 Mtetra
.54296 .35602 .54277 .14618 .54466 .14555 .54499 .35535 Mtetra
.54499 .35535 .54466 .14555 .54656 .14492 .54702 .35468 Mtetra
.54702 .35468 .54656 .14492 .54846 .14428 .54905 .35401 Mtetra
.54905 .35401 .54846 .14428 .55035 .14363 .55109 .35334 Mtetra
.55109 .35334 .55035 .14363 .55225 .14298 .55312 .35267 Mtetra
.55312 .35267 .55225 .14298 .55415 .14231 .55516 .35199 Mtetra
.55516 .35199 .55415 .14231 .55605 .14164 .5572 .35131 Mtetra
.5572 .35131 .55605 .14164 .55796 .14097 .55924 .35063 Mtetra
.55924 .35063 .55796 .14097 .55986 .14028 .56128 .34995 Mtetra
.56128 .34995 .55986 .14028 .56177 .13959 .56332 .34926 Mtetra
.56332 .34926 .56177 .13959 .56367 .1389 .56537 .34858 Mtetra
.56537 .34858 .56367 .1389 .56558 .1382 .56741 .34789 Mtetra
.56741 .34789 .56558 .1382 .56749 .13749 .56946 .3472 Mtetra
.56946 .3472 .56749 .13749 .5694 .13679 .57151 .34651 Mtetra
.57151 .34651 .5694 .13679 .57132 .13608 .57356 .34582 Mtetra
.57356 .34582 .57132 .13608 .57323 .13537 .57561 .34513 Mtetra
.57561 .34513 .57323 .13537 .57514 .13465 .57767 .34444 Mtetra
.57767 .34444 .57514 .13465 .57706 .13394 .57972 .34375 Mtetra
.57972 .34375 .57706 .13394 .57898 .13322 .58178 .34305 Mtetra
.58178 .34305 .57898 .13322 .5809 .1325 .58384 .34236 Mtetra
.58384 .34236 .5809 .1325 .58282 .13179 .58589 .34167 Mtetra
.58589 .34167 .58282 .13179 .58474 .13107 .58796 .34097 Mtetra
.58796 .34097 .58474 .13107 .58666 .13034 .59002 .34028 Mtetra
.59002 .34028 .58666 .13034 .58858 .12962 .59208 .33958 Mtetra
.59208 .33958 .58858 .12962 .59051 .1289 .59415 .33888 Mtetra
.59415 .33888 .59051 .1289 .59244 .12817 .59622 .33818 Mtetra
.59622 .33818 .59244 .12817 .59436 .12745 .59829 .33749 Mtetra
.59829 .33749 .59436 .12745 .59629 .12672 .60036 .33679 Mtetra
.60036 .33679 .59629 .12672 .59822 .12599 .60243 .33609 Mtetra
.60243 .33609 .59822 .12599 .60015 .12526 .6045 .33539 Mtetra
.6045 .33539 .60015 .12526 .60209 .12453 .60658 .33468 Mtetra
.60658 .33468 .60209 .12453 .60402 .1238 .60865 .33398 Mtetra
.60865 .33398 .60402 .1238 .60596 .12306 .61073 .33328 Mtetra
.61073 .33328 .60596 .12306 .6079 .12232 .61281 .33258 Mtetra
.61281 .33258 .6079 .12232 .60983 .12158 .61489 .33187 Mtetra
.61489 .33187 .60983 .12158 .61177 .12084 .61697 .33116 Mtetra
.61697 .33116 .61177 .12084 .61371 .12009 .61906 .33046 Mtetra
.61906 .33046 .61371 .12009 .61566 .11933 .62114 .32974 Mtetra
.62114 .32974 .61566 .11933 .6176 .11857 .62323 .32903 Mtetra
.62323 .32903 .6176 .11857 .61954 .11779 .62532 .32832 Mtetra
.62532 .32832 .61954 .11779 .62149 .117 .62741 .3276 Mtetra
.62741 .3276 .62149 .117 .62343 .1162 .6295 .32687 Mtetra
.6295 .32687 .62343 .1162 .62538 .11537 .63159 .32614 Mtetra
.63159 .32614 .62538 .11537 .62732 .11449 .63369 .3254 Mtetra
.63369 .3254 .62732 .11449 .62927 .11355 .63578 .32464 Mtetra
.63578 .32464 .62927 .11355 .63121 .11262 .63788 .32388 Mtetra
.63788 .32388 .63121 .11262 .63314 .1112 .63997 .32302 Mtetra
.507 .27 .491 r
.63997 .32302 .63314 .1112 .63505 .10912 .64206 .32198 Mtetra
.507 .271 .491 r
.64206 .32198 .63505 .10912 .63701 .10847 .64416 .32123 Mtetra
.509 .272 .491 r
.64416 .32123 .63701 .10847 .63919 .11359 .6463 .32126 Mtetra
.511 .273 .491 r
.6463 .32126 .63919 .11359 .64933 .31923 .64847 .32223 Mtetra
.525 .128 .231 r
.64847 .32223 .64933 .31923 .65163 .3233 .65063 .32291 Mtetra
.103 .633 .87 r
.65063 .32291 .65163 .3233 .65382 .32467 .65278 .32306 Mtetra
.627 .703 .9 r
.65278 .32306 .65382 .32467 .65594 .32422 .6549 .32244 Mtetra
.662 .693 .869 r
.6549 .32244 .65594 .32422 .65805 .32333 .65701 .32161 Mtetra
.673 .707 .873 r
.65701 .32161 .65805 .32333 .66015 .32232 .65912 .32074 Mtetra
.651 .719 .898 r
.65912 .32074 .66015 .32232 .66227 .32157 .66123 .32 Mtetra
.652 .721 .899 r
.66123 .32 .66227 .32157 .66439 .3208 .66335 .31925 Mtetra
.658 .727 .9 r
.66335 .31925 .66439 .3208 .6665 .31998 .66547 .31847 Mtetra
.67 .74 .902 r
.66547 .31847 .6665 .31998 .66861 .31906 .66759 .31764 Mtetra
.667 .753 .914 r
.66759 .31764 .66861 .31906 .67073 .31815 .66971 .31682 Mtetra
.62 .749 .939 r
.66971 .31682 .67073 .31815 .67286 .31749 .67184 .31622 Mtetra
.447 .676 .962 r
.67184 .31622 .67286 .31749 .67502 .31749 .674 .3162 Mtetra
.597 .747 .949 r
.674 .3162 .67502 .31749 .67716 .317 .67614 .31569 Mtetra
.819 .818 .848 r
.67614 .31569 .67716 .317 .67923 .31517 .67822 .31387 Mtetra
.979 .772 .556 r
.67822 .31387 .67923 .31517 .68099 .30687 .67999 .30597 Mtetra
.977 .674 .34 r
.67999 .30597 .68099 .30687 .67225 .09131 .67132 .09035 Mtetra
.973 .816 .626 r
.67132 .09035 .67225 .09131 .67402 .08647 .67308 .08533 Mtetra
.738 .813 .911 r
.67308 .08533 .67402 .08647 .67598 .08543 .67504 .08423 Mtetra
.575 .737 .952 r
.67504 .08423 .67598 .08543 .67798 .0851 .67704 .08383 Mtetra
.498 .686 .951 r
.67704 .08383 .67798 .0851 .68 .08503 .67906 .08369 Mtetra
.659 .748 .916 r
.67906 .08369 .68 .08503 .68198 .08435 .68104 .08297 Mtetra
.672 .745 .906 r
.68104 .08297 .68198 .08435 .68397 .08358 .68302 .08218 Mtetra
.698 .751 .893 r
.68302 .08218 .68397 .08358 .68594 .08266 .685 .08125 Mtetra
.775 .777 .854 r
.685 .08125 .68594 .08266 .68789 .08121 .68695 .07982 Mtetra
.71 .759 .89 r
.68695 .07982 .68789 .08121 .68986 .0802 .68892 .07882 Mtetra
.475 .652 .937 r
.68892 .07882 .68986 .0802 .69189 .08015 .69095 .0788 Mtetra
.756 .333 0 r
.69095 .0788 .69189 .08015 .6942 .08495 .69327 .08357 Mtetra
.972 .66 .309 r
.69327 .08357 .6942 .08495 .7089 .29968 .7079 .29825 Mtetra
.748 .321 0 r
.7079 .29825 .7089 .29968 .71139 .30464 .71039 .30324 Mtetra
.317 .576 .934 r
.71039 .30324 .71139 .30464 .71361 .30504 .71261 .30365 Mtetra
.665 .762 .922 r
.71261 .30365 .71361 .30504 .71576 .30421 .71477 .30284 Mtetra
.851 .818 .817 r
.71477 .30284 .71576 .30421 .71783 .30197 .71684 .30064 Mtetra
.981 .774 .55 r
.71684 .30064 .71783 .30197 .71953 .29381 .71855 .29278 Mtetra
.975 .669 .322 r
.71855 .29278 .71953 .29381 .7081 .07804 .70719 .07696 Mtetra
.975 .808 .613 r
.70719 .07696 .7081 .07804 .70983 .07291 .70891 .07169 Mtetra
.748 .806 .898 r
.70891 .07169 .70983 .07291 .7118 .07178 .71088 .07051 Mtetra
.596 .735 .941 r
.71088 .07051 .7118 .07178 .71383 .07136 .71291 .07004 Mtetra
.5 .677 .944 r
.71291 .07004 .71383 .07136 .71588 .0713 .71496 .06991 Mtetra
.722 .767 .888 r
.71496 .06991 .71588 .0713 .71788 .0704 .71694 .06884 Mtetra
.67 .717 .884 r
.71694 .06884 .71788 .0704 .71989 .06961 .71895 .06803 Mtetra
.546 .654 .906 r
.71895 .06803 .71989 .06961 .72192 .06912 .721 .06779 Mtetra
0 0 .547 r
.721 .06779 .72192 .06912 .72401 .06956 .72324 .07034 Mtetra
.97 .654 .297 r
.72324 .07034 .72401 .06956 .72618 .07102 .73917 .27044 Mtetra
.541 .296 .492 r
.73917 .27044 .72618 .07102 .72857 .07552 .74262 .28816 Mtetra
.459 .079 .231 r
.05299 .52318 .05484 .52028 .05621 .52194 .05459 .52323 Mtetra
.015 0 0 r
.05459 .52323 .05621 .52194 .05775 .52245 .0563 .52251 Mtetra
.731 .97 .932 r
.0563 .52251 .05775 .52245 .05936 .5224 .05807 .52139 Mtetra
.444 .702 .976 r
.05807 .52139 .05936 .5224 .06096 .52251 .05969 .52134 Mtetra
.607 .729 .931 r
.05969 .52134 .06096 .52251 .06264 .52203 .06136 .52092 Mtetra
.759 .771 .863 r
.06136 .52092 .06264 .52203 .06445 .52065 .06314 .51973 Mtetra
.914 .744 .658 r
.06314 .51973 .06445 .52065 .06694 .51424 .06557 .51384 Mtetra
.938 .687 .532 r
.06557 .51384 .06694 .51424 .09681 .30768 .09549 .30747 Mtetra
.94 .774 .648 r
.09549 .30747 .09681 .30768 .09908 .30208 .09785 .30136 Mtetra
.803 .826 .869 r
.09785 .30136 .09908 .30208 .10076 .30087 .09954 .30002 Mtetra
.639 .789 .954 r
.09954 .30002 .10076 .30087 .10234 .30046 .10113 .29949 Mtetra
.499 .719 .97 r
.10113 .29949 .10234 .30046 .10386 .30044 .10267 .29935 Mtetra
.745 .761 .866 r
.10267 .29935 .10386 .30044 .10549 .29958 .10433 .29831 Mtetra
.694 .722 .871 r
.10433 .29831 .10549 .29958 .10711 .29888 .10595 .29754 Mtetra
.519 .65 .916 r
.10595 .29754 .10711 .29888 .10865 .29866 .10749 .29743 Mtetra
.922 .529 .201 r
.10749 .29743 .10865 .29866 .1099 .30076 .10851 .3012 Mtetra
.938 .681 .522 r
.10851 .3012 .1099 .30076 .11014 .31045 .08279 .50633 Mtetra
.523 .284 .494 r
.08279 .50633 .11014 .31045 .08546 .50918 .08362 .51237 Mtetra
.513 .144 .278 r
.08362 .51237 .08546 .50918 .08679 .51149 .0852 .51276 Mtetra
.047 0 0 r
.0852 .51276 .08679 .51149 .08833 .51223 .08692 .5121 Mtetra
.748 .95 .944 r
.08692 .5121 .08833 .51223 .08995 .51231 .08871 .51099 Mtetra
.646 .716 .899 r
.08871 .51099 .08995 .51231 .09165 .51185 .09042 .51041 Mtetra
.631 .691 .888 r
.09042 .51041 .09165 .51185 .09338 .51113 .09212 .50989 Mtetra
.648 .731 .909 r
.09212 .50989 .09338 .51113 .09512 .51032 .09384 .5093 Mtetra
.589 .757 .958 r
.09384 .5093 .09512 .51032 .09678 .51019 .09553 .50891 Mtetra
.676 .731 .892 r
.09553 .50891 .09678 .51019 .09846 .50993 .09727 .50819 Mtetra
.752 .69 .792 r
.09727 .50819 .09846 .50993 .1002 .50912 .0991 .50673 Mtetra
.865 .678 .647 r
.0991 .50673 .1002 .50912 .10226 .5059 .10149 .5009 Mtetra
.937 .683 .527 r
.10149 .5009 .10226 .5059 .10501 .49716 .12926 .29496 Mtetra
.525 .291 .502 r
.12926 .29496 .10501 .49716 .13221 .29429 .13156 .28899 Mtetra
.642 .472 .638 r
.13156 .28899 .13221 .29429 .13421 .29067 .1333 .28742 Mtetra
.602 .502 .713 r
.1333 .28742 .13421 .29067 .13598 .28882 .13492 .28686 Mtetra
.553 .572 .827 r
.13492 .28686 .13598 .28882 .13768 .28762 .13648 .28669 Mtetra
.619 .771 .953 r
.13648 .28669 .13768 .28762 .13931 .2869 .13808 .28623 Mtetra
.641 .832 .974 r
.13808 .28623 .13931 .2869 .14091 .28645 .1397 .28566 Mtetra
.655 .81 .958 r
.1397 .28566 .14091 .28645 .1425 .28612 .14132 .28507 Mtetra
.688 .763 .909 r
.14132 .28507 .1425 .28612 .14412 .28559 .14296 .28436 Mtetra
.687 .73 .883 r
.14296 .28436 .14412 .28559 .14575 .28494 .1446 .28362 Mtetra
.673 .711 .877 r
.1446 .28362 .14575 .28494 .14739 .28425 .14624 .28294 Mtetra
.697 .721 .868 r
.14624 .28294 .14739 .28425 .14907 .28316 .14789 .28214 Mtetra
.648 .759 .93 r
.14789 .28214 .14907 .28316 .15074 .2822 .14951 .28159 Mtetra
.259 .686 .964 r
.14951 .28159 .15074 .2822 .15235 .28172 .15106 .28166 Mtetra
.871 .471 .272 r
.15106 .28166 .15235 .28172 .15374 .28316 .15221 .28508 Mtetra
.941 .68 .513 r
.15221 .28508 .15374 .28316 .15462 .28882 .12932 .48975 Mtetra
.523 .284 .494 r
.12932 .48975 .15462 .28882 .13212 .49195 .13024 .49603 Mtetra
.552 .207 .337 r
.13024 .49603 .13212 .49195 .13339 .49526 .13182 .49683 Mtetra
.171 0 0 r
.13182 .49683 .13339 .49526 .13496 .49615 .13356 .49624 Mtetra
.697 .972 .925 r
.13356 .49624 .13496 .49615 .13662 .49624 .13536 .49514 Mtetra
.714 .776 .901 r
.13536 .49514 .13662 .49624 .13836 .49572 .13714 .49424 Mtetra
.683 .707 .866 r
.13714 .49424 .13836 .49572 .14014 .49482 .13891 .49345 Mtetra
.691 .723 .875 r
.13891 .49345 .14014 .49482 .14194 .49373 .14069 .49262 Mtetra
.701 .772 .906 r
.14069 .49262 .14194 .49373 .14373 .49277 .14246 .49178 Mtetra
.7 .794 .923 r
.14246 .49178 .14373 .49277 .14551 .49194 .14424 .49097 Mtetra
.686 .794 .931 r
.14424 .49097 .14551 .49194 .14728 .49118 .14601 .49021 Mtetra
.646 .785 .948 r
.14601 .49021 .14728 .49118 .14903 .49057 .14776 .48961 Mtetra
.609 .779 .962 r
.14776 .48961 .14903 .49057 .15077 .49006 .1495 .48914 Mtetra
.586 .778 .971 r
.1495 .48914 .15077 .49006 .1525 .48962 .15123 .48872 Mtetra
.338 .679 .978 r
.15123 .48872 .1525 .48962 .1542 .48959 .15291 .48881 Mtetra
.392 .731 .991 r
.15291 .48881 .1542 .48959 .1559 .48947 .1546 .48875 Mtetra
.693 .848 .957 r
.1546 .48875 .1559 .48947 .15767 .48876 .15638 .48795 Mtetra
.914 .781 .7 r
.15638 .48795 .15767 .48876 .15968 .48585 .15854 .48378 Mtetra
.946 .688 .514 r
.15854 .48378 .15968 .48585 .16237 .47677 .183 .27732 Mtetra
.531 .296 .504 r
.183 .27732 .16237 .47677 .18622 .27412 .18551 .26894 Mtetra
.674 .497 .638 r
.18551 .26894 .18622 .27412 .18822 .27039 .18733 .2668 Mtetra
.601 .489 .697 r
.18733 .2668 .18822 .27039 .18999 .26864 .18898 .26617 Mtetra
.551 .523 .777 r
.18898 .26617 .18999 .26864 .19171 .26748 .19059 .26601 Mtetra
.591 .661 .887 r
.19059 .26601 .19171 .26748 .19338 .26668 .19221 .26568 Mtetra
.646 .767 .936 r
.19221 .26568 .19338 .26668 .19503 .2661 .19386 .26512 Mtetra
.652 .774 .938 r
.19386 .26512 .19503 .2661 .19667 .26563 .19552 .26454 Mtetra
.732 .769 .882 r
.19552 .26454 .19667 .26563 .19835 .26483 .19721 .26357 Mtetra
.724 .738 .863 r
.19721 .26357 .19835 .26483 .20004 .26397 .19891 .2626 Mtetra
.606 .685 .898 r
.19891 .2626 .20004 .26397 .20168 .26353 .20055 .2622 Mtetra
.7 .228 0 r
.20055 .2622 .20168 .26353 .20315 .26474 .20192 .26431 Mtetra
.949 .684 .499 r
.20192 .26431 .20315 .26474 .20418 .27025 .18241 .46713 Mtetra
.533 .292 .496 r
.18241 .46713 .20418 .27025 .18477 .47392 .183 .47786 Mtetra
.612 .265 .357 r
.183 .47786 .18477 .47392 .18611 .47754 .18456 .47941 Mtetra
.289 0 .015 r
.18456 .47941 .18611 .47754 .18773 .47841 .18632 .47899 Mtetra
.451 .87 .736 r
.18632 .47899 .18773 .47841 .18943 .47857 .18814 .47798 Mtetra
.667 .871 .976 r
.18814 .47798 .18943 .47857 .19114 .47871 .18994 .47724 Mtetra
.641 .697 .886 r
.18994 .47724 .19114 .47871 .19287 .47862 .19172 .47665 Mtetra
.712 .66 .797 r
.19172 .47665 .19287 .47862 .19467 .47781 .19356 .47548 Mtetra
.834 .676 .687 r
.19356 .47548 .19467 .47781 .19672 .47455 .19565 .4718 Mtetra
.949 .687 .506 r
.19565 .4718 .19672 .47455 .20044 .4544 .21758 .26854 Mtetra
.541 .305 .506 r
.21758 .26854 .20044 .4544 .22153 .25767 .22037 .25672 Mtetra
.877 .788 .758 r
.22037 .25672 .22153 .25767 .22342 .25487 .22224 .25409 Mtetra
.701 .829 .944 r
.22224 .25409 .22342 .25487 .2251 .25418 .22393 .25331 Mtetra
.544 .766 .98 r
.22393 .25331 .2251 .25418 .22673 .25404 .22558 .25302 Mtetra
.602 .753 .95 r
.22558 .25302 .22673 .25404 .22837 .25378 .22723 .2526 Mtetra
.678 .745 .902 r
.22723 .2526 .22837 .25378 .23005 .25315 .22892 .2519 Mtetra
.668 .729 .895 r
.22892 .2519 .23005 .25315 .23174 .25247 .2306 .25124 Mtetra
.692 .738 .886 r
.2306 .25124 .23174 .25247 .23346 .25143 .2323 .25046 Mtetra
.688 .788 .926 r
.2323 .25046 .23346 .25143 .23519 .25027 .23399 .24973 Mtetra
.428 .792 .995 r
.23399 .24973 .23519 .25027 .23687 .24966 .23564 .24952 Mtetra
.773 .276 .032 r
.23564 .24952 .23687 .24966 .23836 .25111 .23708 .25144 Mtetra
.952 .683 .491 r
.23708 .25144 .23836 .25111 .23838 .26846 .21994 .45309 Mtetra
.535 .294 .496 r
.21994 .45309 .23838 .26846 .22183 .46582 .22062 .46455 Mtetra
.597 .103 0 r
.22062 .46455 .22183 .46582 .22338 .4679 .22219 .46643 Mtetra
.565 .672 .91 r
.22219 .46643 .22338 .4679 .22517 .46744 .22396 .46615 Mtetra
.7 .747 .888 r
.22396 .46615 .22517 .46744 .22702 .46638 .22579 .46527 Mtetra
.691 .777 .918 r
.22579 .46527 .22702 .46638 .22884 .46564 .22762 .46447 Mtetra
.64 .752 .93 r
.22762 .46447 .22884 .46564 .23061 .46546 .22942 .46389 Mtetra
.729 .713 .836 r
.22942 .46389 .23061 .46546 .23241 .46486 .23128 .46273 Mtetra
.833 .689 .703 r
.23128 .46273 .23241 .46486 .23435 .46286 .23333 .45944 Mtetra
.952 .687 .498 r
.23333 .45944 .23435 .46286 .23658 .45749 .25272 .25972 Mtetra
.549 .311 .507 r
.25272 .25972 .23658 .45749 .25632 .25161 .25579 .24358 Mtetra
.659 .455 .598 r
.25579 .24358 .25632 .25161 .25857 .2446 .25769 .24058 Mtetra
.615 .484 .679 r
.25769 .24058 .25857 .2446 .26042 .24225 .25941 .23972 Mtetra
.581 .537 .771 r
.25941 .23972 .26042 .24225 .26219 .24078 .26109 .23938 Mtetra
.577 .673 .905 r
.26109 .23938 .26219 .24078 .26392 .23983 .26276 .23908 Mtetra
.642 .826 .971 r
.26276 .23908 .26392 .23983 .26562 .23926 .26446 .23849 Mtetra
.648 .823 .967 r
.26446 .23849 .26562 .23926 .2673 .23886 .26616 .23788 Mtetra
.674 .784 .933 r
.26616 .23788 .2673 .23886 .26899 .23842 .26787 .2372 Mtetra
.688 .743 .893 r
.26787 .2372 .26899 .23842 .2707 .23777 .26959 .23643 Mtetra
.677 .719 .881 r
.26959 .23643 .2707 .23777 .27241 .23707 .2713 .2357 Mtetra
.68 .716 .876 r
.2713 .2357 .27241 .23707 .27414 .23616 .27302 .23495 Mtetra
.68 .743 .899 r
.27302 .23495 .27414 .23616 .27588 .23507 .27473 .23423 Mtetra
.504 .76 .988 r
.27473 .23423 .27588 .23507 .2776 .23437 .27641 .23401 Mtetra
.673 .122 0 r
.27641 .23401 .2776 .23437 .27922 .23484 .27795 .23548 Mtetra
.955 .682 .48 r
.27795 .23548 .27922 .23484 .28058 .23866 .2641 .42894 Mtetra
.553 .309 .5 r
.2641 .42894 .28058 .23866 .26601 .44348 .26424 .4494 Mtetra
.626 .303 .404 r
.26424 .4494 .26601 .44348 .26736 .44889 .26583 .45174 Mtetra
.397 .011 .185 r
.26583 .45174 .26736 .44889 .26917 .44858 .26764 .45146 Mtetra
.276 0 .125 r
.26764 .45146 .26917 .44858 .27103 .44758 .2695 .45058 Mtetra
.269 0 .132 r
.2695 .45058 .27103 .44758 .27284 .44723 .27136 .44962 Mtetra
.308 0 .094 r
.27136 .44962 .27284 .44723 .27455 .44831 .2732 .44906 Mtetra
0 0 0 r
.2732 .44906 .27455 .44831 .27628 .44907 .27504 .44845 Mtetra
.658 .871 .979 r
.27504 .44845 .27628 .44907 .27806 .44928 .27689 .44771 Mtetra
.7 .709 .855 r
.27689 .44771 .27806 .44928 .27989 .44882 .27875 .44676 Mtetra
.685 .646 .805 r
.27875 .44676 .27989 .44882 .28173 .44816 .28062 .44577 Mtetra
.637 .593 .788 r
.28062 .44577 .28173 .44816 .28357 .44759 .28247 .44505 Mtetra
.549 .536 .792 r
.28247 .44505 .28357 .44759 .28539 .44731 .28429 .44488 Mtetra
.626 .585 .789 r
.28429 .44488 .28539 .44731 .28724 .44665 .28613 .44425 Mtetra
.773 .655 .731 r
.28613 .44425 .28724 .44665 .28917 .44497 .2881 .44203 Mtetra
.906 .681 .586 r
.2881 .44203 .28917 .44497 .29131 .44032 .29066 .43147 Mtetra
.951 .681 .488 r
.29066 .43147 .29131 .44032 .30755 .2371 .30719 .22526 Mtetra
.643 .424 .571 r
.30719 .22526 .30755 .2371 .31004 .22572 .30916 .22134 Mtetra
.621 .478 .667 r
.30916 .22134 .31004 .22572 .31191 .22307 .31092 .22031 Mtetra
.593 .529 .753 r
.31092 .22031 .31191 .22307 .31372 .22143 .31264 .21987 Mtetra
.57 .645 .885 r
.31264 .21987 .31372 .22143 .31548 .22032 .31435 .2196 Mtetra
.646 .84 .975 r
.31435 .2196 .31548 .22032 .31723 .21955 .31608 .21897 Mtetra
.636 .866 .985 r
.31608 .21897 .31723 .21955 .31896 .21899 .31782 .21833 Mtetra
.657 .856 .976 r
.31782 .21833 .31896 .21899 .32069 .21851 .31956 .21766 Mtetra
.69 .821 .946 r
.31956 .21766 .32069 .21851 .32242 .21797 .32131 .21689 Mtetra
.684 .774 .919 r
.32131 .21689 .32242 .21797 .32415 .21741 .32305 .21615 Mtetra
.659 .732 .904 r
.32305 .21615 .32415 .21741 .32589 .21676 .32479 .21551 Mtetra
.604 .714 .922 r
.32479 .21551 .32589 .21676 .32765 .21594 .32652 .21509 Mtetra
.567 .786 .981 r
.32652 .21509 .32765 .21594 .3294 .21509 .32825 .21471 Mtetra
.556 .882 .99 r
.32825 .21471 .3294 .21509 .33116 .2142 .32999 .21417 Mtetra
.716 .974 .924 r
.32999 .21417 .33116 .2142 .33293 .21316 .33177 .21304 Mtetra
.575 .927 .951 r
.33177 .21304 .33293 .21316 .33468 .21246 .33352 .21231 Mtetra
.206 0 0 r
.33352 .21231 .33468 .21246 .33639 .21252 .3352 .21269 Mtetra
.911 .544 .323 r
.3352 .21269 .33639 .21252 .33794 .21509 .33652 .21911 Mtetra
.957 .678 .466 r
.33652 .21911 .33794 .21509 .32806 .40511 .32549 .42678 Mtetra
.574 .305 .471 r
.32549 .42678 .32806 .40511 .32851 .42784 .3271 .43053 Mtetra
.424 .029 .183 r
.3271 .43053 .32851 .42784 .33024 .42968 .32894 .43044 Mtetra
0 0 0 r
.32894 .43044 .33024 .42968 .33204 .43028 .33083 .42964 Mtetra
.736 .886 .949 r
.33083 .42964 .33204 .43028 .33389 .43025 .33273 .42858 Mtetra
.618 .668 .877 r
.33273 .42858 .33389 .43025 .33576 .42981 .33461 .42807 Mtetra
.626 .662 .865 r
.33461 .42807 .33576 .42981 .33764 .42915 .33649 .42752 Mtetra
.637 .681 .875 r
.33649 .42752 .33764 .42915 .33953 .42846 .33837 .42691 Mtetra
.606 .683 .896 r
.33837 .42691 .33953 .42846 .34139 .42824 .34024 .42646 Mtetra
.687 .682 .839 r
.34024 .42646 .34139 .42824 .34327 .42767 .34215 .42553 Mtetra
.777 .678 .754 r
.34215 .42553 .34327 .42767 .3452 .42633 .34411 .4235 Mtetra
.903 .684 .595 r
.34411 .4235 .3452 .42633 .3473 .42182 .34646 .41464 Mtetra
.958 .683 .472 r
.34646 .41464 .3473 .42182 .35992 .22306 .35968 .20606 Mtetra
.621 .394 .552 r
.35968 .20606 .35992 .22306 .36255 .20646 .36166 .20149 Mtetra
.617 .462 .65 r
.36166 .20149 .36255 .20646 .36435 .20524 .36346 .20035 Mtetra
.569 .432 .654 r
.36346 .20035 .36435 .20524 .3661 .20488 .36522 .19986 Mtetra
.541 .41 .651 r
.36522 .19986 .3661 .20488 .36786 .20454 .36696 .19967 Mtetra
.578 .438 .655 r
.36696 .19967 .36786 .20454 .36971 .20226 .36873 .19908 Mtetra
.604 .513 .725 r
.36873 .19908 .36971 .20226 .37155 .20024 .3705 .19848 Mtetra
.639 .65 .844 r
.3705 .19848 .37155 .20024 .37338 .19863 .37227 .19787 Mtetra
.643 .836 .975 r
.37227 .19787 .37338 .19863 .37516 .19781 .37404 .19724 Mtetra
.632 .874 .987 r
.37404 .19724 .37516 .19781 .37693 .19718 .37582 .19659 Mtetra
.646 .871 .983 r
.37582 .19659 .37693 .19718 .3787 .19665 .3776 .19591 Mtetra
.675 .846 .965 r
.3776 .19591 .3787 .19665 .38048 .19596 .37938 .19517 Mtetra
.681 .838 .959 r
.37938 .19517 .38048 .19596 .38226 .19527 .38116 .19441 Mtetra
.684 .824 .95 r
.38116 .19441 .38226 .19527 .38404 .1946 .38295 .19365 Mtetra
.69 .807 .937 r
.38295 .19365 .38404 .1946 .38582 .19403 .38474 .19287 Mtetra
.679 .763 .914 r
.38474 .19287 .38582 .19403 .38759 .19344 .38652 .19213 Mtetra
.661 .728 .899 r
.38652 .19213 .38759 .19344 .38938 .19282 .38831 .19146 Mtetra
.603 .699 .911 r
.38831 .19146 .38938 .19282 .39117 .192 .39008 .19104 Mtetra
.571 .766 .971 r
.39008 .19104 .39117 .192 .39296 .19115 .39186 .19066 Mtetra
.499 .843 .996 r
.39186 .19066 .39296 .19115 .39476 .1903 .39363 .19027 Mtetra
.497 .902 .915 r
.39363 .19027 .39476 .1903 .39655 .18954 .39542 .18958 Mtetra
.513 .913 .897 r
.39542 .18958 .39655 .18954 .39834 .18882 .39722 .18881 Mtetra
.544 .925 .913 r
.39722 .18881 .39834 .18882 .40013 .18812 .39901 .18802 Mtetra
.733 .975 .924 r
.39901 .18802 .40013 .18812 .40194 .18709 .40083 .18683 Mtetra
.639 .935 .966 r
.40083 .18683 .40194 .18709 .40374 .1863 .40263 .186 Mtetra
.244 .737 .916 r
.40263 .186 .40374 .1863 .40551 .18602 .4044 .18589 Mtetra
.882 .46 .188 r
.4044 .18589 .40551 .18602 .4072 .18817 .40601 .19011 Mtetra
.965 .679 .442 r
.40601 .19011 .4072 .18817 .40863 .19698 .39964 .39955 Mtetra
.52 .281 .493 r
.39964 .39955 .40863 .19698 .40265 .40167 .40133 .40505 Mtetra
.487 .115 .259 r
.40133 .40505 .40265 .40167 .40453 .40225 .40322 .4053 Mtetra
.328 0 .167 r
.40322 .4053 .40453 .40225 .40647 .40135 .40516 .40456 Mtetra
.254 0 .147 r
.40516 .40456 .40647 .40135 .40842 .40015 .40711 .40336 Mtetra
.335 0 .183 r
.40711 .40336 .40842 .40015 .41029 .40123 .40905 .4026 Mtetra
.118 0 0 r
.40905 .4026 .41029 .40123 .41216 .40224 .41099 .4019 Mtetra
.578 .905 .98 r
.41099 .4019 .41216 .40224 .41406 .4028 .41293 .40119 Mtetra
.65 .695 .879 r
.41293 .40119 .41406 .4028 .41599 .40245 .41487 .4005 Mtetra
.639 .646 .842 r
.41487 .4005 .41599 .40245 .41793 .40177 .41681 .39984 Mtetra
.634 .646 .845 r
.41681 .39984 .41793 .40177 .41987 .40094 .41875 .39921 Mtetra
.613 .663 .875 r
.41875 .39921 .41987 .40094 .42182 .40017 .42068 .3987 Mtetra
.615 .705 .909 r
.42068 .3987 .42182 .40017 .42376 .39942 .42262 .39819 Mtetra
.633 .754 .935 r
.42262 .39819 .42376 .39942 .42571 .3987 .42457 .39759 Mtetra
.586 .759 .961 r
.42457 .39759 .42571 .3987 .42764 .39857 .42651 .39715 Mtetra
.677 .736 .895 r
.42651 .39715 .42764 .39857 .42958 .39824 .42846 .39634 Mtetra
.76 .7 .795 r
.42846 .39634 .42958 .39824 .43154 .39733 .43044 .39471 Mtetra
.895 .692 .621 r
.43044 .39471 .43154 .39733 .43357 .39362 .43256 .38821 Mtetra
.967 .684 .445 r
.43256 .38821 .43357 .39362 .43584 .38145 .44043 .17704 Mtetra
.523 .289 .501 r
.44043 .17704 .43584 .38145 .44334 .17646 .4424 .1713 Mtetra
.646 .479 .643 r
.4424 .1713 .44334 .17646 .44521 .17436 .44425 .16964 Mtetra
.584 .448 .661 r
.44425 .16964 .44521 .17436 .44703 .17381 .44607 .16898 Mtetra
.55 .422 .658 r
.44607 .16898 .44703 .17381 .44884 .17356 .44788 .1687 Mtetra
.572 .436 .657 r
.44788 .1687 .44884 .17356 .4507 .17171 .4497 .16816 Mtetra
.599 .495 .708 r
.4497 .16816 .4507 .17171 .45256 .16967 .45153 .16754 Mtetra
.632 .608 .808 r
.45153 .16754 .45256 .16967 .45441 .16797 .45336 .1669 Mtetra
.662 .781 .937 r
.45336 .1669 .45441 .16797 .45624 .16696 .45518 .16622 Mtetra
.657 .85 .974 r
.45518 .16622 .45624 .16696 .45807 .16628 .45702 .16551 Mtetra
.661 .846 .971 r
.45702 .16551 .45807 .16628 .4599 .16574 .45885 .1648 Mtetra
.674 .813 .95 r
.45885 .1648 .4599 .16574 .46173 .16519 .46068 .16406 Mtetra
.67 .772 .926 r
.46068 .16406 .46173 .16519 .46356 .16464 .46252 .16334 Mtetra
.655 .736 .909 r
.46252 .16334 .46356 .16464 .46539 .16405 .46435 .16268 Mtetra
.607 .704 .913 r
.46435 .16268 .46539 .16405 .46723 .1633 .46618 .16223 Mtetra
.564 .746 .962 r
.46618 .16223 .46723 .1633 .46907 .16247 .46802 .16188 Mtetra
.487 .822 .999 r
.46802 .16188 .46907 .16247 .47091 .16162 .46985 .16154 Mtetra
.429 .867 .91 r
.46985 .16154 .47091 .16162 .47275 .16086 .47169 .16097 Mtetra
.421 .867 .842 r
.47169 .16097 .47275 .16086 .47459 .16015 .47353 .16026 Mtetra
.45 .883 .848 r
.47353 .16026 .47459 .16015 .47644 .15945 .47538 .15949 Mtetra
.462 .889 .875 r
.47538 .15949 .47644 .15945 .47828 .15875 .47722 .15876 Mtetra
.465 .89 .885 r
.47722 .15876 .47828 .15875 .48012 .15805 .47907 .15805 Mtetra
.469 .892 .888 r
.47907 .15805 .48012 .15805 .48197 .15735 .48091 .15734 Mtetra
.48 .897 .894 r
.48091 .15734 .48197 .15735 .48382 .15664 .48276 .15662 Mtetra
.488 .9 .9 r
.48276 .15662 .48382 .15664 .48566 .15593 .48461 .15589 Mtetra
.49 .9 .905 r
.48461 .15589 .48566 .15593 .48751 .15522 .48647 .15517 Mtetra
.661 .967 .915 r
.48647 .15517 .48751 .15522 .48937 .15426 .48832 .15409 Mtetra
.648 .953 .944 r
.48832 .15409 .48937 .15426 .49122 .15338 .49018 .15313 Mtetra
.347 .807 .933 r
.49018 .15313 .49122 .15338 .49307 .15294 .49203 .15281 Mtetra
.801 .309 .008 r
.49203 .15281 .49307 .15294 .49491 .15436 .49385 .15558 Mtetra
.971 .677 .409 r
.49385 .15558 .49491 .15436 .4967 .16046 .49365 .36525 Mtetra
.523 .283 .493 r
.49365 .36525 .4967 .16046 .49671 .3689 .49556 .37274 Mtetra
.566 .2 .306 r
.49556 .37274 .49671 .3689 .49868 .37127 .49755 .37384 Mtetra
.336 0 .128 r
.49755 .37384 .49868 .37127 .50068 .37077 .49955 .37329 Mtetra
.223 0 .073 r
.49955 .37329 .50068 .37077 .50268 .36948 .50155 .37223 Mtetra
.285 0 .124 r
.50155 .37223 .50268 .36948 .50468 .36845 .50355 .37134 Mtetra
.332 0 .157 r
.50355 .37134 .50468 .36845 .50669 .36774 .50556 .37065 Mtetra
.333 0 .159 r
.50556 .37065 .50669 .36774 .50869 .36703 .50757 .36996 Mtetra
.337 0 .162 r
.50757 .36996 .50869 .36703 .51069 .36634 .50957 .36928 Mtetra
.34 0 .164 r
.50957 .36928 .51069 .36634 .5127 .36568 .51158 .36861 Mtetra
.342 0 .165 r
.51158 .36861 .5127 .36568 .5147 .36504 .51359 .36796 Mtetra
.347 0 .166 r
.51359 .36796 .5147 .36504 .51671 .36441 .5156 .36734 Mtetra
.35 0 .168 r
.5156 .36734 .51671 .36441 .51872 .36378 .51762 .36673 Mtetra
.351 0 .17 r
.51762 .36673 .51872 .36378 .52073 .36317 .51963 .36613 Mtetra
.348 0 .17 r
.51963 .36613 .52073 .36317 .52275 .36254 .52165 .3655 Mtetra
.345 0 .168 r
.52165 .3655 .52275 .36254 .52476 .3619 .52367 .36485 Mtetra
.342 0 .166 r
.52367 .36485 .52476 .3619 .52678 .36126 .52569 .36419 Mtetra
.341 0 .164 r
.52569 .36419 .52678 .36126 .52879 .36062 .52771 .36353 Mtetra
.34 0 .162 r
.52771 .36353 .52879 .36062 .53081 .35997 .52973 .36287 Mtetra
.338 0 .161 r
.52973 .36287 .53081 .35997 .53283 .35931 .53175 .3622 Mtetra
.337 0 .159 r
.53175 .3622 .53283 .35931 .53486 .35866 .53378 .36153 Mtetra
.336 0 .157 r
.53378 .36153 .53486 .35866 .53688 .358 .53581 .36086 Mtetra
.335 0 .156 r
.53581 .36086 .53688 .358 .5389 .35734 .53784 .36018 Mtetra
.334 0 .154 r
.53784 .36018 .5389 .35734 .54093 .35668 .53987 .35951 Mtetra
.333 0 .153 r
.53987 .35951 .54093 .35668 .54296 .35602 .5419 .35883 Mtetra
.332 0 .151 r
.5419 .35883 .54296 .35602 .54499 .35535 .54393 .35816 Mtetra
.331 0 .15 r
.54393 .35816 .54499 .35535 .54702 .35468 .54596 .35748 Mtetra
.33 0 .148 r
.54596 .35748 .54702 .35468 .54905 .35401 .548 .3568 Mtetra
.33 0 .147 r
.548 .3568 .54905 .35401 .55109 .35334 .55004 .35612 Mtetra
.329 0 .146 r
.55004 .35612 .55109 .35334 .55312 .35267 .55208 .35544 Mtetra
.328 0 .145 r
.55208 .35544 .55312 .35267 .55516 .35199 .55412 .35475 Mtetra
.328 0 .144 r
.55412 .35475 .55516 .35199 .5572 .35131 .55616 .35407 Mtetra
.327 0 .144 r
.55616 .35407 .5572 .35131 .55924 .35063 .5582 .35338 Mtetra
.327 0 .143 r
.5582 .35338 .55924 .35063 .56128 .34995 .56025 .35269 Mtetra
.326 0 .143 r
.56025 .35269 .56128 .34995 .56332 .34926 .5623 .35201 Mtetra
.326 0 .142 r
.5623 .35201 .56332 .34926 .56537 .34858 .56434 .35132 Mtetra
.56434 .35132 .56537 .34858 .56741 .34789 .56639 .35063 Mtetra
.326 0 .141 r
.56639 .35063 .56741 .34789 .56946 .3472 .56844 .34994 Mtetra
.56844 .34994 .56946 .3472 .57151 .34651 .5705 .34925 Mtetra
.325 0 .141 r
.5705 .34925 .57151 .34651 .57356 .34582 .57255 .34856 Mtetra
.57255 .34856 .57356 .34582 .57561 .34513 .57461 .34786 Mtetra
.57461 .34786 .57561 .34513 .57767 .34444 .57666 .34717 Mtetra
.57666 .34717 .57767 .34444 .57972 .34375 .57872 .34648 Mtetra
.57872 .34648 .57972 .34375 .58178 .34305 .58078 .34578 Mtetra
.58078 .34578 .58178 .34305 .58384 .34236 .58284 .34509 Mtetra
.58284 .34509 .58384 .34236 .58589 .34167 .58491 .34439 Mtetra
.58491 .34439 .58589 .34167 .58796 .34097 .58697 .3437 Mtetra
.58697 .3437 .58796 .34097 .59002 .34028 .58904 .343 Mtetra
.58904 .343 .59002 .34028 .59208 .33958 .59111 .34231 Mtetra
.59111 .34231 .59208 .33958 .59415 .33888 .59318 .34161 Mtetra
.59318 .34161 .59415 .33888 .59622 .33818 .59525 .34091 Mtetra
.59525 .34091 .59622 .33818 .59829 .33749 .59732 .34021 Mtetra
.59732 .34021 .59829 .33749 .60036 .33679 .59939 .33951 Mtetra
.59939 .33951 .60036 .33679 .60243 .33609 .60147 .33881 Mtetra
.60147 .33881 .60243 .33609 .6045 .33539 .60355 .33811 Mtetra
.60355 .33811 .6045 .33539 .60658 .33468 .60563 .33741 Mtetra
.60563 .33741 .60658 .33468 .60865 .33398 .60771 .33671 Mtetra
.60771 .33671 .60865 .33398 .61073 .33328 .60979 .33601 Mtetra
.60979 .33601 .61073 .33328 .61281 .33258 .61187 .3353 Mtetra
.61187 .3353 .61281 .33258 .61489 .33187 .61396 .3346 Mtetra
.61396 .3346 .61489 .33187 .61697 .33116 .61604 .3339 Mtetra
.325 0 .142 r
.61604 .3339 .61697 .33116 .61906 .33046 .61813 .33319 Mtetra
.61813 .33319 .61906 .33046 .62114 .32974 .62022 .33248 Mtetra
.326 0 .142 r
.62022 .33248 .62114 .32974 .62323 .32903 .62231 .33178 Mtetra
.326 0 .143 r
.62231 .33178 .62323 .32903 .62532 .32832 .6244 .33107 Mtetra
.6244 .33107 .62532 .32832 .62741 .3276 .6265 .33035 Mtetra
.326 0 .144 r
.6265 .33035 .62741 .3276 .6295 .32687 .62859 .32964 Mtetra
.326 0 .145 r
.62859 .32964 .6295 .32687 .63159 .32614 .63069 .32892 Mtetra
.327 0 .147 r
.63069 .32892 .63159 .32614 .63369 .3254 .63279 .3282 Mtetra
.328 0 .149 r
.63279 .3282 .63369 .3254 .63578 .32464 .63489 .32748 Mtetra
.329 0 .153 r
.63489 .32748 .63578 .32464 .63788 .32388 .63699 .32674 Mtetra
.33 0 .156 r
.63699 .32674 .63788 .32388 .63997 .32302 .63909 .326 Mtetra
.335 0 .168 r
.63909 .326 .63997 .32302 .64206 .32198 .6412 .32525 Mtetra
.351 0 .197 r
.6412 .32525 .64206 .32198 .64416 .32123 .6433 .32449 Mtetra
.349 0 .195 r
.6433 .32449 .64416 .32123 .6463 .32126 .64541 .32372 Mtetra
.293 0 .102 r
.64541 .32372 .6463 .32126 .64847 .32223 .64752 .32295 Mtetra
0 0 0 r
.64752 .32295 .64847 .32223 .65063 .32291 .64962 .32216 Mtetra
.635 .872 .986 r
.64962 .32216 .65063 .32291 .65278 .32306 .65173 .32139 Mtetra
.655 .707 .885 r
.65173 .32139 .65278 .32306 .6549 .32244 .65385 .32061 Mtetra
.651 .683 .867 r
.65385 .32061 .6549 .32244 .65701 .32161 .65596 .31985 Mtetra
.65 .691 .875 r
.65596 .31985 .65701 .32161 .65912 .32074 .65808 .3191 Mtetra
.65 .709 .891 r
.65808 .3191 .65912 .32074 .66123 .32 .66019 .31836 Mtetra
.647 .708 .892 r
.66019 .31836 .66123 .32 .66335 .31925 .66231 .31763 Mtetra
.641 .709 .897 r
.66231 .31763 .66335 .31925 .66547 .31847 .66444 .31694 Mtetra
.628 .717 .911 r
.66444 .31694 .66547 .31847 .66759 .31764 .66657 .31631 Mtetra
.635 .757 .936 r
.66657 .31631 .66759 .31764 .66971 .31682 .66869 .31565 Mtetra
.632 .785 .955 r
.66869 .31565 .66971 .31682 .67184 .31622 .67082 .31498 Mtetra
.601 .758 .954 r
.67082 .31498 .67184 .31622 .674 .3162 .67296 .31444 Mtetra
.694 .711 .862 r
.67296 .31444 .674 .3162 .67614 .31569 .67508 .31342 Mtetra
.798 .697 .753 r
.67508 .31342 .67614 .31569 .67822 .31387 .67713 .3111 Mtetra
.943 .706 .55 r
.67713 .3111 .67822 .31387 .67999 .30597 .67884 .30172 Mtetra
.976 .672 .348 r
.67884 .30172 .67999 .30597 .67132 .09035 .67037 .0889 Mtetra
.943 .782 .653 r
.67037 .0889 .67132 .09035 .67308 .08533 .67216 .08438 Mtetra
.756 .856 .925 r
.67216 .08438 .67308 .08533 .67504 .08423 .67411 .0832 Mtetra
.605 .789 .969 r
.67411 .0832 .67504 .08423 .67704 .08383 .67611 .08266 Mtetra
.548 .732 .96 r
.67611 .08266 .67704 .08383 .67906 .08369 .67811 .08234 Mtetra
.68 .754 .907 r
.67811 .08234 .67906 .08369 .68104 .08297 .68009 .08151 Mtetra
.674 .734 .895 r
.68009 .08151 .68104 .08297 .68302 .08218 .68207 .08071 Mtetra
.672 .73 .893 r
.68207 .08071 .68302 .08218 .685 .08125 .68406 .07991 Mtetra
.713 .768 .896 r
.68406 .07991 .685 .08125 .68695 .07982 .68603 .07891 Mtetra
.606 .816 .98 r
.68603 .07891 .68695 .07982 .68892 .07882 .68803 .07833 Mtetra
.011 .54 .853 r
.68803 .07833 .68892 .07882 .69095 .0788 .69009 .07875 Mtetra
.893 .469 .116 r
.69009 .07875 .69095 .0788 .69327 .08357 .69251 .08534 Mtetra
.972 .658 .317 r
.69251 .08534 .69327 .08357 .7079 .29825 .70695 .29791 Mtetra
.795 .306 0 r
.70695 .29791 .7079 .29825 .71039 .30324 .70938 .30184 Mtetra
.338 .59 .938 r
.70938 .30184 .71039 .30324 .71261 .30365 .71161 .3022 Mtetra
.659 .747 .915 r
.71161 .3022 .71261 .30365 .71477 .30284 .71376 .30141 Mtetra
.838 .808 .821 r
.71376 .30141 .71477 .30284 .71684 .30064 .71584 .29931 Mtetra
.979 .779 .564 r
.71584 .29931 .71684 .30064 .71855 .29278 .71759 .29199 Mtetra
.975 .67 .321 r
.71759 .29199 .71855 .29278 .70719 .07696 .7063 .07623 Mtetra
.989 .827 .59 r
.7063 .07623 .70719 .07696 .70891 .07169 .708 .07066 Mtetra
.774 .849 .907 r
.708 .07066 .70891 .07169 .71088 .07051 .70997 .06936 Mtetra
.621 .772 .953 r
.70997 .06936 .71088 .07051 .71291 .07004 .71199 .06877 Mtetra
.532 .706 .951 r
.71199 .06877 .71291 .07004 .71496 .06991 .71403 .06852 Mtetra
.745 .775 .877 r
.71403 .06852 .71496 .06991 .71694 .06884 .71601 .06731 Mtetra
.674 .723 .887 r
.71601 .06731 .71694 .06884 .71895 .06803 .71801 .06648 Mtetra
.493 .631 .914 r
.71801 .06648 .71895 .06803 .721 .06779 .72007 .06644 Mtetra
.754 .334 0 r
.72007 .06644 .721 .06779 .72324 .07034 .72248 .07146 Mtetra
.97 .654 .299 r
.72248 .07146 .72324 .07034 .73917 .27044 .73936 .28609 Mtetra
.608 .313 .444 r
.73936 .28609 .73917 .27044 .74262 .28816 .74193 .29099 Mtetra
.373 .764 .988 r
.05163 .52262 .05299 .52318 .05459 .52323 .05325 .5225 Mtetra
.72 .836 .937 r
.05325 .5225 .05459 .52323 .0563 .52251 .05499 .52162 Mtetra
.778 .806 .875 r
.05499 .52162 .0563 .52251 .05807 .52139 .05678 .52035 Mtetra
.389 .669 .971 r
.05678 .52035 .05807 .52139 .05969 .52134 .05838 .52041 Mtetra
.541 .757 .976 r
.05838 .52041 .05969 .52134 .06136 .52092 .06003 .52014 Mtetra
.748 .828 .913 r
.06003 .52014 .06136 .52092 .06314 .51973 .06179 .5191 Mtetra
.922 .764 .667 r
.06179 .5191 .06314 .51973 .06557 .51384 .06417 .51359 Mtetra
.938 .688 .532 r
.06417 .51359 .06557 .51384 .09549 .30747 .09422 .30694 Mtetra
.93 .752 .64 r
.09422 .30694 .09549 .30747 .09785 .30136 .09665 .30029 Mtetra
.786 .767 .836 r
.09665 .30029 .09785 .30136 .09954 .30002 .09836 .29892 Mtetra
.646 .74 .918 r
.09836 .29892 .09954 .30002 .10113 .29949 .09995 .29838 Mtetra
.525 .698 .948 r
.09995 .29838 .10113 .29949 .10267 .29935 .10149 .29822 Mtetra
.762 .756 .847 r
.10149 .29822 .10267 .29935 .10433 .29831 .10317 .29703 Mtetra
.715 .725 .858 r
.10317 .29703 .10433 .29831 .10595 .29754 .10481 .29612 Mtetra
.558 .652 .898 r
.10481 .29612 .10595 .29754 .10749 .29743 .10636 .29591 Mtetra
.921 .53 .159 r
.10636 .29591 .10749 .29743 .10851 .3012 .10738 .29967 Mtetra
.94 .684 .521 r
.10738 .29967 .10851 .3012 .08279 .50633 .08146 .50568 Mtetra
.925 .58 .361 r
.08146 .50568 .08279 .50633 .08362 .51237 .08228 .51175 Mtetra
.076 .58 .89 r
.08228 .51175 .08362 .51237 .0852 .51276 .08388 .51202 Mtetra
.703 .837 .947 r
.08388 .51202 .0852 .51276 .08692 .5121 .08562 .51121 Mtetra
.779 .811 .878 r
.08562 .51121 .08692 .5121 .08871 .51099 .08742 .50993 Mtetra
.573 .744 .957 r
.08742 .50993 .08871 .51099 .09042 .51041 .08911 .50959 Mtetra
.54 .783 .988 r
.08911 .50959 .09042 .51041 .09212 .50989 .09079 .50928 Mtetra
.643 .854 .98 r
.09079 .50928 .09212 .50989 .09384 .5093 .09251 .50865 Mtetra
.832 .845 .856 r
.09251 .50865 .09384 .5093 .09553 .50891 .09437 .50698 Mtetra
.818 .69 .723 r
.09437 .50698 .09553 .50891 .09727 .50819 .09636 .50421 Mtetra
.808 .612 .637 r
.09636 .50421 .09727 .50819 .0991 .50673 .09869 .4989 Mtetra
.933 .679 .529 r
.09869 .4989 .0991 .50673 .10149 .5009 .12619 .29658 Mtetra
.526 .292 .502 r
.12619 .29658 .10149 .5009 .12926 .29496 .12856 .29011 Mtetra
.716 .532 .639 r
.12856 .29011 .12926 .29496 .13156 .28899 .13047 .28719 Mtetra
.709 .658 .797 r
.13047 .28719 .13156 .28899 .1333 .28742 .13215 .28614 Mtetra
.609 .696 .905 r
.13215 .28614 .1333 .28742 .13492 .28686 .13374 .28574 Mtetra
.506 .69 .951 r
.13374 .28574 .13492 .28686 .13648 .28669 .1353 .28561 Mtetra
.618 .739 .933 r
.1353 .28561 .13648 .28669 .13808 .28623 .1369 .28517 Mtetra
.66 .755 .92 r
.1369 .28517 .13808 .28623 .1397 .28566 .13852 .28458 Mtetra
.676 .753 .909 r
.13852 .28458 .1397 .28566 .14132 .28507 .14016 .28391 Mtetra
.731 .751 .868 r
.14016 .28391 .14132 .28507 .14296 .28436 .14183 .28293 Mtetra
.711 .706 .844 r
.14183 .28293 .14296 .28436 .1446 .28362 .14349 .28201 Mtetra
.655 .662 .844 r
.14349 .28201 .1446 .28362 .14624 .28294 .14512 .28137 Mtetra
.406 .556 .892 r
.14512 .28137 .14624 .28294 .14789 .28214 .14665 .2816 Mtetra
.611 .045 0 r
.14665 .2816 .14789 .28214 .14951 .28159 .14806 .2828 Mtetra
.804 .428 .345 r
.14806 .2828 .14951 .28159 .15106 .28166 .14922 .28605 Mtetra
.938 .676 .515 r
.14922 .28605 .15106 .28166 .15221 .28508 .12663 .48675 Mtetra
.524 .285 .494 r
.12663 .48675 .15221 .28508 .12932 .48975 .12746 .49366 Mtetra
.659 .318 .384 r
.12746 .49366 .12932 .48975 .13024 .49603 .12886 .49591 Mtetra
.088 0 0 r
.12886 .49591 .13024 .49603 .13182 .49683 .13051 .49609 Mtetra
.655 .834 .969 r
.13051 .49609 .13182 .49683 .13356 .49624 .13226 .49543 Mtetra
.74 .831 .921 r
.13226 .49543 .13356 .49624 .13536 .49514 .13406 .49443 Mtetra
.706 .846 .95 r
.13406 .49443 .13536 .49514 .13714 .49424 .13583 .49358 Mtetra
.684 .855 .964 r
.13583 .49358 .13714 .49424 .13891 .49345 .1376 .49281 Mtetra
.691 .862 .963 r
.1376 .49281 .13891 .49345 .14069 .49262 .13937 .49201 Mtetra
.714 .869 .955 r
.13937 .49201 .14069 .49262 .14246 .49178 .14115 .49112 Mtetra
.722 .86 .947 r
.14115 .49112 .14246 .49178 .14424 .49097 .14294 .4902 Mtetra
.71 .839 .943 r
.14294 .4902 .14424 .49097 .14601 .49021 .14472 .48934 Mtetra
.66 .809 .955 r
.14472 .48934 .14601 .49021 .14776 .48961 .14648 .48868 Mtetra
.611 .784 .964 r
.14648 .48868 .14776 .48961 .1495 .48914 .14822 .4882 Mtetra
.575 .771 .972 r
.14822 .4882 .1495 .48914 .15123 .48872 .14995 .48782 Mtetra
.259 .635 .962 r
.14995 .48782 .15123 .48872 .15291 .48881 .15162 .48802 Mtetra
.31 .689 .978 r
.15162 .48802 .15291 .48881 .1546 .48875 .1533 .4881 Mtetra
.66 .854 .974 r
.1533 .4881 .1546 .48875 .15638 .48795 .15507 .4874 Mtetra
.925 .803 .706 r
.15507 .4874 .15638 .48795 .15854 .48378 .15722 .48331 Mtetra
.947 .69 .513 r
.15722 .48331 .15854 .48378 .183 .27732 .18184 .27614 Mtetra
.927 .723 .607 r
.18184 .27614 .183 .27732 .18551 .26894 .18439 .26744 Mtetra
.815 .721 .762 r
.18439 .26744 .18551 .26894 .18733 .2668 .18621 .26535 Mtetra
.631 .68 .878 r
.18621 .26535 .18733 .2668 .18898 .26617 .18785 .26485 Mtetra
.472 .636 .927 r
.18785 .26485 .18898 .26617 .19059 .26601 .18943 .26485 Mtetra
.556 .704 .939 r
.18943 .26485 .19059 .26601 .19221 .26568 .19105 .2646 Mtetra
.649 .752 .925 r
.19105 .2646 .19221 .26568 .19386 .26512 .1927 .26403 Mtetra
.667 .755 .916 r
.1927 .26403 .19386 .26512 .19552 .26454 .19436 .26339 Mtetra
.75 .762 .863 r
.19436 .26339 .19552 .26454 .19721 .26357 .19608 .26229 Mtetra
.743 .739 .848 r
.19608 .26229 .19721 .26357 .19891 .2626 .19779 .26118 Mtetra
.633 .685 .881 r
.19779 .26118 .19891 .2626 .20055 .2622 .19944 .26067 Mtetra
.627 .181 0 r
.19944 .26067 .20055 .2622 .20192 .26431 .20082 .26274 Mtetra
.95 .685 .499 r
.20082 .26274 .20192 .26431 .18241 .46713 .18112 .46646 Mtetra
.942 .624 .404 r
.18112 .46646 .18241 .46713 .183 .47786 .18171 .47723 Mtetra
.664 .115 0 r
.18171 .47723 .183 .47786 .18456 .47941 .18326 .47879 Mtetra
.572 .84 .995 r
.18326 .47879 .18456 .47941 .18632 .47899 .18503 .47831 Mtetra
.783 .863 .908 r
.18503 .47831 .18632 .47899 .18814 .47798 .18688 .47705 Mtetra
.825 .813 .839 r
.18688 .47705 .18814 .47798 .18994 .47724 .18878 .47531 Mtetra
.803 .693 .743 r
.18878 .47531 .18994 .47724 .19172 .47665 .19074 .47296 Mtetra
.785 .605 .657 r
.19074 .47296 .19172 .47665 .19356 .47548 .19285 .46911 Mtetra
.893 .645 .556 r
.19285 .46911 .19356 .47548 .19565 .4718 .19693 .4456 Mtetra
.921 .656 .519 r
.19693 .4456 .19565 .4718 .21758 .26854 .2173 .25862 Mtetra
.661 .447 .584 r
.2173 .25862 .21758 .26854 .22037 .25672 .2193 .25479 Mtetra
.767 .673 .758 r
.2193 .25479 .22037 .25672 .22224 .25409 .22108 .25305 Mtetra
.683 .771 .918 r
.22108 .25305 .22224 .25409 .22393 .25331 .22277 .25234 Mtetra
.59 .759 .959 r
.22277 .25234 .22393 .25331 .22558 .25302 .22442 .25195 Mtetra
.653 .758 .927 r
.22442 .25195 .22558 .25302 .22723 .2526 .2261 .25136 Mtetra
.699 .738 .882 r
.2261 .25136 .22723 .2526 .22892 .2519 .2278 .25054 Mtetra
.651 .705 .886 r
.2278 .25054 .22892 .2519 .2306 .25124 .22948 .24995 Mtetra
.475 .646 .933 r
.22948 .24995 .2306 .25124 .2323 .25046 .2311 .24993 Mtetra
.416 0 0 r
.2311 .24993 .2323 .25046 .23399 .24973 .23264 .25082 Mtetra
.762 .348 .266 r
.23264 .25082 .23399 .24973 .23564 .24952 .23404 .25318 Mtetra
.947 .678 .494 r
.23404 .25318 .23564 .24952 .23708 .25144 .21745 .44695 Mtetra
.54 .298 .497 r
.21745 .44695 .23708 .25144 .21994 .45309 .21783 .46145 Mtetra
.624 .322 .437 r
.21783 .46145 .21994 .45309 .22062 .46455 .2193 .46442 Mtetra
.533 0 0 r
.2193 .46442 .22062 .46455 .22219 .46643 .22095 .46538 Mtetra
.48 .716 .974 r
.22095 .46538 .22219 .46643 .22396 .46615 .22272 .46525 Mtetra
.671 .812 .951 r
.22272 .46525 .22396 .46615 .22579 .46527 .22453 .46453 Mtetra
.798 .855 .893 r
.22453 .46453 .22579 .46527 .22762 .46447 .22641 .46315 Mtetra
.838 .76 .777 r
.22641 .46315 .22762 .46447 .22942 .46389 .22837 .46084 Mtetra
.811 .639 .668 r
.22837 .46084 .22942 .46389 .23128 .46273 .23047 .45695 Mtetra
.888 .643 .562 r
.23047 .45695 .23128 .46273 .23333 .45944 .23386 .43872 Mtetra
.932 .664 .509 r
.23386 .43872 .23333 .45944 .25272 .25972 .2528 .24486 Mtetra
.621 .4 .56 r
.2528 .24486 .25272 .25972 .25579 .24358 .25479 .24094 Mtetra
.738 .613 .719 r
.25479 .24094 .25579 .24358 .25769 .24058 .25659 .23911 Mtetra
.653 .689 .871 r
.25659 .23911 .25769 .24058 .25941 .23972 .25829 .23848 Mtetra
.556 .694 .932 r
.25829 .23848 .25941 .23972 .26109 .23938 .25996 .23823 Mtetra
.561 .714 .943 r
.25996 .23823 .26109 .23938 .26276 .23908 .26163 .23795 Mtetra
.652 .749 .921 r
.26163 .23795 .26276 .23908 .26446 .23849 .26333 .23735 Mtetra
.669 .754 .914 r
.26333 .23735 .26446 .23849 .26616 .23788 .26503 .23669 Mtetra
.706 .754 .889 r
.26503 .23669 .26616 .23788 .26787 .2372 .26676 .23584 Mtetra
.726 .73 .854 r
.26676 .23584 .26787 .2372 .26959 .23643 .2685 .23482 Mtetra
.679 .679 .843 r
.2685 .23482 .26959 .23643 .2713 .2357 .27022 .23402 Mtetra
.56 .62 .869 r
.27022 .23402 .2713 .2357 .27302 .23495 .27189 .2338 Mtetra
0 .38 .837 r
.27189 .2338 .27302 .23495 .27473 .23423 .27348 .23459 Mtetra
.78 .32 .152 r
.27348 .23459 .27473 .23423 .27641 .23401 .27496 .23679 Mtetra
.893 .582 .451 r
.27496 .23679 .27641 .23401 .27795 .23548 .27553 .25034 Mtetra
.937 .661 .492 r
.27553 .25034 .27795 .23548 .2641 .42894 .26137 .44676 Mtetra
.577 .304 .466 r
.26137 .44676 .2641 .42894 .26424 .4494 .26289 .45001 Mtetra
.592 .073 0 r
.26289 .45001 .26424 .4494 .26583 .45174 .26459 .45102 Mtetra
.539 .812 .996 r
.26459 .45102 .26583 .45174 .26764 .45146 .26641 .45063 Mtetra
.684 .833 .955 r
.26641 .45063 .26764 .45146 .2695 .45058 .26826 .44984 Mtetra
.68 .85 .964 r
.26826 .44984 .2695 .45058 .27136 .44962 .27011 .44905 Mtetra
.542 .844 .999 r
.27011 .44905 .27136 .44962 .2732 .44906 .27194 .44859 Mtetra
.616 .889 .989 r
.27194 .44859 .2732 .44906 .27504 .44845 .27378 .44792 Mtetra
.788 .901 .922 r
.27378 .44792 .27504 .44845 .27689 .44771 .27568 .44661 Mtetra
.87 .792 .77 r
.27568 .44661 .27689 .44771 .27875 .44676 .27767 .444 Mtetra
.822 .655 .676 r
.27767 .444 .27875 .44676 .28062 .44577 .27975 .44023 Mtetra
.744 .545 .626 r
.27975 .44023 .28062 .44577 .28247 .44505 .28185 .43608 Mtetra
.525 .352 .589 r
.28185 .43608 .28247 .44505 .28429 .44488 .28366 .43598 Mtetra
.531 .357 .59 r
.28366 .43598 .28429 .44488 .28613 .44425 .28547 .43576 Mtetra
.691 .48 .596 r
.28547 .43576 .28613 .44425 .2881 .44203 .28758 .43148 Mtetra
.949 .678 .49 r
.28758 .43148 .2881 .44203 .29066 .43147 .30414 .22753 Mtetra
.522 .288 .501 r
.30414 .22753 .29066 .43147 .30719 .22526 .30621 .22228 Mtetra
.761 .609 .691 r
.30621 .22228 .30719 .22526 .30916 .22134 .30807 .21981 Mtetra
.672 .691 .859 r
.30807 .21981 .30916 .22134 .31092 .22031 .30981 .21907 Mtetra
.578 .705 .929 r
.30981 .21907 .31092 .22031 .31264 .21987 .31152 .21874 Mtetra
.546 .715 .951 r
.31152 .21874 .31264 .21987 .31435 .2196 .31323 .21849 Mtetra
.657 .759 .925 r
.31323 .21849 .31435 .2196 .31608 .21897 .31497 .21786 Mtetra
.673 .764 .919 r
.31497 .21786 .31608 .21897 .31782 .21833 .31671 .21717 Mtetra
.698 .76 .9 r
.31671 .21717 .31782 .21833 .31956 .21766 .31846 .21635 Mtetra
.731 .744 .862 r
.31846 .21635 .31956 .21766 .32131 .21689 .32023 .2153 Mtetra
.689 .689 .845 r
.32023 .2153 .32131 .21689 .32305 .21615 .32198 .21445 Mtetra
.587 .632 .863 r
.32198 .21445 .32305 .21615 .32479 .21551 .3237 .21411 Mtetra
0 .335 .817 r
.3237 .21411 .32479 .21551 .32652 .21509 .32534 .21508 Mtetra
.762 .262 .024 r
.32534 .21508 .32652 .21509 .32825 .21471 .32692 .21708 Mtetra
.734 .357 .336 r
.32692 .21708 .32825 .21471 .32999 .21417 .32844 .21995 Mtetra
.372 .069 .316 r
.32844 .21995 .32999 .21417 .33177 .21304 .33022 .21875 Mtetra
.37 .066 .314 r
.33022 .21875 .33177 .21304 .33352 .21231 .33201 .21754 Mtetra
.579 .251 .378 r
.33201 .21754 .33352 .21231 .3352 .21269 .33364 .21887 Mtetra
.954 .674 .469 r
.33364 .21887 .3352 .21269 .33652 .21911 .32265 .42275 Mtetra
.519 .28 .493 r
.32265 .42275 .33652 .21911 .32549 .42678 .32416 .428 Mtetra
.691 .242 .182 r
.32416 .428 .32549 .42678 .3271 .43053 .32589 .42978 Mtetra
.565 .82 .993 r
.32589 .42978 .3271 .43053 .32894 .43044 .32775 .42932 Mtetra
.71 .789 .913 r
.32775 .42932 .32894 .43044 .33083 .42964 .32965 .42839 Mtetra
.719 .769 .891 r
.32965 .42839 .33083 .42964 .33273 .42858 .33155 .42738 Mtetra
.523 .71 .957 r
.33155 .42738 .33273 .42858 .33461 .42807 .33341 .42717 Mtetra
.557 .786 .984 r
.33341 .42717 .33461 .42807 .33649 .42752 .33528 .42678 Mtetra
.686 .86 .965 r
.33528 .42678 .33649 .42752 .33837 .42691 .33718 .42595 Mtetra
.849 .826 .825 r
.33718 .42595 .33837 .42691 .34024 .42646 .33914 .42393 Mtetra
.819 .668 .695 r
.33914 .42393 .34024 .42646 .34215 .42553 .34118 .42065 Mtetra
.833 .612 .603 r
.34118 .42065 .34215 .42553 .34411 .4235 .34345 .41322 Mtetra
.955 .679 .475 r
.34345 .41322 .34411 .4235 .34646 .41464 .35671 .20752 Mtetra
.521 .287 .501 r
.35671 .20752 .34646 .41464 .35968 .20606 .35873 .20243 Mtetra
.742 .576 .67 r
.35873 .20243 .35968 .20606 .36166 .20149 .3606 .19984 Mtetra
.701 .689 .835 r
.3606 .19984 .36166 .20149 .36346 .20035 .36238 .19887 Mtetra
.626 .686 .886 r
.36238 .19887 .36346 .20035 .36522 .19986 .36414 .19836 Mtetra
.567 .657 .897 r
.36414 .19836 .36522 .19986 .36696 .19967 .36589 .19808 Mtetra
.608 .661 .876 r
.36589 .19808 .36696 .19967 .36873 .19908 .36765 .19764 Mtetra
.604 .685 .899 r
.36765 .19764 .36873 .19908 .3705 .19848 .36942 .19722 Mtetra
.61 .719 .923 r
.36942 .19722 .3705 .19848 .37227 .19787 .37118 .19677 Mtetra
.647 .762 .933 r
.37118 .19677 .37227 .19787 .37404 .19724 .37295 .19617 Mtetra
.668 .775 .929 r
.37295 .19617 .37404 .19724 .37582 .19659 .37473 .19548 Mtetra
.687 .773 .917 r
.37473 .19548 .37582 .19659 .3776 .19591 .37651 .19471 Mtetra
.71 .763 .894 r
.37651 .19471 .3776 .19591 .37938 .19517 .3783 .19381 Mtetra
.707 .735 .872 r
.3783 .19381 .37938 .19517 .38116 .19441 .3801 .19289 Mtetra
.697 .706 .855 r
.3801 .19289 .38116 .19441 .38295 .19365 .38189 .19199 Mtetra
.702 .689 .835 r
.38189 .19199 .38295 .19365 .38474 .19287 .38369 .19102 Mtetra
.664 .651 .827 r
.38369 .19102 .38474 .19287 .38652 .19213 .38547 .19025 Mtetra
.606 .621 .84 r
.38547 .19025 .38652 .19213 .38831 .19146 .38725 .18981 Mtetra
.162 .407 .85 r
.38725 .18981 .38831 .19146 .39008 .19104 .38897 .19065 Mtetra
.697 .156 0 r
.38897 .19065 .39008 .19104 .39186 .19066 .39065 .19244 Mtetra
.781 .387 .308 r
.39065 .19244 .39186 .19066 .39363 .19027 .39226 .19584 Mtetra
.529 .206 .365 r
.39226 .19584 .39363 .19027 .39542 .18958 .394 .19647 Mtetra
.399 .108 .349 r
.394 .19647 .39542 .18958 .39722 .18881 .39581 .19527 Mtetra
.327 .041 .317 r
.39581 .19527 .39722 .18881 .39901 .18802 .39766 .19337 Mtetra
.271 0 .269 r
.39766 .19337 .39901 .18802 .40083 .18683 .39952 .19139 Mtetra
.35 .029 .273 r
.39952 .19139 .40083 .18683 .40263 .186 .40133 .19029 Mtetra
.51 .168 .322 r
.40133 .19029 .40263 .186 .4044 .18589 .40309 .19069 Mtetra
.961 .675 .446 r
.40309 .19069 .4044 .18589 .40601 .19011 .39677 .39383 Mtetra
.525 .284 .493 r
.39677 .39383 .40601 .19011 .39964 .39955 .39835 .40185 Mtetra
.709 .311 .291 r
.39835 .40185 .39964 .39955 .40133 .40505 .40016 .40439 Mtetra
.335 .736 .982 r
.40016 .40439 .40133 .40505 .40322 .4053 .40206 .40434 Mtetra
.659 .814 .958 r
.40206 .40434 .40322 .4053 .40516 .40456 .404 .40361 Mtetra
.733 .835 .928 r
.404 .40361 .40516 .40456 .40711 .40336 .40595 .40256 Mtetra
.696 .854 .958 r
.40595 .40256 .40711 .40336 .40905 .4026 .40789 .40167 Mtetra
.698 .829 .945 r
.40789 .40167 .40905 .4026 .41099 .4019 .40984 .40078 Mtetra
.693 .793 .927 r
.40984 .40078 .41099 .4019 .41293 .40119 .41178 .39992 Mtetra
.66 .754 .92 r
.41178 .39992 .41293 .40119 .41487 .4005 .41372 .3992 Mtetra
.639 .742 .923 r
.41372 .3992 .41487 .4005 .41681 .39984 .41566 .39858 Mtetra
.62 .742 .934 r
.41566 .39858 .41681 .39984 .41875 .39921 .4176 .39803 Mtetra
.507 .712 .964 r
.4176 .39803 .41875 .39921 .42068 .3987 .41953 .39784 Mtetra
.513 .783 .994 r
.41953 .39784 .42068 .3987 .42262 .39819 .42146 .39753 Mtetra
.624 .867 .988 r
.42146 .39753 .42262 .39819 .42457 .39759 .42341 .39684 Mtetra
.843 .879 .867 r
.42341 .39684 .42457 .39759 .42651 .39715 .4254 .39505 Mtetra
.836 .705 .719 r
.4254 .39505 .42651 .39715 .42846 .39634 .42742 .39204 Mtetra
.83 .619 .617 r
.42742 .39204 .42846 .39634 .43044 .39471 .42952 .38599 Mtetra
.963 .68 .449 r
.42952 .38599 .43044 .39471 .43256 .38821 .43749 .17852 Mtetra
.523 .289 .501 r
.43749 .17852 .43256 .38821 .44043 .17704 .43947 .17238 Mtetra
.726 .542 .641 r
.43947 .17238 .44043 .17704 .4424 .1713 .44136 .16939 Mtetra
.729 .675 .797 r
.44136 .16939 .4424 .1713 .44425 .16964 .4432 .1681 Mtetra
.654 .693 .874 r
.4432 .1681 .44425 .16964 .44607 .16898 .44502 .16743 Mtetra
.592 .666 .89 r
.44502 .16743 .44607 .16898 .44788 .1687 .44684 .16705 Mtetra
.607 .656 .872 r
.44684 .16705 .44788 .1687 .4497 .16816 .44866 .1666 Mtetra
.613 .672 .883 r
.44866 .1666 .4497 .16816 .45153 .16754 .45048 .16612 Mtetra
.623 .702 .902 r
.45048 .16612 .45153 .16754 .45336 .1669 .45231 .16561 Mtetra
.675 .743 .902 r
.45231 .16561 .45336 .1669 .45518 .16622 .45414 .16486 Mtetra
.694 .738 .885 r
.45414 .16486 .45518 .16622 .45702 .16551 .45597 .16401 Mtetra
.69 .713 .866 r
.45597 .16401 .45702 .16551 .45885 .1648 .45781 .16314 Mtetra
.693 .692 .845 r
.45781 .16314 .45885 .1648 .46068 .16406 .45965 .16223 Mtetra
.665 .658 .833 r
.45965 .16223 .46068 .16406 .46252 .16334 .46149 .16144 Mtetra
.614 .626 .839 r
.46149 .16144 .46252 .16334 .46435 .16268 .46332 .16094 Mtetra
.318 .489 .87 r
.46332 .16094 .46435 .16268 .46618 .16223 .46513 .16149 Mtetra
.552 .01 0 r
.46513 .16149 .46618 .16223 .46802 .16188 .46692 .16313 Mtetra
.794 .372 .245 r
.46692 .16313 .46802 .16188 .46985 .16154 .46869 .16642 Mtetra
.643 .3 .377 r
.46869 .16642 .46985 .16154 .47169 .16097 .47048 .16888 Mtetra
.462 .17 .383 r
.47048 .16888 .47169 .16097 .47353 .16026 .47232 .16839 Mtetra
.369 .095 .36 r
.47232 .16839 .47353 .16026 .47538 .15949 .4742 .16643 Mtetra
.41 .118 .355 r
.4742 .16643 .47538 .15949 .47722 .15876 .47605 .16531 Mtetra
.431 .131 .354 r
.47605 .16531 .47722 .15876 .47907 .15805 .47791 .16455 Mtetra
.429 .129 .352 r
.47791 .16455 .47907 .15805 .48091 .15734 .47976 .16376 Mtetra
.426 .125 .35 r
.47976 .16376 .48091 .15734 .48276 .15662 .48162 .16294 Mtetra
.424 .123 .348 r
.48162 .16294 .48276 .15662 .48461 .15589 .48347 .16213 Mtetra
.425 .122 .346 r
.48347 .16213 .48461 .15589 .48647 .15517 .48533 .16133 Mtetra
.337 .048 .318 r
.48533 .16133 .48647 .15517 .48832 .15409 .4872 .15956 Mtetra
.355 .053 .306 r
.4872 .15956 .48832 .15409 .49018 .15313 .48907 .15818 Mtetra
.492 .163 .337 r
.48907 .15818 .49018 .15313 .49203 .15281 .49092 .15836 Mtetra
.967 .671 .416 r
.49092 .15836 .49203 .15281 .49385 .15558 .4906 .35973 Mtetra
.528 .286 .493 r
.4906 .35973 .49385 .15558 .49365 .36525 .49248 .3696 Mtetra
.669 .311 .357 r
.49248 .3696 .49365 .36525 .49556 .37274 .49445 .37247 Mtetra
0 .447 .704 r
.49445 .37247 .49556 .37274 .49755 .37384 .49644 .37291 Mtetra
.615 .814 .977 r
.49644 .37291 .49755 .37384 .49955 .37329 .49844 .37231 Mtetra
.704 .831 .943 r
.49844 .37231 .49955 .37329 .50155 .37223 .50044 .37136 Mtetra
.672 .846 .966 r
.50044 .37136 .50155 .37223 .50355 .37134 .50245 .37054 Mtetra
.63 .847 .983 r
.50245 .37054 .50355 .37134 .50556 .37065 .50445 .36986 Mtetra
.628 .847 .983 r
.50445 .36986 .50556 .37065 .50757 .36996 .50646 .36917 Mtetra
.627 .849 .984 r
.50646 .36917 .50757 .36996 .50957 .36928 .50847 .36849 Mtetra
.622 .846 .985 r
.50847 .36849 .50957 .36928 .51158 .36861 .51048 .36782 Mtetra
.61 .842 .987 r
.51048 .36782 .51158 .36861 .51359 .36796 .51249 .36719 Mtetra
.574 .833 .994 r
.51249 .36719 .51359 .36796 .5156 .36734 .5145 .36665 Mtetra
.535 .836 .999 r
.5145 .36665 .5156 .36734 .51762 .36673 .51652 .36618 Mtetra
.51 .85 .996 r
.51652 .36618 .51762 .36673 .51963 .36613 .51853 .3657 Mtetra
.514 .873 .985 r
.51853 .3657 .51963 .36613 .52165 .3655 .52055 .36513 Mtetra
.529 .889 .977 r
.52055 .36513 .52165 .3655 .52367 .36485 .52257 .36449 Mtetra
.538 .895 .975 r
.52257 .36449 .52367 .36485 .52569 .36419 .52459 .36383 Mtetra
.54 .895 .976 r
.52459 .36383 .52569 .36419 .52771 .36353 .52661 .36316 Mtetra
.54 .894 .977 r
.52661 .36316 .52771 .36353 .52973 .36287 .52864 .3625 Mtetra
.541 .895 .977 r
.52864 .3625 .52973 .36287 .53175 .3622 .53066 .36183 Mtetra
.543 .895 .977 r
.53066 .36183 .53175 .3622 .53378 .36153 .53269 .36116 Mtetra
.544 .895 .977 r
.53269 .36116 .53378 .36153 .53581 .36086 .53472 .36048 Mtetra
.545 .896 .978 r
.53472 .36048 .53581 .36086 .53784 .36018 .53675 .35981 Mtetra
.546 .896 .978 r
.53675 .35981 .53784 .36018 .53987 .35951 .53878 .35913 Mtetra
.547 .896 .978 r
.53878 .35913 .53987 .35951 .5419 .35883 .54081 .35845 Mtetra
.548 .896 .978 r
.54081 .35845 .5419 .35883 .54393 .35816 .54285 .35777 Mtetra
.549 .896 .979 r
.54285 .35777 .54393 .35816 .54596 .35748 .54489 .35709 Mtetra
.55 .896 .979 r
.54489 .35709 .54596 .35748 .548 .3568 .54692 .35641 Mtetra
.54692 .35641 .548 .3568 .55004 .35612 .54896 .35572 Mtetra
.551 .896 .979 r
.54896 .35572 .55004 .35612 .55208 .35544 .551 .35504 Mtetra
.552 .896 .979 r
.551 .35504 .55208 .35544 .55412 .35475 .55304 .35435 Mtetra
.552 .896 .98 r
.55304 .35435 .55412 .35475 .55616 .35407 .55509 .35367 Mtetra
.55509 .35367 .55616 .35407 .5582 .35338 .55713 .35298 Mtetra
.553 .896 .98 r
.55713 .35298 .5582 .35338 .56025 .35269 .55918 .35229 Mtetra
.55918 .35229 .56025 .35269 .5623 .35201 .56123 .3516 Mtetra
.56123 .3516 .5623 .35201 .56434 .35132 .56328 .35091 Mtetra
.554 .896 .98 r
.56328 .35091 .56434 .35132 .56639 .35063 .56533 .35022 Mtetra
.56533 .35022 .56639 .35063 .56844 .34994 .56738 .34953 Mtetra
.56738 .34953 .56844 .34994 .5705 .34925 .56944 .34884 Mtetra
.56944 .34884 .5705 .34925 .57255 .34856 .57149 .34815 Mtetra
.57149 .34815 .57255 .34856 .57461 .34786 .57355 .34745 Mtetra
.57355 .34745 .57461 .34786 .57666 .34717 .57561 .34676 Mtetra
.57561 .34676 .57666 .34717 .57872 .34648 .57767 .34606 Mtetra
.57767 .34606 .57872 .34648 .58078 .34578 .57973 .34537 Mtetra
.57973 .34537 .58078 .34578 .58284 .34509 .58179 .34467 Mtetra
.58179 .34467 .58284 .34509 .58491 .34439 .58386 .34398 Mtetra
.58386 .34398 .58491 .34439 .58697 .3437 .58593 .34328 Mtetra
.58593 .34328 .58697 .3437 .58904 .343 .58799 .34258 Mtetra
.555 .896 .98 r
.58799 .34258 .58904 .343 .59111 .34231 .59006 .34189 Mtetra
.59006 .34189 .59111 .34231 .59318 .34161 .59213 .34119 Mtetra
.59213 .34119 .59318 .34161 .59525 .34091 .59421 .34049 Mtetra
.59421 .34049 .59525 .34091 .59732 .34021 .59628 .33979 Mtetra
.59628 .33979 .59732 .34021 .59939 .33951 .59836 .33909 Mtetra
.59836 .33909 .59939 .33951 .60147 .33881 .60043 .33839 Mtetra
.555 .897 .98 r
.60043 .33839 .60147 .33881 .60355 .33811 .60251 .33769 Mtetra
.60251 .33769 .60355 .33811 .60563 .33741 .60459 .33699 Mtetra
.60459 .33699 .60563 .33741 .60771 .33671 .60667 .33629 Mtetra
.60667 .33629 .60771 .33671 .60979 .33601 .60876 .33558 Mtetra
.60876 .33558 .60979 .33601 .61187 .3353 .61084 .33488 Mtetra
.61084 .33488 .61187 .3353 .61396 .3346 .61293 .33417 Mtetra
.61293 .33417 .61396 .3346 .61604 .3339 .61502 .33347 Mtetra
.61502 .33347 .61604 .3339 .61813 .33319 .61711 .33276 Mtetra
.61711 .33276 .61813 .33319 .62022 .33248 .6192 .33206 Mtetra
.6192 .33206 .62022 .33248 .62231 .33178 .62129 .33135 Mtetra
.62129 .33135 .62231 .33178 .6244 .33107 .62339 .33064 Mtetra
.62339 .33064 .6244 .33107 .6265 .33035 .62548 .32993 Mtetra
.555 .898 .979 r
.62548 .32993 .6265 .33035 .62859 .32964 .62758 .32921 Mtetra
.556 .898 .979 r
.62758 .32921 .62859 .32964 .63069 .32892 .62968 .3285 Mtetra
.556 .899 .979 r
.62968 .3285 .63069 .32892 .63279 .3282 .63178 .32778 Mtetra
.556 .899 .978 r
.63178 .32778 .63279 .3282 .63489 .32748 .63388 .32706 Mtetra
.556 .9 .978 r
.63388 .32706 .63489 .32748 .63699 .32674 .63598 .32633 Mtetra
.554 .9 .977 r
.63598 .32633 .63699 .32674 .63909 .326 .63809 .32561 Mtetra
.549 .9 .975 r
.63809 .32561 .63909 .326 .6412 .32525 .64019 .32488 Mtetra
.552 .905 .97 r
.64019 .32488 .6412 .32525 .6433 .32449 .6423 .32413 Mtetra
.575 .916 .968 r
.6423 .32413 .6433 .32449 .64541 .32372 .64441 .32332 Mtetra
.626 .929 .97 r
.64441 .32332 .64541 .32372 .64752 .32295 .64651 .32239 Mtetra
.658 .917 .977 r
.64651 .32239 .64752 .32295 .64962 .32216 .64861 .32145 Mtetra
.666 .889 .979 r
.64861 .32145 .64962 .32216 .65173 .32139 .65072 .32055 Mtetra
.643 .858 .981 r
.65072 .32055 .65173 .32139 .65385 .32061 .65283 .31977 Mtetra
.632 .852 .983 r
.65283 .31977 .65385 .32061 .65596 .31985 .65495 .31903 Mtetra
.623 .853 .986 r
.65495 .31903 .65596 .31985 .65808 .3191 .65707 .31831 Mtetra
.62 .859 .988 r
.65707 .31831 .65808 .3191 .66019 .31836 .65919 .31759 Mtetra
.614 .861 .99 r
.65919 .31759 .66019 .31836 .66231 .31763 .66131 .31688 Mtetra
.592 .855 .994 r
.66131 .31688 .66231 .31763 .66444 .31694 .66344 .31623 Mtetra
.526 .835 .999 r
.66344 .31623 .66444 .31694 .66657 .31631 .66558 .31574 Mtetra
.574 .884 .991 r
.66558 .31574 .66657 .31631 .66869 .31565 .6677 .31505 Mtetra
.721 .929 .96 r
.6677 .31505 .66869 .31565 .67082 .31498 .66981 .31389 Mtetra
.868 .857 .828 r
.66981 .31389 .67082 .31498 .67296 .31444 .67187 .31168 Mtetra
.83 .675 .691 r
.67187 .31168 .67296 .31444 .67508 .31342 .67387 .30826 Mtetra
.843 .61 .585 r
.67387 .30826 .67508 .31342 .67713 .3111 .67569 .30095 Mtetra
.973 .667 .361 r
.67569 .30095 .67713 .3111 .67884 .30172 .66757 .09113 Mtetra
.521 .286 .5 r
.66757 .09113 .67884 .30172 .67037 .0889 .66932 .08571 Mtetra
.769 .614 .687 r
.66932 .08571 .67037 .0889 .67216 .08438 .67121 .08306 Mtetra
.717 .773 .896 r
.67121 .08306 .67216 .08438 .67411 .0832 .67318 .08204 Mtetra
.626 .768 .948 r
.67318 .08204 .67411 .0832 .67611 .08266 .67517 .08144 Mtetra
.598 .745 .947 r
.67517 .08144 .67611 .08266 .67811 .08234 .67717 .08096 Mtetra
.709 .759 .892 r
.67717 .08096 .67811 .08234 .68009 .08151 .67914 .07997 Mtetra
.674 .719 .883 r
.67914 .07997 .68009 .08151 .68207 .08071 .68112 .07915 Mtetra
.598 .683 .901 r
.68112 .07915 .68207 .08071 .68406 .07991 .68312 .0787 Mtetra
.268 .565 .935 r
.68312 .0787 .68406 .07991 .68603 .07891 .68518 .07914 Mtetra
.604 .037 0 r
.68518 .07914 .68603 .07891 .68803 .07833 .6873 .08065 Mtetra
.81 .401 .273 r
.6873 .08065 .68803 .07833 .69009 .07875 .68962 .08567 Mtetra
.97 .654 .332 r
.68962 .08567 .69009 .07875 .69251 .08534 .70363 .2943 Mtetra
.516 .277 .491 r
.70363 .2943 .69251 .08534 .70695 .29791 .70608 .29885 Mtetra
.632 .113 0 r
.70608 .29885 .70695 .29791 .70938 .30184 .70838 .30049 Mtetra
.397 .633 .95 r
.70838 .30049 .70938 .30184 .71161 .3022 .71059 .30065 Mtetra
.65 .728 .906 r
.71059 .30065 .71161 .3022 .71376 .30141 .71275 .2999 Mtetra
.821 .793 .826 r
.71275 .2999 .71376 .30141 .71584 .29931 .71484 .29795 Mtetra
.978 .777 .564 r
.71484 .29795 .71584 .29931 .71759 .29199 .7166 .2906 Mtetra
.975 .669 .322 r
.7166 .2906 .71759 .29199 .7063 .07623 .70536 .07482 Mtetra
.964 .781 .608 r
.70536 .07482 .7063 .07623 .708 .07066 .70707 .06926 Mtetra
.758 .777 .869 r
.70707 .06926 .708 .07066 .70997 .06936 .70904 .06796 Mtetra
.626 .726 .919 r
.70904 .06796 .70997 .06936 .71199 .06877 .71106 .06738 Mtetra
.542 .685 .932 r
.71106 .06738 .71199 .06877 .71403 .06852 .7131 .06712 Mtetra
.749 .775 .874 r
.7131 .06712 .71403 .06852 .71601 .06731 .71508 .06588 Mtetra
.679 .743 .899 r
.71508 .06588 .71601 .06731 .71801 .06648 .71708 .06504 Mtetra
.478 .643 .929 r
.71708 .06504 .71801 .06648 .72007 .06644 .71915 .06501 Mtetra
.778 .367 0 r
.71915 .06501 .72007 .06644 .72248 .07146 .72159 .07059 Mtetra
.97 .655 .293 r
.72159 .07059 .72248 .07146 .73936 .28609 .73844 .28561 Mtetra
.805 .331 0 r
.73844 .28561 .73936 .28609 .74193 .29099 .74098 .29014 Mtetra
.48 .668 .946 r
.05036 .52137 .05163 .52262 .05325 .5225 .05198 .52132 Mtetra
.699 .75 .891 r
.05198 .52132 .05325 .5225 .05499 .52162 .0537 .5205 Mtetra
.759 .769 .86 r
.0537 .5205 .05499 .52162 .05678 .52035 .05548 .51929 Mtetra
.394 .668 .97 r
.05548 .51929 .05678 .52035 .05838 .52041 .05709 .51935 Mtetra
.559 .735 .958 r
.05709 .51935 .05838 .52041 .06003 .52014 .05874 .51906 Mtetra
.741 .775 .88 r
.05874 .51906 .06003 .52014 .06179 .5191 .06051 .518 Mtetra
.905 .738 .664 r
.06051 .518 .06179 .5191 .06417 .51359 .06289 .51249 Mtetra
.937 .686 .533 r
.06289 .51249 .06417 .51359 .09422 .30694 .09303 .30588 Mtetra
.913 .728 .638 r
.09303 .30588 .09422 .30694 .09665 .30029 .09546 .29921 Mtetra
.787 .766 .834 r
.09546 .29921 .09665 .30029 .09836 .29892 .09717 .29782 Mtetra
.651 .743 .917 r
.09717 .29782 .09836 .29892 .09995 .29838 .09876 .29727 Mtetra
.533 .701 .947 r
.09876 .29727 .09995 .29838 .10149 .29822 .1003 .29708 Mtetra
.761 .756 .848 r
.1003 .29708 .10149 .29822 .10317 .29703 .10198 .2959 Mtetra
.721 .753 .878 r
.10198 .2959 .10317 .29703 .10481 .29612 .10362 .29501 Mtetra
.544 .705 .945 r
.10362 .29501 .10481 .29612 .10636 .29591 .10517 .29479 Mtetra
.915 .517 .199 r
.10517 .29479 .10636 .29591 .10738 .29967 .10621 .2984 Mtetra
.94 .683 .521 r
.10621 .2984 .10738 .29967 .08146 .50568 .08025 .50405 Mtetra
.952 .611 .323 r
.08025 .50405 .08146 .50568 .08228 .51175 .08103 .51043 Mtetra
.288 .56 .929 r
.08103 .51043 .08228 .51175 .08388 .51202 .08262 .51078 Mtetra
.683 .739 .893 r
.08262 .51078 .08388 .51202 .08562 .51121 .08435 .51003 Mtetra
.756 .763 .858 r
.08435 .51003 .08562 .51121 .08742 .50993 .08615 .50883 Mtetra
.515 .712 .961 r
.08615 .50883 .08742 .50993 .08911 .50959 .08781 .50865 Mtetra
.541 .756 .976 r
.08781 .50865 .08911 .50959 .09079 .50928 .08948 .50837 Mtetra
.707 .805 .925 r
.08948 .50837 .09079 .50928 .09251 .50865 .09123 .50753 Mtetra
.877 .758 .727 r
.09123 .50753 .09251 .50865 .09437 .50698 .09331 .50423 Mtetra
.884 .673 .612 r
.09331 .50423 .09437 .50698 .09636 .50421 .09614 .49502 Mtetra
.932 .677 .53 r
.09614 .49502 .09636 .50421 .09869 .4989 .12384 .29259 Mtetra
.518 .285 .5 r
.12384 .29259 .09869 .4989 .12619 .29658 .12583 .28907 Mtetra
.622 .432 .604 r
.12583 .28907 .12619 .29658 .12856 .29011 .1276 .28724 Mtetra
.678 .565 .72 r
.1276 .28724 .12856 .29011 .13047 .28719 .1293 .28604 Mtetra
.681 .741 .896 r
.1293 .28604 .13047 .28719 .13215 .28614 .13093 .28534 Mtetra
.601 .795 .974 r
.13093 .28534 .13215 .28614 .13374 .28574 .13253 .28491 Mtetra
.557 .774 .979 r
.13253 .28491 .13374 .28574 .1353 .28561 .13411 .28459 Mtetra
.642 .758 .933 r
.13411 .28459 .1353 .28561 .1369 .28517 .13573 .28406 Mtetra
.67 .748 .909 r
.13573 .28406 .1369 .28517 .13852 .28458 .13735 .28342 Mtetra
.681 .742 .897 r
.13735 .28342 .13852 .28458 .14016 .28391 .13899 .28272 Mtetra
.747 .75 .855 r
.13899 .28272 .14016 .28391 .14183 .28293 .14067 .28163 Mtetra
.721 .727 .855 r
.14067 .28163 .14183 .28293 .14349 .28201 .14234 .28068 Mtetra
.626 .695 .894 r
.14234 .28068 .14349 .28201 .14512 .28137 .14395 .28021 Mtetra
.565 .062 0 r
.14395 .28021 .14512 .28137 .14665 .2816 .14532 .28172 Mtetra
.903 .56 .383 r
.14532 .28172 .14665 .2816 .14806 .2828 .14615 .28768 Mtetra
.937 .675 .515 r
.14615 .28768 .14806 .2828 .14922 .28605 .12309 .49076 Mtetra
.515 .277 .492 r
.12309 .49076 .14922 .28605 .12663 .48675 .12437 .49395 Mtetra
.545 .24 .402 r
.12437 .49395 .12663 .48675 .12746 .49366 .12592 .49486 Mtetra
.406 0 0 r
.12592 .49486 .12746 .49366 .12886 .49591 .12757 .49502 Mtetra
.561 .777 .979 r
.12757 .49502 .12886 .49591 .13051 .49609 .12929 .49466 Mtetra
.661 .708 .882 r
.12929 .49466 .13051 .49609 .13226 .49543 .13104 .494 Mtetra
.692 .715 .867 r
.13104 .494 .13226 .49543 .13406 .49443 .13282 .49315 Mtetra
.686 .739 .892 r
.13282 .49315 .13406 .49443 .13583 .49358 .13458 .49238 Mtetra
.682 .75 .903 r
.13458 .49238 .13583 .49358 .1376 .49281 .13635 .49162 Mtetra
.686 .754 .903 r
.13635 .49162 .1376 .49281 .13937 .49201 .13812 .49085 Mtetra
.697 .762 .902 r
.13812 .49085 .13937 .49201 .14115 .49112 .13989 .49003 Mtetra
.7 .774 .909 r
.13989 .49003 .14115 .49112 .14294 .4902 .14167 .4892 Mtetra
.69 .789 .925 r
.14167 .4892 .14294 .4902 .14472 .48934 .14344 .48842 Mtetra
.65 .797 .953 r
.14344 .48842 .14472 .48934 .14648 .48868 .1452 .4878 Mtetra
.607 .794 .971 r
.1452 .4878 .14648 .48868 .14822 .4882 .14694 .48732 Mtetra
.577 .786 .978 r
.14694 .48732 .14822 .4882 .14995 .48782 .14867 .48692 Mtetra
.297 .658 .971 r
.14867 .48692 .14995 .48782 .15162 .48802 .15034 .48706 Mtetra
.393 .693 .98 r
.15034 .48706 .15162 .48802 .1533 .4881 .15203 .48708 Mtetra
.677 .785 .931 r
.15203 .48708 .1533 .4881 .15507 .4874 .15381 .48636 Mtetra
.9 .765 .704 r
.15381 .48636 .15507 .4874 .15722 .48331 .15594 .48239 Mtetra
.947 .689 .514 r
.15594 .48239 .15722 .48331 .18184 .27614 .18057 .276 Mtetra
.954 .755 .596 r
.18057 .276 .18184 .27614 .18439 .26744 .1832 .26655 Mtetra
.859 .799 .79 r
.1832 .26655 .18439 .26744 .18621 .26535 .18503 .26439 Mtetra
.645 .775 .943 r
.18503 .26439 .18621 .26535 .18785 .26485 .18668 .26383 Mtetra
.458 .697 .97 r
.18668 .26383 .18785 .26485 .18943 .26485 .18827 .26377 Mtetra
.569 .728 .949 r
.18827 .26377 .18943 .26485 .19105 .2646 .18989 .26347 Mtetra
.657 .746 .915 r
.18989 .26347 .19105 .2646 .1927 .26403 .19155 .26287 Mtetra
.67 .743 .905 r
.19155 .26287 .1927 .26403 .19436 .26339 .19321 .26221 Mtetra
.747 .756 .86 r
.19321 .26221 .19436 .26339 .19608 .26229 .19492 .26111 Mtetra
.747 .758 .862 r
.19492 .26111 .19608 .26229 .19779 .26118 .19664 .26002 Mtetra
.632 .733 .921 r
.19664 .26002 .19779 .26118 .19944 .26067 .19828 .25952 Mtetra
.719 .228 0 r
.19828 .25952 .19944 .26067 .20082 .26274 .19967 .26153 Mtetra
.95 .685 .499 r
.19967 .26153 .20082 .26274 .18112 .46646 .18 .46426 Mtetra
.967 .656 .374 r
.18 .46426 .18112 .46646 .18171 .47723 .18049 .47589 Mtetra
.536 .051 0 r
.18049 .47589 .18171 .47723 .18326 .47879 .18203 .47761 Mtetra
.571 .724 .946 r
.18203 .47761 .18326 .47879 .18503 .47831 .18378 .47728 Mtetra
.772 .798 .874 r
.18378 .47728 .18503 .47831 .18688 .47705 .18563 .47599 Mtetra
.873 .783 .758 r
.18563 .47599 .18688 .47705 .18878 .47531 .18764 .47321 Mtetra
.888 .698 .639 r
.18764 .47321 .18878 .47531 .19074 .47296 .19 .46692 Mtetra
.945 .683 .509 r
.19 .46692 .19074 .47296 .19285 .46911 .21251 .2616 Mtetra
.522 .288 .501 r
.21251 .2616 .19285 .46911 .19693 .4456 .21466 .25634 Mtetra
.515 .282 .5 r
.21466 .25634 .19693 .4456 .2173 .25862 .21648 .25426 Mtetra
.645 .494 .663 r
.21648 .25426 .2173 .25862 .2193 .25479 .21822 .25293 Mtetra
.686 .649 .807 r
.21822 .25293 .2193 .25479 .22108 .25305 .21993 .25202 Mtetra
.667 .77 .927 r
.21993 .25202 .22108 .25305 .22277 .25234 .22161 .25138 Mtetra
.627 .774 .951 r
.22161 .25138 .22277 .25234 .22442 .25195 .22327 .25087 Mtetra
.696 .768 .907 r
.22327 .25087 .22442 .25195 .2261 .25136 .22497 .2501 Mtetra
.716 .74 .87 r
.22497 .2501 .2261 .25136 .2278 .25054 .22668 .24917 Mtetra
.634 .697 .89 r
.22668 .24917 .2278 .25054 .22948 .24995 .22835 .24865 Mtetra
0 .331 .811 r
.22835 .24865 .22948 .24995 .2311 .24993 .22988 .24955 Mtetra
.907 .522 .277 r
.22988 .24955 .2311 .24993 .23264 .25082 .23107 .25415 Mtetra
.948 .679 .494 r
.23107 .25415 .23264 .25082 .23404 .25318 .21329 .45852 Mtetra
.518 .279 .492 r
.21329 .45852 .23404 .25318 .21745 .44695 .21461 .46298 Mtetra
.529 .259 .45 r
.21461 .46298 .21745 .44695 .21783 .46145 .21626 .46399 Mtetra
.476 .076 .202 r
.21626 .46399 .21783 .46145 .2193 .46442 .21798 .46421 Mtetra
.08 .633 .817 r
.21798 .46421 .2193 .46442 .22095 .46538 .21973 .46424 Mtetra
.493 .704 .964 r
.21973 .46424 .22095 .46538 .22272 .46525 .22149 .46411 Mtetra
.67 .765 .922 r
.22149 .46411 .22272 .46525 .22453 .46453 .2233 .4634 Mtetra
.84 .785 .798 r
.2233 .4634 .22453 .46453 .22641 .46315 .22525 .46127 Mtetra
.89 .712 .655 r
.22525 .46127 .22641 .46315 .22837 .46084 .22749 .45586 Mtetra
.95 .685 .5 r
.22749 .45586 .22837 .46084 .23047 .45695 .24782 .2499 Mtetra
.526 .291 .502 r
.24782 .2499 .23047 .45695 .23386 .43872 .25008 .24298 Mtetra
.515 .282 .5 r
.25008 .24298 .23386 .43872 .2528 .24486 .25194 .24062 Mtetra
.658 .506 .666 r
.25194 .24062 .2528 .24486 .25479 .24094 .25371 .23913 Mtetra
.693 .659 .812 r
.25371 .23913 .25479 .24094 .25659 .23911 .25544 .23819 Mtetra
.641 .789 .953 r
.25544 .23819 .25659 .23911 .25829 .23848 .25713 .23762 Mtetra
.578 .783 .976 r
.25713 .23762 .25829 .23848 .25996 .23823 .25881 .23723 Mtetra
.606 .762 .954 r
.25881 .23723 .25996 .23823 .26163 .23795 .2605 .23679 Mtetra
.663 .747 .913 r
.2605 .23679 .26163 .23795 .26333 .23735 .2622 .23615 Mtetra
.675 .742 .901 r
.2622 .23615 .26333 .23735 .26503 .23669 .26391 .23545 Mtetra
.717 .747 .876 r
.26391 .23545 .26503 .23669 .26676 .23584 .26564 .23453 Mtetra
.74 .741 .852 r
.26564 .23453 .26676 .23584 .2685 .23482 .26739 .23342 Mtetra
.674 .71 .875 r
.26739 .23342 .2685 .23482 .27022 .23402 .2691 .2327 Mtetra
.27 .535 .917 r
.2691 .2327 .27022 .23402 .27189 .2338 .27073 .23312 Mtetra
.88 .445 .127 r
.27073 .23312 .27189 .2338 .27348 .23459 .2721 .23651 Mtetra
.953 .681 .482 r
.2721 .23651 .27348 .23459 .27496 .23679 .257 .44072 Mtetra
.523 .284 .493 r
.257 .44072 .27496 .23679 .27553 .25034 .25819 .44788 Mtetra
.511 .273 .491 r
.25819 .44788 .27553 .25034 .26137 .44676 .25986 .44929 Mtetra
.505 .105 .215 r
.25986 .44929 .26137 .44676 .26289 .45001 .26161 .44971 Mtetra
.253 .742 .919 r
.26161 .44971 .26289 .45001 .26459 .45102 .2634 .44958 Mtetra
.62 .702 .904 r
.2634 .44958 .26459 .45102 .26641 .45063 .26523 .44908 Mtetra
.659 .698 .875 r
.26523 .44908 .26641 .45063 .26826 .44984 .26707 .44838 Mtetra
.638 .704 .894 r
.26707 .44838 .26826 .44984 .27011 .44905 .26891 .44779 Mtetra
.554 .708 .943 r
.26891 .44779 .27011 .44905 .27194 .44859 .27072 .44751 Mtetra
.657 .777 .937 r
.27072 .44751 .27194 .44859 .27378 .44792 .27257 .44684 Mtetra
.824 .802 .83 r
.27257 .44684 .27378 .44792 .27568 .44661 .2745 .44502 Mtetra
.903 .733 .661 r
.2745 .44502 .27568 .44661 .27767 .444 .27669 .43986 Mtetra
.955 .687 .487 r
.27669 .43986 .27767 .444 .27975 .44023 .29401 .23432 Mtetra
.528 .293 .502 r
.29401 .23432 .27975 .44023 .28185 .43608 .29628 .22648 Mtetra
.511 .279 .498 r
.29628 .22648 .28185 .43608 .28366 .43598 .29803 .22552 Mtetra
.51 .277 .498 r
.29803 .22552 .28366 .43598 .28547 .43576 .29973 .22528 Mtetra
.511 .278 .498 r
.29973 .22528 .28547 .43576 .28758 .43148 .30148 .22452 Mtetra
.515 .282 .499 r
.30148 .22452 .28758 .43148 .30414 .22753 .30333 .22222 Mtetra
.66 .485 .637 r
.30333 .22222 .30414 .22753 .30621 .22228 .30516 .22027 Mtetra
.734 .658 .775 r
.30516 .22027 .30621 .22228 .30807 .21981 .30694 .21888 Mtetra
.657 .796 .949 r
.30694 .21888 .30807 .21981 .30981 .21907 .30867 .21825 Mtetra
.59 .8 .98 r
.30867 .21825 .30981 .21907 .31152 .21874 .3104 .21781 Mtetra
.598 .778 .966 r
.3104 .21781 .31152 .21874 .31323 .21849 .31212 .21737 Mtetra
.669 .761 .919 r
.31212 .21737 .31323 .21849 .31497 .21786 .31386 .21669 Mtetra
.681 .755 .907 r
.31386 .21669 .31497 .21786 .31671 .21717 .3156 .21596 Mtetra
.708 .755 .889 r
.3156 .21596 .31671 .21717 .31846 .21635 .31736 .21508 Mtetra
.751 .755 .856 r
.31736 .21508 .31846 .21635 .32023 .2153 .31914 .21391 Mtetra
.691 .72 .871 r
.31914 .21391 .32023 .2153 .32198 .21445 .32089 .21308 Mtetra
.45 .625 .927 r
.32089 .21308 .32198 .21445 .3237 .21411 .32258 .21314 Mtetra
.837 .378 0 r
.32258 .21314 .3237 .21411 .32534 .21508 .32409 .21615 Mtetra
.959 .682 .466 r
.32409 .21615 .32534 .21508 .32692 .21708 .31256 .41818 Mtetra
.528 .288 .494 r
.31256 .41818 .32692 .21708 .32844 .21995 .31374 .42791 Mtetra
.507 .27 .49 r
.31374 .42791 .32844 .21995 .33022 .21875 .31559 .42769 Mtetra
.505 .269 .49 r
.31559 .42769 .33022 .21875 .33201 .21754 .31749 .42658 Mtetra
.506 .269 .49 r
.31749 .42658 .33201 .21754 .33364 .21887 .31937 .42578 Mtetra
.511 .273 .491 r
.31937 .42578 .33364 .21887 .32265 .42275 .32112 .42705 Mtetra
.554 .206 .332 r
.32112 .42705 .32265 .42275 .32416 .428 .3229 .42797 Mtetra
.217 0 0 r
.3229 .42797 .32416 .428 .32589 .42978 .32472 .42831 Mtetra
.638 .708 .897 r
.32472 .42831 .32589 .42978 .32775 .42932 .32659 .42771 Mtetra
.675 .7 .865 r
.32659 .42771 .32775 .42932 .32965 .42839 .32849 .4269 Mtetra
.669 .715 .883 r
.32849 .4269 .32965 .42839 .33155 .42738 .33037 .42614 Mtetra
.468 .677 .956 r
.33037 .42614 .33155 .42738 .33341 .42717 .33222 .42609 Mtetra
.576 .756 .963 r
.33222 .42609 .33341 .42717 .33528 .42678 .33409 .42569 Mtetra
.759 .804 .889 r
.33409 .42569 .33528 .42678 .33718 .42595 .33601 .42446 Mtetra
.901 .75 .685 r
.33601 .42446 .33718 .42595 .33914 .42393 .33811 .42016 Mtetra
.961 .687 .471 r
.33811 .42016 .33914 .42393 .34118 .42065 .35108 .22521 Mtetra
.558 .317 .507 r
.35108 .22521 .34118 .42065 .34345 .41322 .35399 .20447 Mtetra
.516 .282 .499 r
.35399 .20447 .34345 .41322 .35671 .20752 .35588 .20168 Mtetra
.636 .461 .628 r
.35588 .20168 .35671 .20752 .35873 .20243 .3577 .19998 Mtetra
.688 .604 .757 r
.3577 .19998 .35873 .20243 .3606 .19984 .3595 .19883 Mtetra
.684 .793 .932 r
.3595 .19883 .3606 .19984 .36238 .19887 .36127 .19808 Mtetra
.612 .818 .979 r
.36127 .19808 .36238 .19887 .36414 .19836 .36303 .19755 Mtetra
.568 .799 .987 r
.36303 .19755 .36414 .19836 .36589 .19808 .36479 .19715 Mtetra
.604 .783 .966 r
.36479 .19715 .36589 .19808 .36765 .19764 .36656 .19667 Mtetra
.607 .776 .961 r
.36656 .19667 .36765 .19764 .36942 .19722 .36832 .19619 Mtetra
.623 .77 .951 r
.36832 .19619 .36942 .19722 .37118 .19677 .37009 .19567 Mtetra
.658 .768 .931 r
.37009 .19567 .37118 .19677 .37295 .19617 .37186 .19503 Mtetra
.676 .765 .918 r
.37186 .19503 .37295 .19617 .37473 .19548 .37364 .1943 Mtetra
.691 .763 .907 r
.37364 .1943 .37473 .19548 .37651 .19471 .37543 .19351 Mtetra
.712 .764 .893 r
.37543 .19351 .37651 .19471 .3783 .19381 .37722 .1926 Mtetra
.714 .763 .891 r
.37722 .1926 .3783 .19381 .3801 .19289 .37902 .19168 Mtetra
.709 .761 .893 r
.37902 .19168 .3801 .19289 .38189 .19199 .38081 .19078 Mtetra
.747 .771 .872 r
.38081 .19078 .38189 .19199 .38369 .19102 .38261 .18965 Mtetra
.687 .728 .881 r
.38261 .18965 .38369 .19102 .38547 .19025 .3844 .18885 Mtetra
.559 .671 .913 r
.3844 .18885 .38547 .19025 .38725 .18981 .38617 .18859 Mtetra
.682 .207 0 r
.38617 .18859 .38725 .18981 .38897 .19065 .38782 .19101 Mtetra
.938 .605 .375 r
.38782 .19101 .38897 .19065 .39065 .19244 .38902 .20346 Mtetra
.953 .667 .457 r
.38902 .20346 .39065 .19244 .39226 .19584 .38188 .40449 Mtetra
.509 .272 .49 r
.38188 .40449 .39226 .19584 .394 .19647 .38374 .40499 Mtetra
.506 .269 .49 r
.38374 .40499 .394 .19647 .39581 .19527 .38567 .4041 Mtetra
.504 .268 .489 r
.38567 .4041 .39581 .19527 .39766 .19337 .38764 .40248 Mtetra
.505 .269 .49 r
.38764 .40248 .39766 .19337 .39952 .19139 .38958 .40122 Mtetra
.506 .269 .49 r
.38958 .40122 .39952 .19139 .40133 .19029 .39152 .40023 Mtetra
.507 .27 .49 r
.39152 .40023 .40133 .19029 .40309 .19069 .39343 .39984 Mtetra
.511 .273 .491 r
.39343 .39984 .40309 .19069 .39677 .39383 .39527 .40122 Mtetra
.549 .239 .394 r
.39527 .40122 .39677 .39383 .39835 .40185 .39713 .40234 Mtetra
.455 0 0 r
.39713 .40234 .39835 .40185 .40016 .40439 .39901 .40296 Mtetra
.585 .697 .92 r
.39901 .40296 .40016 .40439 .40206 .40434 .40093 .40256 Mtetra
.651 .673 .858 r
.40093 .40256 .40206 .40434 .404 .40361 .40287 .40185 Mtetra
.678 .685 .85 r
.40287 .40185 .404 .40361 .40595 .40256 .40481 .40097 Mtetra
.672 .708 .875 r
.40481 .40097 .40595 .40256 .40789 .40167 .40675 .40017 Mtetra
.672 .721 .886 r
.40675 .40017 .40789 .40167 .40984 .40078 .4087 .39937 Mtetra
.668 .735 .899 r
.4087 .39937 .40984 .40078 .41178 .39992 .41064 .39861 Mtetra
.644 .743 .921 r
.41064 .39861 .41178 .39992 .41372 .3992 .41258 .39797 Mtetra
.627 .751 .936 r
.41258 .39797 .41372 .3992 .41566 .39858 .41452 .39739 Mtetra
.612 .755 .946 r
.41452 .39739 .41566 .39858 .4176 .39803 .41646 .39687 Mtetra
.451 .69 .968 r
.41646 .39687 .4176 .39803 .41953 .39784 .41838 .39682 Mtetra
.528 .755 .979 r
.41838 .39682 .41953 .39784 .42146 .39753 .42031 .39653 Mtetra
.702 .819 .937 r
.42031 .39653 .42146 .39753 .42341 .39684 .42227 .39562 Mtetra
.905 .789 .721 r
.42227 .39562 .42341 .39684 .4254 .39505 .42431 .39209 Mtetra
.919 .687 .572 r
.42431 .39209 .4254 .39505 .42742 .39204 .42656 .38159 Mtetra
.961 .678 .452 r
.42656 .38159 .42742 .39204 .42952 .38599 .4347 .17484 Mtetra
.517 .283 .499 r
.4347 .17484 .42952 .38599 .43749 .17852 .43661 .17132 Mtetra
.625 .436 .607 r
.43661 .17132 .43749 .17852 .43947 .17238 .43847 .16941 Mtetra
.681 .571 .724 r
.43847 .16941 .43947 .17238 .44136 .16939 .44031 .1681 Mtetra
.705 .752 .888 r
.44031 .1681 .44136 .16939 .4432 .1681 .44214 .1672 Mtetra
.652 .813 .961 r
.44214 .1672 .4432 .1681 .44502 .16743 .44396 .16654 Mtetra
.608 .801 .974 r
.44396 .16654 .44502 .16743 .44684 .16705 .44578 .16602 Mtetra
.62 .776 .955 r
.44578 .16602 .44684 .16705 .44866 .1666 .4476 .16549 Mtetra
.627 .761 .943 r
.4476 .16549 .44866 .1666 .45048 .16612 .44943 .16495 Mtetra
.639 .752 .93 r
.44943 .16495 .45048 .16612 .45231 .16561 .45126 .16436 Mtetra
.681 .752 .906 r
.45126 .16436 .45231 .16561 .45414 .16486 .45309 .16359 Mtetra
.696 .753 .896 r
.45309 .16359 .45414 .16486 .45597 .16401 .45493 .16274 Mtetra
.696 .754 .896 r
.45493 .16274 .45597 .16401 .45781 .16314 .45676 .16189 Mtetra
.728 .766 .883 r
.45676 .16189 .45781 .16314 .45965 .16223 .4586 .16085 Mtetra
.693 .735 .884 r
.4586 .16085 .45965 .16223 .46149 .16144 .46044 .16 Mtetra
.586 .683 .908 r
.46044 .16 .46149 .16144 .46332 .16094 .46227 .15963 Mtetra
0 .082 .613 r
.46227 .15963 .46332 .16094 .46513 .16149 .46406 .16133 Mtetra
.925 .546 .262 r
.46406 .16133 .46513 .16149 .46692 .16313 .46574 .16863 Mtetra
.965 .673 .425 r
.46574 .16863 .46692 .16313 .46869 .16642 .46361 .37596 Mtetra
.511 .274 .491 r
.46361 .37596 .46869 .16642 .47048 .16888 .46554 .37776 Mtetra
.507 .27 .49 r
.46554 .37776 .47048 .16888 .47232 .16839 .46751 .37721 Mtetra
.505 .269 .49 r
.46751 .37721 .47232 .16839 .4742 .16643 .4695 .37593 Mtetra
.506 .269 .49 r
.4695 .37593 .4742 .16643 .47605 .16531 .47149 .37502 Mtetra
.506 .27 .49 r
.47149 .37502 .47605 .16531 .47791 .16455 .47347 .37432 Mtetra
.47347 .37432 .47791 .16455 .47976 .16376 .47545 .37361 Mtetra
.47545 .37361 .47976 .16376 .48162 .16294 .47744 .3729 Mtetra
.47744 .3729 .48162 .16294 .48347 .16213 .47943 .37218 Mtetra
.47943 .37218 .48347 .16213 .48533 .16133 .48142 .37147 Mtetra
.506 .269 .49 r
.48142 .37147 .48533 .16133 .4872 .15956 .48341 .3705 Mtetra
.48341 .3705 .4872 .15956 .48907 .15818 .4854 .36959 Mtetra
.507 .27 .49 r
.4854 .36959 .48907 .15818 .49092 .15836 .48739 .3691 Mtetra
.509 .272 .49 r
.48739 .3691 .49092 .15836 .4906 .35973 .48937 .36986 Mtetra
.534 .241 .416 r
.48937 .36986 .4906 .35973 .49248 .3696 .49135 .37085 Mtetra
.496 .002 .014 r
.49135 .37085 .49248 .3696 .49445 .37247 .49333 .37145 Mtetra
.481 .739 .984 r
.49333 .37145 .49445 .37247 .49644 .37291 .49533 .37126 Mtetra
.642 .693 .883 r
.49533 .37126 .49644 .37291 .49844 .37231 .49733 .3706 Mtetra
.668 .696 .867 r
.49733 .3706 .49844 .37231 .50044 .37136 .49934 .36978 Mtetra
.659 .71 .885 r
.49934 .36978 .50044 .37136 .50245 .37054 .50134 .36902 Mtetra
.647 .715 .898 r
.50134 .36902 .50245 .37054 .50445 .36986 .50335 .36834 Mtetra
.645 .715 .899 r
.50335 .36834 .50445 .36986 .50646 .36917 .50536 .36766 Mtetra
.645 .717 .9 r
.50536 .36766 .50646 .36917 .50847 .36849 .50737 .36699 Mtetra
.641 .717 .903 r
.50737 .36699 .50847 .36849 .51048 .36782 .50938 .36633 Mtetra
.634 .716 .906 r
.50938 .36633 .51048 .36782 .51249 .36719 .51139 .36571 Mtetra
.615 .71 .913 r
.51139 .36571 .51249 .36719 .5145 .36665 .5134 .36517 Mtetra
.603 .704 .915 r
.5134 .36517 .5145 .36665 .51652 .36618 .51542 .36468 Mtetra
.605 .703 .913 r
.51542 .36468 .51652 .36618 .51853 .3657 .51744 .36419 Mtetra
.622 .709 .908 r
.51744 .36419 .51853 .3657 .52055 .36513 .51945 .36363 Mtetra
.636 .714 .904 r
.51945 .36363 .52055 .36513 .52257 .36449 .52147 .36299 Mtetra
.641 .718 .904 r
.52147 .36299 .52257 .36449 .52459 .36383 .5235 .36234 Mtetra
.642 .72 .905 r
.5235 .36234 .52459 .36383 .52661 .36316 .52552 .36167 Mtetra
.641 .721 .906 r
.52552 .36167 .52661 .36316 .52864 .3625 .52754 .36101 Mtetra
.642 .722 .906 r
.52754 .36101 .52864 .3625 .53066 .36183 .52957 .36035 Mtetra
.643 .723 .906 r
.52957 .36035 .53066 .36183 .53269 .36116 .5316 .35968 Mtetra
.644 .723 .906 r
.5316 .35968 .53269 .36116 .53472 .36048 .53363 .359 Mtetra
.53363 .359 .53472 .36048 .53675 .35981 .53566 .35833 Mtetra
.644 .724 .906 r
.53566 .35833 .53675 .35981 .53878 .35913 .53769 .35765 Mtetra
.645 .724 .906 r
.53769 .35765 .53878 .35913 .54081 .35845 .53973 .35697 Mtetra
.53973 .35697 .54081 .35845 .54285 .35777 .54176 .35629 Mtetra
.54176 .35629 .54285 .35777 .54489 .35709 .5438 .3556 Mtetra
.5438 .3556 .54489 .35709 .54692 .35641 .54584 .35492 Mtetra
.54584 .35492 .54692 .35641 .54896 .35572 .54788 .35424 Mtetra
.54788 .35424 .54896 .35572 .551 .35504 .54992 .35355 Mtetra
.54992 .35355 .551 .35504 .55304 .35435 .55196 .35286 Mtetra
.646 .724 .906 r
.55196 .35286 .55304 .35435 .55509 .35367 .554 .35217 Mtetra
.646 .724 .905 r
.554 .35217 .55509 .35367 .55713 .35298 .55605 .35149 Mtetra
.55605 .35149 .55713 .35298 .55918 .35229 .5581 .3508 Mtetra
.5581 .3508 .55918 .35229 .56123 .3516 .56015 .35011 Mtetra
.56015 .35011 .56123 .3516 .56328 .35091 .5622 .34942 Mtetra
.5622 .34942 .56328 .35091 .56533 .35022 .56425 .34872 Mtetra
.56425 .34872 .56533 .35022 .56738 .34953 .5663 .34803 Mtetra
.5663 .34803 .56738 .34953 .56944 .34884 .56836 .34734 Mtetra
.56836 .34734 .56944 .34884 .57149 .34815 .57042 .34665 Mtetra
.57042 .34665 .57149 .34815 .57355 .34745 .57247 .34595 Mtetra
.57247 .34595 .57355 .34745 .57561 .34676 .57453 .34526 Mtetra
.57453 .34526 .57561 .34676 .57767 .34606 .57659 .34456 Mtetra
.57659 .34456 .57767 .34606 .57973 .34537 .57866 .34387 Mtetra
.57866 .34387 .57973 .34537 .58179 .34467 .58072 .34317 Mtetra
.58072 .34317 .58179 .34467 .58386 .34398 .58279 .34247 Mtetra
.58279 .34247 .58386 .34398 .58593 .34328 .58485 .34177 Mtetra
.58485 .34177 .58593 .34328 .58799 .34258 .58692 .34108 Mtetra
.58692 .34108 .58799 .34258 .59006 .34189 .58899 .34038 Mtetra
.58899 .34038 .59006 .34189 .59213 .34119 .59107 .33968 Mtetra
.59107 .33968 .59213 .34119 .59421 .34049 .59314 .33898 Mtetra
.59314 .33898 .59421 .34049 .59628 .33979 .59521 .33828 Mtetra
.59521 .33828 .59628 .33979 .59836 .33909 .59729 .33758 Mtetra
.59729 .33758 .59836 .33909 .60043 .33839 .59937 .33688 Mtetra
.59937 .33688 .60043 .33839 .60251 .33769 .60145 .33617 Mtetra
.60145 .33617 .60251 .33769 .60459 .33699 .60353 .33547 Mtetra
.60353 .33547 .60459 .33699 .60667 .33629 .60561 .33477 Mtetra
.60561 .33477 .60667 .33629 .60876 .33558 .6077 .33406 Mtetra
.6077 .33406 .60876 .33558 .61084 .33488 .60978 .33336 Mtetra
.60978 .33336 .61084 .33488 .61293 .33417 .61187 .33265 Mtetra
.61187 .33265 .61293 .33417 .61502 .33347 .61396 .33195 Mtetra
.61396 .33195 .61502 .33347 .61711 .33276 .61605 .33124 Mtetra
.61605 .33124 .61711 .33276 .6192 .33206 .61814 .33053 Mtetra
.647 .724 .905 r
.61814 .33053 .6192 .33206 .62129 .33135 .62024 .32982 Mtetra
.62024 .32982 .62129 .33135 .62339 .33064 .62233 .32911 Mtetra
.62233 .32911 .62339 .33064 .62548 .32993 .62443 .3284 Mtetra
.62443 .3284 .62548 .32993 .62758 .32921 .62653 .32769 Mtetra
.647 .725 .905 r
.62653 .32769 .62758 .32921 .62968 .3285 .62863 .32697 Mtetra
.648 .725 .905 r
.62863 .32697 .62968 .3285 .63178 .32778 .63073 .32625 Mtetra
.63073 .32625 .63178 .32778 .63388 .32706 .63283 .32553 Mtetra
.649 .726 .905 r
.63283 .32553 .63388 .32706 .63598 .32633 .63493 .32481 Mtetra
.63493 .32481 .63598 .32633 .63809 .32561 .63704 .32408 Mtetra
.648 .726 .906 r
.63704 .32408 .63809 .32561 .64019 .32488 .63915 .32336 Mtetra
.652 .728 .905 r
.63915 .32336 .64019 .32488 .6423 .32413 .64126 .32262 Mtetra
.661 .733 .903 r
.64126 .32262 .6423 .32413 .64441 .32332 .64336 .32183 Mtetra
.676 .744 .901 r
.64336 .32183 .64441 .32332 .64651 .32239 .64547 .32096 Mtetra
.679 .754 .908 r
.64547 .32096 .64651 .32239 .64861 .32145 .64758 .32008 Mtetra
.674 .763 .918 r
.64758 .32008 .64861 .32145 .65072 .32055 .64969 .31923 Mtetra
.657 .766 .93 r
.64969 .31923 .65072 .32055 .65283 .31977 .6518 .31847 Mtetra
.65 .767 .935 r
.6518 .31847 .65283 .31977 .65495 .31903 .65392 .31773 Mtetra
.645 .767 .937 r
.65392 .31773 .65495 .31903 .65707 .31831 .65604 .31702 Mtetra
.644 .767 .938 r
.65604 .31702 .65707 .31831 .65919 .31759 .65816 .31631 Mtetra
.643 .769 .94 r
.65816 .31631 .65919 .31759 .66131 .31688 .66029 .31561 Mtetra
.621 .762 .947 r
.66029 .31561 .66131 .31688 .66344 .31623 .66242 .315 Mtetra
.549 .737 .963 r
.66242 .315 .66344 .31623 .66558 .31574 .66456 .31464 Mtetra
.639 .804 .962 r
.66456 .31464 .66558 .31574 .6677 .31505 .66669 .31393 Mtetra
.806 .848 .882 r
.66669 .31393 .6677 .31505 .66981 .31389 .66878 .31231 Mtetra
.934 .782 .668 r
.66878 .31231 .66981 .31389 .67187 .31168 .67073 .30776 Mtetra
.97 .681 .425 r
.67073 .30776 .67187 .31168 .67387 .30826 .67133 .27471 Mtetra
.951 .64 .407 r
.67133 .27471 .67387 .30826 .67569 .30095 .66449 .08747 Mtetra
.515 .282 .499 r
.66449 .08747 .67569 .30095 .66757 .09113 .66637 .08464 Mtetra
.623 .443 .619 r
.66637 .08464 .66757 .09113 .66932 .08571 .6683 .08292 Mtetra
.674 .587 .749 r
.6683 .08292 .66932 .08571 .67121 .08306 .67026 .08174 Mtetra
.685 .762 .91 r
.67026 .08174 .67121 .08306 .67318 .08204 .67224 .08089 Mtetra
.642 .779 .946 r
.67224 .08089 .67318 .08204 .67517 .08144 .67423 .08023 Mtetra
.646 .767 .937 r
.67423 .08023 .67517 .08144 .67717 .08096 .67622 .07956 Mtetra
.735 .766 .878 r
.67622 .07956 .67717 .08096 .67914 .07997 .67818 .07841 Mtetra
.675 .717 .88 r
.67818 .07841 .67914 .07997 .68112 .07915 .68017 .07758 Mtetra
.506 .633 .91 r
.68017 .07758 .68112 .07915 .68312 .0787 .68219 .07749 Mtetra
0 0 .441 r
.68219 .07749 .68312 .0787 .68518 .07914 .68437 .08027 Mtetra
.972 .659 .319 r
.68437 .08027 .68518 .07914 .6873 .08065 .69784 .28569 Mtetra
.529 .286 .491 r
.69784 .28569 .6873 .08065 .68962 .08567 .70068 .29739 Mtetra
.511 .273 .49 r
.70068 .29739 .68962 .08567 .70363 .2943 .70296 .2989 Mtetra
.5 .149 .304 r
.70296 .2989 .70363 .2943 .70608 .29885 .70518 .29927 Mtetra
.104 0 0 r
.70518 .29927 .70608 .29885 .70838 .30049 .70738 .29913 Mtetra
.466 .672 .953 r
.70738 .29913 .70838 .30049 .71059 .30065 .70958 .29908 Mtetra
.641 .721 .906 r
.70958 .29908 .71059 .30065 .71275 .2999 .71174 .29838 Mtetra
.804 .787 .837 r
.71174 .29838 .71275 .2999 .71484 .29795 .71384 .29658 Mtetra
.978 .777 .564 r
.71384 .29658 .71484 .29795 .7166 .2906 .7156 .28922 Mtetra
.975 .669 .322 r
.7156 .28922 .7166 .2906 .70536 .07482 .70443 .07343 Mtetra
.965 .782 .608 r
.70443 .07343 .70536 .07482 .70707 .06926 .70614 .06787 Mtetra
.759 .779 .87 r
.70614 .06787 .70707 .06926 .70904 .06796 .70811 .06657 Mtetra
.627 .727 .919 r
.70811 .06657 .70904 .06796 .71106 .06738 .71013 .06598 Mtetra
.543 .686 .932 r
.71013 .06598 .71106 .06738 .7131 .06712 .71217 .06572 Mtetra
.75 .774 .873 r
.71217 .06572 .7131 .06712 .71508 .06588 .71415 .06447 Mtetra
.681 .748 .902 r
.71415 .06447 .71508 .06588 .71708 .06504 .71616 .06362 Mtetra
.483 .65 .933 r
.71616 .06362 .71708 .06504 .71915 .06501 .71822 .06357 Mtetra
.759 .347 0 r
.71822 .06357 .71915 .06501 .72159 .07059 .72064 .06886 Mtetra
.97 .656 .29 r
.72064 .06886 .72159 .07059 .73844 .28561 .73743 .28388 Mtetra
.65 .247 0 r
.73743 .28388 .73844 .28561 .74098 .29014 .73998 .28858 Mtetra
.425 .602 .92 r
.04912 .51991 .05036 .52137 .05198 .52132 .05071 .52004 Mtetra
.67 .728 .894 r
.05071 .52004 .05198 .52132 .0537 .5205 .05242 .51936 Mtetra
.751 .766 .865 r
.05242 .51936 .0537 .5205 .05548 .51929 .05419 .51821 Mtetra
.579 .739 .952 r
.05419 .51821 .05548 .51929 .05709 .51935 .05585 .51787 Mtetra
.673 .697 .864 r
.05585 .51787 .05709 .51935 .05874 .51906 .05757 .51713 Mtetra
.747 .669 .774 r
.05757 .51713 .05874 .51906 .06051 .518 .0594 .51561 Mtetra
.872 .678 .637 r
.0594 .51561 .06051 .518 .06289 .51249 .06195 .50889 Mtetra
.935 .683 .534 r
.06195 .50889 .06289 .51249 .09303 .30588 .09201 .30346 Mtetra
.855 .668 .647 r
.09201 .30346 .09303 .30588 .09546 .29921 .09427 .29809 Mtetra
.781 .759 .833 r
.09427 .29809 .09546 .29921 .09717 .29782 .09597 .29673 Mtetra
.658 .745 .914 r
.09597 .29673 .09717 .29782 .09876 .29727 .09757 .29615 Mtetra
.533 .699 .946 r
.09757 .29615 .09876 .29727 .1003 .29708 .09911 .29596 Mtetra
.705 .75 .887 r
.09911 .29596 .1003 .29708 .10198 .2959 .10074 .29516 Mtetra
.632 .812 .969 r
.10074 .29516 .10198 .2959 .10362 .29501 .10234 .29464 Mtetra
.063 .602 .853 r
.10234 .29464 .10362 .29501 .10517 .29479 .10384 .29479 Mtetra
.887 .519 .34 r
.10384 .29479 .10517 .29479 .10621 .2984 .10479 .29905 Mtetra
.938 .681 .522 r
.10479 .29905 .10621 .2984 .08025 .50405 .07888 .50364 Mtetra
.912 .555 .347 r
.07888 .50364 .08025 .50405 .08103 .51043 .0798 .50895 Mtetra
.284 .525 .908 r
.0798 .50895 .08103 .51043 .08262 .51078 .08138 .50937 Mtetra
.648 .703 .886 r
.08138 .50937 .08262 .51078 .08435 .51003 .08309 .50878 Mtetra
.736 .748 .862 r
.08309 .50878 .08435 .51003 .08615 .50883 .08487 .5077 Mtetra
.604 .739 .94 r
.08487 .5077 .08615 .50883 .08781 .50865 .08657 .50728 Mtetra
.668 .714 .883 r
.08657 .50728 .08781 .50865 .08948 .50837 .0883 .50659 Mtetra
.749 .685 .79 r
.0883 .50659 .08948 .50837 .09123 .50753 .09013 .50513 Mtetra
.868 .678 .644 r
.09013 .50513 .09123 .50753 .09331 .50423 .09256 .49905 Mtetra
.936 .682 .528 r
.09256 .49905 .09331 .50423 .09614 .49502 .12091 .29308 Mtetra
.524 .29 .501 r
.12091 .29308 .09614 .49502 .12384 .29259 .12319 .28734 Mtetra
.638 .47 .639 r
.12319 .28734 .12384 .29259 .12583 .28907 .12492 .28583 Mtetra
.599 .5 .714 r
.12492 .28583 .12583 .28907 .1276 .28724 .12653 .28529 Mtetra
.548 .572 .83 r
.12653 .28529 .1276 .28724 .1293 .28604 .12809 .28514 Mtetra
.614 .777 .958 r
.12809 .28514 .1293 .28604 .13093 .28534 .12969 .28469 Mtetra
.633 .835 .978 r
.12969 .28469 .13093 .28534 .13253 .28491 .1313 .28414 Mtetra
.65 .814 .962 r
.1313 .28414 .13253 .28491 .13411 .28459 .13292 .28356 Mtetra
.687 .767 .912 r
.13292 .28356 .13411 .28459 .13573 .28406 .13456 .28285 Mtetra
.687 .734 .886 r
.13456 .28285 .13573 .28406 .13735 .28342 .1362 .28212 Mtetra
.674 .715 .879 r
.1362 .28212 .13735 .28342 .13899 .28272 .13783 .28144 Mtetra
.701 .725 .868 r
.13783 .28144 .13899 .28272 .14067 .28163 .13949 .28061 Mtetra
.651 .761 .93 r
.13949 .28061 .14067 .28163 .14234 .28068 .14111 .28005 Mtetra
.261 .685 .965 r
.14111 .28005 .14234 .28068 .14395 .28021 .14265 .28012 Mtetra
.876 .482 .282 r
.14265 .28012 .14395 .28021 .14532 .28172 .14377 .28369 Mtetra
.94 .679 .514 r
.14377 .28369 .14532 .28172 .14615 .28768 .12028 .48868 Mtetra
.521 .282 .493 r
.12028 .48868 .14615 .28768 .12309 .49076 .12121 .49472 Mtetra
.552 .204 .332 r
.12121 .49472 .12309 .49076 .12437 .49395 .12278 .49551 Mtetra
.192 0 0 r
.12278 .49551 .12437 .49395 .12592 .49486 .12451 .49498 Mtetra
.681 .97 .922 r
.12451 .49498 .12592 .49486 .12757 .49502 .12631 .49391 Mtetra
.742 .777 .881 r
.12631 .49391 .12757 .49502 .12929 .49466 .12811 .49283 Mtetra
.712 .671 .808 r
.12811 .49283 .12929 .49466 .13104 .494 .12992 .49172 Mtetra
.697 .624 .771 r
.12992 .49172 .13104 .494 .13282 .49315 .13173 .49055 Mtetra
.667 .587 .756 r
.13173 .49055 .13282 .49315 .13458 .49238 .13352 .48955 Mtetra
.64 .559 .747 r
.13352 .48955 .13458 .49238 .13635 .49162 .1353 .48873 Mtetra
.618 .542 .747 r
.1353 .48873 .13635 .49162 .13812 .49085 .13705 .48808 Mtetra
.58 .529 .762 r
.13705 .48808 .13812 .49085 .13989 .49003 .13877 .48773 Mtetra
.557 .555 .808 r
.13877 .48773 .13989 .49003 .14167 .4892 .14048 .48753 Mtetra
.549 .628 .883 r
.14048 .48753 .14167 .4892 .14344 .48842 .14218 .48734 Mtetra
.566 .739 .957 r
.14218 .48734 .14344 .48842 .1452 .4878 .1439 .48701 Mtetra
.583 .805 .984 r
.1439 .48701 .1452 .4878 .14694 .48732 .14564 .48657 Mtetra
.613 .823 .981 r
.14564 .48657 .14694 .48732 .14867 .48692 .14739 .48604 Mtetra
.535 .771 .985 r
.14739 .48604 .14867 .48692 .15034 .48706 .14911 .48574 Mtetra
.619 .712 .912 r
.14911 .48574 .15034 .48706 .15203 .48708 .15086 .48526 Mtetra
.72 .676 .806 r
.15086 .48526 .15203 .48708 .15381 .48636 .15268 .48407 Mtetra
.854 .682 .668 r
.15268 .48407 .15381 .48636 .15594 .48239 .15488 .47952 Mtetra
.945 .687 .515 r
.15488 .47952 .15594 .48239 .18057 .276 .17959 .27322 Mtetra
.876 .667 .617 r
.17959 .27322 .18057 .276 .1832 .26655 .18201 .2657 Mtetra
.857 .805 .798 r
.18201 .2657 .1832 .26655 .18503 .26439 .18383 .26361 Mtetra
.67 .822 .956 r
.18383 .26361 .18503 .26439 .18668 .26383 .18549 .26296 Mtetra
.515 .752 .982 r
.18549 .26296 .18668 .26383 .18827 .26377 .1871 .26273 Mtetra
.614 .751 .943 r
.1871 .26273 .18827 .26377 .18989 .26347 .18874 .26229 Mtetra
.671 .74 .902 r
.18874 .26229 .18989 .26347 .19155 .26287 .1904 .26162 Mtetra
.662 .726 .897 r
.1904 .26162 .19155 .26287 .19321 .26221 .19206 .261 Mtetra
.697 .741 .885 r
.19206 .261 .19321 .26221 .19492 .26111 .19374 .2602 Mtetra
.678 .794 .936 r
.19374 .2602 .19492 .26111 .19664 .26002 .19541 .25951 Mtetra
.354 .762 .982 r
.19541 .25951 .19664 .26002 .19828 .25952 .19702 .2594 Mtetra
.831 .381 .155 r
.19702 .2594 .19828 .25952 .19967 .26153 .19835 .26193 Mtetra
.948 .682 .5 r
.19835 .26193 .19967 .26153 .18 .46426 .17842 .46637 Mtetra
.865 .539 .432 r
.17842 .46637 .18 .46426 .18049 .47589 .17927 .47454 Mtetra
0 0 .477 r
.17927 .47454 .18049 .47589 .18203 .47761 .18081 .47623 Mtetra
.512 .664 .93 r
.18081 .47623 .18203 .47761 .18378 .47728 .18254 .47611 Mtetra
.749 .774 .873 r
.18254 .47611 .18378 .47728 .18563 .47599 .18438 .47495 Mtetra
.895 .774 .72 r
.18438 .47495 .18563 .47599 .18764 .47321 .18647 .47138 Mtetra
.949 .689 .507 r
.18647 .47138 .18764 .47321 .19 .46692 .20809 .27671 Mtetra
.563 .323 .51 r
.20809 .27671 .19 .46692 .21251 .2616 .21191 .25503 Mtetra
.672 .478 .614 r
.21191 .25503 .21251 .2616 .21466 .25634 .2138 .25229 Mtetra
.606 .476 .678 r
.2138 .25229 .21466 .25634 .21648 .25426 .21549 .25153 Mtetra
.562 .511 .755 r
.21549 .25153 .21648 .25426 .21822 .25293 .21712 .25129 Mtetra
.586 .636 .867 r
.21712 .25129 .21822 .25293 .21993 .25202 .21877 .25097 Mtetra
.654 .762 .929 r
.21877 .25097 .21993 .25202 .22161 .25138 .22045 .25038 Mtetra
.658 .773 .934 r
.22045 .25038 .22161 .25138 .22327 .25087 .22212 .24977 Mtetra
.726 .768 .886 r
.22212 .24977 .22327 .25087 .22497 .2501 .22383 .24882 Mtetra
.733 .741 .858 r
.22383 .24882 .22497 .2501 .22668 .24917 .22556 .24778 Mtetra
.628 .692 .891 r
.22556 .24778 .22668 .24917 .22835 .24865 .22723 .24729 Mtetra
0 0 .505 r
.22723 .24729 .22835 .24865 .22988 .24955 .22869 .24893 Mtetra
.952 .684 .491 r
.22869 .24893 .22988 .24955 .23107 .25415 .21138 .44635 Mtetra
.545 .302 .498 r
.21138 .44635 .23107 .25415 .21329 .45852 .21151 .46312 Mtetra
.627 .29 .38 r
.21151 .46312 .21329 .45852 .21461 .46298 .21307 .46509 Mtetra
.331 0 .072 r
.21307 .46509 .21461 .46298 .21626 .46399 .21485 .46474 Mtetra
.338 .785 .627 r
.21485 .46474 .21626 .46399 .21798 .46421 .21669 .46375 Mtetra
.685 .902 .974 r
.21669 .46375 .21798 .46421 .21973 .46424 .21851 .4629 Mtetra
.636 .719 .908 r
.21851 .4629 .21973 .46424 .22149 .46411 .22032 .46233 Mtetra
.716 .684 .819 r
.22032 .46233 .22149 .46411 .2233 .4634 .22217 .46119 Mtetra
.831 .684 .7 r
.22217 .46119 .2233 .4634 .22525 .46127 .22423 .45786 Mtetra
.951 .687 .5 r
.22423 .45786 .22525 .46127 .22749 .45586 .24428 .25705 Mtetra
.546 .308 .506 r
.24428 .25705 .22749 .45586 .24782 .2499 .2473 .24188 Mtetra
.657 .454 .598 r
.2473 .24188 .24782 .2499 .25008 .24298 .24921 .23893 Mtetra
.613 .482 .678 r
.24921 .23893 .25008 .24298 .25194 .24062 .25092 .23808 Mtetra
.58 .536 .771 r
.25092 .23808 .25194 .24062 .25371 .23913 .2526 .23775 Mtetra
.578 .675 .906 r
.2526 .23775 .25371 .23913 .25544 .23819 .25427 .23744 Mtetra
.641 .827 .972 r
.25427 .23744 .25544 .23819 .25713 .23762 .25596 .23685 Mtetra
.648 .823 .967 r
.25596 .23685 .25713 .23762 .25881 .23723 .25766 .23624 Mtetra
.673 .783 .932 r
.25766 .23624 .25881 .23723 .2605 .23679 .25937 .23556 Mtetra
.687 .741 .892 r
.25937 .23556 .2605 .23679 .2622 .23615 .26109 .2348 Mtetra
.677 .717 .879 r
.26109 .2348 .2622 .23615 .26391 .23545 .2628 .23407 Mtetra
.684 .715 .872 r
.2628 .23407 .26391 .23545 .26564 .23453 .26452 .2333 Mtetra
.685 .741 .894 r
.26452 .2333 .26564 .23453 .26739 .23342 .26624 .23255 Mtetra
.521 .761 .984 r
.26624 .23255 .26739 .23342 .2691 .2327 .26791 .2323 Mtetra
.665 .112 0 r
.26791 .2323 .2691 .2327 .27073 .23312 .26945 .23375 Mtetra
.946 .657 .461 r
.26945 .23375 .27073 .23312 .2721 .23651 .2684 .26638 Mtetra
.913 .636 .503 r
.2684 .26638 .2721 .23651 .257 .44072 .25512 .44772 Mtetra
.614 .301 .416 r
.25512 .44772 .257 .44072 .25819 .44788 .2567 .45008 Mtetra
.367 0 .103 r
.2567 .45008 .25819 .44788 .25986 .44929 .25851 .44983 Mtetra
.334 .799 .689 r
.25851 .44983 .25986 .44929 .26161 .44971 .26036 .44898 Mtetra
.713 .859 .951 r
.26036 .44898 .26161 .44971 .2634 .44958 .26222 .44806 Mtetra
.633 .693 .888 r
.26222 .44806 .2634 .44958 .26523 .44908 .26405 .4475 Mtetra
.644 .688 .877 r
.26405 .4475 .26523 .44908 .26707 .44838 .26589 .44687 Mtetra
.637 .697 .889 r
.26589 .44687 .26707 .44838 .26891 .44779 .26773 .44629 Mtetra
.623 .692 .894 r
.26773 .44629 .26891 .44779 .27072 .44751 .26956 .44576 Mtetra
.705 .689 .832 r
.26956 .44576 .27072 .44751 .27257 .44684 .27143 .44473 Mtetra
.814 .688 .726 r
.27143 .44473 .27257 .44684 .2745 .44502 .27343 .44203 Mtetra
.915 .682 .572 r
.27343 .44203 .2745 .44502 .27669 .43986 .27622 .42911 Mtetra
.948 .678 .492 r
.27622 .42911 .27669 .43986 .29401 .23432 .2935 .22513 Mtetra
.662 .451 .587 r
.2935 .22513 .29401 .23432 .29628 .22648 .29545 .22152 Mtetra
.606 .454 .65 r
.29545 .22152 .29628 .22648 .29803 .22552 .2972 .22055 Mtetra
.559 .422 .651 r
.2972 .22055 .29803 .22552 .29973 .22528 .29891 .22016 Mtetra
.545 .409 .647 r
.29891 .22016 .29973 .22528 .30148 .22452 .30061 .21993 Mtetra
.58 .446 .662 r
.30061 .21993 .30148 .22452 .30333 .22222 .30234 .21934 Mtetra
.609 .531 .742 r
.30234 .21934 .30333 .22222 .30516 .22027 .30406 .21876 Mtetra
.645 .684 .873 r
.30406 .21876 .30516 .22027 .30694 .21888 .3058 .21817 Mtetra
.642 .839 .976 r
.3058 .21817 .30694 .21888 .30867 .21825 .30753 .21755 Mtetra
.65 .845 .975 r
.30753 .21755 .30867 .21825 .3104 .21781 .30926 .2169 Mtetra
.676 .807 .945 r
.30926 .2169 .3104 .21781 .31212 .21737 .31101 .2162 Mtetra
.697 .759 .9 r
.31101 .2162 .31212 .21737 .31386 .21669 .31276 .21538 Mtetra
.687 .733 .885 r
.31276 .21538 .31386 .21669 .3156 .21596 .31451 .2146 Mtetra
.684 .723 .879 r
.31451 .2146 .3156 .21596 .31736 .21508 .31625 .21382 Mtetra
.7 .745 .887 r
.31625 .21382 .31736 .21508 .31914 .21391 .31801 .21298 Mtetra
.58 .773 .971 r
.31801 .21298 .31914 .21391 .32089 .21308 .31974 .21258 Mtetra
.35 0 0 r
.31974 .21258 .32089 .21308 .32258 .21314 .32138 .21341 Mtetra
.922 .575 .362 r
.32138 .21341 .32258 .21314 .32409 .21615 .32253 .22168 Mtetra
.954 .676 .471 r
.32253 .22168 .32409 .21615 .31256 .41818 .31066 .4278 Mtetra
.618 .318 .439 r
.31066 .4278 .31256 .41818 .31374 .42791 .31227 .43102 Mtetra
.417 .039 .211 r
.31227 .43102 .31374 .42791 .31559 .42769 .31412 .43081 Mtetra
.29 0 .151 r
.31412 .43081 .31559 .42769 .31749 .42658 .31601 .42989 Mtetra
.253 0 .148 r
.31601 .42989 .31749 .42658 .31937 .42578 .31792 .42872 Mtetra
.317 0 .15 r
.31792 .42872 .31937 .42578 .32112 .42705 .3198 .42799 Mtetra
0 0 0 r
.3198 .42799 .32112 .42705 .3229 .42797 .32168 .42728 Mtetra
.637 .857 .983 r
.32168 .42728 .3229 .42797 .32472 .42831 .32356 .4266 Mtetra
.632 .669 .868 r
.32356 .4266 .32472 .42831 .32659 .42771 .32544 .42602 Mtetra
.635 .673 .869 r
.32544 .42602 .32659 .42771 .32849 .4269 .32732 .42542 Mtetra
.638 .705 .895 r
.32732 .42542 .32849 .4269 .33037 .42614 .3292 .42481 Mtetra
.582 .71 .931 r
.3292 .42481 .33037 .42614 .33222 .42609 .33107 .42443 Mtetra
.681 .696 .857 r
.33107 .42443 .33222 .42609 .33409 .42569 .33297 .42357 Mtetra
.78 .681 .755 r
.33297 .42357 .33409 .42569 .33601 .42446 .33493 .42153 Mtetra
.906 .682 .588 r
.33493 .42153 .33601 .42446 .33811 .42016 .33735 .41177 Mtetra
.956 .681 .475 r
.33735 .41177 .33811 .42016 .35108 .22521 .35112 .20408 Mtetra
.598 .37 .542 r
.35112 .20408 .35108 .22521 .35399 .20447 .3531 .19973 Mtetra
.617 .468 .656 r
.3531 .19973 .35399 .20447 .35588 .20168 .35489 .19865 Mtetra
.588 .511 .736 r
.35489 .19865 .35588 .20168 .3577 .19998 .35664 .1982 Mtetra
.539 .6 .863 r
.35664 .1982 .3577 .19998 .3595 .19883 .35838 .19806 Mtetra
.614 .822 .98 r
.35838 .19806 .3595 .19883 .36127 .19808 .36015 .19752 Mtetra
.585 .86 .995 r
.36015 .19752 .36127 .19808 .36303 .19755 .36191 .19698 Mtetra
.592 .86 .994 r
.36191 .19698 .36303 .19755 .36479 .19715 .36368 .19643 Mtetra
.626 .84 .982 r
.36368 .19643 .36479 .19715 .36656 .19667 .36545 .19584 Mtetra
.645 .82 .967 r
.36545 .19584 .36656 .19667 .36832 .19619 .36722 .19522 Mtetra
.661 .794 .946 r
.36722 .19522 .36832 .19619 .37009 .19567 .369 .19456 Mtetra
.684 .771 .917 r
.369 .19456 .37009 .19567 .37186 .19503 .37078 .1938 Mtetra
.681 .75 .903 r
.37078 .1938 .37186 .19503 .37364 .1943 .37256 .19304 Mtetra
.671 .741 .902 r
.37256 .19304 .37364 .1943 .37543 .19351 .37434 .19233 Mtetra
.624 .74 .93 r
.37434 .19233 .37543 .19351 .37722 .1926 .37612 .19182 Mtetra
.593 .815 .984 r
.37612 .19182 .37722 .1926 .37902 .19168 .37789 .19133 Mtetra
.52 .877 .984 r
.37789 .19133 .37902 .19168 .38081 .19078 .37967 .19082 Mtetra
.729 .984 .901 r
.37967 .19082 .38081 .19078 .38261 .18965 .38148 .18957 Mtetra
.621 .948 .94 r
.38148 .18957 .38261 .18965 .3844 .18885 .38327 .18868 Mtetra
.186 .712 .859 r
.38327 .18868 .3844 .18885 .38617 .18859 .38504 .18855 Mtetra
.899 .499 .245 r
.38504 .18855 .38617 .18859 .38782 .19101 .38656 .19361 Mtetra
.963 .679 .448 r
.38656 .19361 .38782 .19101 .38902 .20346 .37885 .40292 Mtetra
.518 .278 .491 r
.37885 .40292 .38902 .20346 .38188 .40449 .38052 .40767 Mtetra
.458 .08 .233 r
.38052 .40767 .38188 .40449 .38374 .40499 .38241 .40773 Mtetra
.293 0 .122 r
.38241 .40773 .38374 .40499 .38567 .4041 .38434 .40694 Mtetra
.204 0 .09 r
.38434 .40694 .38567 .4041 .38764 .40248 .38629 .40572 Mtetra
.327 0 .179 r
.38629 .40572 .38764 .40248 .38958 .40122 .38822 .40492 Mtetra
.353 .001 .22 r
.38822 .40492 .38958 .40122 .39152 .40023 .39015 .40414 Mtetra
.363 .016 .236 r
.39015 .40414 .39152 .40023 .39343 .39984 .39208 .40336 Mtetra
.353 0 .209 r
.39208 .40336 .39343 .39984 .39527 .40122 .39401 .40263 Mtetra
.122 0 0 r
.39401 .40263 .39527 .40122 .39713 .40234 .39594 .40192 Mtetra
.593 .899 .986 r
.39594 .40192 .39713 .40234 .39901 .40296 .39788 .40122 Mtetra
.652 .678 .863 r
.39788 .40122 .39901 .40296 .40093 .40256 .39981 .40051 Mtetra
.641 .635 .829 r
.39981 .40051 .40093 .40256 .40287 .40185 .40175 .39982 Mtetra
.636 .635 .832 r
.40175 .39982 .40287 .40185 .40481 .40097 .40368 .39915 Mtetra
.629 .658 .859 r
.40368 .39915 .40481 .40097 .40675 .40017 .40562 .39856 Mtetra
.625 .686 .887 r
.40562 .39856 .40675 .40017 .4087 .39937 .40755 .39799 Mtetra
.621 .722 .919 r
.40755 .39799 .4087 .39937 .41064 .39861 .40949 .39745 Mtetra
.6 .756 .953 r
.40949 .39745 .41064 .39861 .41258 .39797 .41142 .39697 Mtetra
.601 .789 .97 r
.41142 .39697 .41258 .39797 .41452 .39739 .41336 .39645 Mtetra
.625 .808 .97 r
.41336 .39645 .41452 .39739 .41646 .39687 .4153 .39584 Mtetra
.568 .77 .974 r
.4153 .39584 .41646 .39687 .41838 .39682 .41724 .39543 Mtetra
.671 .739 .902 r
.41724 .39543 .41838 .39682 .42031 .39653 .41919 .39465 Mtetra
.759 .703 .799 r
.41919 .39465 .42031 .39653 .42227 .39562 .42117 .39306 Mtetra
.897 .695 .621 r
.42117 .39306 .42227 .39562 .42431 .39209 .4233 .38653 Mtetra
.966 .684 .447 r
.4233 .38653 .42431 .39209 .42656 .38159 .43179 .17533 Mtetra
.522 .287 .5 r
.43179 .17533 .42656 .38159 .4347 .17484 .43377 .16958 Mtetra
.641 .474 .641 r
.43377 .16958 .4347 .17484 .43661 .17132 .43561 .16796 Mtetra
.605 .507 .717 r
.43561 .16796 .43661 .17132 .43847 .16941 .43743 .16731 Mtetra
.568 .58 .825 r
.43743 .16731 .43847 .16941 .44031 .1681 .43925 .16705 Mtetra
.637 .776 .947 r
.43925 .16705 .44031 .1681 .44214 .1672 .44107 .16646 Mtetra
.65 .848 .976 r
.44107 .16646 .44214 .1672 .44396 .16654 .44289 .16577 Mtetra
.653 .844 .974 r
.44289 .16577 .44396 .16654 .44578 .16602 .44472 .16509 Mtetra
.67 .812 .951 r
.44472 .16509 .44578 .16602 .4476 .16549 .44655 .16436 Mtetra
.669 .772 .927 r
.44655 .16436 .4476 .16549 .44943 .16495 .44838 .16365 Mtetra
.656 .737 .909 r
.44838 .16365 .44943 .16495 .45126 .16436 .45021 .16299 Mtetra
.613 .707 .912 r
.45021 .16299 .45126 .16436 .45309 .16359 .45203 .16251 Mtetra
.579 .751 .959 r
.45203 .16251 .45309 .16359 .45493 .16274 .45386 .16212 Mtetra
.516 .828 1 r
.45386 .16212 .45493 .16274 .45676 .16189 .45569 .16173 Mtetra
.666 .959 .941 r
.45569 .16173 .45676 .16189 .4586 .16085 .45753 .16073 Mtetra
.623 .949 .937 r
.45753 .16073 .4586 .16085 .46044 .16 .45937 .15982 Mtetra
.29 .779 .901 r
.45937 .15982 .46044 .16 .46227 .15963 .4612 .15954 Mtetra
.842 .382 .095 r
.4612 .15954 .46227 .15963 .46406 .16133 .46296 .1629 Mtetra
.969 .678 .42 r
.46296 .1629 .46406 .16133 .46574 .16863 .46055 .37323 Mtetra
.52 .28 .492 r
.46055 .37323 .46574 .16863 .46361 .37596 .46239 .37955 Mtetra
.545 .174 .287 r
.46239 .37955 .46361 .37596 .46554 .37776 .46434 .38038 Mtetra
.337 0 .132 r
.46434 .38038 .46554 .37776 .46751 .37721 .46632 .37983 Mtetra
.239 0 .088 r
.46632 .37983 .46751 .37721 .4695 .37593 .46831 .37881 Mtetra
.308 0 .144 r
.46831 .37881 .4695 .37593 .47149 .37502 .47029 .37802 Mtetra
.338 0 .166 r
.47029 .37802 .47149 .37502 .47347 .37432 .47228 .37734 Mtetra
.337 0 .167 r
.47228 .37734 .47347 .37432 .47545 .37361 .47427 .37665 Mtetra
.339 0 .17 r
.47427 .37665 .47545 .37361 .47744 .3729 .47626 .37596 Mtetra
.341 0 .173 r
.47626 .37596 .47744 .3729 .47943 .37218 .47825 .37527 Mtetra
.341 0 .175 r
.47825 .37527 .47943 .37218 .48142 .37147 .48024 .37458 Mtetra
.341 0 .177 r
.48024 .37458 .48142 .37147 .48341 .3705 .48223 .37387 Mtetra
.353 0 .2 r
.48223 .37387 .48341 .3705 .4854 .36959 .48423 .37316 Mtetra
.362 .004 .217 r
.48423 .37316 .4854 .36959 .48739 .3691 .48622 .37244 Mtetra
.35 0 .197 r
.48622 .37244 .48739 .3691 .48937 .36986 .48822 .37171 Mtetra
.216 0 0 r
.48822 .37171 .48937 .36986 .49135 .37085 .49022 .37099 Mtetra
.381 .844 .821 r
.49022 .37099 .49135 .37085 .49333 .37145 .49222 .37026 Mtetra
.657 .776 .937 r
.49222 .37026 .49333 .37145 .49533 .37126 .49422 .36953 Mtetra
.65 .685 .87 r
.49422 .36953 .49533 .37126 .49733 .3706 .49623 .36882 Mtetra
.647 .677 .865 r
.49623 .36882 .49733 .3706 .49934 .36978 .49823 .36811 Mtetra
.646 .693 .879 r
.49823 .36811 .49934 .36978 .50134 .36902 .50024 .36741 Mtetra
.645 .701 .888 r
.50024 .36741 .50134 .36902 .50335 .36834 .50224 .36674 Mtetra
.642 .701 .889 r
.50224 .36674 .50335 .36834 .50536 .36766 .50425 .36607 Mtetra
.633 .699 .893 r
.50425 .36607 .50536 .36766 .50737 .36699 .50626 .36545 Mtetra
.632 .707 .9 r
.50626 .36545 .50737 .36699 .50938 .36633 .50827 .36483 Mtetra
.643 .719 .903 r
.50827 .36483 .50938 .36633 .51139 .36571 .51029 .36417 Mtetra
.678 .726 .886 r
.51029 .36417 .51139 .36571 .5134 .36517 .5123 .36331 Mtetra
.689 .686 .842 r
.5123 .36331 .5134 .36517 .51542 .36468 .51432 .36232 Mtetra
.671 .625 .795 r
.51432 .36232 .51542 .36468 .51744 .36419 .51634 .36132 Mtetra
.633 .566 .762 r
.51634 .36132 .51744 .36419 .51945 .36363 .51836 .3605 Mtetra
.607 .536 .749 r
.51836 .3605 .51945 .36363 .52147 .36299 .52038 .35986 Mtetra
.6 .531 .749 r
.52038 .35986 .52147 .36299 .5235 .36234 .5224 .35927 Mtetra
.604 .538 .753 r
.5224 .35927 .5235 .36234 .52552 .36167 .52442 .35865 Mtetra
.609 .544 .756 r
.52442 .35865 .52552 .36167 .52754 .36101 .52645 .358 Mtetra
.61 .545 .756 r
.52645 .358 .52754 .36101 .52957 .36035 .52847 .35734 Mtetra
.611 .546 .757 r
.52847 .35734 .52957 .36035 .5316 .35968 .5305 .35668 Mtetra
.612 .547 .757 r
.5305 .35668 .5316 .35968 .53363 .359 .53253 .35601 Mtetra
.612 .548 .758 r
.53253 .35601 .53363 .359 .53566 .35833 .53456 .35534 Mtetra
.613 .548 .758 r
.53456 .35534 .53566 .35833 .53769 .35765 .53659 .35466 Mtetra
.613 .549 .758 r
.53659 .35466 .53769 .35765 .53973 .35697 .53863 .35398 Mtetra
.53863 .35398 .53973 .35697 .54176 .35629 .54066 .3533 Mtetra
.54066 .3533 .54176 .35629 .5438 .3556 .5427 .35262 Mtetra
.614 .549 .758 r
.5427 .35262 .5438 .3556 .54584 .35492 .54474 .35193 Mtetra
.614 .549 .759 r
.54474 .35193 .54584 .35492 .54788 .35424 .54678 .35125 Mtetra
.614 .55 .759 r
.54678 .35125 .54788 .35424 .54992 .35355 .54882 .35056 Mtetra
.54882 .35056 .54992 .35355 .55196 .35286 .55086 .34988 Mtetra
.55086 .34988 .55196 .35286 .554 .35217 .55291 .34919 Mtetra
.55291 .34919 .554 .35217 .55605 .35149 .55495 .3485 Mtetra
.55495 .3485 .55605 .35149 .5581 .3508 .557 .34781 Mtetra
.557 .34781 .5581 .3508 .56015 .35011 .55905 .34712 Mtetra
.55905 .34712 .56015 .35011 .5622 .34942 .5611 .34643 Mtetra
.5611 .34643 .5622 .34942 .56425 .34872 .56315 .34573 Mtetra
.56315 .34573 .56425 .34872 .5663 .34803 .56521 .34504 Mtetra
.56521 .34504 .5663 .34803 .56836 .34734 .56726 .34435 Mtetra
.56726 .34435 .56836 .34734 .57042 .34665 .56932 .34365 Mtetra
.56932 .34365 .57042 .34665 .57247 .34595 .57137 .34296 Mtetra
.57137 .34296 .57247 .34595 .57453 .34526 .57343 .34226 Mtetra
.57343 .34226 .57453 .34526 .57659 .34456 .5755 .34156 Mtetra
.5755 .34156 .57659 .34456 .57866 .34387 .57756 .34087 Mtetra
.57756 .34087 .57866 .34387 .58072 .34317 .57962 .34017 Mtetra
.57962 .34017 .58072 .34317 .58279 .34247 .58169 .33947 Mtetra
.58169 .33947 .58279 .34247 .58485 .34177 .58376 .33877 Mtetra
.58376 .33877 .58485 .34177 .58692 .34108 .58582 .33807 Mtetra
.58582 .33807 .58692 .34108 .58899 .34038 .58789 .33737 Mtetra
.58789 .33737 .58899 .34038 .59107 .33968 .58997 .33667 Mtetra
.58997 .33667 .59107 .33968 .59314 .33898 .59204 .33597 Mtetra
.59204 .33597 .59314 .33898 .59521 .33828 .59411 .33527 Mtetra
.59411 .33527 .59521 .33828 .59729 .33758 .59619 .33457 Mtetra
.59619 .33457 .59729 .33758 .59937 .33688 .59827 .33386 Mtetra
.59827 .33386 .59937 .33688 .60145 .33617 .60035 .33316 Mtetra
.60035 .33316 .60145 .33617 .60353 .33547 .60243 .33246 Mtetra
.60243 .33246 .60353 .33547 .60561 .33477 .60451 .33175 Mtetra
.60451 .33175 .60561 .33477 .6077 .33406 .6066 .33105 Mtetra
.615 .55 .759 r
.6066 .33105 .6077 .33406 .60978 .33336 .60868 .33034 Mtetra
.60868 .33034 .60978 .33336 .61187 .33265 .61077 .32963 Mtetra
.61077 .32963 .61187 .33265 .61396 .33195 .61286 .32892 Mtetra
.61286 .32892 .61396 .33195 .61605 .33124 .61495 .32822 Mtetra
.615 .55 .758 r
.61495 .32822 .61605 .33124 .61814 .33053 .61704 .32751 Mtetra
.61704 .32751 .61814 .33053 .62024 .32982 .61913 .32679 Mtetra
.61913 .32679 .62024 .32982 .62233 .32911 .62123 .32608 Mtetra
.62123 .32608 .62233 .32911 .62443 .3284 .62333 .32537 Mtetra
.62333 .32537 .62443 .3284 .62653 .32769 .62542 .32465 Mtetra
.62542 .32465 .62653 .32769 .62863 .32697 .62752 .32393 Mtetra
.62752 .32393 .62863 .32697 .63073 .32625 .62962 .32321 Mtetra
.616 .55 .758 r
.62962 .32321 .63073 .32625 .63283 .32553 .63173 .32249 Mtetra
.63173 .32249 .63283 .32553 .63493 .32481 .63383 .32176 Mtetra
.616 .55 .757 r
.63383 .32176 .63493 .32481 .63704 .32408 .63594 .32103 Mtetra
.617 .55 .757 r
.63594 .32103 .63704 .32408 .63915 .32336 .63804 .32029 Mtetra
.617 .55 .756 r
.63804 .32029 .63915 .32336 .64126 .32262 .64015 .31955 Mtetra
.64015 .31955 .64126 .32262 .64336 .32183 .64226 .31881 Mtetra
.619 .554 .759 r
.64226 .31881 .64336 .32183 .64547 .32096 .64437 .31805 Mtetra
.622 .563 .768 r
.64437 .31805 .64547 .32096 .64758 .32008 .64649 .3173 Mtetra
.624 .574 .777 r
.64649 .3173 .64758 .32008 .64969 .31923 .6486 .31656 Mtetra
.626 .582 .785 r
.6486 .31656 .64969 .31923 .6518 .31847 .65072 .31581 Mtetra
.625 .584 .787 r
.65072 .31581 .6518 .31847 .65392 .31773 .65283 .31508 Mtetra
.624 .583 .788 r
.65283 .31508 .65392 .31773 .65604 .31702 .65495 .31436 Mtetra
.621 .581 .788 r
.65495 .31436 .65604 .31702 .65816 .31631 .65708 .31366 Mtetra
.62 .582 .789 r
.65708 .31366 .65816 .31631 .66029 .31561 .6592 .31297 Mtetra
.603 .573 .793 r
.6592 .31297 .66029 .31561 .66242 .315 .66133 .3124 Mtetra
.549 .547 .804 r
.66133 .3124 .66242 .315 .66456 .31464 .66348 .31219 Mtetra
.628 .603 .806 r
.66348 .31219 .66456 .31464 .66669 .31393 .66561 .31147 Mtetra
.772 .671 .753 r
.66561 .31147 .66669 .31393 .66878 .31231 .66768 .30937 Mtetra
.936 .7 .556 r
.66768 .30937 .66878 .31231 .67073 .30776 .66942 .30022 Mtetra
.975 .67 .357 r
.66942 .30022 .67073 .30776 .67133 .27471 .66156 .087 Mtetra
.52 .285 .499 r
.66156 .087 .67133 .27471 .66449 .08747 .66336 .08245 Mtetra
.615 .463 .653 r
.66336 .08245 .66449 .08747 .66637 .08464 .66532 .08127 Mtetra
.589 .503 .726 r
.66532 .08127 .66637 .08464 .6683 .08292 .66731 .08073 Mtetra
.569 .581 .826 r
.66731 .08073 .6683 .08292 .67026 .08174 .66931 .08043 Mtetra
.658 .753 .92 r
.66931 .08043 .67026 .08174 .67224 .08089 .6713 .07971 Mtetra
.659 .778 .937 r
.6713 .07971 .67224 .08089 .67423 .08023 .67328 .07898 Mtetra
.681 .774 .921 r
.67328 .07898 .67423 .08023 .67622 .07956 .67527 .07815 Mtetra
.753 .771 .867 r
.67527 .07815 .67622 .07956 .67818 .07841 .67723 .07688 Mtetra
.678 .722 .883 r
.67723 .07688 .67818 .07841 .68017 .07758 .67921 .07603 Mtetra
.421 .591 .913 r
.67921 .07603 .68017 .07758 .68219 .07749 .68125 .07623 Mtetra
.829 .415 0 r
.68125 .07623 .68219 .07749 .68437 .08027 .6836 .0821 Mtetra
.972 .659 .321 r
.6836 .0821 .68437 .08027 .69784 .28569 .69748 .29599 Mtetra
.627 .313 .419 r
.69748 .29599 .69784 .28569 .70068 .29739 .69991 .30013 Mtetra
.41 .011 .168 r
.69991 .30013 .70068 .29739 .70296 .2989 .70209 .29995 Mtetra
0 0 0 r
.70209 .29995 .70296 .2989 .70518 .29927 .70424 .299 Mtetra
.683 .968 .929 r
.70424 .299 .70518 .29927 .70738 .29913 .70637 .29776 Mtetra
.516 .696 .951 r
.70637 .29776 .70738 .29913 .70958 .29908 .70856 .29754 Mtetra
.633 .724 .913 r
.70856 .29754 .70958 .29908 .71174 .29838 .71073 .29688 Mtetra
.792 .789 .849 r
.71073 .29688 .71174 .29838 .71384 .29658 .71284 .2952 Mtetra
.978 .777 .564 r
.71284 .2952 .71384 .29658 .7156 .28922 .7146 .28783 Mtetra
.975 .669 .322 r
.7146 .28783 .7156 .28922 .70443 .07343 .70349 .07204 Mtetra
.965 .783 .608 r
.70349 .07204 .70443 .07343 .70614 .06787 .7052 .06649 Mtetra
.759 .78 .87 r
.7052 .06649 .70614 .06787 .70811 .06657 .70718 .06518 Mtetra
.628 .728 .919 r
.70718 .06518 .70811 .06657 .71013 .06598 .70919 .06458 Mtetra
.545 .687 .932 r
.70919 .06458 .71013 .06598 .71217 .06572 .71124 .06431 Mtetra
.749 .774 .874 r
.71124 .06431 .71217 .06572 .71415 .06447 .71322 .06307 Mtetra
.683 .75 .903 r
.71322 .06307 .71415 .06447 .71616 .06362 .71523 .06221 Mtetra
.492 .658 .934 r
.71523 .06221 .71616 .06362 .71822 .06357 .71729 .06213 Mtetra
.726 .31 0 r
.71729 .06213 .71822 .06357 .72064 .06886 .71968 .06694 Mtetra
.97 .656 .29 r
.71968 .06694 .72064 .06886 .73743 .28388 .73639 .28171 Mtetra
0 0 .341 r
.73639 .28171 .73743 .28388 .73998 .28858 .73897 .28679 Mtetra
.256 .601 .952 r
.04782 .51887 .04912 .51991 .05071 .52004 .04939 .51914 Mtetra
.666 .796 .944 r
.04939 .51914 .05071 .52004 .05242 .51936 .0511 .51848 Mtetra
.79 .809 .867 r
.0511 .51848 .05242 .51936 .05419 .51821 .0529 .51712 Mtetra
.815 .772 .812 r
.0529 .51712 .05419 .51821 .05585 .51787 .05477 .51532 Mtetra
.789 .644 .701 r
.05477 .51532 .05585 .51787 .05757 .51713 .05678 .51252 Mtetra
.793 .592 .63 r
.05678 .51252 .05757 .51713 .0594 .51561 .05915 .50709 Mtetra
.929 .677 .536 r
.05915 .50709 .0594 .51561 .06195 .50889 .08883 .30577 Mtetra
.524 .29 .502 r
.08883 .30577 .06195 .50889 .09201 .30346 .09118 .29971 Mtetra
.745 .573 .661 r
.09118 .29971 .09201 .30346 .09427 .29809 .09309 .29687 Mtetra
.762 .743 .835 r
.09309 .29687 .09427 .29809 .09597 .29673 .09478 .29564 Mtetra
.669 .748 .91 r
.09478 .29564 .09597 .29673 .09757 .29615 .09638 .29501 Mtetra
.513 .689 .947 r
.09638 .29501 .09757 .29615 .09911 .29596 .09792 .29487 Mtetra
.186 .537 .925 r
.09792 .29487 .09911 .29596 .10074 .29516 .09939 .29527 Mtetra
.686 .172 .005 r
.09939 .29527 .10074 .29516 .10234 .29464 .10074 .29651 Mtetra
.778 .422 .382 r
.10074 .29651 .10234 .29464 .10384 .29479 .10182 .29981 Mtetra
.932 .674 .524 r
.10182 .29981 .10384 .29479 .10479 .29905 .07636 .49968 Mtetra
.522 .283 .493 r
.07636 .49968 .10479 .29905 .07888 .50364 .07714 .50595 Mtetra
.696 .323 .338 r
.07714 .50595 .07888 .50364 .0798 .50895 .07849 .50806 Mtetra
.256 .636 .962 r
.07849 .50806 .0798 .50895 .08138 .50937 .0801 .50826 Mtetra
.639 .751 .93 r
.0801 .50826 .08138 .50937 .08309 .50878 .08181 .50771 Mtetra
.751 .78 .876 r
.08181 .50771 .08309 .50878 .08487 .5077 .08359 .50658 Mtetra
.81 .773 .818 r
.08359 .50658 .08487 .5077 .08657 .50728 .08546 .50484 Mtetra
.792 .652 .707 r
.08546 .50484 .08657 .50728 .0883 .50659 .08746 .50211 Mtetra
.796 .596 .632 r
.08746 .50211 .0883 .50659 .09013 .50513 .0898 .49677 Mtetra
.932 .678 .53 r
.0898 .49677 .09013 .50513 .09256 .49905 .11784 .29456 Mtetra
.524 .29 .501 r
.11784 .29456 .09256 .49905 .12091 .29308 .12018 .28842 Mtetra
.72 .537 .643 r
.12018 .28842 .12091 .29308 .12319 .28734 .12209 .28555 Mtetra
.704 .658 .802 r
.12209 .28555 .12319 .28734 .12492 .28583 .12376 .28454 Mtetra
.6 .693 .908 r
.12376 .28454 .12492 .28583 .12653 .28529 .12535 .28417 Mtetra
.492 .686 .953 r
.12535 .28417 .12653 .28529 .12809 .28514 .1269 .28407 Mtetra
.611 .74 .937 r
.1269 .28407 .12809 .28514 .12969 .28469 .1285 .28365 Mtetra
.653 .758 .926 r
.1285 .28365 .12969 .28469 .1313 .28414 .13012 .28308 Mtetra
.673 .758 .915 r
.13012 .28308 .1313 .28414 .13292 .28356 .13175 .28243 Mtetra
.734 .757 .871 r
.13175 .28243 .13292 .28356 .13456 .28285 .13342 .28145 Mtetra
.712 .709 .846 r
.13342 .28145 .13456 .28285 .1362 .28212 .13508 .28052 Mtetra
.656 .664 .846 r
.13508 .28052 .1362 .28212 .13783 .28144 .13671 .27988 Mtetra
.402 .557 .894 r
.13671 .27988 .13783 .28144 .13949 .28061 .13823 .2801 Mtetra
.618 .053 0 r
.13823 .2801 .13949 .28061 .14111 .28005 .13964 .2813 Mtetra
.803 .429 .349 r
.13964 .2813 .14111 .28005 .14265 .28012 .14078 .28458 Mtetra
.937 .676 .516 r
.14078 .28458 .14265 .28012 .14377 .28369 .1176 .48558 Mtetra
.523 .283 .493 r
.1176 .48558 .14377 .28369 .12028 .48868 .11843 .49231 Mtetra
.665 .318 .376 r
.11843 .49231 .12028 .48868 .12121 .49472 .11982 .49454 Mtetra
.191 0 0 r
.11982 .49454 .12121 .49472 .12278 .49551 .12145 .49487 Mtetra
.604 .843 .989 r
.12145 .49487 .12278 .49551 .12451 .49498 .12319 .49434 Mtetra
.766 .865 .922 r
.12319 .49434 .12451 .49498 .12631 .49391 .12499 .4932 Mtetra
.865 .829 .81 r
.12499 .4932 .12631 .49391 .12811 .49283 .12693 .49102 Mtetra
.849 .706 .704 r
.12693 .49102 .12811 .49283 .12992 .49172 .12902 .48754 Mtetra
.818 .615 .628 r
.12902 .48754 .12992 .49172 .13173 .49055 .13141 .48153 Mtetra
.802 .567 .582 r
.13141 .48153 .13173 .49055 .13352 .48955 .13448 .46973 Mtetra
.922 .662 .528 r
.13448 .46973 .13352 .48955 .1353 .48873 .15747 .2891 Mtetra
0 0 .118 r
.15747 .2891 .1353 .48873 .13705 .48808 .13777 .47015 Mtetra
.042 0 .397 r
.13777 .47015 .13705 .48808 .13877 .48773 .13825 .48028 Mtetra
.114 .058 .51 r
.13825 .48028 .13877 .48773 .14048 .48753 .13949 .48405 Mtetra
.084 .164 .65 r
.13949 .48405 .14048 .48753 .14218 .48734 .14096 .4859 Mtetra
.267 .527 .913 r
.14096 .4859 .14218 .48734 .1439 .48701 .14259 .48634 Mtetra
.511 .807 .999 r
.14259 .48634 .1439 .48701 .14564 .48657 .14432 .48602 Mtetra
.694 .881 .967 r
.14432 .48602 .14564 .48657 .14739 .48604 .1461 .48519 Mtetra
.81 .825 .861 r
.1461 .48519 .14739 .48604 .14911 .48574 .14796 .48365 Mtetra
.801 .678 .729 r
.14796 .48365 .14911 .48574 .15086 .48526 .14994 .48115 Mtetra
.79 .599 .642 r
.14994 .48115 .15086 .48526 .15268 .48407 .15214 .47662 Mtetra
.94 .681 .518 r
.15214 .47662 .15268 .48407 .15488 .47952 .17642 .27573 Mtetra
.53 .294 .502 r
.17642 .27573 .15488 .47952 .17959 .27322 .17895 .26737 Mtetra
.707 .512 .622 r
.17895 .26737 .17959 .27322 .18201 .2657 .1809 .26407 Mtetra
.761 .697 .791 r
.1809 .26407 .18201 .2657 .18383 .26361 .18265 .26262 Mtetra
.663 .773 .931 r
.18265 .26262 .18383 .26361 .18549 .26296 .18431 .26199 Mtetra
.57 .753 .964 r
.18431 .26199 .18549 .26296 .1871 .26273 .18593 .26166 Mtetra
.663 .758 .921 r
.18593 .26166 .1871 .26273 .18874 .26229 .18759 .26104 Mtetra
.69 .733 .884 r
.18759 .26104 .18874 .26229 .1904 .26162 .18927 .26028 Mtetra
.639 .701 .891 r
.18927 .26028 .1904 .26162 .19206 .261 .19092 .25974 Mtetra
.419 .627 .94 r
.19092 .25974 .19206 .261 .19374 .2602 .1925 .25984 Mtetra
.538 0 0 r
.1925 .25984 .19374 .2602 .19541 .25951 .19399 .26082 Mtetra
.769 .375 .307 r
.19399 .26082 .19541 .25951 .19702 .2594 .19531 .26346 Mtetra
.943 .677 .503 r
.19531 .26346 .19702 .2594 .19835 .26193 .17584 .46175 Mtetra
.529 .288 .495 r
.17584 .46175 .19835 .26193 .17842 .46637 .17651 .47147 Mtetra
.656 .328 .406 r
.17651 .47147 .17842 .46637 .17927 .47454 .17795 .47414 Mtetra
.495 0 0 r
.17795 .47414 .17927 .47454 .18081 .47623 .17956 .47512 Mtetra
.444 .686 .968 r
.17956 .47512 .18081 .47623 .18254 .47611 .18128 .47509 Mtetra
.719 .796 .912 r
.18128 .47509 .18254 .47611 .18438 .47495 .1831 .47415 Mtetra
.906 .799 .73 r
.1831 .47415 .18438 .47495 .18647 .47138 .18518 .47069 Mtetra
.95 .69 .507 r
.18518 .47069 .18647 .47138 .20809 .27671 .20725 .2724 Mtetra
.904 .661 .56 r
.20725 .2724 .20809 .27671 .21191 .25503 .21081 .25341 Mtetra
.836 .716 .731 r
.21081 .25341 .21191 .25503 .2138 .25229 .21269 .25075 Mtetra
.653 .677 .861 r
.21269 .25075 .2138 .25229 .21549 .25153 .21436 .25013 Mtetra
.501 .639 .916 r
.21436 .25013 .21549 .25153 .21712 .25129 .21598 .25007 Mtetra
.543 .69 .935 r
.21598 .25007 .21712 .25129 .21877 .25097 .21762 .24985 Mtetra
.654 .75 .92 r
.21762 .24985 .21877 .25097 .22045 .25038 .21929 .24926 Mtetra
.67 .754 .913 r
.21929 .24926 .22045 .25038 .22212 .24977 .22098 .24859 Mtetra
.744 .761 .867 r
.22098 .24859 .22212 .24977 .22383 .24882 .2227 .24752 Mtetra
.751 .742 .844 r
.2227 .24752 .22383 .24882 .22556 .24778 .22444 .24634 Mtetra
.652 .692 .874 r
.22444 .24634 .22556 .24778 .22723 .24729 .22612 .24573 Mtetra
0 .035 .586 r
.22612 .24573 .22723 .24729 .22869 .24893 .22759 .24732 Mtetra
.953 .686 .491 r
.22759 .24732 .22869 .24893 .21138 .44635 .2101 .44574 Mtetra
.948 .646 .432 r
.2101 .44574 .21138 .44635 .21151 .46312 .21023 .46249 Mtetra
.747 .227 0 r
.21023 .46249 .21151 .46312 .21307 .46509 .21179 .46447 Mtetra
.534 .829 .999 r
.21179 .46447 .21307 .46509 .21485 .46474 .21357 .46407 Mtetra
.775 .87 .918 r
.21357 .46407 .21485 .46474 .21669 .46375 .21543 .46285 Mtetra
.827 .823 .845 r
.21543 .46285 .21669 .46375 .21851 .4629 .21734 .46111 Mtetra
.809 .71 .756 r
.21734 .46111 .21851 .4629 .22032 .46233 .2193 .45884 Mtetra
.79 .614 .662 r
.2193 .45884 .22032 .46233 .22217 .46119 .2214 .4551 Mtetra
.886 .64 .561 r
.2214 .4551 .22217 .46119 .22423 .45786 .22488 .43631 Mtetra
.93 .663 .51 r
.22488 .43631 .22423 .45786 .24428 .25705 .2443 .2432 Mtetra
.628 .407 .563 r
.2443 .2432 .24428 .25705 .2473 .24188 .24629 .23927 Mtetra
.738 .615 .721 r
.24629 .23927 .2473 .24188 .24921 .23893 .2481 .23745 Mtetra
.651 .687 .871 r
.2481 .23745 .24921 .23893 .25092 .23808 .2498 .23684 Mtetra
.553 .692 .932 r
.2498 .23684 .25092 .23808 .2526 .23775 .25146 .23659 Mtetra
.562 .713 .943 r
.25146 .23659 .2526 .23775 .25427 .23744 .25313 .2363 Mtetra
.652 .749 .921 r
.25313 .2363 .25427 .23744 .25596 .23685 .25483 .23571 Mtetra
.668 .753 .914 r
.25483 .23571 .25596 .23685 .25766 .23624 .25653 .23505 Mtetra
.707 .753 .888 r
.25653 .23505 .25766 .23624 .25937 .23556 .25826 .23418 Mtetra
.725 .728 .853 r
.25826 .23418 .25937 .23556 .26109 .2348 .26 .23317 Mtetra
.679 .677 .841 r
.26 .23317 .26109 .2348 .2628 .23407 .26171 .23237 Mtetra
.56 .618 .867 r
.26171 .23237 .2628 .23407 .26452 .2333 .26339 .23215 Mtetra
0 .396 .847 r
.26339 .23215 .26452 .2333 .26624 .23255 .26498 .2329 Mtetra
.772 .307 .141 r
.26498 .2329 .26624 .23255 .26791 .2323 .26646 .235 Mtetra
.882 .565 .445 r
.26646 .235 .26791 .2323 .26945 .23375 .26716 .24634 Mtetra
.94 .665 .491 r
.26716 .24634 .26945 .23375 .2684 .26638 .25225 .44502 Mtetra
.516 .276 .491 r
.25225 .44502 .2684 .26638 .25512 .44772 .25375 .44836 Mtetra
.593 .077 0 r
.25375 .44836 .25512 .44772 .2567 .45008 .25545 .44936 Mtetra
.541 .815 .997 r
.25545 .44936 .2567 .45008 .25851 .44983 .25727 .44897 Mtetra
.686 .828 .951 r
.25727 .44897 .25851 .44983 .26036 .44898 .25912 .44817 Mtetra
.677 .835 .959 r
.25912 .44817 .26036 .44898 .26222 .44806 .26096 .4474 Mtetra
.543 .828 .998 r
.26096 .4474 .26222 .44806 .26405 .4475 .26279 .44698 Mtetra
.612 .879 .991 r
.26279 .44698 .26405 .4475 .26589 .44687 .26463 .44633 Mtetra
.763 .901 .937 r
.26463 .44633 .26589 .44687 .26773 .44629 .26651 .44516 Mtetra
.845 .792 .8 r
.26651 .44516 .26773 .44629 .26956 .44576 .26847 .443 Mtetra
.812 .652 .683 r
.26847 .443 .26956 .44576 .27143 .44473 .27054 .43953 Mtetra
.846 .618 .593 r
.27054 .43953 .27143 .44473 .27343 .44203 .27305 .43022 Mtetra
.947 .677 .493 r
.27305 .43022 .27343 .44203 .27622 .42911 .29048 .22673 Mtetra
.52 .286 .5 r
.29048 .22673 .27622 .42911 .2935 .22513 .29251 .22219 Mtetra
.749 .605 .697 r
.29251 .22219 .2935 .22513 .29545 .22152 .29436 .21996 Mtetra
.69 .693 .848 r
.29436 .21996 .29545 .22152 .2972 .22055 .2961 .21911 Mtetra
.611 .681 .892 r
.2961 .21911 .2972 .22055 .29891 .22016 .29782 .21867 Mtetra
.571 .657 .895 r
.29782 .21867 .29891 .22016 .30061 .21993 .29952 .21838 Mtetra
.606 .664 .88 r
.29952 .21838 .30061 .21993 .30234 .21934 .30124 .21797 Mtetra
.603 .69 .904 r
.30124 .21797 .30234 .21934 .30406 .21876 .30295 .21755 Mtetra
.617 .727 .925 r
.30295 .21755 .30406 .21876 .3058 .21817 .30467 .21708 Mtetra
.653 .763 .93 r
.30467 .21708 .3058 .21817 .30753 .21755 .30641 .21647 Mtetra
.674 .77 .923 r
.30641 .21647 .30753 .21755 .30926 .2169 .30815 .21577 Mtetra
.706 .768 .9 r
.30815 .21577 .30926 .2169 .31101 .2162 .3099 .21491 Mtetra
.741 .751 .861 r
.3099 .21491 .31101 .2162 .31276 .21538 .31167 .21381 Mtetra
.696 .695 .845 r
.31167 .21381 .31276 .21538 .31451 .2146 .31343 .21291 Mtetra
.606 .643 .862 r
.31343 .21291 .31451 .2146 .31625 .21382 .31515 .21249 Mtetra
.186 .484 .898 r
.31515 .21249 .31625 .21382 .31801 .21298 .31681 .21307 Mtetra
.731 .221 .006 r
.31681 .21307 .31801 .21298 .31974 .21258 .31839 .21482 Mtetra
.845 .497 .394 r
.31839 .21482 .31974 .21258 .32138 .21341 .31966 .22121 Mtetra
.951 .672 .474 r
.31966 .22121 .32138 .21341 .32253 .22168 .30775 .42495 Mtetra
.516 .277 .491 r
.30775 .42495 .32253 .22168 .31066 .4278 .30931 .42894 Mtetra
.643 .176 .129 r
.30931 .42894 .31066 .4278 .31227 .43102 .31105 .43029 Mtetra
.529 .811 .998 r
.31105 .43029 .31227 .43102 .31412 .43081 .31291 .42991 Mtetra
.699 .829 .945 r
.31291 .42991 .31412 .43081 .31601 .42989 .3148 .42904 Mtetra
.746 .846 .925 r
.3148 .42904 .31601 .42989 .31792 .42872 .3167 .42795 Mtetra
.705 .856 .954 r
.3167 .42795 .31792 .42872 .3198 .42799 .3186 .42704 Mtetra
.709 .821 .935 r
.3186 .42704 .3198 .42799 .32168 .42728 .32049 .42613 Mtetra
.686 .778 .921 r
.32049 .42613 .32168 .42728 .32356 .4266 .32238 .42532 Mtetra
.597 .724 .933 r
.32238 .42532 .32356 .4266 .32544 .42602 .32425 .42488 Mtetra
.632 .765 .943 r
.32425 .42488 .32544 .42602 .32732 .42542 .32613 .4243 Mtetra
.721 .793 .909 r
.32613 .4243 .32732 .42542 .3292 .42481 .32803 .42331 Mtetra
.816 .75 .791 r
.32803 .42331 .3292 .42481 .33107 .42443 .33 .42127 Mtetra
.793 .628 .677 r
.33 .42127 .33107 .42443 .33297 .42357 .33205 .41793 Mtetra
.831 .602 .592 r
.33205 .41793 .33297 .42357 .33493 .42153 .3344 .40936 Mtetra
.952 .677 .479 r
.3344 .40936 .33493 .42153 .33735 .41177 .34816 .20518 Mtetra
.52 .285 .5 r
.34816 .20518 .33735 .41177 .35112 .20408 .35016 .2005 Mtetra
.736 .574 .674 r
.35016 .2005 .35112 .20408 .3531 .19973 .35203 .19806 Mtetra
.667 .673 .846 r
.35203 .19806 .3531 .19973 .35489 .19865 .3538 .19731 Mtetra
.569 .686 .92 r
.3538 .19731 .35489 .19865 .35664 .1982 .35555 .19701 Mtetra
.486 .68 .951 r
.35555 .19701 .35664 .1982 .35838 .19806 .35729 .19692 Mtetra
.619 .746 .937 r
.35729 .19692 .35838 .19806 .36015 .19752 .35905 .19642 Mtetra
.63 .759 .94 r
.35905 .19642 .36015 .19752 .36191 .19698 .36081 .19588 Mtetra
.641 .762 .936 r
.36081 .19588 .36191 .19698 .36368 .19643 .36258 .1953 Mtetra
.648 .758 .93 r
.36258 .1953 .36368 .19643 .36545 .19584 .36435 .1947 Mtetra
.657 .758 .925 r
.36435 .1947 .36545 .19584 .36722 .19522 .36613 .19406 Mtetra
.667 .758 .918 r
.36613 .19406 .36722 .19522 .369 .19456 .36791 .19337 Mtetra
.717 .768 .892 r
.36791 .19337 .369 .19456 .37078 .1938 .3697 .19244 Mtetra
.683 .727 .883 r
.3697 .19244 .37078 .1938 .37256 .19304 .37148 .19165 Mtetra
.611 .696 .904 r
.37148 .19165 .37256 .19304 .37434 .19233 .37325 .1912 Mtetra
0 .352 .816 r
.37325 .1912 .37434 .19233 .37612 .19182 .37496 .1921 Mtetra
.739 .241 .048 r
.37496 .1921 .37612 .19182 .37789 .19133 .37661 .19401 Mtetra
.76 .389 .354 r
.37661 .19401 .37789 .19133 .37967 .19082 .37819 .19771 Mtetra
.364 .076 .336 r
.37819 .19771 .37967 .19082 .38148 .18957 .38002 .19612 Mtetra
.352 .062 .326 r
.38002 .19612 .38148 .18957 .38327 .18868 .38186 .19449 Mtetra
.475 .16 .352 r
.38186 .19449 .38327 .18868 .38504 .18855 .38362 .1944 Mtetra
.959 .674 .453 r
.38362 .1944 .38504 .18855 .38656 .19361 .37594 .39868 Mtetra
.52 .28 .492 r
.37594 .39868 .38656 .19361 .37885 .40292 .37754 .40476 Mtetra
.704 .286 .251 r
.37754 .40476 .37885 .40292 .38052 .40767 .37933 .40698 Mtetra
.44 .783 .998 r
.37933 .40698 .38052 .40767 .38241 .40773 .38124 .40675 Mtetra
.676 .814 .949 r
.38124 .40675 .38241 .40773 .38434 .40694 .38317 .40597 Mtetra
.738 .828 .921 r
.38317 .40597 .38434 .40694 .38629 .40572 .38511 .40488 Mtetra
.665 .841 .967 r
.38511 .40488 .38629 .40572 .38822 .40492 .38704 .40412 Mtetra
.665 .847 .97 r
.38704 .40412 .38822 .40492 .39015 .40414 .38897 .40336 Mtetra
.673 .853 .968 r
.38897 .40336 .39015 .40414 .39208 .40336 .39091 .40255 Mtetra
.701 .856 .956 r
.39091 .40255 .39208 .40336 .39401 .40263 .39285 .40164 Mtetra
.707 .821 .936 r
.39285 .40164 .39401 .40263 .39594 .40192 .39479 .40072 Mtetra
.697 .779 .914 r
.39479 .40072 .39594 .40192 .39788 .40122 .39673 .39982 Mtetra
.664 .735 .902 r
.39673 .39982 .39788 .40122 .39981 .40051 .39867 .39908 Mtetra
.643 .722 .906 r
.39867 .39908 .39981 .40051 .40175 .39982 .4006 .39844 Mtetra
.622 .723 .919 r
.4006 .39844 .40175 .39982 .40368 .39915 .40253 .3979 Mtetra
.58 .729 .945 r
.40253 .3979 .40368 .39915 .40562 .39856 .40446 .3975 Mtetra
.555 .758 .972 r
.40446 .3975 .40562 .39856 .40755 .39799 .40639 .39714 Mtetra
.539 .794 .992 r
.40639 .39714 .40755 .39799 .40949 .39745 .40832 .39676 Mtetra
.46 .794 .999 r
.40832 .39676 .40949 .39745 .41142 .39697 .41025 .39649 Mtetra
.501 .854 .993 r
.41025 .39649 .41142 .39697 .41336 .39645 .41218 .39602 Mtetra
.645 .915 .979 r
.41218 .39602 .41336 .39645 .4153 .39584 .41413 .39518 Mtetra
.851 .892 .867 r
.41413 .39518 .4153 .39584 .41724 .39543 .41612 .39334 Mtetra
.835 .705 .72 r
.41612 .39334 .41724 .39543 .41919 .39465 .41815 .39034 Mtetra
.827 .617 .618 r
.41815 .39034 .41919 .39465 .42117 .39306 .42026 .38442 Mtetra
.963 .68 .451 r
.42026 .38442 .42117 .39306 .4233 .38653 .42884 .17678 Mtetra
.523 .287 .5 r
.42884 .17678 .4233 .38653 .43179 .17533 .43083 .17062 Mtetra
.724 .539 .641 r
.43083 .17062 .43179 .17533 .43377 .16958 .43273 .16766 Mtetra
.708 .665 .805 r
.43273 .16766 .43377 .16958 .43561 .16796 .43456 .16654 Mtetra
.618 .697 .901 r
.43456 .16654 .43561 .16796 .43743 .16731 .43638 .16604 Mtetra
.547 .696 .937 r
.43638 .16604 .43743 .16731 .43925 .16705 .43819 .16579 Mtetra
.661 .745 .912 r
.43819 .16579 .43925 .16705 .44107 .16646 .44001 .16511 Mtetra
.69 .738 .887 r
.44001 .16511 .44107 .16646 .44289 .16577 .44184 .16427 Mtetra
.687 .712 .868 r
.44184 .16427 .44289 .16577 .44472 .16509 .44367 .16343 Mtetra
.691 .691 .845 r
.44367 .16343 .44472 .16509 .44655 .16436 .44551 .16252 Mtetra
.663 .656 .833 r
.44551 .16252 .44655 .16436 .44838 .16365 .44734 .16175 Mtetra
.612 .625 .839 r
.44734 .16175 .44838 .16365 .45021 .16299 .44917 .16125 Mtetra
.312 .487 .871 r
.44917 .16125 .45021 .16299 .45203 .16251 .45097 .16181 Mtetra
.55 .002 0 r
.45097 .16181 .45203 .16251 .45386 .16212 .45275 .16339 Mtetra
.783 .358 .241 r
.45275 .16339 .45386 .16212 .45569 .16173 .45449 .16646 Mtetra
.521 .184 .336 r
.45449 .16646 .45569 .16173 .45753 .16073 .45631 .167 Mtetra
.386 .089 .333 r
.45631 .167 .45753 .16073 .45937 .15982 .45816 .16577 Mtetra
.466 .154 .351 r
.45816 .16577 .45937 .15982 .4612 .15954 .45999 .16556 Mtetra
.964 .672 .427 r
.45999 .16556 .4612 .15954 .46296 .1629 .45754 .36852 Mtetra
.523 .283 .492 r
.45754 .36852 .46296 .1629 .46055 .37323 .45933 .37651 Mtetra
.685 .306 .324 r
.45933 .37651 .46055 .37323 .46239 .37955 .46124 .37919 Mtetra
0 .494 .766 r
.46124 .37919 .46239 .37955 .46434 .38038 .4632 .37958 Mtetra
.552 .816 .995 r
.4632 .37958 .46434 .38038 .46632 .37983 .46518 .37913 Mtetra
.646 .869 .983 r
.46518 .37913 .46632 .37983 .46831 .37881 .46717 .37837 Mtetra
.582 .895 .987 r
.46717 .37837 .46831 .37881 .47029 .37802 .46916 .37767 Mtetra
.544 .896 .976 r
.46916 .37767 .47029 .37802 .47228 .37734 .47114 .37701 Mtetra
.552 .902 .974 r
.47114 .37701 .47228 .37734 .47427 .37665 .47313 .37631 Mtetra
.548 .9 .974 r
.47313 .37631 .47427 .37665 .47626 .37596 .47512 .37563 Mtetra
.545 .899 .974 r
.47512 .37563 .47626 .37596 .47825 .37527 .47711 .37495 Mtetra
.546 .901 .972 r
.47711 .37495 .47825 .37527 .48024 .37458 .47911 .37426 Mtetra
.54 .899 .971 r
.47911 .37426 .48024 .37458 .48223 .37387 .4811 .37358 Mtetra
.538 .901 .967 r
.4811 .37358 .48223 .37387 .48423 .37316 .4831 .37289 Mtetra
.547 .908 .963 r
.4831 .37289 .48423 .37316 .48622 .37244 .4851 .37216 Mtetra
.592 .925 .964 r
.4851 .37216 .48622 .37244 .48822 .37171 .4871 .37133 Mtetra
.64 .927 .973 r
.4871 .37133 .48822 .37171 .49022 .37099 .4891 .37044 Mtetra
.666 .907 .978 r
.4891 .37044 .49022 .37099 .49222 .37026 .4911 .36955 Mtetra
.655 .872 .98 r
.4911 .36955 .49222 .37026 .49422 .36953 .49311 .36875 Mtetra
.637 .852 .982 r
.49311 .36875 .49422 .36953 .49623 .36882 .49511 .36803 Mtetra
.625 .849 .985 r
.49511 .36803 .49623 .36882 .49823 .36811 .49712 .36735 Mtetra
.62 .853 .987 r
.49712 .36735 .49823 .36811 .50024 .36741 .49912 .36668 Mtetra
.616 .856 .989 r
.49912 .36668 .50024 .36741 .50224 .36674 .50113 .36601 Mtetra
.613 .857 .99 r
.50113 .36601 .50224 .36674 .50425 .36607 .50314 .36534 Mtetra
.557 .836 .997 r
.50314 .36534 .50425 .36607 .50626 .36545 .50515 .36484 Mtetra
.542 .853 .998 r
.50515 .36484 .50626 .36545 .50827 .36483 .50717 .36431 Mtetra
.629 .902 .985 r
.50717 .36431 .50827 .36483 .51029 .36417 .50918 .36351 Mtetra
.844 .909 .88 r
.50918 .36351 .51029 .36417 .5123 .36331 .5112 .36172 Mtetra
.872 .765 .742 r
.5112 .36172 .5123 .36331 .51432 .36232 .51323 .35873 Mtetra
.816 .629 .649 r
.51323 .35873 .51432 .36232 .51634 .36132 .51525 .35442 Mtetra
.703 .499 .609 r
.51525 .35442 .51634 .36132 .51836 .3605 .51728 .35063 Mtetra
.56 .373 .585 r
.51728 .35063 .51836 .3605 .52038 .35986 .51929 .34969 Mtetra
.505 .332 .58 r
.51929 .34969 .52038 .35986 .5224 .35927 .52131 .35 Mtetra
.524 .351 .589 r
.52131 .35 .5224 .35927 .52442 .35865 .52333 .34991 Mtetra
.547 .372 .596 r
.52333 .34991 .52442 .35865 .52645 .358 .52535 .34935 Mtetra
.548 .374 .597 r
.52535 .34935 .52645 .358 .52847 .35734 .52737 .34879 Mtetra
.55 .376 .598 r
.52737 .34879 .52847 .35734 .5305 .35668 .5294 .3482 Mtetra
.552 .378 .599 r
.5294 .3482 .5305 .35668 .53253 .35601 .53142 .34758 Mtetra
.553 .379 .6 r
.53142 .34758 .53253 .35601 .53456 .35534 .53345 .34694 Mtetra
.553 .38 .6 r
.53345 .34694 .53456 .35534 .53659 .35466 .53548 .34629 Mtetra
.554 .38 .6 r
.53548 .34629 .53659 .35466 .53863 .35398 .53751 .34563 Mtetra
.554 .381 .601 r
.53751 .34563 .53863 .35398 .54066 .3533 .53954 .34497 Mtetra
.555 .381 .601 r
.53954 .34497 .54066 .3533 .5427 .35262 .54157 .3443 Mtetra
.555 .382 .601 r
.54157 .3443 .5427 .35262 .54474 .35193 .54361 .34362 Mtetra
.54361 .34362 .54474 .35193 .54678 .35125 .54565 .34295 Mtetra
.54565 .34295 .54678 .35125 .54882 .35056 .54768 .34226 Mtetra
.555 .382 .602 r
.54768 .34226 .54882 .35056 .55086 .34988 .54972 .34158 Mtetra
.54972 .34158 .55086 .34988 .55291 .34919 .55176 .3409 Mtetra
.556 .382 .602 r
.55176 .3409 .55291 .34919 .55495 .3485 .55381 .34021 Mtetra
.556 .383 .602 r
.55381 .34021 .55495 .3485 .557 .34781 .55585 .33952 Mtetra
.55585 .33952 .557 .34781 .55905 .34712 .5579 .33883 Mtetra
.5579 .33883 .55905 .34712 .5611 .34643 .55994 .33814 Mtetra
.55994 .33814 .5611 .34643 .56315 .34573 .56199 .33745 Mtetra
.56199 .33745 .56315 .34573 .56521 .34504 .56404 .33676 Mtetra
.56404 .33676 .56521 .34504 .56726 .34435 .56609 .33606 Mtetra
.56609 .33606 .56726 .34435 .56932 .34365 .56814 .33536 Mtetra
.56814 .33536 .56932 .34365 .57137 .34296 .5702 .33467 Mtetra
.5702 .33467 .57137 .34296 .57343 .34226 .57226 .33397 Mtetra
.57226 .33397 .57343 .34226 .5755 .34156 .57431 .33327 Mtetra
.57431 .33327 .5755 .34156 .57756 .34087 .57637 .33257 Mtetra
.57637 .33257 .57756 .34087 .57962 .34017 .57843 .33188 Mtetra
.57843 .33188 .57962 .34017 .58169 .33947 .58049 .33118 Mtetra
.58049 .33118 .58169 .33947 .58376 .33877 .58256 .33047 Mtetra
.58256 .33047 .58376 .33877 .58582 .33807 .58462 .32977 Mtetra
.58462 .32977 .58582 .33807 .58789 .33737 .58669 .32907 Mtetra
.58669 .32907 .58789 .33737 .58997 .33667 .58876 .32837 Mtetra
.58876 .32837 .58997 .33667 .59204 .33597 .59083 .32766 Mtetra
.59083 .32766 .59204 .33597 .59411 .33527 .5929 .32696 Mtetra
.5929 .32696 .59411 .33527 .59619 .33457 .59497 .32625 Mtetra
.59497 .32625 .59619 .33457 .59827 .33386 .59705 .32555 Mtetra
.59705 .32555 .59827 .33386 .60035 .33316 .59912 .32484 Mtetra
.59912 .32484 .60035 .33316 .60243 .33246 .6012 .32413 Mtetra
.6012 .32413 .60243 .33246 .60451 .33175 .60328 .32342 Mtetra
.60328 .32342 .60451 .33175 .6066 .33105 .60536 .32271 Mtetra
.60536 .32271 .6066 .33105 .60868 .33034 .60744 .322 Mtetra
.60744 .322 .60868 .33034 .61077 .32963 .60952 .32129 Mtetra
.60952 .32129 .61077 .32963 .61286 .32892 .61161 .32057 Mtetra
.61161 .32057 .61286 .32892 .61495 .32822 .6137 .31986 Mtetra
.6137 .31986 .61495 .32822 .61704 .32751 .61578 .31914 Mtetra
.556 .383 .601 r
.61578 .31914 .61704 .32751 .61913 .32679 .61787 .31842 Mtetra
.61787 .31842 .61913 .32679 .62123 .32608 .61997 .31769 Mtetra
.557 .383 .601 r
.61997 .31769 .62123 .32608 .62333 .32537 .62206 .31696 Mtetra
.62206 .31696 .62333 .32537 .62542 .32465 .62415 .31623 Mtetra
.62415 .31623 .62542 .32465 .62752 .32393 .62625 .3155 Mtetra
.62625 .3155 .62752 .32393 .62962 .32321 .62834 .31475 Mtetra
.62834 .31475 .62962 .32321 .63173 .32249 .63044 .314 Mtetra
.557 .383 .6 r
.63044 .314 .63173 .32249 .63383 .32176 .63254 .31324 Mtetra
.558 .383 .6 r
.63254 .31324 .63383 .32176 .63594 .32103 .63464 .31247 Mtetra
.558 .382 .599 r
.63464 .31247 .63594 .32103 .63804 .32029 .63674 .3117 Mtetra
.63674 .3117 .63804 .32029 .64015 .31955 .63885 .31091 Mtetra
.559 .382 .598 r
.63885 .31091 .64015 .31955 .64226 .31881 .64095 .3101 Mtetra
.64095 .3101 .64226 .31881 .64437 .31805 .64305 .30927 Mtetra
.559 .381 .597 r
.64305 .30927 .64437 .31805 .64649 .3173 .64516 .30844 Mtetra
.558 .38 .596 r
.64516 .30844 .64649 .3173 .6486 .31656 .64727 .30762 Mtetra
.556 .378 .595 r
.64727 .30762 .6486 .31656 .65072 .31581 .64938 .30684 Mtetra
.555 .377 .595 r
.64938 .30684 .65072 .31581 .65283 .31508 .65149 .30608 Mtetra
.553 .375 .595 r
.65149 .30608 .65283 .31508 .65495 .31436 .65361 .30537 Mtetra
.55 .374 .595 r
.65361 .30537 .65495 .31436 .65708 .31366 .65573 .30471 Mtetra
.55 .373 .595 r
.65573 .30471 .65708 .31366 .6592 .31297 .65785 .30408 Mtetra
.535 .364 .596 r
.65785 .30408 .6592 .31297 .66133 .3124 .65999 .30375 Mtetra
.497 .34 .598 r
.65999 .30375 .66133 .3124 .66348 .31219 .66216 .30421 Mtetra
.555 .386 .607 r
.66216 .30421 .66348 .31219 .66561 .31147 .66429 .30354 Mtetra
.688 .477 .596 r
.66429 .30354 .66561 .31147 .66768 .30937 .66627 .29961 Mtetra
.973 .668 .363 r
.66627 .29961 .66768 .30937 .66942 .30022 .65877 .08953 Mtetra
.521 .286 .499 r
.65877 .08953 .66942 .30022 .66156 .087 .66051 .0835 Mtetra
.765 .599 .673 r
.66051 .0835 .66156 .087 .66336 .08245 .66239 .08067 Mtetra
.673 .683 .851 r
.66239 .08067 .66336 .08245 .66532 .08127 .66436 .0798 Mtetra
.587 .693 .915 r
.66436 .0798 .66532 .08127 .66731 .08073 .66636 .07939 Mtetra
.545 .696 .939 r
.66636 .07939 .66731 .08073 .66931 .08043 .66836 .07912 Mtetra
.657 .753 .92 r
.66836 .07912 .66931 .08043 .6713 .07971 .67035 .0784 Mtetra
.668 .758 .917 r
.67035 .0784 .6713 .07971 .67328 .07898 .67233 .07762 Mtetra
.692 .759 .904 r
.67233 .07762 .67328 .07898 .67527 .07815 .67431 .07673 Mtetra
.759 .773 .864 r
.67431 .07673 .67527 .07815 .67723 .07688 .67627 .07542 Mtetra
.683 .738 .892 r
.67627 .07542 .67723 .07688 .67921 .07603 .67826 .07456 Mtetra
.403 .594 .922 r
.67826 .07456 .67921 .07603 .68125 .07623 .6803 .07478 Mtetra
.837 .437 0 r
.6803 .07478 .68125 .07623 .6836 .0821 .68269 .0813 Mtetra
.973 .661 .313 r
.68269 .0813 .6836 .0821 .69748 .29599 .69651 .29541 Mtetra
.774 .287 0 r
.69651 .29541 .69748 .29599 .69991 .30013 .69892 .29927 Mtetra
.497 .793 .998 r
.69892 .29927 .69991 .30013 .70209 .29995 .7011 .29892 Mtetra
.729 .852 .939 r
.7011 .29892 .70209 .29995 .70424 .299 .70324 .29778 Mtetra
.775 .83 .895 r
.70324 .29778 .70424 .299 .70637 .29776 .70536 .29635 Mtetra
.523 .694 .947 r
.70536 .29635 .70637 .29776 .70856 .29754 .70755 .29612 Mtetra
.628 .741 .929 r
.70755 .29612 .70856 .29754 .71073 .29688 .70972 .29548 Mtetra
.794 .804 .86 r
.70972 .29548 .71073 .29688 .71284 .2952 .71183 .29383 Mtetra
.978 .777 .563 r
.71183 .29383 .71284 .2952 .7146 .28783 .7136 .28645 Mtetra
.975 .669 .322 r
.7136 .28645 .7146 .28783 .70349 .07204 .70255 .07063 Mtetra
.964 .782 .608 r
.70255 .07063 .70349 .07204 .7052 .06649 .70427 .06508 Mtetra
.758 .778 .869 r
.70427 .06508 .7052 .06649 .70718 .06518 .70624 .06378 Mtetra
.628 .727 .918 r
.70624 .06378 .70718 .06518 .70919 .06458 .70826 .06318 Mtetra
.546 .687 .932 r
.70826 .06318 .70919 .06458 .71124 .06431 .7103 .0629 Mtetra
.749 .775 .874 r
.7103 .0629 .71124 .06431 .71322 .06307 .71229 .06166 Mtetra
.683 .749 .901 r
.71229 .06166 .71322 .06307 .71523 .06221 .71429 .0608 Mtetra
.493 .657 .933 r
.71429 .0608 .71523 .06221 .71729 .06213 .71636 .06071 Mtetra
.731 .313 0 r
.71636 .06071 .71729 .06213 .71968 .06694 .71875 .06552 Mtetra
.97 .655 .291 r
.71875 .06552 .71968 .06694 .73639 .28171 .7354 .28036 Mtetra
.745 .315 0 r
.7354 .28036 .73639 .28171 .73897 .28679 .73798 .28543 Mtetra
.145 .535 .921 r
.04652 .51781 .04782 .51887 .04939 .51914 .04807 .51823 Mtetra
.658 .795 .948 r
.04807 .51823 .04939 .51914 .0511 .51848 .04977 .51761 Mtetra
.813 .807 .846 r
.04977 .51761 .0511 .51848 .0529 .51712 .05161 .51602 Mtetra
.886 .75 .706 r
.05161 .51602 .0529 .51712 .05477 .51532 .05377 .51213 Mtetra
.894 .669 .591 r
.05377 .51213 .05477 .51532 .05678 .51252 .05735 .49817 Mtetra
.922 .67 .538 r
.05735 .49817 .05678 .51252 .05915 .50709 .08658 .30129 Mtetra
.516 .282 .499 r
.08658 .30129 .05915 .50709 .08883 .30577 .0885 .29843 Mtetra
.616 .429 .605 r
.0885 .29843 .08883 .30577 .09118 .29971 .09025 .29676 Mtetra
.668 .555 .717 r
.09025 .29676 .09118 .29971 .09309 .29687 .09192 .29564 Mtetra
.745 .739 .847 r
.09192 .29564 .09309 .29687 .09478 .29564 .09358 .29454 Mtetra
.679 .75 .905 r
.09358 .29454 .09478 .29564 .09638 .29501 .09519 .29387 Mtetra
.489 .678 .949 r
.09519 .29387 .09638 .29501 .09792 .29487 .09672 .29379 Mtetra
.8 .32 0 r
.09672 .29379 .09792 .29487 .09939 .29527 .09796 .2959 Mtetra
.904 .595 .45 r
.09796 .2959 .09939 .29527 .10074 .29651 .09822 .30512 Mtetra
.928 .669 .526 r
.09822 .30512 .10074 .29651 .10182 .29981 .07268 .50424 Mtetra
.512 .274 .491 r
.07268 .50424 .10182 .29981 .07636 .49968 .07401 .50646 Mtetra
.532 .225 .392 r
.07401 .50646 .07636 .49968 .07714 .50595 .07555 .50714 Mtetra
.361 0 0 r
.07555 .50714 .07714 .50595 .07849 .50806 .07718 .50717 Mtetra
.407 .713 .986 r
.07718 .50717 .07849 .50806 .0801 .50826 .07882 .50714 Mtetra
.624 .746 .934 r
.07882 .50714 .0801 .50826 .08181 .50771 .08052 .50664 Mtetra
.758 .781 .872 r
.08052 .50664 .08181 .50771 .08359 .50658 .08231 .50546 Mtetra
.884 .755 .715 r
.08231 .50546 .08359 .50658 .08546 .50484 .08443 .50183 Mtetra
.893 .672 .596 r
.08443 .50183 .08546 .50484 .08746 .50211 .08766 .48983 Mtetra
.928 .673 .532 r
.08766 .48983 .08746 .50211 .0898 .49677 .11549 .29059 Mtetra
.517 .283 .499 r
.11549 .29059 .0898 .49677 .11784 .29456 .11745 .28736 Mtetra
.623 .435 .607 r
.11745 .28736 .11784 .29456 .12018 .28842 .11922 .28558 Mtetra
.677 .566 .722 r
.11922 .28558 .12018 .28842 .12209 .28555 .12091 .2844 Mtetra
.674 .741 .901 r
.12091 .2844 .12209 .28555 .12376 .28454 .12254 .28374 Mtetra
.586 .789 .976 r
.12254 .28374 .12376 .28454 .12535 .28417 .12413 .28334 Mtetra
.538 .769 .983 r
.12413 .28334 .12535 .28417 .1269 .28407 .12571 .28307 Mtetra
.633 .758 .938 r
.12571 .28307 .1269 .28407 .1285 .28365 .12731 .28257 Mtetra
.664 .751 .915 r
.12731 .28257 .1285 .28365 .13012 .28308 .12894 .28195 Mtetra
.678 .747 .903 r
.12894 .28195 .13012 .28308 .13175 .28243 .13057 .28127 Mtetra
.75 .755 .856 r
.13057 .28127 .13175 .28243 .13342 .28145 .13226 .28016 Mtetra
.723 .73 .856 r
.13226 .28016 .13342 .28145 .13508 .28052 .13393 .2792 Mtetra
.627 .698 .896 r
.13393 .2792 .13508 .28052 .13671 .27988 .13553 .27873 Mtetra
.595 .09 0 r
.13553 .27873 .13671 .27988 .13823 .2801 .13689 .28028 Mtetra
.903 .563 .391 r
.13689 .28028 .13823 .2801 .13964 .2813 .13768 .28645 Mtetra
.936 .675 .516 r
.13768 .28645 .13964 .2813 .14078 .28458 .11406 .48938 Mtetra
.514 .276 .491 r
.11406 .48938 .14078 .28458 .1176 .48558 .11534 .4925 Mtetra
.546 .239 .398 r
.11534 .4925 .1176 .48558 .11843 .49231 .11689 .49343 Mtetra
.405 0 0 r
.11689 .49343 .11843 .49231 .11982 .49454 .11853 .49361 Mtetra
.415 .711 .984 r
.11853 .49361 .11982 .49454 .12145 .49487 .1202 .49358 Mtetra
.617 .715 .915 r
.1202 .49358 .12145 .49487 .12319 .49434 .12193 .4931 Mtetra
.744 .757 .862 r
.12193 .4931 .12319 .49434 .12499 .4932 .12374 .49196 Mtetra
.878 .751 .718 r
.12374 .49196 .12499 .4932 .12693 .49102 .12584 .48847 Mtetra
.904 .684 .594 r
.12584 .48847 .12693 .49102 .12902 .48754 .12891 .47681 Mtetra
.934 .676 .524 r
.12891 .47681 .12902 .48754 .13141 .48153 .15462 .27559 Mtetra
.516 .282 .499 r
.15462 .27559 .13141 .48153 .13448 .46973 .15655 .27261 Mtetra
.511 .278 .498 r
.15655 .27261 .13448 .46973 .15747 .2891 .15824 .2716 Mtetra
.51 .304 .537 r
.15824 .2716 .15747 .2891 .13777 .47015 .15979 .27174 Mtetra
.499 .268 .495 r
.15979 .27174 .13777 .47015 .13825 .48028 .16095 .27523 Mtetra
0 0 .063 r
.16095 .27523 .13825 .48028 .13949 .48405 .13875 .47848 Mtetra
0 0 .199 r
.13875 .47848 .13949 .48405 .14096 .4859 .13974 .4844 Mtetra
0 .18 .702 r
.13974 .4844 .14096 .4859 .14259 .48634 .14128 .48565 Mtetra
.456 .78 .998 r
.14128 .48565 .14259 .48634 .14432 .48602 .14299 .48544 Mtetra
.761 .879 .931 r
.14299 .48544 .14432 .48602 .1461 .48519 .14481 .48432 Mtetra
.89 .794 .747 r
.14481 .48432 .1461 .48519 .14796 .48365 .14685 .48125 Mtetra
.894 .686 .614 r
.14685 .48125 .14796 .48365 .14994 .48115 .14951 .47273 Mtetra
.939 .679 .518 r
.14951 .47273 .14994 .48115 .15214 .47662 .17426 .26936 Mtetra
.518 .284 .499 r
.17426 .26936 .15214 .47662 .17642 .27573 .17628 .26548 Mtetra
.595 .393 .578 r
.17628 .26548 .17642 .27573 .17895 .26737 .17807 .26366 Mtetra
.652 .516 .685 r
.17807 .26366 .17895 .26737 .1809 .26407 .17979 .26245 Mtetra
.685 .675 .834 r
.17979 .26245 .1809 .26407 .18265 .26262 .18147 .26163 Mtetra
.652 .773 .937 r
.18147 .26163 .18265 .26262 .18431 .26199 .18313 .26105 Mtetra
.615 .77 .955 r
.18313 .26105 .18431 .26199 .18593 .26166 .18477 .26058 Mtetra
.703 .766 .901 r
.18477 .26058 .18593 .26166 .18759 .26104 .18644 .25978 Mtetra
.706 .735 .873 r
.18644 .25978 .18759 .26104 .18927 .26028 .18813 .25892 Mtetra
.614 .69 .898 r
.18813 .25892 .18927 .26028 .19092 .25974 .18977 .25849 Mtetra
0 .139 .652 r
.18977 .25849 .19092 .25974 .1925 .25984 .19123 .2597 Mtetra
.909 .548 .34 r
.19123 .2597 .1925 .25984 .19399 .26082 .19224 .26515 Mtetra
.943 .677 .503 r
.19224 .26515 .19399 .26082 .19531 .26346 .172 .46891 Mtetra
.515 .277 .491 r
.172 .46891 .19531 .26346 .17584 .46175 .17332 .47258 Mtetra
.534 .249 .428 r
.17332 .47258 .17584 .46175 .17651 .47147 .17493 .47351 Mtetra
.46 .034 .143 r
.17493 .47351 .17651 .47147 .17795 .47414 .17662 .47371 Mtetra
.081 .612 .867 r
.17662 .47371 .17795 .47414 .17956 .47512 .17832 .47388 Mtetra
.488 .68 .951 r
.17832 .47388 .17956 .47512 .18128 .47509 .18005 .47379 Mtetra
.693 .741 .888 r
.18005 .47379 .18128 .47509 .1831 .47415 .18186 .47295 Mtetra
.881 .762 .726 r
.18186 .47295 .1831 .47415 .18518 .47069 .18393 .46961 Mtetra
.946 .706 .543 r
.18393 .46961 .18518 .47069 .20725 .2724 .18817 .44513 Mtetra
0 0 .005 r
.18817 .44513 .20725 .2724 .21081 .25341 .20963 .25248 Mtetra
.882 .789 .753 r
.20963 .25248 .21081 .25341 .21269 .25075 .21152 .24975 Mtetra
.673 .778 .929 r
.21152 .24975 .21269 .25075 .21436 .25013 .2132 .24908 Mtetra
.49 .705 .965 r
.2132 .24908 .21436 .25013 .21598 .25007 .21483 .24896 Mtetra
.554 .719 .95 r
.21483 .24896 .21598 .25007 .21762 .24985 .21647 .2487 Mtetra
.662 .744 .911 r
.21647 .2487 .21762 .24985 .21929 .24926 .21815 .24806 Mtetra
.674 .742 .902 r
.21815 .24806 .21929 .24926 .22098 .24859 .21984 .24738 Mtetra
.741 .754 .863 r
.21984 .24738 .22098 .24859 .2227 .24752 .22156 .24631 Mtetra
.754 .757 .855 r
.22156 .24631 .2227 .24752 .22444 .24634 .2233 .24515 Mtetra
.654 .737 .91 r
.2233 .24515 .22444 .24634 .22612 .24573 .22498 .24455 Mtetra
.521 .026 0 r
.22498 .24455 .22612 .24573 .22759 .24732 .22645 .2461 Mtetra
.953 .685 .491 r
.22645 .2461 .22759 .24732 .2101 .44574 .20936 .43958 Mtetra
.986 .711 .366 r
.20936 .43958 .2101 .44574 .21023 .46249 .20902 .46112 Mtetra
.66 .179 0 r
.20902 .46112 .21023 .46249 .21179 .46447 .21056 .46326 Mtetra
.541 .71 .949 r
.21056 .46326 .21179 .46447 .21357 .46407 .21233 .46301 Mtetra
.762 .799 .883 r
.21233 .46301 .21357 .46407 .21543 .46285 .21419 .4618 Mtetra
.869 .791 .771 r
.21419 .4618 .21543 .46285 .21734 .46111 .21618 .4592 Mtetra
.892 .709 .648 r
.21618 .4592 .21734 .46111 .2193 .45884 .21847 .45343 Mtetra
.949 .684 .501 r
.21847 .45343 .2193 .45884 .2214 .4551 .23937 .24755 Mtetra
.523 .289 .5 r
.23937 .24755 .2214 .4551 .22488 .43631 .24158 .24131 Mtetra
.514 .281 .499 r
.24158 .24131 .22488 .43631 .2443 .2432 .24344 .23896 Mtetra
.659 .506 .666 r
.24344 .23896 .2443 .2432 .24629 .23927 .24521 .23747 Mtetra
.694 .66 .812 r
.24521 .23747 .24629 .23927 .2481 .23745 .24694 .23652 Mtetra
.638 .786 .953 r
.24694 .23652 .2481 .23745 .2498 .23684 .24863 .23596 Mtetra
.575 .78 .976 r
.24863 .23596 .2498 .23684 .25146 .23659 .25031 .23558 Mtetra
.606 .76 .953 r
.25031 .23558 .25146 .23659 .25313 .2363 .25199 .23514 Mtetra
.663 .746 .912 r
.25199 .23514 .25313 .2363 .25483 .23571 .2537 .2345 Mtetra
.675 .742 .901 r
.2537 .2345 .25483 .23571 .25653 .23505 .25541 .2338 Mtetra
.718 .747 .875 r
.25541 .2338 .25653 .23505 .25826 .23418 .25714 .23286 Mtetra
.74 .74 .851 r
.25714 .23286 .25826 .23418 .26 .23317 .25888 .23176 Mtetra
.674 .707 .873 r
.25888 .23176 .26 .23317 .26171 .23237 .2606 .23103 Mtetra
.265 .53 .915 r
.2606 .23103 .26171 .23237 .26339 .23215 .26221 .23146 Mtetra
.878 .442 .123 r
.26221 .23146 .26339 .23215 .26498 .2329 .26358 .23479 Mtetra
.953 .681 .484 r
.26358 .23479 .26498 .2329 .26646 .235 .24792 .43874 Mtetra
.523 .283 .493 r
.24792 .43874 .26646 .235 .26716 .24634 .24907 .44614 Mtetra
.51 .272 .49 r
.24907 .44614 .26716 .24634 .25225 .44502 .25072 .4476 Mtetra
.51 .112 .221 r
.25072 .4476 .25225 .44502 .25375 .44836 .25246 .44806 Mtetra
.23 .729 .91 r
.25246 .44806 .25375 .44836 .25545 .44936 .25425 .44796 Mtetra
.613 .705 .91 r
.25425 .44796 .25545 .44936 .25727 .44897 .25608 .44748 Mtetra
.655 .706 .885 r
.25608 .44748 .25727 .44897 .25912 .44817 .25792 .44681 Mtetra
.631 .719 .91 r
.25792 .44681 .25912 .44817 .26096 .4474 .25975 .44625 Mtetra
.546 .727 .958 r
.25975 .44625 .26096 .4474 .26279 .44698 .26156 .44597 Mtetra
.656 .792 .947 r
.26156 .44597 .26279 .44698 .26463 .44633 .2634 .4453 Mtetra
.823 .81 .837 r
.2634 .4453 .26463 .44633 .26651 .44516 .26533 .44353 Mtetra
.894 .732 .672 r
.26533 .44353 .26651 .44516 .26847 .443 .2675 .43882 Mtetra
.955 .686 .489 r
.2675 .43882 .26847 .443 .27054 .43953 .28525 .23518 Mtetra
.534 .297 .502 r
.28525 .23518 .27054 .43953 .27305 .43022 .28777 .22447 Mtetra
.515 .281 .499 r
.28777 .22447 .27305 .43022 .29048 .22673 .28965 .22181 Mtetra
.651 .486 .647 r
.28965 .22181 .29048 .22673 .29251 .22219 .29145 .22016 Mtetra
.701 .643 .788 r
.29145 .22016 .29251 .22219 .29436 .21996 .29322 .21907 Mtetra
.675 .809 .947 r
.29322 .21907 .29436 .21996 .2961 .21911 .29495 .21837 Mtetra
.598 .82 .985 r
.29495 .21837 .2961 .21911 .29782 .21867 .29667 .21788 Mtetra
.57 .8 .986 r
.29667 .21788 .29782 .21867 .29952 .21838 .29838 .21748 Mtetra
.604 .785 .968 r
.29838 .21748 .29952 .21838 .30124 .21797 .3001 .21701 Mtetra
.61 .777 .961 r
.3001 .21701 .30124 .21797 .30295 .21755 .30182 .21654 Mtetra
.633 .771 .946 r
.30182 .21654 .30295 .21755 .30467 .21708 .30355 .21599 Mtetra
.668 .767 .924 r
.30355 .21599 .30467 .21708 .30641 .21647 .30529 .21532 Mtetra
.683 .76 .909 r
.30529 .21532 .30641 .21647 .30815 .21577 .30703 .21458 Mtetra
.716 .76 .887 r
.30703 .21458 .30815 .21577 .3099 .21491 .30879 .21366 Mtetra
.758 .759 .853 r
.30879 .21366 .3099 .21491 .31167 .21381 .31057 .21244 Mtetra
.698 .725 .871 r
.31057 .21244 .31167 .21381 .31343 .21291 .31233 .21158 Mtetra
.454 .633 .931 r
.31233 .21158 .31343 .21291 .31515 .21249 .31402 .21161 Mtetra
.826 .355 0 r
.31402 .21161 .31515 .21249 .31681 .21307 .31553 .21442 Mtetra
.958 .681 .468 r
.31553 .21442 .31681 .21307 .31839 .21482 .30349 .41539 Mtetra
.531 .29 .494 r
.30349 .41539 .31839 .21482 .31966 .22121 .30453 .4268 Mtetra
.51 .272 .49 r
.30453 .4268 .31966 .22121 .30775 .42495 .30624 .42844 Mtetra
.516 .148 .281 r
.30624 .42844 .30775 .42495 .30931 .42894 .30804 .42893 Mtetra
.094 .652 .764 r
.30804 .42893 .30931 .42894 .31105 .43029 .30988 .42881 Mtetra
.635 .704 .896 r
.30988 .42881 .31105 .43029 .31291 .42991 .31175 .42822 Mtetra
.676 .689 .855 r
.31175 .42822 .31291 .42991 .3148 .42904 .31363 .42739 Mtetra
.695 .7 .851 r
.31363 .42739 .3148 .42904 .3167 .42795 .31553 .42644 Mtetra
.685 .718 .874 r
.31553 .42644 .3167 .42795 .3186 .42704 .31742 .42559 Mtetra
.685 .726 .881 r
.31742 .42559 .3186 .42704 .32049 .42613 .31931 .42475 Mtetra
.663 .73 .9 r
.31931 .42475 .32049 .42613 .32238 .42532 .3212 .42403 Mtetra
.534 .699 .945 r
.3212 .42403 .32238 .42532 .32425 .42488 .32305 .4238 Mtetra
.627 .774 .951 r
.32305 .4238 .32425 .42488 .32613 .4243 .32493 .42323 Mtetra
.79 .811 .869 r
.32493 .42323 .32613 .4243 .32803 .42331 .32687 .42178 Mtetra
.908 .743 .665 r
.32687 .42178 .32803 .42331 .33 .42127 .32901 .41682 Mtetra
.96 .686 .473 r
.32901 .41682 .33 .42127 .33205 .41793 .34318 .21101 Mtetra
.529 .293 .501 r
.34318 .21101 .33205 .41793 .3344 .40936 .34544 .20221 Mtetra
.514 .281 .498 r
.34544 .20221 .3344 .40936 .34816 .20518 .34731 .19967 Mtetra
.637 .466 .635 r
.34731 .19967 .34816 .20518 .35016 .2005 .34913 .19806 Mtetra
.68 .601 .761 r
.34913 .19806 .35016 .2005 .35203 .19806 .35092 .19698 Mtetra
.642 .766 .938 r
.35092 .19698 .35203 .19806 .3538 .19731 .35269 .1964 Mtetra
.559 .773 .979 r
.35269 .1964 .3538 .19731 .35555 .19701 .35444 .19605 Mtetra
.527 .749 .977 r
.35444 .19605 .35555 .19701 .35729 .19692 .35619 .19579 Mtetra
.619 .747 .938 r
.35619 .19579 .35729 .19692 .35905 .19642 .35795 .19529 Mtetra
.631 .751 .934 r
.35795 .19529 .35905 .19642 .36081 .19588 .35972 .19475 Mtetra
.642 .755 .931 r
.35972 .19475 .36081 .19588 .36258 .1953 .36149 .19416 Mtetra
.654 .758 .926 r
.36149 .19416 .36258 .1953 .36435 .1947 .36326 .19354 Mtetra
.662 .756 .92 r
.36326 .19354 .36435 .1947 .36613 .19406 .36503 .19287 Mtetra
.673 .755 .912 r
.36503 .19287 .36613 .19406 .36791 .19337 .36682 .19216 Mtetra
.745 .769 .872 r
.36682 .19216 .36791 .19337 .3697 .19244 .36862 .19104 Mtetra
.686 .723 .878 r
.36862 .19104 .3697 .19244 .37148 .19165 .3704 .19023 Mtetra
.533 .658 .916 r
.3704 .19023 .37148 .19165 .37325 .1912 .37216 .19006 Mtetra
.812 .354 0 r
.37216 .19006 .37325 .1912 .37496 .1921 .37375 .19317 Mtetra
.964 .681 .45 r
.37375 .19317 .37496 .1921 .37661 .19401 .36541 .39695 Mtetra
.525 .284 .492 r
.36541 .39695 .37661 .19401 .37819 .19771 .36686 .40574 Mtetra
.506 .269 .489 r
.36686 .40574 .37819 .19771 .38002 .19612 .36875 .40552 Mtetra
.505 .268 .489 r
.36875 .40552 .38002 .19612 .38186 .19449 .37068 .40443 Mtetra
.504 .267 .489 r
.37068 .40443 .38186 .19449 .38362 .1944 .37262 .40317 Mtetra
.509 .271 .489 r
.37262 .40317 .38362 .1944 .37594 .39868 .37446 .40424 Mtetra
.541 .212 .359 r
.37446 .40424 .37594 .39868 .37754 .40476 .37631 .40509 Mtetra
.366 0 0 r
.37631 .40509 .37754 .40476 .37933 .40698 .37818 .40554 Mtetra
.62 .71 .91 r
.37818 .40554 .37933 .40698 .38124 .40675 .3801 .405 Mtetra
.667 .682 .855 r
.3801 .405 .38124 .40675 .38317 .40597 .38203 .4042 Mtetra
.688 .689 .845 r
.38203 .4042 .38317 .40597 .38511 .40488 .38396 .40326 Mtetra
.665 .698 .871 r
.38396 .40326 .38511 .40488 .38704 .40412 .3859 .40248 Mtetra
.664 .697 .87 r
.3859 .40248 .38704 .40412 .38897 .40336 .38783 .40172 Mtetra
.667 .698 .869 r
.38783 .40172 .38897 .40336 .39091 .40255 .38976 .40093 Mtetra
.68 .705 .867 r
.38976 .40093 .39091 .40255 .39285 .40164 .3917 .40007 Mtetra
.681 .713 .873 r
.3917 .40007 .39285 .40164 .39479 .40072 .39364 .39922 Mtetra
.675 .722 .885 r
.39364 .39922 .39479 .40072 .39673 .39982 .39558 .39841 Mtetra
.649 .726 .905 r
.39558 .39841 .39673 .39982 .39867 .39908 .39751 .39774 Mtetra
.628 .732 .922 r
.39751 .39774 .39867 .39908 .4006 .39844 .39945 .39717 Mtetra
.607 .736 .936 r
.39945 .39717 .4006 .39844 .40253 .3979 .40138 .39667 Mtetra
.571 .732 .951 r
.40138 .39667 .40253 .3979 .40446 .3975 .4033 .3963 Mtetra
.563 .733 .955 r
.4033 .3963 .40446 .3975 .40639 .39714 .40523 .39594 Mtetra
.571 .738 .955 r
.40523 .39594 .40639 .39714 .40832 .39676 .40716 .39556 Mtetra
.48 .698 .964 r
.40716 .39556 .40832 .39676 .41025 .39649 .40909 .39545 Mtetra
.572 .77 .972 r
.40909 .39545 .41025 .39649 .41218 .39602 .41102 .39503 Mtetra
.728 .827 .926 r
.41102 .39503 .41218 .39602 .41413 .39518 .41298 .39399 Mtetra
.909 .792 .719 r
.41298 .39399 .41413 .39518 .41612 .39334 .41503 .3904 Mtetra
.919 .688 .572 r
.41503 .3904 .41612 .39334 .41815 .39034 .41731 .3799 Mtetra
.961 .678 .453 r
.41731 .3799 .41815 .39034 .42026 .38442 .42605 .17314 Mtetra
.516 .282 .498 r
.42605 .17314 .42026 .38442 .42884 .17678 .42796 .1696 Mtetra
.626 .437 .607 r
.42796 .1696 .42884 .17678 .43083 .17062 .42982 .16766 Mtetra
.682 .572 .725 r
.42982 .16766 .43083 .17062 .43273 .16766 .43167 .16636 Mtetra
.684 .744 .896 r
.43167 .16636 .43273 .16766 .43456 .16654 .43349 .16556 Mtetra
.619 .788 .962 r
.43349 .16556 .43456 .16654 .43638 .16604 .43531 .16503 Mtetra
.592 .768 .964 r
.43531 .16503 .43638 .16604 .43819 .16579 .43713 .16458 Mtetra
.674 .758 .914 r
.43713 .16458 .43819 .16579 .44001 .16511 .43895 .16385 Mtetra
.694 .755 .899 r
.43895 .16385 .44001 .16511 .44184 .16427 .44078 .16301 Mtetra
.694 .754 .898 r
.44078 .16301 .44184 .16427 .44367 .16343 .44262 .16217 Mtetra
.728 .765 .882 r
.44262 .16217 .44367 .16343 .44551 .16252 .44446 .16114 Mtetra
.69 .732 .883 r
.44446 .16114 .44551 .16252 .44734 .16175 .44629 .1603 Mtetra
.582 .68 .907 r
.44629 .1603 .44734 .16175 .44917 .16125 .44811 .15995 Mtetra
0 .052 .584 r
.44811 .15995 .44917 .16125 .45097 .16181 .44988 .16171 Mtetra
.925 .548 .271 r
.44988 .16171 .45097 .16181 .45275 .16339 .45152 .16905 Mtetra
.964 .673 .429 r
.45152 .16905 .45275 .16339 .45449 .16646 .44839 .37619 Mtetra
.51 .272 .489 r
.44839 .37619 .45449 .16646 .45631 .167 .45032 .37761 Mtetra
.505 .268 .489 r
.45032 .37761 .45631 .167 .45816 .16577 .45229 .3769 Mtetra
.45229 .3769 .45816 .16577 .45999 .16556 .45427 .37583 Mtetra
.508 .271 .489 r
.45427 .37583 .45999 .16556 .45754 .36852 .45622 .3765 Mtetra
.538 .232 .395 r
.45622 .3765 .45754 .36852 .45933 .37651 .45816 .37749 Mtetra
.485 0 0 r
.45816 .37749 .45933 .37651 .46124 .37919 .46011 .3781 Mtetra
.466 .716 .978 r
.46011 .3781 .46124 .37919 .4632 .37958 .46208 .37798 Mtetra
.608 .684 .896 r
.46208 .37798 .4632 .37958 .46518 .37913 .46406 .37748 Mtetra
.638 .691 .883 r
.46406 .37748 .46518 .37913 .46717 .37837 .46605 .37684 Mtetra
.64 .71 .898 r
.46605 .37684 .46717 .37837 .46916 .37767 .46803 .37619 Mtetra
.643 .719 .903 r
.46803 .37619 .46916 .37767 .47114 .37701 .47002 .37553 Mtetra
.648 .722 .903 r
.47002 .37553 .47114 .37701 .47313 .37631 .47201 .37485 Mtetra
.647 .724 .905 r
.47201 .37485 .47313 .37631 .47512 .37563 .474 .37417 Mtetra
.647 .725 .906 r
.474 .37417 .47512 .37563 .47711 .37495 .476 .3735 Mtetra
.648 .727 .906 r
.476 .3735 .47711 .37495 .47911 .37426 .47799 .37281 Mtetra
.647 .727 .907 r
.47799 .37281 .47911 .37426 .4811 .37358 .47998 .37213 Mtetra
.649 .728 .907 r
.47998 .37213 .4811 .37358 .4831 .37289 .48198 .37145 Mtetra
.654 .731 .906 r
.48198 .37145 .4831 .37289 .4851 .37216 .48398 .37073 Mtetra
.669 .738 .902 r
.48398 .37073 .4851 .37216 .4871 .37133 .48598 .36994 Mtetra
.679 .748 .904 r
.48598 .36994 .4871 .37133 .4891 .37044 .48798 .3691 Mtetra
.679 .758 .911 r
.48798 .3691 .4891 .37044 .4911 .36955 .48999 .36827 Mtetra
.665 .764 .923 r
.48999 .36827 .4911 .36955 .49311 .36875 .49199 .3675 Mtetra
.652 .765 .932 r
.49199 .3675 .49311 .36875 .49511 .36803 .494 .3668 Mtetra
.646 .765 .936 r
.494 .3668 .49511 .36803 .49712 .36735 .496 .36612 Mtetra
.643 .765 .937 r
.496 .36612 .49712 .36735 .49912 .36668 .49801 .36545 Mtetra
.642 .766 .938 r
.49801 .36545 .49912 .36668 .50113 .36601 .50002 .36479 Mtetra
.641 .767 .939 r
.50002 .36479 .50113 .36601 .50314 .36534 .50203 .36413 Mtetra
.573 .741 .955 r
.50203 .36413 .50314 .36534 .50515 .36484 .50404 .36372 Mtetra
.577 .764 .967 r
.50404 .36372 .50515 .36484 .50717 .36431 .50606 .36328 Mtetra
.698 .822 .942 r
.50606 .36328 .50717 .36431 .50918 .36351 .50807 .36236 Mtetra
.892 .819 .77 r
.50807 .36236 .50918 .36351 .5112 .36172 .5101 .35956 Mtetra
.927 .721 .605 r
.5101 .35956 .5112 .36172 .51323 .35873 .51214 .3525 Mtetra
.971 .681 .417 r
.51214 .3525 .51323 .35873 .51525 .35442 .51487 .14191 Mtetra
.517 .283 .498 r
.51487 .14191 .51525 .35442 .51728 .35063 .51676 .13772 Mtetra
.51 .277 .497 r
.51676 .13772 .51728 .35063 .51929 .34969 .51864 .13679 Mtetra
.508 .276 .497 r
.51864 .13679 .51929 .34969 .52131 .35 .52053 .13664 Mtetra
.509 .276 .497 r
.52053 .13664 .52131 .35 .52333 .34991 .52241 .13635 Mtetra
.51 .277 .497 r
.52241 .13635 .52333 .34991 .52535 .34935 .5243 .13571 Mtetra
.5243 .13571 .52535 .34935 .52737 .34879 .52618 .13508 Mtetra
.52618 .13508 .52737 .34879 .5294 .3482 .52807 .13443 Mtetra
.52807 .13443 .5294 .3482 .53142 .34758 .52997 .13376 Mtetra
.52997 .13376 .53142 .34758 .53345 .34694 .53186 .13308 Mtetra
.53186 .13308 .53345 .34694 .53548 .34629 .53375 .13239 Mtetra
.53375 .13239 .53548 .34629 .53751 .34563 .53564 .13169 Mtetra
.53564 .13169 .53751 .34563 .53954 .34497 .53754 .13099 Mtetra
.53754 .13099 .53954 .34497 .54157 .3443 .53944 .13028 Mtetra
.53944 .13028 .54157 .3443 .54361 .34362 .54134 .12958 Mtetra
.54134 .12958 .54361 .34362 .54565 .34295 .54324 .12887 Mtetra
.54324 .12887 .54565 .34295 .54768 .34226 .54514 .12815 Mtetra
.54514 .12815 .54768 .34226 .54972 .34158 .54704 .12744 Mtetra
.54704 .12744 .54972 .34158 .55176 .3409 .54894 .12672 Mtetra
.54894 .12672 .55176 .3409 .55381 .34021 .55085 .12601 Mtetra
.55085 .12601 .55381 .34021 .55585 .33952 .55276 .12529 Mtetra
.55276 .12529 .55585 .33952 .5579 .33883 .55466 .12457 Mtetra
.55466 .12457 .5579 .33883 .55994 .33814 .55657 .12385 Mtetra
.55657 .12385 .55994 .33814 .56199 .33745 .55848 .12313 Mtetra
.55848 .12313 .56199 .33745 .56404 .33676 .56039 .12241 Mtetra
.56039 .12241 .56404 .33676 .56609 .33606 .56231 .12168 Mtetra
.56231 .12168 .56609 .33606 .56814 .33536 .56422 .12096 Mtetra
.56422 .12096 .56814 .33536 .5702 .33467 .56614 .12023 Mtetra
.56614 .12023 .5702 .33467 .57226 .33397 .56805 .11951 Mtetra
.56805 .11951 .57226 .33397 .57431 .33327 .56997 .11878 Mtetra
.56997 .11878 .57431 .33327 .57637 .33257 .57189 .11806 Mtetra
.57189 .11806 .57637 .33257 .57843 .33188 .57381 .11733 Mtetra
.57381 .11733 .57843 .33188 .58049 .33118 .57574 .1166 Mtetra
.57574 .1166 .58049 .33118 .58256 .33047 .57766 .11587 Mtetra
.57766 .11587 .58256 .33047 .58462 .32977 .57958 .11515 Mtetra
.57958 .11515 .58462 .32977 .58669 .32907 .58151 .11442 Mtetra
.58151 .11442 .58669 .32907 .58876 .32837 .58344 .11369 Mtetra
.58344 .11369 .58876 .32837 .59083 .32766 .58537 .11295 Mtetra
.58537 .11295 .59083 .32766 .5929 .32696 .5873 .11222 Mtetra
.5873 .11222 .5929 .32696 .59497 .32625 .58923 .11149 Mtetra
.58923 .11149 .59497 .32625 .59705 .32555 .59116 .11076 Mtetra
.59116 .11076 .59705 .32555 .59912 .32484 .5931 .11002 Mtetra
.5931 .11002 .59912 .32484 .6012 .32413 .59503 .10929 Mtetra
.59503 .10929 .6012 .32413 .60328 .32342 .59697 .10855 Mtetra
.59697 .10855 .60328 .32342 .60536 .32271 .59891 .10782 Mtetra
.59891 .10782 .60536 .32271 .60744 .322 .60085 .10708 Mtetra
.60085 .10708 .60744 .322 .60952 .32129 .60279 .10634 Mtetra
.60279 .10634 .60952 .32129 .61161 .32057 .60473 .1056 Mtetra
.60473 .1056 .61161 .32057 .6137 .31986 .60667 .10486 Mtetra
.60667 .10486 .6137 .31986 .61578 .31914 .60862 .10412 Mtetra
.60862 .10412 .61578 .31914 .61787 .31842 .61057 .10337 Mtetra
.61057 .10337 .61787 .31842 .61997 .31769 .61251 .10263 Mtetra
.61251 .10263 .61997 .31769 .62206 .31696 .61446 .10188 Mtetra
.61446 .10188 .62206 .31696 .62415 .31623 .61641 .10113 Mtetra
.61641 .10113 .62415 .31623 .62625 .3155 .61836 .10038 Mtetra
.61836 .10038 .62625 .3155 .62834 .31475 .62032 .09962 Mtetra
.62032 .09962 .62834 .31475 .63044 .314 .62227 .09886 Mtetra
.62227 .09886 .63044 .314 .63254 .31324 .62423 .09809 Mtetra
.62423 .09809 .63254 .31324 .63464 .31247 .62618 .09733 Mtetra
.62618 .09733 .63464 .31247 .63674 .3117 .62814 .09655 Mtetra
.62814 .09655 .63674 .3117 .63885 .31091 .6301 .09578 Mtetra
.6301 .09578 .63885 .31091 .64095 .3101 .63206 .095 Mtetra
.63206 .095 .64095 .3101 .64305 .30927 .63402 .09421 Mtetra
.63402 .09421 .64305 .30927 .64516 .30844 .63598 .09342 Mtetra
.63598 .09342 .64516 .30844 .64727 .30762 .63795 .09264 Mtetra
.63795 .09264 .64727 .30762 .64938 .30684 .63991 .09187 Mtetra
.63991 .09187 .64938 .30684 .65149 .30608 .64188 .09111 Mtetra
.64188 .09111 .65149 .30608 .65361 .30537 .64385 .09037 Mtetra
.64385 .09037 .65361 .30537 .65573 .30471 .64582 .08965 Mtetra
.64582 .08965 .65573 .30471 .65785 .30408 .64779 .08894 Mtetra
.509 .277 .497 r
.64779 .08894 .65785 .30408 .65999 .30375 .64977 .08832 Mtetra
.509 .276 .497 r
.64977 .08832 .65999 .30375 .66216 .30421 .65177 .08796 Mtetra
.51 .277 .497 r
.65177 .08796 .66216 .30421 .66429 .30354 .65375 .0873 Mtetra
.511 .278 .498 r
.65375 .0873 .66429 .30354 .66627 .29961 .65569 .08585 Mtetra
.514 .28 .498 r
.65569 .08585 .66627 .29961 .65877 .08953 .65759 .08328 Mtetra
.649 .464 .62 r
.65759 .08328 .65877 .08953 .66051 .0835 .6595 .08111 Mtetra
.735 .647 .762 r
.6595 .08111 .66051 .0835 .66239 .08067 .66144 .07951 Mtetra
.659 .784 .941 r
.66144 .07951 .66239 .08067 .66436 .0798 .66342 .07878 Mtetra
.596 .787 .972 r
.66342 .07878 .66436 .0798 .66636 .07939 .66542 .07826 Mtetra
.591 .762 .961 r
.66542 .07826 .66636 .07939 .66836 .07912 .66741 .07778 Mtetra
.665 .753 .916 r
.66741 .07778 .66836 .07912 .67035 .0784 .6694 .07703 Mtetra
.674 .75 .908 r
.6694 .07703 .67035 .0784 .67233 .07762 .67138 .07622 Mtetra
.695 .752 .896 r
.67138 .07622 .67233 .07762 .67431 .07673 .67336 .0753 Mtetra
.76 .771 .862 r
.67336 .0753 .67431 .07673 .67627 .07542 .67532 .07398 Mtetra
.686 .743 .894 r
.67532 .07398 .67627 .07542 .67826 .07456 .6773 .0731 Mtetra
.413 .604 .926 r
.6773 .0731 .67826 .07456 .6803 .07478 .67935 .07328 Mtetra
.813 .41 0 r
.67935 .07328 .6803 .07478 .68269 .0813 .6817 .07929 Mtetra
.973 .662 .31 r
.6817 .07929 .68269 .0813 .69651 .29541 .69548 .29362 Mtetra
0 0 .373 r
.69548 .29362 .69651 .29541 .69892 .29927 .6979 .29768 Mtetra
.549 .675 .921 r
.6979 .29768 .69892 .29927 .7011 .29892 .70008 .29739 Mtetra
.709 .757 .89 r
.70008 .29739 .7011 .29892 .70324 .29778 .70222 .29631 Mtetra
.755 .782 .875 r
.70222 .29631 .70324 .29778 .70536 .29635 .70435 .29494 Mtetra
.515 .689 .947 r
.70435 .29494 .70536 .29635 .70755 .29612 .70654 .29474 Mtetra
.624 .747 .935 r
.70654 .29474 .70755 .29612 .70972 .29548 .70871 .29411 Mtetra
.796 .81 .863 r
.70871 .29411 .70972 .29548 .71183 .29383 .71083 .29247 Mtetra
.979 .777 .563 r
.71083 .29247 .71183 .29383 .7136 .28645 .71259 .28508 Mtetra
.975 .669 .322 r
.71259 .28508 .7136 .28645 .70255 .07063 .70161 .06923 Mtetra
.964 .782 .608 r
.70161 .06923 .70255 .07063 .70427 .06508 .70333 .06368 Mtetra
.758 .778 .869 r
.70333 .06368 .70427 .06508 .70624 .06378 .70531 .06238 Mtetra
.628 .727 .918 r
.70531 .06238 .70624 .06378 .70826 .06318 .70733 .06177 Mtetra
.546 .687 .932 r
.70733 .06177 .70826 .06318 .7103 .0629 .70937 .0615 Mtetra
.75 .775 .874 r
.70937 .0615 .7103 .0629 .71229 .06166 .71135 .06025 Mtetra
.684 .75 .902 r
.71135 .06025 .71229 .06166 .71429 .0608 .71336 .05938 Mtetra
.493 .658 .934 r
.71336 .05938 .71429 .0608 .71636 .06071 .71542 .05929 Mtetra
.732 .313 0 r
.71542 .05929 .71636 .06071 .71875 .06552 .71782 .06411 Mtetra
.97 .655 .291 r
.71782 .06411 .71875 .06552 .7354 .28036 .73441 .279 Mtetra
.744 .314 0 r
.73441 .279 .7354 .28036 .73798 .28543 .73699 .28407 Mtetra
.049 .474 .885 r
.04522 .51675 .04652 .51781 .04807 .51823 .04675 .51729 Mtetra
.652 .787 .946 r
.04675 .51729 .04807 .51823 .04977 .51761 .04845 .51669 Mtetra
.824 .799 .828 r
.04845 .51669 .04977 .51761 .05161 .51602 .05031 .51494 Mtetra
.91 .734 .652 r
.05031 .51494 .05161 .51602 .05377 .51213 .05281 .50868 Mtetra
.934 .683 .534 r
.05281 .50868 .05377 .51213 .05735 .49817 .0836 .30212 Mtetra
.524 .289 .501 r
.0836 .30212 .05735 .49817 .08658 .30129 .08593 .29634 Mtetra
.63 .469 .646 r
.08593 .29634 .08658 .30129 .0885 .29843 .08762 .29506 Mtetra
.592 .49 .707 r
.08762 .29506 .0885 .29843 .09025 .29676 .0892 .29456 Mtetra
.544 .54 .801 r
.0892 .29456 .09025 .29676 .09192 .29564 .09073 .29444 Mtetra
.733 .742 .859 r
.09073 .29444 .09192 .29564 .09358 .29454 .09239 .29344 Mtetra
.687 .751 .9 r
.09239 .29344 .09358 .29454 .09519 .29387 .094 .29273 Mtetra
.47 .671 .951 r
.094 .29273 .09519 .29387 .09672 .29379 .09553 .29269 Mtetra
.925 .541 .244 r
.09553 .29269 .09672 .29379 .09796 .2959 .0965 .29671 Mtetra
.937 .68 .523 r
.0965 .29671 .09796 .2959 .09822 .30512 .06992 .50205 Mtetra
.52 .281 .492 r
.06992 .50205 .09822 .30512 .07268 .50424 .07077 .50773 Mtetra
.503 .142 .287 r
.07077 .50773 .07268 .50424 .07401 .50646 .07236 .50806 Mtetra
.119 0 0 r
.07236 .50806 .07401 .50646 .07555 .50714 .07408 .50737 Mtetra
.697 .978 .905 r
.07408 .50737 .07555 .50714 .07718 .50717 .07587 .50622 Mtetra
.505 .743 .98 r
.07587 .50622 .07718 .50717 .07882 .50714 .07753 .50602 Mtetra
.61 .744 .94 r
.07753 .50602 .07882 .50714 .08052 .50664 .07923 .50557 Mtetra
.762 .781 .869 r
.07923 .50557 .08052 .50664 .08231 .50546 .08103 .50436 Mtetra
.909 .739 .66 r
.08103 .50436 .08231 .50546 .08443 .50183 .08343 .49865 Mtetra
.938 .685 .529 r
.08343 .49865 .08443 .50183 .08766 .48983 .11246 .29174 Mtetra
.524 .29 .501 r
.11246 .29174 .08766 .48983 .11549 .29059 .11482 .28557 Mtetra
.642 .477 .644 r
.11482 .28557 .11549 .29059 .11745 .28736 .11655 .28408 Mtetra
.593 .495 .712 r
.11655 .28408 .11745 .28736 .11922 .28558 .11815 .28358 Mtetra
.531 .558 .827 r
.11815 .28358 .11922 .28558 .12091 .2844 .1197 .2835 Mtetra
.6 .772 .962 r
.1197 .2835 .12091 .2844 .12254 .28374 .12129 .28308 Mtetra
.614 .831 .983 r
.12129 .28308 .12254 .28374 .12413 .28334 .1229 .28258 Mtetra
.632 .812 .969 r
.1229 .28258 .12413 .28334 .12571 .28307 .12451 .28206 Mtetra
.671 .768 .923 r
.12451 .28206 .12571 .28307 .12731 .28257 .12613 .28141 Mtetra
.675 .742 .9 r
.12613 .28141 .12731 .28257 .12894 .28195 .12776 .28074 Mtetra
.668 .729 .896 r
.12776 .28074 .12894 .28195 .13057 .28127 .12939 .2801 Mtetra
.713 .747 .879 r
.12939 .2801 .13057 .28127 .13226 .28016 .13105 .27923 Mtetra
.664 .783 .938 r
.13105 .27923 .13226 .28016 .13393 .2792 .13268 .27862 Mtetra
.273 .702 .966 r
.13268 .27862 .13393 .2792 .13553 .27873 .13422 .27865 Mtetra
.879 .49 .293 r
.13422 .27865 .13553 .27873 .13689 .28028 .13531 .28236 Mtetra
.94 .679 .515 r
.13531 .28236 .13689 .28028 .13768 .28645 .11123 .4875 Mtetra
.52 .281 .492 r
.11123 .4875 .13768 .28645 .11406 .48938 .11216 .49331 Mtetra
.544 .195 .326 r
.11216 .49331 .11406 .48938 .11534 .4925 .11374 .49402 Mtetra
.165 0 0 r
.11374 .49402 .11534 .4925 .11689 .49343 .11547 .49345 Mtetra
.711 .968 .935 r
.11547 .49345 .11689 .49343 .11853 .49361 .11728 .49236 Mtetra
.654 .735 .909 r
.11728 .49236 .11853 .49361 .1202 .49358 .11902 .49174 Mtetra
.665 .654 .83 r
.11902 .49174 .1202 .49358 .12193 .4931 .12078 .49098 Mtetra
.738 .654 .766 r
.12078 .49098 .12193 .4931 .12374 .49196 .12264 .48946 Mtetra
.865 .675 .644 r
.12264 .48946 .12374 .49196 .12584 .48847 .12503 .48357 Mtetra
.94 .683 .521 r
.12503 .48357 .12584 .48847 .12891 .47681 .15164 .27646 Mtetra
.523 .288 .501 r
.15164 .27646 .12891 .47681 .15462 .27559 .15391 .27065 Mtetra
.679 .504 .643 r
.15391 .27065 .15462 .27559 .15655 .27261 .15573 .26851 Mtetra
.618 .482 .674 r
.15573 .26851 .15655 .27261 .15824 .2716 .1574 .2676 Mtetra
.531 .427 .681 r
.1574 .2676 .15824 .2716 .15979 .27174 .15898 .26754 Mtetra
.094 .117 .594 r
.15898 .26754 .15979 .27174 .16095 .27523 .16029 .26973 Mtetra
.952 .691 .504 r
.16029 .26973 .16095 .27523 .13875 .47848 .14007 .45534 Mtetra
0 0 0 r
.14007 .45534 .13875 .47848 .13974 .4844 .13851 .48298 Mtetra
.61 .132 0 r
.13851 .48298 .13974 .4844 .14128 .48565 .13998 .48487 Mtetra
.433 .753 .995 r
.13998 .48487 .14128 .48565 .14299 .48544 .14168 .48474 Mtetra
.791 .854 .898 r
.14168 .48474 .14299 .48544 .14481 .48432 .14352 .48343 Mtetra
.913 .77 .69 r
.14352 .48343 .14481 .48432 .14685 .48125 .14573 .47895 Mtetra
.945 .687 .515 r
.14573 .47895 .14685 .48125 .14951 .47273 .17106 .27218 Mtetra
.529 .294 .502 r
.17106 .27218 .14951 .47273 .17426 .26936 .17359 .26387 Mtetra
.666 .486 .632 r
.17359 .26387 .17426 .26936 .17628 .26548 .17541 .26177 Mtetra
.599 .482 .692 r
.17541 .26177 .17628 .26548 .17807 .26366 .17706 .26113 Mtetra
.551 .519 .773 r
.17706 .26113 .17807 .26366 .17979 .26245 .17867 .26097 Mtetra
.594 .662 .885 r
.17867 .26097 .17979 .26245 .18147 .26163 .18029 .26062 Mtetra
.646 .766 .936 r
.18029 .26062 .18147 .26163 .18313 .26105 .18194 .26006 Mtetra
.651 .772 .937 r
.18194 .26006 .18313 .26105 .18477 .26058 .1836 .25948 Mtetra
.732 .767 .881 r
.1836 .25948 .18477 .26058 .18644 .25978 .1853 .2585 Mtetra
.721 .737 .863 r
.1853 .2585 .18644 .25978 .18813 .25892 .18699 .25755 Mtetra
.601 .683 .9 r
.18699 .25755 .18813 .25892 .18977 .25849 .18863 .25716 Mtetra
.732 .261 0 r
.18863 .25716 .18977 .25849 .19123 .2597 .18998 .25936 Mtetra
.948 .683 .501 r
.18998 .25936 .19123 .2597 .19224 .26515 .16957 .46293 Mtetra
.53 .289 .494 r
.16957 .46293 .19224 .26515 .172 .46891 .17018 .47307 Mtetra
.603 .258 .358 r
.17018 .47307 .172 .46891 .17332 .47258 .17173 .47455 Mtetra
.293 0 .028 r
.17173 .47455 .17332 .47258 .17493 .47351 .17349 .47412 Mtetra
.44 .862 .725 r
.17349 .47412 .17493 .47351 .17662 .47371 .17532 .47311 Mtetra
.655 .866 .979 r
.17532 .47311 .17662 .47371 .17832 .47388 .17711 .4724 Mtetra
.634 .696 .89 r
.17711 .4724 .17832 .47388 .18005 .47379 .17889 .47185 Mtetra
.711 .664 .802 r
.17889 .47185 .18005 .47379 .18186 .47295 .18073 .4707 Mtetra
.838 .681 .688 r
.18073 .4707 .18186 .47295 .18393 .46961 .18283 .46699 Mtetra
.948 .687 .508 r
.18283 .46699 .18393 .46961 .18817 .44513 .20562 .26343 Mtetra
.54 .303 .505 r
.20562 .26343 .18817 .44513 .20963 .25248 .20846 .25155 Mtetra
.877 .791 .762 r
.20846 .25155 .20963 .25248 .21152 .24975 .21033 .24896 Mtetra
.698 .826 .944 r
.21033 .24896 .21152 .24975 .2132 .24908 .21202 .24819 Mtetra
.541 .76 .978 r
.21202 .24819 .2132 .24908 .21483 .24896 .21367 .24791 Mtetra
.603 .747 .946 r
.21367 .24791 .21483 .24896 .21647 .2487 .21532 .24749 Mtetra
.676 .739 .898 r
.21532 .24749 .21647 .2487 .21815 .24806 .21701 .24679 Mtetra
.668 .725 .892 r
.21701 .24679 .21815 .24806 .21984 .24738 .2187 .24612 Mtetra
.696 .737 .882 r
.2187 .24612 .21984 .24738 .22156 .24631 .2204 .24532 Mtetra
.694 .785 .921 r
.2204 .24532 .22156 .24631 .2233 .24515 .22209 .24455 Mtetra
.453 .793 .999 r
.22209 .24455 .2233 .24515 .22498 .24455 .22374 .24433 Mtetra
.781 .286 .029 r
.22374 .24433 .22498 .24455 .22645 .2461 .22517 .24632 Mtetra
.951 .683 .492 r
.22517 .24632 .22645 .2461 .20936 .43958 .20711 .44899 Mtetra
.768 .47 .482 r
.20711 .44899 .20936 .43958 .20902 .46112 .2078 .4598 Mtetra
.642 .155 0 r
.2078 .4598 .20902 .46112 .21056 .46326 .20935 .46184 Mtetra
.481 .644 .929 r
.20935 .46184 .21056 .46326 .21233 .46301 .21109 .46181 Mtetra
.734 .769 .881 r
.21109 .46181 .21233 .46301 .21419 .4618 .21294 .46073 Mtetra
.889 .781 .737 r
.21294 .46073 .21419 .4618 .21618 .4592 .215 .45752 Mtetra
.936 .707 .566 r
.215 .45752 .21618 .4592 .21847 .45343 .21814 .44266 Mtetra
.943 .678 .505 r
.21814 .44266 .21847 .45343 .23937 .24755 .23878 .24037 Mtetra
.677 .476 .606 r
.23878 .24037 .23937 .24755 .24158 .24131 .24071 .23721 Mtetra
.613 .48 .676 r
.24071 .23721 .24158 .24131 .24344 .23896 .24243 .23636 Mtetra
.573 .527 .766 r
.24243 .23636 .24344 .23896 .24521 .23747 .2441 .23605 Mtetra
.572 .668 .904 r
.2441 .23605 .24521 .23747 .24694 .23652 .24576 .23577 Mtetra
.638 .826 .973 r
.24576 .23577 .24694 .23652 .24863 .23596 .24746 .23518 Mtetra
.645 .822 .968 r
.24746 .23518 .24863 .23596 .25031 .23558 .24916 .23458 Mtetra
.672 .782 .932 r
.24916 .23458 .25031 .23558 .25199 .23514 .25086 .23391 Mtetra
.686 .741 .892 r
.25086 .23391 .25199 .23514 .2537 .2345 .25258 .23315 Mtetra
.677 .718 .88 r
.25258 .23315 .2537 .2345 .25541 .2338 .25429 .23242 Mtetra
.687 .717 .872 r
.25429 .23242 .25541 .2338 .25714 .23286 .25601 .23163 Mtetra
.689 .743 .892 r
.25601 .23163 .25714 .23286 .25888 .23176 .25772 .23086 Mtetra
.534 .761 .98 r
.25772 .23086 .25888 .23176 .2606 .23103 .2594 .23059 Mtetra
.661 .108 0 r
.2594 .23059 .2606 .23103 .26221 .23146 .26093 .23204 Mtetra
.939 .639 .446 r
.26093 .23204 .26221 .23146 .26358 .23479 .26087 .25203 Mtetra
.933 .658 .495 r
.26087 .25203 .26358 .23479 .24792 .43874 .24598 .44608 Mtetra
.609 .298 .418 r
.24598 .44608 .24792 .43874 .24907 .44614 .24755 .44843 Mtetra
.369 0 .113 r
.24755 .44843 .24907 .44614 .25072 .4476 .24935 .44818 Mtetra
.354 .81 .69 r
.24935 .44818 .25072 .4476 .25246 .44806 .25121 .44728 Mtetra
.748 .852 .928 r
.25121 .44728 .25246 .44806 .25425 .44796 .25308 .44619 Mtetra
.684 .678 .838 r
.25308 .44619 .25425 .44796 .25608 .44748 .25494 .4453 Mtetra
.671 .628 .798 r
.25494 .4453 .25608 .44748 .25792 .44681 .2568 .44438 Mtetra
.621 .582 .789 r
.2568 .44438 .25792 .44681 .25975 .44625 .25864 .44377 Mtetra
.545 .538 .798 r
.25864 .44377 .25975 .44625 .26156 .44597 .26044 .44362 Mtetra
.63 .594 .795 r
.26044 .44362 .26156 .44597 .2634 .4453 .26228 .44296 Mtetra
.787 .664 .728 r
.26228 .44296 .2634 .4453 .26533 .44353 .26426 .44056 Mtetra
.909 .681 .581 r
.26426 .44056 .26533 .44353 .2675 .43882 .26697 .42898 Mtetra
.949 .679 .493 r
.26697 .42898 .2675 .43882 .28525 .23518 .28493 .2237 Mtetra
.64 .423 .573 r
.28493 .2237 .28525 .23518 .28777 .22447 .2869 .22001 Mtetra
.614 .471 .664 r
.2869 .22001 .28777 .22447 .28965 .22181 .28865 .21904 Mtetra
.582 .523 .754 r
.28865 .21904 .28965 .22181 .29145 .22016 .29036 .21866 Mtetra
.554 .648 .897 r
.29036 .21866 .29145 .22016 .29322 .21907 .29205 .21844 Mtetra
.606 .847 .99 r
.29205 .21844 .29322 .21907 .29495 .21837 .29378 .21789 Mtetra
.577 .871 .995 r
.29378 .21789 .29495 .21837 .29667 .21788 .2955 .21736 Mtetra
.595 .867 .994 r
.2955 .21736 .29667 .21788 .29838 .21748 .29722 .2168 Mtetra
.632 .846 .982 r
.29722 .2168 .29838 .21748 .3001 .21701 .29895 .2162 Mtetra
.653 .822 .965 r
.29895 .2162 .3001 .21701 .30182 .21654 .30069 .21557 Mtetra
.674 .793 .938 r
.30069 .21557 .30182 .21654 .30355 .21599 .30243 .21487 Mtetra
.692 .768 .909 r
.30243 .21487 .30355 .21599 .30529 .21532 .30418 .21409 Mtetra
.686 .745 .896 r
.30418 .21409 .30529 .21532 .30703 .21458 .30592 .21332 Mtetra
.691 .743 .891 r
.30592 .21332 .30703 .21458 .30879 .21366 .30767 .21252 Mtetra
.717 .771 .895 r
.30767 .21252 .30879 .21366 .31057 .21244 .30943 .2116 Mtetra
.592 .799 .979 r
.30943 .2116 .31057 .21244 .31233 .21158 .31116 .21115 Mtetra
.401 0 0 r
.31116 .21115 .31233 .21158 .31402 .21161 .3128 .21201 Mtetra
.924 .587 .38 r
.3128 .21201 .31402 .21161 .31553 .21442 .31384 .22149 Mtetra
.952 .673 .474 r
.31384 .22149 .31553 .21442 .30349 .41539 .30145 .42645 Mtetra
.601 .308 .444 r
.30145 .42645 .30349 .41539 .30453 .4268 .30307 .42948 Mtetra
.392 0 .163 r
.30307 .42948 .30453 .4268 .30624 .42844 .30491 .42922 Mtetra
0 0 0 r
.30491 .42922 .30624 .42844 .30804 .42893 .30681 .42828 Mtetra
.768 .885 .929 r
.30681 .42828 .30804 .42893 .30988 .42881 .30872 .42707 Mtetra
.67 .68 .851 r
.30872 .42707 .30988 .42881 .31175 .42822 .3106 .42626 Mtetra
.663 .651 .828 r
.3106 .42626 .31175 .42822 .31363 .42739 .31249 .42546 Mtetra
.659 .653 .832 r
.31249 .42546 .31363 .42739 .31553 .42644 .31437 .42468 Mtetra
.652 .67 .854 r
.31437 .42468 .31553 .42644 .31742 .42559 .31626 .42397 Mtetra
.65 .689 .874 r
.31626 .42397 .31742 .42559 .31931 .42475 .31814 .4233 Mtetra
.624 .706 .904 r
.31814 .4233 .31931 .42475 .3212 .42403 .32001 .42276 Mtetra
.466 .671 .953 r
.32001 .42276 .3212 .42403 .32305 .4238 .32186 .42271 Mtetra
.625 .773 .951 r
.32186 .42271 .32305 .4238 .32493 .42323 .32374 .42215 Mtetra
.829 .81 .833 r
.32374 .42215 .32493 .42323 .32687 .42178 .32569 .4203 Mtetra
.943 .728 .582 r
.32569 .4203 .32687 .42178 .32901 .41682 .32815 .41037 Mtetra
.958 .684 .474 r
.32815 .41037 .32901 .41682 .34318 .21101 .34256 .20191 Mtetra
.682 .465 .585 r
.34256 .20191 .34318 .21101 .34544 .20221 .34454 .1976 Mtetra
.615 .469 .66 r
.34454 .1976 .34544 .20221 .34731 .19967 .34633 .19657 Mtetra
.578 .502 .733 r
.34633 .19657 .34731 .19967 .34913 .19806 .34808 .19618 Mtetra
.524 .58 .854 r
.34808 .19618 .34913 .19806 .35092 .19698 .34981 .1961 Mtetra
.607 .797 .972 r
.34981 .1961 .35092 .19698 .35269 .1964 .35157 .19561 Mtetra
.598 .814 .982 r
.35157 .19561 .35269 .1964 .35444 .19605 .35333 .19512 Mtetra
.61 .787 .966 r
.35333 .19512 .35444 .19605 .35619 .19579 .35509 .19462 Mtetra
.624 .743 .932 r
.35509 .19462 .35619 .19579 .35795 .19529 .35685 .19411 Mtetra
.631 .742 .928 r
.35685 .19411 .35795 .19529 .35972 .19475 .35862 .19357 Mtetra
.641 .746 .925 r
.35862 .19357 .35972 .19475 .36149 .19416 .36039 .19299 Mtetra
.658 .753 .92 r
.36039 .19299 .36149 .19416 .36326 .19354 .36216 .19234 Mtetra
.666 .752 .914 r
.36216 .19234 .36326 .19354 .36503 .19287 .36394 .19166 Mtetra
.677 .751 .907 r
.36394 .19166 .36503 .19287 .36682 .19216 .36572 .19092 Mtetra
.763 .769 .858 r
.36572 .19092 .36682 .19216 .36862 .19104 .36754 .18966 Mtetra
.689 .728 .879 r
.36754 .18966 .36862 .19104 .3704 .19023 .36932 .18884 Mtetra
.455 .626 .926 r
.36932 .18884 .3704 .19023 .37216 .19006 .37107 .18889 Mtetra
.932 .551 .2 r
.37107 .18889 .37216 .19006 .37375 .19317 .37251 .19501 Mtetra
.963 .68 .451 r
.37251 .19501 .37375 .19317 .36541 .39695 .36381 .40452 Mtetra
.667 .351 .428 r
.36381 .40452 .36541 .39695 .36686 .40574 .36548 .40869 Mtetra
.424 .037 .2 r
.36548 .40869 .36686 .40574 .36875 .40552 .36737 .40856 Mtetra
.289 0 .144 r
.36737 .40856 .36875 .40552 .37068 .40443 .3693 .40766 Mtetra
.215 0 .125 r
.3693 .40766 .37068 .40443 .37262 .40317 .37125 .40631 Mtetra
.312 0 .163 r
.37125 .40631 .37262 .40317 .37446 .40424 .37318 .40548 Mtetra
.018 0 0 r
.37318 .40548 .37446 .40424 .37631 .40509 .37511 .40465 Mtetra
.651 .912 .98 r
.37511 .40465 .37631 .40509 .37818 .40554 .37704 .40381 Mtetra
.673 .689 .856 r
.37704 .40381 .37818 .40554 .3801 .405 .37897 .40298 Mtetra
.662 .647 .825 r
.37897 .40298 .3801 .405 .38203 .4042 .3809 .40215 Mtetra
.66 .644 .823 r
.3809 .40215 .38203 .4042 .38396 .40326 .38283 .40133 Mtetra
.661 .658 .837 r
.38283 .40133 .38396 .40326 .3859 .40248 .38476 .40053 Mtetra
.656 .653 .835 r
.38476 .40053 .3859 .40248 .38783 .40172 .3867 .39976 Mtetra
.651 .651 .837 r
.3867 .39976 .38783 .40172 .38976 .40093 .38863 .39901 Mtetra
.645 .653 .843 r
.38863 .39901 .38976 .40093 .3917 .40007 .39056 .39831 Mtetra
.642 .672 .863 r
.39056 .39831 .3917 .40007 .39364 .39922 .39249 .39766 Mtetra
.636 .698 .89 r
.39249 .39766 .39364 .39922 .39558 .39841 .39443 .39704 Mtetra
.611 .721 .923 r
.39443 .39704 .39558 .39841 .39751 .39774 .39636 .39654 Mtetra
.607 .75 .946 r
.39636 .39654 .39751 .39774 .39945 .39717 .39829 .39604 Mtetra
.619 .768 .951 r
.39829 .39604 .39945 .39717 .40138 .39667 .40022 .39548 Mtetra
.677 .775 .925 r
.40022 .39548 .40138 .39667 .4033 .3963 .40216 .39469 Mtetra
.68 .708 .869 r
.40216 .39469 .4033 .3963 .40523 .39594 .40411 .39383 Mtetra
.661 .639 .817 r
.40411 .39383 .40523 .39594 .40716 .39556 .40606 .39298 Mtetra
.523 .524 .798 r
.40606 .39298 .40716 .39556 .40909 .39545 .40798 .39294 Mtetra
.575 .559 .798 r
.40798 .39294 .40909 .39545 .41102 .39503 .40991 .3926 Mtetra
.689 .623 .777 r
.40991 .3926 .41102 .39503 .41298 .39399 .41188 .39142 Mtetra
.893 .693 .625 r
.41188 .39142 .41298 .39399 .41503 .3904 .41402 .38512 Mtetra
.966 .685 .448 r
.41402 .38512 .41503 .3904 .41731 .3799 .42312 .17373 Mtetra
.522 .286 .499 r
.42312 .17373 .41731 .3799 .42605 .17314 .42512 .16783 Mtetra
.639 .471 .64 r
.42512 .16783 .42605 .17314 .42796 .1696 .42697 .16623 Mtetra
.604 .506 .716 r
.42697 .16623 .42796 .1696 .42982 .16766 .42879 .16557 Mtetra
.569 .581 .826 r
.42879 .16557 .42982 .16766 .43167 .16636 .4306 .1653 Mtetra
.651 .78 .942 r
.4306 .1653 .43167 .16636 .43349 .16556 .43242 .16466 Mtetra
.666 .816 .956 r
.43242 .16466 .43349 .16556 .43531 .16503 .43424 .16395 Mtetra
.656 .778 .938 r
.43424 .16395 .43531 .16503 .43713 .16458 .43607 .16329 Mtetra
.613 .72 .921 r
.43607 .16329 .43713 .16458 .43895 .16385 .43789 .16281 Mtetra
.582 .759 .962 r
.43789 .16281 .43895 .16385 .44078 .16301 .43971 .1624 Mtetra
.525 .832 1 r
.43971 .1624 .44078 .16301 .44262 .16217 .44153 .16199 Mtetra
.684 .96 .944 r
.44153 .16199 .44262 .16217 .44446 .16114 .44337 .16096 Mtetra
.634 .947 .949 r
.44337 .16096 .44446 .16114 .44629 .1603 .44521 .16006 Mtetra
.302 .781 .919 r
.44521 .16006 .44629 .1603 .44811 .15995 .44703 .15981 Mtetra
.852 .398 .108 r
.44703 .15981 .44811 .15995 .44988 .16171 .44875 .16333 Mtetra
.968 .678 .424 r
.44875 .16333 .44988 .16171 .45152 .16905 .44534 .37376 Mtetra
.519 .279 .491 r
.44534 .37376 .45152 .16905 .44839 .37619 .44714 .37991 Mtetra
.534 .166 .289 r
.44714 .37991 .44839 .37619 .45032 .37761 .44908 .38063 Mtetra
.353 0 .172 r
.44908 .38063 .45032 .37761 .45229 .3769 .45106 .38004 Mtetra
.278 0 .151 r
.45106 .38004 .45229 .3769 .45427 .37583 .45304 .379 Mtetra
.331 0 .175 r
.45304 .379 .45427 .37583 .45622 .3765 .45502 .37823 Mtetra
.211 0 0 r
.45502 .37823 .45622 .3765 .45816 .37749 .457 .37757 Mtetra
.416 .865 .853 r
.457 .37757 .45816 .37749 .46011 .3781 .45898 .37684 Mtetra
.696 .775 .913 r
.45898 .37684 .46011 .3781 .46208 .37798 .46097 .37593 Mtetra
.684 .66 .821 r
.46097 .37593 .46208 .37798 .46406 .37748 .46296 .37493 Mtetra
.664 .604 .778 r
.46296 .37493 .46406 .37748 .46605 .37684 .46495 .37393 Mtetra
.63 .561 .758 r
.46495 .37393 .46605 .37684 .46803 .37619 .46694 .37313 Mtetra
.61 .54 .751 r
.46694 .37313 .46803 .37619 .47002 .37553 .46893 .37247 Mtetra
.605 .537 .752 r
.46893 .37247 .47002 .37553 .47201 .37485 .47092 .37185 Mtetra
.61 .544 .756 r
.47092 .37185 .47201 .37485 .474 .37417 .47291 .3712 Mtetra
.613 .548 .757 r
.47291 .3712 .474 .37417 .476 .3735 .4749 .37053 Mtetra
.614 .549 .757 r
.4749 .37053 .476 .3735 .47799 .37281 .47689 .36985 Mtetra
.615 .55 .758 r
.47689 .36985 .47799 .37281 .47998 .37213 .47889 .36916 Mtetra
.616 .55 .757 r
.47889 .36916 .47998 .37213 .48198 .37145 .48089 .36847 Mtetra
.48089 .36847 .48198 .37145 .48398 .37073 .48288 .36777 Mtetra
.617 .551 .758 r
.48288 .36777 .48398 .37073 .48598 .36994 .48488 .36706 Mtetra
.62 .558 .763 r
.48488 .36706 .48598 .36994 .48798 .3691 .48688 .36635 Mtetra
.623 .569 .773 r
.48688 .36635 .48798 .3691 .48999 .36827 .48889 .36564 Mtetra
.625 .579 .783 r
.48889 .36564 .48999 .36827 .49199 .3675 .49089 .36494 Mtetra
.625 .585 .788 r
.49089 .36494 .49199 .3675 .494 .3668 .4929 .36425 Mtetra
.624 .585 .79 r
.4929 .36425 .494 .3668 .496 .36612 .4949 .36356 Mtetra
.621 .583 .79 r
.4949 .36356 .496 .36612 .49801 .36545 .49691 .3629 Mtetra
.62 .583 .791 r
.49691 .3629 .49801 .36545 .50002 .36479 .49892 .36224 Mtetra
.62 .584 .791 r
.49892 .36224 .50002 .36479 .50203 .36413 .50093 .36159 Mtetra
.564 .555 .802 r
.50093 .36159 .50203 .36413 .50404 .36372 .50294 .3613 Mtetra
.576 .572 .811 r
.50294 .3613 .50404 .36372 .50606 .36328 .50495 .36095 Mtetra
.676 .631 .797 r
.50495 .36095 .50606 .36328 .50807 .36236 .50697 .35992 Mtetra
.861 .697 .677 r
.50697 .35992 .50807 .36236 .5101 .35956 .50901 .35587 Mtetra
.973 .684 .414 r
.50901 .35587 .5101 .35956 .51214 .3525 .51194 .1453 Mtetra
.53 .293 .5 r
.51194 .1453 .51214 .3525 .51487 .14191 .51386 .13528 Mtetra
.66 .467 .612 r
.51386 .13528 .51487 .14191 .51676 .13772 .51575 .13273 Mtetra
.594 .449 .654 r
.51575 .13273 .51676 .13772 .51864 .13679 .51763 .13188 Mtetra
.557 .426 .658 r
.51763 .13188 .51864 .13679 .52053 .13664 .51951 .1315 Mtetra
.563 .425 .651 r
.51951 .1315 .52053 .13664 .52241 .13635 .52139 .13102 Mtetra
.576 .43 .645 r
.52139 .13102 .52241 .13635 .5243 .13571 .52328 .13035 Mtetra
.575 .428 .644 r
.52328 .13035 .5243 .13571 .52618 .13508 .52516 .12967 Mtetra
.576 .428 .643 r
.52516 .12967 .52618 .13508 .52807 .13443 .52705 .12899 Mtetra
.52705 .12899 .52807 .13443 .52997 .13376 .52894 .1283 Mtetra
.576 .427 .642 r
.52894 .1283 .52997 .13376 .53186 .13308 .53083 .1276 Mtetra
.577 .427 .642 r
.53083 .1276 .53186 .13308 .53375 .13239 .53272 .12689 Mtetra
.577 .427 .641 r
.53272 .12689 .53375 .13239 .53564 .13169 .53461 .12618 Mtetra
.53461 .12618 .53564 .13169 .53754 .13099 .53651 .12547 Mtetra
.53651 .12547 .53754 .13099 .53944 .13028 .5384 .12476 Mtetra
.577 .426 .641 r
.5384 .12476 .53944 .13028 .54134 .12958 .5403 .12404 Mtetra
.5403 .12404 .54134 .12958 .54324 .12887 .5422 .12333 Mtetra
.577 .426 .64 r
.5422 .12333 .54324 .12887 .54514 .12815 .5441 .12261 Mtetra
.5441 .12261 .54514 .12815 .54704 .12744 .546 .12189 Mtetra
.546 .12189 .54704 .12744 .54894 .12672 .5479 .12117 Mtetra
.5479 .12117 .54894 .12672 .55085 .12601 .5498 .12045 Mtetra
.5498 .12045 .55085 .12601 .55276 .12529 .55171 .11973 Mtetra
.55171 .11973 .55276 .12529 .55466 .12457 .55361 .11901 Mtetra
.55361 .11901 .55466 .12457 .55657 .12385 .55552 .11829 Mtetra
.55552 .11829 .55657 .12385 .55848 .12313 .55743 .11756 Mtetra
.55743 .11756 .55848 .12313 .56039 .12241 .55934 .11684 Mtetra
.55934 .11684 .56039 .12241 .56231 .12168 .56125 .11611 Mtetra
.56125 .11611 .56231 .12168 .56422 .12096 .56316 .11539 Mtetra
.56316 .11539 .56422 .12096 .56614 .12023 .56508 .11466 Mtetra
.56508 .11466 .56614 .12023 .56805 .11951 .56699 .11393 Mtetra
.56699 .11393 .56805 .11951 .56997 .11878 .56891 .11321 Mtetra
.56891 .11321 .56997 .11878 .57189 .11806 .57082 .11248 Mtetra
.57082 .11248 .57189 .11806 .57381 .11733 .57274 .11175 Mtetra
.57274 .11175 .57381 .11733 .57574 .1166 .57466 .11102 Mtetra
.57466 .11102 .57574 .1166 .57766 .11587 .57659 .11029 Mtetra
.57659 .11029 .57766 .11587 .57958 .11515 .57851 .10956 Mtetra
.57851 .10956 .57958 .11515 .58151 .11442 .58043 .10883 Mtetra
.58043 .10883 .58151 .11442 .58344 .11369 .58236 .1081 Mtetra
.58236 .1081 .58344 .11369 .58537 .11295 .58429 .10737 Mtetra
.58429 .10737 .58537 .11295 .5873 .11222 .58621 .10663 Mtetra
.58621 .10663 .5873 .11222 .58923 .11149 .58814 .1059 Mtetra
.58814 .1059 .58923 .11149 .59116 .11076 .59008 .10517 Mtetra
.59008 .10517 .59116 .11076 .5931 .11002 .59201 .10443 Mtetra
.59201 .10443 .5931 .11002 .59503 .10929 .59394 .1037 Mtetra
.59394 .1037 .59503 .10929 .59697 .10855 .59588 .10296 Mtetra
.59588 .10296 .59697 .10855 .59891 .10782 .59781 .10223 Mtetra
.59781 .10223 .59891 .10782 .60085 .10708 .59975 .10149 Mtetra
.59975 .10149 .60085 .10708 .60279 .10634 .60169 .10075 Mtetra
.60169 .10075 .60279 .10634 .60473 .1056 .60363 .10001 Mtetra
.60363 .10001 .60473 .1056 .60667 .10486 .60557 .09927 Mtetra
.60557 .09927 .60667 .10486 .60862 .10412 .60751 .09853 Mtetra
.577 .427 .64 r
.60751 .09853 .60862 .10412 .61057 .10337 .60946 .09779 Mtetra
.60946 .09779 .61057 .10337 .61251 .10263 .6114 .09705 Mtetra
.6114 .09705 .61251 .10263 .61446 .10188 .61335 .0963 Mtetra
.577 .427 .641 r
.61335 .0963 .61446 .10188 .61641 .10113 .6153 .09556 Mtetra
.578 .427 .641 r
.6153 .09556 .61641 .10113 .61836 .10038 .61725 .09481 Mtetra
.61725 .09481 .61836 .10038 .62032 .09962 .6192 .09406 Mtetra
.578 .428 .641 r
.6192 .09406 .62032 .09962 .62227 .09886 .62115 .09331 Mtetra
.62115 .09331 .62227 .09886 .62423 .09809 .62311 .09256 Mtetra
.578 .429 .642 r
.62311 .09256 .62423 .09809 .62618 .09733 .62506 .09181 Mtetra
.579 .429 .642 r
.62506 .09181 .62618 .09733 .62814 .09655 .62702 .09105 Mtetra
.579 .43 .643 r
.62702 .09105 .62814 .09655 .6301 .09578 .62898 .09029 Mtetra
.62898 .09029 .6301 .09578 .63206 .095 .63094 .08954 Mtetra
.579 .431 .644 r
.63094 .08954 .63206 .095 .63402 .09421 .6329 .08878 Mtetra
.58 .432 .645 r
.6329 .08878 .63402 .09421 .63598 .09342 .63486 .08802 Mtetra
.63486 .08802 .63598 .09342 .63795 .09264 .63682 .08726 Mtetra
.58 .433 .646 r
.63682 .08726 .63795 .09264 .63991 .09187 .63878 .08651 Mtetra
.63878 .08651 .63991 .09187 .64188 .09111 .64075 .08575 Mtetra
.58 .433 .647 r
.64075 .08575 .64188 .09111 .64385 .09037 .64272 .08501 Mtetra
.579 .433 .647 r
.64272 .08501 .64385 .09037 .64582 .08965 .64469 .08427 Mtetra
.578 .432 .646 r
.64469 .08427 .64582 .08965 .64779 .08894 .64666 .08353 Mtetra
.577 .431 .646 r
.64666 .08353 .64779 .08894 .64977 .08832 .64863 .08281 Mtetra
.575 .427 .643 r
.64863 .08281 .64977 .08832 .65177 .08796 .65061 .0821 Mtetra
.571 .418 .635 r
.65061 .0821 .65177 .08796 .65375 .0873 .65258 .0814 Mtetra
.571 .417 .634 r
.65258 .0814 .65375 .0873 .65569 .08585 .65456 .0807 Mtetra
.579 .438 .653 r
.65456 .0807 .65569 .08585 .65759 .08328 .65654 .07999 Mtetra
.609 .52 .728 r
.65654 .07999 .65759 .08328 .6595 .08111 .65852 .07928 Mtetra
.646 .664 .853 r
.65852 .07928 .6595 .08111 .66144 .07951 .6605 .07857 Mtetra
.643 .824 .97 r
.6605 .07857 .66144 .07951 .66342 .07878 .66249 .07787 Mtetra
.645 .832 .972 r
.66249 .07787 .66342 .07878 .66542 .07826 .66447 .07716 Mtetra
.661 .796 .947 r
.66447 .07716 .66542 .07826 .66741 .07778 .66646 .07642 Mtetra
.674 .75 .908 r
.66646 .07642 .66741 .07778 .6694 .07703 .66844 .07561 Mtetra
.678 .744 .9 r
.66844 .07561 .6694 .07703 .67138 .07622 .67043 .07478 Mtetra
.697 .747 .89 r
.67043 .07478 .67138 .07622 .67336 .0753 .6724 .07385 Mtetra
.761 .767 .857 r
.6724 .07385 .67336 .0753 .67532 .07398 .67436 .0725 Mtetra
.691 .738 .887 r
.67436 .0725 .67532 .07398 .6773 .0731 .67635 .07159 Mtetra
.447 .612 .919 r
.67635 .07159 .6773 .0731 .67935 .07328 .67838 .07168 Mtetra
.752 .347 0 r
.67838 .07168 .67935 .07328 .6817 .07929 .6807 .07682 Mtetra
.973 .662 .309 r
.6807 .07682 .6817 .07929 .69548 .29362 .69441 .29126 Mtetra
0 0 .399 r
.69441 .29126 .69548 .29362 .6979 .29768 .69686 .29583 Mtetra
.522 .62 .89 r
.69686 .29583 .6979 .29768 .70008 .29739 .69905 .2957 Mtetra
.68 .72 .879 r
.69905 .2957 .70008 .29739 .70222 .29631 .7012 .29476 Mtetra
.731 .762 .877 r
.7012 .29476 .70222 .29631 .70435 .29494 .70334 .29354 Mtetra
.502 .683 .948 r
.70334 .29354 .70435 .29494 .70654 .29474 .70553 .29338 Mtetra
.621 .75 .938 r
.70553 .29338 .70654 .29474 .70871 .29411 .70771 .29275 Mtetra
.797 .813 .865 r
.70771 .29275 .70871 .29411 .71083 .29247 .70982 .29111 Mtetra
.979 .778 .563 r
.70982 .29111 .71083 .29247 .71259 .28508 .71159 .28374 Mtetra
.975 .669 .322 r
.71159 .28374 .71259 .28508 .70161 .06923 .70067 .06784 Mtetra
.965 .783 .607 r
.70067 .06784 .70161 .06923 .70333 .06368 .70239 .06228 Mtetra
.759 .779 .869 r
.70239 .06228 .70333 .06368 .70531 .06238 .70437 .06097 Mtetra
.629 .728 .918 r
.70437 .06097 .70531 .06238 .70733 .06177 .70639 .06037 Mtetra
.546 .688 .932 r
.70639 .06037 .70733 .06177 .70937 .0615 .70844 .06009 Mtetra
.75 .776 .874 r
.70844 .06009 .70937 .0615 .71135 .06025 .71042 .05884 Mtetra
.684 .751 .902 r
.71042 .05884 .71135 .06025 .71336 .05938 .71243 .05797 Mtetra
.493 .659 .935 r
.71243 .05797 .71336 .05938 .71542 .05929 .71449 .05788 Mtetra
.733 .314 0 r
.71449 .05788 .71542 .05929 .71782 .06411 .71688 .06271 Mtetra
.97 .655 .291 r
.71688 .06271 .71782 .06411 .73441 .279 .73342 .27764 Mtetra
.744 .314 0 r
.73342 .27764 .73441 .279 .73699 .28407 .736 .2827 Mtetra
.022 .459 .874 r
.04392 .51571 .04522 .51675 .04675 .51729 .04544 .51627 Mtetra
.65 .771 .937 r
.04544 .51627 .04675 .51729 .04845 .51669 .04714 .51568 Mtetra
.819 .785 .82 r
.04714 .51568 .04845 .51669 .05031 .51494 .04901 .51391 Mtetra
.914 .733 .644 r
.04901 .51391 .05031 .51494 .05281 .50868 .05159 .50713 Mtetra
.936 .686 .534 r
.05159 .50713 .05281 .50868 .0836 .30212 .08252 .30014 Mtetra
.871 .688 .652 r
.08252 .30014 .0836 .30212 .08593 .29634 .08479 .29476 Mtetra
.729 .688 .81 r
.08479 .29476 .08593 .29634 .08762 .29506 .08646 .29363 Mtetra
.598 .666 .887 r
.08646 .29363 .08762 .29506 .0892 .29456 .08803 .29328 Mtetra
.449 .632 .933 r
.08803 .29328 .0892 .29456 .09073 .29444 .08954 .29332 Mtetra
.736 .757 .869 r
.08954 .29332 .09073 .29444 .09239 .29344 .09119 .29233 Mtetra
.69 .75 .897 r
.09119 .29233 .09239 .29344 .094 .29273 .09281 .2916 Mtetra
.471 .673 .952 r
.09281 .2916 .094 .29273 .09553 .29269 .09434 .29155 Mtetra
.932 .56 .272 r
.09434 .29155 .09553 .29269 .0965 .29671 .09525 .29598 Mtetra
.939 .682 .522 r
.09525 .29598 .0965 .29671 .06992 .50205 .06848 .50204 Mtetra
.895 .539 .362 r
.06848 .50204 .06992 .50205 .07077 .50773 .0694 .50721 Mtetra
.14 .638 .91 r
.0694 .50721 .07077 .50773 .07236 .50806 .07102 .50735 Mtetra
.714 .846 .945 r
.07102 .50735 .07236 .50806 .07408 .50737 .07277 .50648 Mtetra
.788 .812 .872 r
.07277 .50648 .07408 .50737 .07587 .50622 .07458 .50514 Mtetra
.527 .723 .963 r
.07458 .50514 .07587 .50622 .07753 .50602 .07625 .50492 Mtetra
.602 .745 .945 r
.07625 .50492 .07753 .50602 .07923 .50557 .07794 .5045 Mtetra
.76 .781 .87 r
.07794 .5045 .07923 .50557 .08103 .50436 .07974 .5033 Mtetra
.913 .739 .652 r
.07974 .5033 .08103 .50436 .08343 .49865 .08219 .49717 Mtetra
.939 .687 .528 r
.08219 .49717 .08343 .49865 .11246 .29174 .11139 .28972 Mtetra
.876 .688 .645 r
.11139 .28972 .11246 .29174 .11482 .28557 .11369 .28398 Mtetra
.751 .695 .798 r
.11369 .28398 .11482 .28557 .11655 .28408 .1154 .28265 Mtetra
.595 .666 .888 r
.1154 .28265 .11655 .28408 .11815 .28358 .11698 .2823 Mtetra
.425 .622 .934 r
.11698 .2823 .11815 .28358 .1197 .2835 .11851 .28239 Mtetra
.592 .726 .937 r
.11851 .28239 .1197 .2835 .12129 .28308 .1201 .28203 Mtetra
.636 .75 .93 r
.1201 .28203 .12129 .28308 .1229 .28258 .1217 .28152 Mtetra
.65 .752 .924 r
.1217 .28152 .1229 .28258 .12451 .28206 .12332 .28096 Mtetra
.703 .758 .895 r
.12332 .28096 .12451 .28206 .12613 .28141 .12497 .28016 Mtetra
.687 .727 .881 r
.12497 .28016 .12613 .28141 .12776 .28074 .12661 .27942 Mtetra
.63 .699 .895 r
.12661 .27942 .12776 .28074 .12939 .2801 .12821 .27894 Mtetra
.319 .594 .944 r
.12821 .27894 .12939 .2801 .13105 .27923 .12973 .27918 Mtetra
.651 .106 0 r
.12973 .27918 .13105 .27923 .13268 .27862 .13114 .28032 Mtetra
.781 .415 .364 r
.13114 .28032 .13268 .27862 .13422 .27865 .13228 .28352 Mtetra
.936 .675 .517 r
.13228 .28352 .13422 .27865 .13531 .28236 .10852 .48458 Mtetra
.521 .281 .492 r
.10852 .48458 .13531 .28236 .11123 .4875 .10938 .49093 Mtetra
.665 .314 .369 r
.10938 .49093 .11123 .4875 .11216 .49331 .11078 .49309 Mtetra
0 .54 .75 r
.11078 .49309 .11216 .49331 .11374 .49402 .11242 .49326 Mtetra
.671 .833 .961 r
.11242 .49326 .11374 .49402 .11547 .49345 .11417 .49255 Mtetra
.783 .814 .878 r
.11417 .49255 .11547 .49345 .11728 .49236 .116 .49124 Mtetra
.819 .776 .812 r
.116 .49124 .11728 .49236 .11902 .49174 .1179 .48939 Mtetra
.801 .661 .709 r
.1179 .48939 .11902 .49174 .12078 .49098 .11992 .48657 Mtetra
.803 .602 .629 r
.11992 .48657 .12078 .49098 .12264 .48946 .12227 .48099 Mtetra
.936 .679 .523 r
.12227 .48099 .12264 .48946 .12503 .48357 .14858 .27797 Mtetra
.523 .288 .5 r
.14858 .27797 .12503 .48357 .15164 .27646 .15089 .27176 Mtetra
.724 .54 .641 r
.15089 .27176 .15164 .27646 .15391 .27065 .15282 .26875 Mtetra
.769 .672 .757 r
.15282 .26875 .15391 .27065 .15573 .26851 .1546 .267 Mtetra
.714 .697 .833 r
.1546 .267 .15573 .26851 .1574 .2676 .15628 .26602 Mtetra
.568 .634 .877 r
.15628 .26602 .1574 .2676 .15898 .26754 .15788 .26577 Mtetra
0 0 .44 r
.15788 .26577 .15898 .26754 .16029 .26973 .15922 .26774 Mtetra
.964 .661 .403 r
.15922 .26774 .16029 .26973 .14007 .45534 .15941 .27944 Mtetra
0 0 0 r
.15941 .27944 .14007 .45534 .13851 .48298 .13725 .48187 Mtetra
.738 .237 0 r
.13725 .48187 .13851 .48298 .13998 .48487 .13869 .48394 Mtetra
.457 .729 .985 r
.13869 .48394 .13998 .48487 .14168 .48474 .14039 .48382 Mtetra
.786 .815 .875 r
.14039 .48382 .14168 .48474 .14352 .48343 .14224 .48247 Mtetra
.913 .764 .683 r
.14224 .48247 .14352 .48343 .14573 .47895 .14447 .47778 Mtetra
.946 .689 .515 r
.14447 .47778 .14573 .47895 .17106 .27218 .17001 .26991 Mtetra
.891 .685 .617 r
.17001 .26991 .17106 .27218 .17359 .26387 .17247 .26226 Mtetra
.8 .708 .762 r
.17247 .26226 .17359 .26387 .17541 .26177 .17428 .26028 Mtetra
.627 .674 .875 r
.17428 .26028 .17541 .26177 .17706 .26113 .17592 .25979 Mtetra
.474 .635 .925 r
.17592 .25979 .17706 .26113 .17867 .26097 .17751 .25979 Mtetra
.561 .704 .937 r
.17751 .25979 .17867 .26097 .18029 .26062 .17912 .25952 Mtetra
.648 .75 .924 r
.17912 .25952 .18029 .26062 .18194 .26006 .18078 .25895 Mtetra
.666 .754 .916 r
.18078 .25895 .18194 .26006 .1836 .25948 .18244 .25832 Mtetra
.75 .761 .861 r
.18244 .25832 .1836 .25948 .1853 .2585 .18415 .2572 Mtetra
.741 .737 .848 r
.18415 .2572 .1853 .2585 .18699 .25755 .18586 .2561 Mtetra
.628 .682 .881 r
.18586 .2561 .18699 .25755 .18863 .25716 .18751 .25561 Mtetra
.662 .216 0 r
.18751 .25561 .18863 .25716 .18998 .25936 .18887 .25777 Mtetra
.95 .685 .5 r
.18887 .25777 .18998 .25936 .16957 .46293 .16826 .46235 Mtetra
.939 .618 .401 r
.16826 .46235 .16957 .46293 .17018 .47307 .16887 .47247 Mtetra
.648 .093 0 r
.16887 .47247 .17018 .47307 .17173 .47455 .17042 .47395 Mtetra
.578 .846 .995 r
.17042 .47395 .17173 .47455 .17349 .47412 .17219 .47345 Mtetra
.785 .864 .908 r
.17219 .47345 .17349 .47412 .17532 .47311 .17405 .47217 Mtetra
.822 .812 .841 r
.17405 .47217 .17532 .47311 .17711 .4724 .17595 .47045 Mtetra
.799 .69 .745 r
.17595 .47045 .17711 .4724 .17889 .47185 .17791 .46816 Mtetra
.782 .604 .659 r
.17791 .46816 .17889 .47185 .18073 .4707 .18002 .46443 Mtetra
.875 .633 .569 r
.18002 .46443 .18073 .4707 .18283 .46699 .18355 .44706 Mtetra
.928 .665 .517 r
.18355 .44706 .18283 .46699 .20562 .26343 .20536 .25354 Mtetra
.663 .448 .584 r
.20536 .25354 .20562 .26343 .20846 .25155 .20738 .24964 Mtetra
.768 .675 .76 r
.20738 .24964 .20846 .25155 .21033 .24896 .20917 .2479 Mtetra
.682 .769 .917 r
.20917 .2479 .21033 .24896 .21202 .24819 .21085 .24719 Mtetra
.588 .754 .957 r
.21085 .24719 .21202 .24819 .21367 .24791 .21251 .24681 Mtetra
.653 .754 .924 r
.21251 .24681 .21367 .24791 .21532 .24749 .21418 .24622 Mtetra
.696 .734 .88 r
.21418 .24622 .21532 .24749 .21701 .24679 .21588 .24541 Mtetra
.649 .701 .884 r
.21588 .24541 .21701 .24679 .2187 .24612 .21756 .24481 Mtetra
.478 .645 .931 r
.21756 .24481 .2187 .24612 .2204 .24532 .21918 .24479 Mtetra
.392 0 0 r
.21918 .24479 .2204 .24532 .22209 .24455 .22072 .24563 Mtetra
.756 .339 .258 r
.22072 .24563 .22209 .24455 .22374 .24433 .22212 .2479 Mtetra
.947 .678 .495 r
.22212 .2479 .22374 .24433 .22517 .24632 .20481 .441 Mtetra
.541 .298 .496 r
.20481 .441 .22517 .24632 .20711 .44899 .20502 .4566 Mtetra
.632 .325 .431 r
.20502 .4566 .20711 .44899 .2078 .4598 .20647 .4596 Mtetra
.578 .002 0 r
.20647 .4596 .2078 .4598 .20935 .46184 .2081 .46071 Mtetra
.407 .669 .967 r
.2081 .46071 .20935 .46184 .21109 .46181 .20985 .46076 Mtetra
.701 .791 .92 r
.20985 .46076 .21109 .46181 .21294 .46073 .21168 .4599 Mtetra
.898 .808 .751 r
.21168 .4599 .21294 .46073 .215 .45752 .21372 .45683 Mtetra
.952 .726 .56 r
.21372 .45683 .215 .45752 .21814 .44266 .21691 .44153 Mtetra
.953 .69 .499 r
.21691 .44153 .21814 .44266 .23878 .24037 .23768 .23874 Mtetra
.854 .72 .714 r
.23768 .23874 .23878 .24037 .24071 .23721 .23961 .23565 Mtetra
.669 .682 .854 r
.23961 .23565 .24071 .23721 .24243 .23636 .24131 .23493 Mtetra
.526 .647 .911 r
.24131 .23493 .24243 .23636 .2441 .23605 .24296 .2348 Mtetra
.527 .679 .934 r
.24296 .2348 .2441 .23605 .24576 .23577 .24462 .23463 Mtetra
.65 .747 .921 r
.24462 .23463 .24576 .23577 .24746 .23518 .24632 .23404 Mtetra
.666 .751 .914 r
.24632 .23404 .24746 .23518 .24916 .23458 .24802 .23338 Mtetra
.706 .752 .888 r
.24802 .23338 .24916 .23458 .25086 .23391 .24974 .23253 Mtetra
.724 .727 .853 r
.24974 .23253 .25086 .23391 .25258 .23315 .25148 .23151 Mtetra
.678 .676 .841 r
.25148 .23151 .25258 .23315 .25429 .23242 .2532 .23072 Mtetra
.561 .618 .867 r
.2532 .23072 .25429 .23242 .25601 .23163 .25487 .23049 Mtetra
.009 .412 .857 r
.25487 .23049 .25601 .23163 .25772 .23086 .25645 .23121 Mtetra
.764 .294 .129 r
.25645 .23121 .25772 .23086 .2594 .23059 .25793 .23321 Mtetra
.874 .553 .439 r
.25793 .23321 .2594 .23059 .26093 .23204 .25872 .24326 Mtetra
.941 .667 .491 r
.25872 .24326 .26093 .23204 .26087 .25203 .24312 .44334 Mtetra
.514 .275 .49 r
.24312 .44334 .26087 .25203 .24598 .44608 .2446 .44673 Mtetra
.59 .074 0 r
.2446 .44673 .24598 .44608 .24755 .44843 .24629 .44772 Mtetra
.553 .82 .996 r
.24629 .44772 .24755 .44843 .24935 .44818 .24811 .44729 Mtetra
.738 .832 .923 r
.24811 .44729 .24935 .44818 .25121 .44728 .24998 .44625 Mtetra
.819 .809 .841 r
.24998 .44625 .25121 .44728 .25308 .44619 .2519 .44453 Mtetra
.836 .728 .745 r
.2519 .44453 .25308 .44619 .25494 .4453 .25391 .44187 Mtetra
.794 .619 .664 r
.25391 .44187 .25494 .4453 .2568 .44438 .256 .43814 Mtetra
.71 .513 .62 r
.256 .43814 .2568 .44438 .25864 .44377 .25808 .43454 Mtetra
.509 .337 .584 r
.25808 .43454 .25864 .44377 .26044 .44362 .25985 .43471 Mtetra
.529 .355 .589 r
.25985 .43471 .26044 .44362 .26228 .44296 .26165 .43452 Mtetra
.711 .495 .595 r
.26165 .43452 .26228 .44296 .26426 .44056 .26384 .42949 Mtetra
.947 .678 .494 r
.26384 .42949 .26426 .44056 .26697 .42898 .28186 .22585 Mtetra
.52 .285 .499 r
.28186 .22585 .26697 .42898 .28493 .2237 .28394 .2208 Mtetra
.757 .611 .697 r
.28394 .2208 .28493 .2237 .2869 .22001 .2858 .21847 Mtetra
.658 .685 .864 r
.2858 .21847 .2869 .22001 .28865 .21904 .28753 .2178 Mtetra
.547 .695 .937 r
.28753 .2178 .28865 .21904 .29036 .21866 .28923 .21756 Mtetra
.506 .707 .961 r
.28923 .21756 .29036 .21866 .29205 .21844 .29092 .2174 Mtetra
.625 .765 .946 r
.29092 .2174 .29205 .21844 .29378 .21789 .29264 .21689 Mtetra
.637 .775 .947 r
.29264 .21689 .29378 .21789 .2955 .21736 .29436 .21633 Mtetra
.648 .774 .941 r
.29436 .21633 .2955 .21736 .29722 .2168 .29609 .21574 Mtetra
.657 .769 .932 r
.29609 .21574 .29722 .2168 .29895 .2162 .29783 .21511 Mtetra
.666 .766 .925 r
.29783 .21511 .29895 .2162 .30069 .21557 .29956 .21445 Mtetra
.688 .767 .911 r
.29956 .21445 .30069 .21557 .30243 .21487 .30131 .21368 Mtetra
.72 .762 .886 r
.30131 .21368 .30243 .21487 .30418 .21409 .30307 .21274 Mtetra
.68 .724 .883 r
.30307 .21274 .30418 .21409 .30592 .21332 .30482 .21198 Mtetra
.575 .689 .918 r
.30482 .21198 .30592 .21332 .30767 .21252 .30653 .21167 Mtetra
0 .457 .858 r
.30653 .21167 .30767 .21252 .30943 .2116 .30818 .21225 Mtetra
.725 .255 .131 r
.30818 .21225 .30943 .2116 .31116 .21115 .30975 .21406 Mtetra
.851 .518 .421 r
.30975 .21406 .31116 .21115 .3128 .21201 .31088 .2222 Mtetra
.947 .669 .477 r
.31088 .2222 .3128 .21201 .31384 .22149 .29852 .424 Mtetra
.514 .275 .49 r
.29852 .424 .31384 .22149 .30145 .42645 .30009 .42761 Mtetra
.617 .146 .112 r
.30009 .42761 .30145 .42645 .30307 .42948 .30183 .42879 Mtetra
.611 .849 .989 r
.30183 .42879 .30307 .42948 .30491 .42922 .3037 .42819 Mtetra
.742 .81 .906 r
.3037 .42819 .30491 .42922 .30681 .42828 .30561 .42709 Mtetra
.761 .786 .873 r
.30561 .42709 .30681 .42828 .30872 .42707 .30752 .42581 Mtetra
.692 .76 .904 r
.30752 .42581 .30872 .42707 .3106 .42626 .30941 .42496 Mtetra
.681 .75 .903 r
.30941 .42496 .3106 .42626 .31249 .42546 .3113 .42416 Mtetra
.672 .748 .908 r
.3113 .42416 .31249 .42546 .31437 .42468 .31318 .42341 Mtetra
.661 .749 .916 r
.31318 .42341 .31437 .42468 .31626 .42397 .31507 .42271 Mtetra
.652 .748 .92 r
.31507 .42271 .31626 .42397 .31814 .4233 .31695 .42204 Mtetra
.618 .738 .932 r
.31695 .42204 .31814 .4233 .32001 .42276 .31882 .42152 Mtetra
.437 .665 .958 r
.31882 .42152 .32001 .42276 .32186 .42271 .32066 .42154 Mtetra
.624 .756 .941 r
.32066 .42154 .32186 .42271 .32374 .42215 .32254 .42099 Mtetra
.833 .797 .817 r
.32254 .42099 .32374 .42215 .32569 .4203 .32451 .41901 Mtetra
.953 .724 .553 r
.32451 .41901 .32569 .4203 .32815 .41037 .32719 .40541 Mtetra
.959 .686 .473 r
.32719 .40541 .32815 .41037 .34256 .20191 .34152 .19952 Mtetra
.847 .677 .671 r
.34152 .19952 .34256 .20191 .34454 .1976 .34349 .1956 Mtetra
.663 .633 .81 r
.34349 .1956 .34454 .1976 .34633 .19657 .34526 .1948 Mtetra
.537 .602 .866 r
.34526 .1948 .34633 .19657 .34808 .19618 .34699 .19466 Mtetra
.417 .581 .907 r
.34699 .19466 .34808 .19618 .34981 .1961 .34871 .19484 Mtetra
.606 .718 .924 r
.34871 .19484 .34981 .1961 .35157 .19561 .35047 .1944 Mtetra
.62 .734 .928 r
.35047 .1944 .35157 .19561 .35333 .19512 .35223 .19391 Mtetra
.629 .736 .924 r
.35223 .19391 .35333 .19512 .35509 .19462 .35399 .19338 Mtetra
.624 .727 .921 r
.35399 .19338 .35509 .19462 .35685 .19411 .35576 .19287 Mtetra
.631 .731 .92 r
.35576 .19287 .35685 .19411 .35862 .19357 .35752 .19233 Mtetra
.641 .735 .917 r
.35752 .19233 .35862 .19357 .36039 .19299 .3593 .19175 Mtetra
.659 .741 .911 r
.3593 .19175 .36039 .19299 .36216 .19234 .36107 .1911 Mtetra
.666 .744 .908 r
.36107 .1911 .36216 .19234 .36394 .19166 .36285 .19041 Mtetra
.678 .746 .903 r
.36285 .19041 .36394 .19166 .36572 .19092 .36463 .18967 Mtetra
.768 .768 .853 r
.36463 .18967 .36572 .19092 .36754 .18966 .36645 .18837 Mtetra
.693 .743 .889 r
.36645 .18837 .36754 .18966 .36932 .18884 .36824 .18754 Mtetra
.417 .625 .938 r
.36824 .18754 .36932 .18884 .37107 .18889 .36998 .18765 Mtetra
.946 .586 .253 r
.36998 .18765 .37107 .18889 .37251 .19501 .37134 .19534 Mtetra
.964 .682 .449 r
.37134 .19534 .37251 .19501 .36381 .40452 .36257 .40463 Mtetra
.854 .417 .18 r
.36257 .40463 .36381 .40452 .36548 .40869 .36426 .40837 Mtetra
.317 .781 .941 r
.36426 .40837 .36548 .40869 .36737 .40856 .36616 .40814 Mtetra
.704 .927 .965 r
.36616 .40814 .36737 .40856 .3693 .40766 .36809 .40713 Mtetra
.81 .916 .91 r
.36809 .40713 .3693 .40766 .37125 .40631 .37005 .40565 Mtetra
.728 .887 .953 r
.37005 .40565 .37125 .40631 .37318 .40548 .37199 .4046 Mtetra
.734 .847 .933 r
.37199 .4046 .37318 .40548 .37511 .40465 .37393 .40355 Mtetra
.728 .803 .911 r
.37393 .40355 .37511 .40465 .37704 .40381 .37587 .4025 Mtetra
.698 .759 .899 r
.37587 .4025 .37704 .40381 .37897 .40298 .37781 .40159 Mtetra
.685 .743 .895 r
.37781 .40159 .37897 .40298 .3809 .40215 .37974 .40074 Mtetra
.676 .737 .896 r
.37974 .40074 .3809 .40215 .38283 .40133 .38167 .39994 Mtetra
.676 .74 .899 r
.38167 .39994 .38283 .40133 .38476 .40053 .38361 .39914 Mtetra
.669 .737 .902 r
.38361 .39914 .38476 .40053 .3867 .39976 .38554 .39838 Mtetra
.66 .737 .906 r
.38554 .39838 .3867 .39976 .38863 .39901 .38747 .39766 Mtetra
.646 .736 .914 r
.38747 .39766 .38863 .39901 .39056 .39831 .3894 .39701 Mtetra
.636 .74 .924 r
.3894 .39701 .39056 .39831 .39249 .39766 .39134 .3964 Mtetra
.626 .746 .934 r
.39134 .3964 .39249 .39766 .39443 .39704 .39327 .39583 Mtetra
.54 .721 .957 r
.39327 .39583 .39443 .39704 .39636 .39654 .39519 .39555 Mtetra
.573 .78 .977 r
.39519 .39555 .39636 .39654 .39829 .39604 .39711 .39512 Mtetra
.674 .828 .957 r
.39711 .39512 .39829 .39604 .40022 .39548 .39906 .39432 Mtetra
.858 .807 .8 r
.39906 .39432 .40022 .39548 .40216 .39469 .40106 .39204 Mtetra
.826 .668 .687 r
.40106 .39204 .40216 .39469 .40411 .39383 .40311 .38853 Mtetra
.79 .578 .614 r
.40311 .38853 .40411 .39383 .40606 .39298 .40523 .38296 Mtetra
.542 .358 .582 r
.40523 .38296 .40606 .39298 .40798 .39294 .40717 .38242 Mtetra
.494 .32 .574 r
.40717 .38242 .40798 .39294 .40991 .3926 .40907 .38293 Mtetra
.572 .382 .586 r
.40907 .38293 .40991 .3926 .41188 .39142 .41103 .38173 Mtetra
.961 .679 .454 r
.41103 .38173 .41188 .39142 .41402 .38512 .42013 .17624 Mtetra
.524 .288 .499 r
.42013 .17624 .41402 .38512 .42312 .17373 .42217 .16924 Mtetra
.744 .557 .641 r
.42217 .16924 .42312 .17373 .42512 .16783 .42407 .16594 Mtetra
.713 .671 .807 r
.42407 .16594 .42512 .16783 .42697 .16623 .42591 .16479 Mtetra
.62 .697 .899 r
.42591 .16479 .42697 .16623 .42879 .16557 .42772 .16429 Mtetra
.551 .695 .935 r
.42772 .16429 .42879 .16557 .4306 .1653 .42953 .16402 Mtetra
.699 .754 .894 r
.42953 .16402 .4306 .1653 .43242 .16466 .43136 .16316 Mtetra
.696 .716 .864 r
.43136 .16316 .43242 .16466 .43424 .16395 .43319 .16226 Mtetra
.643 .667 .859 r
.43319 .16226 .43424 .16395 .43607 .16329 .43502 .16163 Mtetra
.305 .496 .881 r
.43502 .16163 .43607 .16329 .43789 .16281 .43681 .16216 Mtetra
.563 .009 0 r
.43681 .16216 .43789 .16281 .43971 .1624 .43857 .16371 Mtetra
.778 .354 .244 r
.43857 .16371 .43971 .1624 .44153 .16199 .4403 .16671 Mtetra
.497 .161 .327 r
.4403 .16671 .44153 .16199 .44337 .16096 .44211 .16697 Mtetra
.38 .079 .324 r
.44211 .16697 .44337 .16096 .44521 .16006 .44396 .16576 Mtetra
.466 .149 .344 r
.44396 .16576 .44521 .16006 .44703 .15981 .44578 .1656 Mtetra
.964 .673 .431 r
.44578 .1656 .44703 .15981 .44875 .16333 .44235 .36894 Mtetra
.522 .281 .491 r
.44235 .36894 .44875 .16333 .44534 .37376 .44409 .37689 Mtetra
.688 .306 .319 r
.44409 .37689 .44534 .37376 .44714 .37991 .44598 .37954 Mtetra
0 .515 .783 r
.44598 .37954 .44714 .37991 .44908 .38063 .44793 .37989 Mtetra
.548 .827 .997 r
.44793 .37989 .44908 .38063 .45106 .38004 .44991 .37943 Mtetra
.65 .887 .983 r
.44991 .37943 .45106 .38004 .45304 .379 .45189 .37863 Mtetra
.552 .896 .98 r
.45189 .37863 .45304 .379 .45502 .37823 .45387 .37796 Mtetra
.564 .913 .966 r
.45387 .37796 .45502 .37823 .457 .37757 .45585 .37721 Mtetra
.694 .942 .961 r
.45585 .37721 .457 .37757 .45898 .37684 .45784 .37615 Mtetra
.87 .892 .848 r
.45784 .37615 .45898 .37684 .46097 .37593 .45985 .3741 Mtetra
.858 .735 .727 r
.45985 .3741 .46097 .37593 .46296 .37493 .46188 .371 Mtetra
.803 .612 .644 r
.46188 .371 .46296 .37493 .46495 .37393 .46394 .36664 Mtetra
.675 .476 .608 r
.46394 .36664 .46495 .37393 .46694 .37313 .46597 .36345 Mtetra
.556 .371 .586 r
.46597 .36345 .46694 .37313 .46893 .37247 .46796 .36262 Mtetra
.507 .335 .582 r
.46796 .36262 .46893 .37247 .47092 .37185 .46992 .36284 Mtetra
.536 .361 .592 r
.46992 .36284 .47092 .37185 .47291 .3712 .47191 .3625 Mtetra
.552 .375 .596 r
.47191 .3625 .47291 .3712 .4749 .37053 .47389 .36185 Mtetra
.552 .376 .596 r
.47389 .36185 .4749 .37053 .47689 .36985 .47588 .36119 Mtetra
.554 .377 .596 r
.47588 .36119 .47689 .36985 .47889 .36916 .47788 .3605 Mtetra
.555 .378 .596 r
.47788 .3605 .47889 .36916 .48089 .36847 .47987 .35978 Mtetra
.556 .378 .596 r
.47987 .35978 .48089 .36847 .48288 .36777 .48186 .35904 Mtetra
.557 .379 .596 r
.48186 .35904 .48288 .36777 .48488 .36706 .48386 .35828 Mtetra
.557 .379 .595 r
.48386 .35828 .48488 .36706 .48688 .36635 .48586 .3575 Mtetra
.557 .378 .594 r
.48586 .3575 .48688 .36635 .48889 .36564 .48786 .35673 Mtetra
.555 .376 .594 r
.48786 .35673 .48889 .36564 .49089 .36494 .48986 .35598 Mtetra
.553 .375 .593 r
.48986 .35598 .49089 .36494 .4929 .36425 .49186 .35527 Mtetra
.552 .373 .593 r
.49186 .35527 .4929 .36425 .4949 .36356 .49386 .35459 Mtetra
.549 .371 .593 r
.49386 .35459 .4949 .36356 .49691 .3629 .49587 .35397 Mtetra
.547 .371 .593 r
.49587 .35397 .49691 .3629 .49892 .36224 .49787 .35338 Mtetra
.548 .371 .594 r
.49787 .35338 .49892 .36224 .50093 .36159 .49988 .3528 Mtetra
.504 .341 .593 r
.49988 .3528 .50093 .36159 .50294 .3613 .50188 .35309 Mtetra
.515 .354 .6 r
.50188 .35309 .50294 .3613 .50495 .36095 .50389 .35316 Mtetra
.591 .412 .607 r
.50389 .35316 .50495 .36095 .50697 .35992 .5059 .35181 Mtetra
.899 .628 .518 r
.5059 .35181 .50697 .35992 .50901 .35587 .50803 .32965 Mtetra
.95 .655 .445 r
.50803 .32965 .50901 .35587 .51194 .1453 .51094 .13721 Mtetra
.694 .478 .589 r
.51094 .13721 .51194 .1453 .51386 .13528 .51284 .13299 Mtetra
.761 .659 .749 r
.51284 .13299 .51386 .13528 .51575 .13273 .51472 .13113 Mtetra
.672 .697 .865 r
.51472 .13113 .51575 .13273 .51763 .13188 .5166 .13033 Mtetra
.608 .68 .893 r
.5166 .13033 .51763 .13188 .51951 .1315 .51848 .12986 Mtetra
.623 .672 .877 r
.51848 .12986 .51951 .1315 .52139 .13102 .52037 .12932 Mtetra
.648 .674 .861 r
.52037 .12932 .52139 .13102 .52328 .13035 .52225 .12864 Mtetra
.52225 .12864 .52328 .13035 .52516 .12967 .52414 .12796 Mtetra
.649 .673 .86 r
.52414 .12796 .52516 .12967 .52705 .12899 .52603 .12728 Mtetra
.651 .674 .859 r
.52603 .12728 .52705 .12899 .52894 .1283 .52792 .12658 Mtetra
.652 .674 .858 r
.52792 .12658 .52894 .1283 .53083 .1276 .52981 .12588 Mtetra
.52981 .12588 .53083 .1276 .53272 .12689 .5317 .12517 Mtetra
.653 .674 .858 r
.5317 .12517 .53272 .12689 .53461 .12618 .53359 .12446 Mtetra
.653 .674 .857 r
.53359 .12446 .53461 .12618 .53651 .12547 .53549 .12375 Mtetra
.53549 .12375 .53651 .12547 .5384 .12476 .53738 .12303 Mtetra
.654 .674 .857 r
.53738 .12303 .5384 .12476 .5403 .12404 .53928 .12232 Mtetra
.53928 .12232 .5403 .12404 .5422 .12333 .54118 .1216 Mtetra
.54118 .1216 .5422 .12333 .5441 .12261 .54308 .12088 Mtetra
.54308 .12088 .5441 .12261 .546 .12189 .54498 .12016 Mtetra
.54498 .12016 .546 .12189 .5479 .12117 .54688 .11944 Mtetra
.54688 .11944 .5479 .12117 .5498 .12045 .54879 .11872 Mtetra
.54879 .11872 .5498 .12045 .55171 .11973 .55069 .118 Mtetra
.55069 .118 .55171 .11973 .55361 .11901 .5526 .11727 Mtetra
.5526 .11727 .55361 .11901 .55552 .11829 .55451 .11655 Mtetra
.55451 .11655 .55552 .11829 .55743 .11756 .55642 .11582 Mtetra
.55642 .11582 .55743 .11756 .55934 .11684 .55833 .1151 Mtetra
.55833 .1151 .55934 .11684 .56125 .11611 .56024 .11437 Mtetra
.56024 .11437 .56125 .11611 .56316 .11539 .56215 .11365 Mtetra
.56215 .11365 .56316 .11539 .56508 .11466 .56407 .11292 Mtetra
.56407 .11292 .56508 .11466 .56699 .11393 .56598 .11219 Mtetra
.56598 .11219 .56699 .11393 .56891 .11321 .5679 .11146 Mtetra
.5679 .11146 .56891 .11321 .57082 .11248 .56982 .11073 Mtetra
.56982 .11073 .57082 .11248 .57274 .11175 .57174 .11 Mtetra
.57174 .11 .57274 .11175 .57466 .11102 .57366 .10927 Mtetra
.57366 .10927 .57466 .11102 .57659 .11029 .57558 .10854 Mtetra
.57558 .10854 .57659 .11029 .57851 .10956 .5775 .10781 Mtetra
.5775 .10781 .57851 .10956 .58043 .10883 .57943 .10708 Mtetra
.57943 .10708 .58043 .10883 .58236 .1081 .58135 .10635 Mtetra
.654 .674 .856 r
.58135 .10635 .58236 .1081 .58429 .10737 .58328 .10561 Mtetra
.58328 .10561 .58429 .10737 .58621 .10663 .58521 .10488 Mtetra
.58521 .10488 .58621 .10663 .58814 .1059 .58714 .10415 Mtetra
.655 .674 .856 r
.58714 .10415 .58814 .1059 .59008 .10517 .58907 .10341 Mtetra
.58907 .10341 .59008 .10517 .59201 .10443 .59101 .10268 Mtetra
.59101 .10268 .59201 .10443 .59394 .1037 .59294 .10194 Mtetra
.59294 .10194 .59394 .1037 .59588 .10296 .59488 .1012 Mtetra
.59488 .1012 .59588 .10296 .59781 .10223 .59681 .10046 Mtetra
.59681 .10046 .59781 .10223 .59975 .10149 .59875 .09973 Mtetra
.59875 .09973 .59975 .10149 .60169 .10075 .60069 .09899 Mtetra
.60069 .09899 .60169 .10075 .60363 .10001 .60263 .09825 Mtetra
.60263 .09825 .60363 .10001 .60557 .09927 .60457 .09751 Mtetra
.60457 .09751 .60557 .09927 .60751 .09853 .60652 .09676 Mtetra
.60652 .09676 .60751 .09853 .60946 .09779 .60846 .09602 Mtetra
.60846 .09602 .60946 .09779 .6114 .09705 .61041 .09528 Mtetra
.61041 .09528 .6114 .09705 .61335 .0963 .61236 .09453 Mtetra
.61236 .09453 .61335 .0963 .6153 .09556 .61431 .09379 Mtetra
.61431 .09379 .6153 .09556 .61725 .09481 .61626 .09304 Mtetra
.655 .675 .856 r
.61626 .09304 .61725 .09481 .6192 .09406 .61821 .09229 Mtetra
.656 .675 .856 r
.61821 .09229 .6192 .09406 .62115 .09331 .62016 .09154 Mtetra
.656 .675 .857 r
.62016 .09154 .62115 .09331 .62311 .09256 .62212 .09079 Mtetra
.656 .676 .857 r
.62212 .09079 .62311 .09256 .62506 .09181 .62407 .09004 Mtetra
.62407 .09004 .62506 .09181 .62702 .09105 .62603 .08929 Mtetra
.656 .677 .857 r
.62603 .08929 .62702 .09105 .62898 .09029 .62799 .08853 Mtetra
.657 .677 .858 r
.62799 .08853 .62898 .09029 .63094 .08954 .62995 .08778 Mtetra
.657 .678 .858 r
.62995 .08778 .63094 .08954 .6329 .08878 .63191 .08702 Mtetra
.657 .678 .859 r
.63191 .08702 .6329 .08878 .63486 .08802 .63387 .08627 Mtetra
.657 .679 .859 r
.63387 .08627 .63486 .08802 .63682 .08726 .63583 .08551 Mtetra
.656 .679 .86 r
.63583 .08551 .63682 .08726 .63878 .08651 .6378 .08476 Mtetra
.6378 .08476 .63878 .08651 .64075 .08575 .63977 .084 Mtetra
.655 .679 .86 r
.63977 .084 .64075 .08575 .64272 .08501 .64174 .08325 Mtetra
.655 .678 .86 r
.64174 .08325 .64272 .08501 .64469 .08427 .6437 .08251 Mtetra
.654 .677 .86 r
.6437 .08251 .64469 .08427 .64666 .08353 .64568 .08177 Mtetra
.653 .676 .859 r
.64568 .08177 .64666 .08353 .64863 .08281 .64765 .08103 Mtetra
.653 .674 .857 r
.64765 .08103 .64863 .08281 .65061 .0821 .64962 .08029 Mtetra
.648 .667 .854 r
.64962 .08029 .65061 .0821 .65258 .0814 .6516 .07957 Mtetra
.638 .66 .855 r
.6516 .07957 .65258 .0814 .65456 .0807 .65358 .0789 Mtetra
.62 .656 .864 r
.65358 .0789 .65456 .0807 .65654 .07999 .65557 .07834 Mtetra
.618 .677 .884 r
.65557 .07834 .65654 .07999 .65852 .07928 .65756 .07779 Mtetra
.626 .708 .905 r
.65756 .07779 .65852 .07928 .6605 .07857 .65955 .07721 Mtetra
.651 .743 .917 r
.65955 .07721 .6605 .07857 .66249 .07787 .66153 .07652 Mtetra
.662 .748 .914 r
.66153 .07652 .66249 .07787 .66447 .07716 .66352 .07577 Mtetra
.67 .745 .906 r
.66352 .07577 .66447 .07716 .66646 .07642 .6655 .07498 Mtetra
.674 .738 .899 r
.6655 .07498 .66646 .07642 .66844 .07561 .66748 .07417 Mtetra
.682 .741 .895 r
.66748 .07417 .66844 .07561 .67043 .07478 .66947 .07332 Mtetra
.706 .747 .884 r
.66947 .07332 .67043 .07478 .6724 .07385 .67144 .07233 Mtetra
.774 .762 .842 r
.67144 .07233 .6724 .07385 .67436 .0725 .6734 .07086 Mtetra
.704 .719 .86 r
.6734 .07086 .67436 .0725 .67635 .07159 .67538 .06983 Mtetra
.5 .602 .887 r
.67538 .06983 .67635 .07159 .67838 .07168 .67741 .0698 Mtetra
.651 .268 0 r
.67741 .0698 .67838 .07168 .6807 .07682 .67969 .07437 Mtetra
.973 .662 .309 r
.67969 .07437 .6807 .07682 .69441 .29126 .69336 .28929 Mtetra
.676 .288 0 r
.69336 .28929 .69441 .29126 .69686 .29583 .69584 .29439 Mtetra
.484 .667 .944 r
.69584 .29439 .69686 .29583 .69905 .2957 .69804 .2943 Mtetra
.685 .77 .915 r
.69804 .2943 .69905 .2957 .7012 .29476 .70019 .29337 Mtetra
.738 .79 .894 r
.70019 .29337 .7012 .29476 .70334 .29354 .70232 .29214 Mtetra
.493 .682 .95 r
.70232 .29214 .70334 .29354 .70553 .29338 .70452 .29201 Mtetra
.617 .747 .939 r
.70452 .29201 .70553 .29338 .70771 .29275 .7067 .2914 Mtetra
.795 .813 .866 r
.7067 .2914 .70771 .29275 .70982 .29111 .70882 .28977 Mtetra
.979 .779 .564 r
.70882 .28977 .70982 .29111 .71159 .28374 .71059 .28244 Mtetra
.975 .669 .322 r
.71059 .28244 .71159 .28374 .70067 .06784 .69973 .06647 Mtetra
.966 .785 .606 r
.69973 .06647 .70067 .06784 .70239 .06228 .70145 .06089 Mtetra
.759 .78 .87 r
.70145 .06089 .70239 .06228 .70437 .06097 .70343 .05957 Mtetra
.629 .728 .919 r
.70343 .05957 .70437 .06097 .70639 .06037 .70545 .05897 Mtetra
.546 .689 .932 r
.70545 .05897 .70639 .06037 .70844 .06009 .7075 .05869 Mtetra
.751 .777 .874 r
.7075 .05869 .70844 .06009 .71042 .05884 .70948 .05743 Mtetra
.684 .751 .902 r
.70948 .05743 .71042 .05884 .71243 .05797 .7115 .05656 Mtetra
.493 .659 .935 r
.7115 .05656 .71243 .05797 .71449 .05788 .71356 .05647 Mtetra
.735 .316 0 r
.71356 .05647 .71449 .05788 .71688 .06271 .71595 .06131 Mtetra
.97 .655 .291 r
.71595 .06131 .71688 .06271 .73342 .27764 .73243 .27629 Mtetra
.746 .315 0 r
.73243 .27629 .73342 .27764 .736 .2827 .735 .28134 Mtetra
.022 .46 .874 r
.04261 .51466 .04392 .51571 .04544 .51627 .04414 .51523 Mtetra
.649 .765 .934 r
.04414 .51523 .04544 .51627 .04714 .51568 .04583 .51464 Mtetra
.816 .781 .82 r
.04583 .51464 .04714 .51568 .04901 .51391 .0477 .51289 Mtetra
.913 .735 .648 r
.0477 .51289 .04901 .51391 .05159 .50713 .05025 .50635 Mtetra
.937 .687 .533 r
.05025 .50635 .05159 .50713 .08252 .30014 .08127 .29936 Mtetra
.917 .749 .658 r
.08127 .29936 .08252 .30014 .08479 .29476 .08357 .29381 Mtetra
.77 .788 .867 r
.08357 .29381 .08479 .29476 .08646 .29363 .08525 .29263 Mtetra
.602 .749 .948 r
.08525 .29263 .08646 .29363 .08803 .29328 .08682 .29224 Mtetra
.439 .679 .965 r
.08682 .29224 .08803 .29328 .08954 .29332 .08834 .29223 Mtetra
.74 .761 .87 r
.08834 .29223 .08954 .29332 .09119 .29233 .09 .29122 Mtetra
.693 .75 .895 r
.09 .29122 .09119 .29233 .09281 .2916 .09162 .29047 Mtetra
.479 .677 .952 r
.09162 .29047 .09281 .2916 .09434 .29155 .09315 .29041 Mtetra
.929 .553 .258 r
.09315 .29041 .09434 .29155 .09525 .29598 .09408 .29465 Mtetra
.94 .683 .522 r
.09408 .29465 .09525 .29598 .06848 .50204 .06725 .50057 Mtetra
.943 .586 .289 r
.06725 .50057 .06848 .50204 .0694 .50721 .06814 .50594 Mtetra
.358 .61 .945 r
.06814 .50594 .0694 .50721 .07102 .50735 .06974 .50614 Mtetra
.697 .748 .891 r
.06974 .50614 .07102 .50735 .07277 .50648 .07149 .50532 Mtetra
.766 .765 .852 r
.07149 .50532 .07277 .50648 .07458 .50514 .07329 .50402 Mtetra
.52 .713 .96 r
.07329 .50402 .07458 .50514 .07625 .50492 .07496 .50383 Mtetra
.596 .745 .948 r
.07496 .50383 .07625 .50492 .07794 .5045 .07665 .50343 Mtetra
.757 .781 .873 r
.07665 .50343 .07794 .5045 .07974 .5033 .07844 .50225 Mtetra
.912 .741 .656 r
.07844 .50225 .07974 .5033 .08219 .49717 .08087 .49633 Mtetra
.94 .687 .528 r
.08087 .49633 .08219 .49717 .11139 .28972 .11015 .28896 Mtetra
.923 .75 .65 r
.11015 .28896 .11139 .28972 .11369 .28398 .11248 .28303 Mtetra
.794 .791 .849 r
.11248 .28303 .11369 .28398 .1154 .28265 .1142 .28165 Mtetra
.594 .751 .953 r
.1142 .28165 .1154 .28265 .11698 .2823 .11578 .28127 Mtetra
.398 .666 .968 r
.11578 .28127 .11698 .2823 .11851 .28239 .11731 .28133 Mtetra
.599 .738 .942 r
.11731 .28133 .11851 .28239 .1201 .28203 .1189 .28094 Mtetra
.642 .745 .924 r
.1189 .28094 .1201 .28203 .1217 .28152 .12052 .28041 Mtetra
.653 .744 .917 r
.12052 .28041 .1217 .28152 .12332 .28096 .12213 .27984 Mtetra
.728 .759 .877 r
.12213 .27984 .12332 .28096 .12497 .28016 .1238 .27889 Mtetra
.698 .727 .873 r
.1238 .27889 .12497 .28016 .12661 .27942 .12545 .27809 Mtetra
.585 .681 .906 r
.12545 .27809 .12661 .27942 .12821 .27894 .12703 .27777 Mtetra
.689 .192 0 r
.12703 .27777 .12821 .27894 .12973 .27918 .12835 .27956 Mtetra
.907 .585 .425 r
.12835 .27956 .12973 .27918 .13114 .28032 .12889 .28753 Mtetra
.933 .672 .518 r
.12889 .28753 .13114 .28032 .13228 .28352 .10497 .4884 Mtetra
.512 .274 .49 r
.10497 .4884 .13228 .28352 .10852 .48458 .10628 .49113 Mtetra
.543 .232 .39 r
.10628 .49113 .10852 .48458 .10938 .49093 .10784 .49199 Mtetra
.381 0 0 r
.10784 .49199 .10938 .49093 .11078 .49309 .10948 .49212 Mtetra
.489 .736 .981 r
.10948 .49212 .11078 .49309 .11242 .49326 .11117 .49195 Mtetra
.655 .726 .901 r
.11117 .49195 .11242 .49326 .11417 .49255 .11291 .49132 Mtetra
.765 .761 .849 r
.11291 .49132 .11417 .49255 .116 .49124 .11474 .49002 Mtetra
.878 .753 .72 r
.11474 .49002 .116 .49124 .1179 .48939 .11684 .48657 Mtetra
.895 .676 .599 r
.11684 .48657 .1179 .48939 .11992 .48657 .11985 .47566 Mtetra
.933 .676 .525 r
.11985 .47566 .11992 .48657 .12227 .48099 .14615 .27424 Mtetra
.516 .282 .498 r
.14615 .27424 .12227 .48099 .14858 .27797 .14814 .27069 Mtetra
.627 .437 .606 r
.14814 .27069 .14858 .27797 .15089 .27176 .14994 .26877 Mtetra
.686 .565 .713 r
.14994 .26877 .15089 .27176 .15282 .26875 .15167 .26743 Mtetra
.765 .735 .826 r
.15167 .26743 .15282 .26875 .1546 .267 .15339 .26612 Mtetra
.739 .808 .907 r
.15339 .26612 .1546 .267 .15628 .26602 .15508 .26516 Mtetra
.559 .772 .978 r
.15508 .26516 .15628 .26602 .15788 .26577 .15668 .26484 Mtetra
.77 .271 0 r
.15668 .26484 .15788 .26577 .15922 .26774 .15802 .26684 Mtetra
.947 .65 .444 r
.15802 .26684 .15922 .26774 .15941 .27944 .15787 .28139 Mtetra
.943 .68 .509 r
.15787 .28139 .15941 .27944 .13725 .48187 .13596 .48094 Mtetra
.745 .234 0 r
.13596 .48094 .13725 .48187 .13869 .48394 .13741 .48292 Mtetra
.474 .72 .977 r
.13741 .48292 .13869 .48394 .14039 .48382 .13911 .4828 Mtetra
.778 .797 .868 r
.13911 .4828 .14039 .48382 .14224 .48247 .14096 .48147 Mtetra
.909 .762 .687 r
.14096 .48147 .14224 .48247 .14447 .47778 .14317 .47695 Mtetra
.946 .689 .515 r
.14317 .47695 .14447 .47778 .17001 .26991 .16875 .26955 Mtetra
.948 .756 .611 r
.16875 .26955 .17001 .26991 .17247 .26226 .17128 .26133 Mtetra
.85 .795 .797 r
.17128 .26133 .17247 .26226 .17428 .26028 .1731 .25928 Mtetra
.639 .767 .94 r
.1731 .25928 .17428 .26028 .17592 .25979 .17474 .25874 Mtetra
.459 .691 .966 r
.17474 .25874 .17592 .25979 .17751 .25979 .17633 .25869 Mtetra
.572 .725 .946 r
.17633 .25869 .17751 .25979 .17912 .25952 .17796 .25838 Mtetra
.655 .743 .914 r
.17796 .25838 .17912 .25952 .18078 .25895 .17961 .25778 Mtetra
.669 .741 .905 r
.17961 .25778 .18078 .25895 .18244 .25832 .18128 .25712 Mtetra
.748 .755 .859 r
.18128 .25712 .18244 .25832 .18415 .2572 .18299 .25602 Mtetra
.745 .756 .861 r
.18299 .25602 .18415 .2572 .18586 .2561 .1847 .25493 Mtetra
.628 .729 .92 r
.1847 .25493 .18586 .2561 .18751 .25561 .18635 .25444 Mtetra
.741 .256 0 r
.18635 .25444 .18751 .25561 .18887 .25777 .18772 .25654 Mtetra
.949 .685 .5 r
.18772 .25654 .18887 .25777 .16826 .46235 .16711 .46029 Mtetra
.965 .651 .37 r
.16711 .46029 .16826 .46235 .16887 .47247 .16764 .47114 Mtetra
0 0 .487 r
.16764 .47114 .16887 .47247 .17042 .47395 .16917 .47278 Mtetra
.578 .731 .947 r
.16917 .47278 .17042 .47395 .17219 .47345 .17093 .47242 Mtetra
.776 .8 .873 r
.17093 .47242 .17219 .47345 .17405 .47217 .17278 .47111 Mtetra
.873 .782 .758 r
.17278 .47111 .17405 .47217 .17595 .47045 .1748 .46831 Mtetra
.886 .696 .64 r
.1748 .46831 .17595 .47045 .17791 .46816 .17718 .46209 Mtetra
.944 .683 .51 r
.17718 .46209 .17791 .46816 .18002 .46443 .20053 .25668 Mtetra
.521 .286 .499 r
.20053 .25668 .18002 .46443 .18355 .44706 .20271 .25131 Mtetra
.513 .279 .498 r
.20271 .25131 .18355 .44706 .20536 .25354 .20454 .24916 Mtetra
.647 .495 .662 r
.20454 .24916 .20536 .25354 .20738 .24964 .20629 .24778 Mtetra
.689 .651 .807 r
.20629 .24778 .20738 .24964 .20917 .2479 .208 .24685 Mtetra
.666 .767 .925 r
.208 .24685 .20917 .2479 .21085 .24719 .20968 .24621 Mtetra
.626 .769 .948 r
.20968 .24621 .21085 .24719 .21251 .24681 .21135 .2457 Mtetra
.695 .763 .904 r
.21135 .2457 .21251 .24681 .21418 .24622 .21304 .24492 Mtetra
.713 .735 .868 r
.21304 .24492 .21418 .24622 .21588 .24541 .21475 .24401 Mtetra
.631 .693 .889 r
.21475 .24401 .21588 .24541 .21756 .24481 .21642 .2435 Mtetra
0 .319 .803 r
.21642 .2435 .21756 .24481 .21918 .24479 .21795 .24442 Mtetra
.906 .52 .277 r
.21795 .24442 .21918 .24479 .22072 .24563 .21912 .24897 Mtetra
.947 .679 .495 r
.21912 .24897 .22072 .24563 .22212 .2479 .2005 .45344 Mtetra
.516 .277 .49 r
.2005 .45344 .22212 .2479 .20481 .441 .20179 .45797 Mtetra
.528 .259 .45 r
.20179 .45797 .20481 .441 .20502 .4566 .20343 .45905 Mtetra
.482 .077 .196 r
.20343 .45905 .20502 .4566 .20647 .4596 .20514 .45933 Mtetra
.013 .578 .793 r
.20514 .45933 .20647 .4596 .2081 .46071 .20687 .45948 Mtetra
.462 .672 .955 r
.20687 .45948 .2081 .46071 .20985 .46076 .20862 .45944 Mtetra
.678 .738 .896 r
.20862 .45944 .20985 .46076 .21168 .4599 .21045 .45868 Mtetra
.871 .768 .746 r
.21045 .45868 .21168 .4599 .21372 .45683 .21248 .45575 Mtetra
.945 .722 .57 r
.21248 .45575 .21372 .45683 .21691 .44153 .21552 .44214 Mtetra
.955 .692 .498 r
.21552 .44214 .21691 .44153 .23768 .23874 .23651 .23782 Mtetra
.898 .787 .73 r
.23651 .23782 .23768 .23874 .23961 .23565 .23845 .23465 Mtetra
.694 .785 .921 r
.23845 .23465 .23961 .23565 .24131 .23493 .24016 .23388 Mtetra
.517 .718 .963 r
.24016 .23388 .24131 .23493 .24296 .2348 .24182 .23369 Mtetra
.536 .714 .954 r
.24182 .23369 .24296 .2348 .24462 .23463 .24348 .23346 Mtetra
.661 .746 .913 r
.24348 .23346 .24462 .23463 .24632 .23404 .24518 .23283 Mtetra
.672 .741 .902 r
.24518 .23283 .24632 .23404 .24802 .23338 .24689 .23214 Mtetra
.718 .747 .875 r
.24689 .23214 .24802 .23338 .24974 .23253 .24862 .2312 Mtetra
.74 .74 .851 r
.24862 .2312 .24974 .23253 .25148 .23151 .25036 .2301 Mtetra
.674 .707 .873 r
.25036 .2301 .25148 .23151 .2532 .23072 .25207 .22937 Mtetra
.259 .526 .913 r
.25207 .22937 .2532 .23072 .25487 .23049 .25368 .22981 Mtetra
.876 .437 .12 r
.25368 .22981 .25487 .23049 .25645 .23121 .25505 .23308 Mtetra
.952 .681 .485 r
.25505 .23308 .25645 .23121 .25793 .23321 .23884 .43665 Mtetra
.523 .282 .492 r
.23884 .43665 .25793 .23321 .25872 .24326 .23993 .44438 Mtetra
.509 .271 .489 r
.23993 .44438 .25872 .24326 .24312 .44334 .24157 .44592 Mtetra
.511 .112 .22 r
.24157 .44592 .24312 .44334 .2446 .44673 .2433 .44639 Mtetra
.196 .702 .903 r
.2433 .44639 .2446 .44673 .24629 .44772 .24508 .44636 Mtetra
.584 .701 .923 r
.24508 .44636 .24629 .44772 .24811 .44729 .2469 .44598 Mtetra
.711 .752 .884 r
.2469 .44598 .24811 .44729 .24998 .44625 .24876 .44503 Mtetra
.845 .778 .787 r
.24876 .44503 .24998 .44625 .2519 .44453 .25073 .44276 Mtetra
.904 .72 .643 r
.25073 .44276 .2519 .44453 .25391 .44187 .25302 .43677 Mtetra
.953 .685 .492 r
.25302 .43677 .25391 .44187 .256 .43814 .2719 .23035 Mtetra
.521 .286 .499 r
.2719 .23035 .256 .43814 .25808 .43454 .27403 .22483 Mtetra
.509 .276 .497 r
.27403 .22483 .25808 .43454 .25985 .43471 .27577 .22403 Mtetra
.508 .275 .496 r
.27577 .22403 .25985 .43471 .26165 .43452 .27745 .22386 Mtetra
.509 .276 .497 r
.27745 .22386 .26165 .43452 .26384 .42949 .27919 .223 Mtetra
.513 .279 .497 r
.27919 .223 .26384 .42949 .28186 .22585 .28105 .22074 Mtetra
.662 .49 .641 r
.28105 .22074 .28186 .22585 .28394 .2208 .28288 .21883 Mtetra
.727 .66 .783 r
.28288 .21883 .28394 .2208 .2858 .21847 .28465 .21753 Mtetra
.629 .788 .958 r
.28465 .21753 .2858 .21847 .28753 .2178 .28637 .217 Mtetra
.538 .785 .989 r
.28637 .217 .28753 .2178 .28923 .21756 .28808 .21667 Mtetra
.542 .768 .981 r
.28808 .21667 .28923 .21756 .29092 .2174 .28978 .21637 Mtetra
.626 .766 .946 r
.28978 .21637 .29092 .2174 .29264 .21689 .2915 .21585 Mtetra
.64 .769 .941 r
.2915 .21585 .29264 .21689 .29436 .21633 .29323 .21528 Mtetra
.653 .771 .935 r
.29323 .21528 .29436 .21633 .29609 .21574 .29496 .21467 Mtetra
.666 .77 .928 r
.29496 .21467 .29609 .21574 .29783 .21511 .2967 .214 Mtetra
.674 .765 .92 r
.2967 .214 .29783 .21511 .29956 .21445 .29844 .2133 Mtetra
.703 .766 .902 r
.29844 .2133 .29956 .21445 .30131 .21368 .30019 .21246 Mtetra
.743 .763 .869 r
.30019 .21246 .30131 .21368 .30307 .21274 .30196 .21137 Mtetra
.674 .719 .882 r
.30196 .21137 .30307 .21274 .30482 .21198 .30371 .21064 Mtetra
.365 .586 .928 r
.30371 .21064 .30482 .21198 .30653 .21167 .30538 .21088 Mtetra
.875 .435 .089 r
.30538 .21088 .30653 .21167 .30818 .21225 .30683 .21433 Mtetra
.957 .68 .471 r
.30683 .21433 .30818 .21225 .30975 .21406 .29396 .41886 Mtetra
.521 .28 .491 r
.29396 .41886 .30975 .21406 .31088 .2222 .29528 .42581 Mtetra
.509 .271 .489 r
.29528 .42581 .31088 .2222 .29852 .424 .29701 .42722 Mtetra
.505 .128 .259 r
.29701 .42722 .29852 .424 .30009 .42761 .2988 .42763 Mtetra
.142 .687 .781 r
.2988 .42763 .30009 .42761 .30183 .42879 .30064 .42743 Mtetra
.672 .736 .899 r
.30064 .42743 .30183 .42879 .3037 .42819 .30252 .42667 Mtetra
.71 .724 .861 r
.30252 .42667 .3037 .42819 .30561 .42709 .30442 .42565 Mtetra
.725 .741 .865 r
.30442 .42565 .30561 .42709 .30752 .42581 .30633 .42457 Mtetra
.691 .762 .906 r
.30633 .42457 .30752 .42581 .30941 .42496 .30822 .42372 Mtetra
.682 .76 .911 r
.30822 .42372 .30941 .42496 .3113 .42416 .31011 .42292 Mtetra
.671 .758 .916 r
.31011 .42292 .3113 .42416 .31318 .42341 .31199 .42217 Mtetra
.658 .755 .921 r
.31199 .42217 .31318 .42341 .31507 .42271 .31387 .42148 Mtetra
.649 .754 .926 r
.31387 .42148 .31507 .42271 .31695 .42204 .31575 .42083 Mtetra
.614 .745 .939 r
.31575 .42083 .31695 .42204 .31882 .42152 .31763 .42032 Mtetra
.432 .669 .962 r
.31763 .42032 .31882 .42152 .32066 .42154 .31947 .42034 Mtetra
.623 .75 .938 r
.31947 .42034 .32066 .42154 .32254 .42099 .32135 .41979 Mtetra
.828 .792 .817 r
.32135 .41979 .32254 .42099 .32451 .41901 .32332 .41784 Mtetra
.955 .729 .558 r
.32332 .41784 .32451 .41901 .32719 .40541 .32594 .40522 Mtetra
.964 .692 .469 r
.32594 .40522 .32719 .40541 .34152 .19952 .34041 .1985 Mtetra
.92 .782 .692 r
.34041 .1985 .34152 .19952 .34349 .1956 .34238 .19451 Mtetra
.704 .781 .912 r
.34238 .19451 .34349 .1956 .34526 .1948 .34415 .19367 Mtetra
.521 .708 .956 r
.34415 .19367 .34526 .1948 .34699 .19466 .34589 .19347 Mtetra
.393 .635 .952 r
.34589 .19347 .34699 .19466 .34871 .19484 .34761 .19359 Mtetra
.611 .721 .924 r
.34761 .19359 .34871 .19484 .35047 .1944 .34937 .19313 Mtetra
.622 .722 .918 r
.34937 .19313 .35047 .1944 .35223 .19391 .35113 .19263 Mtetra
.629 .724 .915 r
.35113 .19263 .35223 .19391 .35399 .19338 .3529 .1921 Mtetra
.625 .722 .917 r
.3529 .1921 .35399 .19338 .35576 .19287 .35466 .19159 Mtetra
.631 .724 .915 r
.35466 .19159 .35576 .19287 .35752 .19233 .35643 .19105 Mtetra
.64 .727 .912 r
.35643 .19105 .35752 .19233 .3593 .19175 .3582 .19047 Mtetra
.657 .734 .906 r
.3582 .19047 .3593 .19175 .36107 .1911 .35998 .18983 Mtetra
.665 .737 .904 r
.35998 .18983 .36107 .1911 .36285 .19041 .36176 .18914 Mtetra
.676 .742 .9 r
.36176 .18914 .36285 .19041 .36463 .18967 .36354 .1884 Mtetra
.766 .766 .852 r
.36354 .1884 .36463 .18967 .36645 .18837 .36536 .18711 Mtetra
.695 .75 .894 r
.36536 .18711 .36645 .18837 .36824 .18754 .36715 .18628 Mtetra
.419 .635 .945 r
.36715 .18628 .36824 .18754 .36998 .18765 .36889 .18637 Mtetra
.943 .578 .235 r
.36889 .18637 .36998 .18765 .37134 .19534 .37027 .19358 Mtetra
.967 .685 .446 r
.37027 .19358 .37134 .19534 .36257 .40463 .36141 .40312 Mtetra
.828 .395 0 r
.36141 .40312 .36257 .40463 .36426 .40837 .3631 .40696 Mtetra
.537 .681 .932 r
.3631 .40696 .36426 .40837 .36616 .40814 .36499 .40674 Mtetra
.712 .748 .88 r
.36499 .40674 .36616 .40814 .36809 .40713 .36693 .40573 Mtetra
.775 .763 .843 r
.36693 .40573 .36809 .40713 .37005 .40565 .36889 .40425 Mtetra
.713 .749 .88 r
.36889 .40425 .37005 .40565 .37199 .4046 .37083 .40323 Mtetra
.716 .754 .882 r
.37083 .40323 .37199 .4046 .37393 .40355 .37277 .40221 Mtetra
.716 .76 .887 r
.37277 .40221 .37393 .40355 .37587 .4025 .37471 .40119 Mtetra
.699 .76 .899 r
.37471 .40119 .37587 .4025 .37781 .40159 .37664 .40028 Mtetra
.69 .756 .902 r
.37664 .40028 .37781 .40159 .37974 .40074 .37858 .39941 Mtetra
.68 .751 .904 r
.37858 .39941 .37974 .40074 .38167 .39994 .38051 .39859 Mtetra
.676 .747 .904 r
.38051 .39859 .38167 .39994 .38361 .39914 .38245 .3978 Mtetra
.667 .744 .908 r
.38245 .3978 .38361 .39914 .38554 .39838 .38438 .39705 Mtetra
.655 .743 .914 r
.38438 .39705 .38554 .39838 .38747 .39766 .38631 .39635 Mtetra
.633 .74 .925 r
.38631 .39635 .38747 .39766 .3894 .39701 .38824 .39576 Mtetra
.62 .746 .936 r
.38824 .39576 .3894 .39701 .39134 .3964 .39017 .39521 Mtetra
.612 .754 .946 r
.39017 .39521 .39134 .3964 .39327 .39583 .3921 .39469 Mtetra
.454 .697 .971 r
.3921 .39469 .39327 .39583 .39519 .39555 .39401 .39462 Mtetra
.549 .783 .986 r
.39401 .39462 .39519 .39555 .39711 .39512 .39594 .39424 Mtetra
.731 .848 .936 r
.39594 .39424 .39711 .39512 .39906 .39432 .3979 .39319 Mtetra
.927 .786 .686 r
.3979 .39319 .39906 .39432 .40106 .39204 .39998 .38881 Mtetra
.967 .687 .45 r
.39998 .38881 .40106 .39204 .40311 .38853 .40967 .18578 Mtetra
.538 .299 .501 r
.40967 .18578 .40311 .38853 .40523 .38296 .41196 .17269 Mtetra
.511 .277 .497 r
.41196 .17269 .40523 .38296 .40717 .38242 .41381 .17115 Mtetra
.508 .275 .496 r
.41381 .17115 .40717 .38242 .40907 .38293 .41562 .17073 Mtetra
.41562 .17073 .40907 .38293 .41103 .38173 .41742 .17049 Mtetra
.512 .278 .497 r
.41742 .17049 .41103 .38173 .42013 .17624 .41928 .16845 Mtetra
.624 .43 .599 r
.41928 .16845 .42013 .17624 .42217 .16924 .42115 .16637 Mtetra
.719 .597 .72 r
.42115 .16637 .42217 .16924 .42407 .16594 .42301 .16467 Mtetra
.698 .754 .896 r
.42301 .16467 .42407 .16594 .42591 .16479 .42483 .16381 Mtetra
.625 .789 .96 r
.42483 .16381 .42591 .16479 .42772 .16429 .42665 .16326 Mtetra
.597 .768 .961 r
.42665 .16326 .42772 .16429 .42953 .16402 .42847 .1628 Mtetra
.731 .772 .886 r
.42847 .1628 .42953 .16402 .43136 .16316 .4303 .16176 Mtetra
.708 .736 .873 r
.4303 .16176 .43136 .16316 .43319 .16226 .43213 .16082 Mtetra
.61 .692 .902 r
.43213 .16082 .43319 .16226 .43502 .16163 .43395 .16035 Mtetra
0 .021 .55 r
.43395 .16035 .43502 .16163 .43681 .16216 .43571 .16216 Mtetra
.925 .553 .288 r
.43571 .16216 .43681 .16216 .43857 .16371 .43729 .16982 Mtetra
.963 .673 .434 r
.43729 .16982 .43857 .16371 .4403 .16671 .43318 .37659 Mtetra
.508 .27 .488 r
.43318 .37659 .4403 .16671 .44211 .16697 .43509 .37781 Mtetra
.504 .267 .488 r
.43509 .37781 .44211 .16697 .44396 .16576 .43706 .37705 Mtetra
.504 .266 .488 r
.43706 .37705 .44396 .16576 .44578 .1656 .43904 .37598 Mtetra
.508 .269 .488 r
.43904 .37598 .44578 .1656 .44235 .36894 .44097 .37678 Mtetra
.54 .231 .393 r
.44097 .37678 .44235 .36894 .44409 .37689 .4429 .3778 Mtetra
.486 0 0 r
.4429 .3778 .44409 .37689 .44598 .37954 .44484 .37843 Mtetra
.468 .713 .976 r
.44484 .37843 .44598 .37954 .44793 .37989 .4468 .37831 Mtetra
.606 .687 .9 r
.4468 .37831 .44793 .37989 .44991 .37943 .44878 .37782 Mtetra
.643 .699 .887 r
.44878 .37782 .44991 .37943 .45189 .37863 .45076 .37715 Mtetra
.599 .703 .916 r
.45076 .37715 .45189 .37863 .45387 .37796 .45273 .37669 Mtetra
.636 .753 .933 r
.45273 .37669 .45387 .37796 .45585 .37721 .45471 .37606 Mtetra
.74 .807 .905 r
.45471 .37606 .45585 .37721 .45784 .37615 .45671 .37492 Mtetra
.901 .798 .737 r
.45671 .37492 .45784 .37615 .45985 .3741 .45874 .37166 Mtetra
.922 .706 .593 r
.45874 .37166 .45985 .3741 .46188 .371 .46088 .36357 Mtetra
.967 .681 .435 r
.46088 .36357 .46188 .371 .46394 .36664 .46693 .15407 Mtetra
.515 .28 .497 r
.46693 .15407 .46394 .36664 .46597 .36345 .46883 .15079 Mtetra
.509 .276 .497 r
.46883 .15079 .46597 .36345 .46796 .36262 .47069 .14996 Mtetra
.507 .275 .496 r
.47069 .14996 .46796 .36262 .46992 .36284 .47253 .14985 Mtetra
.508 .275 .496 r
.47253 .14985 .46992 .36284 .47191 .3625 .47438 .14941 Mtetra
.509 .276 .496 r
.47438 .14941 .47191 .3625 .47389 .36185 .47624 .14872 Mtetra
.47624 .14872 .47389 .36185 .47588 .36119 .4781 .14804 Mtetra
.4781 .14804 .47588 .36119 .47788 .3605 .47996 .14734 Mtetra
.47996 .14734 .47788 .3605 .47987 .35978 .48182 .14662 Mtetra
.48182 .14662 .47987 .35978 .48186 .35904 .48369 .14589 Mtetra
.48369 .14589 .48186 .35904 .48386 .35828 .48555 .14515 Mtetra
.48555 .14515 .48386 .35828 .48586 .3575 .48742 .14441 Mtetra
.48742 .14441 .48586 .3575 .48786 .35673 .48929 .14367 Mtetra
.48929 .14367 .48786 .35673 .48986 .35598 .49115 .14294 Mtetra
.49115 .14294 .48986 .35598 .49186 .35527 .49302 .14222 Mtetra
.49302 .14222 .49186 .35527 .49386 .35459 .49489 .14152 Mtetra
.49489 .14152 .49386 .35459 .49587 .35397 .49677 .14083 Mtetra
.49677 .14083 .49587 .35397 .49787 .35338 .49864 .14016 Mtetra
.49864 .14016 .49787 .35338 .49988 .3528 .50051 .1395 Mtetra
.508 .275 .496 r
.50051 .1395 .49988 .3528 .50188 .35309 .50239 .13908 Mtetra
.50239 .13908 .50188 .35309 .50389 .35316 .50426 .13867 Mtetra
.509 .276 .497 r
.50426 .13867 .50389 .35316 .5059 .35181 .50614 .13782 Mtetra
.512 .278 .497 r
.50614 .13782 .5059 .35181 .50803 .32965 .50803 .13574 Mtetra
.513 .279 .497 r
.50803 .13574 .50803 .32965 .51094 .13721 .50992 .13337 Mtetra
.699 .547 .677 r
.50992 .13337 .51094 .13721 .51284 .13299 .51181 .13141 Mtetra
.738 .726 .84 r
.51181 .13141 .51284 .13299 .51472 .13113 .51369 .13019 Mtetra
.663 .817 .958 r
.51369 .13019 .51472 .13113 .5166 .13033 .51557 .12946 Mtetra
.611 .816 .979 r
.51557 .12946 .5166 .13033 .51848 .12986 .51746 .1289 Mtetra
.63 .802 .965 r
.51746 .1289 .51848 .12986 .52037 .12932 .51934 .1283 Mtetra
.653 .797 .951 r
.51934 .1283 .52037 .12932 .52225 .12864 .52123 .12762 Mtetra
.654 .797 .951 r
.52123 .12762 .52225 .12864 .52414 .12796 .52312 .12694 Mtetra
.656 .798 .95 r
.52312 .12694 .52414 .12796 .52603 .12728 .525 .12625 Mtetra
.658 .798 .95 r
.525 .12625 .52603 .12728 .52792 .12658 .5269 .12555 Mtetra
.659 .798 .949 r
.5269 .12555 .52792 .12658 .52981 .12588 .52879 .12485 Mtetra
.66 .799 .949 r
.52879 .12485 .52981 .12588 .5317 .12517 .53068 .12414 Mtetra
.661 .799 .949 r
.53068 .12414 .5317 .12517 .53359 .12446 .53257 .12343 Mtetra
.53257 .12343 .53359 .12446 .53549 .12375 .53447 .12271 Mtetra
.662 .8 .949 r
.53447 .12271 .53549 .12375 .53738 .12303 .53637 .122 Mtetra
.53637 .122 .53738 .12303 .53928 .12232 .53827 .12128 Mtetra
.662 .8 .948 r
.53827 .12128 .53928 .12232 .54118 .1216 .54017 .12056 Mtetra
.54017 .12056 .54118 .1216 .54308 .12088 .54207 .11984 Mtetra
.663 .8 .948 r
.54207 .11984 .54308 .12088 .54498 .12016 .54397 .11912 Mtetra
.54397 .11912 .54498 .12016 .54688 .11944 .54587 .1184 Mtetra
.54587 .1184 .54688 .11944 .54879 .11872 .54778 .11768 Mtetra
.54778 .11768 .54879 .11872 .55069 .118 .54968 .11696 Mtetra
.54968 .11696 .55069 .118 .5526 .11727 .55159 .11623 Mtetra
.55159 .11623 .5526 .11727 .55451 .11655 .5535 .11551 Mtetra
.5535 .11551 .55451 .11655 .55642 .11582 .55541 .11478 Mtetra
.55541 .11478 .55642 .11582 .55833 .1151 .55732 .11405 Mtetra
.55732 .11405 .55833 .1151 .56024 .11437 .55923 .11333 Mtetra
.55923 .11333 .56024 .11437 .56215 .11365 .56115 .1126 Mtetra
.56115 .1126 .56215 .11365 .56407 .11292 .56306 .11187 Mtetra
.56306 .11187 .56407 .11292 .56598 .11219 .56498 .11114 Mtetra
.56498 .11114 .56598 .11219 .5679 .11146 .5669 .11041 Mtetra
.5669 .11041 .5679 .11146 .56982 .11073 .56882 .10968 Mtetra
.56882 .10968 .56982 .11073 .57174 .11 .57074 .10895 Mtetra
.57074 .10895 .57174 .11 .57366 .10927 .57266 .10822 Mtetra
.57266 .10822 .57366 .10927 .57558 .10854 .57458 .10749 Mtetra
.57458 .10749 .57558 .10854 .5775 .10781 .57651 .10676 Mtetra
.57651 .10676 .5775 .10781 .57943 .10708 .57844 .10603 Mtetra
.57844 .10603 .57943 .10708 .58135 .10635 .58036 .10529 Mtetra
.58036 .10529 .58135 .10635 .58328 .10561 .58229 .10456 Mtetra
.58229 .10456 .58328 .10561 .58521 .10488 .58422 .10382 Mtetra
.664 .8 .948 r
.58422 .10382 .58521 .10488 .58714 .10415 .58615 .10309 Mtetra
.58615 .10309 .58714 .10415 .58907 .10341 .58809 .10235 Mtetra
.58809 .10235 .58907 .10341 .59101 .10268 .59002 .10162 Mtetra
.59002 .10162 .59101 .10268 .59294 .10194 .59196 .10088 Mtetra
.59196 .10088 .59294 .10194 .59488 .1012 .59389 .10014 Mtetra
.59389 .10014 .59488 .1012 .59681 .10046 .59583 .0994 Mtetra
.664 .8 .947 r
.59583 .0994 .59681 .10046 .59875 .09973 .59777 .09866 Mtetra
.59777 .09866 .59875 .09973 .60069 .09899 .59971 .09792 Mtetra
.664 .799 .947 r
.59971 .09792 .60069 .09899 .60263 .09825 .60165 .09718 Mtetra
.60165 .09718 .60263 .09825 .60457 .09751 .6036 .09644 Mtetra
.6036 .09644 .60457 .09751 .60652 .09676 .60554 .09569 Mtetra
.60554 .09569 .60652 .09676 .60846 .09602 .60749 .09495 Mtetra
.60749 .09495 .60846 .09602 .61041 .09528 .60943 .0942 Mtetra
.665 .799 .947 r
.60943 .0942 .61041 .09528 .61236 .09453 .61138 .09346 Mtetra
.61138 .09346 .61236 .09453 .61431 .09379 .61333 .09271 Mtetra
.61333 .09271 .61431 .09379 .61626 .09304 .61528 .09196 Mtetra
.61528 .09196 .61626 .09304 .61821 .09229 .61724 .09122 Mtetra
.61724 .09122 .61821 .09229 .62016 .09154 .61919 .09047 Mtetra
.665 .8 .947 r
.61919 .09047 .62016 .09154 .62212 .09079 .62115 .08972 Mtetra
.62115 .08972 .62212 .09079 .62407 .09004 .6231 .08896 Mtetra
.6231 .08896 .62407 .09004 .62603 .08929 .62506 .08821 Mtetra
.665 .801 .947 r
.62506 .08821 .62603 .08929 .62799 .08853 .62702 .08746 Mtetra
.62702 .08746 .62799 .08853 .62995 .08778 .62898 .0867 Mtetra
.666 .801 .948 r
.62898 .0867 .62995 .08778 .63191 .08702 .63095 .08595 Mtetra
.665 .802 .948 r
.63095 .08595 .63191 .08702 .63387 .08627 .63291 .08519 Mtetra
.63291 .08519 .63387 .08627 .63583 .08551 .63487 .08444 Mtetra
.63487 .08444 .63583 .08551 .6378 .08476 .63684 .08368 Mtetra
.665 .802 .949 r
.63684 .08368 .6378 .08476 .63977 .084 .63881 .08293 Mtetra
.664 .802 .949 r
.63881 .08293 .63977 .084 .64174 .08325 .64078 .08218 Mtetra
.664 .801 .948 r
.64078 .08218 .64174 .08325 .6437 .08251 .64275 .08142 Mtetra
.663 .8 .948 r
.64275 .08142 .6437 .08251 .64568 .08177 .64472 .08068 Mtetra
.663 .798 .947 r
.64472 .08068 .64568 .08177 .64765 .08103 .64669 .07993 Mtetra
.664 .797 .946 r
.64669 .07993 .64765 .08103 .64962 .08029 .64867 .07917 Mtetra
.66 .793 .945 r
.64867 .07917 .64962 .08029 .6516 .07957 .65065 .07843 Mtetra
.651 .786 .946 r
.65065 .07843 .6516 .07957 .65358 .0789 .65263 .07773 Mtetra
.633 .771 .947 r
.65263 .07773 .65358 .0789 .65557 .07834 .65461 .07711 Mtetra
.632 .759 .939 r
.65461 .07711 .65557 .07834 .65756 .07779 .6566 .07649 Mtetra
.64 .749 .927 r
.6566 .07649 .65756 .07779 .65955 .07721 .65859 .07585 Mtetra
.66 .745 .913 r
.65859 .07585 .65955 .07721 .66153 .07652 .66057 .07511 Mtetra
.668 .74 .904 r
.66057 .07511 .66153 .07652 .66352 .07577 .66255 .07433 Mtetra
.674 .737 .898 r
.66255 .07433 .66352 .07577 .6655 .07498 .66454 .07351 Mtetra
.677 .734 .894 r
.66454 .07351 .6655 .07498 .66748 .07417 .66652 .07268 Mtetra
.682 .733 .889 r
.66652 .07268 .66748 .07417 .66947 .07332 .66851 .07182 Mtetra
.704 .74 .879 r
.66851 .07182 .66947 .07332 .67144 .07233 .67048 .07083 Mtetra
.771 .764 .847 r
.67048 .07083 .67144 .07233 .6734 .07086 .67244 .06939 Mtetra
.708 .747 .882 r
.67244 .06939 .6734 .07086 .67538 .06983 .67442 .06839 Mtetra
.477 .642 .929 r
.67442 .06839 .67538 .06983 .67741 .0698 .67645 .06836 Mtetra
.724 .303 0 r
.67645 .06836 .67741 .0698 .67969 .07437 .67873 .07282 Mtetra
.973 .661 .311 r
.67873 .07282 .67969 .07437 .69336 .28929 .69234 .2877 Mtetra
.749 .333 0 r
.69234 .2877 .69336 .28929 .69584 .29439 .69482 .29293 Mtetra
.477 .661 .943 r
.69482 .29293 .69584 .29439 .69804 .2943 .69702 .29287 Mtetra
.681 .763 .913 r
.69702 .29287 .69804 .2943 .70019 .29337 .69917 .29197 Mtetra
.734 .786 .895 r
.69917 .29197 .70019 .29337 .70232 .29214 .70131 .29076 Mtetra
.487 .681 .952 r
.70131 .29076 .70232 .29214 .70452 .29201 .70351 .29064 Mtetra
.614 .747 .94 r
.70351 .29064 .70452 .29201 .7067 .2914 .70569 .29005 Mtetra
.794 .813 .867 r
.70569 .29005 .7067 .2914 .70882 .28977 .70781 .28843 Mtetra
.979 .78 .565 r
.70781 .28843 .70882 .28977 .71059 .28244 .70959 .28114 Mtetra
.975 .669 .322 r
.70959 .28114 .71059 .28244 .69973 .06647 .69879 .06511 Mtetra
.967 .785 .605 r
.69879 .06511 .69973 .06647 .70145 .06089 .70051 .05949 Mtetra
.76 .781 .87 r
.70051 .05949 .70145 .06089 .70343 .05957 .70249 .05818 Mtetra
.629 .73 .92 r
.70249 .05818 .70343 .05957 .70545 .05897 .70452 .05757 Mtetra
.546 .69 .933 r
.70452 .05757 .70545 .05897 .7075 .05869 .70656 .05729 Mtetra
.751 .778 .874 r
.70656 .05729 .7075 .05869 .70948 .05743 .70855 .05603 Mtetra
.685 .752 .903 r
.70855 .05603 .70948 .05743 .7115 .05656 .71056 .05516 Mtetra
.492 .66 .936 r
.71056 .05516 .7115 .05656 .71356 .05647 .71262 .05507 Mtetra
.737 .318 0 r
.71262 .05507 .71356 .05647 .71595 .06131 .71502 .05992 Mtetra
.97 .655 .291 r
.71502 .05992 .71595 .06131 .73243 .27629 .73143 .27495 Mtetra
.746 .314 0 r
.73143 .27495 .73243 .27629 .735 .28134 .73401 .27999 Mtetra
.032 .466 .878 r
.0413 .51362 .04261 .51466 .04414 .51523 .04283 .51417 Mtetra
.648 .763 .933 r
.04283 .51417 .04414 .51523 .04583 .51464 .04453 .51358 Mtetra
.812 .779 .822 r
.04453 .51358 .04583 .51464 .0477 .51289 .04639 .51187 Mtetra
.911 .738 .655 r
.04639 .51187 .0477 .51289 .05025 .50635 .04887 .50579 Mtetra
.937 .687 .533 r
.04887 .50579 .05025 .50635 .08127 .29936 .07995 .29906 Mtetra
.936 .771 .652 r
.07995 .29906 .08127 .29936 .08357 .29381 .08232 .29308 Mtetra
.798 .828 .875 r
.08232 .29308 .08357 .29381 .08525 .29263 .08401 .29179 Mtetra
.635 .791 .957 r
.08401 .29179 .08525 .29263 .08682 .29224 .0856 .29127 Mtetra
.491 .719 .972 r
.0856 .29127 .08682 .29224 .08834 .29223 .08713 .29114 Mtetra
.745 .763 .867 r
.08713 .29114 .08834 .29223 .09 .29122 .0888 .2901 Mtetra
.695 .75 .894 r
.0888 .2901 .09 .29122 .09162 .29047 .09042 .28934 Mtetra
.488 .682 .952 r
.09042 .28934 .09162 .29047 .09315 .29041 .09195 .28926 Mtetra
.923 .535 .227 r
.09195 .28926 .09315 .29041 .09408 .29465 .09293 .29314 Mtetra
.94 .683 .522 r
.09293 .29314 .09408 .29465 .06725 .50057 .06609 .49852 Mtetra
.956 .61 .275 r
.06609 .49852 .06725 .50057 .06814 .50594 .0669 .50441 Mtetra
.337 .546 .909 r
.0669 .50441 .06814 .50594 .06974 .50614 .06849 .50474 Mtetra
.667 .711 .881 r
.06849 .50474 .06974 .50614 .07149 .50532 .07022 .50405 Mtetra
.744 .748 .855 r
.07022 .50405 .07149 .50532 .07329 .50402 .07201 .5029 Mtetra
.503 .705 .961 r
.07201 .5029 .07329 .50402 .07496 .50383 .07366 .50275 Mtetra
.591 .745 .95 r
.07366 .50275 .07496 .50383 .07665 .50343 .07535 .50236 Mtetra
.754 .781 .875 r
.07535 .50236 .07665 .50343 .07844 .50225 .07715 .50121 Mtetra
.91 .744 .664 r
.07715 .50121 .07844 .50225 .08087 .49633 .07953 .49567 Mtetra
.94 .688 .528 r
.07953 .49567 .08087 .49633 .11015 .28896 .10884 .28872 Mtetra
.942 .772 .642 r
.10884 .28872 .11015 .28896 .11248 .28303 .11123 .28231 Mtetra
.819 .829 .857 r
.11123 .28231 .11248 .28303 .1142 .28165 .11297 .28082 Mtetra
.621 .793 .964 r
.11297 .28082 .1142 .28165 .11578 .28127 .11457 .28034 Mtetra
.446 .707 .978 r
.11457 .28034 .11578 .28127 .11731 .28133 .11612 .28027 Mtetra
.617 .745 .938 r
.11612 .28027 .11731 .28133 .1189 .28094 .11771 .27983 Mtetra
.648 .743 .919 r
.11771 .27983 .1189 .28094 .12052 .28041 .11933 .27928 Mtetra
.653 .74 .914 r
.11933 .27928 .12052 .28041 .12213 .27984 .12095 .2787 Mtetra
.745 .759 .863 r
.12095 .2787 .12213 .27984 .1238 .27889 .12263 .27764 Mtetra
.707 .732 .871 r
.12263 .27764 .1238 .27889 .12545 .27809 .12428 .27679 Mtetra
.545 .672 .92 r
.12428 .27679 .12545 .27809 .12703 .27777 .12586 .27659 Mtetra
.906 .496 .151 r
.12586 .27659 .12703 .27777 .12835 .27956 .12696 .28003 Mtetra
.941 .681 .515 r
.12696 .28003 .12835 .27956 .12889 .28753 .10224 .4857 Mtetra
.521 .281 .492 r
.10224 .4857 .12889 .28753 .10497 .4884 .10309 .492 Mtetra
.538 .18 .308 r
.10309 .492 .10497 .4884 .10628 .49113 .10467 .49264 Mtetra
.122 0 0 r
.10467 .49264 .10628 .49113 .10784 .49199 .10642 .492 Mtetra
.733 .968 .934 r
.10642 .492 .10784 .49199 .10948 .49212 .10822 .49085 Mtetra
.597 .713 .925 r
.10822 .49085 .10948 .49212 .11117 .49195 .10994 .49045 Mtetra
.617 .681 .888 r
.10994 .49045 .11117 .49195 .11291 .49132 .11166 .48998 Mtetra
.746 .741 .847 r
.11166 .48998 .11291 .49132 .11474 .49002 .11348 .48878 Mtetra
.903 .739 .669 r
.11348 .48878 .11474 .49002 .11684 .48657 .11579 .48363 Mtetra
.942 .686 .521 r
.11579 .48363 .11684 .48657 .11985 .47566 .14306 .27588 Mtetra
.525 .289 .5 r
.14306 .27588 .11985 .47566 .14615 .27424 .14545 .26917 Mtetra
.663 .491 .641 r
.14545 .26917 .14615 .27424 .14814 .27069 .14724 .26729 Mtetra
.612 .502 .705 r
.14724 .26729 .14814 .27069 .14994 .26877 .14889 .26659 Mtetra
.569 .559 .803 r
.14889 .26659 .14994 .26877 .15167 .26743 .15049 .26634 Mtetra
.675 .756 .912 r
.15049 .26634 .15167 .26743 .15339 .26612 .15213 .26567 Mtetra
.637 .882 .986 r
.15213 .26567 .15339 .26612 .15508 .26516 .15378 .26504 Mtetra
.138 .68 .829 r
.15378 .26504 .15508 .26516 .15668 .26484 .15536 .26496 Mtetra
.826 .393 .211 r
.15536 .26496 .15668 .26484 .15802 .26684 .15662 .26753 Mtetra
.944 .682 .509 r
.15662 .26753 .15802 .26684 .15787 .28139 .13409 .47065 Mtetra
.529 .287 .493 r
.13409 .47065 .15787 .28139 .13596 .48094 .13464 .48022 Mtetra
.69 .151 0 r
.13464 .48022 .13596 .48094 .13741 .48292 .13614 .48186 Mtetra
.482 .713 .972 r
.13614 .48186 .13741 .48292 .13911 .4828 .13784 .48173 Mtetra
.764 .79 .874 r
.13784 .48173 .13911 .4828 .14096 .48147 .13967 .4805 Mtetra
.906 .769 .699 r
.13967 .4805 .14096 .48147 .14317 .47695 .14185 .47632 Mtetra
.947 .689 .515 r
.14185 .47632 .14317 .47695 .16875 .26955 .16733 .27051 Mtetra
.977 .789 .584 r
.16733 .27051 .16875 .26955 .17128 .26133 .17005 .26067 Mtetra
.876 .83 .798 r
.17005 .26067 .17128 .26133 .1731 .25928 .17189 .25845 Mtetra
.671 .81 .95 r
.17189 .25845 .1731 .25928 .17474 .25874 .17355 .25779 Mtetra
.506 .732 .975 r
.17355 .25779 .17474 .25874 .17633 .25869 .17516 .25761 Mtetra
.609 .742 .939 r
.17516 .25761 .17633 .25869 .17796 .25838 .17679 .25718 Mtetra
.668 .737 .902 r
.17679 .25718 .17796 .25838 .17961 .25778 .17846 .25652 Mtetra
.66 .724 .897 r
.17846 .25652 .17961 .25778 .18128 .25712 .18012 .2559 Mtetra
.701 .741 .883 r
.18012 .2559 .18128 .25712 .18299 .25602 .1818 .25508 Mtetra
.684 .792 .931 r
.1818 .25508 .18299 .25602 .1847 .25493 .18347 .25437 Mtetra
.386 .769 .99 r
.18347 .25437 .1847 .25493 .18635 .25444 .18508 .25424 Mtetra
.837 .386 .15 r
.18508 .25424 .18635 .25444 .18772 .25654 .1864 .2568 Mtetra
.948 .683 .501 r
.1864 .2568 .18772 .25654 .16711 .46029 .16558 .46166 Mtetra
.883 .553 .42 r
.16558 .46166 .16711 .46029 .16764 .47114 .16641 .46975 Mtetra
0 0 .505 r
.16641 .46975 .16764 .47114 .16917 .47278 .16794 .4714 Mtetra
.521 .668 .929 r
.16794 .4714 .16917 .47278 .17093 .47242 .16968 .47124 Mtetra
.753 .774 .87 r
.16968 .47124 .17093 .47242 .17278 .47111 .17152 .47005 Mtetra
.896 .772 .717 r
.17152 .47005 .17278 .47111 .1748 .46831 .17363 .46639 Mtetra
.948 .688 .509 r
.17363 .46639 .1748 .46831 .17718 .46209 .19652 .2672 Mtetra
.551 .312 .506 r
.19652 .2672 .17718 .46209 .20053 .25668 .19997 .24983 Mtetra
.665 .47 .611 r
.19997 .24983 .20053 .25668 .20271 .25131 .20186 .24714 Mtetra
.603 .471 .674 r
.20186 .24714 .20271 .25131 .20454 .24916 .20355 .24637 Mtetra
.563 .508 .752 r
.20355 .24637 .20454 .24916 .20629 .24778 .20519 .24613 Mtetra
.591 .636 .864 r
.20519 .24613 .20629 .24778 .208 .24685 .20684 .24578 Mtetra
.655 .759 .926 r
.20684 .24578 .208 .24685 .20968 .24621 .20851 .24517 Mtetra
.658 .769 .931 r
.20851 .24517 .20968 .24621 .21135 .2457 .21019 .24456 Mtetra
.725 .763 .883 r
.21019 .24456 .21135 .2457 .21304 .24492 .2119 .24362 Mtetra
.728 .737 .858 r
.2119 .24362 .21304 .24492 .21475 .24401 .21362 .2426 Mtetra
.622 .688 .891 r
.21362 .2426 .21475 .24401 .21642 .2435 .21529 .24213 Mtetra
0 0 .465 r
.21529 .24213 .21642 .2435 .21795 .24442 .21674 .24384 Mtetra
.952 .684 .493 r
.21674 .24384 .21795 .24442 .21912 .24897 .19845 .44304 Mtetra
.54 .297 .495 r
.19845 .44304 .21912 .24897 .2005 .45344 .19867 .45826 Mtetra
.619 .284 .38 r
.19867 .45826 .2005 .45344 .20179 .45797 .20022 .46017 Mtetra
.335 0 .081 r
.20022 .46017 .20179 .45797 .20343 .45905 .202 .45981 Mtetra
0 0 0 r
.202 .45981 .20343 .45905 .20514 .45933 .20384 .45884 Mtetra
.665 .893 .979 r
.20384 .45884 .20514 .45933 .20687 .45948 .20566 .45806 Mtetra
.621 .702 .903 r
.20566 .45806 .20687 .45948 .20862 .45944 .20745 .45755 Mtetra
.702 .668 .813 r
.20745 .45755 .20862 .45944 .21045 .45868 .20931 .45648 Mtetra
.828 .684 .703 r
.20931 .45648 .21045 .45868 .21248 .45575 .21137 .45324 Mtetra
.942 .69 .529 r
.21137 .45324 .21248 .45575 .21552 .44214 .2165 .41773 Mtetra
.925 .657 .513 r
.2165 .41773 .21552 .44214 .23651 .23782 .23535 .23686 Mtetra
.891 .786 .738 r
.23535 .23686 .23651 .23782 .23845 .23465 .23727 .23386 Mtetra
.717 .834 .937 r
.23727 .23386 .23845 .23465 .24016 .23388 .23899 .23299 Mtetra
.563 .773 .977 r
.23899 .23299 .24016 .23388 .24182 .23369 .24066 .23264 Mtetra
.595 .75 .951 r
.24066 .23264 .24182 .23369 .24348 .23346 .24234 .23224 Mtetra
.684 .742 .896 r
.24234 .23224 .24348 .23346 .24518 .23283 .24405 .23149 Mtetra
.674 .72 .884 r
.24405 .23149 .24518 .23283 .24689 .23214 .24576 .23078 Mtetra
.688 .721 .874 r
.24576 .23078 .24689 .23214 .24862 .2312 .24748 .22999 Mtetra
.693 .747 .893 r
.24748 .22999 .24862 .2312 .25036 .2301 .2492 .2292 Mtetra
.544 .763 .979 r
.2492 .2292 .25036 .2301 .25207 .22937 .25087 .2289 Mtetra
.659 .106 0 r
.25087 .2289 .25207 .22937 .25368 .22981 .25239 .23036 Mtetra
.936 .633 .441 r
.25239 .23036 .25368 .22981 .25505 .23308 .25251 .2476 Mtetra
.936 .662 .495 r
.25251 .2476 .25505 .23308 .23884 .43665 .23682 .44442 Mtetra
.603 .295 .421 r
.23682 .44442 .23884 .43665 .23993 .44438 .23839 .44673 Mtetra
.361 0 .114 r
.23839 .44673 .23993 .44438 .24157 .44592 .2402 .44643 Mtetra
.399 .842 .731 r
.2402 .44643 .24157 .44592 .2433 .44639 .24205 .44552 Mtetra
.676 .824 .955 r
.24205 .44552 .2433 .44639 .24508 .44636 .2439 .44476 Mtetra
.543 .645 .901 r
.2439 .44476 .24508 .44636 .2469 .44598 .24569 .44456 Mtetra
.672 .723 .887 r
.24569 .44456 .2469 .44598 .24876 .44503 .24754 .4438 Mtetra
.862 .776 .765 r
.24754 .4438 .24876 .44503 .25073 .44276 .24954 .44118 Mtetra
.94 .713 .569 r
.24954 .44118 .25073 .44276 .25302 .43677 .25243 .428 Mtetra
.949 .681 .495 r
.25243 .428 .25302 .43677 .2719 .23035 .27125 .22333 Mtetra
.691 .487 .606 r
.27125 .22333 .2719 .23035 .27403 .22483 .27321 .21982 Mtetra
.6 .449 .649 r
.27321 .21982 .27403 .22483 .27577 .22403 .27496 .21891 Mtetra
.551 .413 .646 r
.27496 .21891 .27577 .22403 .27745 .22386 .27665 .21859 Mtetra
.539 .402 .642 r
.27665 .21859 .27745 .22386 .27919 .223 .27834 .21839 Mtetra
.575 .441 .661 r
.27834 .21839 .27919 .223 .28105 .22074 .28006 .21786 Mtetra
.6 .526 .743 r
.28006 .21786 .28105 .22074 .28288 .21883 .28177 .21734 Mtetra
.626 .68 .881 r
.28177 .21734 .28288 .21883 .28465 .21753 .28349 .21683 Mtetra
.598 .829 .987 r
.28349 .21683 .28465 .21753 .28637 .217 .28521 .21633 Mtetra
.594 .836 .99 r
.28521 .21633 .28637 .217 .28808 .21667 .28693 .21583 Mtetra
.617 .803 .971 r
.28693 .21583 .28808 .21667 .28978 .21637 .28865 .21531 Mtetra
.633 .764 .941 r
.28865 .21531 .28978 .21637 .2915 .21585 .29037 .21477 Mtetra
.643 .762 .935 r
.29037 .21477 .2915 .21585 .29323 .21528 .2921 .2142 Mtetra
.657 .765 .929 r
.2921 .2142 .29323 .21528 .29496 .21467 .29383 .21357 Mtetra
.674 .767 .921 r
.29383 .21357 .29496 .21467 .2967 .214 .29557 .21287 Mtetra
.68 .762 .913 r
.29557 .21287 .2967 .214 .29844 .2133 .29731 .21214 Mtetra
.713 .765 .893 r
.29731 .21214 .29844 .2133 .30019 .21246 .29907 .21124 Mtetra
.759 .764 .857 r
.29907 .21124 .30019 .21246 .30196 .21137 .30085 .21002 Mtetra
.67 .722 .888 r
.30085 .21002 .30196 .21137 .30371 .21064 .3026 .20932 Mtetra
.089 .427 .871 r
.3026 .20932 .30371 .21064 .30538 .21088 .30424 .21004 Mtetra
.95 .616 .352 r
.30424 .21004 .30538 .21088 .30683 .21433 .30521 .22006 Mtetra
.953 .675 .474 r
.30521 .22006 .30683 .21433 .29396 .41886 .2922 .42542 Mtetra
.641 .321 .413 r
.2922 .42542 .29396 .41886 .29528 .42581 .29381 .42838 Mtetra
.381 0 .146 r
.29381 .42838 .29528 .42581 .29701 .42722 .29566 .42811 Mtetra
0 0 0 r
.29566 .42811 .29701 .42722 .2988 .42763 .29755 .42715 Mtetra
.766 .916 .939 r
.29755 .42715 .2988 .42763 .30064 .42743 .29946 .42593 Mtetra
.678 .718 .879 r
.29946 .42593 .30064 .42743 .30252 .42667 .30135 .42512 Mtetra
.68 .711 .872 r
.30135 .42512 .30252 .42667 .30442 .42565 .30323 .4243 Mtetra
.687 .742 .893 r
.30323 .4243 .30442 .42565 .30633 .42457 .30512 .42345 Mtetra
.693 .787 .923 r
.30512 .42345 .30633 .42457 .30822 .42372 .30701 .42261 Mtetra
.689 .786 .925 r
.30701 .42261 .30822 .42372 .31011 .42292 .3089 .42178 Mtetra
.679 .779 .926 r
.3089 .42178 .31011 .42292 .31199 .42217 .31079 .421 Mtetra
.658 .767 .93 r
.31079 .421 .31199 .42217 .31387 .42148 .31267 .42031 Mtetra
.647 .764 .934 r
.31267 .42031 .31387 .42148 .31575 .42083 .31456 .41967 Mtetra
.614 .755 .945 r
.31456 .41967 .31575 .42083 .31763 .42032 .31643 .41915 Mtetra
.455 .688 .966 r
.31643 .41915 .31763 .42032 .31947 .42034 .31828 .4191 Mtetra
.623 .744 .934 r
.31828 .4191 .31947 .42034 .32135 .41979 .32016 .41855 Mtetra
.809 .787 .831 r
.32016 .41855 .32135 .41979 .32332 .41784 .32211 .41681 Mtetra
.95 .752 .602 r
.32211 .41681 .32332 .41784 .32594 .40522 .32446 .40871 Mtetra
.968 .696 .465 r
.32446 .40871 .32594 .40522 .34041 .1985 .33917 .19939 Mtetra
.984 .906 .622 r
.33917 .19939 .34041 .1985 .34238 .19451 .34119 .19459 Mtetra
.744 .988 .894 r
.34119 .19459 .34238 .19451 .34415 .19367 .343 .19329 Mtetra
.608 .902 .986 r
.343 .19329 .34415 .19367 .34589 .19347 .34477 .19262 Mtetra
.554 .784 .985 r
.34477 .19262 .34589 .19347 .34761 .19359 .34652 .19226 Mtetra
.639 .716 .904 r
.34652 .19226 .34761 .19359 .34937 .19313 .34828 .19169 Mtetra
.623 .691 .893 r
.34828 .19169 .34937 .19313 .35113 .19263 .35005 .19118 Mtetra
.615 .688 .895 r
.35005 .19118 .35113 .19263 .3529 .1921 .35181 .19071 Mtetra
.621 .701 .902 r
.35181 .19071 .3529 .1921 .35466 .19159 .35357 .19021 Mtetra
.625 .705 .903 r
.35357 .19021 .35466 .19159 .35643 .19105 .35534 .1897 Mtetra
.633 .712 .904 r
.35534 .1897 .35643 .19105 .3582 .19047 .35711 .18915 Mtetra
.652 .724 .902 r
.35711 .18915 .3582 .19047 .35998 .18983 .35889 .18852 Mtetra
.661 .731 .901 r
.35889 .18852 .35998 .18983 .36176 .18914 .36067 .18785 Mtetra
.673 .737 .898 r
.36067 .18785 .36176 .18914 .36354 .1884 .36245 .18712 Mtetra
.756 .762 .857 r
.36245 .18712 .36354 .1884 .36536 .18711 .36426 .1859 Mtetra
.695 .759 .901 r
.36426 .1859 .36536 .18711 .36715 .18628 .36605 .18508 Mtetra
.461 .668 .952 r
.36605 .18508 .36715 .18628 .36889 .18637 .3678 .18505 Mtetra
.904 .501 .101 r
.3678 .18505 .36889 .18637 .37027 .19358 .3693 .18989 Mtetra
.969 .688 .444 r
.3693 .18989 .37027 .19358 .36141 .40312 .36037 .39921 Mtetra
0 0 .315 r
.36037 .39921 .36141 .40312 .3631 .40696 .362 .40414 Mtetra
.483 .48 .778 r
.362 .40414 .3631 .40696 .36499 .40674 .36388 .40433 Mtetra
.619 .59 .798 r
.36388 .40433 .36499 .40674 .36693 .40573 .36579 .40372 Mtetra
.693 .663 .815 r
.36579 .40372 .36693 .40573 .36889 .40425 .36773 .40267 Mtetra
.677 .71 .873 r
.36773 .40267 .36889 .40425 .37083 .40323 .36966 .40183 Mtetra
.698 .744 .887 r
.36966 .40183 .37083 .40323 .37277 .40221 .3716 .40091 Mtetra
.709 .765 .896 r
.3716 .40091 .37277 .40221 .37471 .40119 .37354 .39994 Mtetra
.698 .77 .907 r
.37354 .39994 .37471 .40119 .37664 .40028 .37547 .39904 Mtetra
.693 .772 .912 r
.37547 .39904 .37664 .40028 .37858 .39941 .37741 .39817 Mtetra
.686 .768 .913 r
.37741 .39817 .37858 .39941 .38051 .39859 .37935 .39733 Mtetra
.676 .761 .915 r
.37935 .39733 .38051 .39859 .38245 .3978 .38128 .39653 Mtetra
.664 .758 .92 r
.38128 .39653 .38245 .3978 .38438 .39705 .38321 .3958 Mtetra
.649 .756 .928 r
.38321 .3958 .38438 .39705 .38631 .39635 .38515 .39514 Mtetra
.619 .751 .94 r
.38515 .39514 .38631 .39635 .38824 .39576 .38708 .39459 Mtetra
.604 .755 .95 r
.38708 .39459 .38824 .39576 .39017 .39521 .389 .39409 Mtetra
.596 .762 .958 r
.389 .39409 .39017 .39521 .3921 .39469 .39093 .39361 Mtetra
.364 .664 .972 r
.39093 .39361 .3921 .39469 .39401 .39462 .39284 .39372 Mtetra
.523 .779 .99 r
.39284 .39372 .39401 .39462 .39594 .39424 .39476 .39339 Mtetra
.761 .86 .923 r
.39476 .39339 .39594 .39424 .3979 .39319 .39673 .39218 Mtetra
.953 .773 .622 r
.39673 .39218 .3979 .39319 .39998 .38881 .3989 .38566 Mtetra
.967 .687 .45 r
.3989 .38566 .39998 .38881 .40967 .18578 .40901 .1736 Mtetra
.68 .45 .566 r
.40901 .1736 .40967 .18578 .41196 .17269 .41103 .16778 Mtetra
.641 .48 .65 r
.41103 .16778 .41196 .17269 .41381 .17115 .41287 .16628 Mtetra
.576 .438 .656 r
.41287 .16628 .41381 .17115 .41562 .17073 .41468 .16569 Mtetra
.541 .41 .652 r
.41468 .16569 .41562 .17073 .41742 .17049 .41648 .16548 Mtetra
.571 .431 .652 r
.41648 .16548 .41742 .17049 .41928 .16845 .41829 .16492 Mtetra
.599 .496 .709 r
.41829 .16492 .41928 .16845 .42115 .16637 .42011 .16429 Mtetra
.635 .615 .813 r
.42011 .16429 .42115 .16637 .42301 .16467 .42193 .16364 Mtetra
.673 .793 .939 r
.42193 .16364 .42301 .16467 .42483 .16381 .42375 .16291 Mtetra
.671 .82 .955 r
.42375 .16291 .42483 .16381 .42665 .16326 .42558 .16218 Mtetra
.661 .78 .937 r
.42558 .16218 .42665 .16326 .42847 .1628 .4274 .1615 Mtetra
.699 .75 .892 r
.4274 .1615 .42847 .1628 .4303 .16176 .42923 .16063 Mtetra
.64 .763 .938 r
.42923 .16063 .4303 .16176 .43213 .16082 .43105 .16004 Mtetra
.315 .69 .979 r
.43105 .16004 .43213 .16082 .43395 .16035 .43286 .16011 Mtetra
.871 .431 .132 r
.43286 .16011 .43395 .16035 .43571 .16216 .43455 .16406 Mtetra
.968 .678 .428 r
.43455 .16406 .43571 .16216 .43729 .16982 .43012 .37466 Mtetra
.517 .277 .49 r
.43012 .37466 .43729 .16982 .43318 .37659 .4319 .38035 Mtetra
.521 .155 .286 r
.4319 .38035 .43318 .37659 .43509 .37781 .43383 .38094 Mtetra
.352 0 .179 r
.43383 .38094 .43509 .37781 .43706 .37705 .4358 .38033 Mtetra
.281 0 .16 r
.4358 .38033 .43706 .37705 .43904 .37598 .43778 .37926 Mtetra
.338 0 .184 r
.43778 .37926 .43904 .37598 .44097 .37678 .43975 .37851 Mtetra
.208 0 0 r
.43975 .37851 .44097 .37678 .4429 .3778 .44173 .37785 Mtetra
.431 .872 .87 r
.44173 .37785 .4429 .3778 .44484 .37843 .4437 .37713 Mtetra
.691 .766 .909 r
.4437 .37713 .44484 .37843 .4468 .37831 .44568 .37625 Mtetra
.678 .655 .821 r
.44568 .37625 .4468 .37831 .44878 .37782 .44767 .37528 Mtetra
.661 .603 .78 r
.44767 .37528 .44878 .37782 .45076 .37715 .44966 .37431 Mtetra
.572 .533 .773 r
.44966 .37431 .45076 .37715 .45273 .37669 .45163 .37397 Mtetra
.585 .549 .781 r
.45163 .37397 .45273 .37669 .45471 .37606 .45361 .37354 Mtetra
.679 .614 .776 r
.45361 .37354 .45471 .37606 .45671 .37492 .4556 .37242 Mtetra
.875 .695 .655 r
.4556 .37242 .45671 .37492 .45874 .37166 .45767 .3676 Mtetra
.97 .685 .432 r
.45767 .3676 .45874 .37166 .46088 .36357 .46397 .15575 Mtetra
.525 .288 .499 r
.46397 .15575 .46088 .36357 .46693 .15407 .46597 .14786 Mtetra
.648 .464 .62 r
.46597 .14786 .46693 .15407 .46883 .15079 .46785 .14575 Mtetra
.588 .443 .652 r
.46785 .14575 .46883 .15079 .47069 .14996 .4697 .14497 Mtetra
.553 .421 .654 r
.4697 .14497 .47069 .14996 .47253 .14985 .47155 .14461 Mtetra
.568 .426 .647 r
.47155 .14461 .47253 .14985 .47438 .14941 .4734 .14405 Mtetra
.577 .429 .644 r
.4734 .14405 .47438 .14941 .47624 .14872 .47526 .14336 Mtetra
.577 .429 .643 r
.47526 .14336 .47624 .14872 .4781 .14804 .47712 .14266 Mtetra
.578 .429 .643 r
.47712 .14266 .4781 .14804 .47996 .14734 .47898 .14196 Mtetra
.578 .43 .643 r
.47898 .14196 .47996 .14734 .48182 .14662 .48084 .14124 Mtetra
.579 .43 .643 r
.48084 .14124 .48182 .14662 .48369 .14589 .4827 .14052 Mtetra
.579 .43 .644 r
.4827 .14052 .48369 .14589 .48555 .14515 .48456 .1398 Mtetra
.579 .431 .644 r
.48456 .1398 .48555 .14515 .48742 .14441 .48643 .13908 Mtetra
.579 .431 .645 r
.48643 .13908 .48742 .14441 .48929 .14367 .48829 .13837 Mtetra
.579 .432 .645 r
.48829 .13837 .48929 .14367 .49115 .14294 .49016 .13765 Mtetra
.579 .432 .646 r
.49016 .13765 .49115 .14294 .49302 .14222 .49203 .13694 Mtetra
.49203 .13694 .49302 .14222 .49489 .14152 .4939 .13623 Mtetra
.578 .432 .646 r
.4939 .13623 .49489 .14152 .49677 .14083 .49577 .13553 Mtetra
.578 .431 .646 r
.49577 .13553 .49677 .14083 .49864 .14016 .49764 .13484 Mtetra
.577 .43 .645 r
.49764 .13484 .49864 .14016 .50051 .1395 .49951 .13415 Mtetra
.575 .428 .644 r
.49951 .13415 .50051 .1395 .50239 .13908 .50139 .13348 Mtetra
.572 .421 .638 r
.50139 .13348 .50239 .13908 .50426 .13867 .50326 .13281 Mtetra
.569 .415 .633 r
.50326 .13281 .50426 .13867 .50614 .13782 .50514 .13215 Mtetra
.572 .42 .637 r
.50514 .13215 .50614 .13782 .50803 .13574 .50702 .13149 Mtetra
.589 .465 .679 r
.50702 .13149 .50803 .13574 .50992 .13337 .5089 .13081 Mtetra
.624 .571 .775 r
.5089 .13081 .50992 .13337 .51181 .13141 .51078 .13014 Mtetra
.651 .747 .92 r
.51078 .13014 .51181 .13141 .51369 .13019 .51266 .12948 Mtetra
.625 .857 .986 r
.51266 .12948 .51369 .13019 .51557 .12946 .51454 .12883 Mtetra
.616 .869 .99 r
.51454 .12883 .51557 .12946 .51746 .1289 .51643 .12818 Mtetra
.631 .855 .984 r
.51643 .12818 .51746 .1289 .51934 .1283 .51831 .12751 Mtetra
.64 .845 .979 r
.51831 .12751 .51934 .1283 .52123 .12762 .5202 .12683 Mtetra
.642 .846 .978 r
.5202 .12683 .52123 .12762 .52312 .12694 .52209 .12615 Mtetra
.645 .846 .977 r
.52209 .12615 .52312 .12694 .525 .12625 .52398 .12546 Mtetra
.647 .847 .977 r
.52398 .12546 .525 .12625 .5269 .12555 .52587 .12476 Mtetra
.648 .847 .977 r
.52587 .12476 .5269 .12555 .52879 .12485 .52777 .12405 Mtetra
.649 .848 .976 r
.52777 .12405 .52879 .12485 .53068 .12414 .52966 .12335 Mtetra
.65 .848 .976 r
.52966 .12335 .53068 .12414 .53257 .12343 .53156 .12264 Mtetra
.53156 .12264 .53257 .12343 .53447 .12271 .53345 .12192 Mtetra
.651 .848 .976 r
.53345 .12192 .53447 .12271 .53637 .122 .53535 .12121 Mtetra
.651 .849 .976 r
.53535 .12121 .53637 .122 .53827 .12128 .53725 .12049 Mtetra
.652 .849 .976 r
.53725 .12049 .53827 .12128 .54017 .12056 .53915 .11977 Mtetra
.53915 .11977 .54017 .12056 .54207 .11984 .54105 .11905 Mtetra
.54105 .11905 .54207 .11984 .54397 .11912 .54296 .11833 Mtetra
.54296 .11833 .54397 .11912 .54587 .1184 .54486 .11761 Mtetra
.652 .849 .975 r
.54486 .11761 .54587 .1184 .54778 .11768 .54677 .11688 Mtetra
.54677 .11688 .54778 .11768 .54968 .11696 .54867 .11616 Mtetra
.653 .849 .975 r
.54867 .11616 .54968 .11696 .55159 .11623 .55058 .11543 Mtetra
.55058 .11543 .55159 .11623 .5535 .11551 .55249 .11471 Mtetra
.55249 .11471 .5535 .11551 .55541 .11478 .5544 .11398 Mtetra
.5544 .11398 .55541 .11478 .55732 .11405 .55632 .11325 Mtetra
.55632 .11325 .55732 .11405 .55923 .11333 .55823 .11252 Mtetra
.55823 .11252 .55923 .11333 .56115 .1126 .56015 .1118 Mtetra
.56015 .1118 .56115 .1126 .56306 .11187 .56206 .11107 Mtetra
.56206 .11107 .56306 .11187 .56498 .11114 .56398 .11034 Mtetra
.56398 .11034 .56498 .11114 .5669 .11041 .5659 .10961 Mtetra
.5659 .10961 .5669 .11041 .56882 .10968 .56782 .10888 Mtetra
.56782 .10888 .56882 .10968 .57074 .10895 .56974 .10815 Mtetra
.56974 .10815 .57074 .10895 .57266 .10822 .57167 .10741 Mtetra
.57167 .10741 .57266 .10822 .57458 .10749 .57359 .10668 Mtetra
.57359 .10668 .57458 .10749 .57651 .10676 .57552 .10595 Mtetra
.57552 .10595 .57651 .10676 .57844 .10603 .57744 .10521 Mtetra
.57744 .10521 .57844 .10603 .58036 .10529 .57937 .10448 Mtetra
.57937 .10448 .58036 .10529 .58229 .10456 .5813 .10374 Mtetra
.5813 .10374 .58229 .10456 .58422 .10382 .58323 .10301 Mtetra
.58323 .10301 .58422 .10382 .58615 .10309 .58517 .10227 Mtetra
.58517 .10227 .58615 .10309 .58809 .10235 .5871 .10153 Mtetra
.654 .849 .975 r
.5871 .10153 .58809 .10235 .59002 .10162 .58904 .1008 Mtetra
.58904 .1008 .59002 .10162 .59196 .10088 .59097 .10006 Mtetra
.59097 .10006 .59196 .10088 .59389 .10014 .59291 .09932 Mtetra
.59291 .09932 .59389 .10014 .59583 .0994 .59485 .09858 Mtetra
.59485 .09858 .59583 .0994 .59777 .09866 .59679 .09783 Mtetra
.654 .848 .975 r
.59679 .09783 .59777 .09866 .59971 .09792 .59873 .09709 Mtetra
.655 .848 .974 r
.59873 .09709 .59971 .09792 .60165 .09718 .60068 .09635 Mtetra
.60068 .09635 .60165 .09718 .6036 .09644 .60262 .0956 Mtetra
.60262 .0956 .6036 .09644 .60554 .09569 .60457 .09486 Mtetra
.60457 .09486 .60554 .09569 .60749 .09495 .60652 .09411 Mtetra
.60652 .09411 .60749 .09495 .60943 .0942 .60846 .09337 Mtetra
.60846 .09337 .60943 .0942 .61138 .09346 .61041 .09262 Mtetra
.655 .847 .974 r
.61041 .09262 .61138 .09346 .61333 .09271 .61237 .09187 Mtetra
.61237 .09187 .61333 .09271 .61528 .09196 .61432 .09112 Mtetra
.61432 .09112 .61528 .09196 .61724 .09122 .61627 .09037 Mtetra
.61627 .09037 .61724 .09122 .61919 .09047 .61823 .08962 Mtetra
.655 .848 .974 r
.61823 .08962 .61919 .09047 .62115 .08972 .62019 .08887 Mtetra
.62019 .08887 .62115 .08972 .6231 .08896 .62214 .08812 Mtetra
.62214 .08812 .6231 .08896 .62506 .08821 .6241 .08737 Mtetra
.6241 .08737 .62506 .08821 .62702 .08746 .62606 .08662 Mtetra
.655 .849 .974 r
.62606 .08662 .62702 .08746 .62898 .0867 .62803 .08586 Mtetra
.62803 .08586 .62898 .0867 .63095 .08595 .62999 .08511 Mtetra
.62999 .08511 .63095 .08595 .63291 .08519 .63195 .08435 Mtetra
.655 .85 .975 r
.63195 .08435 .63291 .08519 .63487 .08444 .63392 .0836 Mtetra
.63392 .0836 .63487 .08444 .63684 .08368 .63589 .08284 Mtetra
.655 .85 .974 r
.63589 .08284 .63684 .08368 .63881 .08293 .63786 .08208 Mtetra
.655 .849 .974 r
.63786 .08208 .63881 .08293 .64078 .08218 .63983 .08133 Mtetra
.655 .848 .974 r
.63983 .08133 .64078 .08218 .64275 .08142 .6418 .08057 Mtetra
.656 .847 .973 r
.6418 .08057 .64275 .08142 .64472 .08068 .64377 .07981 Mtetra
.656 .845 .973 r
.64377 .07981 .64472 .08068 .64669 .07993 .64575 .07905 Mtetra
.656 .843 .972 r
.64575 .07905 .64669 .07993 .64867 .07917 .64772 .07829 Mtetra
.658 .844 .971 r
.64772 .07829 .64867 .07917 .65065 .07843 .6497 .07753 Mtetra
.663 .84 .968 r
.6497 .07753 .65065 .07843 .65263 .07773 .65168 .07676 Mtetra
.671 .827 .958 r
.65168 .07676 .65263 .07773 .65461 .07711 .65366 .07596 Mtetra
.676 .793 .937 r
.65366 .07596 .65461 .07711 .6566 .07649 .65564 .07516 Mtetra
.675 .756 .912 r
.65564 .07516 .6566 .07649 .65859 .07585 .65762 .07435 Mtetra
.67 .727 .892 r
.65762 .07435 .65859 .07585 .66057 .07511 .6596 .07355 Mtetra
.67 .717 .884 r
.6596 .07355 .66057 .07511 .66255 .07433 .66158 .07275 Mtetra
.673 .715 .88 r
.66158 .07275 .66255 .07433 .66454 .07351 .66357 .07192 Mtetra
.684 .717 .874 r
.66357 .07192 .66454 .07351 .66652 .07268 .66555 .07103 Mtetra
.677 .705 .869 r
.66555 .07103 .66652 .07268 .66851 .07182 .66754 .07017 Mtetra
.675 .705 .87 r
.66754 .07017 .66851 .07182 .67048 .07083 .66952 .06932 Mtetra
.71 .74 .875 r
.66952 .06932 .67048 .07083 .67244 .06939 .6715 .06829 Mtetra
.627 .785 .958 r
.6715 .06829 .67244 .06939 .67442 .06839 .6735 .06767 Mtetra
.136 .592 .925 r
.6735 .06767 .67442 .06839 .67645 .06836 .67556 .06803 Mtetra
.871 .433 .051 r
.67556 .06803 .67645 .06836 .67873 .07282 .67789 .07364 Mtetra
.972 .66 .318 r
.67789 .07364 .67873 .07282 .69234 .2877 .69137 .28722 Mtetra
.806 .329 0 r
.69137 .28722 .69234 .2877 .69482 .29293 .6938 .29149 Mtetra
.488 .67 .944 r
.6938 .29149 .69482 .29293 .69702 .29287 .69599 .29139 Mtetra
.673 .75 .909 r
.69599 .29139 .69702 .29287 .69917 .29197 .69815 .29052 Mtetra
.719 .774 .896 r
.69815 .29052 .69917 .29197 .70131 .29076 .7003 .28939 Mtetra
.471 .676 .954 r
.7003 .28939 .70131 .29076 .70351 .29064 .7025 .28932 Mtetra
.603 .75 .948 r
.7025 .28932 .70351 .29064 .70569 .29005 .70468 .28876 Mtetra
.792 .825 .877 r
.70468 .28876 .70569 .29005 .70781 .28843 .70681 .28718 Mtetra
.981 .786 .568 r
.70681 .28718 .70781 .28843 .70959 .28114 .7086 .28006 Mtetra
.975 .669 .322 r
.7086 .28006 .70959 .28114 .69879 .06511 .69786 .06385 Mtetra
.972 .79 .599 r
.69786 .06385 .69879 .06511 .70051 .05949 .69957 .05811 Mtetra
.762 .784 .871 r
.69957 .05811 .70051 .05949 .70249 .05818 .70155 .05679 Mtetra
.63 .731 .92 r
.70155 .05679 .70249 .05818 .70452 .05757 .70358 .05617 Mtetra
.546 .69 .934 r
.70358 .05617 .70452 .05757 .70656 .05729 .70563 .05589 Mtetra
.752 .779 .875 r
.70563 .05589 .70656 .05729 .70855 .05603 .70761 .05463 Mtetra
.685 .753 .903 r
.70761 .05463 .70855 .05603 .71056 .05516 .70962 .05375 Mtetra
.492 .66 .936 r
.70962 .05375 .71056 .05516 .71262 .05507 .71169 .05366 Mtetra
.739 .32 0 r
.71169 .05366 .71262 .05507 .71502 .05992 .71408 .05854 Mtetra
.97 .655 .291 r
.71408 .05854 .71502 .05992 .73143 .27495 .73044 .27361 Mtetra
.745 .313 0 r
.73044 .27361 .73143 .27495 .73401 .27999 .73302 .27863 Mtetra
.033 .466 .878 r
.03999 .51257 .0413 .51362 .04283 .51417 .04152 .51312 Mtetra
.647 .765 .935 r
.04152 .51312 .04283 .51417 .04453 .51358 .04322 .51254 Mtetra
.812 .781 .823 r
.04322 .51254 .04453 .51358 .04639 .51187 .04508 .51082 Mtetra
.91 .738 .656 r
.04508 .51082 .04639 .51187 .04887 .50579 .04756 .50478 Mtetra
.937 .686 .534 r
.04756 .50478 .04887 .50579 .07995 .29906 .07874 .298 Mtetra
.909 .731 .649 r
.07874 .298 .07995 .29906 .08232 .29308 .08111 .29198 Mtetra
.776 .762 .841 r
.08111 .29198 .08232 .29308 .08401 .29179 .08281 .29068 Mtetra
.64 .739 .92 r
.08281 .29068 .08401 .29179 .0856 .29127 .0844 .29016 Mtetra
.509 .694 .952 r
.0844 .29016 .0856 .29127 .08713 .29114 .08593 .29003 Mtetra
.745 .759 .864 r
.08593 .29003 .08713 .29114 .0888 .2901 .0876 .28898 Mtetra
.696 .75 .893 r
.0876 .28898 .0888 .2901 .09042 .28934 .08922 .28821 Mtetra
.492 .683 .952 r
.08922 .28821 .09042 .28934 .09195 .28926 .09076 .28812 Mtetra
.922 .534 .227 r
.09076 .28812 .09195 .28926 .09293 .29314 .09174 .29199 Mtetra
.939 .683 .522 r
.09174 .29199 .09293 .29314 .06609 .49852 .0648 .49739 Mtetra
.938 .59 .336 r
.0648 .49739 .06609 .49852 .0669 .50441 .06561 .50332 Mtetra
.224 .576 .942 r
.06561 .50332 .0669 .50441 .06849 .50474 .06719 .50365 Mtetra
.673 .765 .92 r
.06719 .50365 .06849 .50474 .07022 .50405 .06892 .50295 Mtetra
.753 .777 .873 r
.06892 .50295 .07022 .50405 .07201 .5029 .07071 .50181 Mtetra
.496 .709 .966 r
.07071 .50181 .07201 .5029 .07366 .50275 .07237 .50166 Mtetra
.588 .744 .951 r
.07237 .50166 .07366 .50275 .07535 .50236 .07406 .50128 Mtetra
.752 .78 .876 r
.07406 .50128 .07535 .50236 .07715 .50121 .07585 .50014 Mtetra
.909 .743 .664 r
.07585 .50014 .07715 .50121 .07953 .49567 .07823 .49463 Mtetra
.94 .687 .528 r
.07823 .49463 .07953 .49567 .10884 .28872 .10764 .28763 Mtetra
.914 .731 .64 r
.10764 .28763 .10884 .28872 .11123 .28231 .11004 .28119 Mtetra
.795 .764 .825 r
.11004 .28119 .11123 .28231 .11297 .28082 .11177 .2797 Mtetra
.628 .736 .925 r
.11177 .2797 .11297 .28082 .11457 .28034 .11338 .27922 Mtetra
.471 .679 .956 r
.11338 .27922 .11457 .28034 .11612 .28027 .11492 .27917 Mtetra
.619 .735 .929 r
.11492 .27917 .11612 .28027 .11771 .27983 .11652 .27871 Mtetra
.65 .743 .917 r
.11652 .27871 .11771 .27983 .11933 .27928 .11814 .27815 Mtetra
.657 .742 .913 r
.11814 .27815 .11933 .27928 .12095 .2787 .11976 .27756 Mtetra
.75 .759 .86 r
.11976 .27756 .12095 .2787 .12263 .27764 .12145 .27646 Mtetra
.714 .747 .878 r
.12145 .27646 .12263 .27764 .12428 .27679 .1231 .27559 Mtetra
.536 .688 .937 r
.1231 .27559 .12428 .27679 .12586 .27659 .12468 .2754 Mtetra
.917 .518 .187 r
.12468 .2754 .12586 .27659 .12696 .28003 .12574 .27915 Mtetra
.943 .683 .515 r
.12574 .27915 .12696 .28003 .10224 .4857 .10081 .48571 Mtetra
.901 .549 .366 r
.10081 .48571 .10224 .4857 .10309 .492 .10174 .49145 Mtetra
0 .435 .759 r
.10174 .49145 .10309 .492 .10467 .49264 .10334 .49192 Mtetra
.701 .845 .951 r
.10334 .49192 .10467 .49264 .10642 .492 .10511 .49109 Mtetra
.787 .814 .874 r
.10511 .49109 .10642 .492 .10822 .49085 .10694 .48975 Mtetra
.608 .749 .944 r
.10694 .48975 .10822 .49085 .10994 .49045 .10866 .48929 Mtetra
.611 .739 .937 r
.10866 .48929 .10994 .49045 .11166 .48998 .11039 .48883 Mtetra
.756 .773 .867 r
.11039 .48883 .11166 .48998 .11348 .48878 .11221 .48763 Mtetra
.91 .742 .661 r
.11221 .48763 .11348 .48878 .11579 .48363 .11457 .48204 Mtetra
.943 .687 .521 r
.11457 .48204 .11579 .48363 .14306 .27588 .14202 .27361 Mtetra
.875 .681 .637 r
.14202 .27361 .14306 .27588 .14545 .26917 .14433 .26751 Mtetra
.787 .699 .767 r
.14433 .26751 .14545 .26917 .14724 .26729 .14612 .26569 Mtetra
.648 .665 .852 r
.14612 .26569 .14724 .26729 .14889 .26659 .14776 .26509 Mtetra
.482 .609 .901 r
.14776 .26509 .14889 .26659 .15049 .26634 .14932 .2651 Mtetra
.308 .573 .934 r
.14932 .2651 .15049 .26634 .15213 .26567 .15085 .26539 Mtetra
.488 0 0 r
.15085 .26539 .15213 .26567 .15378 .26504 .15232 .26621 Mtetra
.739 .327 .268 r
.15232 .26621 .15378 .26504 .15536 .26496 .15365 .26826 Mtetra
.889 .596 .485 r
.15365 .26826 .15536 .26496 .15662 .26753 .15325 .28474 Mtetra
.922 .657 .517 r
.15325 .28474 .15662 .26753 .13409 .47065 .13198 .47666 Mtetra
.659 .343 .425 r
.13198 .47666 .13409 .47065 .13464 .48022 .13329 .47976 Mtetra
.529 0 0 r
.13329 .47976 .13464 .48022 .13614 .48186 .13486 .48081 Mtetra
.435 .696 .975 r
.13486 .48081 .13614 .48186 .13784 .48173 .13655 .48078 Mtetra
.731 .806 .911 r
.13655 .48078 .13784 .48173 .13967 .4805 .13836 .47979 Mtetra
.914 .794 .714 r
.13836 .47979 .13967 .4805 .14185 .47632 .1405 .47591 Mtetra
.947 .69 .515 r
.1405 .47591 .14185 .47632 .16733 .27051 .16587 .27186 Mtetra
.979 .779 .566 r
.16587 .27186 .16733 .27051 .17005 .26067 .16887 .25964 Mtetra
.857 .778 .773 r
.16887 .25964 .17005 .26067 .17189 .25845 .17072 .25731 Mtetra
.675 .75 .907 r
.17072 .25731 .17189 .25845 .17355 .25779 .17238 .25663 Mtetra
.527 .697 .946 r
.17238 .25663 .17355 .25779 .17516 .25761 .17399 .25645 Mtetra
.642 .737 .918 r
.17399 .25645 .17516 .25761 .17679 .25718 .17564 .25591 Mtetra
.685 .729 .884 r
.17564 .25591 .17679 .25718 .17846 .25652 .17731 .25516 Mtetra
.635 .697 .891 r
.17731 .25516 .17846 .25652 .18012 .2559 .17896 .25464 Mtetra
.421 .628 .94 r
.17896 .25464 .18012 .2559 .1818 .25508 .18054 .25473 Mtetra
.517 0 0 r
.18054 .25473 .1818 .25508 .18347 .25437 .18203 .25566 Mtetra
.763 .365 .299 r
.18203 .25566 .18347 .25437 .18508 .25424 .18335 .25818 Mtetra
.943 .677 .504 r
.18335 .25818 .18508 .25424 .1864 .2568 .16308 .45634 Mtetra
.529 .287 .493 r
.16308 .45634 .1864 .2568 .16558 .46166 .16366 .46661 Mtetra
.66 .33 .403 r
.16366 .46661 .16558 .46166 .16641 .46975 .16507 .46933 Mtetra
.486 0 0 r
.16507 .46933 .16641 .46975 .16794 .4714 .16668 .47029 Mtetra
.454 .694 .97 r
.16668 .47029 .16794 .4714 .16968 .47124 .1684 .47023 Mtetra
.726 .8 .91 r
.1684 .47023 .16968 .47124 .17152 .47005 .17023 .46926 Mtetra
.909 .798 .726 r
.17023 .46926 .17152 .47005 .17363 .46639 .17233 .46569 Mtetra
.95 .69 .508 r
.17233 .46569 .17363 .46639 .19652 .2672 .19557 .26393 Mtetra
.91 .673 .568 r
.19557 .26393 .19652 .2672 .19997 .24983 .19886 .24816 Mtetra
.831 .711 .732 r
.19886 .24816 .19997 .24983 .20186 .24714 .20075 .24557 Mtetra
.651 .672 .857 r
.20075 .24557 .20186 .24714 .20355 .24637 .20242 .24495 Mtetra
.506 .636 .912 r
.20242 .24495 .20355 .24637 .20519 .24613 .20404 .24487 Mtetra
.553 .689 .93 r
.20404 .24487 .20519 .24613 .20684 .24578 .20568 .24463 Mtetra
.656 .745 .915 r
.20568 .24463 .20684 .24578 .20851 .24517 .20735 .24402 Mtetra
.671 .748 .908 r
.20735 .24402 .20851 .24517 .21019 .24456 .20904 .24335 Mtetra
.741 .754 .863 r
.20904 .24335 .21019 .24456 .2119 .24362 .21077 .24227 Mtetra
.745 .735 .842 r
.21077 .24227 .2119 .24362 .21362 .2426 .2125 .24112 Mtetra
.645 .684 .872 r
.2125 .24112 .21362 .2426 .21529 .24213 .21418 .24053 Mtetra
0 0 .555 r
.21418 .24053 .21529 .24213 .21674 .24384 .21563 .24221 Mtetra
.953 .686 .492 r
.21563 .24221 .21674 .24384 .19845 .44304 .19716 .44239 Mtetra
.947 .642 .426 r
.19716 .44239 .19845 .44304 .19867 .45826 .19737 .45765 Mtetra
.738 .213 0 r
.19737 .45765 .19867 .45826 .20022 .46017 .19892 .45956 Mtetra
.535 .833 .999 r
.19892 .45956 .20022 .46017 .202 .45981 .2007 .45914 Mtetra
.774 .87 .919 r
.2007 .45914 .202 .45981 .20384 .45884 .20257 .45793 Mtetra
.822 .822 .849 r
.20257 .45793 .20384 .45884 .20566 .45806 .20448 .45623 Mtetra
.801 .705 .759 r
.20448 .45623 .20566 .45806 .20745 .45755 .20644 .45406 Mtetra
.781 .609 .667 r
.20644 .45406 .20745 .45755 .20931 .45648 .20852 .45059 Mtetra
.843 .611 .587 r
.20852 .45059 .20931 .45648 .21137 .45324 .2113 .43984 Mtetra
.94 .674 .507 r
.2113 .43984 .21137 .45324 .2165 .41773 .23224 .23902 Mtetra
.519 .284 .499 r
.23224 .23902 .2165 .41773 .23535 .23686 .23429 .23473 Mtetra
.772 .661 .74 r
.23429 .23473 .23535 .23686 .23727 .23386 .23611 .23277 Mtetra
.694 .77 .911 r
.23611 .23277 .23727 .23386 .23899 .23299 .23783 .232 Mtetra
.607 .764 .955 r
.23783 .232 .23899 .23299 .24066 .23264 .23951 .23155 Mtetra
.666 .761 .921 r
.23951 .23155 .24066 .23264 .24234 .23224 .24121 .23089 Mtetra
.724 .732 .857 r
.24121 .23089 .24234 .23224 .24405 .23149 .24295 .22989 Mtetra
.678 .68 .845 r
.24295 .22989 .24405 .23149 .24576 .23078 .24466 .2291 Mtetra
.558 .621 .871 r
.24466 .2291 .24576 .23078 .24748 .22999 .24633 .22888 Mtetra
.008 .419 .859 r
.24633 .22888 .24748 .22999 .2492 .2292 .24791 .22957 Mtetra
.757 .286 .127 r
.24791 .22957 .2492 .2292 .25087 .2289 .24939 .23151 Mtetra
.869 .545 .437 r
.24939 .23151 .25087 .2289 .25239 .23036 .2502 .24088 Mtetra
.941 .668 .492 r
.2502 .24088 .25239 .23036 .25251 .2476 .23397 .44161 Mtetra
.513 .274 .489 r
.23397 .44161 .25251 .2476 .23682 .44442 .23544 .44505 Mtetra
.567 .043 0 r
.23544 .44505 .23682 .44442 .23839 .44673 .23713 .44594 Mtetra
.629 .828 .977 r
.23713 .44594 .23839 .44673 .2402 .44643 .23896 .44533 Mtetra
.73 .791 .901 r
.23896 .44533 .2402 .44643 .24205 .44552 .24083 .4443 Mtetra
.665 .756 .918 r
.24083 .4443 .24205 .44552 .2439 .44476 .24267 .4436 Mtetra
.451 .684 .965 r
.24267 .4436 .2439 .44476 .24569 .44456 .24445 .44356 Mtetra
.637 .789 .955 r
.24445 .44356 .24569 .44456 .24754 .4438 .24629 .44296 Mtetra
.882 .824 .786 r
.24629 .44296 .24754 .4438 .24954 .44118 .24828 .44042 Mtetra
.955 .732 .562 r
.24828 .44042 .24954 .44118 .25243 .428 .25121 .42685 Mtetra
.957 .69 .489 r
.25121 .42685 .25243 .428 .27125 .22333 .27016 .22166 Mtetra
.867 .721 .698 r
.27016 .22166 .27125 .22333 .27321 .21982 .27212 .21815 Mtetra
.696 .68 .831 r
.27212 .21815 .27321 .21982 .27496 .21891 .27387 .21722 Mtetra
.582 .632 .866 r
.27387 .21722 .27496 .21891 .27665 .21859 .27556 .2169 Mtetra
.533 .609 .875 r
.27556 .2169 .27665 .21859 .27834 .21839 .27724 .21677 Mtetra
.592 .646 .873 r
.27724 .21677 .27834 .21839 .28006 .21786 .27895 .21641 Mtetra
.581 .67 .9 r
.27895 .21641 .28006 .21786 .28177 .21734 .28065 .21608 Mtetra
.586 .707 .926 r
.28065 .21608 .28177 .21734 .28349 .21683 .28235 .21572 Mtetra
.614 .746 .94 r
.28235 .21572 .28349 .21683 .28521 .21633 .28407 .21525 Mtetra
.626 .757 .941 r
.28407 .21525 .28521 .21633 .28693 .21583 .28579 .21474 Mtetra
.634 .757 .937 r
.28579 .21474 .28693 .21583 .28865 .21531 .28751 .2142 Mtetra
.637 .753 .932 r
.28751 .2142 .28865 .21531 .29037 .21477 .28924 .21365 Mtetra
.647 .754 .928 r
.28924 .21365 .29037 .21477 .2921 .2142 .29097 .21306 Mtetra
.661 .756 .92 r
.29097 .21306 .2921 .2142 .29383 .21357 .2927 .21241 Mtetra
.677 .757 .911 r
.2927 .21241 .29383 .21357 .29557 .21287 .29445 .21169 Mtetra
.682 .755 .907 r
.29445 .21169 .29557 .21287 .29731 .21214 .29619 .21094 Mtetra
.716 .761 .888 r
.29619 .21094 .29731 .21214 .29907 .21124 .29795 .21002 Mtetra
.764 .767 .855 r
.29795 .21002 .29907 .21124 .30085 .21002 .29974 .20877 Mtetra
.67 .738 .901 r
.29974 .20877 .30085 .21002 .3026 .20932 .30148 .20807 Mtetra
0 .35 .822 r
.30148 .20807 .3026 .20932 .30424 .21004 .30311 .20896 Mtetra
.961 .685 .467 r
.30311 .20896 .30424 .21004 .30521 .22006 .29095 .39985 Mtetra
.564 .316 .498 r
.29095 .39985 .30521 .22006 .2922 .42542 .2909 .4255 Mtetra
.803 .334 .112 r
.2909 .4255 .2922 .42542 .29381 .42838 .29254 .42812 Mtetra
.426 .846 .959 r
.29254 .42812 .29381 .42838 .29566 .42811 .29439 .42769 Mtetra
.737 .926 .954 r
.29439 .42769 .29566 .42811 .29755 .42715 .2963 .42659 Mtetra
.789 .903 .922 r
.2963 .42659 .29755 .42715 .29946 .42593 .29822 .42526 Mtetra
.675 .869 .972 r
.29822 .42526 .29946 .42593 .30135 .42512 .30011 .42445 Mtetra
.675 .87 .973 r
.30011 .42445 .30135 .42512 .30323 .4243 .30199 .42364 Mtetra
.685 .876 .97 r
.30199 .42364 .30323 .4243 .30512 .42345 .30388 .4228 Mtetra
.716 .88 .957 r
.30388 .4228 .30512 .42345 .30701 .42261 .30578 .42183 Mtetra
.72 .857 .947 r
.30578 .42183 .30701 .42261 .3089 .42178 .30768 .42086 Mtetra
.707 .827 .939 r
.30768 .42086 .3089 .42178 .31079 .421 .30958 .41995 Mtetra
.666 .793 .942 r
.30958 .41995 .31079 .421 .31267 .42031 .31147 .41922 Mtetra
.648 .78 .944 r
.31147 .41922 .31267 .42031 .31456 .41967 .31335 .41857 Mtetra
.617 .769 .953 r
.31335 .41857 .31456 .41967 .31643 .41915 .31523 .41803 Mtetra
.516 .726 .968 r
.31523 .41803 .31643 .41915 .31828 .4191 .31709 .41781 Mtetra
.623 .735 .927 r
.31709 .41781 .31828 .4191 .32016 .41855 .31897 .41727 Mtetra
.758 .773 .865 r
.31897 .41727 .32016 .41855 .32211 .41681 .3209 .41598 Mtetra
.924 .812 .718 r
.3209 .41598 .32211 .41681 .32446 .40871 .32298 .41224 Mtetra
.979 .845 .452 r
.32298 .41224 .32446 .40871 .33917 .19939 .32549 .4016 Mtetra
0 0 .174 r
.32549 .4016 .33917 .19939 .34119 .19459 .33977 .19856 Mtetra
0 0 0 r
.33977 .19856 .34119 .19459 .343 .19329 .34175 .19454 Mtetra
.696 .912 .569 r
.34175 .19454 .343 .19329 .34477 .19262 .34362 .19216 Mtetra
.84 .915 .886 r
.34362 .19216 .34477 .19262 .34652 .19226 .34544 .19059 Mtetra
.675 .678 .845 r
.34544 .19059 .34652 .19226 .34828 .19169 .34722 .18979 Mtetra
.615 .623 .836 r
.34722 .18979 .34828 .19169 .35005 .19118 .34898 .18929 Mtetra
.581 .608 .844 r
.34898 .18929 .35005 .19118 .35181 .19071 .35074 .18896 Mtetra
.597 .635 .859 r
.35074 .18896 .35181 .19071 .35357 .19021 .3525 .18856 Mtetra
.593 .648 .873 r
.3525 .18856 .35357 .19021 .35534 .1897 .35426 .18818 Mtetra
.601 .672 .89 r
.35426 .18818 .35534 .1897 .35711 .18915 .35602 .18777 Mtetra
.639 .71 .898 r
.35602 .18777 .35711 .18915 .35889 .18852 .35779 .18719 Mtetra
.655 .725 .9 r
.35779 .18719 .35889 .18852 .36067 .18785 .35957 .18655 Mtetra
.67 .735 .898 r
.35957 .18655 .36067 .18785 .36245 .18712 .36136 .18583 Mtetra
.733 .755 .871 r
.36136 .18583 .36245 .18712 .36426 .1859 .36316 .18477 Mtetra
.693 .774 .913 r
.36316 .18477 .36426 .1859 .36605 .18508 .36495 .18396 Mtetra
.551 .727 .956 r
.36495 .18396 .36605 .18508 .3678 .18505 .36672 .18367 Mtetra
0 .004 .541 r
.36672 .18367 .3678 .18505 .3693 .18989 .36837 .18547 Mtetra
0 0 .187 r
.36837 .18547 .3693 .18989 .36037 .39921 .3698 .19179 Mtetra
0 0 .213 r
.3698 .19179 .36037 .39921 .362 .40414 .36116 .39635 Mtetra
.211 .137 .55 r
.36116 .39635 .362 .40414 .36388 .40433 .36286 .39998 Mtetra
.321 .292 .67 r
.36286 .39998 .36388 .40433 .36579 .40372 .36467 .40141 Mtetra
.399 .479 .826 r
.36467 .40141 .36579 .40372 .36773 .40267 .36654 .40186 Mtetra
.636 .839 .978 r
.36654 .40186 .36773 .40267 .36966 .40183 .36846 .40119 Mtetra
.733 .893 .952 r
.36846 .40119 .36966 .40183 .3716 .40091 .3704 .40013 Mtetra
.777 .87 .917 r
.3704 .40013 .3716 .40091 .37354 .39994 .37236 .39883 Mtetra
.708 .799 .921 r
.37236 .39883 .37354 .39994 .37547 .39904 .3743 .3979 Mtetra
.695 .789 .923 r
.3743 .3979 .37547 .39904 .37741 .39817 .37624 .39702 Mtetra
.683 .786 .928 r
.37624 .39702 .37741 .39817 .37935 .39733 .37817 .3962 Mtetra
.674 .786 .934 r
.37817 .3962 .37935 .39733 .38128 .39653 .38011 .39542 Mtetra
.659 .785 .941 r
.38011 .39542 .38128 .39653 .38321 .3958 .38204 .39471 Mtetra
.641 .783 .949 r
.38204 .39471 .38321 .3958 .38515 .39514 .38397 .39406 Mtetra
.614 .778 .96 r
.38397 .39406 .38515 .39514 .38708 .39459 .3859 .39351 Mtetra
.594 .772 .964 r
.3859 .39351 .38708 .39459 .389 .39409 .38783 .39303 Mtetra
.577 .769 .97 r
.38783 .39303 .389 .39409 .39093 .39361 .38976 .3926 Mtetra
.26 .621 .959 r
.38976 .3926 .39093 .39361 .39284 .39372 .39166 .39287 Mtetra
.452 .759 .995 r
.39166 .39287 .39284 .39372 .39476 .39339 .39358 .39268 Mtetra
.737 .884 .948 r
.39358 .39268 .39476 .39339 .39673 .39218 .39554 .39159 Mtetra
.966 .799 .624 r
.39554 .39159 .39673 .39218 .3989 .38566 .3977 .3853 Mtetra
.97 .691 .446 r
.3977 .3853 .3989 .38566 .40901 .1736 .40794 .17218 Mtetra
.934 .746 .624 r
.40794 .17218 .40901 .1736 .41103 .16778 .40996 .16614 Mtetra
.772 .72 .804 r
.40996 .16614 .41103 .16778 .41287 .16628 .41181 .16459 Mtetra
.64 .666 .859 r
.41181 .16459 .41287 .16628 .41468 .16569 .41362 .16398 Mtetra
.547 .62 .877 r
.41362 .16398 .41468 .16569 .41648 .16548 .41542 .16378 Mtetra
.603 .648 .867 r
.41542 .16378 .41648 .16548 .41829 .16492 .41723 .16334 Mtetra
.613 .671 .882 r
.41723 .16334 .41829 .16492 .42011 .16429 .41904 .16286 Mtetra
.623 .7 .9 r
.41904 .16286 .42011 .16429 .42193 .16364 .42086 .16234 Mtetra
.711 .753 .885 r
.42086 .16234 .42193 .16364 .42375 .16291 .42269 .1614 Mtetra
.698 .716 .862 r
.42269 .1614 .42375 .16291 .42558 .16218 .42452 .16049 Mtetra
.645 .668 .858 r
.42452 .16049 .42558 .16218 .4274 .1615 .42634 .15984 Mtetra
.419 .562 .891 r
.42634 .15984 .4274 .1615 .42923 .16063 .42814 .16006 Mtetra
.45 0 0 r
.42814 .16006 .42923 .16063 .43105 .16004 .42991 .16124 Mtetra
.8 .381 .252 r
.42991 .16124 .43105 .16004 .43286 .16011 .43161 .16461 Mtetra
.965 .675 .433 r
.43161 .16461 .43286 .16011 .43455 .16406 .4271 .37112 Mtetra
.519 .278 .49 r
.4271 .37112 .43455 .16406 .43012 .37466 .42884 .37775 Mtetra
.664 .279 .308 r
.42884 .37775 .43012 .37466 .4319 .38035 .43072 .37999 Mtetra
.013 .568 .818 r
.43072 .37999 .4319 .38035 .43383 .38094 .43267 .38023 Mtetra
.553 .834 .998 r
.43267 .38023 .43383 .38094 .4358 .38033 .43463 .37974 Mtetra
.653 .893 .982 r
.43463 .37974 .4358 .38033 .43778 .37926 .43661 .37892 Mtetra
.544 .896 .976 r
.43661 .37892 .43778 .37926 .43975 .37851 .43858 .37826 Mtetra
.564 .915 .963 r
.43858 .37826 .43975 .37851 .44173 .37785 .44056 .3775 Mtetra
.696 .943 .96 r
.44056 .3775 .44173 .37785 .4437 .37713 .44255 .37644 Mtetra
.87 .889 .846 r
.44255 .37644 .4437 .37713 .44568 .37625 .44456 .37437 Mtetra
.853 .73 .728 r
.44456 .37437 .44568 .37625 .44767 .37528 .4466 .37132 Mtetra
.798 .608 .645 r
.4466 .37132 .44767 .37528 .44966 .37431 .44866 .36709 Mtetra
.617 .435 .614 r
.44866 .36709 .44966 .37431 .45163 .37397 .45066 .36533 Mtetra
.528 .358 .595 r
.45066 .36533 .45163 .37397 .45361 .37354 .45263 .36515 Mtetra
.573 .393 .599 r
.45263 .36515 .45361 .37354 .4556 .37242 .45462 .36408 Mtetra
.966 .68 .438 r
.45462 .36408 .4556 .37242 .45767 .3676 .46093 .16151 Mtetra
.534 .295 .5 r
.46093 .16151 .45767 .3676 .46397 .15575 .46302 .14963 Mtetra
.722 .516 .611 r
.46302 .14963 .46397 .15575 .46597 .14786 .46494 .14575 Mtetra
.749 .666 .77 r
.46494 .14575 .46597 .14786 .46785 .14575 .46681 .14415 Mtetra
.665 .693 .866 r
.46681 .14415 .46785 .14575 .4697 .14497 .46866 .1434 Mtetra
.607 .673 .888 r
.46866 .1434 .4697 .14497 .47155 .14461 .47051 .14294 Mtetra
.637 .67 .865 r
.47051 .14294 .47155 .14461 .4734 .14405 .47236 .14233 Mtetra
.653 .67 .854 r
.47236 .14233 .4734 .14405 .47526 .14336 .47422 .14162 Mtetra
.653 .669 .853 r
.47422 .14162 .47526 .14336 .47712 .14266 .47608 .14091 Mtetra
.654 .668 .851 r
.47608 .14091 .47712 .14266 .47898 .14196 .47794 .1402 Mtetra
.654 .667 .85 r
.47794 .1402 .47898 .14196 .48084 .14124 .4798 .13948 Mtetra
.4798 .13948 .48084 .14124 .4827 .14052 .48166 .13876 Mtetra
.48166 .13876 .4827 .14052 .48456 .1398 .48353 .13805 Mtetra
.48353 .13805 .48456 .1398 .48643 .13908 .48539 .13733 Mtetra
.654 .667 .851 r
.48539 .13733 .48643 .13908 .48829 .13837 .48726 .13661 Mtetra
.654 .668 .851 r
.48726 .13661 .48829 .13837 .49016 .13765 .48912 .1359 Mtetra
.653 .668 .852 r
.48912 .1359 .49016 .13765 .49203 .13694 .49099 .13519 Mtetra
.652 .668 .852 r
.49099 .13519 .49203 .13694 .4939 .13623 .49286 .13448 Mtetra
.652 .667 .852 r
.49286 .13448 .4939 .13623 .49577 .13553 .49473 .13377 Mtetra
.651 .667 .852 r
.49473 .13377 .49577 .13553 .49764 .13484 .49661 .13307 Mtetra
.649 .666 .852 r
.49661 .13307 .49764 .13484 .49951 .13415 .49848 .13238 Mtetra
.65 .665 .852 r
.49848 .13238 .49951 .13415 .50139 .13348 .50035 .13169 Mtetra
.647 .661 .85 r
.50035 .13169 .50139 .13348 .50326 .13281 .50223 .131 Mtetra
.641 .655 .849 r
.50223 .131 .50326 .13281 .50514 .13215 .50411 .13035 Mtetra
.624 .649 .854 r
.50411 .13035 .50514 .13215 .50702 .13149 .50599 .12979 Mtetra
.612 .658 .871 r
.50599 .12979 .50702 .13149 .5089 .13081 .50787 .12929 Mtetra
.611 .686 .896 r
.50787 .12929 .5089 .13081 .51078 .13014 .50975 .12881 Mtetra
.629 .726 .917 r
.50975 .12881 .51078 .13014 .51266 .12948 .51163 .12824 Mtetra
.648 .751 .925 r
.51163 .12824 .51266 .12948 .51454 .12883 .51351 .12759 Mtetra
.656 .755 .923 r
.51351 .12759 .51454 .12883 .51643 .12818 .5154 .12691 Mtetra
.656 .75 .919 r
.5154 .12691 .51643 .12818 .51831 .12751 .51729 .12623 Mtetra
.656 .747 .917 r
.51729 .12623 .51831 .12751 .5202 .12683 .51917 .12555 Mtetra
.657 .747 .916 r
.51917 .12555 .5202 .12683 .52209 .12615 .52106 .12486 Mtetra
.659 .746 .915 r
.52106 .12486 .52209 .12615 .52398 .12546 .52295 .12416 Mtetra
.66 .746 .914 r
.52295 .12416 .52398 .12546 .52587 .12476 .52485 .12346 Mtetra
.66 .746 .913 r
.52485 .12346 .52587 .12476 .52777 .12405 .52674 .12275 Mtetra
.661 .746 .913 r
.52674 .12275 .52777 .12405 .52966 .12335 .52864 .12204 Mtetra
.662 .746 .913 r
.52864 .12204 .52966 .12335 .53156 .12264 .53053 .12133 Mtetra
.662 .746 .912 r
.53053 .12133 .53156 .12264 .53345 .12192 .53243 .12061 Mtetra
.53243 .12061 .53345 .12192 .53535 .12121 .53433 .1199 Mtetra
.663 .746 .912 r
.53433 .1199 .53535 .12121 .53725 .12049 .53623 .11918 Mtetra
.53623 .11918 .53725 .12049 .53915 .11977 .53813 .11846 Mtetra
.53813 .11846 .53915 .11977 .54105 .11905 .54003 .11774 Mtetra
.54003 .11774 .54105 .11905 .54296 .11833 .54194 .11701 Mtetra
.54194 .11701 .54296 .11833 .54486 .11761 .54384 .11629 Mtetra
.54384 .11629 .54486 .11761 .54677 .11688 .54575 .11557 Mtetra
.663 .746 .911 r
.54575 .11557 .54677 .11688 .54867 .11616 .54766 .11484 Mtetra
.54766 .11484 .54867 .11616 .55058 .11543 .54957 .11411 Mtetra
.54957 .11411 .55058 .11543 .55249 .11471 .55148 .11339 Mtetra
.664 .746 .911 r
.55148 .11339 .55249 .11471 .5544 .11398 .55339 .11266 Mtetra
.55339 .11266 .5544 .11398 .55632 .11325 .55531 .11193 Mtetra
.55531 .11193 .55632 .11325 .55823 .11252 .55722 .1112 Mtetra
.55722 .1112 .55823 .11252 .56015 .1118 .55914 .11047 Mtetra
.55914 .11047 .56015 .1118 .56206 .11107 .56106 .10974 Mtetra
.56106 .10974 .56206 .11107 .56398 .11034 .56297 .10901 Mtetra
.56297 .10901 .56398 .11034 .5659 .10961 .56489 .10828 Mtetra
.56489 .10828 .5659 .10961 .56782 .10888 .56682 .10755 Mtetra
.56682 .10755 .56782 .10888 .56974 .10815 .56874 .10682 Mtetra
.56874 .10682 .56974 .10815 .57167 .10741 .57066 .10608 Mtetra
.57066 .10608 .57167 .10741 .57359 .10668 .57259 .10535 Mtetra
.57259 .10535 .57359 .10668 .57552 .10595 .57452 .10462 Mtetra
.57452 .10462 .57552 .10595 .57744 .10521 .57644 .10388 Mtetra
.57644 .10388 .57744 .10521 .57937 .10448 .57837 .10315 Mtetra
.57837 .10315 .57937 .10448 .5813 .10374 .5803 .10241 Mtetra
.5803 .10241 .5813 .10374 .58323 .10301 .58224 .10167 Mtetra
.58224 .10167 .58323 .10301 .58517 .10227 .58417 .10093 Mtetra
.58417 .10093 .58517 .10227 .5871 .10153 .58611 .10019 Mtetra
.58611 .10019 .5871 .10153 .58904 .1008 .58804 .09946 Mtetra
.58804 .09946 .58904 .1008 .59097 .10006 .58998 .09871 Mtetra
.58998 .09871 .59097 .10006 .59291 .09932 .59192 .09797 Mtetra
.664 .745 .911 r
.59192 .09797 .59291 .09932 .59485 .09858 .59386 .09723 Mtetra
.664 .745 .91 r
.59386 .09723 .59485 .09858 .59679 .09783 .5958 .09649 Mtetra
.665 .745 .91 r
.5958 .09649 .59679 .09783 .59873 .09709 .59774 .09574 Mtetra
.59774 .09574 .59873 .09709 .60068 .09635 .59969 .095 Mtetra
.59969 .095 .60068 .09635 .60262 .0956 .60163 .09425 Mtetra
.60163 .09425 .60262 .0956 .60457 .09486 .60358 .0935 Mtetra
.60358 .0935 .60457 .09486 .60652 .09411 .60553 .09276 Mtetra
.665 .744 .91 r
.60553 .09276 .60652 .09411 .60846 .09337 .60748 .09201 Mtetra
.60748 .09201 .60846 .09337 .61041 .09262 .60943 .09126 Mtetra
.665 .744 .909 r
.60943 .09126 .61041 .09262 .61237 .09187 .61138 .09051 Mtetra
.665 .744 .91 r
.61138 .09051 .61237 .09187 .61432 .09112 .61333 .08976 Mtetra
.664 .744 .91 r
.61333 .08976 .61432 .09112 .61627 .09037 .61529 .08901 Mtetra
.61529 .08901 .61627 .09037 .61823 .08962 .61725 .08826 Mtetra
.664 .745 .91 r
.61725 .08826 .61823 .08962 .62019 .08887 .6192 .08751 Mtetra
.6192 .08751 .62019 .08887 .62214 .08812 .62116 .08676 Mtetra
.62116 .08676 .62214 .08812 .6241 .08737 .62312 .08601 Mtetra
.665 .746 .911 r
.62312 .08601 .6241 .08737 .62606 .08662 .62509 .08526 Mtetra
.62509 .08526 .62606 .08662 .62803 .08586 .62705 .08451 Mtetra
.665 .747 .911 r
.62705 .08451 .62803 .08586 .62999 .08511 .62901 .08375 Mtetra
.62901 .08375 .62999 .08511 .63195 .08435 .63098 .083 Mtetra
.63098 .083 .63195 .08435 .63392 .0836 .63295 .08224 Mtetra
.63295 .08224 .63392 .0836 .63589 .08284 .63492 .08148 Mtetra
.666 .748 .911 r
.63492 .08148 .63589 .08284 .63786 .08208 .63689 .08072 Mtetra
.666 .747 .911 r
.63689 .08072 .63786 .08208 .63983 .08133 .63886 .07996 Mtetra
.666 .747 .91 r
.63886 .07996 .63983 .08133 .6418 .08057 .64083 .0792 Mtetra
.667 .746 .909 r
.64083 .0792 .6418 .08057 .64377 .07981 .6428 .07843 Mtetra
.667 .744 .908 r
.6428 .07843 .64377 .07981 .64575 .07905 .64478 .07766 Mtetra
.665 .742 .907 r
.64478 .07766 .64575 .07905 .64772 .07829 .64676 .0769 Mtetra
.67 .743 .905 r
.64676 .0769 .64772 .07829 .6497 .07753 .64873 .07611 Mtetra
.681 .743 .898 r
.64873 .07611 .6497 .07753 .65168 .07676 .65071 .07527 Mtetra
.698 .739 .883 r
.65071 .07527 .65168 .07676 .65366 .07596 .65268 .07432 Mtetra
.694 .714 .864 r
.65268 .07432 .65366 .07596 .65564 .07516 .65466 .07337 Mtetra
.683 .687 .848 r
.65466 .07337 .65564 .07516 .65762 .07435 .65663 .07244 Mtetra
.664 .664 .839 r
.65663 .07244 .65762 .07435 .6596 .07355 .65861 .0716 Mtetra
.659 .656 .836 r
.65861 .0716 .6596 .07355 .66158 .07275 .6606 .07079 Mtetra
.663 .657 .834 r
.6606 .07079 .66158 .07275 .66357 .07192 .66258 .06994 Mtetra
.688 .667 .824 r
.66258 .06994 .66357 .07192 .66555 .07103 .66456 .06893 Mtetra
.658 .639 .82 r
.66456 .06893 .66555 .07103 .66754 .07017 .66654 .06809 Mtetra
.599 .611 .836 r
.66654 .06809 .66754 .07017 .66952 .06932 .66855 .06762 Mtetra
.379 .542 .891 r
.66855 .06762 .66952 .06932 .6715 .06829 .6706 .06799 Mtetra
.458 0 0 r
.6706 .06799 .6715 .06829 .6735 .06767 .6727 .06928 Mtetra
.791 .352 .206 r
.6727 .06928 .6735 .06767 .67556 .06803 .67494 .07311 Mtetra
.971 .656 .33 r
.67494 .07311 .67556 .06803 .67789 .07364 .68798 .28257 Mtetra
.516 .275 .488 r
.68798 .28257 .67789 .07364 .69137 .28722 .69048 .28831 Mtetra
.649 .143 .03 r
.69048 .28831 .69137 .28722 .6938 .29149 .69278 .2901 Mtetra
.545 .709 .947 r
.69278 .2901 .6938 .29149 .69599 .29139 .69496 .28978 Mtetra
.66 .726 .898 r
.69496 .28978 .69599 .29139 .69815 .29052 .69713 .28897 Mtetra
.679 .743 .899 r
.69713 .28897 .69815 .29052 .7003 .28939 .69928 .28806 Mtetra
.412 .65 .956 r
.69928 .28806 .7003 .28939 .7025 .28932 .7015 .28815 Mtetra
.552 .757 .973 r
.7015 .28815 .7025 .28932 .70468 .28876 .70369 .28775 Mtetra
.779 .87 .915 r
.70369 .28775 .70468 .28876 .70681 .28718 .70582 .28632 Mtetra
.99 .813 .573 r
.70582 .28632 .70681 .28718 .7086 .28006 .70765 .27971 Mtetra
.975 .67 .32 r
.70765 .27971 .7086 .28006 .69786 .06385 .69694 .06295 Mtetra
.988 .807 .573 r
.69694 .06295 .69786 .06385 .69957 .05811 .69863 .05675 Mtetra
.768 .789 .87 r
.69863 .05675 .69957 .05811 .70155 .05679 .70061 .05539 Mtetra
.631 .731 .92 r
.70061 .05539 .70155 .05679 .70358 .05617 .70264 .05477 Mtetra
.543 .688 .933 r
.70264 .05477 .70358 .05617 .70563 .05589 .70469 .0545 Mtetra
.754 .78 .875 r
.70469 .0545 .70563 .05589 .70761 .05463 .70667 .05323 Mtetra
.686 .754 .903 r
.70667 .05323 .70761 .05463 .70962 .05375 .70869 .05235 Mtetra
.492 .661 .936 r
.70869 .05235 .70962 .05375 .71169 .05366 .71075 .05225 Mtetra
.741 .322 0 r
.71075 .05225 .71169 .05366 .71408 .05854 .71315 .05715 Mtetra
.97 .655 .291 r
.71315 .05715 .71408 .05854 .73044 .27361 .72945 .27227 Mtetra
.743 .311 0 r
.72945 .27227 .73044 .27361 .73302 .27863 .73202 .27727 Mtetra
.034 .467 .879 r
.03868 .51152 .03999 .51257 .04152 .51312 .04021 .51207 Mtetra
.646 .765 .935 r
.04021 .51207 .04152 .51312 .04322 .51254 .04191 .51149 Mtetra
.812 .78 .823 r
.04191 .51149 .04322 .51254 .04508 .51082 .04377 .50978 Mtetra
.91 .738 .656 r
.04377 .50978 .04508 .51082 .04756 .50478 .04625 .50377 Mtetra
.937 .686 .534 r
.04625 .50377 .04756 .50478 .07874 .298 .07752 .29695 Mtetra
.91 .732 .648 r
.07752 .29695 .07874 .298 .08111 .29198 .07991 .29088 Mtetra
.778 .764 .841 r
.07991 .29088 .08111 .29198 .08281 .29068 .08161 .28957 Mtetra
.641 .74 .921 r
.08161 .28957 .08281 .29068 .0844 .29016 .08319 .28905 Mtetra
.511 .695 .952 r
.08319 .28905 .0844 .29016 .08593 .29003 .08473 .28891 Mtetra
.746 .759 .864 r
.08473 .28891 .08593 .29003 .0876 .28898 .0864 .28785 Mtetra
.697 .75 .893 r
.0864 .28785 .0876 .28898 .08922 .28821 .08802 .28709 Mtetra
.494 .685 .952 r
.08802 .28709 .08922 .28821 .09076 .28812 .08956 .28699 Mtetra
.922 .532 .225 r
.08956 .28699 .09076 .28812 .09174 .29199 .09054 .29083 Mtetra
.939 .683 .522 r
.09054 .29083 .09174 .29199 .0648 .49739 .06351 .49625 Mtetra
.939 .591 .337 r
.06351 .49625 .0648 .49739 .06561 .50332 .06431 .50222 Mtetra
.224 .574 .941 r
.06431 .50222 .06561 .50332 .06719 .50365 .0659 .50255 Mtetra
.673 .764 .92 r
.0659 .50255 .06719 .50365 .06892 .50295 .06762 .50186 Mtetra
.752 .777 .873 r
.06762 .50186 .06892 .50295 .07071 .50181 .06942 .50071 Mtetra
.492 .708 .966 r
.06942 .50071 .07071 .50181 .07237 .50166 .07107 .50058 Mtetra
.586 .744 .952 r
.07107 .50058 .07237 .50166 .07406 .50128 .07276 .5002 Mtetra
.751 .78 .876 r
.07276 .5002 .07406 .50128 .07585 .50014 .07455 .49907 Mtetra
.908 .743 .665 r
.07455 .49907 .07585 .50014 .07823 .49463 .07693 .49358 Mtetra
.94 .687 .528 r
.07693 .49358 .07823 .49463 .10764 .28763 .10644 .28655 Mtetra
.914 .731 .64 r
.10644 .28655 .10764 .28763 .11004 .28119 .10884 .28008 Mtetra
.795 .765 .825 r
.10884 .28008 .11004 .28119 .11177 .2797 .11058 .27858 Mtetra
.628 .736 .925 r
.11058 .27858 .11177 .2797 .11338 .27922 .11218 .2781 Mtetra
.473 .678 .955 r
.11218 .2781 .11338 .27922 .11492 .27917 .11373 .27804 Mtetra
.621 .733 .927 r
.11373 .27804 .11492 .27917 .11652 .27871 .11533 .27759 Mtetra
.652 .741 .915 r
.11533 .27759 .11652 .27871 .11814 .27815 .11695 .27701 Mtetra
.659 .741 .911 r
.11695 .27701 .11814 .27815 .11976 .27756 .11857 .27641 Mtetra
.751 .758 .858 r
.11857 .27641 .11976 .27756 .12145 .27646 .12026 .27531 Mtetra
.716 .751 .88 r
.12026 .27531 .12145 .27646 .1231 .27559 .12192 .27442 Mtetra
.541 .697 .941 r
.12192 .27442 .1231 .27559 .12468 .2754 .12349 .27421 Mtetra
.911 .507 .168 r
.12349 .27421 .12468 .2754 .12574 .27915 .12458 .27779 Mtetra
.943 .684 .514 r
.12458 .27779 .12574 .27915 .10081 .48571 .09959 .48413 Mtetra
.949 .597 .296 r
.09959 .48413 .10081 .48571 .10174 .49145 .10048 .49015 Mtetra
.168 .499 .907 r
.10048 .49015 .10174 .49145 .10334 .49192 .10207 .49067 Mtetra
.688 .744 .893 r
.10207 .49067 .10334 .49192 .10511 .49109 .10384 .48988 Mtetra
.766 .762 .849 r
.10384 .48988 .10511 .49109 .10694 .48975 .10567 .48856 Mtetra
.604 .733 .936 r
.10567 .48856 .10694 .48975 .10866 .48929 .10739 .48813 Mtetra
.608 .739 .938 r
.10739 .48813 .10866 .48929 .11039 .48883 .10911 .48768 Mtetra
.755 .772 .867 r
.10911 .48768 .11039 .48883 .11221 .48763 .11093 .48649 Mtetra
.91 .742 .662 r
.11093 .48649 .11221 .48763 .11457 .48204 .11329 .48097 Mtetra
.944 .688 .52 r
.11329 .48097 .11457 .48204 .14202 .27361 .14081 .27265 Mtetra
.921 .742 .643 r
.14081 .27265 .14202 .27361 .14433 .26751 .14314 .26647 Mtetra
.835 .778 .797 r
.14314 .26647 .14433 .26751 .14612 .26569 .14494 .26453 Mtetra
.677 .743 .901 r
.14494 .26453 .14612 .26569 .14776 .26509 .14659 .26384 Mtetra
.424 .63 .94 r
.14659 .26384 .14776 .26509 .14932 .2651 .14815 .26392 Mtetra
.508 .008 0 r
.14815 .26392 .14932 .2651 .15085 .26539 .14954 .26533 Mtetra
.892 .517 .32 r
.14954 .26533 .15085 .26539 .15232 .26621 .15058 .26973 Mtetra
.94 .677 .511 r
.15058 .26973 .15232 .26621 .15365 .26826 .12764 .47312 Mtetra
.515 .276 .49 r
.12764 .47312 .15365 .26826 .15325 .28474 .12878 .47761 Mtetra
.508 .269 .488 r
.12878 .47761 .15325 .28474 .13198 .47666 .13031 .47888 Mtetra
.5 .087 .187 r
.13031 .47888 .13198 .47666 .13329 .47976 .13195 .47927 Mtetra
0 .513 .808 r
.13195 .47927 .13329 .47976 .13486 .48081 .13359 .47961 Mtetra
.479 .685 .957 r
.13359 .47961 .13486 .48081 .13655 .48078 .13529 .47953 Mtetra
.705 .751 .888 r
.13529 .47953 .13655 .48078 .13836 .47979 .13709 .47864 Mtetra
.891 .759 .709 r
.13709 .47864 .13836 .47979 .1405 .47591 .13923 .47484 Mtetra
.946 .689 .515 r
.13923 .47484 .1405 .47591 .16587 .27186 .16463 .27118 Mtetra
.943 .726 .579 r
.16463 .27118 .16587 .27186 .16887 .25964 .16769 .25854 Mtetra
.854 .77 .768 r
.16769 .25854 .16887 .25964 .17072 .25731 .16954 .25619 Mtetra
.68 .754 .907 r
.16954 .25619 .17072 .25731 .17238 .25663 .17121 .25549 Mtetra
.533 .703 .948 r
.17121 .25549 .17238 .25663 .17399 .25645 .17282 .25529 Mtetra
.671 .745 .906 r
.17282 .25529 .17399 .25645 .17564 .25591 .17448 .25462 Mtetra
.701 .731 .874 r
.17448 .25462 .17564 .25591 .17731 .25516 .17617 .25379 Mtetra
.606 .686 .899 r
.17617 .25379 .17731 .25516 .17896 .25464 .1778 .25338 Mtetra
0 .122 .635 r
.1778 .25338 .17896 .25464 .18054 .25473 .17926 .25462 Mtetra
.907 .546 .341 r
.17926 .25462 .18054 .25473 .18203 .25566 .18025 .25999 Mtetra
.942 .677 .505 r
.18025 .25999 .18203 .25566 .18335 .25818 .15916 .4639 Mtetra
.514 .274 .489 r
.15916 .4639 .18335 .25818 .16308 .45634 .16045 .46762 Mtetra
.534 .25 .429 r
.16045 .46762 .16308 .45634 .16366 .46661 .16205 .46862 Mtetra
.466 .038 .141 r
.16205 .46862 .16366 .46661 .16507 .46933 .16374 .46887 Mtetra
.076 .605 .869 r
.16374 .46887 .16507 .46933 .16668 .47029 .16543 .46906 Mtetra
.494 .685 .952 r
.16543 .46906 .16668 .47029 .1684 .47023 .16716 .46894 Mtetra
.699 .745 .887 r
.16716 .46894 .1684 .47023 .17023 .46926 .16897 .46807 Mtetra
.884 .763 .723 r
.16897 .46807 .17023 .46926 .17233 .46569 .17106 .46463 Mtetra
.949 .689 .508 r
.17106 .46463 .17233 .46569 .19557 .26393 .19391 .26737 Mtetra
.99 .774 .518 r
.19391 .26737 .19557 .26393 .19886 .24816 .19768 .24719 Mtetra
.877 .785 .756 r
.19768 .24719 .19886 .24816 .20075 .24557 .19957 .24453 Mtetra
.673 .772 .924 r
.19957 .24453 .20075 .24557 .20242 .24495 .20125 .24386 Mtetra
.497 .701 .961 r
.20125 .24386 .20242 .24495 .20404 .24487 .20288 .24373 Mtetra
.565 .716 .943 r
.20288 .24373 .20404 .24487 .20568 .24463 .20452 .24343 Mtetra
.663 .739 .906 r
.20452 .24343 .20568 .24463 .20735 .24402 .2062 .24279 Mtetra
.674 .736 .897 r
.2062 .24279 .20735 .24402 .20904 .24335 .20789 .2421 Mtetra
.739 .748 .86 r
.20789 .2421 .20904 .24335 .21077 .24227 .20962 .24103 Mtetra
.749 .751 .854 r
.20962 .24103 .21077 .24227 .2125 .24112 .21135 .23989 Mtetra
.648 .728 .908 r
.21135 .23989 .2125 .24112 .21418 .24053 .21303 .23931 Mtetra
.545 .053 0 r
.21303 .23931 .21418 .24053 .21563 .24221 .21449 .24093 Mtetra
.952 .685 .492 r
.21449 .24093 .21563 .24221 .19716 .44239 .19631 .43736 Mtetra
.984 .702 .371 r
.19631 .43736 .19716 .44239 .19737 .45765 .19614 .45628 Mtetra
.647 .165 0 r
.19614 .45628 .19737 .45765 .19892 .45956 .19768 .45835 Mtetra
.545 .714 .951 r
.19768 .45835 .19892 .45956 .2007 .45914 .19945 .45809 Mtetra
.762 .8 .883 r
.19945 .45809 .2007 .45914 .20257 .45793 .20131 .45687 Mtetra
.868 .79 .772 r
.20131 .45687 .20257 .45793 .20448 .45623 .20331 .45428 Mtetra
.888 .708 .652 r
.20331 .45428 .20448 .45623 .20644 .45406 .2056 .44871 Mtetra
.948 .684 .503 r
.2056 .44871 .20644 .45406 .20852 .45059 .22731 .2431 Mtetra
.523 .287 .499 r
.22731 .2431 .20852 .45059 .2113 .43984 .22958 .23652 Mtetra
.512 .278 .497 r
.22958 .23652 .2113 .43984 .23224 .23902 .23144 .23419 Mtetra
.644 .483 .65 r
.23144 .23419 .23224 .23902 .23429 .23473 .23322 .2327 Mtetra
.691 .636 .79 r
.23322 .2327 .23429 .23473 .23611 .23277 .23496 .23169 Mtetra
.675 .767 .92 r
.23496 .23169 .23611 .23277 .23783 .232 .23666 .231 Mtetra
.641 .774 .944 r
.23666 .231 .23783 .232 .23951 .23155 .23835 .23044 Mtetra
.705 .768 .902 r
.23835 .23044 .23951 .23155 .24121 .23089 .24007 .2296 Mtetra
.741 .746 .856 r
.24007 .2296 .24121 .23089 .24295 .22989 .24182 .2285 Mtetra
.674 .712 .877 r
.24182 .2285 .24295 .22989 .24466 .2291 .24353 .22778 Mtetra
.234 .517 .912 r
.24353 .22778 .24466 .2291 .24633 .22888 .24513 .22825 Mtetra
.877 .441 .133 r
.24513 .22825 .24633 .22888 .24791 .22957 .24648 .23153 Mtetra
.952 .681 .486 r
.24648 .23153 .24791 .22957 .24939 .23151 .22969 .43512 Mtetra
.522 .281 .491 r
.22969 .43512 .24939 .23151 .2502 .24088 .23077 .4427 Mtetra
.509 .27 .488 r
.23077 .4427 .2502 .24088 .23397 .44161 .2324 .44423 Mtetra
.509 .111 .221 r
.2324 .44423 .23397 .44161 .23544 .44505 .23413 .44469 Mtetra
.332 .782 .955 r
.23413 .44469 .23544 .44505 .23713 .44594 .23593 .44448 Mtetra
.659 .713 .887 r
.23593 .44448 .23713 .44594 .23896 .44533 .23776 .44379 Mtetra
.692 .71 .862 r
.23776 .44379 .23896 .44533 .24083 .4443 .23962 .44289 Mtetra
.628 .71 .905 r
.23962 .44289 .24083 .4443 .24267 .4436 .24145 .44235 Mtetra
.459 .67 .954 r
.24145 .44235 .24267 .4436 .24445 .44356 .24323 .44232 Mtetra
.639 .743 .924 r
.24323 .44232 .24445 .44356 .24629 .44296 .24506 .44172 Mtetra
.856 .776 .772 r
.24506 .44172 .24629 .44296 .24828 .44042 .24706 .43921 Mtetra
.946 .723 .568 r
.24706 .43921 .24828 .44042 .25121 .42685 .24994 .42628 Mtetra
.957 .691 .489 r
.24994 .42628 .25121 .42685 .27016 .22166 .26901 .22065 Mtetra
.905 .779 .711 r
.26901 .22065 .27016 .22166 .27212 .21815 .27098 .21711 Mtetra
.721 .788 .904 r
.27098 .21711 .27212 .21815 .27387 .21722 .27272 .21619 Mtetra
.559 .741 .961 r
.27272 .21619 .27387 .21722 .27556 .2169 .27442 .21587 Mtetra
.486 .713 .971 r
.27442 .21587 .27556 .2169 .27724 .21677 .2761 .21574 Mtetra
.587 .753 .957 r
.2761 .21574 .27724 .21677 .27895 .21641 .27781 .21535 Mtetra
.579 .744 .955 r
.27781 .21535 .27895 .21641 .28065 .21608 .27951 .21498 Mtetra
.59 .74 .947 r
.27951 .21498 .28065 .21608 .28235 .21572 .28122 .21459 Mtetra
.618 .743 .936 r
.28122 .21459 .28235 .21572 .28407 .21525 .28294 .21411 Mtetra
.629 .744 .93 r
.28294 .21411 .28407 .21525 .28579 .21474 .28466 .21358 Mtetra
.637 .745 .927 r
.28466 .21358 .28579 .21474 .28751 .2142 .28638 .21303 Mtetra
.641 .745 .924 r
.28638 .21303 .28751 .2142 .28924 .21365 .28811 .21247 Mtetra
.65 .745 .919 r
.28811 .21247 .28924 .21365 .29097 .21306 .28984 .21186 Mtetra
.663 .746 .912 r
.28984 .21186 .29097 .21306 .2927 .21241 .29158 .2112 Mtetra
.678 .749 .904 r
.29158 .2112 .2927 .21241 .29445 .21169 .29332 .21047 Mtetra
.683 .748 .901 r
.29332 .21047 .29445 .21169 .29619 .21094 .29507 .20972 Mtetra
.715 .756 .885 r
.29507 .20972 .29619 .21094 .29795 .21002 .29683 .2088 Mtetra
.763 .766 .856 r
.29683 .2088 .29795 .21002 .29974 .20877 .29861 .20756 Mtetra
.67 .746 .908 r
.29861 .20756 .29974 .20877 .30148 .20807 .30036 .20687 Mtetra
0 .355 .823 r
.30036 .20687 .30148 .20807 .30311 .20896 .30199 .20774 Mtetra
.961 .659 .411 r
.30199 .20774 .30311 .20896 .29095 .39985 .3022 .22815 Mtetra
0 0 .09 r
.3022 .22815 .29095 .39985 .2909 .4255 .28971 .42415 Mtetra
.737 .266 0 r
.28971 .42415 .2909 .4255 .29254 .42812 .29134 .42682 Mtetra
.581 .717 .936 r
.29134 .42682 .29254 .42812 .29439 .42769 .29319 .42644 Mtetra
.726 .769 .887 r
.29319 .42644 .29439 .42769 .2963 .42659 .29509 .42539 Mtetra
.761 .784 .872 r
.29509 .42539 .2963 .42659 .29822 .42526 .29701 .42411 Mtetra
.681 .776 .923 r
.29701 .42411 .29822 .42526 .30011 .42445 .2989 .42331 Mtetra
.683 .78 .924 r
.2989 .42331 .30011 .42445 .30199 .42364 .30078 .42251 Mtetra
.69 .783 .922 r
.30078 .42251 .30199 .42364 .30388 .4228 .30267 .42168 Mtetra
.709 .79 .915 r
.30267 .42168 .30388 .4228 .30578 .42183 .30457 .42075 Mtetra
.71 .798 .919 r
.30457 .42075 .30578 .42183 .30768 .42086 .30647 .41982 Mtetra
.701 .803 .928 r
.30647 .41982 .30768 .42086 .30958 .41995 .30837 .41893 Mtetra
.668 .8 .946 r
.30837 .41893 .30958 .41995 .31147 .41922 .31026 .4182 Mtetra
.651 .794 .951 r
.31026 .4182 .31147 .41922 .31335 .41857 .31214 .41752 Mtetra
.629 .784 .956 r
.31214 .41752 .31335 .41857 .31523 .41803 .31402 .41694 Mtetra
.58 .757 .962 r
.31402 .41694 .31523 .41803 .31709 .41781 .31589 .41652 Mtetra
.624 .736 .927 r
.31589 .41652 .31709 .41781 .31897 .41727 .31778 .41597 Mtetra
.685 .755 .904 r
.31778 .41597 .31897 .41727 .3209 .41598 .31968 .41515 Mtetra
.786 .855 .902 r
.31968 .41515 .3209 .41598 .32298 .41224 .32161 .4138 Mtetra
0 0 0 r
.32161 .4138 .32298 .41224 .32549 .4016 .32359 .41167 Mtetra
.228 0 .317 r
.32359 .41167 .32549 .4016 .33977 .19856 .32571 .40745 Mtetra
0 0 .179 r
.32571 .40745 .33977 .19856 .34175 .19454 .34025 .19969 Mtetra
0 0 0 r
.34025 .19969 .34175 .19454 .34362 .19216 .34243 .19238 Mtetra
.951 .937 .738 r
.34243 .19238 .34362 .19216 .34544 .19059 .34434 .18933 Mtetra
.723 .756 .879 r
.34434 .18933 .34544 .19059 .34722 .18979 .34613 .18834 Mtetra
.617 .69 .895 r
.34613 .18834 .34722 .18979 .34898 .18929 .34789 .18786 Mtetra
.545 .662 .913 r
.34789 .18786 .34898 .18929 .35074 .18896 .34964 .18764 Mtetra
.602 .707 .917 r
.34964 .18764 .35074 .18896 .3525 .18856 .3514 .18722 Mtetra
.597 .699 .915 r
.3514 .18722 .3525 .18856 .35426 .18818 .35316 .18681 Mtetra
.603 .697 .91 r
.35316 .18681 .35426 .18818 .35602 .18777 .35493 .18638 Mtetra
.635 .708 .899 r
.35493 .18638 .35602 .18777 .35779 .18719 .3567 .18583 Mtetra
.649 .716 .897 r
.3567 .18583 .35779 .18719 .35957 .18655 .35848 .18521 Mtetra
.662 .726 .896 r
.35848 .18521 .35957 .18655 .36136 .18583 .36026 .18453 Mtetra
.702 .744 .884 r
.36026 .18453 .36136 .18583 .36316 .18477 .36206 .18365 Mtetra
.688 .773 .916 r
.36206 .18365 .36316 .18477 .36495 .18396 .36385 .18286 Mtetra
.636 .762 .939 r
.36385 .18286 .36495 .18396 .36672 .18367 .36563 .18229 Mtetra
.517 .66 .925 r
.36563 .18229 .36672 .18367 .36837 .18547 .36739 .18215 Mtetra
.441 .407 .725 r
.36739 .18215 .36837 .18547 .3698 .19179 .36911 .18264 Mtetra
.404 .257 .566 r
.36911 .18264 .3698 .19179 .36116 .39635 .37077 .18451 Mtetra
0 0 .222 r
.37077 .18451 .36116 .39635 .36286 .39998 .36215 .3895 Mtetra
0 0 .39 r
.36215 .3895 .36286 .39998 .36467 .40141 .36359 .39817 Mtetra
0 .097 .63 r
.36359 .39817 .36467 .40141 .36654 .40186 .36536 .40059 Mtetra
.576 .723 .943 r
.36536 .40059 .36654 .40186 .36846 .40119 .36727 .4002 Mtetra
.729 .825 .924 r
.36727 .4002 .36846 .40119 .3704 .40013 .36922 .39916 Mtetra
.789 .838 .889 r
.36922 .39916 .3704 .40013 .37236 .39883 .37118 .39775 Mtetra
.704 .802 .926 r
.37118 .39775 .37236 .39883 .3743 .3979 .37312 .39683 Mtetra
.693 .803 .933 r
.37312 .39683 .3743 .3979 .37624 .39702 .37506 .39596 Mtetra
.683 .802 .939 r
.37506 .39596 .37624 .39702 .37817 .3962 .37699 .39514 Mtetra
.669 .799 .944 r
.37699 .39514 .37817 .3962 .38011 .39542 .37893 .39438 Mtetra
.653 .798 .952 r
.37893 .39438 .38011 .39542 .38204 .39471 .38086 .39368 Mtetra
.635 .796 .96 r
.38086 .39368 .38204 .39471 .38397 .39406 .38279 .39305 Mtetra
.607 .789 .968 r
.38279 .39305 .38397 .39406 .3859 .39351 .38472 .39251 Mtetra
.589 .785 .973 r
.38472 .39251 .3859 .39351 .38783 .39303 .38665 .39203 Mtetra
.575 .78 .976 r
.38665 .39203 .38783 .39303 .38976 .3926 .38858 .39159 Mtetra
.287 .638 .965 r
.38858 .39159 .38976 .3926 .39166 .39287 .39048 .39181 Mtetra
.501 .737 .979 r
.39048 .39181 .39166 .39287 .39358 .39268 .39241 .39159 Mtetra
.735 .81 .911 r
.39241 .39159 .39358 .39268 .39554 .39159 .39437 .3905 Mtetra
.946 .773 .635 r
.39437 .3905 .39554 .39159 .3977 .3853 .39653 .38451 Mtetra
.969 .69 .447 r
.39653 .38451 .3977 .3853 .40794 .17218 .40684 .17146 Mtetra
.963 .783 .613 r
.40684 .17146 .40794 .17218 .40996 .16614 .40888 .16511 Mtetra
.814 .818 .853 r
.40888 .16511 .40996 .16614 .41181 .16459 .41073 .16353 Mtetra
.647 .778 .943 r
.41073 .16353 .41181 .16459 .41362 .16398 .41254 .16291 Mtetra
.512 .724 .969 r
.41254 .16291 .41362 .16398 .41542 .16378 .41434 .1627 Mtetra
.609 .762 .952 r
.41434 .1627 .41542 .16378 .41723 .16334 .41615 .16221 Mtetra
.627 .757 .941 r
.41615 .16221 .41723 .16334 .41904 .16286 .41797 .16166 Mtetra
.637 .748 .929 r
.41797 .16166 .41904 .16286 .42086 .16234 .41979 .16108 Mtetra
.737 .767 .877 r
.41979 .16108 .42086 .16234 .42269 .1614 .42162 .15999 Mtetra
.709 .735 .871 r
.42162 .15999 .42269 .1614 .42452 .16049 .42346 .15904 Mtetra
.612 .693 .901 r
.42346 .15904 .42452 .16049 .42634 .15984 .42528 .15856 Mtetra
0 .085 .61 r
.42528 .15856 .42634 .15984 .42814 .16006 .42703 .16019 Mtetra
.912 .527 .273 r
.42703 .16019 .42814 .16006 .42991 .16124 .42862 .16665 Mtetra
.964 .674 .435 r
.42862 .16665 .42991 .16124 .43161 .16461 .42387 .37466 Mtetra
.511 .272 .488 r
.42387 .37466 .43161 .16461 .4271 .37112 .42571 .37772 Mtetra
.54 .22 .374 r
.42571 .37772 .4271 .37112 .42884 .37775 .42763 .37867 Mtetra
.368 0 0 r
.42763 .37867 .42884 .37775 .43072 .37999 .42957 .37888 Mtetra
.506 .731 .975 r
.42957 .37888 .43072 .37999 .43267 .38023 .43153 .37866 Mtetra
.609 .69 .901 r
.43153 .37866 .43267 .38023 .43463 .37974 .43349 .37816 Mtetra
.647 .704 .888 r
.43349 .37816 .43463 .37974 .43661 .37892 .43547 .37747 Mtetra
.598 .707 .92 r
.43547 .37747 .43661 .37892 .43858 .37826 .43744 .37701 Mtetra
.64 .759 .935 r
.43744 .37701 .43858 .37826 .44056 .3775 .43941 .37637 Mtetra
.744 .81 .905 r
.43941 .37637 .44056 .3775 .44255 .37644 .4414 .37521 Mtetra
.903 .796 .733 r
.4414 .37521 .44255 .37644 .44456 .37437 .44345 .37187 Mtetra
.92 .703 .593 r
.44345 .37187 .44456 .37437 .4466 .37132 .44562 .36366 Mtetra
.966 .681 .439 r
.44562 .36366 .4466 .37132 .44866 .36709 .45265 .1544 Mtetra
.513 .278 .496 r
.45265 .1544 .44866 .36709 .45066 .36533 .45455 .15153 Mtetra
.508 .274 .495 r
.45455 .15153 .45066 .36533 .45263 .36515 .4564 .1509 Mtetra
.507 .274 .495 r
.4564 .1509 .45263 .36515 .45462 .36408 .45824 .15062 Mtetra
.511 .277 .496 r
.45824 .15062 .45462 .36408 .46093 .16151 .46012 .14856 Mtetra
.589 .377 .561 r
.46012 .14856 .46093 .16151 .46302 .14963 .46201 .14622 Mtetra
.711 .569 .693 r
.46201 .14622 .46302 .14963 .46494 .14575 .46389 .14432 Mtetra
.732 .743 .861 r
.46389 .14432 .46494 .14575 .46681 .14415 .46575 .14321 Mtetra
.664 .814 .956 r
.46575 .14321 .46681 .14415 .46866 .1434 .4676 .14249 Mtetra
.621 .809 .972 r
.4676 .14249 .46866 .1434 .47051 .14294 .46946 .14192 Mtetra
.651 .794 .951 r
.46946 .14192 .47051 .14294 .47236 .14233 .47131 .14126 Mtetra
.666 .789 .94 r
.47131 .14126 .47236 .14233 .47422 .14162 .47317 .14055 Mtetra
.666 .788 .939 r
.47317 .14055 .47422 .14162 .47608 .14091 .47503 .13983 Mtetra
.667 .786 .937 r
.47503 .13983 .47608 .14091 .47794 .1402 .47689 .13911 Mtetra
.667 .785 .937 r
.47689 .13911 .47794 .1402 .4798 .13948 .47875 .13839 Mtetra
.667 .784 .936 r
.47875 .13839 .4798 .13948 .48166 .13876 .48062 .13766 Mtetra
.667 .783 .936 r
.48062 .13766 .48166 .13876 .48353 .13805 .48248 .13694 Mtetra
.666 .783 .936 r
.48248 .13694 .48353 .13805 .48539 .13733 .48435 .13622 Mtetra
.48435 .13622 .48539 .13733 .48726 .13661 .48621 .13551 Mtetra
.665 .782 .936 r
.48621 .13551 .48726 .13661 .48912 .1359 .48808 .13479 Mtetra
.664 .782 .937 r
.48808 .13479 .48912 .1359 .49099 .13519 .48995 .13408 Mtetra
.663 .782 .937 r
.48995 .13408 .49099 .13519 .49286 .13448 .49182 .13337 Mtetra
.662 .782 .938 r
.49182 .13337 .49286 .13448 .49473 .13377 .49369 .13267 Mtetra
.661 .782 .938 r
.49369 .13267 .49473 .13377 .49661 .13307 .49557 .13197 Mtetra
.66 .781 .938 r
.49557 .13197 .49661 .13307 .49848 .13238 .49744 .13127 Mtetra
.49744 .13127 .49848 .13238 .50035 .13169 .49932 .13058 Mtetra
.658 .78 .938 r
.49932 .13058 .50035 .13169 .50223 .131 .50119 .12989 Mtetra
.652 .777 .94 r
.50119 .12989 .50223 .131 .50411 .13035 .50307 .12922 Mtetra
.633 .768 .944 r
.50307 .12922 .50411 .13035 .50599 .12979 .50495 .12863 Mtetra
.619 .757 .944 r
.50495 .12863 .50599 .12979 .50787 .12929 .50683 .12809 Mtetra
.619 .748 .938 r
.50683 .12809 .50787 .12929 .50975 .12881 .50871 .12756 Mtetra
.636 .745 .927 r
.50871 .12756 .50975 .12881 .51163 .12824 .5106 .12696 Mtetra
.651 .745 .918 r
.5106 .12696 .51163 .12824 .51351 .12759 .51248 .1263 Mtetra
.657 .745 .915 r
.51248 .1263 .51351 .12759 .5154 .12691 .51437 .12561 Mtetra
.657 .744 .914 r
.51437 .12561 .5154 .12691 .51729 .12623 .51626 .12492 Mtetra
.657 .743 .913 r
.51626 .12492 .51729 .12623 .51917 .12555 .51815 .12423 Mtetra
.658 .742 .912 r
.51815 .12423 .51917 .12555 .52106 .12486 .52004 .12354 Mtetra
.659 .742 .911 r
.52004 .12354 .52106 .12486 .52295 .12416 .52193 .12284 Mtetra
.66 .742 .91 r
.52193 .12284 .52295 .12416 .52485 .12346 .52382 .12213 Mtetra
.661 .741 .91 r
.52382 .12213 .52485 .12346 .52674 .12275 .52572 .12142 Mtetra
.661 .741 .909 r
.52572 .12142 .52674 .12275 .52864 .12204 .52761 .12071 Mtetra
.662 .741 .909 r
.52761 .12071 .52864 .12204 .53053 .12133 .52951 .12 Mtetra
.52951 .12 .53053 .12133 .53243 .12061 .53141 .11928 Mtetra
.662 .741 .908 r
.53141 .11928 .53243 .12061 .53433 .1199 .53331 .11856 Mtetra
.53331 .11856 .53433 .1199 .53623 .11918 .53521 .11784 Mtetra
.663 .741 .908 r
.53521 .11784 .53623 .11918 .53813 .11846 .53711 .11712 Mtetra
.53711 .11712 .53813 .11846 .54003 .11774 .53902 .11639 Mtetra
.53902 .11639 .54003 .11774 .54194 .11701 .54092 .11567 Mtetra
.54092 .11567 .54194 .11701 .54384 .11629 .54283 .11495 Mtetra
.54283 .11495 .54384 .11629 .54575 .11557 .54474 .11422 Mtetra
.54474 .11422 .54575 .11557 .54766 .11484 .54664 .11349 Mtetra
.54664 .11349 .54766 .11484 .54957 .11411 .54855 .11277 Mtetra
.54855 .11277 .54957 .11411 .55148 .11339 .55047 .11204 Mtetra
.55047 .11204 .55148 .11339 .55339 .11266 .55238 .11131 Mtetra
.55238 .11131 .55339 .11266 .55531 .11193 .55429 .11058 Mtetra
.55429 .11058 .55531 .11193 .55722 .1112 .55621 .10985 Mtetra
.55621 .10985 .55722 .1112 .55914 .11047 .55813 .10912 Mtetra
.55813 .10912 .55914 .11047 .56106 .10974 .56005 .10839 Mtetra
.56005 .10839 .56106 .10974 .56297 .10901 .56197 .10766 Mtetra
.56197 .10766 .56297 .10901 .56489 .10828 .56389 .10693 Mtetra
.56389 .10693 .56489 .10828 .56682 .10755 .56581 .10619 Mtetra
.56581 .10619 .56682 .10755 .56874 .10682 .56773 .10546 Mtetra
.56773 .10546 .56874 .10682 .57066 .10608 .56966 .10473 Mtetra
.56966 .10473 .57066 .10608 .57259 .10535 .57158 .10399 Mtetra
.57158 .10399 .57259 .10535 .57452 .10462 .57351 .10326 Mtetra
.663 .741 .907 r
.57351 .10326 .57452 .10462 .57644 .10388 .57544 .10252 Mtetra
.664 .741 .907 r
.57544 .10252 .57644 .10388 .57837 .10315 .57737 .10178 Mtetra
.57737 .10178 .57837 .10315 .5803 .10241 .5793 .10104 Mtetra
.5793 .10104 .5803 .10241 .58224 .10167 .58124 .10031 Mtetra
.58124 .10031 .58224 .10167 .58417 .10093 .58317 .09957 Mtetra
.58317 .09957 .58417 .10093 .58611 .10019 .58511 .09883 Mtetra
.58511 .09883 .58611 .10019 .58804 .09946 .58704 .09809 Mtetra
.58704 .09809 .58804 .09946 .58998 .09871 .58898 .09734 Mtetra
.664 .74 .907 r
.58898 .09734 .58998 .09871 .59192 .09797 .59092 .0966 Mtetra
.59092 .0966 .59192 .09797 .59386 .09723 .59286 .09586 Mtetra
.59286 .09586 .59386 .09723 .5958 .09649 .59481 .09511 Mtetra
.664 .74 .906 r
.59481 .09511 .5958 .09649 .59774 .09574 .59675 .09436 Mtetra
.665 .74 .906 r
.59675 .09436 .59774 .09574 .59969 .095 .59869 .09362 Mtetra
.59869 .09362 .59969 .095 .60163 .09425 .60064 .09287 Mtetra
.60064 .09287 .60163 .09425 .60358 .0935 .60259 .09212 Mtetra
.665 .739 .906 r
.60259 .09212 .60358 .0935 .60553 .09276 .60454 .09137 Mtetra
.60454 .09137 .60553 .09276 .60748 .09201 .60649 .09062 Mtetra
.664 .739 .906 r
.60649 .09062 .60748 .09201 .60943 .09126 .60844 .08987 Mtetra
.60844 .08987 .60943 .09126 .61138 .09051 .61039 .08912 Mtetra
.61039 .08912 .61138 .09051 .61333 .08976 .61235 .08837 Mtetra
.61235 .08837 .61333 .08976 .61529 .08901 .6143 .08762 Mtetra
.6143 .08762 .61529 .08901 .61725 .08826 .61626 .08687 Mtetra
.61626 .08687 .61725 .08826 .6192 .08751 .61822 .08612 Mtetra
.61822 .08612 .6192 .08751 .62116 .08676 .62018 .08537 Mtetra
.62018 .08537 .62116 .08676 .62312 .08601 .62214 .08462 Mtetra
.664 .74 .907 r
.62214 .08462 .62312 .08601 .62509 .08526 .62411 .08387 Mtetra
.62411 .08387 .62509 .08526 .62705 .08451 .62607 .08312 Mtetra
.664 .741 .907 r
.62607 .08312 .62705 .08451 .62901 .08375 .62804 .08237 Mtetra
.62804 .08237 .62901 .08375 .63098 .083 .63 .08161 Mtetra
.665 .742 .907 r
.63 .08161 .63098 .083 .63295 .08224 .63197 .08086 Mtetra
.63197 .08086 .63295 .08224 .63492 .08148 .63394 .0801 Mtetra
.666 .742 .907 r
.63394 .0801 .63492 .08148 .63689 .08072 .63591 .07933 Mtetra
.63591 .07933 .63689 .08072 .63886 .07996 .63788 .07857 Mtetra
.667 .742 .906 r
.63788 .07857 .63886 .07996 .64083 .0792 .63986 .07779 Mtetra
.668 .741 .905 r
.63986 .07779 .64083 .0792 .6428 .07843 .64183 .07702 Mtetra
.669 .74 .903 r
.64183 .07702 .6428 .07843 .64478 .07766 .64381 .07623 Mtetra
.668 .737 .902 r
.64381 .07623 .64478 .07766 .64676 .0769 .64578 .07545 Mtetra
.673 .736 .898 r
.64578 .07545 .64676 .0769 .64873 .07611 .64776 .07465 Mtetra
.682 .737 .892 r
.64776 .07465 .64873 .07611 .65071 .07527 .64974 .07379 Mtetra
.698 .741 .885 r
.64974 .07379 .65071 .07527 .65268 .07432 .65171 .07285 Mtetra
.699 .742 .885 r
.65171 .07285 .65268 .07432 .65466 .07337 .65369 .0719 Mtetra
.695 .741 .887 r
.65369 .0719 .65466 .07337 .65663 .07244 .65566 .07097 Mtetra
.681 .735 .892 r
.65566 .07097 .65663 .07244 .65861 .0716 .65764 .07011 Mtetra
.676 .731 .891 r
.65764 .07011 .65861 .0716 .6606 .07079 .65963 .06928 Mtetra
.684 .732 .887 r
.65963 .06928 .6606 .07079 .66258 .06994 .66161 .06841 Mtetra
.725 .744 .866 r
.66161 .06841 .66258 .06994 .66456 .06893 .66358 .06728 Mtetra
.67 .704 .872 r
.66358 .06728 .66456 .06893 .66654 .06809 .66557 .06646 Mtetra
.517 .631 .903 r
.66557 .06646 .66654 .06809 .66855 .06762 .6676 .06633 Mtetra
0 .031 .57 r
.6676 .06633 .66855 .06762 .6706 .06799 .66974 .06858 Mtetra
.923 .535 .226 r
.66974 .06858 .6706 .06799 .6727 .06928 .67229 .07871 Mtetra
.969 .652 .342 r
.67229 .07871 .6727 .06928 .67494 .07311 .68503 .28615 Mtetra
.509 .27 .487 r
.68503 .28615 .67494 .07311 .68798 .28257 .68733 .28821 Mtetra
.514 .178 .335 r
.68733 .28821 .68798 .28257 .69048 .28831 .68956 .28881 Mtetra
.153 0 0 r
.68956 .28881 .69048 .28831 .69278 .2901 .69176 .28872 Mtetra
.6 .739 .942 r
.69176 .28872 .69278 .2901 .69496 .28978 .69393 .28818 Mtetra
.647 .722 .903 r
.69393 .28818 .69496 .28978 .69713 .28897 .6961 .28744 Mtetra
.643 .731 .913 r
.6961 .28744 .69713 .28897 .69928 .28806 .69827 .28671 Mtetra
.417 .651 .955 r
.69827 .28671 .69928 .28806 .7015 .28815 .70049 .2868 Mtetra
.567 .728 .95 r
.70049 .2868 .7015 .28815 .70369 .28775 .70268 .28638 Mtetra
.768 .806 .884 r
.70268 .28638 .70369 .28775 .70582 .28632 .70481 .28496 Mtetra
.975 .786 .587 r
.70481 .28496 .70582 .28632 .70765 .27971 .70665 .2784 Mtetra
.975 .669 .322 r
.70665 .2784 .70765 .27971 .69694 .06295 .696 .06164 Mtetra
.975 .782 .582 r
.696 .06164 .69694 .06295 .69863 .05675 .69769 .05539 Mtetra
.77 .79 .87 r
.69769 .05539 .69863 .05675 .70061 .05539 .69967 .05402 Mtetra
.632 .736 .923 r
.69967 .05402 .70061 .05539 .70264 .05477 .7017 .05339 Mtetra
.544 .693 .937 r
.7017 .05339 .70264 .05477 .70469 .0545 .70375 .05311 Mtetra
.755 .782 .875 r
.70375 .05311 .70469 .0545 .70667 .05323 .70574 .05183 Mtetra
.687 .755 .904 r
.70574 .05183 .70667 .05323 .70869 .05235 .70775 .05094 Mtetra
.492 .661 .937 r
.70775 .05094 .70869 .05235 .71075 .05225 .70982 .05085 Mtetra
.742 .324 0 r
.70982 .05085 .71075 .05225 .71315 .05715 .71221 .05577 Mtetra
.97 .655 .291 r
.71221 .05577 .71315 .05715 .72945 .27227 .72845 .27092 Mtetra
.742 .31 0 r
.72845 .27092 .72945 .27227 .73202 .27727 .73102 .2759 Mtetra
.036 .468 .88 r
.03737 .51046 .03868 .51152 .04021 .51207 .0389 .51101 Mtetra
.646 .764 .935 r
.0389 .51101 .04021 .51207 .04191 .51149 .0406 .51043 Mtetra
.811 .78 .823 r
.0406 .51043 .04191 .51149 .04377 .50978 .04246 .50872 Mtetra
.909 .738 .657 r
.04246 .50872 .04377 .50978 .04625 .50377 .04493 .50276 Mtetra
.937 .686 .534 r
.04493 .50276 .04625 .50377 .07752 .29695 .0763 .2959 Mtetra
.91 .731 .647 r
.0763 .2959 .07752 .29695 .07991 .29088 .0787 .28978 Mtetra
.778 .764 .84 r
.0787 .28978 .07991 .29088 .08161 .28957 .0804 .28847 Mtetra
.642 .74 .92 r
.0804 .28847 .08161 .28957 .08319 .28905 .08199 .28794 Mtetra
.513 .696 .952 r
.08199 .28794 .08319 .28905 .08473 .28891 .08353 .28779 Mtetra
.746 .759 .863 r
.08353 .28779 .08473 .28891 .0864 .28785 .08519 .28673 Mtetra
.698 .75 .892 r
.08519 .28673 .0864 .28785 .08802 .28709 .08682 .28596 Mtetra
.495 .686 .952 r
.08682 .28596 .08802 .28709 .08956 .28699 .08836 .28585 Mtetra
.921 .531 .224 r
.08836 .28585 .08956 .28699 .09054 .29083 .08934 .28968 Mtetra
.939 .683 .522 r
.08934 .28968 .09054 .29083 .06351 .49625 .06222 .49512 Mtetra
.938 .591 .338 r
.06222 .49512 .06351 .49625 .06431 .50222 .06301 .50112 Mtetra
.22 .572 .94 r
.06301 .50112 .06431 .50222 .0659 .50255 .0646 .50146 Mtetra
.672 .765 .92 r
.0646 .50146 .0659 .50255 .06762 .50186 .06633 .50077 Mtetra
.752 .778 .874 r
.06633 .50077 .06762 .50186 .06942 .50071 .06812 .49963 Mtetra
.49 .708 .967 r
.06812 .49963 .06942 .50071 .07107 .50058 .06977 .4995 Mtetra
.585 .744 .952 r
.06977 .4995 .07107 .50058 .07276 .5002 .07146 .49912 Mtetra
.751 .78 .877 r
.07146 .49912 .07276 .5002 .07455 .49907 .07326 .49799 Mtetra
.908 .743 .665 r
.07326 .49799 .07455 .49907 .07693 .49358 .07564 .49251 Mtetra
.94 .687 .528 r
.07564 .49251 .07693 .49358 .10644 .28655 .10524 .28544 Mtetra
.914 .73 .639 r
.10524 .28544 .10644 .28655 .10884 .28008 .10765 .27895 Mtetra
.795 .763 .824 r
.10765 .27895 .10884 .28008 .11058 .27858 .10939 .27745 Mtetra
.629 .734 .923 r
.10939 .27745 .11058 .27858 .11218 .2781 .11099 .27697 Mtetra
.475 .677 .954 r
.11099 .27697 .11218 .2781 .11373 .27804 .11254 .27691 Mtetra
.622 .731 .925 r
.11254 .27691 .11373 .27804 .11533 .27759 .11414 .27644 Mtetra
.653 .739 .913 r
.11414 .27644 .11533 .27759 .11695 .27701 .11576 .27587 Mtetra
.66 .74 .909 r
.11576 .27587 .11695 .27701 .11857 .27641 .11738 .27526 Mtetra
.75 .757 .858 r
.11738 .27526 .11857 .27641 .12026 .27531 .11907 .27416 Mtetra
.717 .753 .88 r
.11907 .27416 .12026 .27531 .12192 .27442 .12073 .27327 Mtetra
.551 .704 .941 r
.12073 .27327 .12192 .27442 .12349 .27421 .12231 .27303 Mtetra
.899 .481 .128 r
.12231 .27303 .12349 .27421 .12458 .27779 .12343 .27631 Mtetra
.943 .684 .514 r
.12343 .27631 .12458 .27779 .09959 .48413 .09846 .48188 Mtetra
.96 .623 .282 r
.09846 .48188 .09959 .48413 .10048 .49015 .09925 .48856 Mtetra
.168 .443 .874 r
.09925 .48856 .10048 .49015 .10207 .49067 .10083 .48922 Mtetra
.661 .705 .88 r
.10083 .48922 .10207 .49067 .10384 .48988 .10258 .48855 Mtetra
.745 .744 .85 r
.10258 .48855 .10384 .48988 .10567 .48856 .1044 .48736 Mtetra
.59 .725 .937 r
.1044 .48736 .10567 .48856 .10739 .48813 .10611 .48698 Mtetra
.607 .74 .939 r
.10611 .48698 .10739 .48813 .10911 .48768 .10784 .48653 Mtetra
.755 .773 .868 r
.10784 .48653 .10911 .48768 .11093 .48649 .10965 .48534 Mtetra
.908 .744 .666 r
.10965 .48534 .11093 .48649 .11329 .48097 .11199 .48002 Mtetra
.944 .688 .52 r
.11199 .48002 .11329 .48097 .14081 .27265 .13956 .27203 Mtetra
.934 .757 .639 r
.13956 .27203 .14081 .27265 .14314 .26647 .14192 .26559 Mtetra
.856 .797 .793 r
.14192 .26559 .14314 .26647 .14494 .26453 .14375 .26347 Mtetra
.709 .769 .899 r
.14375 .26347 .14494 .26453 .14659 .26384 .14542 .26263 Mtetra
.426 .641 .947 r
.14542 .26263 .14659 .26384 .14815 .26392 .14697 .26269 Mtetra
.816 .354 0 r
.14697 .26269 .14815 .26392 .14954 .26533 .14824 .26514 Mtetra
.945 .683 .509 r
.14824 .26514 .14954 .26533 .15058 .26973 .1254 .46612 Mtetra
.534 .291 .494 r
.1254 .46612 .15058 .26973 .12764 .47312 .12556 .47864 Mtetra
.578 .254 .383 r
.12556 .47864 .12764 .47312 .12878 .47761 .12708 .47997 Mtetra
.336 0 .099 r
.12708 .47997 .12878 .47761 .13031 .47888 .12881 .47959 Mtetra
.38 .82 .676 r
.12881 .47959 .13031 .47888 .13195 .47927 .13062 .47862 Mtetra
.584 .837 .993 r
.13062 .47862 .13195 .47927 .13359 .47961 .13236 .47813 Mtetra
.625 .69 .891 r
.13236 .47813 .13359 .47961 .13529 .47953 .13411 .47762 Mtetra
.716 .667 .801 r
.13411 .47762 .13529 .47953 .13709 .47864 .13594 .47643 Mtetra
.853 .686 .674 r
.13594 .47643 .13709 .47864 .13923 .47484 .13815 .47206 Mtetra
.944 .687 .516 r
.13815 .47206 .13923 .47484 .16463 .27118 .16396 .26568 Mtetra
.822 .598 .599 r
.16396 .26568 .16463 .27118 .16769 .25854 .16653 .25726 Mtetra
.833 .749 .771 r
.16653 .25726 .16769 .25854 .16954 .25619 .16836 .2551 Mtetra
.681 .76 .911 r
.16836 .2551 .16954 .25619 .17121 .25549 .17003 .2544 Mtetra
.55 .719 .951 r
.17003 .2544 .17121 .25549 .17282 .25529 .17165 .25414 Mtetra
.699 .754 .894 r
.17165 .25414 .17282 .25529 .17448 .25462 .17333 .25334 Mtetra
.716 .735 .866 r
.17333 .25334 .17448 .25462 .17617 .25379 .17502 .25241 Mtetra
.589 .68 .904 r
.17502 .25241 .17617 .25379 .1778 .25338 .17665 .25207 Mtetra
.763 .294 0 r
.17665 .25207 .1778 .25338 .17926 .25462 .17798 .25437 Mtetra
.948 .683 .502 r
.17798 .25437 .17926 .25462 .18025 .25999 .15666 .45863 Mtetra
.527 .285 .492 r
.15666 .45863 .18025 .25999 .15916 .4639 .15728 .46828 Mtetra
.596 .254 .36 r
.15728 .46828 .15916 .4639 .16045 .46762 .15883 .46971 Mtetra
.307 0 .048 r
.15883 .46971 .16045 .46762 .16205 .46862 .16059 .4693 Mtetra
.391 .828 .686 r
.16059 .4693 .16205 .46862 .16374 .46887 .16241 .46832 Mtetra
.636 .873 .986 r
.16241 .46832 .16374 .46887 .16543 .46906 .1642 .46765 Mtetra
.635 .708 .899 r
.1642 .46765 .16543 .46906 .16716 .46894 .16598 .46709 Mtetra
.717 .675 .809 r
.16598 .46709 .16716 .46894 .16897 .46807 .16782 .46592 Mtetra
.844 .689 .689 r
.16782 .46592 .16897 .46807 .17106 .46463 .16995 .46214 Mtetra
.948 .688 .509 r
.16995 .46214 .17106 .46463 .19391 .26737 .19364 .25784 Mtetra
.795 .556 .575 r
.19364 .25784 .19391 .26737 .19768 .24719 .19649 .24628 Mtetra
.877 .794 .765 r
.19649 .24628 .19768 .24719 .19957 .24453 .19837 .24372 Mtetra
.7 .823 .941 r
.19837 .24372 .19957 .24453 .20125 .24386 .20007 .24293 Mtetra
.552 .758 .973 r
.20007 .24293 .20125 .24386 .20288 .24373 .20171 .24263 Mtetra
.616 .743 .937 r
.20171 .24263 .20288 .24373 .20452 .24343 .20337 .24217 Mtetra
.68 .732 .889 r
.20337 .24217 .20452 .24343 .2062 .24279 .20506 .24144 Mtetra
.67 .714 .882 r
.20506 .24144 .2062 .24279 .20789 .2421 .20675 .24075 Mtetra
.695 .722 .871 r
.20675 .24075 .20789 .2421 .20962 .24103 .20845 .23993 Mtetra
.69 .765 .909 r
.20845 .23993 .20962 .24103 .21135 .23989 .21015 .23918 Mtetra
.475 .778 .997 r
.21015 .23918 .21135 .23989 .21303 .23931 .21179 .23896 Mtetra
.783 .284 .002 r
.21179 .23896 .21303 .23931 .21449 .24093 .21321 .24096 Mtetra
.951 .683 .493 r
.21321 .24096 .21449 .24093 .19631 .43736 .19431 .44366 Mtetra
.815 .509 .472 r
.19431 .44366 .19631 .43736 .19614 .45628 .19492 .45488 Mtetra
.627 .146 0 r
.19492 .45488 .19614 .45628 .19768 .45835 .19646 .45691 Mtetra
.484 .644 .927 r
.19646 .45691 .19768 .45835 .19945 .45809 .19821 .45687 Mtetra
.736 .768 .879 r
.19821 .45687 .19945 .45809 .20131 .45687 .20006 .45578 Mtetra
.888 .779 .735 r
.20006 .45578 .20131 .45687 .20331 .45428 .20213 .45253 Mtetra
.934 .706 .568 r
.20213 .45253 .20331 .45428 .2056 .44871 .20531 .43789 Mtetra
.942 .677 .506 r
.20531 .43789 .2056 .44871 .22731 .2431 .22681 .23524 Mtetra
.665 .461 .599 r
.22681 .23524 .22731 .2431 .22958 .23652 .22875 .2321 Mtetra
.606 .467 .665 r
.22875 .2321 .22958 .23652 .23144 .23419 .23046 .23124 Mtetra
.57 .503 .741 r
.23046 .23124 .23144 .23419 .23322 .2327 .23213 .23093 Mtetra
.589 .621 .852 r
.23213 .23093 .23322 .2327 .23496 .23169 .2338 .23058 Mtetra
.668 .758 .918 r
.2338 .23058 .23496 .23169 .23666 .231 .2355 .22991 Mtetra
.662 .763 .925 r
.2355 .22991 .23666 .231 .23835 .23044 .23721 .22928 Mtetra
.691 .756 .901 r
.23721 .22928 .23835 .23044 .24007 .2296 .23892 .2285 Mtetra
.703 .77 .904 r
.23892 .2285 .24007 .2296 .24182 .2285 .24064 .22768 Mtetra
.548 .782 .986 r
.24064 .22768 .24182 .2285 .24353 .22778 .24232 .22734 Mtetra
.679 .13 0 r
.24232 .22734 .24353 .22778 .24513 .22825 .24383 .22885 Mtetra
.953 .682 .485 r
.24383 .22885 .24513 .22825 .24648 .23153 .22834 .41596 Mtetra
.565 .318 .499 r
.22834 .41596 .24648 .23153 .22969 .43512 .22764 .44294 Mtetra
.597 .29 .419 r
.22764 .44294 .22969 .43512 .23077 .4427 .22921 .44514 Mtetra
.35 0 .114 r
.22921 .44514 .23077 .4427 .2324 .44423 .23101 .44477 Mtetra
.427 .857 .732 r
.23101 .44477 .2324 .44423 .23413 .44469 .23287 .44379 Mtetra
.733 .829 .924 r
.23287 .44379 .23413 .44469 .23593 .44448 .23474 .44277 Mtetra
.644 .671 .861 r
.23474 .44277 .23593 .44448 .23776 .44379 .23657 .44213 Mtetra
.652 .682 .865 r
.23657 .44213 .23776 .44379 .23962 .44289 .23841 .44145 Mtetra
.631 .706 .9 r
.23841 .44145 .23962 .44289 .24145 .44235 .24024 .44089 Mtetra
.607 .695 .906 r
.24024 .44089 .24145 .44235 .24323 .44232 .24206 .44043 Mtetra
.696 .67 .821 r
.24206 .44043 .24323 .44232 .24506 .44172 .24393 .43941 Mtetra
.817 .677 .708 r
.24393 .43941 .24506 .44172 .24706 .43921 .24597 .43638 Mtetra
.955 .688 .491 r
.24597 .43638 .24706 .43921 .24994 .42628 .26484 .23548 Mtetra
.547 .307 .504 r
.26484 .23548 .24994 .42628 .26901 .22065 .26788 .21941 Mtetra
.882 .761 .723 r
.26788 .21941 .26901 .22065 .27098 .21711 .26981 .21624 Mtetra
.711 .822 .934 r
.26981 .21624 .27098 .21711 .27272 .21619 .27155 .21539 Mtetra
.526 .782 .991 r
.27155 .21539 .27272 .21619 .27442 .21587 .27325 .21509 Mtetra
.464 .76 .994 r
.27325 .21509 .27442 .21587 .2761 .21574 .27494 .21491 Mtetra
.611 .806 .975 r
.27494 .21491 .2761 .21574 .27781 .21535 .27665 .21441 Mtetra
.616 .783 .961 r
.27665 .21441 .27781 .21535 .27951 .21498 .27837 .21391 Mtetra
.622 .757 .943 r
.27837 .21391 .27951 .21498 .28122 .21459 .28009 .21341 Mtetra
.628 .737 .926 r
.28009 .21341 .28122 .21459 .28294 .21411 .28181 .21289 Mtetra
.633 .732 .92 r
.28181 .21289 .28294 .21411 .28466 .21358 .28353 .21236 Mtetra
.638 .732 .916 r
.28353 .21236 .28466 .21358 .28638 .21303 .28526 .2118 Mtetra
.645 .734 .914 r
.28526 .2118 .28638 .21303 .28811 .21247 .28698 .21122 Mtetra
.653 .733 .909 r
.28698 .21122 .28811 .21247 .28984 .21186 .28872 .2106 Mtetra
.663 .735 .903 r
.28872 .2106 .28984 .21186 .29158 .2112 .29046 .20994 Mtetra
.676 .738 .897 r
.29046 .20994 .29158 .2112 .29332 .21047 .2922 .20921 Mtetra
.68 .74 .896 r
.2922 .20921 .29332 .21047 .29507 .20972 .29395 .20846 Mtetra
.709 .749 .883 r
.29395 .20846 .29507 .20972 .29683 .2088 .2957 .20757 Mtetra
.754 .763 .861 r
.2957 .20757 .29683 .2088 .29861 .20756 .29749 .20639 Mtetra
.671 .755 .914 r
.29749 .20639 .29861 .20756 .30036 .20687 .29923 .2057 Mtetra
.077 .453 .883 r
.29923 .2057 .30036 .20687 .30199 .20774 .30088 .20635 Mtetra
.953 .605 .29 r
.30088 .20635 .30199 .20774 .3022 .22815 .30199 .21434 Mtetra
.974 .702 .453 r
.30199 .21434 .3022 .22815 .28971 .42415 .28864 .42099 Mtetra
0 0 .468 r
.28864 .42099 .28971 .42415 .29134 .42682 .29023 .42418 Mtetra
.561 .537 .785 r
.29023 .42418 .29134 .42682 .29319 .42644 .29208 .42393 Mtetra
.664 .601 .775 r
.29208 .42393 .29319 .42644 .29509 .42539 .29397 .42297 Mtetra
.696 .623 .771 r
.29397 .42297 .29509 .42539 .29701 .42411 .29589 .42173 Mtetra
.653 .607 .79 r
.29589 .42173 .29701 .42411 .2989 .42331 .29778 .42089 Mtetra
.648 .6 .787 r
.29778 .42089 .2989 .42331 .30078 .42251 .29966 .42008 Mtetra
.632 .591 .79 r
.29966 .42008 .30078 .42251 .30267 .42168 .30155 .41937 Mtetra
.598 .586 .811 r
.30155 .41937 .30267 .42168 .30457 .42075 .30341 .41892 Mtetra
.596 .639 .864 r
.30341 .41892 .30457 .42075 .30647 .41982 .30528 .4185 Mtetra
.606 .724 .928 r
.30528 .4185 .30647 .41982 .30837 .41893 .30715 .41802 Mtetra
.647 .816 .965 r
.30715 .41802 .30837 .41893 .31026 .4182 .30903 .41736 Mtetra
.653 .832 .969 r
.30903 .41736 .31026 .4182 .31214 .41752 .31092 .41665 Mtetra
.649 .824 .967 r
.31092 .41665 .31214 .41752 .31402 .41694 .31281 .41597 Mtetra
.623 .797 .966 r
.31281 .41597 .31402 .41694 .31589 .41652 .31469 .41539 Mtetra
.625 .766 .947 r
.31469 .41539 .31589 .41652 .31778 .41597 .31657 .41482 Mtetra
.608 .756 .949 r
.31657 .41482 .31778 .41597 .31968 .41515 .31845 .41432 Mtetra
.43 .751 .994 r
.31845 .41432 .31968 .41515 .32161 .4138 .32031 .41418 Mtetra
.232 .74 .693 r
.32031 .41418 .32161 .4138 .32359 .41167 .3222 .41358 Mtetra
0 0 0 r
.3222 .41358 .32359 .41167 .32571 .40745 .32416 .41189 Mtetra
.751 .777 .278 r
.32416 .41189 .32571 .40745 .34025 .19969 .32646 .40469 Mtetra
0 0 .162 r
.32646 .40469 .34025 .19969 .34243 .19238 .34113 .19433 Mtetra
.935 .907 .517 r
.34113 .19433 .34243 .19238 .34434 .18933 .34317 .18912 Mtetra
.738 .96 .941 r
.34317 .18912 .34434 .18933 .34613 .18834 .34497 .188 Mtetra
.478 .859 .981 r
.34497 .188 .34613 .18834 .34789 .18786 .34674 .18756 Mtetra
.28 .759 .929 r
.34674 .18756 .34789 .18786 .34964 .18764 .34848 .1874 Mtetra
.641 .934 .967 r
.34848 .1874 .34964 .18764 .3514 .18722 .35027 .18657 Mtetra
.696 .874 .965 r
.35027 .18657 .3514 .18722 .35316 .18681 .35205 .18573 Mtetra
.691 .783 .921 r
.35205 .18573 .35316 .18681 .35493 .18638 .35384 .18494 Mtetra
.643 .701 .888 r
.35384 .18494 .35493 .18638 .3567 .18583 .35562 .18434 Mtetra
.635 .691 .885 r
.35562 .18434 .3567 .18583 .35848 .18521 .35739 .18377 Mtetra
.639 .702 .892 r
.35739 .18377 .35848 .18521 .36026 .18453 .35917 .18319 Mtetra
.67 .73 .895 r
.35917 .18319 .36026 .18453 .36206 .18365 .36096 .18248 Mtetra
.68 .763 .914 r
.36096 .18248 .36206 .18365 .36385 .18286 .36275 .18172 Mtetra
.687 .771 .916 r
.36275 .18172 .36385 .18286 .36563 .18229 .36454 .18094 Mtetra
.751 .751 .852 r
.36454 .18094 .36563 .18229 .36739 .18215 .36635 .17973 Mtetra
.651 .59 .773 r
.36635 .17973 .36739 .18215 .36911 .18264 .36815 .1789 Mtetra
.536 .447 .701 r
.36815 .1789 .36911 .18264 .37077 .18451 .36991 .17878 Mtetra
0 0 .508 r
.36991 .17878 .37077 .18451 .36215 .3895 .37146 .18288 Mtetra
0 0 .201 r
.37146 .18288 .36215 .3895 .36359 .39817 .36265 .39227 Mtetra
0 0 .387 r
.36265 .39227 .36359 .39817 .36536 .40059 .36425 .3981 Mtetra
.452 .492 .81 r
.36425 .3981 .36536 .40059 .36727 .4002 .36612 .39838 Mtetra
.628 .658 .86 r
.36612 .39838 .36727 .4002 .36922 .39916 .36805 .39779 Mtetra
.721 .756 .881 r
.36805 .39779 .36922 .39916 .37118 .39775 .36999 .39673 Mtetra
.682 .81 .944 r
.36999 .39673 .37118 .39775 .37312 .39683 .37193 .39592 Mtetra
.695 .833 .949 r
.37193 .39592 .37312 .39683 .37506 .39596 .37387 .39504 Mtetra
.698 .832 .947 r
.37387 .39504 .37506 .39596 .37699 .39514 .37581 .39415 Mtetra
.666 .81 .952 r
.37581 .39415 .37699 .39514 .37893 .39438 .37775 .39339 Mtetra
.648 .806 .959 r
.37775 .39339 .37893 .39438 .38086 .39368 .37968 .39271 Mtetra
.629 .803 .966 r
.37968 .39271 .38086 .39368 .38279 .39305 .38161 .39209 Mtetra
.579 .788 .978 r
.38161 .39209 .38279 .39305 .38472 .39251 .38354 .39163 Mtetra
.57 .801 .986 r
.38354 .39163 .38472 .39251 .38665 .39203 .38547 .39117 Mtetra
.589 .814 .985 r
.38547 .39117 .38665 .39203 .38858 .39159 .3874 .39065 Mtetra
.505 .763 .989 r
.3874 .39065 .38858 .39159 .39048 .39181 .38933 .39038 Mtetra
.651 .727 .904 r
.38933 .39038 .39048 .39181 .39241 .39159 .39127 .38969 Mtetra
.751 .698 .802 r
.39127 .38969 .39241 .39159 .39437 .3905 .39325 .38817 Mtetra
.906 .705 .62 r
.39325 .38817 .39437 .3905 .39653 .38451 .39544 .38147 Mtetra
.967 .687 .449 r
.39544 .38147 .39653 .38451 .40684 .17146 .40577 .16996 Mtetra
.928 .743 .633 r
.40577 .16996 .40684 .17146 .40888 .16511 .40779 .16426 Mtetra
.817 .852 .875 r
.40779 .16426 .40888 .16511 .41073 .16353 .40963 .16275 Mtetra
.637 .835 .977 r
.40963 .16275 .41073 .16353 .41254 .16291 .41145 .16212 Mtetra
.493 .779 .996 r
.41145 .16212 .41254 .16291 .41434 .1627 .41325 .16186 Mtetra
.654 .827 .966 r
.41325 .16186 .41434 .1627 .41615 .16221 .41507 .16118 Mtetra
.674 .793 .938 r
.41507 .16118 .41615 .16221 .41797 .16166 .41689 .16044 Mtetra
.661 .753 .918 r
.41689 .16044 .41797 .16166 .41979 .16108 .41872 .15976 Mtetra
.703 .748 .887 r
.41872 .15976 .41979 .16108 .42162 .15999 .42055 .15886 Mtetra
.646 .764 .935 r
.42055 .15886 .42162 .15999 .42346 .15904 .42237 .15824 Mtetra
.334 .697 .982 r
.42237 .15824 .42346 .15904 .42528 .15856 .42417 .15829 Mtetra
.872 .432 .13 r
.42417 .15829 .42528 .15856 .42703 .16019 .42585 .16222 Mtetra
.967 .678 .431 r
.42585 .16222 .42703 .16019 .42862 .16665 .42079 .37288 Mtetra
.517 .276 .489 r
.42079 .37288 .42862 .16665 .42387 .37466 .42255 .37862 Mtetra
.521 .159 .293 r
.42255 .37862 .42387 .37466 .42571 .37772 .42447 .37922 Mtetra
.185 0 0 r
.42447 .37922 .42571 .37772 .42763 .37867 .42644 .37862 Mtetra
.641 .96 .919 r
.42644 .37862 .42763 .37867 .42957 .37888 .42842 .37753 Mtetra
.703 .761 .897 r
.42842 .37753 .42957 .37888 .43153 .37866 .4304 .37657 Mtetra
.675 .651 .819 r
.4304 .37657 .43153 .37866 .43349 .37816 .43238 .37563 Mtetra
.66 .604 .781 r
.43238 .37563 .43349 .37816 .43547 .37747 .43436 .37466 Mtetra
.568 .533 .776 r
.43436 .37466 .43547 .37747 .43744 .37701 .43633 .37434 Mtetra
.588 .555 .785 r
.43633 .37434 .43744 .37701 .43941 .37637 .4383 .3739 Mtetra
.684 .621 .779 r
.4383 .3739 .43941 .37637 .4414 .37521 .44029 .37275 Mtetra
.88 .698 .652 r
.44029 .37275 .4414 .37521 .44345 .37187 .44238 .36774 Mtetra
.969 .685 .436 r
.44238 .36774 .44345 .37187 .44562 .36366 .44969 .15571 Mtetra
.524 .287 .498 r
.44969 .15571 .44562 .36366 .45265 .1544 .45171 .14812 Mtetra
.641 .458 .62 r
.45171 .14812 .45265 .1544 .45455 .15153 .45359 .14612 Mtetra
.58 .429 .642 r
.45359 .14612 .45455 .15153 .4564 .1509 .45544 .14538 Mtetra
.545 .404 .64 r
.45544 .14538 .4564 .1509 .45824 .15062 .45728 .14508 Mtetra
.564 .416 .639 r
.45728 .14508 .45824 .15062 .46012 .14856 .45913 .14453 Mtetra
.593 .474 .687 r
.45913 .14453 .46012 .14856 .46201 .14622 .46098 .14386 Mtetra
.629 .588 .789 r
.46098 .14386 .46201 .14622 .46389 .14432 .46283 .14318 Mtetra
.656 .771 .934 r
.46283 .14318 .46389 .14432 .46575 .14321 .46468 .14251 Mtetra
.638 .86 .983 r
.46468 .14251 .46575 .14321 .4676 .14249 .46654 .14183 Mtetra
.639 .867 .984 r
.46654 .14183 .4676 .14249 .46946 .14192 .46839 .14114 Mtetra
.659 .848 .972 r
.46839 .14114 .46946 .14192 .47131 .14126 .47025 .14041 Mtetra
.669 .836 .964 r
.47025 .14041 .47131 .14126 .47317 .14055 .47211 .13967 Mtetra
.671 .83 .96 r
.47211 .13967 .47317 .14055 .47503 .13983 .47397 .13891 Mtetra
.669 .822 .957 r
.47397 .13891 .47503 .13983 .47689 .13911 .47584 .13817 Mtetra
.667 .818 .956 r
.47584 .13817 .47689 .13911 .47875 .13839 .4777 .13744 Mtetra
.666 .816 .955 r
.4777 .13744 .47875 .13839 .48062 .13766 .47956 .13672 Mtetra
.665 .815 .955 r
.47956 .13672 .48062 .13766 .48248 .13694 .48143 .13599 Mtetra
.664 .814 .955 r
.48143 .13599 .48248 .13694 .48435 .13622 .4833 .13527 Mtetra
.663 .813 .955 r
.4833 .13527 .48435 .13622 .48621 .13551 .48516 .13455 Mtetra
.662 .813 .956 r
.48516 .13455 .48621 .13551 .48808 .13479 .48703 .13384 Mtetra
.661 .813 .956 r
.48703 .13384 .48808 .13479 .48995 .13408 .4889 .13313 Mtetra
.66 .813 .957 r
.4889 .13313 .48995 .13408 .49182 .13337 .49078 .13242 Mtetra
.659 .813 .957 r
.49078 .13242 .49182 .13337 .49369 .13267 .49265 .13171 Mtetra
.658 .812 .957 r
.49265 .13171 .49369 .13267 .49557 .13197 .49452 .13101 Mtetra
.657 .812 .958 r
.49452 .13101 .49557 .13197 .49744 .13127 .4964 .13032 Mtetra
.656 .811 .958 r
.4964 .13032 .49744 .13127 .49932 .13058 .49828 .12962 Mtetra
.654 .812 .959 r
.49828 .12962 .49932 .13058 .50119 .12989 .50015 .12893 Mtetra
.653 .812 .96 r
.50015 .12893 .50119 .12989 .50307 .12922 .50203 .12825 Mtetra
.652 .808 .958 r
.50203 .12825 .50307 .12922 .50495 .12863 .50391 .12757 Mtetra
.653 .79 .948 r
.50391 .12757 .50495 .12863 .50683 .12809 .5058 .1269 Mtetra
.654 .763 .929 r
.5058 .1269 .50683 .12809 .50871 .12756 .50768 .12622 Mtetra
.654 .737 .91 r
.50768 .12622 .50871 .12756 .5106 .12696 .50956 .12555 Mtetra
.654 .723 .899 r
.50956 .12555 .5106 .12696 .51248 .1263 .51145 .12486 Mtetra
.654 .72 .896 r
.51145 .12486 .51248 .1263 .51437 .12561 .51334 .12418 Mtetra
.656 .72 .896 r
.51334 .12418 .51437 .12561 .51626 .12492 .51523 .12349 Mtetra
.657 .721 .896 r
.51523 .12349 .51626 .12492 .51815 .12423 .51712 .12279 Mtetra
.657 .72 .895 r
.51712 .12279 .51815 .12423 .52004 .12354 .51901 .12209 Mtetra
.658 .719 .894 r
.51901 .12209 .52004 .12354 .52193 .12284 .5209 .12138 Mtetra
.659 .719 .893 r
.5209 .12138 .52193 .12284 .52382 .12213 .52279 .12068 Mtetra
.52279 .12068 .52382 .12213 .52572 .12142 .52469 .11996 Mtetra
.659 .718 .892 r
.52469 .11996 .52572 .12142 .52761 .12071 .52659 .11925 Mtetra
.66 .718 .892 r
.52659 .11925 .52761 .12071 .52951 .12 .52848 .11853 Mtetra
.52848 .11853 .52951 .12 .53141 .11928 .53038 .11781 Mtetra
.66 .718 .891 r
.53038 .11781 .53141 .11928 .53331 .11856 .53228 .11709 Mtetra
.53228 .11709 .53331 .11856 .53521 .11784 .53419 .11637 Mtetra
.661 .718 .891 r
.53419 .11637 .53521 .11784 .53711 .11712 .53609 .11565 Mtetra
.53609 .11565 .53711 .11712 .53902 .11639 .53799 .11492 Mtetra
.53799 .11492 .53902 .11639 .54092 .11567 .5399 .1142 Mtetra
.5399 .1142 .54092 .11567 .54283 .11495 .54181 .11347 Mtetra
.54181 .11347 .54283 .11495 .54474 .11422 .54372 .11275 Mtetra
.54372 .11275 .54474 .11422 .54664 .11349 .54563 .11202 Mtetra
.54563 .11202 .54664 .11349 .54855 .11277 .54754 .11129 Mtetra
.54754 .11129 .54855 .11277 .55047 .11204 .54945 .11056 Mtetra
.54945 .11056 .55047 .11204 .55238 .11131 .55136 .10983 Mtetra
.55136 .10983 .55238 .11131 .55429 .11058 .55328 .1091 Mtetra
.55328 .1091 .55429 .11058 .55621 .10985 .5552 .10837 Mtetra
.5552 .10837 .55621 .10985 .55813 .10912 .55711 .10764 Mtetra
.55711 .10764 .55813 .10912 .56005 .10839 .55903 .10691 Mtetra
.55903 .10691 .56005 .10839 .56197 .10766 .56095 .10617 Mtetra
.56095 .10617 .56197 .10766 .56389 .10693 .56288 .10544 Mtetra
.56288 .10544 .56389 .10693 .56581 .10619 .5648 .10471 Mtetra
.5648 .10471 .56581 .10619 .56773 .10546 .56672 .10397 Mtetra
.56672 .10397 .56773 .10546 .56966 .10473 .56865 .10324 Mtetra
.56865 .10324 .56966 .10473 .57158 .10399 .57058 .1025 Mtetra
.57058 .1025 .57158 .10399 .57351 .10326 .5725 .10176 Mtetra
.661 .718 .89 r
.5725 .10176 .57351 .10326 .57544 .10252 .57443 .10103 Mtetra
.57443 .10103 .57544 .10252 .57737 .10178 .57637 .10029 Mtetra
.57637 .10029 .57737 .10178 .5793 .10104 .5783 .09955 Mtetra
.5783 .09955 .5793 .10104 .58124 .10031 .58023 .09881 Mtetra
.58023 .09881 .58124 .10031 .58317 .09957 .58217 .09807 Mtetra
.662 .718 .89 r
.58217 .09807 .58317 .09957 .58511 .09883 .5841 .09733 Mtetra
.5841 .09733 .58511 .09883 .58704 .09809 .58604 .09659 Mtetra
.58604 .09659 .58704 .09809 .58898 .09734 .58798 .09584 Mtetra
.58798 .09584 .58898 .09734 .59092 .0966 .58992 .0951 Mtetra
.58992 .0951 .59092 .0966 .59286 .09586 .59186 .09435 Mtetra
.662 .717 .89 r
.59186 .09435 .59286 .09586 .59481 .09511 .59381 .0936 Mtetra
.662 .717 .889 r
.59381 .0936 .59481 .09511 .59675 .09436 .59575 .09286 Mtetra
.59575 .09286 .59675 .09436 .59869 .09362 .5977 .09211 Mtetra
.5977 .09211 .59869 .09362 .60064 .09287 .59965 .09136 Mtetra
.59965 .09136 .60064 .09287 .60259 .09212 .60159 .0906 Mtetra
.60159 .0906 .60259 .09212 .60454 .09137 .60354 .08985 Mtetra
.662 .716 .889 r
.60354 .08985 .60454 .09137 .60649 .09062 .6055 .0891 Mtetra
.662 .716 .888 r
.6055 .0891 .60649 .09062 .60844 .08987 .60745 .08835 Mtetra
.60745 .08835 .60844 .08987 .61039 .08912 .6094 .0876 Mtetra
.6094 .0876 .61039 .08912 .61235 .08837 .61136 .08685 Mtetra
.661 .716 .889 r
.61136 .08685 .61235 .08837 .6143 .08762 .61331 .0861 Mtetra
.61331 .0861 .6143 .08762 .61626 .08687 .61527 .08535 Mtetra
.61527 .08535 .61626 .08687 .61822 .08612 .61723 .0846 Mtetra
.61723 .0846 .61822 .08612 .62018 .08537 .61919 .08385 Mtetra
.61919 .08385 .62018 .08537 .62214 .08462 .62116 .0831 Mtetra
.661 .717 .89 r
.62116 .0831 .62214 .08462 .62411 .08387 .62312 .08235 Mtetra
.62312 .08235 .62411 .08387 .62607 .08312 .62508 .0816 Mtetra
.661 .718 .89 r
.62508 .0816 .62607 .08312 .62804 .08237 .62705 .08085 Mtetra
.662 .718 .89 r
.62705 .08085 .62804 .08237 .63 .08161 .62902 .0801 Mtetra
.662 .719 .89 r
.62902 .0801 .63 .08161 .63197 .08086 .63099 .07934 Mtetra
.663 .719 .89 r
.63099 .07934 .63197 .08086 .63394 .0801 .63296 .07858 Mtetra
.664 .719 .89 r
.63296 .07858 .63394 .0801 .63591 .07933 .63493 .07781 Mtetra
.665 .72 .89 r
.63493 .07781 .63591 .07933 .63788 .07857 .6369 .07704 Mtetra
.666 .72 .889 r
.6369 .07704 .63788 .07857 .63986 .07779 .63888 .07626 Mtetra
.667 .719 .888 r
.63888 .07626 .63986 .07779 .64183 .07702 .64085 .07548 Mtetra
.67 .719 .886 r
.64085 .07548 .64183 .07702 .64381 .07623 .64283 .07468 Mtetra
.676 .719 .881 r
.64283 .07468 .64381 .07623 .64578 .07545 .6448 .07384 Mtetra
.669 .707 .876 r
.6448 .07384 .64578 .07545 .64776 .07465 .64678 .07303 Mtetra
.654 .7 .88 r
.64678 .07303 .64776 .07465 .64974 .07379 .64876 .0723 Mtetra
.619 .705 .907 r
.64876 .0723 .64974 .07379 .65171 .07285 .65076 .07175 Mtetra
.603 .775 .963 r
.65076 .07175 .65171 .07285 .65369 .0719 .65275 .07122 Mtetra
.58 .86 .995 r
.65275 .07122 .65369 .0719 .65566 .07097 .65474 .07062 Mtetra
.59 .924 .965 r
.65474 .07062 .65566 .07097 .65764 .07011 .65673 .0698 Mtetra
.601 .933 .957 r
.65673 .0698 .65764 .07011 .65963 .06928 .65871 .06893 Mtetra
.646 .943 .958 r
.65871 .06893 .65963 .06928 .66161 .06841 .66069 .06797 Mtetra
.751 .958 .939 r
.66069 .06797 .66161 .06841 .66358 .06728 .66266 .0667 Mtetra
.642 .905 .983 r
.66266 .0667 .66358 .06728 .66557 .06646 .66465 .06588 Mtetra
.152 .632 .923 r
.66465 .06588 .66557 .06646 .6676 .06633 .66669 .0661 Mtetra
.873 .434 .065 r
.66669 .0661 .6676 .06633 .66974 .06858 .669 .07165 Mtetra
.972 .659 .327 r
.669 .07165 .66974 .06858 .67229 .07871 .68184 .28536 Mtetra
.513 .272 .487 r
.68184 .28536 .67229 .07871 .68503 .28615 .68425 .28961 Mtetra
.433 .058 .225 r
.68425 .28961 .68503 .28615 .68733 .28821 .68644 .28948 Mtetra
.065 0 0 r
.68644 .28948 .68733 .28821 .68956 .28881 .6886 .28857 Mtetra
.664 .965 .924 r
.6886 .28857 .68956 .28881 .69176 .28872 .69074 .28735 Mtetra
.629 .754 .937 r
.69074 .28735 .69176 .28872 .69393 .28818 .69291 .28669 Mtetra
.635 .735 .92 r
.69291 .28669 .69393 .28818 .6961 .28744 .69508 .28601 Mtetra
.635 .745 .928 r
.69508 .28601 .6961 .28744 .69827 .28671 .69725 .28533 Mtetra
.552 .714 .948 r
.69725 .28533 .69827 .28671 .70049 .2868 .69944 .28498 Mtetra
.656 .693 .873 r
.69944 .28498 .70049 .2868 .70268 .28638 .70161 .28416 Mtetra
.765 .694 .784 r
.70161 .28416 .70268 .28638 .70481 .28496 .70372 .28232 Mtetra
.94 .715 .571 r
.70372 .28232 .70481 .28496 .70665 .2784 .70549 .2745 Mtetra
.975 .668 .328 r
.70549 .2745 .70665 .2784 .696 .06164 .695 .05933 Mtetra
.917 .72 .622 r
.695 .05933 .696 .06164 .69769 .05539 .69675 .05401 Mtetra
.761 .785 .873 r
.69675 .05401 .69769 .05539 .69967 .05402 .69873 .05269 Mtetra
.635 .747 .93 r
.69873 .05269 .69967 .05402 .7017 .05339 .70076 .05206 Mtetra
.555 .708 .942 r
.70076 .05206 .7017 .05339 .70375 .05311 .70281 .05173 Mtetra
.757 .783 .875 r
.70281 .05173 .70375 .05311 .70574 .05183 .7048 .05043 Mtetra
.688 .757 .904 r
.7048 .05043 .70574 .05183 .70775 .05094 .70681 .04954 Mtetra
.493 .663 .937 r
.70681 .04954 .70775 .05094 .70982 .05085 .70888 .04944 Mtetra
.744 .326 0 r
.70888 .04944 .70982 .05085 .71221 .05577 .71127 .05438 Mtetra
.97 .655 .291 r
.71127 .05438 .71221 .05577 .72845 .27092 .72745 .26957 Mtetra
.741 .308 0 r
.72745 .26957 .72845 .27092 .73102 .2759 .73002 .27453 Mtetra
.038 .469 .881 r
.03605 .5094 .03737 .51046 .0389 .51101 .03758 .50995 Mtetra
.646 .764 .935 r
.03758 .50995 .0389 .51101 .0406 .51043 .03928 .50937 Mtetra
.811 .78 .824 r
.03928 .50937 .0406 .51043 .04246 .50872 .04114 .50767 Mtetra
.909 .738 .657 r
.04114 .50767 .04246 .50872 .04493 .50276 .04362 .50172 Mtetra
.937 .686 .534 r
.04362 .50172 .04493 .50276 .0763 .2959 .07509 .29481 Mtetra
.909 .73 .647 r
.07509 .29481 .0763 .2959 .0787 .28978 .07749 .28867 Mtetra
.778 .762 .839 r
.07749 .28867 .0787 .28978 .0804 .28847 .07919 .28735 Mtetra
.643 .738 .918 r
.07919 .28735 .0804 .28847 .08199 .28794 .08078 .28682 Mtetra
.514 .695 .951 r
.08078 .28682 .08199 .28794 .08353 .28779 .08232 .28667 Mtetra
.747 .759 .862 r
.08232 .28667 .08353 .28779 .08519 .28673 .08399 .28561 Mtetra
.699 .751 .892 r
.08399 .28561 .08519 .28673 .08682 .28596 .08562 .28483 Mtetra
.496 .686 .952 r
.08562 .28483 .08682 .28596 .08836 .28585 .08715 .28472 Mtetra
.921 .531 .224 r
.08715 .28472 .08836 .28585 .08934 .28968 .08814 .28855 Mtetra
.939 .683 .522 r
.08814 .28855 .08934 .28968 .06222 .49512 .06092 .49404 Mtetra
.937 .59 .341 r
.06092 .49404 .06222 .49512 .06301 .50112 .06171 .50004 Mtetra
.213 .572 .94 r
.06171 .50004 .06301 .50112 .0646 .50146 .06329 .50038 Mtetra
.672 .767 .922 r
.06329 .50038 .0646 .50146 .06633 .50077 .06502 .49969 Mtetra
.752 .779 .875 r
.06502 .49969 .06633 .50077 .06812 .49963 .06682 .49854 Mtetra
.489 .709 .968 r
.06682 .49854 .06812 .49963 .06977 .4995 .06847 .49841 Mtetra
.585 .744 .952 r
.06847 .49841 .06977 .4995 .07146 .49912 .07016 .49803 Mtetra
.751 .779 .876 r
.07016 .49803 .07146 .49912 .07326 .49799 .07196 .4969 Mtetra
.908 .742 .664 r
.07196 .4969 .07326 .49799 .07564 .49251 .07434 .4914 Mtetra
.94 .687 .528 r
.07434 .4914 .07564 .49251 .10524 .28544 .10404 .28426 Mtetra
.911 .726 .64 r
.10404 .28426 .10524 .28544 .10765 .27895 .10646 .27779 Mtetra
.793 .759 .822 r
.10646 .27779 .10765 .27895 .10939 .27745 .10819 .2763 Mtetra
.628 .729 .92 r
.10819 .2763 .10939 .27745 .11099 .27697 .1098 .27582 Mtetra
.476 .674 .951 r
.1098 .27582 .11099 .27697 .11254 .27691 .11134 .27576 Mtetra
.622 .729 .923 r
.11134 .27576 .11254 .27691 .11414 .27644 .11295 .2753 Mtetra
.653 .738 .912 r
.11295 .2753 .11414 .27644 .11576 .27587 .11457 .27472 Mtetra
.661 .74 .908 r
.11457 .27472 .11576 .27587 .11738 .27526 .11619 .27411 Mtetra
.75 .757 .858 r
.11619 .27411 .11738 .27526 .11907 .27416 .11788 .273 Mtetra
.717 .752 .879 r
.11788 .273 .11907 .27416 .12073 .27327 .11954 .27211 Mtetra
.552 .703 .94 r
.11954 .27211 .12073 .27327 .12231 .27303 .12112 .27186 Mtetra
.899 .481 .13 r
.12112 .27186 .12231 .27303 .12343 .27631 .12225 .27514 Mtetra
.943 .684 .514 r
.12225 .27514 .12343 .27631 .09846 .48188 .09717 .48076 Mtetra
.941 .599 .347 r
.09717 .48076 .09846 .48188 .09925 .48856 .09796 .48747 Mtetra
0 .426 .856 r
.09796 .48747 .09925 .48856 .10083 .48922 .09954 .48812 Mtetra
.669 .766 .923 r
.09954 .48812 .10083 .48922 .10258 .48855 .10129 .48744 Mtetra
.758 .779 .87 r
.10129 .48744 .10258 .48855 .1044 .48736 .10311 .48623 Mtetra
.586 .738 .948 r
.10311 .48623 .1044 .48736 .10611 .48698 .10483 .48585 Mtetra
.607 .745 .942 r
.10483 .48585 .10611 .48698 .10784 .48653 .10655 .4854 Mtetra
.76 .776 .866 r
.10655 .4854 .10784 .48653 .10965 .48534 .10838 .48417 Mtetra
.91 .74 .658 r
.10838 .48417 .10965 .48534 .11199 .48002 .11076 .47846 Mtetra
.943 .687 .521 r
.11076 .47846 .11199 .48002 .13956 .27203 .13848 .27001 Mtetra
.882 .691 .64 r
.13848 .27001 .13956 .27203 .14192 .26559 .14079 .26401 Mtetra
.809 .711 .758 r
.14079 .26401 .14192 .26559 .14375 .26347 .14261 .26192 Mtetra
.691 .687 .842 r
.14261 .26192 .14375 .26347 .14542 .26263 .14428 .26109 Mtetra
.467 .595 .896 r
.14428 .26109 .14542 .26263 .14697 .26269 .14584 .26114 Mtetra
.785 .343 0 r
.14584 .26114 .14697 .26269 .14824 .26514 .1471 .26368 Mtetra
.946 .685 .508 r
.1471 .26368 .14824 .26514 .1254 .46612 .1239 .46687 Mtetra
.912 .602 .444 r
.1239 .46687 .1254 .46612 .12556 .47864 .1242 .47818 Mtetra
.623 .058 0 r
.1242 .47818 .12556 .47864 .12708 .47997 .12573 .47946 Mtetra
.571 .86 .996 r
.12573 .47946 .12708 .47997 .12881 .47959 .12748 .47895 Mtetra
.791 .867 .905 r
.12748 .47895 .12881 .47959 .13062 .47862 .12932 .47764 Mtetra
.817 .803 .838 r
.12932 .47764 .13062 .47862 .13236 .47813 .13121 .47595 Mtetra
.789 .67 .732 r
.13121 .47595 .13236 .47813 .13411 .47762 .13318 .4736 Mtetra
.779 .594 .65 r
.13318 .4736 .13411 .47762 .13594 .47643 .13535 .4696 Mtetra
.94 .681 .518 r
.13535 .4696 .13594 .47643 .13815 .47206 .16048 .27059 Mtetra
.535 .297 .502 r
.16048 .27059 .13815 .47206 .16396 .26568 .16341 .25916 Mtetra
.703 .501 .612 r
.16341 .25916 .16396 .26568 .16653 .25726 .16541 .2556 Mtetra
.764 .696 .786 r
.16541 .2556 .16653 .25726 .16836 .2551 .16717 .25408 Mtetra
.673 .772 .924 r
.16717 .25408 .16836 .2551 .17003 .2544 .16884 .25341 Mtetra
.591 .757 .957 r
.16884 .25341 .17003 .2544 .17165 .25414 .17047 .25302 Mtetra
.733 .766 .88 r
.17047 .25302 .17165 .25414 .17333 .25334 .17217 .25204 Mtetra
.737 .737 .851 r
.17217 .25204 .17333 .25334 .17502 .25241 .17388 .25096 Mtetra
.619 .679 .884 r
.17388 .25096 .17502 .25241 .17665 .25207 .17553 .2505 Mtetra
.697 .251 0 r
.17553 .2505 .17665 .25207 .17798 .25437 .17686 .25277 Mtetra
.949 .685 .501 r
.17686 .25277 .17798 .25437 .15666 .45863 .15533 .45806 Mtetra
.937 .614 .398 r
.15533 .45806 .15666 .45863 .15728 .46828 .15595 .46771 Mtetra
.664 .112 0 r
.15595 .46771 .15728 .46828 .15883 .46971 .1575 .46921 Mtetra
.486 .835 .997 r
.1575 .46921 .15883 .46971 .16059 .4693 .15925 .46885 Mtetra
.756 .908 .943 r
.15925 .46885 .16059 .4693 .16241 .46832 .16109 .46773 Mtetra
.832 .873 .874 r
.16109 .46773 .16241 .46832 .1642 .46765 .16298 .46609 Mtetra
.823 .731 .763 r
.16298 .46609 .1642 .46765 .16598 .46709 .16495 .46378 Mtetra
.797 .623 .665 r
.16495 .46378 .16598 .46709 .16782 .46592 .16708 .45999 Mtetra
.871 .632 .574 r
.16708 .45999 .16782 .46592 .16995 .46214 .17048 .44452 Mtetra
.931 .668 .517 r
.17048 .44452 .16995 .46214 .19364 .25784 .19337 .24833 Mtetra
.668 .454 .585 r
.19337 .24833 .19364 .25784 .19649 .24628 .1954 .24438 Mtetra
.769 .676 .761 r
.1954 .24438 .19649 .24628 .19837 .24372 .1972 .24264 Mtetra
.685 .766 .913 r
.1972 .24264 .19837 .24372 .20007 .24293 .19889 .2419 Mtetra
.604 .754 .95 r
.19889 .2419 .20007 .24293 .20171 .24263 .20055 .24148 Mtetra
.682 .752 .905 r
.20055 .24148 .20171 .24263 .20337 .24217 .20223 .24075 Mtetra
.714 .717 .852 r
.20223 .24075 .20337 .24217 .20506 .24144 .20395 .2398 Mtetra
.666 .669 .843 r
.20395 .2398 .20506 .24144 .20675 .24075 .20564 .23908 Mtetra
.52 .602 .876 r
.20564 .23908 .20675 .24075 .20845 .23993 .20727 .23899 Mtetra
0 .308 .754 r
.20727 .23899 .20845 .23993 .21015 .23918 .2088 .23981 Mtetra
.772 .334 .209 r
.2088 .23981 .21015 .23918 .21179 .23896 .21019 .24203 Mtetra
.9 .602 .472 r
.21019 .24203 .21179 .23896 .21321 .24096 .21001 .25968 Mtetra
.926 .655 .506 r
.21001 .25968 .21321 .24096 .19431 .44366 .19215 .45151 Mtetra
.634 .327 .433 r
.19215 .45151 .19431 .44366 .19492 .45488 .19358 .45465 Mtetra
.582 .007 0 r
.19358 .45465 .19492 .45488 .19646 .45691 .1952 .45579 Mtetra
.408 .671 .968 r
.1952 .45579 .19646 .45691 .19821 .45687 .19694 .45583 Mtetra
.704 .794 .92 r
.19694 .45583 .19821 .45687 .20006 .45578 .19878 .45496 Mtetra
.9 .808 .748 r
.19878 .45496 .20006 .45578 .20213 .45253 .20083 .45183 Mtetra
.952 .726 .56 r
.20083 .45183 .20213 .45253 .20531 .43789 .2041 .43637 Mtetra
.952 .689 .5 r
.2041 .43637 .20531 .43789 .22681 .23524 .2257 .23355 Mtetra
.849 .715 .714 r
.2257 .23355 .22681 .23524 .22875 .2321 .22763 .2305 Mtetra
.666 .676 .85 r
.22763 .2305 .22875 .2321 .23046 .23124 .22934 .22978 Mtetra
.524 .642 .908 r
.22934 .22978 .23046 .23124 .23213 .23093 .23099 .22965 Mtetra
.568 .694 .926 r
.23099 .22965 .23213 .23093 .2338 .23058 .23265 .22936 Mtetra
.688 .745 .894 r
.23265 .22936 .2338 .23058 .2355 .22991 .23437 .22859 Mtetra
.65 .715 .896 r
.23437 .22859 .2355 .22991 .23721 .22928 .23607 .22799 Mtetra
.512 .669 .934 r
.23607 .22799 .23721 .22928 .23892 .2285 .23772 .22786 Mtetra
0 .348 .723 r
.23772 .22786 .23892 .2285 .24064 .22768 .2393 .22852 Mtetra
.732 .286 .191 r
.2393 .22852 .24064 .22768 .24232 .22734 .24077 .23041 Mtetra
.874 .559 .45 r
.24077 .23041 .24232 .22734 .24383 .22885 .24138 .24173 Mtetra
.938 .665 .495 r
.24138 .24173 .24383 .22885 .22834 .41596 .22477 .44026 Mtetra
.559 .294 .47 r
.22477 .44026 .22834 .41596 .22764 .44294 .22624 .44356 Mtetra
.547 .018 0 r
.22624 .44356 .22764 .44294 .22921 .44514 .22793 .44438 Mtetra
.648 .84 .974 r
.22793 .44438 .22921 .44514 .23101 .44477 .22977 .4437 Mtetra
.747 .799 .894 r
.22977 .4437 .23101 .44477 .23287 .44379 .23164 .44257 Mtetra
.723 .77 .89 r
.23164 .44257 .23287 .44379 .23474 .44277 .23351 .44156 Mtetra
.624 .744 .933 r
.23351 .44156 .23474 .44277 .23657 .44213 .23533 .44103 Mtetra
.675 .779 .929 r
.23533 .44103 .23657 .44213 .23841 .44145 .23718 .44028 Mtetra
.774 .786 .862 r
.23718 .44028 .23841 .44145 .24024 .44089 .23908 .43891 Mtetra
.815 .699 .736 r
.23908 .43891 .24024 .44089 .24206 .44043 .24108 .43635 Mtetra
.797 .604 .64 r
.24108 .43635 .24206 .44043 .24393 .43941 .24327 .43171 Mtetra
.949 .682 .495 r
.24327 .43171 .24393 .43941 .24597 .43638 .26244 .22939 Mtetra
.529 .291 .499 r
.26244 .22939 .24597 .43638 .26484 .23548 .26492 .22003 Mtetra
.607 .386 .555 r
.26492 .22003 .26484 .23548 .26788 .21941 .26688 .21653 Mtetra
.727 .597 .711 r
.26688 .21653 .26788 .21941 .26981 .21624 .26871 .21471 Mtetra
.648 .683 .869 r
.26871 .21471 .26981 .21624 .27155 .21539 .27043 .21409 Mtetra
.55 .685 .928 r
.27043 .21409 .27155 .21539 .27325 .21509 .27212 .21385 Mtetra
.529 .688 .94 r
.27212 .21385 .27325 .21509 .27494 .21491 .27381 .21366 Mtetra
.621 .722 .919 r
.27381 .21366 .27494 .21491 .27665 .21441 .27552 .21318 Mtetra
.628 .727 .919 r
.27552 .21318 .27665 .21441 .27837 .21391 .27724 .21266 Mtetra
.632 .726 .915 r
.27724 .21266 .27837 .21391 .28009 .21341 .27896 .21213 Mtetra
.633 .721 .911 r
.27896 .21213 .28009 .21341 .28181 .21289 .28068 .2116 Mtetra
.637 .72 .908 r
.28068 .2116 .28181 .21289 .28353 .21236 .28241 .21105 Mtetra
.642 .719 .904 r
.28241 .21105 .28353 .21236 .28526 .2118 .28413 .21047 Mtetra
.647 .718 .9 r
.28413 .21047 .28526 .2118 .28698 .21122 .28587 .20988 Mtetra
.653 .718 .896 r
.28587 .20988 .28698 .21122 .28872 .2106 .2876 .20926 Mtetra
.661 .719 .892 r
.2876 .20926 .28872 .2106 .29046 .20994 .28934 .20859 Mtetra
.67 .723 .889 r
.28934 .20859 .29046 .20994 .2922 .20921 .29108 .20789 Mtetra
.675 .727 .889 r
.29108 .20789 .2922 .20921 .29395 .20846 .29283 .20716 Mtetra
.695 .737 .883 r
.29283 .20716 .29395 .20846 .2957 .20757 .29458 .20633 Mtetra
.731 .757 .873 r
.29458 .20633 .2957 .20757 .29749 .20639 .29635 .2053 Mtetra
.675 .77 .922 r
.29635 .2053 .29749 .20639 .29923 .2057 .2981 .20459 Mtetra
.356 .633 .959 r
.2981 .20459 .29923 .2057 .30088 .20635 .29978 .20474 Mtetra
.743 .31 0 r
.29978 .20474 .30088 .20635 .30199 .21434 .30127 .20762 Mtetra
.967 .693 .461 r
.30127 .20762 .30199 .21434 .28864 .42099 .28851 .40511 Mtetra
0 0 .365 r
.28851 .40511 .28864 .42099 .29023 .42418 .28947 .41686 Mtetra
.525 .367 .609 r
.28947 .41686 .29023 .42418 .29208 .42393 .29129 .41677 Mtetra
.6 .423 .614 r
.29129 .41677 .29208 .42393 .29397 .42297 .29322 .4154 Mtetra
.631 .441 .608 r
.29322 .4154 .29397 .42297 .29589 .42173 .29519 .41327 Mtetra
.615 .422 .598 r
.29519 .41327 .29589 .42173 .29778 .42089 .29716 .41126 Mtetra
.57 .381 .585 r
.29716 .41126 .29778 .42089 .29966 .42008 .29907 .41009 Mtetra
.447 .286 .569 r
.29907 .41009 .29966 .42008 .30155 .41937 .30081 .41137 Mtetra
.233 .147 .548 r
.30081 .41137 .30155 .41937 .30341 .41892 .30241 .41476 Mtetra
.199 .215 .651 r
.30241 .41476 .30341 .41892 .30528 .4185 .30411 .41668 Mtetra
.184 .416 .852 r
.30411 .41668 .30528 .4185 .30715 .41802 .3059 .41751 Mtetra
.512 .848 .997 r
.3059 .41751 .30715 .41802 .30903 .41736 .30777 .41706 Mtetra
.6 .916 .976 r
.30777 .41706 .30903 .41736 .31092 .41665 .30966 .41631 Mtetra
.649 .924 .975 r
.30966 .41631 .31092 .41665 .31281 .41597 .31156 .41545 Mtetra
.589 .878 .993 r
.31156 .41545 .31281 .41597 .31469 .41539 .31345 .41483 Mtetra
.591 .871 .994 r
.31345 .41483 .31469 .41539 .31657 .41482 .31533 .41422 Mtetra
.574 .857 .996 r
.31533 .41422 .31657 .41482 .31845 .41432 .31722 .41367 Mtetra
.45 .796 .998 r
.31722 .41367 .31845 .41432 .32031 .41418 .31909 .41341 Mtetra
.602 .832 .987 r
.31909 .41341 .32031 .41418 .3222 .41358 .32098 .41284 Mtetra
.775 .875 .92 r
.32098 .41284 .3222 .41358 .32416 .41189 .32291 .41158 Mtetra
.951 .861 .716 r
.32291 .41158 .32416 .41189 .32646 .40469 .325 .40774 Mtetra
.976 .858 .468 r
.325 .40774 .32646 .40469 .34113 .19433 .32742 .39853 Mtetra
0 0 .176 r
.32742 .39853 .34113 .19433 .34317 .18912 .34168 .19421 Mtetra
.357 .042 .286 r
.34168 .19421 .34317 .18912 .34497 .188 .34349 .1931 Mtetra
.476 .148 .331 r
.34349 .1931 .34497 .188 .34674 .18756 .34523 .19312 Mtetra
.422 .107 .324 r
.34523 .19312 .34674 .18756 .34848 .1874 .347 .19251 Mtetra
0 0 .067 r
.347 .19251 .34848 .1874 .35027 .18657 .349 .18819 Mtetra
.72 .888 .498 r
.349 .18819 .35027 .18657 .35205 .18573 .35091 .18524 Mtetra
.883 .894 .835 r
.35091 .18524 .35205 .18573 .35384 .18494 .35277 .18321 Mtetra
.658 .665 .845 r
.35277 .18321 .35384 .18494 .35562 .18434 .35455 .1825 Mtetra
.597 .623 .848 r
.35455 .1825 .35562 .18434 .35739 .18377 .35632 .18209 Mtetra
.568 .632 .875 r
.35632 .18209 .35739 .18377 .35917 .18319 .35808 .18181 Mtetra
.649 .715 .896 r
.35808 .18181 .35917 .18319 .36096 .18248 .35986 .18119 Mtetra
.668 .738 .902 r
.35986 .18119 .36096 .18248 .36275 .18172 .36165 .18048 Mtetra
.688 .752 .901 r
.36165 .18048 .36275 .18172 .36454 .18094 .36344 .17969 Mtetra
.762 .768 .858 r
.36344 .17969 .36454 .18094 .36635 .17973 .36526 .17843 Mtetra
.721 .751 .876 r
.36526 .17843 .36635 .17973 .36815 .1789 .36707 .17744 Mtetra
.618 .689 .894 r
.36707 .17744 .36815 .1789 .36991 .17878 .36885 .17694 Mtetra
0 .181 .716 r
.36885 .17694 .36991 .17878 .37146 .18288 .37052 .17847 Mtetra
0 0 .381 r
.37052 .17847 .37146 .18288 .36265 .39227 .37204 .1832 Mtetra
0 0 .213 r
.37204 .1832 .36265 .39227 .36425 .3981 .36344 .38955 Mtetra
.169 .097 .527 r
.36344 .38955 .36425 .3981 .36612 .39838 .36511 .39392 Mtetra
.299 .273 .662 r
.36511 .39392 .36612 .39838 .36805 .39779 .36692 .39551 Mtetra
.378 .471 .829 r
.36692 .39551 .36805 .39779 .36999 .39673 .36879 .39602 Mtetra
.606 .85 .99 r
.36879 .39602 .36999 .39673 .37193 .39592 .37072 .39541 Mtetra
.708 .915 .965 r
.37072 .39541 .37193 .39592 .37387 .39504 .37266 .3944 Mtetra
.759 .898 .939 r
.37266 .3944 .37387 .39504 .37581 .39415 .37462 .39321 Mtetra
.676 .824 .955 r
.37462 .39321 .37581 .39415 .37775 .39339 .37656 .39241 Mtetra
.647 .807 .96 r
.37656 .39241 .37775 .39339 .37968 .39271 .3785 .39173 Mtetra
.617 .799 .969 r
.3785 .39173 .37968 .39271 .38161 .39209 .38043 .39115 Mtetra
.457 .742 .99 r
.38043 .39115 .38161 .39209 .38354 .39163 .38234 .39099 Mtetra
.457 .806 .998 r
.38234 .39099 .38354 .39163 .38547 .39117 .38426 .39069 Mtetra
.588 .888 .99 r
.38426 .39069 .38547 .39117 .3874 .39065 .38621 .39002 Mtetra
.845 .899 .875 r
.38621 .39002 .3874 .39065 .38933 .39038 .38819 .38825 Mtetra
.828 .701 .724 r
.38819 .38825 .38933 .39038 .39127 .38969 .39023 .38537 Mtetra
.817 .611 .624 r
.39023 .38537 .39127 .38969 .39325 .38817 .39237 .37989 Mtetra
.962 .681 .456 r
.39237 .37989 .39325 .38817 .39544 .38147 .40274 .17263 Mtetra
.521 .285 .497 r
.40274 .17263 .39544 .38147 .40577 .16996 .4048 .16595 Mtetra
.751 .572 .653 r
.4048 .16595 .40577 .16996 .40779 .16426 .40671 .16287 Mtetra
.747 .748 .853 r
.40671 .16287 .40779 .16426 .40963 .16275 .40855 .16166 Mtetra
.653 .776 .939 r
.40855 .16166 .40963 .16275 .41145 .16212 .41037 .16102 Mtetra
.59 .75 .954 r
.41037 .16102 .41145 .16212 .41325 .16186 .41217 .16059 Mtetra
.716 .761 .888 r
.41217 .16059 .41325 .16186 .41507 .16118 .41401 .15963 Mtetra
.697 .71 .858 r
.41401 .15963 .41507 .16118 .41689 .16044 .41584 .15872 Mtetra
.64 .662 .855 r
.41584 .15872 .41689 .16044 .41872 .15976 .41766 .15809 Mtetra
.421 .562 .89 r
.41766 .15809 .41872 .15976 .42055 .15886 .41945 .1583 Mtetra
.444 0 0 r
.41945 .1583 .42055 .15886 .42237 .15824 .42121 .15945 Mtetra
.796 .375 .249 r
.42121 .15945 .42237 .15824 .42417 .15829 .4229 .16272 Mtetra
.964 .675 .434 r
.4229 .16272 .42417 .15829 .42585 .16222 .41778 .36939 Mtetra
.518 .277 .489 r
.41778 .36939 .42585 .16222 .42079 .37288 .41949 .37608 Mtetra
.659 .277 .311 r
.41949 .37608 .42079 .37288 .42255 .37862 .42136 .37828 Mtetra
.006 .566 .808 r
.42136 .37828 .42255 .37862 .42447 .37922 .4233 .37851 Mtetra
.594 .851 .993 r
.4233 .37851 .42447 .37922 .42644 .37862 .42527 .37791 Mtetra
.752 .89 .941 r
.42527 .37791 .42644 .37862 .42842 .37753 .42726 .37674 Mtetra
.867 .87 .838 r
.42726 .37674 .42842 .37753 .4304 .37657 .42927 .37464 Mtetra
.848 .724 .726 r
.42927 .37464 .4304 .37657 .43238 .37563 .43131 .37161 Mtetra
.795 .606 .645 r
.43131 .37161 .43238 .37563 .43436 .37466 .43339 .36738 Mtetra
.606 .427 .613 r
.43339 .36738 .43436 .37466 .43633 .37434 .43538 .36582 Mtetra
.528 .359 .596 r
.43538 .36582 .43633 .37434 .4383 .3739 .43734 .36564 Mtetra
.576 .396 .6 r
.43734 .36564 .4383 .3739 .44029 .37275 .43933 .36451 Mtetra
.965 .68 .442 r
.43933 .36451 .44029 .37275 .44238 .36774 .44662 .16108 Mtetra
.532 .293 .499 r
.44662 .16108 .44238 .36774 .44969 .15571 .44875 .14984 Mtetra
.726 .522 .614 r
.44875 .14984 .44969 .15571 .45171 .14812 .45067 .14601 Mtetra
.744 .665 .773 r
.45067 .14601 .45171 .14812 .45359 .14612 .45254 .14447 Mtetra
.66 .683 .861 r
.45254 .14447 .45359 .14612 .45544 .14538 .45439 .14374 Mtetra
.595 .656 .88 r
.45439 .14374 .45544 .14538 .45728 .14508 .45623 .14333 Mtetra
.607 .646 .863 r
.45623 .14333 .45728 .14508 .45913 .14453 .45808 .14286 Mtetra
.614 .661 .872 r
.45808 .14286 .45913 .14453 .46098 .14386 .45993 .14237 Mtetra
.615 .69 .897 r
.45993 .14237 .46098 .14386 .46283 .14318 .46177 .14187 Mtetra
.638 .73 .915 r
.46177 .14187 .46283 .14318 .46468 .14251 .46363 .14127 Mtetra
.658 .752 .919 r
.46363 .14127 .46468 .14251 .46654 .14183 .46548 .14059 Mtetra
.673 .756 .913 r
.46548 .14059 .46654 .14183 .46839 .14114 .46734 .13984 Mtetra
.692 .753 .898 r
.46734 .13984 .46839 .14114 .47025 .14041 .4692 .13899 Mtetra
.697 .733 .879 r
.4692 .13899 .47025 .14041 .47211 .13967 .47107 .13809 Mtetra
.69 .708 .862 r
.47107 .13809 .47211 .13967 .47397 .13891 .47293 .1372 Mtetra
.67 .681 .852 r
.47293 .1372 .47397 .13891 .47584 .13817 .47479 .1364 Mtetra
.658 .668 .848 r
.47479 .1364 .47584 .13817 .4777 .13744 .47666 .13566 Mtetra
.654 .664 .848 r
.47666 .13566 .4777 .13744 .47956 .13672 .47852 .13494 Mtetra
.654 .665 .849 r
.47852 .13494 .47956 .13672 .48143 .13599 .48039 .13422 Mtetra
.654 .666 .849 r
.48039 .13422 .48143 .13599 .4833 .13527 .48226 .13349 Mtetra
.653 .665 .849 r
.48226 .13349 .4833 .13527 .48516 .13455 .48412 .13277 Mtetra
.48412 .13277 .48516 .13455 .48703 .13384 .48599 .13206 Mtetra
.652 .665 .849 r
.48599 .13206 .48703 .13384 .4889 .13313 .48787 .13135 Mtetra
.651 .665 .85 r
.48787 .13135 .4889 .13313 .49078 .13242 .48974 .13064 Mtetra
.651 .664 .85 r
.48974 .13064 .49078 .13242 .49265 .13171 .49161 .12993 Mtetra
.65 .664 .85 r
.49161 .12993 .49265 .13171 .49452 .13101 .49349 .12923 Mtetra
.49349 .12923 .49452 .13101 .4964 .13032 .49536 .12853 Mtetra
.649 .663 .85 r
.49536 .12853 .4964 .13032 .49828 .12962 .49724 .12783 Mtetra
.648 .662 .85 r
.49724 .12783 .49828 .12962 .50015 .12893 .49912 .12713 Mtetra
.648 .661 .849 r
.49912 .12713 .50015 .12893 .50203 .12825 .501 .12644 Mtetra
.646 .659 .848 r
.501 .12644 .50203 .12825 .50391 .12757 .50288 .12575 Mtetra
.645 .658 .848 r
.50288 .12575 .50391 .12757 .5058 .1269 .50476 .12507 Mtetra
.645 .657 .847 r
.50476 .12507 .5058 .1269 .50768 .12622 .50665 .12439 Mtetra
.646 .656 .846 r
.50665 .12439 .50768 .12622 .50956 .12555 .50853 .1237 Mtetra
.646 .655 .845 r
.50853 .1237 .50956 .12555 .51145 .12486 .51042 .12301 Mtetra
.646 .654 .843 r
.51042 .12301 .51145 .12486 .51334 .12418 .51231 .12231 Mtetra
.647 .653 .842 r
.51231 .12231 .51334 .12418 .51523 .12349 .5142 .12161 Mtetra
.647 .652 .841 r
.5142 .12161 .51523 .12349 .51712 .12279 .51609 .12091 Mtetra
.647 .651 .84 r
.51609 .12091 .51712 .12279 .51901 .12209 .51798 .1202 Mtetra
.648 .651 .839 r
.51798 .1202 .51901 .12209 .5209 .12138 .51987 .11949 Mtetra
.648 .65 .839 r
.51987 .11949 .5209 .12138 .52279 .12068 .52177 .11878 Mtetra
.648 .65 .838 r
.52177 .11878 .52279 .12068 .52469 .11996 .52366 .11806 Mtetra
.52366 .11806 .52469 .11996 .52659 .11925 .52556 .11734 Mtetra
.52556 .11734 .52659 .11925 .52848 .11853 .52746 .11662 Mtetra
.649 .649 .837 r
.52746 .11662 .52848 .11853 .53038 .11781 .52936 .1159 Mtetra
.52936 .1159 .53038 .11781 .53228 .11709 .53126 .11518 Mtetra
.53126 .11518 .53228 .11709 .53419 .11637 .53316 .11446 Mtetra
.53316 .11446 .53419 .11637 .53609 .11565 .53507 .11373 Mtetra
.53507 .11373 .53609 .11565 .53799 .11492 .53697 .11301 Mtetra
.53697 .11301 .53799 .11492 .5399 .1142 .53888 .11228 Mtetra
.53888 .11228 .5399 .1142 .54181 .11347 .54078 .11155 Mtetra
.54078 .11155 .54181 .11347 .54372 .11275 .54269 .11082 Mtetra
.54269 .11082 .54372 .11275 .54563 .11202 .5446 .1101 Mtetra
.5446 .1101 .54563 .11202 .54754 .11129 .54652 .10937 Mtetra
.649 .649 .836 r
.54652 .10937 .54754 .11129 .54945 .11056 .54843 .10864 Mtetra
.54843 .10864 .54945 .11056 .55136 .10983 .55034 .10791 Mtetra
.55034 .10791 .55136 .10983 .55328 .1091 .55226 .10717 Mtetra
.55226 .10717 .55328 .1091 .5552 .10837 .55418 .10644 Mtetra
.55418 .10644 .5552 .10837 .55711 .10764 .55609 .10571 Mtetra
.55609 .10571 .55711 .10764 .55903 .10691 .55801 .10498 Mtetra
.55801 .10498 .55903 .10691 .56095 .10617 .55994 .10424 Mtetra
.55994 .10424 .56095 .10617 .56288 .10544 .56186 .10351 Mtetra
.56186 .10351 .56288 .10544 .5648 .10471 .56378 .10277 Mtetra
.56378 .10277 .5648 .10471 .56672 .10397 .56571 .10204 Mtetra
.56571 .10204 .56672 .10397 .56865 .10324 .56763 .1013 Mtetra
.56763 .1013 .56865 .10324 .57058 .1025 .56956 .10057 Mtetra
.56956 .10057 .57058 .1025 .5725 .10176 .57149 .09983 Mtetra
.57149 .09983 .5725 .10176 .57443 .10103 .57342 .09909 Mtetra
.57342 .09909 .57443 .10103 .57637 .10029 .57535 .09835 Mtetra
.57535 .09835 .57637 .10029 .5783 .09955 .57728 .09761 Mtetra
.57728 .09761 .5783 .09955 .58023 .09881 .57922 .09687 Mtetra
.57922 .09687 .58023 .09881 .58217 .09807 .58116 .09613 Mtetra
.65 .649 .836 r
.58116 .09613 .58217 .09807 .5841 .09733 .58309 .09539 Mtetra
.58309 .09539 .5841 .09733 .58604 .09659 .58503 .09464 Mtetra
.58503 .09464 .58604 .09659 .58798 .09584 .58697 .0939 Mtetra
.58697 .0939 .58798 .09584 .58992 .0951 .58891 .09315 Mtetra
.58891 .09315 .58992 .0951 .59186 .09435 .59085 .0924 Mtetra
.59085 .0924 .59186 .09435 .59381 .0936 .5928 .09165 Mtetra
.5928 .09165 .59381 .0936 .59575 .09286 .59474 .0909 Mtetra
.59474 .0909 .59575 .09286 .5977 .09211 .59669 .09015 Mtetra
.59669 .09015 .5977 .09211 .59965 .09136 .59864 .0894 Mtetra
.65 .649 .835 r
.59864 .0894 .59965 .09136 .60159 .0906 .60059 .08865 Mtetra
.60059 .08865 .60159 .0906 .60354 .08985 .60254 .08789 Mtetra
.60254 .08789 .60354 .08985 .6055 .0891 .60449 .08714 Mtetra
.65 .648 .835 r
.60449 .08714 .6055 .0891 .60745 .08835 .60644 .08638 Mtetra
.60644 .08638 .60745 .08835 .6094 .0876 .6084 .08563 Mtetra
.649 .648 .835 r
.6084 .08563 .6094 .0876 .61136 .08685 .61035 .08488 Mtetra
.61035 .08488 .61136 .08685 .61331 .0861 .61231 .08413 Mtetra
.61231 .08413 .61331 .0861 .61527 .08535 .61427 .08338 Mtetra
.649 .648 .836 r
.61427 .08338 .61527 .08535 .61723 .0846 .61623 .08263 Mtetra
.61623 .08263 .61723 .0846 .61919 .08385 .61819 .08189 Mtetra
.61819 .08189 .61919 .08385 .62116 .0831 .62015 .08114 Mtetra
.649 .649 .836 r
.62015 .08114 .62116 .0831 .62312 .08235 .62212 .08039 Mtetra
.649 .649 .837 r
.62212 .08039 .62312 .08235 .62508 .0816 .62408 .07964 Mtetra
.62408 .07964 .62508 .0816 .62705 .08085 .62605 .07889 Mtetra
.649 .65 .837 r
.62605 .07889 .62705 .08085 .62902 .0801 .62802 .07814 Mtetra
.65 .65 .837 r
.62802 .07814 .62902 .0801 .63099 .07934 .62999 .07738 Mtetra
.651 .651 .837 r
.62999 .07738 .63099 .07934 .63296 .07858 .63196 .07662 Mtetra
.63196 .07662 .63296 .07858 .63493 .07781 .63393 .07586 Mtetra
.653 .652 .837 r
.63393 .07586 .63493 .07781 .6369 .07704 .63591 .07508 Mtetra
.654 .653 .836 r
.63591 .07508 .6369 .07704 .63888 .07626 .63788 .0743 Mtetra
.654 .652 .836 r
.63788 .0743 .63888 .07626 .64085 .07548 .63986 .07351 Mtetra
.662 .656 .834 r
.63986 .07351 .64085 .07548 .64283 .07468 .64183 .07268 Mtetra
.68 .661 .824 r
.64183 .07268 .64283 .07468 .6448 .07384 .6438 .07171 Mtetra
.649 .631 .819 r
.6438 .07171 .6448 .07384 .64678 .07303 .64578 .07093 Mtetra
.569 .593 .837 r
.64578 .07093 .64678 .07303 .64876 .0723 .64778 .07061 Mtetra
.194 .428 .858 r
.64778 .07061 .64876 .0723 .65076 .07175 .64984 .07152 Mtetra
.62 .058 0 r
.64984 .07152 .65076 .07175 .65275 .07122 .65194 .07339 Mtetra
.724 .296 .233 r
.65194 .07339 .65275 .07122 .65474 .07062 .65409 .07626 Mtetra
.473 .15 .337 r
.65409 .07626 .65474 .07062 .65673 .0698 .65612 .07623 Mtetra
.377 .083 .334 r
.65612 .07623 .65673 .0698 .65871 .06893 .65808 .07477 Mtetra
.318 .029 .307 r
.65808 .07477 .65871 .06893 .66069 .06797 .66002 .0728 Mtetra
.28 0 .266 r
.66002 .0728 .66069 .06797 .66266 .0667 .66196 .07087 Mtetra
.361 .029 .26 r
.66196 .07087 .66266 .0667 .66465 .06588 .66395 .0699 Mtetra
.573 .205 .304 r
.66395 .0699 .66465 .06588 .66669 .0661 .66605 .07121 Mtetra
.971 .657 .333 r
.66605 .07121 .66669 .0661 .669 .07165 .67845 .28061 Mtetra
.516 .275 .487 r
.67845 .28061 .669 .07165 .68184 .28536 .68096 .28687 Mtetra
.662 .185 .11 r
.68096 .28687 .68184 .28536 .68425 .28961 .68325 .28883 Mtetra
.547 .835 .998 r
.68325 .28883 .68425 .28961 .68644 .28948 .68543 .2883 Mtetra
.715 .821 .931 r
.68543 .2883 .68644 .28948 .6886 .28857 .68757 .28722 Mtetra
.741 .799 .899 r
.68757 .28722 .6886 .28857 .69074 .28735 .68971 .28598 Mtetra
.592 .736 .944 r
.68971 .28598 .69074 .28735 .69291 .28669 .69189 .28547 Mtetra
.62 .778 .957 r
.69189 .28547 .69291 .28669 .69508 .28601 .69407 .28483 Mtetra
.701 .817 .937 r
.69407 .28483 .69508 .28601 .69725 .28533 .69622 .28382 Mtetra
.821 .797 .829 r
.69622 .28382 .69725 .28533 .69944 .28498 .69833 .28187 Mtetra
.794 .644 .696 r
.69833 .28187 .69944 .28498 .70161 .28416 .70037 .27888 Mtetra
.808 .587 .602 r
.70037 .27888 .70161 .28416 .70372 .28232 .70226 .27311 Mtetra
.974 .664 .341 r
.70226 .27311 .70372 .28232 .70549 .2745 .69223 .06197 Mtetra
.519 .282 .496 r
.69223 .06197 .70549 .2745 .695 .05933 .69392 .05561 Mtetra
.766 .593 .664 r
.69392 .05561 .695 .05933 .69675 .05401 .6958 .0526 Mtetra
.728 .768 .885 r
.6958 .0526 .69675 .05401 .69873 .05269 .6978 .05148 Mtetra
.639 .771 .943 r
.6978 .05148 .69873 .05269 .70076 .05206 .69983 .05082 Mtetra
.589 .744 .95 r
.69983 .05082 .70076 .05206 .70281 .05173 .70187 .05035 Mtetra
.758 .785 .875 r
.70187 .05035 .70281 .05173 .7048 .05043 .70385 .04904 Mtetra
.69 .759 .904 r
.70385 .04904 .7048 .05043 .70681 .04954 .70587 .04814 Mtetra
.495 .665 .938 r
.70587 .04814 .70681 .04954 .70888 .04944 .70794 .04803 Mtetra
.746 .328 0 r
.70794 .04803 .70888 .04944 .71127 .05438 .71033 .053 Mtetra
.97 .655 .291 r
.71033 .053 .71127 .05438 .72745 .26957 .72645 .26822 Mtetra
.739 .306 0 r
.72645 .26822 .72745 .26957 .73002 .27453 .72902 .27316 Mtetra
.041 .47 .882 r
.03474 .50834 .03605 .5094 .03758 .50995 .03627 .50889 Mtetra
.646 .763 .934 r
.03627 .50889 .03758 .50995 .03928 .50937 .03797 .50831 Mtetra
.811 .779 .824 r
.03797 .50831 .03928 .50937 .04114 .50767 .03983 .50661 Mtetra
.909 .737 .658 r
.03983 .50661 .04114 .50767 .04362 .50172 .04231 .50067 Mtetra
.937 .686 .534 r
.04231 .50067 .04362 .50172 .07509 .29481 .07388 .29371 Mtetra
.909 .729 .646 r
.07388 .29371 .07509 .29481 .07749 .28867 .07628 .28755 Mtetra
.778 .761 .838 r
.07628 .28755 .07749 .28867 .07919 .28735 .07799 .28623 Mtetra
.643 .738 .918 r
.07799 .28623 .07919 .28735 .08078 .28682 .07958 .2857 Mtetra
.515 .695 .95 r
.07958 .2857 .08078 .28682 .08232 .28667 .08112 .28555 Mtetra
.747 .759 .862 r
.08112 .28555 .08232 .28667 .08399 .28561 .08279 .28448 Mtetra
.699 .751 .892 r
.08279 .28448 .08399 .28561 .08562 .28483 .08441 .2837 Mtetra
.496 .687 .952 r
.08441 .2837 .08562 .28483 .08715 .28472 .08595 .2836 Mtetra
.921 .531 .225 r
.08595 .2836 .08715 .28472 .08814 .28855 .08693 .28743 Mtetra
.939 .683 .522 r
.08693 .28743 .08814 .28855 .06092 .49404 .05961 .49298 Mtetra
.936 .589 .341 r
.05961 .49298 .06092 .49404 .06171 .50004 .0604 .49896 Mtetra
.211 .573 .941 r
.0604 .49896 .06171 .50004 .06329 .50038 .06199 .4993 Mtetra
.672 .769 .923 r
.06199 .4993 .06329 .50038 .06502 .49969 .06372 .49861 Mtetra
.753 .78 .875 r
.06372 .49861 .06502 .49969 .06682 .49854 .06551 .49746 Mtetra
.49 .71 .968 r
.06551 .49746 .06682 .49854 .06847 .49841 .06717 .49732 Mtetra
.586 .744 .952 r
.06717 .49732 .06847 .49841 .07016 .49803 .06886 .49694 Mtetra
.751 .779 .876 r
.06886 .49694 .07016 .49803 .07196 .4969 .07066 .4958 Mtetra
.908 .742 .664 r
.07066 .4958 .07196 .4969 .07434 .4914 .07305 .49028 Mtetra
.94 .687 .528 r
.07305 .49028 .07434 .4914 .10404 .28426 .10285 .28307 Mtetra
.911 .726 .64 r
.10285 .28307 .10404 .28426 .10646 .27779 .10526 .27663 Mtetra
.792 .758 .822 r
.10526 .27663 .10646 .27779 .10819 .2763 .107 .27514 Mtetra
.628 .729 .919 r
.107 .27514 .10819 .2763 .1098 .27582 .1086 .27466 Mtetra
.477 .673 .95 r
.1086 .27466 .1098 .27582 .11134 .27576 .11015 .2746 Mtetra
.622 .727 .922 r
.11015 .2746 .11134 .27576 .11295 .2753 .11175 .27413 Mtetra
.653 .736 .91 r
.11175 .27413 .11295 .2753 .11457 .27472 .11337 .27356 Mtetra
.66 .738 .908 r
.11337 .27356 .11457 .27472 .11619 .27411 .115 .27295 Mtetra
.749 .757 .858 r
.115 .27295 .11619 .27411 .11788 .273 .11669 .27185 Mtetra
.717 .752 .88 r
.11669 .27185 .11788 .273 .11954 .27211 .11835 .27095 Mtetra
.551 .705 .942 r
.11835 .27095 .11954 .27211 .12112 .27186 .11993 .27071 Mtetra
.898 .48 .131 r
.11993 .27071 .12112 .27186 .12225 .27514 .12105 .27398 Mtetra
.943 .684 .514 r
.12105 .27398 .12225 .27514 .09717 .48076 .09589 .47964 Mtetra
.941 .599 .347 r
.09589 .47964 .09717 .48076 .09796 .48747 .09667 .48636 Mtetra
0 .427 .857 r
.09667 .48636 .09796 .48747 .09954 .48812 .09825 .48702 Mtetra
.669 .766 .923 r
.09825 .48702 .09954 .48812 .10129 .48744 .10001 .48633 Mtetra
.759 .78 .87 r
.10001 .48633 .10129 .48744 .10311 .48623 .10183 .48512 Mtetra
.59 .742 .949 r
.10183 .48512 .10311 .48623 .10483 .48585 .10354 .48472 Mtetra
.611 .746 .941 r
.10354 .48472 .10483 .48585 .10655 .4854 .10527 .48425 Mtetra
.762 .774 .863 r
.10527 .48425 .10655 .4854 .10838 .48417 .1071 .48301 Mtetra
.911 .74 .657 r
.1071 .48301 .10838 .48417 .11076 .47846 .1095 .47721 Mtetra
.943 .688 .52 r
.1095 .47721 .11076 .47846 .13848 .27001 .13731 .26874 Mtetra
.908 .728 .646 r
.13731 .26874 .13848 .27001 .14079 .26401 .13961 .26282 Mtetra
.833 .758 .78 r
.13961 .26282 .14079 .26401 .14261 .26192 .14143 .26074 Mtetra
.706 .748 .885 r
.14143 .26074 .14261 .26192 .14428 .26109 .1431 .25991 Mtetra
.43 .649 .95 r
.1431 .25991 .14428 .26109 .14584 .26114 .14466 .25995 Mtetra
.822 .36 0 r
.14466 .25995 .14584 .26114 .1471 .26368 .14593 .26241 Mtetra
.946 .684 .508 r
.14593 .26241 .1471 .26368 .1239 .46687 .12279 .46441 Mtetra
.968 .667 .397 r
.12279 .46441 .1239 .46687 .1242 .47818 .12295 .47687 Mtetra
0 .022 .53 r
.12295 .47687 .1242 .47818 .12573 .47946 .12445 .47835 Mtetra
.587 .743 .951 r
.12445 .47835 .12573 .47946 .12748 .47895 .12619 .47795 Mtetra
.787 .802 .865 r
.12619 .47795 .12748 .47895 .12932 .47764 .12804 .47656 Mtetra
.879 .772 .74 r
.12804 .47656 .12932 .47764 .13121 .47595 .1301 .47346 Mtetra
.884 .682 .624 r
.1301 .47346 .13121 .47595 .13318 .4736 .13269 .46593 Mtetra
.939 .68 .519 r
.13269 .46593 .13318 .4736 .13535 .4696 .15865 .26154 Mtetra
.516 .281 .497 r
.15865 .26154 .13535 .4696 .16048 .27059 .16074 .25726 Mtetra
.581 .37 .56 r
.16074 .25726 .16048 .27059 .16341 .25916 .16256 .25526 Mtetra
.655 .513 .678 r
.16256 .25526 .16341 .25916 .16541 .2556 .16429 .25393 Mtetra
.692 .673 .827 r
.16429 .25393 .16541 .2556 .16717 .25408 .16598 .25305 Mtetra
.664 .768 .928 r
.16598 .25305 .16717 .25408 .16884 .25341 .16764 .25242 Mtetra
.633 .768 .944 r
.16764 .25242 .16884 .25341 .17047 .25302 .16929 .25189 Mtetra
.742 .766 .873 r
.16929 .25189 .17047 .25302 .17217 .25204 .171 .25085 Mtetra
.742 .757 .864 r
.171 .25085 .17217 .25204 .17388 .25096 .17271 .24978 Mtetra
.62 .727 .923 r
.17271 .24978 .17388 .25096 .17553 .2505 .17436 .24932 Mtetra
.765 .285 0 r
.17436 .24932 .17553 .2505 .17686 .25277 .1757 .25152 Mtetra
.949 .685 .501 r
.1757 .25152 .17686 .25277 .15533 .45806 .15415 .45618 Mtetra
.962 .644 .369 r
.15415 .45618 .15533 .45806 .15595 .46771 .15471 .4664 Mtetra
.539 .045 0 r
.15471 .4664 .15595 .46771 .1575 .46921 .15623 .46806 Mtetra
.537 .72 .958 r
.15623 .46806 .1575 .46921 .15925 .46885 .15797 .46781 Mtetra
.756 .799 .887 r
.15797 .46781 .15925 .46885 .16109 .46773 .15982 .46664 Mtetra
.866 .781 .765 r
.15982 .46664 .16109 .46773 .16298 .46609 .16183 .46399 Mtetra
.882 .697 .648 r
.16183 .46399 .16298 .46609 .16495 .46378 .16418 .45822 Mtetra
.944 .684 .511 r
.16418 .45822 .16495 .46378 .16708 .45999 .18843 .25227 Mtetra
.521 .285 .498 r
.18843 .25227 .16708 .45999 .17048 .44452 .19069 .24626 Mtetra
.512 .277 .496 r
.19069 .24626 .17048 .44452 .19337 .24833 .19255 .24398 Mtetra
.653 .5 .663 r
.19255 .24398 .19337 .24833 .1954 .24438 .19431 .24252 Mtetra
.695 .655 .806 r
.19431 .24252 .1954 .24438 .1972 .24264 .19603 .24155 Mtetra
.674 .763 .917 r
.19603 .24155 .1972 .24264 .19889 .2419 .19771 .24087 Mtetra
.641 .764 .937 r
.19771 .24087 .19889 .2419 .20055 .24148 .19938 .24031 Mtetra
.714 .758 .887 r
.19938 .24031 .20055 .24148 .20223 .24075 .20109 .23942 Mtetra
.729 .733 .854 r
.20109 .23942 .20223 .24075 .20395 .2398 .20281 .23839 Mtetra
.655 .7 .88 r
.20281 .23839 .20395 .2398 .20564 .23908 .20449 .23776 Mtetra
.018 .383 .845 r
.20449 .23776 .20564 .23908 .20727 .23899 .20603 .23854 Mtetra
.895 .491 .232 r
.20603 .23854 .20727 .23899 .2088 .23981 .20725 .24242 Mtetra
.947 .68 .496 r
.20725 .24242 .2088 .23981 .21019 .24203 .18776 .44716 Mtetra
.517 .276 .489 r
.18776 .44716 .21019 .24203 .21001 .25968 .18893 .45271 Mtetra
.507 .268 .487 r
.18893 .45271 .21001 .25968 .19215 .45151 .19053 .45398 Mtetra
.495 .09 .202 r
.19053 .45398 .19215 .45151 .19358 .45465 .19224 .45435 Mtetra
0 .555 .786 r
.19224 .45435 .19358 .45465 .1952 .45579 .19396 .45455 Mtetra
.458 .671 .955 r
.19396 .45455 .1952 .45579 .19694 .45583 .19571 .45452 Mtetra
.679 .741 .898 r
.19571 .45452 .19694 .45583 .19878 .45496 .19753 .45375 Mtetra
.873 .77 .745 r
.19753 .45375 .19878 .45496 .20083 .45183 .19958 .45077 Mtetra
.945 .722 .57 r
.19958 .45077 .20083 .45183 .2041 .43637 .20268 .43711 Mtetra
.955 .692 .499 r
.20268 .43711 .2041 .43637 .2257 .23355 .22452 .23261 Mtetra
.896 .786 .732 r
.22452 .23261 .2257 .23355 .22763 .2305 .22647 .22947 Mtetra
.691 .781 .92 r
.22647 .22947 .22763 .2305 .22934 .22978 .22818 .22871 Mtetra
.511 .713 .962 r
.22818 .22871 .22934 .22978 .23099 .22965 .22983 .22853 Mtetra
.599 .736 .941 r
.22983 .22853 .23099 .22965 .23265 .22936 .23151 .22812 Mtetra
.712 .748 .88 r
.23151 .22812 .23265 .22936 .23437 .22859 .23323 .22723 Mtetra
.636 .703 .895 r
.23323 .22723 .23437 .22859 .23607 .22799 .23493 .22668 Mtetra
.091 .432 .874 r
.23493 .22668 .23607 .22799 .23772 .22786 .23651 .22737 Mtetra
.894 .483 .21 r
.23651 .22737 .23772 .22786 .2393 .22852 .23779 .23124 Mtetra
.95 .68 .488 r
.23779 .23124 .2393 .22852 .24077 .23041 .22032 .43569 Mtetra
.517 .276 .489 r
.22032 .43569 .24077 .23041 .24138 .24173 .22155 .44145 Mtetra
.507 .268 .487 r
.22155 .44145 .24138 .24173 .22477 .44026 .22319 .44282 Mtetra
.498 .097 .21 r
.22319 .44282 .22477 .44026 .22624 .44356 .22492 .44322 Mtetra
.364 .802 .961 r
.22492 .44322 .22624 .44356 .22793 .44438 .22672 .44295 Mtetra
.676 .724 .886 r
.22672 .44295 .22793 .44438 .22977 .4437 .22856 .44217 Mtetra
.711 .719 .856 r
.22856 .44217 .22977 .4437 .23164 .44257 .23043 .44116 Mtetra
.68 .727 .886 r
.23043 .44116 .23164 .44257 .23351 .44156 .23228 .44036 Mtetra
.587 .734 .945 r
.23228 .44036 .23351 .44156 .23533 .44103 .23409 .43996 Mtetra
.691 .79 .926 r
.23409 .43996 .23533 .44103 .23718 .44028 .23594 .43914 Mtetra
.85 .789 .791 r
.23594 .43914 .23718 .44028 .23908 .43891 .23792 .43686 Mtetra
.905 .706 .622 r
.23792 .43686 .23908 .43891 .24108 .43635 .24034 .42962 Mtetra
.95 .683 .494 r
.24034 .42962 .24108 .43635 .24327 .43171 .2601 .22277 Mtetra
.518 .282 .497 r
.2601 .22277 .24327 .43171 .26244 .22939 .2622 .21779 Mtetra
.59 .383 .568 r
.2622 .21779 .26244 .22939 .26492 .22003 .26404 .21575 Mtetra
.646 .497 .667 r
.26404 .21575 .26492 .22003 .26688 .21653 .26582 .21441 Mtetra
.669 .62 .791 r
.26582 .21441 .26688 .21653 .26871 .21471 .26757 .21353 Mtetra
.625 .736 .927 r
.26757 .21353 .26871 .21471 .27043 .21409 .26928 .21303 Mtetra
.562 .737 .958 r
.26928 .21303 .27043 .21409 .27212 .21385 .27098 .21271 Mtetra
.565 .722 .947 r
.27098 .21271 .27212 .21385 .27381 .21366 .27268 .2124 Mtetra
.624 .72 .915 r
.27268 .2124 .27381 .21366 .27552 .21318 .27439 .2119 Mtetra
.632 .721 .911 r
.27439 .2119 .27552 .21318 .27724 .21266 .27611 .21137 Mtetra
.636 .719 .908 r
.27611 .21137 .27724 .21266 .27896 .21213 .27783 .21082 Mtetra
.637 .716 .905 r
.27783 .21082 .27896 .21213 .28068 .2116 .27956 .21027 Mtetra
.641 .715 .901 r
.27956 .21027 .28068 .2116 .28241 .21105 .28129 .2097 Mtetra
.645 .713 .897 r
.28129 .2097 .28241 .21105 .28413 .21047 .28302 .20911 Mtetra
.649 .712 .894 r
.28302 .20911 .28413 .21047 .28587 .20988 .28475 .2085 Mtetra
.653 .712 .891 r
.28475 .2085 .28587 .20988 .2876 .20926 .28648 .20788 Mtetra
.659 .713 .888 r
.28648 .20788 .2876 .20926 .28934 .20859 .28822 .20722 Mtetra
.665 .716 .887 r
.28822 .20722 .28934 .20859 .29108 .20789 .28996 .20654 Mtetra
.669 .722 .888 r
.28996 .20654 .29108 .20789 .29283 .20716 .29171 .20583 Mtetra
.681 .73 .887 r
.29171 .20583 .29283 .20716 .29458 .20633 .29346 .20507 Mtetra
.703 .748 .886 r
.29346 .20507 .29458 .20633 .29635 .2053 .29522 .2042 Mtetra
.679 .772 .921 r
.29522 .2042 .29635 .2053 .2981 .20459 .29697 .20347 Mtetra
.574 .734 .951 r
.29697 .20347 .2981 .20459 .29978 .20474 .29869 .20312 Mtetra
.3 .499 .884 r
.29869 .20312 .29978 .20474 .30127 .20762 .30035 .20361 Mtetra
.387 .336 .678 r
.30035 .20361 .30127 .20762 .28851 .40511 .30198 .20451 Mtetra
.503 .27 .494 r
.30198 .20451 .28851 .40511 .28947 .41686 .30362 .20536 Mtetra
.507 .273 .495 r
.30362 .20536 .28947 .41686 .29129 .41677 .30537 .20473 Mtetra
.508 .274 .495 r
.30537 .20473 .29129 .41677 .29322 .4154 .30716 .20362 Mtetra
.509 .275 .495 r
.30716 .20362 .29322 .4154 .29519 .41327 .30896 .20228 Mtetra
.30896 .20228 .29519 .41327 .29716 .41126 .31077 .20079 Mtetra
.507 .274 .495 r
.31077 .20079 .29716 .41126 .29907 .41009 .31254 .20002 Mtetra
.503 .27 .494 r
.31254 .20002 .29907 .41009 .30081 .41137 .31418 .20105 Mtetra
0 0 .184 r
.31418 .20105 .30081 .41137 .30241 .41476 .30179 .40502 Mtetra
0 0 .312 r
.30179 .40502 .30241 .41476 .30411 .41668 .303 .41415 Mtetra
0 .014 .589 r
.303 .41415 .30411 .41668 .3059 .41751 .30468 .41647 Mtetra
.516 .744 .978 r
.30468 .41647 .3059 .41751 .30777 .41706 .30654 .41622 Mtetra
.679 .839 .96 r
.30654 .41622 .30777 .41706 .30966 .41631 .30843 .41542 Mtetra
.726 .839 .934 r
.30843 .41542 .30966 .41631 .31156 .41545 .31035 .41442 Mtetra
.645 .791 .952 r
.31035 .41442 .31156 .41545 .31345 .41483 .31223 .41377 Mtetra
.645 .786 .949 r
.31223 .41377 .31345 .41483 .31533 .41422 .31413 .41312 Mtetra
.639 .776 .947 r
.31413 .41312 .31533 .41422 .31722 .41367 .31602 .4125 Mtetra
.6 .75 .949 r
.31602 .4125 .31722 .41367 .31909 .41341 .3179 .41202 Mtetra
.639 .725 .911 r
.3179 .41202 .31909 .41341 .32098 .41284 .31979 .41141 Mtetra
.701 .738 .879 r
.31979 .41141 .32098 .41284 .32291 .41158 .3217 .41047 Mtetra
.832 .808 .828 r
.3217 .41047 .32291 .41158 .325 .40774 .32368 .40855 Mtetra
.816 .985 .715 r
.32368 .40855 .325 .40774 .32742 .39853 .32569 .40615 Mtetra
.29 .013 .308 r
.32569 .40615 .32742 .39853 .34168 .19421 .3277 .40364 Mtetra
.504 .265 .486 r
.3277 .40364 .34168 .19421 .34349 .1931 .32956 .40352 Mtetra
.503 .265 .486 r
.32956 .40352 .34349 .1931 .34523 .19312 .33144 .40318 Mtetra
.501 .263 .485 r
.33144 .40318 .34523 .19312 .347 .19251 .33341 .40148 Mtetra
0 0 .194 r
.33341 .40148 .347 .19251 .349 .18819 .34725 .19775 Mtetra
0 0 0 r
.34725 .19775 .349 .18819 .35091 .18524 .34972 .18551 Mtetra
.967 .918 .702 r
.34972 .18551 .35091 .18524 .35277 .18321 .35167 .18192 Mtetra
.713 .75 .881 r
.35167 .18192 .35277 .18321 .35455 .1825 .35346 .18098 Mtetra
.596 .671 .892 r
.35346 .18098 .35455 .1825 .35632 .18209 .35523 .18058 Mtetra
.524 .64 .905 r
.35523 .18058 .35632 .18209 .35808 .18181 .35698 .18044 Mtetra
.643 .714 .899 r
.35698 .18044 .35808 .18181 .35986 .18119 .35876 .17984 Mtetra
.657 .724 .898 r
.35876 .17984 .35986 .18119 .36165 .18048 .36055 .17918 Mtetra
.675 .738 .898 r
.36055 .17918 .36165 .18048 .36344 .17969 .36234 .17844 Mtetra
.732 .764 .879 r
.36234 .17844 .36344 .17969 .36526 .17843 .36415 .1774 Mtetra
.72 .801 .915 r
.36415 .1774 .36526 .17843 .36707 .17744 .36595 .17647 Mtetra
.663 .799 .948 r
.36595 .17647 .36707 .17744 .36885 .17694 .36774 .17578 Mtetra
.477 .686 .959 r
.36774 .17578 .36885 .17694 .37052 .17847 .36951 .17569 Mtetra
.403 .421 .764 r
.36951 .17569 .37052 .17847 .37204 .1832 .37124 .17625 Mtetra
.359 .248 .589 r
.37124 .17625 .37204 .1832 .36344 .38955 .3729 .17814 Mtetra
0 0 .223 r
.3729 .17814 .36344 .38955 .36511 .39392 .36447 .38188 Mtetra
0 0 .361 r
.36447 .38188 .36511 .39392 .36692 .39551 .36584 .39225 Mtetra
0 .066 .611 r
.36584 .39225 .36692 .39551 .36879 .39602 .36761 .39482 Mtetra
.543 .726 .959 r
.36761 .39482 .36879 .39602 .37072 .39541 .36952 .39452 Mtetra
.714 .844 .944 r
.36952 .39452 .37072 .39541 .37266 .3944 .37147 .39356 Mtetra
.777 .86 .911 r
.37147 .39356 .37266 .3944 .37462 .39321 .37343 .39225 Mtetra
.67 .819 .955 r
.37343 .39225 .37462 .39321 .37656 .39241 .37537 .39147 Mtetra
.643 .816 .966 r
.37537 .39147 .37656 .39241 .3785 .39173 .37731 .39079 Mtetra
.621 .81 .973 r
.37731 .39079 .3785 .39173 .38043 .39115 .37924 .39019 Mtetra
.408 .715 .987 r
.37924 .39019 .38043 .39115 .38234 .39099 .38115 .39015 Mtetra
.511 .787 .995 r
.38115 .39015 .38234 .39099 .38426 .39069 .38308 .38982 Mtetra
.706 .847 .95 r
.38308 .38982 .38426 .39069 .38621 .39002 .38503 .38889 Mtetra
.912 .795 .718 r
.38503 .38889 .38621 .39002 .38819 .38825 .3871 .38523 Mtetra
.916 .685 .574 r
.3871 .38523 .38819 .38825 .39023 .38537 .38946 .37477 Mtetra
.96 .678 .459 r
.38946 .37477 .39023 .38537 .39237 .37989 .4 .16805 Mtetra
.513 .278 .496 r
.4 .16805 .39237 .37989 .40274 .17263 .40193 .16466 Mtetra
.614 .421 .597 r
.40193 .16466 .40274 .17263 .4048 .16595 .40379 .16276 Mtetra
.672 .556 .714 r
.40379 .16276 .4048 .16595 .40671 .16287 .40564 .16146 Mtetra
.697 .731 .877 r
.40564 .16146 .40671 .16287 .40855 .16166 .40746 .16058 Mtetra
.658 .778 .937 r
.40746 .16058 .40855 .16166 .41037 .16102 .40928 .15991 Mtetra
.635 .766 .942 r
.40928 .15991 .41037 .16102 .41217 .16059 .4111 .15933 Mtetra
.741 .769 .875 r
.4111 .15933 .41217 .16059 .41401 .15963 .41293 .15822 Mtetra
.709 .734 .871 r
.41293 .15822 .41401 .15963 .41584 .15872 .41477 .15726 Mtetra
.607 .691 .902 r
.41477 .15726 .41584 .15872 .41766 .15809 .41658 .1568 Mtetra
0 .072 .598 r
.41658 .1568 .41766 .15809 .41945 .1583 .41832 .15845 Mtetra
.911 .528 .277 r
.41832 .15845 .41945 .1583 .42121 .15945 .4199 .16492 Mtetra
.963 .674 .436 r
.4199 .16492 .42121 .15945 .4229 .16272 .41452 .37292 Mtetra
.51 .271 .487 r
.41452 .37292 .4229 .16272 .41778 .36939 .41636 .37601 Mtetra
.541 .22 .373 r
.41636 .37601 .41778 .36939 .41949 .37608 .41827 .37699 Mtetra
.362 0 0 r
.41827 .37699 .41949 .37608 .42136 .37828 .4202 .37719 Mtetra
.433 .7 .977 r
.4202 .37719 .42136 .37828 .4233 .37851 .42215 .37714 Mtetra
.611 .725 .927 r
.42215 .37714 .4233 .37851 .42527 .37791 .42412 .37662 Mtetra
.74 .781 .886 r
.42412 .37662 .42527 .37791 .42726 .37674 .42611 .37545 Mtetra
.901 .788 .727 r
.42611 .37545 .42726 .37674 .42927 .37464 .42816 .37203 Mtetra
.918 .698 .59 r
.42816 .37203 .42927 .37464 .43131 .37161 .43037 .36353 Mtetra
.965 .681 .443 r
.43037 .36353 .43131 .37161 .43339 .36738 .43839 .15454 Mtetra
.511 .277 .495 r
.43839 .15454 .43339 .36738 .43538 .36582 .44029 .15189 Mtetra
.507 .273 .495 r
.44029 .15189 .43538 .36582 .43734 .36564 .44213 .1513 Mtetra
.506 .272 .494 r
.44213 .1513 .43734 .36564 .43933 .36451 .44396 .15102 Mtetra
.51 .276 .495 r
.44396 .15102 .43933 .36451 .44662 .16108 .44585 .14885 Mtetra
.593 .382 .564 r
.44585 .14885 .44662 .16108 .44875 .14984 .44774 .1465 Mtetra
.713 .573 .696 r
.44774 .1465 .44875 .14984 .45067 .14601 .44962 .1446 Mtetra
.73 .744 .863 r
.44962 .1446 .45067 .14601 .45254 .14447 .45147 .1435 Mtetra
.662 .808 .953 r
.45147 .1435 .45254 .14447 .45439 .14374 .45332 .1428 Mtetra
.613 .797 .97 r
.45332 .1428 .45439 .14374 .45623 .14333 .45517 .14226 Mtetra
.62 .772 .953 r
.45517 .14226 .45623 .14333 .45808 .14286 .45702 .14171 Mtetra
.624 .757 .942 r
.45702 .14171 .45808 .14286 .45993 .14237 .45887 .14116 Mtetra
.627 .748 .934 r
.45887 .14116 .45993 .14237 .46177 .14187 .46072 .14061 Mtetra
.647 .745 .92 r
.46072 .14061 .46177 .14187 .46363 .14127 .46257 .13997 Mtetra
.663 .743 .91 r
.46257 .13997 .46363 .14127 .46548 .14059 .46443 .13926 Mtetra
.674 .743 .902 r
.46443 .13926 .46548 .14059 .46734 .13984 .46629 .1385 Mtetra
.691 .747 .894 r
.46629 .1385 .46734 .13984 .4692 .13899 .46815 .13765 Mtetra
.699 .749 .89 r
.46815 .13765 .4692 .13899 .47107 .13809 .47001 .13676 Mtetra
.698 .749 .892 r
.47001 .13676 .47107 .13809 .47293 .1372 .47188 .13587 Mtetra
.683 .745 .898 r
.47188 .13587 .47293 .1372 .47479 .1364 .47374 .13507 Mtetra
.671 .741 .902 r
.47374 .13507 .47479 .1364 .47666 .13566 .47561 .13432 Mtetra
.666 .737 .903 r
.47561 .13432 .47666 .13566 .47852 .13494 .47747 .13359 Mtetra
.666 .736 .902 r
.47747 .13359 .47852 .13494 .48039 .13422 .47934 .13286 Mtetra
.665 .735 .902 r
.47934 .13286 .48039 .13422 .48226 .13349 .48121 .13213 Mtetra
.664 .734 .902 r
.48121 .13213 .48226 .13349 .48412 .13277 .48308 .13141 Mtetra
.663 .734 .902 r
.48308 .13141 .48412 .13277 .48599 .13206 .48495 .1307 Mtetra
.662 .733 .903 r
.48495 .1307 .48599 .13206 .48787 .13135 .48682 .12999 Mtetra
.661 .733 .903 r
.48682 .12999 .48787 .13135 .48974 .13064 .48869 .12928 Mtetra
.48869 .12928 .48974 .13064 .49161 .12993 .49057 .12857 Mtetra
.66 .733 .904 r
.49057 .12857 .49161 .12993 .49349 .12923 .49244 .12787 Mtetra
.49244 .12787 .49349 .12923 .49536 .12853 .49432 .12716 Mtetra
.659 .733 .904 r
.49432 .12716 .49536 .12853 .49724 .12783 .4962 .12646 Mtetra
.659 .732 .904 r
.4962 .12646 .49724 .12783 .49912 .12713 .49808 .12576 Mtetra
.658 .732 .904 r
.49808 .12576 .49912 .12713 .501 .12644 .49996 .12507 Mtetra
.657 .73 .903 r
.49996 .12507 .501 .12644 .50288 .12575 .50184 .12437 Mtetra
.657 .729 .903 r
.50184 .12437 .50288 .12575 .50476 .12507 .50373 .12368 Mtetra
.657 .728 .902 r
.50373 .12368 .50476 .12507 .50665 .12439 .50561 .12299 Mtetra
.657 .726 .9 r
.50561 .12299 .50665 .12439 .50853 .1237 .5075 .12229 Mtetra
.658 .725 .899 r
.5075 .12229 .50853 .1237 .51042 .12301 .50938 .12159 Mtetra
.658 .724 .898 r
.50938 .12159 .51042 .12301 .51231 .12231 .51127 .12089 Mtetra
.659 .723 .897 r
.51127 .12089 .51231 .12231 .5142 .12161 .51316 .12018 Mtetra
.659 .723 .896 r
.51316 .12018 .5142 .12161 .51609 .12091 .51505 .11947 Mtetra
.659 .722 .895 r
.51505 .11947 .51609 .12091 .51798 .1202 .51695 .11876 Mtetra
.66 .722 .895 r
.51695 .11876 .51798 .1202 .51987 .11949 .51884 .11805 Mtetra
.66 .721 .894 r
.51884 .11805 .51987 .11949 .52177 .11878 .52074 .11733 Mtetra
.52074 .11733 .52177 .11878 .52366 .11806 .52263 .11661 Mtetra
.52263 .11661 .52366 .11806 .52556 .11734 .52453 .11589 Mtetra
.661 .721 .893 r
.52453 .11589 .52556 .11734 .52746 .11662 .52643 .11517 Mtetra
.52643 .11517 .52746 .11662 .52936 .1159 .52833 .11445 Mtetra
.52833 .11445 .52936 .1159 .53126 .11518 .53023 .11372 Mtetra
.661 .72 .893 r
.53023 .11372 .53126 .11518 .53316 .11446 .53214 .113 Mtetra
.53214 .113 .53316 .11446 .53507 .11373 .53404 .11227 Mtetra
.53404 .11227 .53507 .11373 .53697 .11301 .53595 .11155 Mtetra
.53595 .11155 .53697 .11301 .53888 .11228 .53785 .11082 Mtetra
.53785 .11082 .53888 .11228 .54078 .11155 .53976 .11009 Mtetra
.53976 .11009 .54078 .11155 .54269 .11082 .54167 .10936 Mtetra
.54167 .10936 .54269 .11082 .5446 .1101 .54358 .10863 Mtetra
.661 .72 .892 r
.54358 .10863 .5446 .1101 .54652 .10937 .5455 .1079 Mtetra
.5455 .1079 .54652 .10937 .54843 .10864 .54741 .10717 Mtetra
.54741 .10717 .54843 .10864 .55034 .10791 .54933 .10644 Mtetra
.54933 .10644 .55034 .10791 .55226 .10717 .55124 .1057 Mtetra
.55124 .1057 .55226 .10717 .55418 .10644 .55316 .10497 Mtetra
.55316 .10497 .55418 .10644 .55609 .10571 .55508 .10424 Mtetra
.55508 .10424 .55609 .10571 .55801 .10498 .557 .1035 Mtetra
.557 .1035 .55801 .10498 .55994 .10424 .55892 .10277 Mtetra
.55892 .10277 .55994 .10424 .56186 .10351 .56084 .10203 Mtetra
.56084 .10203 .56186 .10351 .56378 .10277 .56277 .1013 Mtetra
.56277 .1013 .56378 .10277 .56571 .10204 .56469 .10056 Mtetra
.56469 .10056 .56571 .10204 .56763 .1013 .56662 .09982 Mtetra
.662 .72 .892 r
.56662 .09982 .56763 .1013 .56956 .10057 .56855 .09909 Mtetra
.56855 .09909 .56956 .10057 .57149 .09983 .57048 .09835 Mtetra
.57048 .09835 .57149 .09983 .57342 .09909 .57241 .09761 Mtetra
.57241 .09761 .57342 .09909 .57535 .09835 .57434 .09687 Mtetra
.57434 .09687 .57535 .09835 .57728 .09761 .57628 .09613 Mtetra
.57628 .09613 .57728 .09761 .57922 .09687 .57821 .09539 Mtetra
.57821 .09539 .57922 .09687 .58116 .09613 .58015 .09464 Mtetra
.58015 .09464 .58116 .09613 .58309 .09539 .58209 .0939 Mtetra
.58209 .0939 .58309 .09539 .58503 .09464 .58403 .09315 Mtetra
.58403 .09315 .58503 .09464 .58697 .0939 .58597 .09241 Mtetra
.58597 .09241 .58697 .0939 .58891 .09315 .58791 .09166 Mtetra
.663 .72 .892 r
.58791 .09166 .58891 .09315 .59085 .0924 .58985 .09091 Mtetra
.663 .72 .891 r
.58985 .09091 .59085 .0924 .5928 .09165 .5918 .09016 Mtetra
.5918 .09016 .5928 .09165 .59474 .0909 .59374 .08941 Mtetra
.59374 .08941 .59474 .0909 .59669 .09015 .59569 .08865 Mtetra
.59569 .08865 .59669 .09015 .59864 .0894 .59764 .0879 Mtetra
.663 .719 .89 r
.59764 .0879 .59864 .0894 .60059 .08865 .59959 .08714 Mtetra
.59959 .08714 .60059 .08865 .60254 .08789 .60154 .08638 Mtetra
.60154 .08638 .60254 .08789 .60449 .08714 .60349 .08563 Mtetra
.663 .718 .89 r
.60349 .08563 .60449 .08714 .60644 .08638 .60545 .08487 Mtetra
.662 .718 .89 r
.60545 .08487 .60644 .08638 .6084 .08563 .6074 .08412 Mtetra
.662 .717 .89 r
.6074 .08412 .6084 .08563 .61035 .08488 .60936 .08336 Mtetra
.661 .717 .89 r
.60936 .08336 .61035 .08488 .61231 .08413 .61132 .08261 Mtetra
.61132 .08261 .61231 .08413 .61427 .08338 .61328 .08186 Mtetra
.61328 .08186 .61427 .08338 .61623 .08263 .61524 .08112 Mtetra
.66 .717 .891 r
.61524 .08112 .61623 .08263 .61819 .08189 .6172 .08037 Mtetra
.6172 .08037 .61819 .08189 .62015 .08114 .61916 .07962 Mtetra
.66 .718 .891 r
.61916 .07962 .62015 .08114 .62212 .08039 .62113 .07888 Mtetra
.66 .718 .892 r
.62113 .07888 .62212 .08039 .62408 .07964 .6231 .07813 Mtetra
.661 .719 .892 r
.6231 .07813 .62408 .07964 .62605 .07889 .62507 .07738 Mtetra
.661 .72 .892 r
.62507 .07738 .62605 .07889 .62802 .07814 .62703 .07663 Mtetra
.662 .72 .892 r
.62703 .07663 .62802 .07814 .62999 .07738 .62901 .07587 Mtetra
.663 .721 .892 r
.62901 .07587 .62999 .07738 .63196 .07662 .63098 .07511 Mtetra
.664 .721 .892 r
.63098 .07511 .63196 .07662 .63393 .07586 .63295 .07435 Mtetra
.665 .722 .891 r
.63295 .07435 .63393 .07586 .63591 .07508 .63492 .07357 Mtetra
.668 .723 .89 r
.63492 .07357 .63591 .07508 .63788 .0743 .6369 .07278 Mtetra
.668 .722 .89 r
.6369 .07278 .63788 .0743 .63986 .07351 .63888 .07199 Mtetra
.682 .728 .885 r
.63888 .07199 .63986 .07351 .64183 .07268 .64085 .07113 Mtetra
.718 .737 .867 r
.64085 .07113 .64183 .07268 .6438 .07171 .64282 .07005 Mtetra
.659 .695 .873 r
.64282 .07005 .6438 .07171 .64578 .07093 .6448 .06928 Mtetra
.462 .6 .903 r
.6448 .06928 .64578 .07093 .64778 .07061 .64682 .06936 Mtetra
.595 .14 0 r
.64682 .06936 .64778 .07061 .64984 .07152 .64896 .07232 Mtetra
.973 .663 .33 r
.64896 .07232 .64984 .07152 .65194 .07339 .65997 .27867 Mtetra
.524 .281 .488 r
.65997 .27867 .65194 .07339 .65409 .07626 .66262 .28946 Mtetra
.504 .266 .486 r
.66262 .28946 .65409 .07626 .65612 .07623 .6648 .2895 Mtetra
.502 .264 .486 r
.6648 .2895 .65612 .07623 .65808 .07477 .66693 .28836 Mtetra
.501 .263 .486 r
.66693 .28836 .65808 .07477 .66002 .0728 .66903 .28663 Mtetra
.502 .264 .486 r
.66903 .28663 .66002 .0728 .66196 .07087 .67115 .2853 Mtetra
.67115 .2853 .66196 .07087 .66395 .0699 .67329 .28431 Mtetra
.504 .265 .486 r
.67329 .28431 .66395 .0699 .66605 .07121 .67548 .28427 Mtetra
.507 .268 .486 r
.67548 .28427 .66605 .07121 .67845 .28061 .67775 .28583 Mtetra
.544 .196 .328 r
.67775 .28583 .67845 .28061 .68096 .28687 .68 .28688 Mtetra
.194 0 0 r
.68 .28688 .68096 .28687 .68325 .28883 .68222 .28728 Mtetra
.639 .726 .911 r
.68222 .28728 .68325 .28883 .68543 .2883 .68438 .28657 Mtetra
.684 .719 .876 r
.68438 .28657 .68543 .2883 .68757 .28722 .68653 .2856 Mtetra
.691 .738 .887 r
.68653 .2856 .68757 .28722 .68971 .28598 .68869 .28462 Mtetra
.536 .713 .953 r
.68869 .28462 .68971 .28598 .69189 .28547 .69088 .28431 Mtetra
.611 .788 .966 r
.69088 .28431 .69189 .28547 .69407 .28483 .69306 .28369 Mtetra
.77 .847 .909 r
.69306 .28369 .69407 .28483 .69622 .28382 .6952 .28231 Mtetra
.941 .796 .672 r
.6952 .28231 .69622 .28382 .69833 .28187 .69716 .27787 Mtetra
.963 .681 .451 r
.69716 .27787 .69833 .28187 .70037 .27888 .69816 .25622 Mtetra
.965 .651 .371 r
.69816 .25622 .70037 .27888 .70226 .27311 .68902 .05732 Mtetra
.512 .277 .495 r
.68902 .05732 .70226 .27311 .69223 .06197 .69091 .05434 Mtetra
.612 .422 .601 r
.69091 .05434 .69223 .06197 .69392 .05561 .69287 .05248 Mtetra
.672 .567 .729 r
.69287 .05248 .69392 .05561 .6958 .0526 .69486 .05118 Mtetra
.688 .753 .901 r
.69486 .05118 .6958 .0526 .6978 .05148 .69687 .05029 Mtetra
.645 .779 .945 r
.69687 .05029 .6978 .05148 .69983 .05082 .69889 .0496 Mtetra
.63 .766 .945 r
.69889 .0496 .69983 .05082 .70187 .05035 .70092 .04897 Mtetra
.76 .786 .874 r
.70092 .04897 .70187 .05035 .70385 .04904 .70291 .04766 Mtetra
.692 .76 .904 r
.70291 .04766 .70385 .04904 .70587 .04814 .70493 .04674 Mtetra
.497 .666 .938 r
.70493 .04674 .70587 .04814 .70794 .04803 .707 .04662 Mtetra
.748 .329 0 r
.707 .04662 .70794 .04803 .71033 .053 .70939 .05161 Mtetra
.97 .655 .291 r
.70939 .05161 .71033 .053 .72645 .26822 .72545 .26686 Mtetra
.737 .304 0 r
.72545 .26686 .72645 .26822 .72902 .27316 .72802 .27179 Mtetra
.043 .472 .883 r
.03342 .50728 .03474 .50834 .03627 .50889 .03495 .50782 Mtetra
.646 .763 .934 r
.03495 .50782 .03627 .50889 .03797 .50831 .03665 .50724 Mtetra
.81 .779 .824 r
.03665 .50724 .03797 .50831 .03983 .50661 .03852 .50554 Mtetra
.909 .737 .658 r
.03852 .50554 .03983 .50661 .04231 .50067 .041 .49961 Mtetra
.937 .686 .534 r
.041 .49961 .04231 .50067 .07388 .29371 .07266 .2926 Mtetra
.909 .728 .646 r
.07266 .2926 .07388 .29371 .07628 .28755 .07507 .28643 Mtetra
.777 .761 .838 r
.07507 .28643 .07628 .28755 .07799 .28623 .07678 .28511 Mtetra
.643 .737 .918 r
.07678 .28511 .07799 .28623 .07958 .2857 .07837 .28458 Mtetra
.514 .694 .95 r
.07837 .28458 .07958 .2857 .08112 .28555 .07991 .28443 Mtetra
.747 .759 .862 r
.07991 .28443 .08112 .28555 .08279 .28448 .08158 .28336 Mtetra
.699 .751 .892 r
.08158 .28336 .08279 .28448 .08441 .2837 .08321 .28258 Mtetra
.495 .687 .953 r
.08321 .28258 .08441 .2837 .08595 .2836 .08474 .28247 Mtetra
.922 .532 .227 r
.08474 .28247 .08595 .2836 .08693 .28743 .08572 .28632 Mtetra
.939 .683 .522 r
.08572 .28632 .08693 .28743 .05961 .49298 .0583 .49195 Mtetra
.935 .588 .342 r
.0583 .49195 .05961 .49298 .0604 .49896 .0591 .4979 Mtetra
.211 .575 .941 r
.0591 .4979 .0604 .49896 .06199 .4993 .06068 .49823 Mtetra
.673 .771 .924 r
.06068 .49823 .06199 .4993 .06372 .49861 .06241 .49753 Mtetra
.754 .782 .876 r
.06241 .49753 .06372 .49861 .06551 .49746 .06421 .49638 Mtetra
.492 .712 .969 r
.06421 .49638 .06551 .49746 .06717 .49732 .06587 .49624 Mtetra
.588 .746 .952 r
.06587 .49624 .06717 .49732 .06886 .49694 .06756 .49585 Mtetra
.753 .779 .874 r
.06756 .49585 .06886 .49694 .07066 .4958 .06936 .4947 Mtetra
.908 .741 .662 r
.06936 .4947 .07066 .4958 .07305 .49028 .07177 .48909 Mtetra
.94 .687 .528 r
.07177 .48909 .07305 .49028 .10285 .28307 .10168 .28173 Mtetra
.905 .72 .641 r
.10168 .28173 .10285 .28307 .10526 .27663 .10407 .2754 Mtetra
.786 .749 .819 r
.10407 .2754 .10526 .27663 .107 .27514 .10581 .27393 Mtetra
.624 .718 .914 r
.10581 .27393 .107 .27514 .1086 .27466 .10741 .27346 Mtetra
.473 .664 .946 r
.10741 .27346 .1086 .27466 .11015 .2746 .10896 .27342 Mtetra
.619 .723 .92 r
.10896 .27342 .11015 .2746 .11175 .27413 .11056 .27297 Mtetra
.651 .734 .91 r
.11056 .27297 .11175 .27413 .11337 .27356 .11218 .27239 Mtetra
.659 .737 .908 r
.11218 .27239 .11337 .27356 .115 .27295 .1138 .27179 Mtetra
.749 .756 .859 r
.1138 .27179 .115 .27295 .11669 .27185 .11549 .27069 Mtetra
.716 .752 .881 r
.11549 .27069 .11669 .27185 .11835 .27095 .11716 .26981 Mtetra
.548 .705 .943 r
.11716 .26981 .11835 .27095 .11993 .27071 .11874 .26957 Mtetra
.901 .485 .14 r
.11874 .26957 .11993 .27071 .12105 .27398 .11985 .27288 Mtetra
.943 .684 .514 r
.11985 .27288 .12105 .27398 .09589 .47964 .09457 .47874 Mtetra
.935 .592 .353 r
.09457 .47874 .09589 .47964 .09667 .48636 .09537 .48534 Mtetra
0 .429 .849 r
.09537 .48534 .09667 .48636 .09825 .48702 .09695 .48597 Mtetra
.674 .778 .929 r
.09695 .48597 .09825 .48702 .10001 .48633 .09871 .48526 Mtetra
.764 .787 .872 r
.09871 .48526 .10001 .48633 .10183 .48512 .10053 .48403 Mtetra
.608 .753 .948 r
.10053 .48403 .10183 .48512 .10354 .48472 .10226 .48357 Mtetra
.622 .746 .935 r
.10226 .48357 .10354 .48472 .10527 .48425 .10399 .48307 Mtetra
.756 .768 .863 r
.10399 .48307 .10527 .48425 .1071 .48301 .10582 .48185 Mtetra
.906 .745 .671 r
.10582 .48185 .1071 .48301 .1095 .47721 .10814 .47671 Mtetra
.944 .689 .52 r
.10814 .47671 .1095 .47721 .13731 .26874 .1359 .26931 Mtetra
.971 .813 .628 r
.1359 .26931 .13731 .26874 .13961 .26282 .13831 .26258 Mtetra
.896 .889 .817 r
.13831 .26258 .13961 .26282 .14143 .26074 .14015 .26042 Mtetra
.7 .917 .968 r
.14015 .26042 .14143 .26074 .1431 .25991 .14182 .25957 Mtetra
.122 .649 .875 r
.14182 .25957 .1431 .25991 .14466 .25995 .14338 .25963 Mtetra
.846 .399 .154 r
.14338 .25963 .14466 .25995 .14593 .26241 .14463 .26222 Mtetra
.945 .683 .509 r
.14463 .26222 .14593 .26241 .12279 .46441 .1213 .46504 Mtetra
.911 .596 .436 r
.1213 .46504 .12279 .46441 .12295 .47687 .12172 .47535 Mtetra
0 .005 .541 r
.12172 .47535 .12295 .47687 .12445 .47835 .1232 .47695 Mtetra
.537 .672 .925 r
.1232 .47695 .12445 .47835 .12619 .47795 .12491 .47675 Mtetra
.769 .769 .853 r
.12491 .47675 .12619 .47795 .12804 .47656 .12676 .47542 Mtetra
.901 .754 .689 r
.12676 .47542 .12804 .47656 .1301 .47346 .12899 .47098 Mtetra
.944 .687 .517 r
.12899 .47098 .1301 .47346 .13269 .46593 .15544 .26406 Mtetra
.528 .291 .499 r
.15544 .26406 .13269 .46593 .15865 .26154 .15806 .25538 Mtetra
.653 .468 .621 r
.15806 .25538 .15865 .26154 .16074 .25726 .15989 .25326 Mtetra
.596 .471 .68 r
.15989 .25326 .16074 .25726 .16256 .25526 .16155 .2526 Mtetra
.555 .512 .762 r
.16155 .2526 .16256 .25526 .16429 .25393 .16316 .25239 Mtetra
.612 .661 .874 r
.16316 .25239 .16429 .25393 .16598 .25305 .1648 .25196 Mtetra
.661 .757 .921 r
.1648 .25196 .16598 .25305 .16764 .25242 .16646 .25134 Mtetra
.655 .757 .925 r
.16646 .25134 .16764 .25242 .16929 .25189 .16811 .25074 Mtetra
.704 .755 .891 r
.16811 .25074 .16929 .25189 .171 .25085 .1698 .24991 Mtetra
.686 .793 .93 r
.1698 .24991 .171 .25085 .17271 .24978 .17147 .24919 Mtetra
.403 .77 .994 r
.17147 .24919 .17271 .24978 .17436 .24932 .17308 .24904 Mtetra
.846 .399 .154 r
.17308 .24904 .17436 .24932 .1757 .25152 .17437 .25171 Mtetra
.947 .683 .502 r
.17437 .25171 .1757 .25152 .15415 .45618 .15263 .45728 Mtetra
.887 .554 .412 r
.15263 .45728 .15415 .45618 .15471 .4664 .15347 .465 Mtetra
0 .083 .604 r
.15347 .465 .15471 .4664 .15623 .46806 .15502 .46643 Mtetra
.597 .659 .881 r
.15502 .46643 .15623 .46806 .15797 .46781 .15678 .46603 Mtetra
.751 .694 .796 r
.15678 .46603 .15797 .46781 .15982 .46664 .15865 .46455 Mtetra
.855 .694 .683 r
.15865 .46455 .15982 .46664 .16183 .46399 .16082 .46046 Mtetra
.946 .686 .51 r
.16082 .46046 .16183 .46399 .16418 .45822 .18518 .2553 Mtetra
.533 .295 .5 r
.18518 .2553 .16418 .45822 .18843 .25227 .18798 .24451 Mtetra
.644 .446 .6 r
.18798 .24451 .18843 .25227 .19069 .24626 .18986 .242 Mtetra
.604 .469 .67 r
.18986 .242 .19069 .24626 .19255 .24398 .19155 .2412 Mtetra
.575 .516 .751 r
.19155 .2412 .19255 .24398 .19431 .24252 .1932 .24087 Mtetra
.618 .648 .858 r
.1932 .24087 .19431 .24252 .19603 .24155 .19486 .2404 Mtetra
.676 .75 .907 r
.19486 .2404 .19603 .24155 .19771 .24087 .19654 .2397 Mtetra
.666 .746 .91 r
.19654 .2397 .19771 .24087 .19938 .24031 .19823 .23905 Mtetra
.694 .736 .883 r
.19823 .23905 .19938 .24031 .20109 .23942 .19992 .23825 Mtetra
.685 .75 .901 r
.19992 .23825 .20109 .23942 .20281 .23839 .20162 .23751 Mtetra
.5 .75 .985 r
.20162 .23751 .20281 .23839 .20449 .23776 .20326 .2373 Mtetra
.787 .288 0 r
.20326 .2373 .20449 .23776 .20603 .23854 .20466 .23934 Mtetra
.949 .682 .495 r
.20466 .23934 .20603 .23854 .20725 .24242 .18519 .44203 Mtetra
.529 .287 .492 r
.18519 .44203 .20725 .24242 .18776 .44716 .18575 .45329 Mtetra
.594 .273 .396 r
.18575 .45329 .18776 .44716 .18893 .45271 .18731 .45506 Mtetra
.356 0 .108 r
.18731 .45506 .18893 .45271 .19053 .45398 .18908 .45475 Mtetra
0 0 0 r
.18908 .45475 .19053 .45398 .19224 .45435 .19091 .45387 Mtetra
.63 .887 .987 r
.19091 .45387 .19224 .45435 .19396 .45455 .19273 .45318 Mtetra
.613 .709 .913 r
.19273 .45318 .19396 .45455 .19571 .45452 .19452 .4527 Mtetra
.703 .677 .822 r
.19452 .4527 .19571 .45452 .19753 .45375 .19637 .45165 Mtetra
.833 .692 .707 r
.19637 .45165 .19753 .45375 .19958 .45077 .19845 .44841 Mtetra
.934 .693 .551 r
.19845 .44841 .19958 .45077 .20268 .43711 .20224 .42776 Mtetra
.944 .679 .505 r
.20224 .42776 .20268 .43711 .22452 .23261 .22334 .23171 Mtetra
.895 .793 .74 r
.22334 .23171 .22452 .23261 .22647 .22947 .22527 .2287 Mtetra
.717 .838 .939 r
.22527 .2287 .22647 .22947 .22818 .22871 .22699 .22783 Mtetra
.555 .773 .979 r
.22699 .22783 .22818 .22871 .22983 .22853 .22866 .2275 Mtetra
.651 .77 .936 r
.22866 .2275 .22983 .22853 .23151 .22812 .23036 .2269 Mtetra
.73 .754 .871 r
.23036 .2269 .23151 .22812 .23323 .22723 .2321 .22589 Mtetra
.624 .704 .903 r
.2321 .22589 .23323 .22723 .23493 .22668 .23378 .22539 Mtetra
0 .063 .584 r
.23378 .22539 .23493 .22668 .23651 .22737 .23529 .22682 Mtetra
.951 .656 .444 r
.23529 .22682 .23651 .22737 .23779 .23124 .23488 .24862 Mtetra
.931 .657 .499 r
.23488 .24862 .23779 .23124 .22032 .43569 .21841 .44168 Mtetra
.616 .292 .399 r
.21841 .44168 .22032 .43569 .22155 .44145 .21998 .44386 Mtetra
.335 0 .101 r
.21998 .44386 .22155 .44145 .22319 .44282 .22178 .44345 Mtetra
.434 .856 .71 r
.22178 .44345 .22319 .44282 .22492 .44322 .22365 .44239 Mtetra
.753 .845 .92 r
.22365 .44239 .22492 .44322 .22672 .44295 .22552 .44127 Mtetra
.668 .685 .856 r
.22552 .44127 .22672 .44295 .22856 .44217 .22737 .44049 Mtetra
.67 .686 .856 r
.22737 .44049 .22856 .44217 .23043 .44116 .22922 .43971 Mtetra
.628 .704 .9 r
.22922 .43971 .23043 .44116 .23228 .44036 .23104 .43916 Mtetra
.56 .724 .95 r
.23104 .43916 .23228 .44036 .23409 .43996 .23285 .43884 Mtetra
.699 .783 .916 r
.23285 .43884 .23409 .43996 .23594 .43914 .2347 .43797 Mtetra
.875 .781 .754 r
.2347 .43797 .23594 .43914 .23792 .43686 .23674 .4351 Mtetra
.946 .702 .538 r
.23674 .4351 .23792 .43686 .24034 .42962 .24048 .41286 Mtetra
.939 .67 .501 r
.24048 .41286 .24034 .42962 .2601 .22277 .25927 .21798 Mtetra
.732 .543 .637 r
.25927 .21798 .2601 .22277 .2622 .21779 .26122 .21473 Mtetra
.637 .538 .725 r
.26122 .21473 .2622 .21779 .26404 .21575 .26296 .21386 Mtetra
.585 .607 .841 r
.26296 .21386 .26404 .21575 .26582 .21441 .26466 .21352 Mtetra
.545 .771 .982 r
.26466 .21352 .26582 .21441 .26757 .21353 .26635 .2132 Mtetra
.641 .917 .979 r
.26635 .2132 .26757 .21353 .26928 .21303 .26809 .21246 Mtetra
.672 .878 .976 r
.26809 .21246 .26928 .21303 .27098 .21271 .26982 .21171 Mtetra
.669 .786 .937 r
.26982 .21171 .27098 .21271 .27268 .2124 .27155 .21104 Mtetra
.639 .708 .897 r
.27155 .21104 .27268 .2124 .27439 .2119 .27327 .21047 Mtetra
.631 .694 .891 r
.27327 .21047 .27439 .2119 .27611 .21137 .27499 .20994 Mtetra
.632 .695 .89 r
.27499 .20994 .27611 .21137 .27783 .21082 .27672 .20941 Mtetra
.64 .7 .89 r
.27672 .20941 .27783 .21082 .27956 .21027 .27844 .20884 Mtetra
.643 .698 .886 r
.27844 .20884 .27956 .21027 .28129 .2097 .28017 .20825 Mtetra
.646 .697 .883 r
.28017 .20825 .28129 .2097 .28302 .20911 .2819 .20765 Mtetra
.649 .696 .88 r
.2819 .20765 .28302 .20911 .28475 .2085 .28364 .20703 Mtetra
.652 .695 .878 r
.28364 .20703 .28475 .2085 .28648 .20788 .28537 .2064 Mtetra
.655 .696 .876 r
.28537 .2064 .28648 .20788 .28822 .20722 .28711 .20575 Mtetra
.658 .699 .876 r
.28711 .20575 .28822 .20722 .28996 .20654 .28885 .20509 Mtetra
.662 .703 .878 r
.28885 .20509 .28996 .20654 .29171 .20583 .29059 .20441 Mtetra
.665 .708 .88 r
.29059 .20441 .29171 .20583 .29346 .20507 .29234 .20371 Mtetra
.669 .721 .888 r
.29234 .20371 .29346 .20507 .29522 .2042 .29409 .20301 Mtetra
.675 .752 .909 r
.29409 .20301 .29522 .2042 .29697 .20347 .29584 .20229 Mtetra
.676 .755 .91 r
.29584 .20229 .29697 .20347 .29869 .20312 .29759 .20157 Mtetra
.667 .69 .862 r
.29759 .20157 .29869 .20312 .30035 .20361 .29934 .20085 Mtetra
.629 .552 .749 r
.29934 .20085 .30035 .20361 .30198 .20451 .30109 .20011 Mtetra
.596 .462 .668 r
.30109 .20011 .30198 .20451 .30362 .20536 .30285 .19935 Mtetra
.578 .416 .626 r
.30285 .19935 .30362 .20536 .30537 .20473 .30461 .19857 Mtetra
.576 .413 .623 r
.30461 .19857 .30537 .20473 .30716 .20362 .30637 .19778 Mtetra
.584 .424 .63 r
.30637 .19778 .30716 .20362 .30896 .20228 .30813 .19692 Mtetra
.608 .448 .64 r
.30813 .19692 .30896 .20228 .31077 .20079 .30992 .19581 Mtetra
.582 .438 .651 r
.30992 .19581 .31077 .20079 .31254 .20002 .31168 .19511 Mtetra
.482 .371 .651 r
.31168 .19511 .31254 .20002 .31418 .20105 .31336 .19547 Mtetra
0 0 .402 r
.31336 .19547 .31418 .20105 .30179 .40502 .31472 .20047 Mtetra
0 0 .157 r
.31472 .20047 .30179 .40502 .303 .41415 .30201 .40977 Mtetra
0 0 .393 r
.30201 .40977 .303 .41415 .30468 .41647 .30354 .41423 Mtetra
.521 .554 .83 r
.30354 .41423 .30468 .41647 .30654 .41622 .30539 .41417 Mtetra
.666 .644 .819 r
.30539 .41417 .30654 .41622 .30843 .41542 .30729 .41331 Mtetra
.704 .655 .798 r
.30729 .41331 .30843 .41542 .31035 .41442 .30921 .41214 Mtetra
.639 .61 .804 r
.30921 .41214 .31035 .41442 .31223 .41377 .31111 .41142 Mtetra
.632 .6 .8 r
.31111 .41142 .31223 .41377 .31413 .41312 .313 .41073 Mtetra
.616 .589 .8 r
.313 .41073 .31413 .41312 .31602 .4125 .31489 .41015 Mtetra
.576 .572 .812 r
.31489 .41015 .31602 .4125 .3179 .41202 .31676 .40981 Mtetra
.574 .585 .826 r
.31676 .40981 .3179 .41202 .31979 .41141 .31863 .40949 Mtetra
.588 .625 .856 r
.31863 .40949 .31979 .41141 .3217 .41047 .32051 .4091 Mtetra
.635 .728 .915 r
.32051 .4091 .3217 .41047 .32368 .40855 .32241 .4085 Mtetra
.468 .886 .918 r
.32241 .4085 .32368 .40855 .32569 .40615 .32431 .40784 Mtetra
.199 0 0 r
.32431 .40784 .32569 .40615 .3277 .40364 .32621 .40723 Mtetra
.436 .07 .243 r
.32621 .40723 .3277 .40364 .32956 .40352 .32808 .40709 Mtetra
.375 .012 .215 r
.32808 .40709 .32956 .40352 .33144 .40318 .32997 .40654 Mtetra
.187 0 .114 r
.32997 .40654 .33144 .40318 .33341 .40148 .33193 .40506 Mtetra
.76 .806 .325 r
.33193 .40506 .33341 .40148 .34725 .19775 .33415 .39901 Mtetra
0 0 .153 r
.33415 .39901 .34725 .19775 .34972 .18551 .34839 .18807 Mtetra
.931 .879 .461 r
.34839 .18807 .34972 .18551 .35167 .18192 .3505 .18167 Mtetra
.824 .955 .901 r
.3505 .18167 .35167 .18192 .35346 .18098 .35233 .18018 Mtetra
.68 .838 .959 r
.35233 .18018 .35346 .18098 .35523 .18058 .35412 .17942 Mtetra
.587 .733 .944 r
.35412 .17942 .35523 .18058 .35698 .18044 .35589 .17902 Mtetra
.652 .71 .89 r
.35589 .17902 .35698 .18044 .35876 .17984 .35767 .17838 Mtetra
.642 .699 .888 r
.35767 .17838 .35876 .17984 .36055 .17918 .35946 .17778 Mtetra
.643 .71 .896 r
.35946 .17778 .36055 .17918 .36234 .17844 .36124 .17718 Mtetra
.675 .746 .904 r
.36124 .17718 .36234 .17844 .36415 .1774 .36303 .17644 Mtetra
.684 .808 .941 r
.36303 .17644 .36415 .1774 .36595 .17647 .36483 .17568 Mtetra
.683 .843 .96 r
.36483 .17568 .36595 .17647 .36774 .17578 .36663 .1749 Mtetra
.771 .839 .904 r
.36663 .1749 .36774 .17578 .36951 .17569 .36845 .17371 Mtetra
.666 .639 .813 r
.36845 .17371 .36951 .17569 .37124 .17625 .37025 .17288 Mtetra
.54 .467 .722 r
.37025 .17288 .37124 .17625 .3729 .17814 .37202 .17274 Mtetra
0 .001 .516 r
.37202 .17274 .3729 .17814 .36447 .38188 .37358 .17662 Mtetra
0 0 .197 r
.37358 .17662 .36447 .38188 .36584 .39225 .3649 .38622 Mtetra
0 0 .362 r
.3649 .38622 .36584 .39225 .36761 .39482 .36649 .39244 Mtetra
.423 .487 .821 r
.36649 .39244 .36761 .39482 .36952 .39452 .36837 .39281 Mtetra
.617 .669 .878 r
.36837 .39281 .36952 .39452 .37147 .39356 .37029 .39228 Mtetra
.709 .77 .9 r
.37029 .39228 .37147 .39356 .37343 .39225 .37224 .39131 Mtetra
.623 .81 .972 r
.37224 .39131 .37343 .39225 .37537 .39147 .37417 .3907 Mtetra
.629 .846 .983 r
.37417 .3907 .37537 .39147 .37731 .39079 .37611 .39003 Mtetra
.653 .855 .977 r
.37611 .39003 .37731 .39079 .37924 .39019 .37805 .38929 Mtetra
.543 .787 .989 r
.37805 .38929 .37924 .39019 .38115 .39015 .37998 .38891 Mtetra
.667 .766 .924 r
.37998 .38891 .38115 .39015 .38308 .38982 .38192 .38815 Mtetra
.768 .729 .817 r
.38192 .38815 .38308 .38982 .38503 .38889 .3839 .38658 Mtetra
.907 .706 .619 r
.3839 .38658 .38503 .38889 .3871 .38523 .38611 .37981 Mtetra
.965 .685 .454 r
.38611 .37981 .3871 .38523 .38946 .37477 .39707 .16818 Mtetra
.519 .283 .496 r
.39707 .16818 .38946 .37477 .4 .16805 .3991 .16249 Mtetra
.627 .459 .635 r
.3991 .16249 .4 .16805 .40193 .16466 .40094 .161 Mtetra
.596 .489 .702 r
.40094 .161 .40193 .16466 .40379 .16276 .40276 .16036 Mtetra
.565 .549 .795 r
.40276 .16036 .40379 .16276 .40564 .16146 .40456 .16008 Mtetra
.659 .723 .896 r
.40456 .16008 .40564 .16146 .40746 .16058 .40638 .1594 Mtetra
.67 .763 .92 r
.40638 .1594 .40746 .16058 .40928 .15991 .4082 .15868 Mtetra
.658 .749 .917 r
.4082 .15868 .40928 .15991 .4111 .15933 .41002 .15801 Mtetra
.706 .748 .885 r
.41002 .15801 .4111 .15933 .41293 .15822 .41185 .15709 Mtetra
.649 .767 .935 r
.41185 .15709 .41293 .15822 .41477 .15726 .41367 .15645 Mtetra
.34 .699 .983 r
.41367 .15645 .41477 .15726 .41658 .1568 .41547 .15649 Mtetra
.875 .438 .134 r
.41547 .15649 .41658 .1568 .41832 .15845 .41713 .1605 Mtetra
.967 .678 .432 r
.41713 .1605 .41832 .15845 .4199 .16492 .41144 .37128 Mtetra
.516 .275 .488 r
.41144 .37128 .4199 .16492 .41452 .37292 .41318 .37696 Mtetra
.517 .157 .294 r
.41318 .37696 .41452 .37292 .41636 .37601 .4151 .37752 Mtetra
.184 0 0 r
.4151 .37752 .41636 .37601 .41827 .37699 .41707 .37693 Mtetra
.648 .961 .924 r
.41707 .37693 .41827 .37699 .4202 .37719 .41905 .37583 Mtetra
.615 .73 .928 r
.41905 .37583 .4202 .37719 .42215 .37714 .42101 .3753 Mtetra
.651 .67 .854 r
.42101 .3753 .42215 .37714 .42412 .37662 .42299 .37455 Mtetra
.737 .679 .794 r
.42299 .37455 .42412 .37662 .42611 .37545 .42499 .37307 Mtetra
.891 .704 .643 r
.42499 .37307 .42611 .37545 .42816 .37203 .42711 .36762 Mtetra
.968 .685 .44 r
.42711 .36762 .42816 .37203 .43037 .36353 .43544 .15527 Mtetra
.521 .285 .497 r
.43544 .15527 .43037 .36353 .43839 .15454 .43746 .14827 Mtetra
.635 .454 .62 r
.43746 .14827 .43839 .15454 .44029 .15189 .43934 .1464 Mtetra
.576 .425 .64 r
.43934 .1464 .44029 .15189 .44213 .1513 .44118 .14568 Mtetra
.543 .401 .637 r
.44118 .14568 .44213 .1513 .44396 .15102 .44301 .14539 Mtetra
.564 .415 .637 r
.44301 .14539 .44396 .15102 .44585 .14885 .44486 .14483 Mtetra
.593 .475 .687 r
.44486 .14483 .44585 .14885 .44774 .1465 .4467 .14415 Mtetra
.631 .591 .79 r
.4467 .14415 .44774 .1465 .44962 .1446 .44855 .14347 Mtetra
.661 .774 .933 r
.44855 .14347 .44962 .1446 .45147 .1435 .4504 .14278 Mtetra
.647 .856 .979 r
.4504 .14278 .45147 .1435 .45332 .1428 .45225 .14208 Mtetra
.647 .858 .98 r
.45225 .14208 .45332 .1428 .45517 .14226 .4541 .14138 Mtetra
.657 .826 .965 r
.4541 .14138 .45517 .14226 .45702 .14171 .45595 .14068 Mtetra
.662 .794 .946 r
.45595 .14068 .45702 .14171 .45887 .14116 .4578 .13998 Mtetra
.664 .765 .925 r
.4578 .13998 .45887 .14116 .46072 .14061 .45966 .13927 Mtetra
.671 .74 .902 r
.45966 .13927 .46072 .14061 .46257 .13997 .46152 .13852 Mtetra
.669 .72 .887 r
.46152 .13852 .46257 .13997 .46443 .13926 .46338 .13777 Mtetra
.661 .71 .884 r
.46338 .13777 .46443 .13926 .46629 .1385 .46523 .13706 Mtetra
.632 .706 .9 r
.46523 .13706 .46629 .1385 .46815 .13765 .46709 .13648 Mtetra
.61 .749 .944 r
.46709 .13648 .46815 .13765 .47001 .13676 .46895 .13598 Mtetra
.582 .824 .99 r
.46895 .13598 .47001 .13676 .47188 .13587 .47081 .13548 Mtetra
.571 .897 .984 r
.47081 .13548 .47188 .13587 .47374 .13507 .47267 .13483 Mtetra
.573 .921 .96 r
.47267 .13483 .47374 .13507 .47561 .13432 .47454 .13408 Mtetra
.587 .926 .959 r
.47454 .13408 .47561 .13432 .47747 .13359 .47641 .1333 Mtetra
.589 .92 .968 r
.47641 .1333 .47747 .13359 .47934 .13286 .47828 .13255 Mtetra
.585 .915 .973 r
.47828 .13255 .47934 .13286 .48121 .13213 .48015 .13182 Mtetra
.582 .914 .973 r
.48015 .13182 .48121 .13213 .48308 .13141 .48202 .13109 Mtetra
.579 .913 .974 r
.48202 .13109 .48308 .13141 .48495 .1307 .48389 .13038 Mtetra
.576 .911 .973 r
.48389 .13038 .48495 .1307 .48682 .12999 .48576 .12967 Mtetra
.573 .911 .973 r
.48576 .12967 .48682 .12999 .48869 .12928 .48764 .12897 Mtetra
.571 .911 .972 r
.48764 .12897 .48869 .12928 .49057 .12857 .48951 .12826 Mtetra
.569 .91 .972 r
.48951 .12826 .49057 .12857 .49244 .12787 .49139 .12756 Mtetra
.567 .91 .971 r
.49139 .12756 .49244 .12787 .49432 .12716 .49327 .12686 Mtetra
.565 .91 .971 r
.49327 .12686 .49432 .12716 .4962 .12646 .49515 .12616 Mtetra
.564 .91 .97 r
.49515 .12616 .4962 .12646 .49808 .12576 .49703 .12546 Mtetra
.563 .91 .97 r
.49703 .12546 .49808 .12576 .49996 .12507 .49891 .12476 Mtetra
.562 .909 .97 r
.49891 .12476 .49996 .12507 .50184 .12437 .50079 .12407 Mtetra
.563 .909 .97 r
.50079 .12407 .50184 .12437 .50373 .12368 .50268 .12337 Mtetra
.565 .909 .971 r
.50268 .12337 .50373 .12368 .50561 .12299 .50457 .12267 Mtetra
.567 .909 .972 r
.50457 .12267 .50561 .12299 .5075 .12229 .50645 .12197 Mtetra
.569 .91 .973 r
.50645 .12197 .5075 .12229 .50938 .12159 .50834 .12127 Mtetra
.57 .91 .973 r
.50834 .12127 .50938 .12159 .51127 .12089 .51023 .12056 Mtetra
.572 .91 .973 r
.51023 .12056 .51127 .12089 .51316 .12018 .51212 .11985 Mtetra
.573 .911 .973 r
.51212 .11985 .51316 .12018 .51505 .11947 .51402 .11914 Mtetra
.574 .911 .973 r
.51402 .11914 .51505 .11947 .51695 .11876 .51591 .11843 Mtetra
.575 .911 .973 r
.51591 .11843 .51695 .11876 .51884 .11805 .51781 .11771 Mtetra
.576 .911 .974 r
.51781 .11771 .51884 .11805 .52074 .11733 .5197 .117 Mtetra
.577 .912 .974 r
.5197 .117 .52074 .11733 .52263 .11661 .5216 .11628 Mtetra
.5216 .11628 .52263 .11661 .52453 .11589 .5235 .11555 Mtetra
.578 .912 .974 r
.5235 .11555 .52453 .11589 .52643 .11517 .5254 .11483 Mtetra
.5254 .11483 .52643 .11517 .52833 .11445 .5273 .11411 Mtetra
.579 .912 .974 r
.5273 .11411 .52833 .11445 .53023 .11372 .52921 .11338 Mtetra
.52921 .11338 .53023 .11372 .53214 .113 .53111 .11266 Mtetra
.53111 .11266 .53214 .113 .53404 .11227 .53302 .11193 Mtetra
.53302 .11193 .53404 .11227 .53595 .11155 .53493 .1112 Mtetra
.579 .913 .974 r
.53493 .1112 .53595 .11155 .53785 .11082 .53683 .11047 Mtetra
.53683 .11047 .53785 .11082 .53976 .11009 .53874 .10974 Mtetra
.53874 .10974 .53976 .11009 .54167 .10936 .54066 .10901 Mtetra
.58 .913 .974 r
.54066 .10901 .54167 .10936 .54358 .10863 .54257 .10828 Mtetra
.54257 .10828 .54358 .10863 .5455 .1079 .54448 .10755 Mtetra
.54448 .10755 .5455 .1079 .54741 .10717 .5464 .10682 Mtetra
.5464 .10682 .54741 .10717 .54933 .10644 .54832 .10609 Mtetra
.54832 .10609 .54933 .10644 .55124 .1057 .55023 .10535 Mtetra
.55023 .10535 .55124 .1057 .55316 .10497 .55215 .10462 Mtetra
.55215 .10462 .55316 .10497 .55508 .10424 .55407 .10389 Mtetra
.55407 .10389 .55508 .10424 .557 .1035 .556 .10315 Mtetra
.556 .10315 .557 .1035 .55892 .10277 .55792 .10242 Mtetra
.55792 .10242 .55892 .10277 .56084 .10203 .55984 .10168 Mtetra
.55984 .10168 .56084 .10203 .56277 .1013 .56177 .10094 Mtetra
.56177 .10094 .56277 .1013 .56469 .10056 .5637 .10021 Mtetra
.5637 .10021 .56469 .10056 .56662 .09982 .56563 .09947 Mtetra
.56563 .09947 .56662 .09982 .56855 .09909 .56756 .09873 Mtetra
.581 .913 .974 r
.56756 .09873 .56855 .09909 .57048 .09835 .56949 .09799 Mtetra
.56949 .09799 .57048 .09835 .57241 .09761 .57142 .09725 Mtetra
.57142 .09725 .57241 .09761 .57434 .09687 .57335 .09651 Mtetra
.57335 .09651 .57434 .09687 .57628 .09613 .57529 .09576 Mtetra
.582 .913 .974 r
.57529 .09576 .57628 .09613 .57821 .09539 .57723 .09502 Mtetra
.57723 .09502 .57821 .09539 .58015 .09464 .57916 .09428 Mtetra
.583 .913 .974 r
.57916 .09428 .58015 .09464 .58209 .0939 .5811 .09353 Mtetra
.5811 .09353 .58209 .0939 .58403 .09315 .58304 .09278 Mtetra
.584 .914 .974 r
.58304 .09278 .58403 .09315 .58597 .09241 .58499 .09203 Mtetra
.585 .914 .974 r
.58499 .09203 .58597 .09241 .58791 .09166 .58693 .09128 Mtetra
.586 .914 .975 r
.58693 .09128 .58791 .09166 .58985 .09091 .58888 .09053 Mtetra
.588 .914 .975 r
.58888 .09053 .58985 .09091 .5918 .09016 .59082 .08978 Mtetra
.589 .914 .975 r
.59082 .08978 .5918 .09016 .59374 .08941 .59277 .08902 Mtetra
.591 .914 .976 r
.59277 .08902 .59374 .08941 .59569 .08865 .59472 .08826 Mtetra
.592 .914 .976 r
.59472 .08826 .59569 .08865 .59764 .0879 .59667 .0875 Mtetra
.594 .914 .977 r
.59667 .0875 .59764 .0879 .59959 .08714 .59862 .08674 Mtetra
.595 .914 .977 r
.59862 .08674 .59959 .08714 .60154 .08638 .60057 .08597 Mtetra
.596 .913 .978 r
.60057 .08597 .60154 .08638 .60349 .08563 .60253 .08521 Mtetra
.597 .912 .978 r
.60253 .08521 .60349 .08563 .60545 .08487 .60448 .08445 Mtetra
.596 .911 .979 r
.60448 .08445 .60545 .08487 .6074 .08412 .60644 .08369 Mtetra
.60644 .08369 .6074 .08412 .60936 .08336 .6084 .08293 Mtetra
.595 .91 .98 r
.6084 .08293 .60936 .08336 .61132 .08261 .61036 .08218 Mtetra
.593 .909 .98 r
.61036 .08218 .61132 .08261 .61328 .08186 .61232 .08143 Mtetra
.592 .909 .98 r
.61232 .08143 .61328 .08186 .61524 .08112 .61428 .08069 Mtetra
.59 .909 .98 r
.61428 .08069 .61524 .08112 .6172 .08037 .61624 .07994 Mtetra
.588 .909 .98 r
.61624 .07994 .6172 .08037 .61916 .07962 .61821 .0792 Mtetra
.586 .909 .979 r
.61821 .0792 .61916 .07962 .62113 .07888 .62018 .07846 Mtetra
.586 .909 .978 r
.62018 .07846 .62113 .07888 .6231 .07813 .62215 .07772 Mtetra
.585 .91 .978 r
.62215 .07772 .6231 .07813 .62507 .07738 .62412 .07697 Mtetra
.586 .911 .977 r
.62412 .07697 .62507 .07738 .62703 .07663 .62609 .07622 Mtetra
.587 .912 .977 r
.62609 .07622 .62703 .07663 .62901 .07587 .62806 .07547 Mtetra
.588 .913 .976 r
.62806 .07547 .62901 .07587 .63098 .07511 .63003 .07471 Mtetra
.591 .914 .976 r
.63003 .07471 .63098 .07511 .63295 .07435 .63201 .07394 Mtetra
.595 .915 .976 r
.63201 .07394 .63295 .07435 .63492 .07357 .63398 .07316 Mtetra
.603 .918 .975 r
.63398 .07316 .63492 .07357 .6369 .07278 .63596 .07236 Mtetra
.604 .917 .976 r
.63596 .07236 .6369 .07278 .63888 .07199 .63794 .07156 Mtetra
.644 .93 .971 r
.63794 .07156 .63888 .07199 .64085 .07113 .63991 .07066 Mtetra
.743 .951 .945 r
.63991 .07066 .64085 .07113 .64282 .07005 .64188 .06945 Mtetra
.622 .892 .988 r
.64188 .06945 .64282 .07005 .6448 .06928 .64386 .0687 Mtetra
.001 .518 .856 r
.64386 .0687 .6448 .06928 .64682 .06936 .6459 .06919 Mtetra
.907 .498 .146 r
.6459 .06919 .64682 .06936 .64896 .07232 .64823 .07661 Mtetra
.972 .66 .339 r
.64823 .07661 .64896 .07232 .65997 .27867 .65945 .28925 Mtetra
.605 .294 .416 r
.65945 .28925 .65997 .27867 .66262 .28946 .66178 .29272 Mtetra
.415 .034 .205 r
.66178 .29272 .66262 .28946 .6648 .2895 .66396 .29249 Mtetra
.296 0 .147 r
.66396 .29249 .6648 .2895 .66693 .28836 .6661 .29153 Mtetra
.262 0 .152 r
.6661 .29153 .66693 .28836 .66903 .28663 .66823 .29028 Mtetra
.352 0 .212 r
.66823 .29028 .66903 .28663 .67115 .2853 .67038 .28945 Mtetra
.37 .026 .245 r
.67038 .28945 .67115 .2853 .67329 .28431 .67253 .2886 Mtetra
.375 .034 .254 r
.67253 .2886 .67329 .28431 .67548 .28427 .67468 .28776 Mtetra
.35 0 .202 r
.67468 .28776 .67548 .28427 .67775 .28583 .67684 .28696 Mtetra
.072 0 0 r
.67684 .28696 .67775 .28583 .68 .28688 .679 .28619 Mtetra
.61 .88 .991 r
.679 .28619 .68 .28688 .68222 .28728 .68116 .28543 Mtetra
.645 .684 .872 r
.68116 .28543 .68222 .28728 .68438 .28657 .68333 .28467 Mtetra
.641 .675 .867 r
.68333 .28467 .68438 .28657 .68653 .2856 .68549 .28393 Mtetra
.626 .701 .899 r
.68549 .28393 .68653 .2856 .68869 .28462 .68767 .28329 Mtetra
.473 .686 .96 r
.68767 .28329 .68869 .28462 .69088 .28431 .68987 .28319 Mtetra
.6 .789 .971 r
.68987 .28319 .69088 .28431 .69306 .28369 .69205 .2826 Mtetra
.812 .863 .885 r
.69205 .2826 .69306 .28369 .6952 .28231 .69417 .28092 Mtetra
.979 .775 .559 r
.69417 .28092 .6952 .28231 .69716 .27787 .69597 .27332 Mtetra
.975 .668 .333 r
.69597 .27332 .69716 .27787 .69816 .25622 .68609 .05723 Mtetra
.517 .281 .495 r
.68609 .05723 .69816 .25622 .68902 .05732 .68784 .05183 Mtetra
.61 .451 .641 r
.68784 .05183 .68902 .05732 .69091 .05434 .68983 .05056 Mtetra
.582 .483 .707 r
.68983 .05056 .69091 .05434 .69287 .05248 .69186 .05 Mtetra
.55 .546 .803 r
.69186 .05 .69287 .05248 .69486 .05118 .69391 .04979 Mtetra
.65 .741 .916 r
.69391 .04979 .69486 .05118 .69687 .05029 .69593 .04908 Mtetra
.653 .778 .94 r
.69593 .04908 .69687 .05029 .69889 .0496 .69796 .04836 Mtetra
.663 .776 .933 r
.69796 .04836 .69889 .0496 .70092 .04897 .69998 .04759 Mtetra
.761 .786 .874 r
.69998 .04759 .70092 .04897 .70291 .04766 .70197 .04626 Mtetra
.694 .761 .903 r
.70197 .04626 .70291 .04766 .70493 .04674 .70399 .04534 Mtetra
.5 .667 .938 r
.70399 .04534 .70493 .04674 .707 .04662 .70605 .04521 Mtetra
.749 .331 0 r
.70605 .04521 .707 .04662 .70939 .05161 .70845 .05022 Mtetra
.97 .655 .291 r
.70845 .05022 .70939 .05161 .72545 .26686 .72445 .2655 Mtetra
.735 .303 0 r
.72445 .2655 .72545 .26686 .72802 .27179 .72701 .27041 Mtetra
.046 .473 .884 r
.0321 .50622 .03342 .50728 .03495 .50782 .03363 .50675 Mtetra
.646 .763 .934 r
.03363 .50675 .03495 .50782 .03665 .50724 .03533 .50617 Mtetra
.81 .779 .823 r
.03533 .50617 .03665 .50724 .03852 .50554 .0372 .50447 Mtetra
.908 .737 .658 r
.0372 .50447 .03852 .50554 .041 .49961 .03968 .49854 Mtetra
.937 .686 .534 r
.03968 .49854 .041 .49961 .07266 .2926 .07145 .29149 Mtetra
.909 .728 .646 r
.07145 .29149 .07266 .2926 .07507 .28643 .07386 .2853 Mtetra
.777 .76 .838 r
.07386 .2853 .07507 .28643 .07678 .28511 .07557 .28398 Mtetra
.642 .737 .918 r
.07557 .28398 .07678 .28511 .07837 .28458 .07716 .28345 Mtetra
.513 .694 .95 r
.07716 .28345 .07837 .28458 .07991 .28443 .0787 .2833 Mtetra
.747 .759 .862 r
.0787 .2833 .07991 .28443 .08158 .28336 .08037 .28223 Mtetra
.699 .751 .892 r
.08037 .28223 .08158 .28336 .08321 .28258 .082 .28145 Mtetra
.493 .686 .953 r
.082 .28145 .08321 .28258 .08474 .28247 .08354 .28135 Mtetra
.922 .534 .231 r
.08354 .28135 .08474 .28247 .08572 .28632 .08451 .28524 Mtetra
.939 .683 .522 r
.08451 .28524 .08572 .28632 .0583 .49195 .05698 .49096 Mtetra
.934 .585 .342 r
.05698 .49096 .0583 .49195 .0591 .4979 .05778 .49685 Mtetra
.21 .58 .943 r
.05778 .49685 .0591 .4979 .06068 .49823 .05937 .49718 Mtetra
.675 .774 .925 r
.05937 .49718 .06068 .49823 .06241 .49753 .0611 .49647 Mtetra
.756 .783 .876 r
.0611 .49647 .06241 .49753 .06421 .49638 .0629 .49531 Mtetra
.489 .712 .969 r
.0629 .49531 .06421 .49638 .06587 .49624 .06456 .49517 Mtetra
.59 .749 .953 r
.06456 .49517 .06587 .49624 .06756 .49585 .06625 .49477 Mtetra
.759 .781 .872 r
.06625 .49477 .06756 .49585 .06936 .4947 .06806 .49358 Mtetra
.911 .737 .654 r
.06806 .49358 .06936 .4947 .07177 .48909 .07053 .48754 Mtetra
.939 .687 .528 r
.07053 .48754 .07177 .48909 .10168 .28173 .1006 .27967 Mtetra
.876 .688 .643 r
.1006 .27967 .10168 .28173 .10407 .2754 .10293 .27382 Mtetra
.753 .698 .8 r
.10293 .27382 .10407 .2754 .10581 .27393 .10465 .27247 Mtetra
.595 .664 .887 r
.10465 .27247 .10581 .27393 .10741 .27346 .10624 .27212 Mtetra
.433 .616 .927 r
.10624 .27212 .10741 .27346 .10896 .27342 .10777 .2722 Mtetra
.605 .711 .919 r
.10777 .2722 .10896 .27342 .11056 .27297 .10937 .2718 Mtetra
.648 .734 .912 r
.10937 .2718 .11056 .27297 .11218 .27239 .11098 .27124 Mtetra
.66 .74 .909 r
.11098 .27124 .11218 .27239 .1138 .27179 .11261 .27063 Mtetra
.749 .757 .859 r
.11261 .27063 .1138 .27179 .11549 .27069 .1143 .26953 Mtetra
.715 .751 .881 r
.1143 .26953 .11549 .27069 .11716 .26981 .11596 .26865 Mtetra
.537 .699 .944 r
.11596 .26865 .11716 .26981 .11874 .26957 .11754 .26844 Mtetra
.912 .509 .183 r
.11754 .26844 .11874 .26957 .11985 .27288 .11861 .27208 Mtetra
.943 .683 .515 r
.11861 .27208 .11985 .27288 .09457 .47874 .09313 .47881 Mtetra
.901 .552 .373 r
.09313 .47881 .09457 .47874 .09537 .48534 .09401 .48475 Mtetra
0 .437 .771 r
.09401 .48475 .09537 .48534 .09695 .48597 .09561 .48523 Mtetra
.704 .843 .949 r
.09561 .48523 .09695 .48597 .09871 .48526 .09739 .48439 Mtetra
.791 .821 .875 r
.09739 .48439 .09871 .48526 .10053 .48403 .09923 .48301 Mtetra
.662 .782 .938 r
.09923 .48301 .10053 .48403 .10226 .48357 .10098 .48235 Mtetra
.643 .74 .919 r
.10098 .48235 .10226 .48357 .10399 .48307 .10273 .48177 Mtetra
.727 .746 .867 r
.10273 .48177 .10399 .48307 .10582 .48185 .10453 .48073 Mtetra
.879 .764 .731 r
.10453 .48073 .10582 .48185 .10814 .47671 .10662 .47745 Mtetra
.971 .793 .605 r
.10662 .47745 .10814 .47671 .1359 .26931 .10942 .46847 Mtetra
0 0 .011 r
.10942 .46847 .1359 .26931 .13831 .26258 .13644 .26682 Mtetra
0 0 0 r
.13644 .26682 .13831 .26258 .14015 .26042 .13842 .2636 Mtetra
.264 0 .145 r
.13842 .2636 .14015 .26042 .14182 .25957 .1401 .26265 Mtetra
.519 .149 .278 r
.1401 .26265 .14182 .25957 .14338 .25963 .14161 .26312 Mtetra
.818 .5 .452 r
.14161 .26312 .14338 .25963 .14463 .26222 .14231 .27021 Mtetra
.934 .671 .514 r
.14231 .27021 .14463 .26222 .1213 .46504 .11916 .47089 Mtetra
.687 .37 .432 r
.11916 .47089 .1213 .46504 .12172 .47535 .12038 .4747 Mtetra
.471 0 0 r
.12038 .4747 .12172 .47535 .1232 .47695 .12193 .47573 Mtetra
.527 .701 .949 r
.12193 .47573 .1232 .47695 .12491 .47675 .12365 .47553 Mtetra
.755 .764 .86 r
.12365 .47553 .12491 .47675 .12676 .47542 .12548 .4743 Mtetra
.905 .753 .682 r
.12548 .4743 .12676 .47542 .12899 .47098 .12774 .46962 Mtetra
.945 .688 .516 r
.12774 .46962 .12899 .47098 .15544 .26406 .15445 .2613 Mtetra
.878 .669 .616 r
.15445 .2613 .15544 .26406 .15806 .25538 .15695 .25366 Mtetra
.793 .696 .758 r
.15695 .25366 .15806 .25538 .15989 .25326 .15876 .2517 Mtetra
.628 .665 .866 r
.15876 .2517 .15989 .25326 .16155 .2526 .1604 .2512 Mtetra
.484 .631 .918 r
.1604 .2512 .16155 .2526 .16316 .25239 .16199 .25117 Mtetra
.616 .718 .918 r
.16199 .25117 .16316 .25239 .1648 .25196 .16363 .25072 Mtetra
.676 .733 .893 r
.16363 .25072 .1648 .25196 .16646 .25134 .1653 .25002 Mtetra
.631 .706 .9 r
.1653 .25002 .16646 .25134 .16811 .25074 .16694 .24951 Mtetra
.416 .635 .946 r
.16694 .24951 .16811 .25074 .1698 .24991 .16852 .2496 Mtetra
.508 0 0 r
.16852 .2496 .1698 .24991 .17147 .24919 .17001 .25049 Mtetra
.756 .354 .292 r
.17001 .25049 .17147 .24919 .17308 .24904 .17133 .25289 Mtetra
.942 .677 .505 r
.17133 .25289 .17308 .24904 .17437 .25171 .15006 .45269 Mtetra
.525 .283 .491 r
.15006 .45269 .17437 .25171 .15263 .45728 .15068 .46222 Mtetra
.644 .311 .394 r
.15068 .46222 .15263 .45728 .15347 .465 .15211 .4646 Mtetra
.368 .793 .972 r
.15211 .4646 .15347 .465 .15502 .46643 .15385 .46437 Mtetra
.775 .676 .754 r
.15385 .46437 .15502 .46643 .15678 .46603 .15579 .4624 Mtetra
.79 .61 .657 r
.15579 .4624 .15678 .46603 .15865 .46455 .15794 .45848 Mtetra
.943 .683 .513 r
.15794 .45848 .15865 .46455 .16082 .46046 .18134 .26369 Mtetra
.55 .31 .504 r
.18134 .26369 .16082 .46046 .18518 .2553 .18492 .24588 Mtetra
.665 .452 .586 r
.18492 .24588 .18518 .2553 .18798 .24451 .18695 .24209 Mtetra
.731 .622 .736 r
.18695 .24209 .18798 .24451 .18986 .242 .18873 .24048 Mtetra
.643 .677 .867 r
.18873 .24048 .18986 .242 .19155 .2412 .1904 .2399 Mtetra
.56 .684 .922 r
.1904 .2399 .19155 .2412 .1932 .24087 .19204 .23964 Mtetra
.658 .732 .904 r
.19204 .23964 .1932 .24087 .19486 .2404 .19371 .23901 Mtetra
.71 .721 .858 r
.19371 .23901 .19486 .2404 .19654 .2397 .19542 .23809 Mtetra
.665 .674 .849 r
.19542 .23809 .19654 .2397 .19823 .23905 .19711 .23738 Mtetra
.52 .605 .878 r
.19711 .23738 .19823 .23905 .19992 .23825 .19873 .23729 Mtetra
0 .329 .773 r
.19873 .23729 .19992 .23825 .20162 .23751 .20027 .23808 Mtetra
.772 .329 .198 r
.20027 .23808 .20162 .23751 .20326 .2373 .20166 .24025 Mtetra
.946 .678 .497 r
.20166 .24025 .20326 .2373 .20466 .23934 .18358 .42782 Mtetra
.555 .309 .497 r
.18358 .42782 .20466 .23934 .18519 .44203 .18293 .45055 Mtetra
.625 .321 .435 r
.18293 .45055 .18519 .44203 .18575 .45329 .18434 .45362 Mtetra
.542 0 0 r
.18434 .45362 .18575 .45329 .18731 .45506 .186 .45446 Mtetra
.49 .818 1 r
.186 .45446 .18731 .45506 .18908 .45475 .18777 .45412 Mtetra
.712 .875 .958 r
.18777 .45412 .18908 .45475 .19091 .45387 .18961 .45321 Mtetra
.81 .869 .891 r
.18961 .45321 .19091 .45387 .19273 .45318 .1915 .45174 Mtetra
.823 .748 .781 r
.1915 .45174 .19273 .45318 .19452 .4527 .19347 .44958 Mtetra
.794 .629 .676 r
.19347 .44958 .19452 .4527 .19637 .45165 .19556 .44616 Mtetra
.839 .612 .594 r
.19556 .44616 .19637 .45165 .19845 .44841 .19826 .43662 Mtetra
.941 .676 .507 r
.19826 .43662 .19845 .44841 .20224 .42776 .22019 .23407 Mtetra
.517 .281 .497 r
.22019 .23407 .20224 .42776 .22334 .23171 .22227 .22962 Mtetra
.775 .665 .741 r
.22227 .22962 .22334 .23171 .22527 .2287 .2241 .22763 Mtetra
.694 .775 .914 r
.2241 .22763 .22527 .2287 .22699 .22783 .22582 .22685 Mtetra
.593 .765 .961 r
.22582 .22685 .22699 .22783 .22866 .2275 .22749 .22644 Mtetra
.678 .773 .922 r
.22749 .22644 .22866 .2275 .23036 .2269 .2292 .22573 Mtetra
.739 .766 .875 r
.2292 .22573 .23036 .2269 .2321 .22589 .23094 .22468 Mtetra
.626 .73 .922 r
.23094 .22468 .2321 .22589 .23378 .22539 .23263 .22418 Mtetra
0 0 .491 r
.23263 .22418 .23378 .22539 .23529 .22682 .23413 .22575 Mtetra
.955 .685 .486 r
.23413 .22575 .23529 .22682 .23488 .24862 .21665 .42736 Mtetra
.538 .293 .493 r
.21665 .42736 .23488 .24862 .21841 .44168 .2171 .44128 Mtetra
.746 .226 0 r
.2171 .44128 .21841 .44168 .21998 .44386 .21868 .44322 Mtetra
.61 .855 .99 r
.21868 .44322 .21998 .44386 .22178 .44345 .22051 .44262 Mtetra
.775 .846 .905 r
.22051 .44262 .22178 .44345 .22365 .44239 .22239 .44137 Mtetra
.77 .809 .884 r
.22239 .44137 .22365 .44239 .22552 .44127 .22428 .44009 Mtetra
.687 .768 .913 r
.22428 .44009 .22552 .44127 .22737 .44049 .22613 .43928 Mtetra
.68 .761 .912 r
.22613 .43928 .22737 .44049 .22922 .43971 .22798 .43851 Mtetra
.636 .751 .931 r
.22798 .43851 .22922 .43971 .23104 .43916 .22981 .43792 Mtetra
.591 .729 .939 r
.22981 .43792 .23104 .43916 .23285 .43884 .23162 .4375 Mtetra
.683 .742 .895 r
.23162 .4375 .23285 .43884 .2347 .43797 .23347 .4367 Mtetra
.837 .773 .79 r
.23347 .4367 .2347 .43797 .23674 .4351 .23545 .4345 Mtetra
.949 .778 .636 r
.23545 .4345 .23674 .4351 .24048 .41286 .23781 .42802 Mtetra
.972 .711 .477 r
.23781 .42802 .24048 .41286 .25927 .21798 .25765 .22223 Mtetra
0 0 0 r
.25765 .22223 .25927 .21798 .26122 .21473 .25973 .21754 Mtetra
.398 .013 .188 r
.25973 .21754 .26122 .21473 .26296 .21386 .26142 .21729 Mtetra
.502 .138 .28 r
.26142 .21729 .26296 .21386 .26466 .21352 .26306 .21765 Mtetra
.308 0 .225 r
.26306 .21765 .26466 .21352 .26635 .2132 .26482 .21653 Mtetra
0 0 0 r
.26482 .21653 .26635 .2132 .26809 .21246 .26677 .21333 Mtetra
.857 .987 .711 r
.26677 .21333 .26809 .21246 .26982 .21171 .26865 .21087 Mtetra
.826 .832 .853 r
.26865 .21087 .26982 .21171 .27155 .21104 .27046 .20926 Mtetra
.66 .656 .835 r
.27046 .20926 .27155 .21104 .27327 .21047 .2722 .20854 Mtetra
.614 .616 .83 r
.2722 .20854 .27327 .21047 .27499 .20994 .27391 .20805 Mtetra
.607 .618 .836 r
.27391 .20805 .27499 .20994 .27672 .20941 .27563 .2076 Mtetra
.636 .642 .839 r
.27563 .2076 .27672 .20941 .27844 .20884 .27736 .20701 Mtetra
.637 .639 .836 r
.27736 .20701 .27844 .20884 .28017 .20825 .27909 .20641 Mtetra
.638 .638 .834 r
.27909 .20641 .28017 .20825 .2819 .20765 .28082 .20579 Mtetra
.64 .638 .832 r
.28082 .20579 .2819 .20765 .28364 .20703 .28255 .20517 Mtetra
.642 .638 .831 r
.28255 .20517 .28364 .20703 .28537 .2064 .28429 .20453 Mtetra
.644 .638 .83 r
.28429 .20453 .28537 .2064 .28711 .20575 .28603 .20388 Mtetra
.646 .639 .829 r
.28603 .20388 .28711 .20575 .28885 .20509 .28777 .20322 Mtetra
.645 .639 .829 r
.28777 .20322 .28885 .20509 .29059 .20441 .28951 .20256 Mtetra
.638 .638 .834 r
.28951 .20256 .29059 .20441 .29234 .20371 .29125 .20195 Mtetra
.623 .643 .849 r
.29125 .20195 .29234 .20371 .29409 .20301 .29298 .20143 Mtetra
.631 .672 .87 r
.29298 .20143 .29409 .20301 .29584 .20229 .29472 .20088 Mtetra
.658 .708 .885 r
.29472 .20088 .29584 .20229 .29759 .20157 .29647 .20022 Mtetra
.701 .732 .875 r
.29647 .20022 .29759 .20157 .29934 .20085 .29823 .19934 Mtetra
.701 .709 .855 r
.29823 .19934 .29934 .20085 .30109 .20011 .3 .19843 Mtetra
.688 .68 .837 r
.3 .19843 .30109 .20011 .30285 .19935 .30177 .19755 Mtetra
.666 .656 .83 r
.30177 .19755 .30285 .19935 .30461 .19857 .30352 .19677 Mtetra
.661 .656 .834 r
.30352 .19677 .30461 .19857 .30637 .19778 .30528 .19603 Mtetra
.67 .665 .836 r
.30528 .19603 .30637 .19778 .30813 .19692 .30704 .19525 Mtetra
.702 .687 .832 r
.30704 .19525 .30813 .19692 .30992 .19581 .30882 .19427 Mtetra
.661 .691 .868 r
.30882 .19427 .30992 .19581 .31168 .19511 .31058 .19358 Mtetra
.48 .613 .905 r
.31058 .19358 .31168 .19511 .31336 .19547 .31229 .19358 Mtetra
0 0 .498 r
.31229 .19358 .31336 .19547 .31472 .20047 .31384 .19578 Mtetra
.767 .515 0 r
.31384 .19578 .31472 .20047 .30201 .40977 .31505 .20315 Mtetra
0 0 .178 r
.31505 .20315 .30201 .40977 .30354 .41423 .30281 .40603 Mtetra
.482 .327 .593 r
.30281 .40603 .30354 .41423 .30539 .41417 .30461 .40658 Mtetra
.584 .407 .608 r
.30461 .40658 .30539 .41417 .30729 .41331 .30653 .40542 Mtetra
.623 .433 .604 r
.30653 .40542 .30729 .41331 .30921 .41214 .30851 .40336 Mtetra
.6 .409 .594 r
.30851 .40336 .30921 .41214 .31111 .41142 .31047 .40162 Mtetra
.554 .368 .583 r
.31047 .40162 .31111 .41142 .313 .41073 .31237 .40078 Mtetra
.444 .284 .569 r
.31237 .40078 .313 .41073 .31489 .41015 .31413 .40209 Mtetra
.23 .145 .547 r
.31413 .40209 .31489 .41015 .31676 .40981 .31575 .40553 Mtetra
.204 .214 .648 r
.31575 .40553 .31676 .40981 .31863 .40949 .31748 .40749 Mtetra
.187 .391 .831 r
.31748 .40749 .31863 .40949 .32051 .4091 .31928 .4084 Mtetra
.503 .811 1 r
.31928 .4084 .32051 .4091 .32241 .4085 .32116 .40805 Mtetra
.59 .89 .99 r
.32116 .40805 .32241 .4085 .32431 .40784 .32306 .40739 Mtetra
.629 .901 .985 r
.32306 .40739 .32431 .40784 .32621 .40723 .32497 .40663 Mtetra
.45 .808 .997 r
.32497 .40663 .32621 .40723 .32808 .40709 .32685 .40633 Mtetra
.606 .837 .988 r
.32685 .40633 .32808 .40709 .32997 .40654 .32875 .40575 Mtetra
.761 .864 .925 r
.32875 .40575 .32997 .40654 .33193 .40506 .33069 .40455 Mtetra
.932 .862 .748 r
.33069 .40455 .33193 .40506 .33415 .39901 .33275 .40128 Mtetra
.965 .888 .506 r
.33275 .40128 .33415 .39901 .34839 .18807 .33502 .39444 Mtetra
0 0 .176 r
.33502 .39444 .34839 .18807 .3505 .18167 .34902 .18683 Mtetra
0 0 0 r
.34902 .18683 .3505 .18167 .35233 .18018 .35107 .18165 Mtetra
.689 .889 .516 r
.35107 .18165 .35233 .18018 .35412 .17942 .35297 .179 Mtetra
.852 .921 .876 r
.35297 .179 .35412 .17942 .35589 .17902 .35481 .17731 Mtetra
.663 .671 .847 r
.35481 .17731 .35589 .17902 .35767 .17838 .3566 .17657 Mtetra
.601 .631 .853 r
.3566 .17657 .35767 .17838 .35946 .17778 .35838 .17614 Mtetra
.571 .641 .881 r
.35838 .17614 .35946 .17778 .36124 .17718 .36014 .17584 Mtetra
.654 .725 .901 r
.36014 .17584 .36124 .17718 .36303 .17644 .36193 .1752 Mtetra
.671 .748 .908 r
.36193 .1752 .36303 .17644 .36483 .17568 .36373 .17448 Mtetra
.688 .761 .907 r
.36373 .17448 .36483 .17568 .36663 .1749 .36553 .17368 Mtetra
.762 .775 .864 r
.36553 .17368 .36663 .1749 .36845 .17371 .36735 .17244 Mtetra
.72 .758 .883 r
.36735 .17244 .36845 .17371 .37025 .17288 .36916 .17146 Mtetra
.617 .697 .901 r
.36916 .17146 .37025 .17288 .37202 .17274 .37095 .17097 Mtetra
0 .178 .713 r
.37095 .17097 .37202 .17274 .37358 .17662 .37263 .17248 Mtetra
0 0 .354 r
.37263 .17248 .37358 .17662 .3649 .38622 .37416 .17723 Mtetra
0 0 .212 r
.37416 .17723 .3649 .38622 .36649 .39244 .36566 .38409 Mtetra
.158 .092 .526 r
.36566 .38409 .36649 .39244 .36837 .39281 .36734 .38845 Mtetra
.287 .27 .665 r
.36734 .38845 .36837 .39281 .37029 .39228 .36916 .39006 Mtetra
.349 .463 .835 r
.36916 .39006 .37029 .39228 .37224 .39131 .37103 .39064 Mtetra
.386 .765 .991 r
.37103 .39064 .37224 .39131 .37417 .3907 .37294 .39049 Mtetra
.506 .894 .955 r
.37294 .39049 .37417 .3907 .37611 .39003 .37488 .38985 Mtetra
.7 .962 .943 r
.37488 .38985 .37611 .39003 .37805 .38929 .37684 .38872 Mtetra
.854 .906 .87 r
.37684 .38872 .37805 .38929 .37998 .38891 .37884 .38686 Mtetra
.832 .709 .728 r
.37884 .38686 .37998 .38891 .38192 .38815 .38088 .384 Mtetra
.82 .616 .627 r
.38088 .384 .38192 .38815 .3839 .38658 .38303 .37861 Mtetra
.962 .682 .457 r
.38303 .37861 .3839 .38658 .38611 .37981 .39405 .17023 Mtetra
.52 .284 .496 r
.39405 .17023 .38611 .37981 .39707 .16818 .39612 .16363 Mtetra
.732 .548 .643 r
.39612 .16363 .39707 .16818 .3991 .16249 .39804 .16059 Mtetra
.702 .666 .812 r
.39804 .16059 .3991 .16249 .40094 .161 .39987 .15953 Mtetra
.614 .691 .898 r
.39987 .15953 .40094 .161 .40276 .16036 .40168 .15905 Mtetra
.544 .69 .934 r
.40168 .15905 .40276 .16036 .40456 .16008 .40348 .1588 Mtetra
.707 .756 .89 r
.40348 .1588 .40456 .16008 .40638 .1594 .4053 .15789 Mtetra
.697 .715 .862 r
.4053 .15789 .40638 .1594 .4082 .15868 .40713 .15697 Mtetra
.643 .667 .858 r
.40713 .15697 .4082 .15868 .41002 .15801 .40895 .15634 Mtetra
.421 .563 .891 r
.40895 .15634 .41002 .15801 .41185 .15709 .41074 .15654 Mtetra
.443 0 0 r
.41074 .15654 .41185 .15709 .41367 .15645 .4125 .15767 Mtetra
.793 .372 .249 r
.4125 .15767 .41367 .15645 .41547 .15649 .41418 .16089 Mtetra
.964 .675 .436 r
.41418 .16089 .41547 .15649 .41713 .1605 .40844 .3677 Mtetra
.517 .276 .488 r
.40844 .3677 .41713 .1605 .41144 .37128 .41013 .37441 Mtetra
.661 .277 .307 r
.41013 .37441 .41144 .37128 .41318 .37696 .41199 .37661 Mtetra
.019 .575 .816 r
.41199 .37661 .41318 .37696 .4151 .37752 .41392 .37683 Mtetra
.593 .853 .993 r
.41392 .37683 .4151 .37752 .41707 .37693 .41589 .37622 Mtetra
.753 .891 .941 r
.41589 .37622 .41707 .37693 .41905 .37583 .41788 .37504 Mtetra
.837 .876 .871 r
.41788 .37504 .41905 .37583 .42101 .3753 .41988 .37327 Mtetra
.825 .712 .74 r
.41988 .37327 .42101 .3753 .42299 .37455 .42192 .37062 Mtetra
.811 .617 .64 r
.42192 .37062 .42299 .37455 .42499 .37307 .42401 .36597 Mtetra
.966 .682 .444 r
.42401 .36597 .42499 .37307 .42711 .36762 .43241 .15823 Mtetra
.525 .287 .497 r
.43241 .15823 .42711 .36762 .43544 .15527 .4345 .14956 Mtetra
.715 .517 .62 r
.4345 .14956 .43544 .15527 .43746 .14827 .43642 .14615 Mtetra
.732 .659 .777 r
.43642 .14615 .43746 .14827 .43934 .1464 .43828 .14472 Mtetra
.656 .678 .859 r
.43828 .14472 .43934 .1464 .44118 .14568 .44013 .14401 Mtetra
.592 .65 .877 r
.44013 .14401 .44118 .14568 .44301 .14539 .44196 .14361 Mtetra
.605 .641 .86 r
.44196 .14361 .44301 .14539 .44486 .14483 .4438 .14315 Mtetra
.613 .66 .871 r
.4438 .14315 .44486 .14483 .4467 .14415 .44564 .14265 Mtetra
.622 .692 .894 r
.44564 .14265 .4467 .14415 .44855 .14347 .44749 .14212 Mtetra
.67 .737 .9 r
.44749 .14212 .44855 .14347 .4504 .14278 .44934 .14138 Mtetra
.69 .735 .886 r
.44934 .14138 .4504 .14278 .45225 .14208 .45119 .14053 Mtetra
.688 .71 .866 r
.45119 .14053 .45225 .14208 .4541 .14138 .45305 .13966 Mtetra
.666 .678 .852 r
.45305 .13966 .4541 .14138 .45595 .14068 .4549 .13888 Mtetra
.654 .662 .846 r
.4549 .13888 .45595 .14068 .4578 .13998 .45676 .13816 Mtetra
.65 .658 .844 r
.45676 .13816 .4578 .13998 .45966 .13927 .45861 .13745 Mtetra
.677 .669 .836 r
.45861 .13745 .45966 .13927 .46152 .13852 .46047 .13659 Mtetra
.665 .65 .825 r
.46047 .13659 .46152 .13852 .46338 .13777 .46233 .13576 Mtetra
.622 .622 .829 r
.46233 .13576 .46338 .13777 .46523 .13706 .46419 .13519 Mtetra
.39 .517 .866 r
.46419 .13519 .46523 .13706 .46709 .13648 .46603 .13556 Mtetra
0 .149 .622 r
.46603 .13556 .46709 .13648 .46895 .13598 .46785 .13691 Mtetra
.758 .3 .16 r
.46785 .13691 .46895 .13598 .47081 .13548 .46966 .13941 Mtetra
.604 .241 .327 r
.46966 .13941 .47081 .13548 .47267 .13483 .47148 .14101 Mtetra
.431 .123 .339 r
.47148 .14101 .47267 .13483 .47454 .13408 .47335 .14039 Mtetra
.352 .058 .318 r
.47335 .14039 .47454 .13408 .47641 .1333 .47524 .13882 Mtetra
.379 .068 .308 r
.47524 .13882 .47641 .1333 .47828 .13255 .47712 .13774 Mtetra
.403 .083 .306 r
.47712 .13774 .47828 .13255 .48015 .13182 .47899 .13698 Mtetra
.404 .084 .305 r
.47899 .13698 .48015 .13182 .48202 .13109 .48087 .13623 Mtetra
.408 .087 .306 r
.48087 .13623 .48202 .13109 .48389 .13038 .48275 .13554 Mtetra
.412 .09 .308 r
.48275 .13554 .48389 .13038 .48576 .12967 .48463 .13487 Mtetra
.414 .093 .31 r
.48463 .13487 .48576 .12967 .48764 .12897 .4865 .13422 Mtetra
.415 .095 .312 r
.4865 .13422 .48764 .12897 .48951 .12826 .48838 .13357 Mtetra
.415 .096 .313 r
.48838 .13357 .48951 .12826 .49139 .12756 .49027 .13292 Mtetra
.417 .098 .315 r
.49027 .13292 .49139 .12756 .49327 .12686 .49215 .13226 Mtetra
.417 .1 .317 r
.49215 .13226 .49327 .12686 .49515 .12616 .49403 .13161 Mtetra
.418 .101 .318 r
.49403 .13161 .49515 .12616 .49703 .12546 .49592 .13096 Mtetra
.419 .103 .32 r
.49592 .13096 .49703 .12546 .49891 .12476 .49781 .13031 Mtetra
.42 .104 .321 r
.49781 .13031 .49891 .12476 .50079 .12407 .49969 .12966 Mtetra
.421 .105 .323 r
.49969 .12966 .50079 .12407 .50268 .12337 .50158 .129 Mtetra
.421 .106 .324 r
.50158 .129 .50268 .12337 .50457 .12267 .50347 .12835 Mtetra
.422 .107 .325 r
.50347 .12835 .50457 .12267 .50645 .12197 .50537 .12769 Mtetra
.422 .108 .326 r
.50537 .12769 .50645 .12197 .50834 .12127 .50726 .12702 Mtetra
.422 .109 .327 r
.50726 .12702 .50834 .12127 .51023 .12056 .50916 .12635 Mtetra
.422 .109 .328 r
.50916 .12635 .51023 .12056 .51212 .11985 .51105 .12567 Mtetra
.51105 .12567 .51212 .11985 .51402 .11914 .51295 .12498 Mtetra
.422 .11 .329 r
.51295 .12498 .51402 .11914 .51591 .11843 .51485 .12429 Mtetra
.421 .11 .329 r
.51485 .12429 .51591 .11843 .51781 .11771 .51675 .12359 Mtetra
.421 .11 .33 r
.51675 .12359 .51781 .11771 .5197 .117 .51866 .12289 Mtetra
.51866 .12289 .5197 .117 .5216 .11628 .52056 .12218 Mtetra
.52056 .12218 .5216 .11628 .5235 .11555 .52246 .12147 Mtetra
.421 .11 .331 r
.52246 .12147 .5235 .11555 .5254 .11483 .52437 .12076 Mtetra
.52437 .12076 .5254 .11483 .5273 .11411 .52628 .12004 Mtetra
.52628 .12004 .5273 .11411 .52921 .11338 .52819 .11932 Mtetra
.421 .111 .331 r
.52819 .11932 .52921 .11338 .53111 .11266 .5301 .1186 Mtetra
.5301 .1186 .53111 .11266 .53302 .11193 .53201 .11788 Mtetra
.53201 .11788 .53302 .11193 .53493 .1112 .53392 .11715 Mtetra
.53392 .11715 .53493 .1112 .53683 .11047 .53584 .11642 Mtetra
.53584 .11642 .53683 .11047 .53874 .10974 .53775 .1157 Mtetra
.53775 .1157 .53874 .10974 .54066 .10901 .53967 .11497 Mtetra
.53967 .11497 .54066 .10901 .54257 .10828 .54159 .11424 Mtetra
.54159 .11424 .54257 .10828 .54448 .10755 .54351 .11351 Mtetra
.54351 .11351 .54448 .10755 .5464 .10682 .54543 .11278 Mtetra
.421 .111 .332 r
.54543 .11278 .5464 .10682 .54832 .10609 .54735 .11204 Mtetra
.54735 .11204 .54832 .10609 .55023 .10535 .54928 .11131 Mtetra
.54928 .11131 .55023 .10535 .55215 .10462 .5512 .11058 Mtetra
.5512 .11058 .55215 .10462 .55407 .10389 .55313 .10984 Mtetra
.421 .111 .331 r
.55313 .10984 .55407 .10389 .556 .10315 .55505 .10911 Mtetra
.55505 .10911 .556 .10315 .55792 .10242 .55698 .10837 Mtetra
.42 .11 .331 r
.55698 .10837 .55792 .10242 .55984 .10168 .55891 .10763 Mtetra
.55891 .10763 .55984 .10168 .56177 .10094 .56085 .10689 Mtetra
.56085 .10689 .56177 .10094 .5637 .10021 .56278 .10616 Mtetra
.56278 .10616 .5637 .10021 .56563 .09947 .56471 .10541 Mtetra
.56471 .10541 .56563 .09947 .56756 .09873 .56665 .10467 Mtetra
.56665 .10467 .56756 .09873 .56949 .09799 .56859 .10393 Mtetra
.56859 .10393 .56949 .09799 .57142 .09725 .57052 .10318 Mtetra
.57052 .10318 .57142 .09725 .57335 .09651 .57246 .10244 Mtetra
.42 .109 .331 r
.57246 .10244 .57335 .09651 .57529 .09576 .57441 .10169 Mtetra
.419 .109 .33 r
.57441 .10169 .57529 .09576 .57723 .09502 .57635 .10094 Mtetra
.57635 .10094 .57723 .09502 .57916 .09428 .57829 .10018 Mtetra
.418 .108 .33 r
.57829 .10018 .57916 .09428 .5811 .09353 .58024 .09942 Mtetra
.418 .107 .329 r
.58024 .09942 .5811 .09353 .58304 .09278 .58218 .09866 Mtetra
.417 .107 .329 r
.58218 .09866 .58304 .09278 .58499 .09203 .58413 .09789 Mtetra
.416 .106 .328 r
.58413 .09789 .58499 .09203 .58693 .09128 .58608 .09711 Mtetra
.416 .105 .327 r
.58608 .09711 .58693 .09128 .58888 .09053 .58803 .09633 Mtetra
.415 .103 .326 r
.58803 .09633 .58888 .09053 .59082 .08978 .58998 .09554 Mtetra
.413 .102 .325 r
.58998 .09554 .59082 .08978 .59277 .08902 .59193 .09474 Mtetra
.412 .1 .324 r
.59193 .09474 .59277 .08902 .59472 .08826 .59389 .09394 Mtetra
.411 .099 .322 r
.59389 .09394 .59472 .08826 .59667 .0875 .59584 .09313 Mtetra
.409 .096 .321 r
.59584 .09313 .59667 .0875 .59862 .08674 .5978 .0923 Mtetra
.407 .094 .318 r
.5978 .0923 .59862 .08674 .60057 .08597 .59975 .09147 Mtetra
.406 .092 .316 r
.59975 .09147 .60057 .08597 .60253 .08521 .60171 .09063 Mtetra
.406 .091 .314 r
.60171 .09063 .60253 .08521 .60448 .08445 .60367 .08982 Mtetra
.407 .091 .313 r
.60367 .08982 .60448 .08445 .60644 .08369 .60563 .08903 Mtetra
.408 .091 .312 r
.60563 .08903 .60644 .08369 .6084 .08293 .60759 .08825 Mtetra
.409 .091 .312 r
.60759 .08825 .6084 .08293 .61036 .08218 .60956 .08749 Mtetra
.41 .092 .312 r
.60956 .08749 .61036 .08218 .61232 .08143 .61153 .08675 Mtetra
.412 .094 .313 r
.61153 .08675 .61232 .08143 .61428 .08069 .6135 .08602 Mtetra
.414 .096 .314 r
.6135 .08602 .61428 .08069 .61624 .07994 .61547 .08531 Mtetra
.417 .098 .316 r
.61547 .08531 .61624 .07994 .61821 .0792 .61744 .08462 Mtetra
.418 .1 .317 r
.61744 .08462 .61821 .0792 .62018 .07846 .61941 .08394 Mtetra
.418 .101 .319 r
.61941 .08394 .62018 .07846 .62215 .07772 .62139 .08325 Mtetra
.417 .101 .32 r
.62139 .08325 .62215 .07772 .62412 .07697 .62337 .08253 Mtetra
.416 .101 .321 r
.62337 .08253 .62412 .07697 .62609 .07622 .62534 .0818 Mtetra
.415 .101 .321 r
.62534 .0818 .62609 .07622 .62806 .07547 .62732 .08106 Mtetra
.414 .1 .321 r
.62732 .08106 .62806 .07547 .63003 .07471 .6293 .08029 Mtetra
.412 .098 .32 r
.6293 .08029 .63003 .07471 .63201 .07394 .63128 .0795 Mtetra
.408 .095 .319 r
.63128 .0795 .63201 .07394 .63398 .07316 .63326 .07867 Mtetra
.403 .09 .316 r
.63326 .07867 .63398 .07316 .63596 .07236 .63524 .07779 Mtetra
.401 .087 .314 r
.63524 .07779 .63596 .07236 .63794 .07156 .63722 .07691 Mtetra
.375 .064 .305 r
.63722 .07691 .63794 .07156 .63991 .07066 .63919 .07576 Mtetra
.298 0 .277 r
.63919 .07576 .63991 .07066 .64188 .06945 .64114 .07391 Mtetra
.388 .057 .278 r
.64114 .07391 .64188 .06945 .64386 .0687 .64312 .07313 Mtetra
.635 .269 .332 r
.64312 .07313 .64386 .0687 .6459 .06919 .64524 .07549 Mtetra
.971 .658 .345 r
.64524 .07549 .6459 .06919 .64823 .07661 .65612 .28507 Mtetra
.513 .272 .486 r
.65612 .28507 .64823 .07661 .65945 .28925 .65851 .29019 Mtetra
.641 .125 0 r
.65851 .29019 .65945 .28925 .66178 .29272 .66077 .29189 Mtetra
.512 .809 .999 r
.66077 .29189 .66178 .29272 .66396 .29249 .66293 .29148 Mtetra
.678 .841 .961 r
.66293 .29148 .66396 .29249 .6661 .29153 .66508 .29057 Mtetra
.719 .864 .95 r
.66508 .29057 .6661 .29153 .66823 .29028 .66722 .28948 Mtetra
.634 .868 .986 r
.66722 .28948 .66823 .29028 .67038 .28945 .66937 .28869 Mtetra
.638 .878 .986 r
.66937 .28869 .67038 .28945 .67253 .2886 .67153 .28787 Mtetra
.65 .887 .983 r
.67153 .28787 .67253 .2886 .67468 .28776 .67368 .28699 Mtetra
.683 .892 .973 r
.67368 .28699 .67468 .28776 .67684 .28696 .67583 .28601 Mtetra
.696 .859 .96 r
.67583 .28601 .67684 .28696 .679 .28619 .67798 .28501 Mtetra
.689 .814 .942 r
.67798 .28501 .679 .28619 .68116 .28543 .68013 .28407 Mtetra
.656 .768 .931 r
.68013 .28407 .68116 .28543 .68333 .28467 .6823 .28328 Mtetra
.638 .754 .933 r
.6823 .28328 .68333 .28467 .68549 .28393 .68447 .28258 Mtetra
.599 .744 .946 r
.68447 .28258 .68549 .28393 .68767 .28329 .68665 .28204 Mtetra
.397 .66 .965 r
.68665 .28204 .68767 .28329 .68987 .28319 .68886 .28213 Mtetra
.549 .78 .984 r
.68886 .28213 .68987 .28319 .69205 .2826 .69105 .28169 Mtetra
.802 .895 .91 r
.69105 .28169 .69205 .2826 .69417 .28092 .69318 .28013 Mtetra
.993 .802 .543 r
.69318 .28013 .69417 .28092 .69597 .27332 .69498 .27252 Mtetra
.976 .67 .324 r
.69498 .27252 .69597 .27332 .68609 .05723 .6851 .05536 Mtetra
.941 .751 .618 r
.6851 .05536 .68609 .05723 .68784 .05183 .68686 .04995 Mtetra
.707 .692 .833 r
.68686 .04995 .68784 .05183 .68983 .05056 .68886 .04883 Mtetra
.579 .651 .885 r
.68886 .04883 .68983 .05056 .69186 .05 .6909 .04845 Mtetra
.476 .626 .918 r
.6909 .04845 .69186 .05 .69391 .04979 .69296 .04844 Mtetra
.644 .748 .925 r
.69296 .04844 .69391 .04979 .69593 .04908 .69499 .04776 Mtetra
.658 .759 .924 r
.69499 .04776 .69593 .04908 .69796 .04836 .69701 .04701 Mtetra
.672 .761 .918 r
.69701 .04701 .69796 .04836 .69998 .04759 .69903 .0462 Mtetra
.763 .787 .872 r
.69903 .0462 .69998 .04759 .70197 .04626 .70103 .04486 Mtetra
.696 .761 .901 r
.70103 .04486 .70197 .04626 .70399 .04534 .70304 .04393 Mtetra
.502 .668 .937 r
.70304 .04393 .70399 .04534 .70605 .04521 .70511 .04379 Mtetra
.749 .332 0 r
.70511 .04379 .70605 .04521 .70845 .05022 .70751 .04882 Mtetra
.97 .655 .291 r
.70751 .04882 .70845 .05022 .72445 .2655 .72344 .26413 Mtetra
.734 .301 0 r
.72344 .26413 .72445 .2655 .72701 .27041 .72601 .26902 Mtetra
.048 .474 .885 r
.03078 .50515 .0321 .50622 .03363 .50675 .03232 .50568 Mtetra
.646 .762 .934 r
.03232 .50568 .03363 .50675 .03533 .50617 .03402 .5051 Mtetra
.81 .778 .823 r
.03402 .5051 .03533 .50617 .0372 .50447 .03588 .5034 Mtetra
.908 .737 .658 r
.03588 .5034 .0372 .50447 .03968 .49854 .03837 .49747 Mtetra
.937 .686 .534 r
.03837 .49747 .03968 .49854 .07145 .29149 .07023 .29036 Mtetra
.908 .728 .646 r
.07023 .29036 .07145 .29149 .07386 .2853 .07265 .28417 Mtetra
.777 .76 .838 r
.07265 .28417 .07386 .2853 .07557 .28398 .07436 .28285 Mtetra
.642 .737 .918 r
.07436 .28285 .07557 .28398 .07716 .28345 .07595 .28232 Mtetra
.512 .693 .95 r
.07595 .28232 .07716 .28345 .0787 .2833 .07749 .28218 Mtetra
.746 .759 .863 r
.07749 .28218 .0787 .2833 .08037 .28223 .07916 .28111 Mtetra
.698 .752 .893 r
.07916 .28111 .08037 .28223 .082 .28145 .08079 .28033 Mtetra
.49 .686 .954 r
.08079 .28033 .082 .28145 .08354 .28135 .08233 .28023 Mtetra
.923 .536 .235 r
.08233 .28023 .08354 .28135 .08451 .28524 .08329 .28416 Mtetra
.939 .683 .522 r
.08329 .28416 .08451 .28524 .05698 .49096 .05566 .48998 Mtetra
.933 .584 .34 r
.05566 .48998 .05698 .49096 .05778 .49685 .05647 .49581 Mtetra
.216 .583 .944 r
.05647 .49581 .05778 .49685 .05937 .49718 .05806 .49612 Mtetra
.676 .774 .924 r
.05806 .49612 .05937 .49718 .0611 .49647 .05979 .49541 Mtetra
.757 .784 .875 r
.05979 .49541 .0611 .49647 .0629 .49531 .06159 .49424 Mtetra
.495 .716 .97 r
.06159 .49424 .0629 .49531 .06456 .49517 .06325 .49408 Mtetra
.595 .748 .95 r
.06325 .49408 .06456 .49517 .06625 .49477 .06495 .49367 Mtetra
.76 .778 .869 r
.06495 .49367 .06625 .49477 .06806 .49358 .06676 .49246 Mtetra
.911 .737 .653 r
.06676 .49246 .06806 .49358 .07053 .48754 .06924 .48638 Mtetra
.94 .687 .528 r
.06924 .48638 .07053 .48754 .1006 .27967 .0994 .27847 Mtetra
.906 .729 .65 r
.0994 .27847 .1006 .27967 .10293 .27382 .10174 .27266 Mtetra
.779 .758 .834 r
.10174 .27266 .10293 .27382 .10465 .27247 .10346 .2713 Mtetra
.593 .716 .929 r
.10346 .2713 .10465 .27247 .10624 .27212 .10505 .27094 Mtetra
.415 .641 .95 r
.10505 .27094 .10624 .27212 .10777 .2722 .10658 .27101 Mtetra
.603 .715 .923 r
.10658 .27101 .10777 .2722 .10937 .2718 .10817 .27061 Mtetra
.645 .729 .91 r
.10817 .27061 .10937 .2718 .11098 .27124 .10979 .27006 Mtetra
.656 .734 .907 r
.10979 .27006 .11098 .27124 .11261 .27063 .11141 .26947 Mtetra
.746 .756 .86 r
.11141 .26947 .11261 .27063 .1143 .26953 .1131 .26838 Mtetra
.713 .753 .884 r
.1131 .26838 .1143 .26953 .11596 .26865 .11477 .26752 Mtetra
.529 .701 .949 r
.11477 .26752 .11596 .26865 .11754 .26844 .11634 .26733 Mtetra
.914 .512 .189 r
.11634 .26733 .11754 .26844 .11861 .27208 .1174 .271 Mtetra
.943 .684 .514 r
.1174 .271 .11861 .27208 .09313 .47881 .09182 .47781 Mtetra
.934 .58 .325 r
.09182 .47781 .09313 .47881 .09401 .48475 .09271 .48368 Mtetra
.106 .512 .908 r
.09271 .48368 .09401 .48475 .09561 .48523 .09431 .48416 Mtetra
.7 .779 .913 r
.09431 .48416 .09561 .48523 .09739 .48439 .09609 .48333 Mtetra
.78 .788 .86 r
.09609 .48333 .09739 .48439 .09923 .48301 .09793 .48196 Mtetra
.695 .782 .918 r
.09793 .48196 .09923 .48301 .10098 .48235 .0997 .48116 Mtetra
.662 .749 .915 r
.0997 .48116 .10098 .48235 .10273 .48177 .10146 .48049 Mtetra
.699 .744 .886 r
.10146 .48049 .10273 .48177 .10453 .48073 .10324 .47963 Mtetra
.813 .783 .825 r
.10324 .47963 .10453 .48073 .10662 .47745 .10513 .4779 Mtetra
.913 .966 .799 r
.10513 .4779 .10662 .47745 .10942 .46847 .10712 .47541 Mtetra
.144 0 .217 r
.10712 .47541 .10942 .46847 .13644 .26682 .10918 .47228 Mtetra
.498 .259 .484 r
.10918 .47228 .13644 .26682 .13842 .2636 .11116 .46987 Mtetra
.501 .263 .485 r
.11116 .46987 .13842 .2636 .1401 .26265 .11295 .46895 Mtetra
.504 .265 .486 r
.11295 .46895 .1401 .26265 .14161 .26312 .11456 .46947 Mtetra
.508 .268 .486 r
.11456 .46947 .14161 .26312 .14231 .27021 .116 .47141 Mtetra
.507 .268 .486 r
.116 .47141 .14231 .27021 .11916 .47089 .11747 .47306 Mtetra
.587 .18 .239 r
.11747 .47306 .11916 .47089 .12038 .4747 .11903 .47404 Mtetra
0 .495 .834 r
.11903 .47404 .12038 .4747 .12193 .47573 .12067 .47447 Mtetra
.536 .696 .942 r
.12067 .47447 .12193 .47573 .12365 .47553 .12238 .47425 Mtetra
.733 .752 .867 r
.12238 .47425 .12365 .47553 .12548 .4743 .1242 .47316 Mtetra
.902 .754 .687 r
.1242 .47316 .12548 .4743 .12774 .46962 .12644 .46866 Mtetra
.946 .689 .516 r
.12644 .46866 .12774 .46962 .15445 .2613 .1532 .26065 Mtetra
.939 .746 .615 r
.1532 .26065 .15445 .2613 .15695 .25366 .15574 .25266 Mtetra
.843 .786 .797 r
.15574 .25266 .15695 .25366 .15876 .2517 .15757 .25065 Mtetra
.641 .759 .934 r
.15757 .25065 .15876 .2517 .1604 .2512 .15921 .2501 Mtetra
.468 .687 .962 r
.15921 .2501 .1604 .2512 .16199 .25117 .16081 .25003 Mtetra
.652 .745 .918 r
.16081 .25003 .16199 .25117 .16363 .25072 .16246 .24945 Mtetra
.693 .732 .88 r
.16246 .24945 .16363 .25072 .1653 .25002 .16414 .24866 Mtetra
.6 .687 .903 r
.16414 .24866 .1653 .25002 .16694 .24951 .16577 .24827 Mtetra
0 .096 .608 r
.16577 .24827 .16694 .24951 .16852 .2496 .16722 .24954 Mtetra
.905 .544 .345 r
.16722 .24954 .16852 .2496 .17001 .25049 .16818 .25491 Mtetra
.942 .677 .506 r
.16818 .25491 .17001 .25049 .17133 .25289 .14625 .45888 Mtetra
.513 .272 .488 r
.14625 .45888 .17133 .25289 .15006 .45269 .14747 .46302 Mtetra
.543 .253 .424 r
.14747 .46302 .15006 .45269 .15068 .46222 .14904 .46422 Mtetra
.391 0 .088 r
.14904 .46422 .15068 .46222 .15211 .4646 .15076 .46415 Mtetra
.878 .878 .83 r
.15076 .46415 .15211 .4646 .15385 .46437 .15272 .46201 Mtetra
.873 .685 .646 r
.15272 .46201 .15385 .46437 .15579 .4624 .15508 .45625 Mtetra
.943 .683 .512 r
.15508 .45625 .15579 .4624 .15794 .45848 .17993 .25016 Mtetra
.519 .283 .497 r
.17993 .25016 .15794 .45848 .18134 .26369 .18218 .24435 Mtetra
.567 .347 .541 r
.18218 .24435 .18134 .26369 .18492 .24588 .18405 .24197 Mtetra
.671 .523 .675 r
.18405 .24197 .18492 .24588 .18695 .24209 .18583 .24042 Mtetra
.7 .679 .826 r
.18583 .24042 .18695 .24209 .18873 .24048 .18754 .23948 Mtetra
.642 .773 .943 r
.18754 .23948 .18873 .24048 .1904 .2399 .18921 .23892 Mtetra
.596 .763 .959 r
.18921 .23892 .1904 .2399 .19204 .23964 .19086 .23851 Mtetra
.701 .762 .899 r
.19086 .23851 .19204 .23964 .19371 .23901 .19256 .23769 Mtetra
.726 .735 .858 r
.19256 .23769 .19371 .23901 .19542 .23809 .19428 .23668 Mtetra
.654 .7 .88 r
.19428 .23668 .19542 .23809 .19711 .23738 .19596 .23606 Mtetra
.022 .385 .846 r
.19596 .23606 .19711 .23738 .19873 .23729 .19749 .23683 Mtetra
.892 .483 .223 r
.19749 .23683 .19873 .23729 .20027 .23808 .19871 .24057 Mtetra
.947 .68 .497 r
.19871 .24057 .20027 .23808 .20166 .24025 .17865 .44514 Mtetra
.517 .276 .488 r
.17865 .44514 .20166 .24025 .18358 .42782 .17975 .45111 Mtetra
.528 .265 .46 r
.17975 .45111 .18358 .42782 .18293 .45055 .18133 .45258 Mtetra
.51 .084 .167 r
.18133 .45258 .18293 .45055 .18434 .45362 .18302 .45308 Mtetra
.194 .672 .933 r
.18302 .45308 .18434 .45362 .186 .45446 .18475 .45317 Mtetra
.551 .701 .939 r
.18475 .45317 .186 .45446 .18777 .45412 .18652 .45289 Mtetra
.697 .759 .9 r
.18652 .45289 .18777 .45412 .18961 .45321 .18835 .45204 Mtetra
.844 .78 .79 r
.18835 .45204 .18961 .45321 .1915 .45174 .19033 .4498 Mtetra
.883 .708 .66 r
.19033 .4498 .1915 .45174 .19347 .44958 .1926 .44462 Mtetra
.948 .685 .504 r
.1926 .44462 .19347 .44958 .19556 .44616 .21511 .23937 Mtetra
.524 .287 .498 r
.21511 .23937 .19556 .44616 .19826 .43662 .21752 .23161 Mtetra
.511 .276 .495 r
.21752 .23161 .19826 .43662 .22019 .23407 .21941 .22915 Mtetra
.645 .482 .648 r
.21941 .22915 .22019 .23407 .22227 .22962 .22119 .22761 Mtetra
.693 .641 .793 r
.22119 .22761 .22227 .22962 .2241 .22763 .22293 .22659 Mtetra
.672 .775 .927 r
.22293 .22659 .2241 .22763 .22582 .22685 .22463 .22591 Mtetra
.624 .782 .957 r
.22463 .22591 .22582 .22685 .22749 .22644 .22632 .2254 Mtetra
.702 .782 .913 r
.22632 .2254 .22749 .22644 .2292 .22573 .22804 .22458 Mtetra
.742 .77 .875 r
.22804 .22458 .2292 .22573 .23094 .22468 .22979 .22352 Mtetra
.631 .739 .926 r
.22979 .22352 .23094 .22468 .23263 .22418 .23148 .223 Mtetra
0 0 .501 r
.23148 .223 .23263 .22418 .23413 .22575 .23298 .22452 Mtetra
.955 .685 .485 r
.23298 .22452 .23413 .22575 .21665 .42736 .21554 .42483 Mtetra
.971 .667 .382 r
.21554 .42483 .21665 .42736 .2171 .44128 .21587 .43997 Mtetra
.62 .129 0 r
.21587 .43997 .2171 .44128 .21868 .44322 .21744 .44196 Mtetra
.632 .737 .924 r
.21744 .44196 .21868 .44322 .22051 .44262 .21927 .44139 Mtetra
.752 .773 .87 r
.21927 .44139 .22051 .44262 .22239 .44137 .22115 .44017 Mtetra
.758 .78 .871 r
.22115 .44017 .22239 .44137 .22428 .44009 .22304 .43893 Mtetra
.686 .772 .916 r
.22304 .43893 .22428 .44009 .22613 .43928 .22489 .43813 Mtetra
.679 .771 .92 r
.22489 .43813 .22613 .43928 .22798 .43851 .22673 .43735 Mtetra
.653 .765 .931 r
.22673 .43735 .22798 .43851 .22981 .43792 .22857 .4367 Mtetra
.627 .744 .931 r
.22857 .4367 .22981 .43792 .23162 .4375 .2304 .43614 Mtetra
.666 .733 .9 r
.2304 .43614 .23162 .4375 .23347 .4367 .23224 .43542 Mtetra
.764 .769 .857 r
.23224 .43542 .23347 .4367 .23545 .4345 .23414 .43409 Mtetra
.899 .887 .811 r
.23414 .43409 .23545 .4345 .23781 .42802 .23614 .43167 Mtetra
0 0 0 r
.23614 .43167 .23781 .42802 .25765 .22223 .23821 .4285 Mtetra
.498 .26 .484 r
.23821 .4285 .25765 .22223 .25973 .21754 .24019 .42624 Mtetra
.505 .266 .486 r
.24019 .42624 .25973 .21754 .26142 .21729 .2419 .427 Mtetra
.503 .264 .485 r
.2419 .427 .26142 .21729 .26306 .21765 .24369 .42705 Mtetra
.495 .258 .483 r
.24369 .42705 .26306 .21765 .26482 .21653 .24579 .42343 Mtetra
0 0 .122 r
.24579 .42343 .26482 .21653 .26677 .21333 .26524 .21665 Mtetra
.869 .864 .416 r
.26524 .21665 .26677 .21333 .26865 .21087 .26744 .21051 Mtetra
.917 .878 .782 r
.26744 .21051 .26865 .21087 .27046 .20926 .26933 .20791 Mtetra
.7 .73 .874 r
.26933 .20791 .27046 .20926 .2722 .20854 .27108 .20705 Mtetra
.61 .676 .888 r
.27108 .20705 .2722 .20854 .27391 .20805 .2728 .2066 Mtetra
.589 .675 .9 r
.2728 .2066 .27391 .20805 .27563 .2076 .2745 .20624 Mtetra
.649 .712 .894 r
.2745 .20624 .27563 .2076 .27736 .20701 .27623 .20563 Mtetra
.648 .71 .892 r
.27623 .20563 .27736 .20701 .27909 .20641 .27797 .20502 Mtetra
.65 .709 .891 r
.27797 .20502 .27909 .20641 .28082 .20579 .2797 .2044 Mtetra
.653 .71 .889 r
.2797 .2044 .28082 .20579 .28255 .20517 .28143 .20377 Mtetra
.654 .71 .888 r
.28143 .20377 .28255 .20517 .28429 .20453 .28317 .20314 Mtetra
.656 .71 .888 r
.28317 .20314 .28429 .20453 .28603 .20388 .28491 .20249 Mtetra
.657 .711 .888 r
.28491 .20249 .28603 .20388 .28777 .20322 .28665 .20184 Mtetra
.655 .713 .89 r
.28665 .20184 .28777 .20322 .28951 .20256 .28839 .2012 Mtetra
.646 .712 .896 r
.28839 .2012 .28951 .20256 .29125 .20195 .29013 .2006 Mtetra
.627 .708 .904 r
.29013 .2006 .29125 .20195 .29298 .20143 .29186 .20008 Mtetra
.631 .71 .903 r
.29186 .20008 .29298 .20143 .29472 .20088 .2936 .19954 Mtetra
.652 .72 .898 r
.2936 .19954 .29472 .20088 .29647 .20022 .29534 .19892 Mtetra
.69 .738 .887 r
.29534 .19892 .29647 .20022 .29823 .19934 .2971 .19811 Mtetra
.7 .752 .892 r
.2971 .19811 .29823 .19934 .3 .19843 .29887 .19726 Mtetra
.698 .764 .903 r
.29887 .19726 .3 .19843 .30177 .19755 .30063 .19644 Mtetra
.681 .77 .919 r
.30063 .19644 .30177 .19755 .30352 .19677 .30239 .19569 Mtetra
.676 .776 .926 r
.30239 .19569 .30352 .19677 .30528 .19603 .30414 .19498 Mtetra
.68 .782 .927 r
.30414 .19498 .30528 .19603 .30704 .19525 .3059 .19424 Mtetra
.704 .797 .923 r
.3059 .19424 .30704 .19525 .30882 .19427 .30767 .1934 Mtetra
.669 .817 .954 r
.30767 .1934 .30882 .19427 .31058 .19358 .30943 .1927 Mtetra
.555 .779 .982 r
.30943 .1927 .31058 .19358 .31229 .19358 .31116 .19234 Mtetra
.202 .519 .916 r
.31116 .19234 .31229 .19358 .31384 .19578 .31284 .19283 Mtetra
.313 .349 .738 r
.31284 .19283 .31384 .19578 .31505 .20315 .31449 .19378 Mtetra
.454 .291 .569 r
.31449 .19378 .31505 .20315 .30281 .40603 .31613 .19483 Mtetra
.505 .271 .493 r
.31613 .19483 .30281 .40603 .30461 .40658 .31788 .19444 Mtetra
.507 .272 .494 r
.31788 .19444 .30461 .40658 .30653 .40542 .31966 .19353 Mtetra
.507 .273 .494 r
.31966 .19353 .30653 .40542 .30851 .40336 .32146 .19235 Mtetra
.508 .273 .494 r
.32146 .19235 .30851 .40336 .31047 .40162 .32328 .19097 Mtetra
.506 .272 .494 r
.32328 .19097 .31047 .40162 .31237 .40078 .32505 .19024 Mtetra
.502 .269 .493 r
.32505 .19024 .31237 .40078 .31413 .40209 .32672 .19112 Mtetra
0 0 .192 r
.32672 .19112 .31413 .40209 .31575 .40553 .31514 .39521 Mtetra
0 0 .32 r
.31514 .39521 .31575 .40553 .31748 .40749 .31638 .40474 Mtetra
0 .011 .584 r
.31638 .40474 .31748 .40749 .31928 .4084 .31807 .4072 Mtetra
.512 .712 .962 r
.31807 .4072 .31928 .4084 .32116 .40805 .31994 .407 Mtetra
.67 .798 .943 r
.31994 .407 .32116 .40805 .32306 .40739 .32185 .40625 Mtetra
.714 .792 .912 r
.32185 .40625 .32306 .40739 .32497 .40663 .32377 .40527 Mtetra
.602 .719 .927 r
.32377 .40527 .32497 .40663 .32685 .40633 .32567 .40481 Mtetra
.636 .703 .895 r
.32567 .40481 .32685 .40633 .32875 .40575 .32757 .4042 Mtetra
.687 .718 .873 r
.32757 .4042 .32875 .40575 .33069 .40455 .32949 .40331 Mtetra
.78 .787 .858 r
.32949 .40331 .33069 .40455 .33275 .40128 .33145 .40186 Mtetra
.816 .996 .766 r
.33145 .40186 .33275 .40128 .33502 .39444 .33345 .39969 Mtetra
0 0 .109 r
.33345 .39969 .33502 .39444 .34902 .18683 .33554 .39589 Mtetra
0 0 .186 r
.33554 .39589 .34902 .18683 .35107 .18165 .34944 .18935 Mtetra
0 0 0 r
.34944 .18935 .35107 .18165 .35297 .179 .35177 .17941 Mtetra
.96 .94 .706 r
.35177 .17941 .35297 .179 .35481 .17731 .35371 .17604 Mtetra
.716 .755 .882 r
.35371 .17604 .35481 .17731 .3566 .17657 .35551 .17508 Mtetra
.6 .677 .895 r
.35551 .17508 .3566 .17657 .35838 .17614 .35729 .17466 Mtetra
.525 .646 .911 r
.35729 .17466 .35838 .17614 .36014 .17584 .35905 .17451 Mtetra
.647 .723 .904 r
.35905 .17451 .36014 .17584 .36193 .1752 .36083 .17389 Mtetra
.66 .733 .904 r
.36083 .17389 .36193 .1752 .36373 .17448 .36263 .17322 Mtetra
.675 .747 .905 r
.36263 .17322 .36373 .17448 .36553 .17368 .36442 .17248 Mtetra
.732 .772 .885 r
.36442 .17248 .36553 .17368 .36735 .17244 .36624 .17144 Mtetra
.718 .808 .921 r
.36624 .17144 .36735 .17244 .36916 .17146 .36804 .17052 Mtetra
.657 .805 .954 r
.36804 .17052 .36916 .17146 .37095 .17097 .36984 .16985 Mtetra
.452 .686 .965 r
.36984 .16985 .37095 .17097 .37263 .17248 .37161 .16981 Mtetra
.378 .414 .772 r
.37161 .16981 .37263 .17248 .37416 .17723 .37334 .17043 Mtetra
.335 .233 .587 r
.37334 .17043 .37416 .17723 .36566 .38409 .375 .1725 Mtetra
0 0 .221 r
.375 .1725 .36566 .38409 .36734 .38845 .36663 .37761 Mtetra
0 0 .371 r
.36663 .37761 .36734 .38845 .36916 .39006 .36807 .38694 Mtetra
0 .061 .612 r
.36807 .38694 .36916 .39006 .37103 .39064 .36985 .38948 Mtetra
.305 .616 .957 r
.36985 .38948 .37103 .39064 .37294 .39049 .37174 .38974 Mtetra
.614 .845 .987 r
.37174 .38974 .37294 .39049 .37488 .38985 .37368 .38911 Mtetra
.803 .881 .903 r
.37368 .38911 .37488 .38985 .37684 .38872 .37566 .38764 Mtetra
.914 .801 .72 r
.37566 .38764 .37684 .38872 .37884 .38686 .37773 .384 Mtetra
.912 .688 .586 r
.37773 .384 .37884 .38686 .38088 .384 .38007 .37472 Mtetra
.96 .68 .459 r
.38007 .37472 .38088 .384 .38303 .37861 .39127 .16662 Mtetra
.513 .278 .495 r
.39127 .16662 .38303 .37861 .39405 .17023 .39323 .16284 Mtetra
.629 .437 .603 r
.39323 .16284 .39405 .17023 .39612 .16363 .3951 .16075 Mtetra
.693 .583 .727 r
.3951 .16075 .39612 .16363 .39804 .16059 .39695 .15934 Mtetra
.687 .755 .903 r
.39695 .15934 .39804 .16059 .39987 .15953 .39877 .15853 Mtetra
.62 .784 .96 r
.39877 .15853 .39987 .15953 .40168 .15905 .40058 .15799 Mtetra
.591 .761 .96 r
.40058 .15799 .40168 .15905 .40348 .1588 .40239 .15755 Mtetra
.738 .77 .879 r
.40239 .15755 .40348 .1588 .4053 .15789 .40423 .15646 Mtetra
.708 .733 .871 r
.40423 .15646 .4053 .15789 .40713 .15697 .40606 .15551 Mtetra
.609 .69 .9 r
.40606 .15551 .40713 .15697 .40895 .15634 .40787 .15505 Mtetra
0 .059 .586 r
.40787 .15505 .40895 .15634 .41074 .15654 .4096 .15672 Mtetra
.911 .529 .281 r
.4096 .15672 .41074 .15654 .4125 .15767 .41116 .16322 Mtetra
.963 .674 .438 r
.41116 .16322 .4125 .15767 .41418 .16089 .40517 .3712 Mtetra
.51 .269 .486 r
.40517 .3712 .41418 .16089 .40844 .3677 .40699 .37428 Mtetra
.542 .22 .372 r
.40699 .37428 .40844 .3677 .41013 .37441 .40889 .37528 Mtetra
.363 0 0 r
.40889 .37528 .41013 .37441 .41199 .37661 .41082 .3755 Mtetra
.432 .697 .976 r
.41082 .3755 .41199 .37661 .41392 .37683 .41277 .37546 Mtetra
.612 .727 .928 r
.41277 .37546 .41392 .37683 .41589 .37622 .41473 .37494 Mtetra
.741 .782 .886 r
.41473 .37494 .41589 .37622 .41788 .37504 .41672 .37376 Mtetra
.895 .79 .738 r
.41672 .37376 .41788 .37504 .41988 .37327 .41877 .37053 Mtetra
.905 .692 .603 r
.41877 .37053 .41988 .37327 .42192 .37062 .42097 .36296 Mtetra
.965 .681 .445 r
.42097 .36296 .42192 .37062 .42401 .36597 .42964 .15301 Mtetra
.515 .279 .495 r
.42964 .15301 .42401 .36597 .43241 .15823 .4316 .1485 Mtetra
.609 .405 .58 r
.4316 .1485 .43241 .15823 .4345 .14956 .43349 .14624 Mtetra
.686 .558 .705 r
.43349 .14624 .4345 .14956 .43642 .14615 .43535 .14472 Mtetra
.713 .736 .869 r
.43535 .14472 .43642 .14615 .43828 .14472 .43721 .14373 Mtetra
.66 .802 .951 r
.43721 .14373 .43828 .14472 .44013 .14401 .43905 .14303 Mtetra
.611 .789 .967 r
.43905 .14303 .44013 .14401 .44196 .14361 .44089 .14251 Mtetra
.62 .765 .949 r
.44089 .14251 .44196 .14361 .4438 .14315 .44273 .14197 Mtetra
.626 .752 .938 r
.44273 .14197 .4438 .14315 .44564 .14265 .44457 .14142 Mtetra
.636 .745 .927 r
.44457 .14142 .44564 .14265 .44749 .14212 .44642 .14083 Mtetra
.677 .749 .905 r
.44642 .14083 .44749 .14212 .44934 .14138 .44827 .14006 Mtetra
.694 .749 .894 r
.44827 .14006 .44934 .14138 .45119 .14053 .45013 .1392 Mtetra
.696 .748 .892 r
.45013 .1392 .45119 .14053 .45305 .13966 .45198 .13832 Mtetra
.68 .742 .898 r
.45198 .13832 .45305 .13966 .4549 .13888 .45384 .13753 Mtetra
.67 .736 .899 r
.45384 .13753 .4549 .13888 .45676 .13816 .4557 .13678 Mtetra
.665 .73 .898 r
.4557 .13678 .45676 .13816 .45861 .13745 .45755 .13606 Mtetra
.712 .744 .876 r
.45755 .13606 .45861 .13745 .46047 .13659 .45942 .13508 Mtetra
.692 .719 .87 r
.45942 .13508 .46047 .13659 .46233 .13576 .46128 .13419 Mtetra
.602 .673 .89 r
.46128 .13419 .46233 .13576 .46419 .13519 .46313 .13374 Mtetra
0 .212 .731 r
.46313 .13374 .46419 .13519 .46603 .13556 .46495 .13516 Mtetra
.909 .503 .186 r
.46495 .13516 .46603 .13556 .46785 .13691 .46669 .14088 Mtetra
.968 .674 .416 r
.46669 .14088 .46785 .13691 .46966 .13941 .46458 .34974 Mtetra
.508 .268 .486 r
.46458 .34974 .46966 .13941 .47148 .14101 .46652 .35213 Mtetra
.502 .263 .485 r
.46652 .35213 .47148 .14101 .47335 .14039 .46852 .35159 Mtetra
.5 .262 .485 r
.46852 .35159 .47335 .14039 .47524 .13882 .47054 .35022 Mtetra
.501 .263 .485 r
.47054 .35022 .47524 .13882 .47712 .13774 .47255 .3492 Mtetra
.502 .263 .485 r
.47255 .3492 .47712 .13774 .47899 .13698 .47456 .34848 Mtetra
.47456 .34848 .47899 .13698 .48087 .13623 .47657 .34777 Mtetra
.47657 .34777 .48087 .13623 .48275 .13554 .47859 .3471 Mtetra
.47859 .3471 .48275 .13554 .48463 .13487 .4806 .34645 Mtetra
.4806 .34645 .48463 .13487 .4865 .13422 .48261 .34582 Mtetra
.48261 .34582 .4865 .13422 .48838 .13357 .48463 .34518 Mtetra
.48463 .34518 .48838 .13357 .49027 .13292 .48665 .34453 Mtetra
.48665 .34453 .49027 .13292 .49215 .13226 .48866 .34388 Mtetra
.48866 .34388 .49215 .13226 .49403 .13161 .49068 .34322 Mtetra
.49068 .34322 .49403 .13161 .49592 .13096 .49271 .34257 Mtetra
.49271 .34257 .49592 .13096 .49781 .13031 .49473 .34191 Mtetra
.49473 .34191 .49781 .13031 .49969 .12966 .49676 .34125 Mtetra
.49676 .34125 .49969 .12966 .50158 .129 .49878 .34058 Mtetra
.49878 .34058 .50158 .129 .50347 .12835 .50081 .33991 Mtetra
.50081 .33991 .50347 .12835 .50537 .12769 .50284 .33924 Mtetra
.50284 .33924 .50537 .12769 .50726 .12702 .50487 .33857 Mtetra
.50487 .33857 .50726 .12702 .50916 .12635 .5069 .33789 Mtetra
.5069 .33789 .50916 .12635 .51105 .12567 .50894 .33721 Mtetra
.50894 .33721 .51105 .12567 .51295 .12498 .51098 .33652 Mtetra
.51098 .33652 .51295 .12498 .51485 .12429 .51301 .33584 Mtetra
.51301 .33584 .51485 .12429 .51675 .12359 .51505 .33515 Mtetra
.51505 .33515 .51675 .12359 .51866 .12289 .51709 .33445 Mtetra
.51709 .33445 .51866 .12289 .52056 .12218 .51914 .33376 Mtetra
.51914 .33376 .52056 .12218 .52246 .12147 .52118 .33307 Mtetra
.52118 .33307 .52246 .12147 .52437 .12076 .52322 .33237 Mtetra
.52322 .33237 .52437 .12076 .52628 .12004 .52527 .33167 Mtetra
.52527 .33167 .52628 .12004 .52819 .11932 .52732 .33097 Mtetra
.52732 .33097 .52819 .11932 .5301 .1186 .52937 .33027 Mtetra
.52937 .33027 .5301 .1186 .53201 .11788 .53142 .32957 Mtetra
.53142 .32957 .53201 .11788 .53392 .11715 .53347 .32887 Mtetra
.53347 .32887 .53392 .11715 .53584 .11642 .53553 .32816 Mtetra
.53553 .32816 .53584 .11642 .53775 .1157 .53758 .32746 Mtetra
.53758 .32746 .53775 .1157 .53967 .11497 .53964 .32675 Mtetra
.53964 .32675 .53967 .11497 .54159 .11424 .5417 .32605 Mtetra
.5417 .32605 .54159 .11424 .54351 .11351 .54376 .32534 Mtetra
.54376 .32534 .54351 .11351 .54543 .11278 .54582 .32464 Mtetra
.54582 .32464 .54543 .11278 .54735 .11204 .54789 .32393 Mtetra
.54789 .32393 .54735 .11204 .54928 .11131 .54995 .32322 Mtetra
.54995 .32322 .54928 .11131 .5512 .11058 .55202 .32251 Mtetra
.55202 .32251 .5512 .11058 .55313 .10984 .55409 .3218 Mtetra
.55409 .3218 .55313 .10984 .55505 .10911 .55616 .32109 Mtetra
.55616 .32109 .55505 .10911 .55698 .10837 .55823 .32038 Mtetra
.55823 .32038 .55698 .10837 .55891 .10763 .5603 .31967 Mtetra
.5603 .31967 .55891 .10763 .56085 .10689 .56238 .31896 Mtetra
.56238 .31896 .56085 .10689 .56278 .10616 .56445 .31825 Mtetra
.56445 .31825 .56278 .10616 .56471 .10541 .56653 .31753 Mtetra
.56653 .31753 .56471 .10541 .56665 .10467 .56861 .31682 Mtetra
.56861 .31682 .56665 .10467 .56859 .10393 .57069 .3161 Mtetra
.57069 .3161 .56859 .10393 .57052 .10318 .57277 .31539 Mtetra
.57277 .31539 .57052 .10318 .57246 .10244 .57485 .31467 Mtetra
.57485 .31467 .57246 .10244 .57441 .10169 .57694 .31395 Mtetra
.57694 .31395 .57441 .10169 .57635 .10094 .57903 .31323 Mtetra
.57903 .31323 .57635 .10094 .57829 .10018 .58112 .3125 Mtetra
.58112 .3125 .57829 .10018 .58024 .09942 .58321 .31178 Mtetra
.58321 .31178 .58024 .09942 .58218 .09866 .5853 .31105 Mtetra
.5853 .31105 .58218 .09866 .58413 .09789 .58739 .31032 Mtetra
.58739 .31032 .58413 .09789 .58608 .09711 .58948 .30958 Mtetra
.58948 .30958 .58608 .09711 .58803 .09633 .59158 .30884 Mtetra
.59158 .30884 .58803 .09633 .58998 .09554 .59368 .3081 Mtetra
.59368 .3081 .58998 .09554 .59193 .09474 .59578 .30735 Mtetra
.59578 .30735 .59193 .09474 .59389 .09394 .59788 .30659 Mtetra
.59788 .30659 .59389 .09394 .59584 .09313 .59998 .30583 Mtetra
.59998 .30583 .59584 .09313 .5978 .0923 .60208 .30506 Mtetra
.60208 .30506 .5978 .0923 .59975 .09147 .60419 .30428 Mtetra
.60419 .30428 .59975 .09147 .60171 .09063 .60629 .3035 Mtetra
.60629 .3035 .60171 .09063 .60367 .08982 .6084 .30273 Mtetra
.6084 .30273 .60367 .08982 .60563 .08903 .61051 .30198 Mtetra
.61051 .30198 .60563 .08903 .60759 .08825 .61262 .30123 Mtetra
.61262 .30123 .60759 .08825 .60956 .08749 .61473 .3005 Mtetra
.61473 .3005 .60956 .08749 .61153 .08675 .61685 .29978 Mtetra
.61685 .29978 .61153 .08675 .6135 .08602 .61897 .29908 Mtetra
.61897 .29908 .6135 .08602 .61547 .08531 .62109 .29838 Mtetra
.62109 .29838 .61547 .08531 .61744 .08462 .62321 .2977 Mtetra
.62321 .2977 .61744 .08462 .61941 .08394 .62533 .29703 Mtetra
.62533 .29703 .61941 .08394 .62139 .08325 .62745 .29634 Mtetra
.62745 .29634 .62139 .08325 .62337 .08253 .62958 .29564 Mtetra
.62958 .29564 .62337 .08253 .62534 .0818 .63171 .29493 Mtetra
.63171 .29493 .62534 .0818 .62732 .08106 .63384 .29422 Mtetra
.63384 .29422 .62732 .08106 .6293 .08029 .63597 .29349 Mtetra
.63597 .29349 .6293 .08029 .63128 .0795 .6381 .29275 Mtetra
.6381 .29275 .63128 .0795 .63326 .07867 .64023 .29199 Mtetra
.64023 .29199 .63326 .07867 .63524 .07779 .64236 .29121 Mtetra
.64236 .29121 .63524 .07779 .63722 .07691 .6445 .29041 Mtetra
.6445 .29041 .63722 .07691 .63919 .07576 .64663 .28952 Mtetra
.501 .263 .485 r
.64663 .28952 .63919 .07576 .64114 .07391 .64875 .28834 Mtetra
.502 .263 .485 r
.64875 .28834 .64114 .07391 .64312 .07313 .65089 .28753 Mtetra
.503 .264 .485 r
.65089 .28753 .64312 .07313 .64524 .07549 .65306 .28764 Mtetra
.506 .266 .485 r
.65306 .28764 .64524 .07549 .65612 .28507 .6553 .28903 Mtetra
.541 .167 .28 r
.6553 .28903 .65612 .28507 .65851 .29019 .65752 .28998 Mtetra
0 .506 .732 r
.65752 .28998 .65851 .29019 .66077 .29189 .65971 .2903 Mtetra
.62 .711 .911 r
.65971 .2903 .66077 .29189 .66293 .29148 .66187 .28969 Mtetra
.664 .701 .874 r
.66187 .28969 .66293 .29148 .66508 .29057 .66402 .28884 Mtetra
.68 .715 .875 r
.66402 .28884 .66508 .29057 .66722 .28948 .66617 .28789 Mtetra
.655 .727 .902 r
.66617 .28789 .66722 .28948 .66937 .28869 .66832 .2871 Mtetra
.659 .729 .902 r
.66832 .2871 .66937 .28869 .67153 .28787 .67048 .2863 Mtetra
.666 .735 .902 r
.67048 .2863 .67153 .28787 .67368 .28699 .67264 .28546 Mtetra
.682 .748 .901 r
.67264 .28546 .67368 .28699 .67583 .28601 .67479 .28453 Mtetra
.683 .757 .908 r
.67479 .28453 .67583 .28601 .67798 .28501 .67694 .2836 Mtetra
.675 .765 .919 r
.67694 .2836 .67798 .28501 .68013 .28407 .6791 .28272 Mtetra
.647 .766 .935 r
.6791 .28272 .68013 .28407 .6823 .28328 .68127 .28197 Mtetra
.629 .766 .945 r
.68127 .28197 .6823 .28328 .68447 .28258 .68344 .2813 Mtetra
.591 .756 .957 r
.68344 .2813 .68447 .28258 .68665 .28204 .68562 .28078 Mtetra
.404 .662 .965 r
.68562 .28078 .68665 .28204 .68886 .28213 .68784 .28085 Mtetra
.568 .746 .96 r
.68784 .28085 .68886 .28213 .69105 .28169 .69003 .28041 Mtetra
.787 .825 .883 r
.69003 .28041 .69105 .28169 .69318 .28013 .69216 .27887 Mtetra
.981 .785 .567 r
.69216 .27887 .69318 .28013 .69498 .27252 .69399 .27164 Mtetra
.976 .67 .324 r
.69399 .27164 .69498 .27252 .6851 .05536 .68417 .05439 Mtetra
.982 .812 .596 r
.68417 .05439 .6851 .05536 .68686 .04995 .68592 .04874 Mtetra
.745 .811 .905 r
.68592 .04874 .68686 .04995 .68886 .04883 .68791 .04758 Mtetra
.575 .735 .951 r
.68791 .04758 .68886 .04883 .6909 .04845 .68995 .04716 Mtetra
.462 .669 .953 r
.68995 .04716 .6909 .04845 .69296 .04844 .69202 .04711 Mtetra
.65 .754 .925 r
.69202 .04711 .69296 .04844 .69499 .04776 .69404 .0464 Mtetra
.661 .754 .919 r
.69404 .0464 .69499 .04776 .69701 .04701 .69607 .04564 Mtetra
.674 .756 .913 r
.69607 .04564 .69701 .04701 .69903 .0462 .69809 .04482 Mtetra
.766 .787 .871 r
.69809 .04482 .69903 .0462 .70103 .04486 .70008 .04346 Mtetra
.698 .76 .9 r
.70008 .04346 .70103 .04486 .70304 .04393 .7021 .04251 Mtetra
.504 .668 .936 r
.7021 .04251 .70304 .04393 .70511 .04379 .70416 .04237 Mtetra
.75 .332 0 r
.70416 .04237 .70511 .04379 .70751 .04882 .70656 .0474 Mtetra
.97 .655 .291 r
.70656 .0474 .70751 .04882 .72344 .26413 .72244 .26275 Mtetra
.732 .3 0 r
.72244 .26275 .72344 .26413 .72601 .26902 .725 .26764 Mtetra
.05 .474 .885 r
.02946 .50407 .03078 .50515 .03232 .50568 .03099 .50461 Mtetra
.646 .762 .933 r
.03099 .50461 .03232 .50568 .03402 .5051 .0327 .50402 Mtetra
.81 .778 .823 r
.0327 .50402 .03402 .5051 .03588 .5034 .03456 .50232 Mtetra
.908 .737 .658 r
.03456 .50232 .03588 .5034 .03837 .49747 .03705 .49638 Mtetra
.937 .686 .534 r
.03705 .49638 .03837 .49747 .07023 .29036 .06902 .28922 Mtetra
.908 .727 .646 r
.06902 .28922 .07023 .29036 .07265 .28417 .07144 .28304 Mtetra
.777 .759 .837 r
.07144 .28304 .07265 .28417 .07436 .28285 .07314 .28172 Mtetra
.641 .736 .918 r
.07314 .28172 .07436 .28285 .07595 .28232 .07474 .28119 Mtetra
.51 .692 .95 r
.07474 .28119 .07595 .28232 .07749 .28218 .07628 .28105 Mtetra
.746 .759 .863 r
.07628 .28105 .07749 .28218 .07916 .28111 .07795 .27998 Mtetra
.697 .752 .894 r
.07795 .27998 .07916 .28111 .08079 .28033 .07958 .27921 Mtetra
.485 .685 .955 r
.07958 .27921 .08079 .28033 .08233 .28023 .08111 .27912 Mtetra
.924 .541 .244 r
.08111 .27912 .08233 .28023 .08329 .28416 .08206 .28314 Mtetra
.939 .683 .522 r
.08206 .28314 .08329 .28416 .05566 .48998 .05432 .48913 Mtetra
.928 .576 .342 r
.05432 .48913 .05566 .48998 .05647 .49581 .05514 .49482 Mtetra
.212 .595 .947 r
.05514 .49482 .05647 .49581 .05806 .49612 .05674 .49511 Mtetra
.681 .784 .928 r
.05674 .49511 .05806 .49612 .05979 .49541 .05847 .49438 Mtetra
.761 .79 .876 r
.05847 .49438 .05979 .49541 .06159 .49424 .06028 .49318 Mtetra
.521 .729 .969 r
.06028 .49318 .06159 .49424 .06325 .49408 .06195 .49297 Mtetra
.605 .745 .943 r
.06195 .49297 .06325 .49408 .06495 .49367 .06365 .49252 Mtetra
.752 .771 .868 r
.06365 .49252 .06495 .49367 .06676 .49246 .06545 .49136 Mtetra
.905 .744 .67 r
.06545 .49136 .06676 .49246 .06924 .48638 .06782 .48612 Mtetra
.941 .688 .527 r
.06782 .48612 .06924 .48638 .0994 .27847 .0979 .27945 Mtetra
.977 .824 .625 r
.0979 .27945 .0994 .27847 .10174 .27266 .1004 .2725 Mtetra
.86 .921 .868 r
.1004 .2725 .10174 .27266 .10346 .2713 .10217 .27082 Mtetra
.662 .878 .979 r
.10217 .27082 .10346 .2713 .10505 .27094 .1038 .27014 Mtetra
.525 .773 .988 r
.1038 .27014 .10505 .27094 .10658 .27101 .10537 .26987 Mtetra
.633 .737 .923 r
.10537 .26987 .10658 .27101 .10817 .27061 .10698 .26937 Mtetra
.643 .719 .904 r
.10698 .26937 .10817 .27061 .10979 .27006 .1086 .26883 Mtetra
.642 .72 .905 r
.1086 .26883 .10979 .27006 .11141 .26947 .11022 .26829 Mtetra
.737 .752 .865 r
.11022 .26829 .11141 .26947 .1131 .26838 .1119 .26726 Mtetra
.708 .758 .891 r
.1119 .26726 .1131 .26838 .11477 .26752 .11356 .26643 Mtetra
.537 .714 .954 r
.11356 .26643 .11477 .26752 .11634 .26733 .11514 .26621 Mtetra
.888 .46 .106 r
.11514 .26621 .11634 .26733 .1174 .271 .11628 .26927 Mtetra
.944 .684 .514 r
.11628 .26927 .1174 .271 .09182 .47781 .09087 .47407 Mtetra
.95 .645 .207 r
.09087 .47407 .09182 .47781 .09271 .48368 .09156 .48145 Mtetra
.212 .368 .803 r
.09156 .48145 .09271 .48368 .09431 .48416 .09311 .48231 Mtetra
.611 .633 .848 r
.09311 .48231 .09431 .48416 .09609 .48333 .09484 .48184 Mtetra
.708 .715 .854 r
.09484 .48184 .09609 .48333 .09793 .48196 .09663 .48088 Mtetra
.689 .775 .917 r
.09663 .48088 .09793 .48196 .0997 .48116 .0984 .48009 Mtetra
.68 .778 .925 r
.0984 .48009 .0997 .48116 .10146 .48049 .10016 .47936 Mtetra
.685 .765 .912 r
.10016 .47936 .10146 .48049 .10324 .47963 .10193 .47859 Mtetra
.679 .781 .928 r
.10193 .47859 .10324 .47963 .10513 .4779 .1037 .47786 Mtetra
.552 .918 .948 r
.1037 .47786 .10513 .4779 .10712 .47541 .10546 .47715 Mtetra
.154 0 0 r
.10546 .47715 .10712 .47541 .10918 .47228 .10722 .47648 Mtetra
.376 .03 .245 r
.10722 .47648 .10918 .47228 .11116 .46987 .10898 .47585 Mtetra
.422 .106 .323 r
.10898 .47585 .11116 .46987 .11295 .46895 .11073 .47525 Mtetra
.43 .118 .333 r
.11073 .47525 .11295 .46895 .11456 .46947 .11248 .4747 Mtetra
.42 .093 .303 r
.11248 .4747 .11456 .46947 .116 .47141 .11422 .47421 Mtetra
.343 0 .142 r
.11422 .47421 .116 .47141 .11747 .47306 .11596 .47374 Mtetra
0 0 0 r
.11596 .47374 .11747 .47306 .11903 .47404 .1177 .47328 Mtetra
.371 .73 .989 r
.1177 .47328 .11903 .47404 .12067 .47447 .11939 .47323 Mtetra
.534 .702 .947 r
.11939 .47323 .12067 .47447 .12238 .47425 .12111 .47301 Mtetra
.711 .756 .888 r
.12111 .47301 .12238 .47425 .1242 .47316 .12291 .47209 Mtetra
.9 .761 .698 r
.12291 .47209 .1242 .47316 .12644 .46866 .12511 .46793 Mtetra
.946 .689 .516 r
.12511 .46793 .12644 .46866 .1532 .26065 .1518 .26127 Mtetra
.97 .783 .594 r
.1518 .26127 .1532 .26065 .15574 .25266 .1545 .25198 Mtetra
.872 .829 .801 r
.1545 .25198 .15574 .25266 .15757 .25065 .15634 .24981 Mtetra
.674 .81 .948 r
.15634 .24981 .15757 .25065 .15921 .2501 .15801 .24913 Mtetra
.513 .733 .973 r
.15801 .24913 .15921 .2501 .16081 .25003 .15962 .24893 Mtetra
.69 .761 .906 r
.15962 .24893 .16081 .25003 .16246 .24945 .16129 .24818 Mtetra
.707 .736 .874 r
.16129 .24818 .16246 .24945 .16414 .24866 .16298 .24731 Mtetra
.571 .679 .913 r
.16298 .24731 .16414 .24866 .16577 .24827 .1646 .24702 Mtetra
.804 .34 0 r
.1646 .24702 .16577 .24827 .16722 .24954 .16591 .24948 Mtetra
.947 .683 .503 r
.16591 .24948 .16722 .24954 .16818 .25491 .14363 .45461 Mtetra
.523 .281 .49 r
.14363 .45461 .16818 .25491 .14625 .45888 .14431 .46346 Mtetra
.604 .265 .368 r
.14431 .46346 .14625 .45888 .14747 .46302 .14583 .46507 Mtetra
.349 0 .065 r
.14583 .46507 .14747 .46302 .14904 .46422 .14757 .46483 Mtetra
.608 .948 .787 r
.14757 .46483 .14904 .46422 .15076 .46415 .14943 .46353 Mtetra
.921 .805 .715 r
.14943 .46353 .15076 .46415 .15272 .46201 .15159 .45962 Mtetra
.947 .687 .511 r
.15159 .45962 .15272 .46201 .15508 .45625 .1764 .25558 Mtetra
.537 .298 .501 r
.1764 .25558 .15508 .45625 .17993 .25016 .17945 .24277 Mtetra
.651 .454 .604 r
.17945 .24277 .17993 .25016 .18218 .24435 .18134 .24022 Mtetra
.606 .474 .675 r
.18134 .24022 .18218 .24435 .18405 .24197 .18303 .23942 Mtetra
.574 .532 .771 r
.18303 .23942 .18405 .24197 .18583 .24042 .18467 .23912 Mtetra
.617 .705 .907 r
.18467 .23912 .18583 .24042 .18754 .23948 .18633 .23866 Mtetra
.672 .817 .952 r
.18633 .23866 .18754 .23948 .18921 .23892 .18801 .23798 Mtetra
.664 .789 .941 r
.18801 .23798 .18921 .23892 .19086 .23851 .18969 .23733 Mtetra
.699 .754 .894 r
.18969 .23733 .19086 .23851 .19256 .23769 .19139 .23652 Mtetra
.687 .752 .901 r
.19139 .23652 .19256 .23769 .19428 .23668 .19308 .23577 Mtetra
.513 .748 .981 r
.19308 .23577 .19428 .23668 .19596 .23606 .19472 .23555 Mtetra
.783 .281 0 r
.19472 .23555 .19596 .23606 .19749 .23683 .19612 .23756 Mtetra
.949 .682 .496 r
.19612 .23756 .19749 .23683 .19871 .24057 .17615 .43944 Mtetra
.531 .287 .491 r
.17615 .43944 .19871 .24057 .17865 .44514 .17658 .45161 Mtetra
.59 .272 .399 r
.17658 .45161 .17865 .44514 .17975 .45111 .17813 .45336 Mtetra
.339 0 .084 r
.17813 .45336 .17975 .45111 .18133 .45258 .17991 .45302 Mtetra
.461 .884 .789 r
.17991 .45302 .18133 .45258 .18302 .45308 .18174 .4521 Mtetra
.661 .797 .947 r
.18174 .4521 .18302 .45308 .18475 .45317 .18355 .45141 Mtetra
.609 .65 .865 r
.18355 .45141 .18475 .45317 .18652 .45289 .18534 .45095 Mtetra
.697 .662 .811 r
.18534 .45095 .18652 .45289 .18835 .45204 .18719 .4499 Mtetra
.835 .69 .702 r
.18719 .4499 .18835 .45204 .19033 .4498 .18928 .44654 Mtetra
.95 .687 .503 r
.18928 .44654 .19033 .4498 .1926 .44462 .21127 .24835 Mtetra
.551 .31 .503 r
.21127 .24835 .1926 .44462 .21511 .23937 .21478 .22991 Mtetra
.637 .429 .584 r
.21478 .22991 .21511 .23937 .21752 .23161 .21671 .22701 Mtetra
.6 .458 .66 r
.21671 .22701 .21752 .23161 .21941 .22915 .21842 .22618 Mtetra
.567 .501 .74 r
.21842 .22618 .21941 .22915 .22119 .22761 .22009 .22587 Mtetra
.582 .625 .86 r
.22009 .22587 .22119 .22761 .22293 .22659 .22176 .22555 Mtetra
.65 .769 .936 r
.22176 .22555 .22293 .22659 .22463 .22591 .22345 .22496 Mtetra
.652 .787 .947 r
.22345 .22496 .22463 .22591 .22632 .2254 .22515 .22435 Mtetra
.72 .784 .903 r
.22515 .22435 .22632 .2254 .22804 .22458 .22688 .22344 Mtetra
.743 .772 .876 r
.22688 .22344 .22804 .22458 .22979 .22352 .22863 .22238 Mtetra
.636 .745 .927 r
.22863 .22238 .22979 .22352 .23148 .223 .23032 .22183 Mtetra
0 .036 .538 r
.23032 .22183 .23148 .223 .23298 .22452 .23183 .22326 Mtetra
.955 .685 .485 r
.23183 .22326 .23298 .22452 .21554 .42483 .21506 .41571 Mtetra
.973 .72 .299 r
.21506 .41571 .21554 .42483 .21587 .43997 .21466 .43837 Mtetra
.584 .131 0 r
.21466 .43837 .21587 .43997 .21744 .44196 .21622 .44051 Mtetra
.601 .695 .909 r
.21622 .44051 .21744 .44196 .21927 .44139 .21803 .44007 Mtetra
.728 .755 .873 r
.21803 .44007 .21927 .44139 .22115 .44017 .21991 .439 Mtetra
.743 .781 .884 r
.21991 .439 .22115 .44017 .22304 .43893 .22178 .43787 Mtetra
.681 .789 .931 r
.22178 .43787 .22304 .43893 .22489 .43813 .22363 .43709 Mtetra
.68 .794 .935 r
.22363 .43709 .22489 .43813 .22673 .43735 .22548 .43632 Mtetra
.673 .793 .938 r
.22548 .43632 .22673 .43735 .22857 .4367 .22732 .43557 Mtetra
.663 .774 .932 r
.22732 .43557 .22857 .4367 .2304 .43614 .22917 .43488 Mtetra
.655 .745 .916 r
.22917 .43488 .2304 .43614 .23224 .43542 .23101 .43421 Mtetra
.647 .753 .927 r
.23101 .43421 .23224 .43542 .23414 .43409 .23284 .43358 Mtetra
.589 .874 .994 r
.23284 .43358 .23414 .43409 .23614 .43167 .23468 .43298 Mtetra
.121 0 0 r
.23468 .43298 .23614 .43167 .23821 .4285 .23652 .4324 Mtetra
.414 .058 .249 r
.23652 .4324 .23821 .4285 .24019 .42624 .23833 .43207 Mtetra
.467 .145 .336 r
.23833 .43207 .24019 .42624 .2419 .427 .24013 .43197 Mtetra
.4 .069 .285 r
.24013 .43197 .2419 .427 .24369 .42705 .24198 .43132 Mtetra
.073 0 .107 r
.24198 .43132 .24369 .42705 .24579 .42343 .24398 .42894 Mtetra
.886 .827 .356 r
.24398 .42894 .24579 .42343 .26524 .21665 .24664 .41881 Mtetra
0 0 .105 r
.24664 .41881 .26524 .21665 .26744 .21051 .26612 .21138 Mtetra
.967 .936 .67 r
.26612 .21138 .26744 .21051 .26933 .20791 .26812 .20753 Mtetra
.729 .924 .957 r
.26812 .20753 .26933 .20791 .27108 .20705 .26988 .20654 Mtetra
.509 .84 .998 r
.26988 .20654 .27108 .20705 .2728 .2066 .27159 .20615 Mtetra
.413 .808 .986 r
.27159 .20615 .2728 .2066 .2745 .20624 .27329 .20589 Mtetra
.581 .897 .986 r
.27329 .20589 .2745 .20624 .27623 .20563 .27502 .20528 Mtetra
.579 .896 .986 r
.27502 .20528 .27623 .20563 .27797 .20502 .27676 .20468 Mtetra
.581 .897 .986 r
.27676 .20468 .27797 .20502 .2797 .2044 .27849 .20406 Mtetra
.589 .9 .985 r
.27849 .20406 .2797 .2044 .28143 .20377 .28023 .20343 Mtetra
.59 .901 .985 r
.28023 .20343 .28143 .20377 .28317 .20314 .28197 .2028 Mtetra
.584 .9 .985 r
.28197 .2028 .28317 .20314 .28491 .20249 .2837 .20217 Mtetra
.566 .897 .983 r
.2837 .20217 .28491 .20249 .28665 .20184 .28544 .20158 Mtetra
.569 .906 .976 r
.28544 .20158 .28665 .20184 .28839 .2012 .28718 .20094 Mtetra
.614 .922 .974 r
.28718 .20094 .28839 .2012 .29013 .2006 .28893 .20021 Mtetra
.698 .92 .968 r
.28893 .20021 .29013 .2006 .29186 .20008 .2907 .19931 Mtetra
.721 .848 .942 r
.2907 .19931 .29186 .20008 .2936 .19954 .29246 .19841 Mtetra
.702 .77 .905 r
.29246 .19841 .2936 .19954 .29534 .19892 .29422 .19756 Mtetra
.668 .722 .89 r
.29422 .19756 .29534 .19892 .2971 .19811 .29598 .19686 Mtetra
.662 .739 .907 r
.29598 .19686 .2971 .19811 .29887 .19726 .29773 .19619 Mtetra
.662 .774 .932 r
.29773 .19619 .29887 .19726 .30063 .19644 .29948 .19553 Mtetra
.669 .81 .951 r
.29948 .19553 .30063 .19644 .30239 .19569 .30123 .19484 Mtetra
.668 .819 .956 r
.30123 .19484 .30239 .19569 .30414 .19498 .30299 .19414 Mtetra
.667 .824 .959 r
.30299 .19414 .30414 .19498 .3059 .19424 .30475 .19345 Mtetra
.664 .832 .964 r
.30475 .19345 .3059 .19424 .30767 .1934 .3065 .19275 Mtetra
.654 .862 .979 r
.3065 .19275 .30767 .1934 .30943 .1927 .30826 .19206 Mtetra
.652 .864 .98 r
.30826 .19206 .30943 .1927 .31116 .19234 .31002 .19138 Mtetra
.666 .797 .945 r
.31002 .19138 .31116 .19234 .31284 .19283 .31178 .19069 Mtetra
.641 .609 .802 r
.31178 .19069 .31284 .19283 .31449 .19378 .31354 .19001 Mtetra
.601 .486 .694 r
.31354 .19001 .31449 .19378 .31613 .19483 .31531 .18931 Mtetra
.578 .424 .637 r
.31531 .18931 .31613 .19483 .31788 .19444 .31708 .18857 Mtetra
.574 .416 .629 r
.31708 .18857 .31788 .19444 .31966 .19353 .31884 .18784 Mtetra
.581 .423 .633 r
.31884 .18784 .31966 .19353 .32146 .19235 .32062 .18706 Mtetra
.607 .449 .642 r
.32062 .18706 .32146 .19235 .32328 .19097 .32241 .18596 Mtetra
.582 .438 .65 r
.32241 .18596 .32328 .19097 .32505 .19024 .32418 .18526 Mtetra
.495 .379 .65 r
.32418 .18526 .32505 .19024 .32672 .19112 .32589 .1855 Mtetra
0 0 .443 r
.32589 .1855 .32672 .19112 .31514 .39521 .32731 .19015 Mtetra
0 0 .164 r
.32731 .19015 .31514 .39521 .31638 .40474 .3154 .39996 Mtetra
0 0 .371 r
.3154 .39996 .31638 .40474 .31807 .4072 .31694 .40492 Mtetra
.454 .514 .831 r
.31694 .40492 .31807 .4072 .31994 .407 .31878 .40514 Mtetra
.621 .65 .857 r
.31878 .40514 .31994 .407 .32185 .40625 .32068 .40458 Mtetra
.686 .701 .859 r
.32068 .40458 .32185 .40625 .32377 .40527 .3226 .40368 Mtetra
.63 .69 .888 r
.3226 .40368 .32377 .40527 .32567 .40481 .3245 .4031 Mtetra
.64 .678 .87 r
.3245 .4031 .32567 .40481 .32757 .4042 .3264 .40245 Mtetra
.638 .672 .866 r
.3264 .40245 .32757 .4042 .32949 .40331 .32831 .40182 Mtetra
.532 .666 .922 r
.32831 .40182 .32949 .40331 .33145 .40186 .33019 .40161 Mtetra
.512 .891 .965 r
.33019 .40161 .33145 .40186 .33345 .39969 .3321 .401 Mtetra
0 0 0 r
.3321 .401 .33345 .39969 .33554 .39589 .33406 .39949 Mtetra
.761 .805 .324 r
.33406 .39949 .33554 .39589 .34944 .18935 .33629 .3934 Mtetra
0 0 .16 r
.33629 .3934 .34944 .18935 .35177 .17941 .35043 .18215 Mtetra
.911 .872 .438 r
.35043 .18215 .35177 .17941 .35371 .17604 .35255 .17576 Mtetra
.823 .952 .902 r
.35255 .17576 .35371 .17604 .35551 .17508 .35438 .17427 Mtetra
.678 .838 .96 r
.35438 .17427 .35551 .17508 .35729 .17466 .35617 .17351 Mtetra
.581 .736 .949 r
.35617 .17351 .35729 .17466 .35905 .17451 .35795 .17313 Mtetra
.655 .719 .896 r
.35795 .17313 .35905 .17451 .36083 .17389 .35974 .17247 Mtetra
.645 .709 .894 r
.35974 .17247 .36083 .17389 .36263 .17322 .36153 .17186 Mtetra
.645 .72 .903 r
.36153 .17186 .36263 .17322 .36442 .17248 .36332 .17125 Mtetra
.674 .753 .911 r
.36332 .17125 .36442 .17248 .36624 .17144 .36512 .17052 Mtetra
.679 .815 .948 r
.36512 .17052 .36624 .17144 .36804 .17052 .36692 .16977 Mtetra
.672 .85 .968 r
.36692 .16977 .36804 .17052 .36984 .16985 .36872 .16902 Mtetra
.766 .85 .914 r
.36872 .16902 .36984 .16985 .37161 .16981 .37054 .16786 Mtetra
.662 .643 .821 r
.37054 .16786 .37161 .16981 .37334 .17043 .37235 .16707 Mtetra
.532 .462 .723 r
.37235 .16707 .37334 .17043 .375 .1725 .37412 .16698 Mtetra
0 0 .492 r
.37412 .16698 .375 .1725 .36663 .37761 .37568 .17122 Mtetra
0 0 .198 r
.37568 .17122 .36663 .37761 .36807 .38694 .36709 .38163 Mtetra
0 0 .375 r
.36709 .38163 .36807 .38694 .36985 .38948 .36871 .38721 Mtetra
.332 .447 .828 r
.36871 .38721 .36985 .38948 .37174 .38974 .37059 .38786 Mtetra
.63 .655 .856 r
.37059 .38786 .37174 .38974 .37368 .38911 .37253 .38725 Mtetra
.778 .711 .789 r
.37253 .38725 .37368 .38911 .37566 .38764 .37452 .38545 Mtetra
.905 .711 .631 r
.37452 .38545 .37566 .38764 .37773 .384 .37672 .37926 Mtetra
.965 .686 .455 r
.37672 .37926 .37773 .384 .38007 .37472 .38832 .16716 Mtetra
.519 .282 .496 r
.38832 .16716 .38007 .37472 .39127 .16662 .39038 .16088 Mtetra
.627 .455 .631 r
.39038 .16088 .39127 .16662 .39323 .16284 .39223 .15935 Mtetra
.603 .5 .71 r
.39223 .15935 .39323 .16284 .3951 .16075 .39405 .15867 Mtetra
.571 .586 .829 r
.39405 .15867 .3951 .16075 .39695 .15934 .39585 .15837 Mtetra
.665 .804 .949 r
.39585 .15837 .39695 .15934 .39877 .15853 .39767 .15767 Mtetra
.668 .827 .96 r
.39767 .15767 .39877 .15853 .40058 .15799 .39949 .15694 Mtetra
.658 .785 .942 r
.39949 .15694 .40058 .15799 .40239 .15755 .4013 .15626 Mtetra
.712 .756 .887 r
.4013 .15626 .40239 .15755 .40423 .15646 .40314 .15532 Mtetra
.653 .765 .932 r
.40314 .15532 .40423 .15646 .40606 .15551 .40496 .15467 Mtetra
.354 .699 .983 r
.40496 .15467 .40606 .15551 .40787 .15505 .40675 .1547 Mtetra
.879 .444 .138 r
.40675 .1547 .40787 .15505 .4096 .15672 .40839 .15878 Mtetra
.966 .679 .434 r
.40839 .15878 .4096 .15672 .41116 .16322 .40208 .36968 Mtetra
.515 .273 .487 r
.40208 .36968 .41116 .16322 .40517 .3712 .4038 .37529 Mtetra
.512 .152 .293 r
.4038 .37529 .40517 .3712 .40699 .37428 .40572 .37581 Mtetra
.181 0 0 r
.40572 .37581 .40699 .37428 .40889 .37528 .40768 .37521 Mtetra
.654 .962 .927 r
.40768 .37521 .40889 .37528 .41082 .3755 .40966 .37411 Mtetra
.607 .72 .925 r
.40966 .37411 .41082 .3755 .41277 .37546 .41162 .37361 Mtetra
.648 .667 .855 r
.41162 .37361 .41277 .37546 .41473 .37494 .41359 .37289 Mtetra
.736 .681 .797 r
.41359 .37289 .41473 .37494 .41672 .37376 .41559 .37142 Mtetra
.892 .706 .644 r
.41559 .37142 .41672 .37376 .41877 .37053 .41772 .36598 Mtetra
.968 .685 .442 r
.41772 .36598 .41877 .37053 .42097 .36296 .42668 .15362 Mtetra
.521 .284 .496 r
.42668 .15362 .42097 .36296 .42964 .15301 .42873 .14653 Mtetra
.632 .448 .617 r
.42873 .14653 .42964 .15301 .4316 .1485 .4306 .14466 Mtetra
.602 .487 .694 r
.4306 .14466 .4316 .1485 .43349 .14624 .43245 .14392 Mtetra
.574 .563 .804 r
.43245 .14392 .43349 .14624 .43535 .14472 .43428 .1436 Mtetra
.637 .767 .942 r
.43428 .1436 .43535 .14472 .43721 .14373 .43612 .143 Mtetra
.646 .855 .979 r
.43612 .143 .43721 .14373 .43905 .14303 .43796 .14231 Mtetra
.645 .855 .98 r
.43796 .14231 .43905 .14303 .44089 .14251 .43981 .14162 Mtetra
.665 .826 .961 r
.43981 .14162 .44089 .14251 .44273 .14197 .44166 .14089 Mtetra
.668 .787 .938 r
.44166 .14089 .44273 .14197 .44457 .14142 .44351 .14017 Mtetra
.66 .751 .917 r
.44351 .14017 .44457 .14142 .44642 .14083 .44535 .13948 Mtetra
.629 .721 .913 r
.44535 .13948 .44642 .14083 .44827 .14006 .4472 .13892 Mtetra
.61 .754 .947 r
.4472 .13892 .44827 .14006 .45013 .1392 .44905 .13842 Mtetra
.587 .825 .989 r
.44905 .13842 .45013 .1392 .45198 .13832 .4509 .13791 Mtetra
.588 .899 .986 r
.4509 .13791 .45198 .13832 .45384 .13753 .45275 .13724 Mtetra
.596 .922 .97 r
.45275 .13724 .45384 .13753 .4557 .13678 .45461 .13648 Mtetra
.609 .924 .971 r
.45461 .13648 .4557 .13678 .45755 .13606 .45647 .13569 Mtetra
.735 .947 .949 r
.45647 .13569 .45755 .13606 .45942 .13508 .45834 .13457 Mtetra
.703 .917 .967 r
.45834 .13457 .45942 .13508 .46128 .13419 .4602 .13362 Mtetra
.462 .816 .997 r
.4602 .13362 .46128 .13419 .46313 .13374 .46206 .1333 Mtetra
.795 .301 0 r
.46206 .1333 .46313 .13374 .46495 .13516 .46385 .1361 Mtetra
.971 .678 .412 r
.46385 .1361 .46495 .13516 .46669 .14088 .46149 .34655 Mtetra
.519 .276 .487 r
.46149 .34655 .46669 .14088 .46458 .34974 .46333 .35425 Mtetra
.552 .197 .319 r
.46333 .35425 .46458 .34974 .46652 .35213 .4653 .35528 Mtetra
.355 0 .175 r
.4653 .35528 .46652 .35213 .46852 .35159 .46731 .3547 Mtetra
.262 0 .134 r
.46731 .3547 .46852 .35159 .47054 .35022 .46932 .35361 Mtetra
.319 0 .178 r
.46932 .35361 .47054 .35022 .47255 .3492 .47134 .35273 Mtetra
.355 0 .202 r
.47134 .35273 .47255 .3492 .47456 .34848 .47335 .35203 Mtetra
.356 0 .204 r
.47335 .35203 .47456 .34848 .47657 .34777 .47537 .35134 Mtetra
.361 0 .207 r
.47537 .35134 .47657 .34777 .47859 .3471 .47738 .35068 Mtetra
.365 .002 .209 r
.47738 .35068 .47859 .3471 .4806 .34645 .4794 .35003 Mtetra
.4794 .35003 .4806 .34645 .48261 .34582 .48142 .34939 Mtetra
.363 0 .208 r
.48142 .34939 .48261 .34582 .48463 .34518 .48344 .34873 Mtetra
.361 0 .206 r
.48344 .34873 .48463 .34518 .48665 .34453 .48546 .34807 Mtetra
.36 0 .204 r
.48546 .34807 .48665 .34453 .48866 .34388 .48748 .3474 Mtetra
.358 0 .203 r
.48748 .3474 .48866 .34388 .49068 .34322 .48951 .34672 Mtetra
.357 0 .201 r
.48951 .34672 .49068 .34322 .49271 .34257 .49153 .34605 Mtetra
.356 0 .199 r
.49153 .34605 .49271 .34257 .49473 .34191 .49356 .34537 Mtetra
.355 0 .198 r
.49356 .34537 .49473 .34191 .49676 .34125 .49559 .34469 Mtetra
.354 0 .196 r
.49559 .34469 .49676 .34125 .49878 .34058 .49762 .34401 Mtetra
.353 0 .194 r
.49762 .34401 .49878 .34058 .50081 .33991 .49965 .34332 Mtetra
.352 0 .193 r
.49965 .34332 .50081 .33991 .50284 .33924 .50169 .34263 Mtetra
.351 0 .191 r
.50169 .34263 .50284 .33924 .50487 .33857 .50372 .34194 Mtetra
.35 0 .19 r
.50372 .34194 .50487 .33857 .5069 .33789 .50576 .34125 Mtetra
.349 0 .189 r
.50576 .34125 .5069 .33789 .50894 .33721 .5078 .34056 Mtetra
.349 0 .188 r
.5078 .34056 .50894 .33721 .51098 .33652 .50984 .33987 Mtetra
.348 0 .187 r
.50984 .33987 .51098 .33652 .51301 .33584 .51188 .33917 Mtetra
.51188 .33917 .51301 .33584 .51505 .33515 .51392 .33848 Mtetra
.347 0 .186 r
.51392 .33848 .51505 .33515 .51709 .33445 .51597 .33778 Mtetra
.51597 .33778 .51709 .33445 .51914 .33376 .51801 .33708 Mtetra
.347 0 .185 r
.51801 .33708 .51914 .33376 .52118 .33307 .52006 .33638 Mtetra
.346 0 .185 r
.52006 .33638 .52118 .33307 .52322 .33237 .52211 .33568 Mtetra
.346 0 .184 r
.52211 .33568 .52322 .33237 .52527 .33167 .52416 .33498 Mtetra
.52416 .33498 .52527 .33167 .52732 .33097 .52621 .33428 Mtetra
.52621 .33428 .52732 .33097 .52937 .33027 .52827 .33358 Mtetra
.52827 .33358 .52937 .33027 .53142 .32957 .53032 .33288 Mtetra
.53032 .33288 .53142 .32957 .53347 .32887 .53238 .33217 Mtetra
.53238 .33217 .53347 .32887 .53553 .32816 .53444 .33147 Mtetra
.53444 .33147 .53553 .32816 .53758 .32746 .5365 .33076 Mtetra
.5365 .33076 .53758 .32746 .53964 .32675 .53856 .33006 Mtetra
.53856 .33006 .53964 .32675 .5417 .32605 .54062 .32935 Mtetra
.346 0 .183 r
.54062 .32935 .5417 .32605 .54376 .32534 .54269 .32864 Mtetra
.345 0 .183 r
.54269 .32864 .54376 .32534 .54582 .32464 .54475 .32794 Mtetra
.54475 .32794 .54582 .32464 .54789 .32393 .54682 .32723 Mtetra
.54682 .32723 .54789 .32393 .54995 .32322 .54889 .32652 Mtetra
.54889 .32652 .54995 .32322 .55202 .32251 .55096 .32581 Mtetra
.55096 .32581 .55202 .32251 .55409 .3218 .55303 .3251 Mtetra
.55303 .3251 .55409 .3218 .55616 .32109 .55511 .32439 Mtetra
.55511 .32439 .55616 .32109 .55823 .32038 .55718 .32368 Mtetra
.55718 .32368 .55823 .32038 .5603 .31967 .55926 .32297 Mtetra
.55926 .32297 .5603 .31967 .56238 .31896 .56134 .32226 Mtetra
.56134 .32226 .56238 .31896 .56445 .31825 .56342 .32155 Mtetra
.345 0 .184 r
.56342 .32155 .56445 .31825 .56653 .31753 .5655 .32083 Mtetra
.5655 .32083 .56653 .31753 .56861 .31682 .56758 .32012 Mtetra
.56758 .32012 .56861 .31682 .57069 .3161 .56967 .3194 Mtetra
.56967 .3194 .57069 .3161 .57277 .31539 .57175 .31869 Mtetra
.57175 .31869 .57277 .31539 .57485 .31467 .57384 .31797 Mtetra
.57384 .31797 .57485 .31467 .57694 .31395 .57593 .31725 Mtetra
.346 0 .184 r
.57593 .31725 .57694 .31395 .57903 .31323 .57802 .31654 Mtetra
.57802 .31654 .57903 .31323 .58112 .3125 .58011 .31582 Mtetra
.346 0 .185 r
.58011 .31582 .58112 .3125 .58321 .31178 .58221 .31509 Mtetra
.58221 .31509 .58321 .31178 .5853 .31105 .5843 .31437 Mtetra
.5843 .31437 .5853 .31105 .58739 .31032 .5864 .31365 Mtetra
.346 0 .186 r
.5864 .31365 .58739 .31032 .58948 .30958 .5885 .31292 Mtetra
.5885 .31292 .58948 .30958 .59158 .30884 .5906 .31219 Mtetra
.346 0 .187 r
.5906 .31219 .59158 .30884 .59368 .3081 .5927 .31145 Mtetra
.346 0 .188 r
.5927 .31145 .59368 .3081 .59578 .30735 .59481 .31072 Mtetra
.346 0 .189 r
.59481 .31072 .59578 .30735 .59788 .30659 .59691 .30998 Mtetra
.346 0 .19 r
.59691 .30998 .59788 .30659 .59998 .30583 .59902 .30923 Mtetra
.346 0 .191 r
.59902 .30923 .59998 .30583 .60208 .30506 .60113 .30848 Mtetra
.344 0 .192 r
.60113 .30848 .60208 .30506 .60419 .30428 .60323 .3077 Mtetra
.60323 .3077 .60419 .30428 .60629 .3035 .60534 .30693 Mtetra
.346 0 .193 r
.60534 .30693 .60629 .3035 .6084 .30273 .60746 .30617 Mtetra
.349 0 .195 r
.60746 .30617 .6084 .30273 .61051 .30198 .60957 .30542 Mtetra
.351 0 .196 r
.60957 .30542 .61051 .30198 .61262 .30123 .61169 .30469 Mtetra
.353 0 .197 r
.61169 .30469 .61262 .30123 .61473 .3005 .6138 .30396 Mtetra
.354 0 .198 r
.6138 .30396 .61473 .3005 .61685 .29978 .61592 .30324 Mtetra
.355 0 .198 r
.61592 .30324 .61685 .29978 .61897 .29908 .61805 .30252 Mtetra
.357 0 .198 r
.61805 .30252 .61897 .29908 .62109 .29838 .62017 .30182 Mtetra
.359 0 .198 r
.62017 .30182 .62109 .29838 .62321 .2977 .6223 .30114 Mtetra
.6223 .30114 .62321 .2977 .62533 .29703 .62442 .30046 Mtetra
.358 0 .198 r
.62442 .30046 .62533 .29703 .62745 .29634 .62655 .29977 Mtetra
.355 0 .197 r
.62655 .29977 .62745 .29634 .62958 .29564 .62868 .29906 Mtetra
.354 0 .196 r
.62868 .29906 .62958 .29564 .63171 .29493 .63081 .29835 Mtetra
.353 0 .195 r
.63081 .29835 .63171 .29493 .63384 .29422 .63295 .29763 Mtetra
.352 0 .194 r
.63295 .29763 .63384 .29422 .63597 .29349 .63508 .2969 Mtetra
.351 0 .194 r
.63508 .2969 .63597 .29349 .6381 .29275 .63722 .29617 Mtetra
.351 0 .195 r
.63722 .29617 .6381 .29275 .64023 .29199 .63935 .29543 Mtetra
.351 0 .196 r
.63935 .29543 .64023 .29199 .64236 .29121 .64149 .29468 Mtetra
.352 0 .199 r
.64149 .29468 .64236 .29121 .6445 .29041 .64363 .29393 Mtetra
.352 0 .202 r
.64363 .29393 .6445 .29041 .64663 .28952 .64577 .29316 Mtetra
.355 0 .21 r
.64577 .29316 .64663 .28952 .64875 .28834 .64792 .29238 Mtetra
.37 .022 .237 r
.64792 .29238 .64875 .28834 .65089 .28753 .65006 .29159 Mtetra
.371 .024 .239 r
.65006 .29159 .65089 .28753 .65306 .28764 .6522 .29081 Mtetra
.334 0 .17 r
.6522 .29081 .65306 .28764 .6553 .28903 .65435 .29004 Mtetra
.027 0 0 r
.65435 .29004 .6553 .28903 .65752 .28998 .6565 .28926 Mtetra
.621 .879 .989 r
.6565 .28926 .65752 .28998 .65971 .2903 .65865 .28848 Mtetra
.654 .692 .873 r
.65865 .28848 .65971 .2903 .66187 .28969 .6608 .28768 Mtetra
.65 .665 .851 r
.6608 .28768 .66187 .28969 .66402 .28884 .66295 .28687 Mtetra
.651 .671 .857 r
.66295 .28687 .66402 .28884 .66617 .28789 .66511 .28606 Mtetra
.652 .691 .873 r
.66511 .28606 .66617 .28789 .66832 .2871 .66726 .28527 Mtetra
.651 .689 .873 r
.66726 .28527 .66832 .2871 .67048 .2863 .66942 .28448 Mtetra
.649 .691 .876 r
.66942 .28448 .67048 .2863 .67264 .28546 .67158 .28371 Mtetra
.648 .7 .884 r
.67158 .28371 .67264 .28546 .67479 .28453 .67374 .28294 Mtetra
.647 .725 .906 r
.67374 .28294 .67479 .28453 .67694 .2836 .67591 .28219 Mtetra
.641 .753 .93 r
.67591 .28219 .67694 .2836 .6791 .28272 .67808 .28148 Mtetra
.619 .775 .955 r
.67808 .28148 .6791 .28272 .68127 .28197 .68025 .28084 Mtetra
.618 .796 .967 r
.68025 .28084 .68127 .28197 .68344 .2813 .68242 .28018 Mtetra
.616 .798 .969 r
.68242 .28018 .68344 .2813 .68562 .28078 .6846 .27953 Mtetra
.543 .74 .967 r
.6846 .27953 .68562 .28078 .68784 .28085 .68679 .27917 Mtetra
.661 .718 .891 r
.68679 .27917 .68784 .28085 .69003 .28041 .68896 .27834 Mtetra
.778 .716 .793 r
.68896 .27834 .69003 .28041 .69216 .27887 .69108 .27645 Mtetra
.947 .725 .571 r
.69108 .27645 .69216 .27887 .69399 .27164 .69288 .26869 Mtetra
.975 .669 .329 r
.69288 .26869 .69399 .27164 .68417 .05439 .68322 .05313 Mtetra
.968 .796 .616 r
.68322 .05313 .68417 .05439 .68592 .04874 .68499 .04782 Mtetra
.766 .873 .926 r
.68499 .04782 .68592 .04874 .68791 .04758 .68698 .04656 Mtetra
.599 .798 .976 r
.68698 .04656 .68791 .04758 .68995 .04716 .68901 .04601 Mtetra
.505 .723 .97 r
.68901 .04601 .68995 .04716 .69202 .04711 .69107 .04578 Mtetra
.66 .759 .923 r
.69107 .04578 .69202 .04711 .69404 .0464 .69309 .04503 Mtetra
.665 .753 .916 r
.69309 .04503 .69404 .0464 .69607 .04564 .69512 .04425 Mtetra
.674 .753 .91 r
.69512 .04425 .69607 .04564 .69809 .04482 .69714 .04342 Mtetra
.768 .787 .869 r
.69714 .04342 .69809 .04482 .70008 .04346 .69913 .04205 Mtetra
.699 .76 .899 r
.69913 .04205 .70008 .04346 .7021 .04251 .70115 .04109 Mtetra
.506 .668 .936 r
.70115 .04109 .7021 .04251 .70416 .04237 .70322 .04094 Mtetra
.749 .332 0 r
.70322 .04094 .70416 .04237 .70656 .0474 .70562 .04598 Mtetra
.97 .655 .291 r
.70562 .04598 .70656 .0474 .72244 .26275 .72143 .26136 Mtetra
.731 .299 0 r
.72143 .26136 .72244 .26275 .725 .26764 .72399 .26624 Mtetra
.052 .475 .886 r
.02814 .50299 .02946 .50407 .03099 .50461 .02967 .50353 Mtetra
.646 .761 .933 r
.02967 .50353 .03099 .50461 .0327 .50402 .03137 .50294 Mtetra
.81 .778 .823 r
.03137 .50294 .0327 .50402 .03456 .50232 .03324 .50123 Mtetra
.908 .737 .658 r
.03324 .50123 .03456 .50232 .03705 .49638 .03574 .49529 Mtetra
.937 .686 .534 r
.03574 .49529 .03705 .49638 .06902 .28922 .0678 .28807 Mtetra
.908 .727 .646 r
.0678 .28807 .06902 .28922 .07144 .28304 .07022 .2819 Mtetra
.776 .759 .838 r
.07022 .2819 .07144 .28304 .07314 .28172 .07193 .28058 Mtetra
.639 .735 .918 r
.07193 .28058 .07314 .28172 .07474 .28119 .07352 .28006 Mtetra
.506 .691 .951 r
.07352 .28006 .07474 .28119 .07628 .28105 .07506 .27992 Mtetra
.747 .759 .863 r
.07506 .27992 .07628 .28105 .07795 .27998 .07674 .27885 Mtetra
.696 .75 .893 r
.07674 .27885 .07795 .27998 .07958 .27921 .07837 .27809 Mtetra
.469 .677 .955 r
.07837 .27809 .07958 .27921 .08111 .27912 .07989 .27803 Mtetra
.93 .559 .279 r
.07989 .27803 .08111 .27912 .08206 .28314 .08078 .28249 Mtetra
.939 .682 .522 r
.08078 .28249 .08206 .28314 .05432 .48913 .05286 .48911 Mtetra
.895 .538 .359 r
.05286 .48911 .05432 .48913 .05514 .49482 .05376 .49425 Mtetra
.161 .645 .923 r
.05376 .49425 .05514 .49482 .05674 .49511 .05537 .49439 Mtetra
.713 .844 .945 r
.05537 .49439 .05674 .49511 .05847 .49438 .05713 .49352 Mtetra
.788 .819 .877 r
.05713 .49352 .05847 .49438 .06028 .49318 .05896 .49218 Mtetra
.594 .764 .96 r
.05896 .49218 .06028 .49318 .06195 .49297 .06065 .49175 Mtetra
.623 .733 .926 r
.06065 .49175 .06195 .49297 .06365 .49252 .06236 .49125 Mtetra
.717 .746 .875 r
.06236 .49125 .06365 .49252 .06545 .49136 .06414 .49029 Mtetra
.872 .768 .745 r
.06414 .49029 .06545 .49136 .06782 .48612 .06619 .48732 Mtetra
.981 .847 .635 r
.06619 .48732 .06782 .48612 .0979 .27945 .06875 .4807 Mtetra
0 0 0 r
.06875 .4807 .0979 .27945 .1004 .2725 .09829 .2779 Mtetra
.09829 .2779 .1004 .2725 .10217 .27082 .10051 .27297 Mtetra
.569 .814 .435 r
.10051 .27297 .10217 .27082 .1038 .27014 .10239 .27051 Mtetra
.824 .994 .858 r
.10239 .27051 .1038 .27014 .10537 .26987 .10415 .2689 Mtetra
.721 .787 .904 r
.10415 .2689 .10537 .26987 .10698 .26937 .10581 .26802 Mtetra
.642 .701 .889 r
.10581 .26802 .10698 .26937 .1086 .26883 .10743 .26748 Mtetra
.604 .688 .902 r
.10743 .26748 .1086 .26883 .11022 .26829 .10902 .26708 Mtetra
.71 .743 .878 r
.10902 .26708 .11022 .26829 .1119 .26726 .11069 .26622 Mtetra
.7 .771 .907 r
.11069 .26622 .1119 .26726 .11356 .26643 .11234 .26544 Mtetra
.584 .752 .958 r
.11234 .26544 .11356 .26643 .11514 .26621 .11394 .26508 Mtetra
0 .029 .519 r
.11394 .26508 .11514 .26621 .11628 .26927 .11531 .26637 Mtetra
.852 .523 0 r
.11531 .26637 .11628 .26927 .09087 .47407 .11629 .27071 Mtetra
0 0 .019 r
.11629 .27071 .09087 .47407 .09156 .48145 .09127 .47269 Mtetra
.016 0 .447 r
.09127 .47269 .09156 .48145 .09311 .48231 .09229 .47761 Mtetra
.248 .217 .626 r
.09229 .47761 .09311 .48231 .09484 .48184 .09373 .47931 Mtetra
.341 .413 .79 r
.09373 .47931 .09484 .48184 .09663 .48088 .09531 .47995 Mtetra
.569 .775 .976 r
.09531 .47995 .09663 .48088 .0984 .48009 .09703 .47957 Mtetra
.701 .886 .966 r
.09703 .47957 .0984 .48009 .10016 .47936 .09881 .47871 Mtetra
.747 .865 .934 r
.09881 .47871 .10016 .47936 .10193 .47859 .10062 .47766 Mtetra
.661 .801 .95 r
.10062 .47766 .10193 .47859 .1037 .47786 .10237 .477 Mtetra
.598 .799 .976 r
.10237 .477 .1037 .47786 .10546 .47715 .10411 .47653 Mtetra
.56 .834 .997 r
.10411 .47653 .10546 .47715 .10722 .47648 .10584 .47608 Mtetra
.556 .876 .993 r
.10584 .47608 .10722 .47648 .10898 .47585 .10758 .47555 Mtetra
.56 .893 .985 r
.10758 .47555 .10898 .47585 .11073 .47525 .10934 .47496 Mtetra
.576 .899 .984 r
.10934 .47496 .11073 .47525 .11248 .4747 .11109 .47434 Mtetra
.626 .902 .985 r
.11109 .47434 .11248 .4747 .11422 .47421 .11286 .47364 Mtetra
.658 .873 .979 r
.11286 .47364 .11422 .47421 .11596 .47374 .11464 .47292 Mtetra
.658 .822 .962 r
.11464 .47292 .11596 .47374 .1177 .47328 .1164 .47225 Mtetra
.413 .692 .977 r
.1164 .47225 .1177 .47328 .11939 .47323 .11809 .47225 Mtetra
.438 .713 .982 r
.11809 .47225 .11939 .47323 .12111 .47301 .11979 .47217 Mtetra
.681 .823 .952 r
.11979 .47217 .12111 .47301 .12291 .47209 .12157 .47142 Mtetra
.916 .798 .715 r
.12157 .47142 .12291 .47209 .12511 .46793 .12373 .46754 Mtetra
.946 .689 .516 r
.12373 .46754 .12511 .46793 .1518 .26127 .15035 .26221 Mtetra
.973 .775 .577 r
.15035 .26221 .1518 .26127 .1545 .25198 .1533 .25093 Mtetra
.854 .777 .776 r
.1533 .25093 .1545 .25198 .15634 .24981 .15516 .24866 Mtetra
.676 .749 .906 r
.15516 .24866 .15634 .24981 .15801 .24913 .15682 .24796 Mtetra
.532 .699 .946 r
.15682 .24796 .15801 .24913 .15962 .24893 .15843 .24776 Mtetra
.695 .751 .895 r
.15843 .24776 .15962 .24893 .16129 .24818 .16011 .24698 Mtetra
.715 .75 .879 r
.16011 .24698 .16129 .24818 .16298 .24731 .16181 .24608 Mtetra
.567 .7 .93 r
.16181 .24608 .16298 .24731 .1646 .24702 .16343 .24579 Mtetra
.836 .382 0 r
.16343 .24579 .1646 .24702 .16591 .24948 .16471 .24846 Mtetra
.948 .684 .503 r
.16471 .24846 .16591 .24948 .14363 .45461 .14215 .45529 Mtetra
.898 .563 .404 r
.14215 .45529 .14363 .45461 .14431 .46346 .14296 .46298 Mtetra
.648 .09 0 r
.14296 .46298 .14431 .46346 .14583 .46507 .1445 .46439 Mtetra
.545 .821 .997 r
.1445 .46439 .14583 .46507 .14757 .46483 .14626 .46398 Mtetra
.806 .831 .87 r
.14626 .46398 .14757 .46483 .14943 .46353 .14814 .46248 Mtetra
.906 .766 .695 r
.14814 .46248 .14943 .46353 .15159 .45962 .15034 .45821 Mtetra
.948 .689 .51 r
.15034 .45821 .15159 .45962 .1764 .25558 .17565 .25063 Mtetra
.848 .621 .593 r
.17565 .25063 .1764 .25558 .17945 .24277 .17835 .24092 Mtetra
.808 .692 .737 r
.17835 .24092 .17945 .24277 .18134 .24022 .18021 .2386 Mtetra
.65 .666 .853 r
.18021 .2386 .18134 .24022 .18303 .23942 .18189 .23797 Mtetra
.528 .644 .907 r
.18189 .23797 .18303 .23942 .18467 .23912 .18351 .23783 Mtetra
.639 .716 .903 r
.18351 .23783 .18467 .23912 .18633 .23866 .18518 .23728 Mtetra
.707 .722 .861 r
.18518 .23728 .18633 .23866 .18801 .23798 .18688 .23638 Mtetra
.663 .675 .851 r
.18688 .23638 .18801 .23798 .18969 .23733 .18857 .23568 Mtetra
.521 .608 .88 r
.18857 .23568 .18969 .23733 .19139 .23652 .19019 .23559 Mtetra
0 .356 .79 r
.19019 .23559 .19139 .23652 .19308 .23577 .19172 .23632 Mtetra
.761 .311 .181 r
.19172 .23632 .19308 .23577 .19472 .23555 .19312 .23835 Mtetra
.892 .588 .465 r
.19312 .23835 .19472 .23555 .19612 .23756 .1932 .25261 Mtetra
.931 .661 .505 r
.1932 .25261 .19612 .23756 .17615 .43944 .17377 .44875 Mtetra
.62 .32 .44 r
.17377 .44875 .17615 .43944 .17658 .45161 .17516 .45192 Mtetra
.508 0 0 r
.17516 .45192 .17658 .45161 .17813 .45336 .17682 .45265 Mtetra
.59 .833 .991 r
.17682 .45265 .17813 .45336 .17991 .45302 .17861 .45214 Mtetra
.752 .83 .912 r
.17861 .45214 .17991 .45302 .18174 .4521 .18047 .45102 Mtetra
.8 .798 .85 r
.18047 .45102 .18174 .4521 .18355 .45141 .18237 .44946 Mtetra
.791 .692 .756 r
.18237 .44946 .18355 .45141 .18534 .45095 .18434 .44734 Mtetra
.777 .604 .665 r
.18434 .44734 .18534 .45095 .18719 .4499 .18644 .44389 Mtetra
.862 .624 .577 r
.18644 .44389 .18719 .4499 .18928 .44654 .18958 .43026 Mtetra
.935 .67 .51 r
.18958 .43026 .18928 .44654 .21127 .24835 .21172 .2313 Mtetra
.611 .386 .551 r
.21172 .2313 .21127 .24835 .21478 .22991 .21377 .22723 Mtetra
.732 .609 .72 r
.21377 .22723 .21478 .22991 .21671 .22701 .21558 .22545 Mtetra
.635 .671 .867 r
.21558 .22545 .21671 .22701 .21842 .22618 .21727 .22489 Mtetra
.525 .675 .933 r
.21727 .22489 .21842 .22618 .22009 .22587 .21892 .22472 Mtetra
.548 .712 .948 r
.21892 .22472 .22009 .22587 .22176 .22555 .22059 .22447 Mtetra
.647 .759 .931 r
.22059 .22447 .22176 .22555 .22345 .22496 .22228 .22388 Mtetra
.66 .766 .928 r
.22228 .22388 .22345 .22496 .22515 .22435 .22398 .22324 Mtetra
.725 .775 .892 r
.22398 .22324 .22515 .22435 .22688 .22344 .22572 .2223 Mtetra
.746 .772 .874 r
.22572 .2223 .22688 .22344 .22863 .22238 .22746 .22121 Mtetra
.634 .741 .925 r
.22746 .22121 .22863 .22238 .23032 .22183 .22916 .22068 Mtetra
.531 .029 0 r
.22916 .22068 .23032 .22183 .23183 .22326 .23065 .22224 Mtetra
.955 .685 .486 r
.23065 .22224 .23183 .22326 .21506 .41571 .21287 .42449 Mtetra
.802 .502 .48 r
.21287 .42449 .21506 .41571 .21466 .43837 .21335 .43785 Mtetra
.75 .231 0 r
.21335 .43785 .21466 .43837 .21622 .44051 .21492 .43986 Mtetra
.543 .831 .998 r
.21492 .43986 .21622 .44051 .21803 .44007 .21674 .43942 Mtetra
.738 .878 .945 r
.21674 .43942 .21803 .44007 .21991 .439 .21861 .43838 Mtetra
.747 .885 .942 r
.21861 .43838 .21991 .439 .22178 .43787 .22048 .43729 Mtetra
.655 .88 .981 r
.22048 .43729 .22178 .43787 .22363 .43709 .22233 .43654 Mtetra
.658 .886 .981 r
.22233 .43654 .22363 .43709 .22548 .43632 .22417 .43578 Mtetra
.674 .89 .976 r
.22417 .43578 .22548 .43632 .22732 .43557 .22603 .43495 Mtetra
.697 .879 .966 r
.22603 .43495 .22732 .43557 .22917 .43488 .22789 .43407 Mtetra
.691 .843 .956 r
.22789 .43407 .22917 .43488 .23101 .43421 .22974 .43324 Mtetra
.648 .8 .956 r
.22974 .43324 .23101 .43421 .23284 .43358 .23159 .43259 Mtetra
.573 .773 .973 r
.23159 .43259 .23284 .43358 .23468 .43298 .23341 .43218 Mtetra
.533 .798 .994 r
.23341 .43218 .23468 .43298 .23652 .4324 .23522 .43182 Mtetra
.445 .804 .996 r
.23522 .43182 .23652 .4324 .23833 .43207 .23704 .43155 Mtetra
.407 .798 .988 r
.23704 .43155 .23833 .43207 .24013 .43197 .23885 .43131 Mtetra
.622 .856 .987 r
.23885 .43131 .24013 .43197 .24198 .43132 .24069 .43067 Mtetra
.84 .875 .868 r
.24069 .43067 .24198 .43132 .24398 .42894 .24264 .42893 Mtetra
.962 .857 .69 r
.24264 .42893 .24398 .42894 .24664 .41881 .24482 .42447 Mtetra
.998 .807 .457 r
.24482 .42447 .24664 .41881 .26612 .21138 .24828 .40501 Mtetra
0 0 .123 r
.24828 .40501 .26612 .21138 .26812 .20753 .2665 .21199 Mtetra
.294 0 .232 r
.2665 .21199 .26812 .20753 .26988 .20654 .26829 .21069 Mtetra
.457 .112 .291 r
.26829 .21069 .26988 .20654 .27159 .20615 .26997 .21063 Mtetra
.497 .157 .32 r
.26997 .21063 .27159 .20615 .27329 .20589 .27163 .21092 Mtetra
.419 .094 .305 r
.27163 .21092 .27329 .20589 .27502 .20528 .27336 .21041 Mtetra
.421 .098 .309 r
.27336 .21041 .27502 .20528 .27676 .20468 .27509 .20991 Mtetra
.421 .099 .312 r
.27509 .20991 .27676 .20468 .27849 .20406 .27682 .20938 Mtetra
.418 .098 .313 r
.27682 .20938 .27849 .20406 .28023 .20343 .27855 .20882 Mtetra
.417 .098 .315 r
.27855 .20882 .28023 .20343 .28197 .2028 .28029 .20823 Mtetra
.442 .122 .326 r
.28029 .20823 .28197 .2028 .2837 .20217 .28201 .20789 Mtetra
.499 .178 .354 r
.28201 .20789 .2837 .20217 .28544 .20158 .28368 .20817 Mtetra
.425 .121 .344 r
.28368 .20817 .28544 .20158 .28718 .20094 .28544 .20747 Mtetra
.185 0 .249 r
.28544 .20747 .28718 .20094 .28893 .20021 .28736 .20455 Mtetra
0 0 0 r
.28736 .20455 .28893 .20021 .2907 .19931 .28938 .20045 Mtetra
.854 .969 .648 r
.28938 .20045 .2907 .19931 .29246 .19841 .2913 .19762 Mtetra
.853 .843 .835 r
.2913 .19762 .29246 .19841 .29422 .19756 .29314 .19576 Mtetra
.679 .663 .827 r
.29314 .19576 .29422 .19756 .29598 .19686 .2949 .19491 Mtetra
.632 .625 .824 r
.2949 .19491 .29598 .19686 .29773 .19619 .29665 .1943 Mtetra
.621 .627 .835 r
.29665 .1943 .29773 .19619 .29948 .19553 .29839 .19378 Mtetra
.653 .658 .842 r
.29839 .19378 .29948 .19553 .30123 .19484 .30014 .19309 Mtetra
.65 .657 .844 r
.30014 .19309 .30123 .19484 .30299 .19414 .3019 .19242 Mtetra
.642 .658 .851 r
.3019 .19242 .30299 .19414 .30475 .19345 .30365 .1918 Mtetra
.624 .662 .866 r
.30365 .1918 .30475 .19345 .3065 .19275 .30539 .19128 Mtetra
.629 .69 .888 r
.30539 .19128 .3065 .19275 .30826 .19206 .30714 .19075 Mtetra
.651 .725 .903 r
.30714 .19075 .30826 .19206 .31002 .19138 .3089 .19013 Mtetra
.696 .75 .893 r
.3089 .19013 .31002 .19138 .31178 .19069 .31067 .18929 Mtetra
.698 .726 .872 r
.31067 .18929 .31178 .19069 .31354 .19001 .31244 .18842 Mtetra
.686 .694 .852 r
.31244 .18842 .31354 .19001 .31531 .18931 .31422 .18757 Mtetra
.661 .665 .843 r
.31422 .18757 .31531 .18931 .31708 .18857 .31599 .18684 Mtetra
.656 .662 .844 r
.31599 .18684 .31708 .18857 .31884 .18784 .31775 .18613 Mtetra
.663 .669 .845 r
.31775 .18613 .31884 .18784 .32062 .18706 .31952 .1854 Mtetra
.702 .691 .836 r
.31952 .1854 .32062 .18706 .32241 .18596 .32131 .18442 Mtetra
.663 .693 .868 r
.32131 .18442 .32241 .18596 .32418 .18526 .32308 .18371 Mtetra
.515 .629 .902 r
.32308 .18371 .32418 .18526 .32589 .1855 .32481 .18361 Mtetra
0 .057 .62 r
.32481 .18361 .32589 .1855 .32731 .19015 .32642 .18544 Mtetra
0 0 .22 r
.32642 .18544 .32731 .19015 .3154 .39996 .32776 .19144 Mtetra
0 0 .182 r
.32776 .19144 .3154 .39996 .31694 .40492 .31613 .3975 Mtetra
.174 .113 .543 r
.31613 .3975 .31694 .40492 .31878 .40514 .31775 .40112 Mtetra
.293 .287 .681 r
.31775 .40112 .31878 .40514 .32068 .40458 .31952 .40253 Mtetra
.37 .496 .855 r
.31952 .40253 .32068 .40458 .3226 .40368 .32136 .40298 Mtetra
.523 .819 .999 r
.32136 .40298 .3226 .40368 .3245 .4031 .32325 .40258 Mtetra
.617 .888 .989 r
.32325 .40258 .3245 .4031 .3264 .40245 .32516 .40187 Mtetra
.66 .889 .981 r
.32516 .40187 .3264 .40245 .32831 .40182 .32708 .40107 Mtetra
.487 .795 .999 r
.32708 .40107 .32831 .40182 .33019 .40161 .32896 .40077 Mtetra
.611 .822 .981 r
.32896 .40077 .33019 .40161 .3321 .401 .33087 .40018 Mtetra
.756 .861 .927 r
.33087 .40018 .3321 .401 .33406 .39949 .33281 .39901 Mtetra
.934 .865 .748 r
.33281 .39901 .33406 .39949 .33629 .3934 .33488 .39572 Mtetra
.963 .886 .501 r
.33488 .39572 .33629 .3934 .35043 .18215 .33716 .3888 Mtetra
0 0 .176 r
.33716 .3888 .35043 .18215 .35255 .17576 .35107 .18085 Mtetra
0 0 0 r
.35107 .18085 .35255 .17576 .35438 .17427 .35312 .17575 Mtetra
.677 .882 .51 r
.35312 .17575 .35438 .17427 .35617 .17351 .35502 .17312 Mtetra
.852 .927 .878 r
.35502 .17312 .35617 .17351 .35795 .17313 .35687 .17144 Mtetra
.666 .676 .85 r
.35687 .17144 .35795 .17313 .35974 .17247 .35866 .17068 Mtetra
.604 .635 .855 r
.35866 .17068 .35974 .17247 .36153 .17186 .36044 .17024 Mtetra
.571 .645 .885 r
.36044 .17024 .36153 .17186 .36332 .17125 .36222 .16994 Mtetra
.652 .73 .906 r
.36222 .16994 .36332 .17125 .36512 .17052 .36401 .1693 Mtetra
.668 .752 .913 r
.36401 .1693 .36512 .17052 .36692 .16977 .36581 .16859 Mtetra
.682 .765 .914 r
.36581 .16859 .36692 .16977 .36872 .16902 .36761 .16782 Mtetra
.759 .78 .871 r
.36761 .16782 .36872 .16902 .37054 .16786 .36944 .16661 Mtetra
.716 .762 .889 r
.36944 .16661 .37054 .16786 .37235 .16707 .37126 .16566 Mtetra
.607 .696 .907 r
.37126 .16566 .37235 .16707 .37412 .16698 .37305 .16521 Mtetra
0 .025 .589 r
.37305 .16521 .37412 .16698 .37568 .17122 .37472 .16716 Mtetra
.742 .471 0 r
.37472 .16716 .37568 .17122 .36709 .38163 .37616 .17386 Mtetra
0 0 .211 r
.37616 .17386 .36709 .38163 .36871 .38721 .36784 .3796 Mtetra
.384 .264 .59 r
.36784 .3796 .36871 .38721 .37059 .38786 .36966 .38137 Mtetra
.56 .403 .626 r
.36966 .38137 .37059 .38786 .37253 .38725 .37159 .38077 Mtetra
.673 .483 .621 r
.37159 .38077 .37253 .38725 .37452 .38545 .37363 .37803 Mtetra
.962 .682 .458 r
.37363 .37803 .37452 .38545 .37672 .37926 .38515 .17194 Mtetra
.526 .288 .497 r
.38515 .17194 .37672 .37926 .38832 .16716 .38737 .16258 Mtetra
.752 .56 .636 r
.38737 .16258 .38832 .16716 .39038 .16088 .38932 .15901 Mtetra
.709 .672 .812 r
.38932 .15901 .39038 .16088 .39223 .15935 .39115 .1579 Mtetra
.62 .697 .899 r
.39115 .1579 .39223 .15935 .39405 .15867 .39296 .15739 Mtetra
.549 .698 .938 r
.39296 .15739 .39405 .15867 .39585 .15837 .39476 .15712 Mtetra
.714 .763 .891 r
.39476 .15712 .39585 .15837 .39767 .15767 .39659 .15617 Mtetra
.699 .719 .864 r
.39659 .15617 .39767 .15767 .39949 .15694 .39842 .15525 Mtetra
.644 .669 .86 r
.39842 .15525 .39949 .15694 .4013 .15626 .40023 .1546 Mtetra
.421 .566 .893 r
.40023 .1546 .4013 .15626 .40314 .15532 .40202 .1548 Mtetra
.444 0 0 r
.40202 .1548 .40314 .15532 .40496 .15467 .40377 .15591 Mtetra
.79 .369 .249 r
.40377 .15591 .40496 .15467 .40675 .1547 .40544 .15908 Mtetra
.964 .675 .438 r
.40544 .15908 .40675 .1547 .40839 .15878 .39908 .366 Mtetra
.516 .275 .487 r
.39908 .366 .40839 .15878 .40208 .36968 .40074 .37273 Mtetra
.662 .276 .303 r
.40074 .37273 .40208 .36968 .4038 .37529 .40259 .37494 Mtetra
.039 .59 .83 r
.40259 .37494 .4038 .37529 .40572 .37581 .40453 .37513 Mtetra
.596 .856 .993 r
.40453 .37513 .40572 .37581 .40768 .37521 .40649 .37451 Mtetra
.755 .893 .94 r
.40649 .37451 .40768 .37521 .40966 .37411 .40848 .37332 Mtetra
.835 .876 .873 r
.40848 .37332 .40966 .37411 .41162 .37361 .41048 .37157 Mtetra
.822 .71 .741 r
.41048 .37157 .41162 .37361 .41359 .37289 .41252 .36895 Mtetra
.808 .615 .641 r
.41252 .36895 .41359 .37289 .41559 .37142 .41463 .36438 Mtetra
.965 .682 .445 r
.41463 .36438 .41559 .37142 .41772 .36598 .42364 .15658 Mtetra
.524 .286 .496 r
.42364 .15658 .41772 .36598 .42668 .15362 .42575 .14778 Mtetra
.711 .512 .618 r
.42575 .14778 .42668 .15362 .42873 .14653 .42768 .14438 Mtetra
.714 .649 .783 r
.42768 .14438 .42873 .14653 .4306 .14466 .42954 .14311 Mtetra
.625 .684 .885 r
.42954 .14311 .4306 .14466 .43245 .14392 .43138 .14256 Mtetra
.553 .686 .928 r
.43138 .14256 .43245 .14392 .43428 .1436 .4332 .14229 Mtetra
.658 .739 .909 r
.4332 .14229 .43428 .1436 .43612 .143 .43505 .1416 Mtetra
.69 .735 .885 r
.43505 .1416 .43612 .143 .43796 .14231 .4369 .14075 Mtetra
.686 .708 .865 r
.4369 .14075 .43796 .14231 .43981 .14162 .43875 .13989 Mtetra
.688 .685 .842 r
.43875 .13989 .43981 .14162 .44166 .14089 .4406 .13898 Mtetra
.662 .651 .829 r
.4406 .13898 .44166 .14089 .44351 .14017 .44246 .13818 Mtetra
.615 .621 .834 r
.44246 .13818 .44351 .14017 .44535 .13948 .4443 .13765 Mtetra
.359 .506 .869 r
.4443 .13765 .44535 .13948 .4472 .13892 .44612 .13809 Mtetra
0 .111 .565 r
.44612 .13809 .4472 .13892 .44905 .13842 .44792 .13946 Mtetra
.755 .304 .18 r
.44792 .13946 .44905 .13842 .4509 .13791 .4497 .14197 Mtetra
.583 .224 .325 r
.4497 .14197 .4509 .13791 .45275 .13724 .45151 .1433 Mtetra
.421 .111 .332 r
.45151 .1433 .45275 .13724 .45461 .13648 .45337 .14259 Mtetra
.345 .048 .309 r
.45337 .14259 .45461 .13648 .45647 .13569 .45525 .14103 Mtetra
.279 0 .267 r
.45525 .14103 .45647 .13569 .45834 .13457 .45714 .13914 Mtetra
.322 .001 .255 r
.45714 .13914 .45834 .13457 .4602 .13362 .45902 .13787 Mtetra
.471 .123 .294 r
.45902 .13787 .4602 .13362 .46206 .1333 .46087 .13794 Mtetra
.967 .673 .419 r
.46087 .13794 .46206 .1333 .46385 .1361 .45851 .3383 Mtetra
.528 .284 .488 r
.45851 .3383 .46385 .1361 .46149 .34655 .46023 .35095 Mtetra
.675 .314 .354 r
.46023 .35095 .46149 .34655 .46333 .35425 .46216 .354 Mtetra
0 .45 .696 r
.46216 .354 .46333 .35425 .4653 .35528 .46415 .35441 Mtetra
.61 .83 .984 r
.46415 .35441 .4653 .35528 .46731 .3547 .46616 .35379 Mtetra
.704 .85 .952 r
.46616 .35379 .46731 .3547 .46932 .35361 .46818 .35283 Mtetra
.664 .865 .975 r
.46818 .35283 .46932 .35361 .47134 .35273 .47019 .352 Mtetra
.62 .861 .988 r
.47019 .352 .47134 .35273 .47335 .35203 .47221 .35131 Mtetra
.609 .858 .99 r
.47221 .35131 .47335 .35203 .47537 .35134 .47422 .35064 Mtetra
.568 .848 .997 r
.47422 .35064 .47537 .35134 .47738 .35068 .47624 .35008 Mtetra
.524 .85 .997 r
.47624 .35008 .47738 .35068 .4794 .35003 .47825 .34958 Mtetra
.49 .86 .986 r
.47825 .34958 .4794 .35003 .48142 .34939 .48027 .34907 Mtetra
.489 .878 .966 r
.48027 .34907 .48142 .34939 .48344 .34873 .48229 .34848 Mtetra
.499 .89 .955 r
.48229 .34848 .48344 .34873 .48546 .34807 .48431 .34782 Mtetra
.507 .895 .954 r
.48431 .34782 .48546 .34807 .48748 .3474 .48634 .34714 Mtetra
.51 .895 .956 r
.48634 .34714 .48748 .3474 .48951 .34672 .48836 .34646 Mtetra
.51 .894 .957 r
.48836 .34646 .48951 .34672 .49153 .34605 .49039 .34578 Mtetra
.512 .895 .958 r
.49039 .34578 .49153 .34605 .49356 .34537 .49242 .3451 Mtetra
.513 .896 .958 r
.49242 .3451 .49356 .34537 .49559 .34469 .49445 .34442 Mtetra
.515 .896 .959 r
.49445 .34442 .49559 .34469 .49762 .34401 .49649 .34373 Mtetra
.516 .896 .959 r
.49649 .34373 .49762 .34401 .49965 .34332 .49852 .34304 Mtetra
.518 .897 .96 r
.49852 .34304 .49965 .34332 .50169 .34263 .50055 .34235 Mtetra
.519 .897 .96 r
.50055 .34235 .50169 .34263 .50372 .34194 .50259 .34166 Mtetra
.52 .897 .961 r
.50259 .34166 .50372 .34194 .50576 .34125 .50463 .34097 Mtetra
.521 .898 .961 r
.50463 .34097 .50576 .34125 .5078 .34056 .50667 .34027 Mtetra
.522 .898 .961 r
.50667 .34027 .5078 .34056 .50984 .33987 .50871 .33958 Mtetra
.522 .898 .962 r
.50871 .33958 .50984 .33987 .51188 .33917 .51076 .33888 Mtetra
.523 .898 .962 r
.51076 .33888 .51188 .33917 .51392 .33848 .5128 .33818 Mtetra
.524 .898 .962 r
.5128 .33818 .51392 .33848 .51597 .33778 .51485 .33749 Mtetra
.51485 .33749 .51597 .33778 .51801 .33708 .51689 .33679 Mtetra
.51689 .33679 .51801 .33708 .52006 .33638 .51894 .33609 Mtetra
.525 .898 .963 r
.51894 .33609 .52006 .33638 .52211 .33568 .52099 .33538 Mtetra
.52099 .33538 .52211 .33568 .52416 .33498 .52305 .33468 Mtetra
.52305 .33468 .52416 .33498 .52621 .33428 .5251 .33398 Mtetra
.525 .899 .963 r
.5251 .33398 .52621 .33428 .52827 .33358 .52716 .33328 Mtetra
.52716 .33328 .52827 .33358 .53032 .33288 .52921 .33257 Mtetra
.526 .899 .963 r
.52921 .33257 .53032 .33288 .53238 .33217 .53127 .33187 Mtetra
.53127 .33187 .53238 .33217 .53444 .33147 .53333 .33116 Mtetra
.53333 .33116 .53444 .33147 .5365 .33076 .53539 .33046 Mtetra
.53539 .33046 .5365 .33076 .53856 .33006 .53746 .32975 Mtetra
.53746 .32975 .53856 .33006 .54062 .32935 .53952 .32904 Mtetra
.53952 .32904 .54062 .32935 .54269 .32864 .54159 .32834 Mtetra
.54159 .32834 .54269 .32864 .54475 .32794 .54366 .32763 Mtetra
.54366 .32763 .54475 .32794 .54682 .32723 .54573 .32692 Mtetra
.54573 .32692 .54682 .32723 .54889 .32652 .5478 .32621 Mtetra
.5478 .32621 .54889 .32652 .55096 .32581 .54987 .3255 Mtetra
.54987 .3255 .55096 .32581 .55303 .3251 .55194 .32479 Mtetra
.55194 .32479 .55303 .3251 .55511 .32439 .55402 .32408 Mtetra
.55402 .32408 .55511 .32439 .55718 .32368 .5561 .32337 Mtetra
.5561 .32337 .55718 .32368 .55926 .32297 .55817 .32265 Mtetra
.55817 .32265 .55926 .32297 .56134 .32226 .56025 .32194 Mtetra
.56025 .32194 .56134 .32226 .56342 .32155 .56234 .32123 Mtetra
.56234 .32123 .56342 .32155 .5655 .32083 .56442 .32051 Mtetra
.56442 .32051 .5655 .32083 .56758 .32012 .5665 .3198 Mtetra
.5665 .3198 .56758 .32012 .56967 .3194 .56859 .31908 Mtetra
.56859 .31908 .56967 .3194 .57175 .31869 .57068 .31837 Mtetra
.57068 .31837 .57175 .31869 .57384 .31797 .57277 .31765 Mtetra
.527 .899 .963 r
.57277 .31765 .57384 .31797 .57593 .31725 .57486 .31693 Mtetra
.57486 .31693 .57593 .31725 .57802 .31654 .57695 .31621 Mtetra
.57695 .31621 .57802 .31654 .58011 .31582 .57905 .31549 Mtetra
.57905 .31549 .58011 .31582 .58221 .31509 .58114 .31477 Mtetra
.528 .9 .963 r
.58114 .31477 .58221 .31509 .5843 .31437 .58324 .31405 Mtetra
.58324 .31405 .5843 .31437 .5864 .31365 .58534 .31332 Mtetra
.529 .9 .963 r
.58534 .31332 .5864 .31365 .5885 .31292 .58744 .31259 Mtetra
.53 .901 .963 r
.58744 .31259 .5885 .31292 .5906 .31219 .58954 .31186 Mtetra
.531 .901 .963 r
.58954 .31186 .5906 .31219 .5927 .31145 .59165 .31113 Mtetra
.59165 .31113 .5927 .31145 .59481 .31072 .59375 .31039 Mtetra
.528 .9 .962 r
.59375 .31039 .59481 .31072 .59691 .30998 .59586 .30966 Mtetra
.536 .905 .96 r
.59586 .30966 .59691 .30998 .59902 .30923 .59797 .30891 Mtetra
.564 .916 .962 r
.59797 .30891 .59902 .30923 .60113 .30848 .60007 .30809 Mtetra
.613 .928 .968 r
.60007 .30809 .60113 .30848 .60323 .3077 .60218 .30718 Mtetra
.643 .918 .978 r
.60218 .30718 .60323 .3077 .60534 .30693 .60429 .30626 Mtetra
.648 .895 .983 r
.60429 .30626 .60534 .30693 .60746 .30617 .6064 .30539 Mtetra
.629 .868 .987 r
.6064 .30539 .60746 .30617 .60957 .30542 .60852 .30463 Mtetra
.62 .86 .988 r
.60852 .30463 .60957 .30542 .61169 .30469 .61063 .3039 Mtetra
.616 .86 .989 r
.61063 .3039 .61169 .30469 .6138 .30396 .61275 .30318 Mtetra
.62 .863 .989 r
.61275 .30318 .6138 .30396 .61592 .30324 .61487 .30244 Mtetra
.612 .857 .99 r
.61487 .30244 .61592 .30324 .61805 .30252 .617 .30173 Mtetra
.589 .85 .994 r
.617 .30173 .61805 .30252 .62017 .30182 .61912 .3011 Mtetra
.545 .844 .999 r
.61912 .3011 .62017 .30182 .6223 .30114 .62126 .30055 Mtetra
.514 .856 .994 r
.62126 .30055 .6223 .30114 .62442 .30046 .62339 .30001 Mtetra
.496 .871 .979 r
.62339 .30001 .62442 .30046 .62655 .29977 .62552 .29942 Mtetra
.508 .89 .963 r
.62552 .29942 .62655 .29977 .62868 .29906 .62766 .29874 Mtetra
.515 .896 .959 r
.62766 .29874 .62868 .29906 .63081 .29835 .62979 .29802 Mtetra
.52 .898 .96 r
.62979 .29802 .63081 .29835 .63295 .29763 .63192 .29729 Mtetra
.52 .897 .961 r
.63192 .29729 .63295 .29763 .63508 .2969 .63406 .29657 Mtetra
.521 .898 .961 r
.63406 .29657 .63508 .2969 .63722 .29617 .6362 .29584 Mtetra
.523 .899 .96 r
.6362 .29584 .63722 .29617 .63935 .29543 .63834 .2951 Mtetra
.523 .9 .959 r
.63834 .2951 .63935 .29543 .64149 .29468 .64048 .29436 Mtetra
.524 .901 .958 r
.64048 .29436 .64149 .29468 .64363 .29393 .64262 .29361 Mtetra
.523 .901 .956 r
.64262 .29361 .64363 .29393 .64577 .29316 .64476 .29286 Mtetra
.517 .9 .953 r
.64476 .29286 .64577 .29316 .64792 .29238 .64691 .29211 Mtetra
.517 .903 .945 r
.64691 .29211 .64792 .29238 .65006 .29159 .64905 .29133 Mtetra
.537 .914 .943 r
.64905 .29133 .65006 .29159 .6522 .29081 .6512 .2905 Mtetra
.597 .934 .952 r
.6512 .2905 .6522 .29081 .65435 .29004 .65334 .28955 Mtetra
.645 .928 .973 r
.65334 .28955 .65435 .29004 .6565 .28926 .65548 .28857 Mtetra
.664 .901 .979 r
.65548 .28857 .6565 .28926 .65865 .28848 .65763 .28763 Mtetra
.646 .863 .981 r
.65763 .28763 .65865 .28848 .6608 .28768 .65978 .28681 Mtetra
.637 .856 .983 r
.65978 .28681 .6608 .28768 .66295 .28687 .66193 .28603 Mtetra
.629 .858 .986 r
.66193 .28603 .66295 .28687 .66511 .28606 .66409 .28526 Mtetra
.628 .867 .987 r
.66409 .28526 .66511 .28606 .66726 .28527 .66625 .28449 Mtetra
.623 .868 .988 r
.66625 .28449 .66726 .28527 .66942 .28448 .66841 .28372 Mtetra
.618 .87 .99 r
.66841 .28372 .66942 .28448 .67158 .28371 .67057 .28296 Mtetra
.612 .871 .991 r
.67057 .28296 .67158 .28371 .67374 .28294 .67274 .28221 Mtetra
.606 .872 .992 r
.67274 .28221 .67374 .28294 .67591 .28219 .6749 .28147 Mtetra
.589 .867 .994 r
.6749 .28147 .67591 .28219 .67808 .28148 .67707 .28078 Mtetra
.509 .836 .999 r
.67707 .28078 .67808 .28148 .68025 .28084 .67926 .28029 Mtetra
.543 .881 .988 r
.67926 .28029 .68025 .28084 .68242 .28018 .68143 .27963 Mtetra
.674 .929 .971 r
.68143 .27963 .68242 .28018 .6846 .27953 .68359 .27858 Mtetra
.853 .891 .864 r
.68359 .27858 .6846 .27953 .68679 .27917 .6857 .2766 Mtetra
.823 .689 .716 r
.6857 .2766 .68679 .27917 .68896 .27834 .68776 .27362 Mtetra
.821 .605 .61 r
.68776 .27362 .68896 .27834 .69108 .27645 .68968 .26808 Mtetra
.974 .665 .342 r
.68968 .26808 .69108 .27645 .69288 .26869 .68045 .05639 Mtetra
.518 .281 .494 r
.68045 .05639 .69288 .26869 .68322 .05313 .68214 .0495 Mtetra
.773 .6 .665 r
.68214 .0495 .68322 .05313 .68499 .04782 .68404 .04645 Mtetra
.719 .774 .895 r
.68404 .04645 .68499 .04782 .68698 .04656 .68604 .04539 Mtetra
.614 .77 .954 r
.68604 .04539 .68698 .04656 .68901 .04601 .68807 .04481 Mtetra
.554 .737 .961 r
.68807 .04481 .68901 .04601 .69107 .04578 .69012 .04445 Mtetra
.663 .759 .921 r
.69012 .04445 .69107 .04578 .69309 .04503 .69214 .04368 Mtetra
.67 .759 .917 r
.69214 .04368 .69309 .04503 .69512 .04425 .69417 .04287 Mtetra
.68 .758 .911 r
.69417 .04287 .69512 .04425 .69714 .04342 .69619 .04202 Mtetra
.769 .786 .867 r
.69619 .04202 .69714 .04342 .69913 .04205 .69818 .04063 Mtetra
.701 .76 .898 r
.69818 .04063 .69913 .04205 .70115 .04109 .7002 .03966 Mtetra
.508 .668 .935 r
.7002 .03966 .70115 .04109 .70322 .04094 .70227 .0395 Mtetra
.748 .331 0 r
.70227 .0395 .70322 .04094 .70562 .04598 .70467 .04453 Mtetra
.97 .655 .291 r
.70467 .04453 .70562 .04598 .72143 .26136 .72042 .25995 Mtetra
.729 .299 0 r
.72042 .25995 .72143 .26136 .72399 .26624 .72298 .26484 Mtetra
.053 .475 .886 r
.02682 .50191 .02814 .50299 .02967 .50353 .02835 .50244 Mtetra
.647 .761 .932 r
.02835 .50244 .02967 .50353 .03137 .50294 .03005 .50185 Mtetra
.81 .777 .822 r
.03005 .50185 .03137 .50294 .03324 .50123 .03192 .50014 Mtetra
.908 .736 .657 r
.03192 .50014 .03324 .50123 .03574 .49529 .03442 .49418 Mtetra
.937 .686 .534 r
.03442 .49418 .03574 .49529 .0678 .28807 .06659 .28691 Mtetra
.907 .726 .646 r
.06659 .28691 .0678 .28807 .07022 .2819 .06901 .28075 Mtetra
.775 .758 .838 r
.06901 .28075 .07022 .2819 .07193 .28058 .07072 .27944 Mtetra
.638 .734 .918 r
.07072 .27944 .07193 .28058 .07352 .28006 .07231 .27892 Mtetra
.503 .689 .951 r
.07231 .27892 .07352 .28006 .07506 .27992 .07385 .2788 Mtetra
.745 .759 .863 r
.07385 .2788 .07506 .27992 .07674 .27885 .07552 .27773 Mtetra
.694 .752 .897 r
.07552 .27773 .07674 .27885 .07837 .27809 .07715 .27698 Mtetra
.459 .677 .958 r
.07715 .27698 .07837 .27809 .07989 .27803 .07868 .27694 Mtetra
.931 .563 .285 r
.07868 .27694 .07989 .27803 .08078 .28249 .07955 .28148 Mtetra
.939 .683 .522 r
.07955 .28148 .08078 .28249 .05286 .48911 .05152 .48815 Mtetra
.927 .563 .309 r
.05152 .48815 .05286 .48911 .05376 .49425 .05243 .49321 Mtetra
.333 .65 .969 r
.05243 .49321 .05376 .49425 .05537 .49439 .05405 .49334 Mtetra
.709 .783 .91 r
.05405 .49334 .05537 .49439 .05713 .49352 .05581 .49248 Mtetra
.778 .789 .862 r
.05581 .49248 .05713 .49352 .05896 .49218 .05763 .49115 Mtetra
.646 .773 .941 r
.05763 .49115 .05896 .49218 .06065 .49175 .05936 .49055 Mtetra
.638 .739 .922 r
.05936 .49055 .06065 .49175 .06236 .49125 .06107 .48999 Mtetra
.681 .74 .895 r
.06107 .48999 .06236 .49125 .06414 .49029 .06282 .48924 Mtetra
.764 .787 .872 r
.06282 .48924 .06414 .49029 .06619 .48732 .06463 .48801 Mtetra
.805 1 .811 r
.06463 .48801 .06619 .48732 .06875 .4807 .06653 .48617 Mtetra
.003 0 .102 r
.06653 .48617 .06875 .4807 .09829 .2779 .0686 .48309 Mtetra
.444 .212 .467 r
.0686 .48309 .09829 .2779 .10051 .27297 .07329 .46095 Mtetra
0 0 0 r
.07329 .46095 .10051 .27297 .10239 .27051 .10085 .27176 Mtetra
.963 .941 .682 r
.10085 .27176 .10239 .27051 .10415 .2689 .10292 .26796 Mtetra
.784 .796 .862 r
.10292 .26796 .10415 .2689 .10581 .26802 .10463 .26668 Mtetra
.643 .701 .888 r
.10463 .26668 .10581 .26802 .10743 .26748 .10625 .26612 Mtetra
.562 .671 .911 r
.10625 .26612 .10743 .26748 .10902 .26708 .10783 .26587 Mtetra
.676 .734 .894 r
.10783 .26587 .10902 .26708 .11069 .26622 .10947 .26518 Mtetra
.685 .769 .915 r
.10947 .26518 .11069 .26622 .11234 .26544 .11111 .26447 Mtetra
.636 .771 .945 r
.11111 .26447 .11234 .26544 .11394 .26508 .11273 .26394 Mtetra
.501 .691 .953 r
.11273 .26394 .11394 .26508 .11531 .26637 .1143 .26382 Mtetra
.406 .433 .775 r
.1143 .26382 .11531 .26637 .11629 .27071 .11579 .26425 Mtetra
.358 .244 .585 r
.11579 .26425 .11629 .27071 .09127 .47269 .11714 .2658 Mtetra
0 0 .073 r
.11714 .2658 .09127 .47269 .09229 .47761 .09382 .45495 Mtetra
0 0 .126 r
.09382 .45495 .09229 .47761 .09373 .47931 .09277 .47557 Mtetra
0 0 .462 r
.09277 .47557 .09373 .47931 .09531 .47995 .09405 .47855 Mtetra
.397 .609 .934 r
.09405 .47855 .09531 .47995 .09703 .47957 .0957 .4787 Mtetra
.698 .819 .94 r
.0957 .4787 .09703 .47957 .09881 .47871 .09747 .47789 Mtetra
.767 .832 .903 r
.09747 .47789 .09881 .47871 .10062 .47766 .0993 .47671 Mtetra
.681 .799 .937 r
.0993 .47671 .10062 .47766 .10237 .477 .10107 .47596 Mtetra
.625 .77 .95 r
.10107 .47596 .10237 .477 .10411 .47653 .10281 .47543 Mtetra
.618 .757 .945 r
.10281 .47543 .10411 .47653 .10584 .47608 .10455 .47493 Mtetra
.637 .752 .932 r
.10455 .47493 .10584 .47608 .10758 .47555 .1063 .47437 Mtetra
.647 .749 .924 r
.1063 .47437 .10758 .47555 .10934 .47496 .10805 .47377 Mtetra
.651 .747 .92 r
.10805 .47377 .10934 .47496 .11109 .47434 .10981 .47314 Mtetra
.663 .751 .915 r
.10981 .47314 .11109 .47434 .11286 .47364 .11158 .47247 Mtetra
.664 .756 .919 r
.11158 .47247 .11286 .47364 .11464 .47292 .11335 .47179 Mtetra
.652 .761 .929 r
.11335 .47179 .11464 .47292 .1164 .47225 .11511 .47117 Mtetra
.415 .681 .972 r
.11511 .47117 .1164 .47225 .11809 .47225 .11679 .47118 Mtetra
.452 .701 .974 r
.11679 .47118 .11809 .47225 .11979 .47217 .11849 .4711 Mtetra
.681 .779 .925 r
.11849 .4711 .11979 .47217 .12157 .47142 .12027 .47035 Mtetra
.896 .766 .71 r
.12027 .47035 .12157 .47142 .12373 .46754 .12243 .46651 Mtetra
.946 .689 .516 r
.12243 .46651 .12373 .46754 .15035 .26221 .14908 .2617 Mtetra
.946 .733 .583 r
.14908 .2617 .15035 .26221 .1533 .25093 .15211 .24983 Mtetra
.852 .771 .772 r
.15211 .24983 .1533 .25093 .15516 .24866 .15397 .24753 Mtetra
.68 .755 .908 r
.15397 .24753 .15516 .24866 .15682 .24796 .15564 .24682 Mtetra
.537 .706 .948 r
.15564 .24682 .15682 .24796 .15843 .24776 .15725 .2466 Mtetra
.699 .753 .894 r
.15725 .2466 .15843 .24776 .16011 .24698 .15893 .2458 Mtetra
.719 .754 .88 r
.15893 .2458 .16011 .24698 .16181 .24608 .16063 .24488 Mtetra
.573 .708 .934 r
.16063 .24488 .16181 .24608 .16343 .24579 .16225 .24456 Mtetra
.824 .365 0 r
.16225 .24456 .16343 .24579 .16471 .24846 .16354 .24713 Mtetra
.948 .685 .503 r
.16354 .24713 .16471 .24846 .14215 .45529 .14094 .45353 Mtetra
.958 .626 .334 r
.14094 .45353 .14215 .45529 .14296 .46298 .1417 .46167 Mtetra
0 .039 .548 r
.1417 .46167 .14296 .46298 .1445 .46439 .14323 .46314 Mtetra
.58 .718 .938 r
.14323 .46314 .1445 .46439 .14626 .46398 .14499 .46277 Mtetra
.782 .773 .845 r
.14499 .46277 .14626 .46398 .14814 .46248 .14687 .46132 Mtetra
.899 .758 .696 r
.14687 .46132 .14814 .46248 .15034 .45821 .14906 .45712 Mtetra
.948 .689 .51 r
.14906 .45712 .15034 .45821 .17565 .25063 .17441 .24997 Mtetra
.944 .737 .592 r
.17441 .24997 .17565 .25063 .17835 .24092 .17716 .23986 Mtetra
.859 .778 .771 r
.17716 .23986 .17835 .24092 .18021 .2386 .17903 .23749 Mtetra
.669 .758 .917 r
.17903 .23749 .18021 .2386 .18189 .23797 .18071 .23683 Mtetra
.523 .702 .951 r
.18071 .23683 .18189 .23797 .18351 .23783 .18233 .23664 Mtetra
.669 .743 .906 r
.18233 .23664 .18351 .23783 .18518 .23728 .18402 .23597 Mtetra
.724 .737 .861 r
.18402 .23597 .18518 .23728 .18688 .23638 .18573 .23498 Mtetra
.652 .701 .883 r
.18573 .23498 .18688 .23638 .18857 .23568 .18741 .23437 Mtetra
.014 .382 .844 r
.18741 .23437 .18857 .23568 .19019 .23559 .18894 .23514 Mtetra
.888 .475 .215 r
.18894 .23514 .19019 .23559 .19172 .23632 .19016 .23873 Mtetra
.947 .68 .498 r
.19016 .23873 .19172 .23632 .19312 .23835 .16956 .44286 Mtetra
.517 .275 .488 r
.16956 .44286 .19312 .23835 .1932 .25261 .17059 .44926 Mtetra
.506 .266 .485 r
.17059 .44926 .1932 .25261 .17377 .44875 .17216 .45082 Mtetra
.51 .086 .17 r
.17216 .45082 .17377 .44875 .17516 .45192 .17384 .45132 Mtetra
.287 .719 .968 r
.17384 .45132 .17516 .45192 .17682 .45265 .17557 .45131 Mtetra
.606 .713 .92 r
.17557 .45131 .17682 .45265 .17861 .45214 .17736 .45086 Mtetra
.729 .758 .876 r
.17736 .45086 .17861 .45214 .18047 .45102 .17921 .44979 Mtetra
.853 .771 .771 r
.17921 .44979 .18047 .45102 .18237 .44946 .18122 .4473 Mtetra
.884 .697 .645 r
.18122 .4473 .18237 .44946 .18434 .44734 .18357 .44142 Mtetra
.947 .684 .505 r
.18357 .44142 .18434 .44734 .18644 .44389 .20673 .23552 Mtetra
.519 .282 .496 r
.20673 .23552 .18644 .44389 .18958 .43026 .209 .2294 Mtetra
.51 .275 .494 r
.209 .2294 .18958 .43026 .21172 .2313 .21088 .22697 Mtetra
.66 .505 .663 r
.21088 .22697 .21172 .2313 .21377 .22723 .21267 .2254 Mtetra
.69 .659 .814 r
.21267 .2254 .21377 .22723 .21558 .22545 .2144 .22447 Mtetra
.611 .771 .957 r
.2144 .22447 .21558 .22545 .21727 .22489 .21608 .224 Mtetra
.529 .761 .982 r
.21608 .224 .21727 .22489 .21892 .22472 .21774 .22372 Mtetra
.577 .755 .963 r
.21774 .22372 .21892 .22472 .22059 .22447 .21941 .22336 Mtetra
.649 .756 .927 r
.21941 .22336 .22059 .22447 .22228 .22388 .22111 .22276 Mtetra
.663 .758 .921 r
.22111 .22276 .22228 .22388 .22398 .22324 .22282 .22212 Mtetra
.725 .771 .889 r
.22282 .22212 .22398 .22324 .22572 .2223 .22455 .22116 Mtetra
.747 .773 .875 r
.22455 .22116 .22572 .2223 .22746 .22121 .2263 .22007 Mtetra
.632 .745 .929 r
.2263 .22007 .22746 .22121 .22916 .22068 .228 .21954 Mtetra
.556 .05 0 r
.228 .21954 .22916 .22068 .23065 .22224 .22948 .22114 Mtetra
.955 .685 .486 r
.22948 .22114 .23065 .22224 .21287 .42449 .21152 .42438 Mtetra
.937 .619 .41 r
.21152 .42438 .21287 .42449 .21335 .43785 .21209 .43679 Mtetra
.679 .164 0 r
.21209 .43679 .21335 .43785 .21492 .43986 .21367 .43877 Mtetra
.586 .756 .959 r
.21367 .43877 .21492 .43986 .21674 .43942 .21548 .43834 Mtetra
.729 .795 .905 r
.21548 .43834 .21674 .43942 .21861 .43838 .21735 .43732 Mtetra
.738 .8 .902 r
.21735 .43732 .21861 .43838 .22048 .43729 .21922 .43624 Mtetra
.673 .791 .937 r
.21922 .43624 .22048 .43729 .22233 .43654 .22107 .4355 Mtetra
.678 .793 .936 r
.22107 .4355 .22233 .43654 .22417 .43578 .22291 .43474 Mtetra
.69 .796 .931 r
.22291 .43474 .22417 .43578 .22603 .43495 .22477 .43392 Mtetra
.702 .8 .926 r
.22477 .43392 .22603 .43495 .22789 .43407 .22663 .43304 Mtetra
.694 .799 .93 r
.22663 .43304 .22789 .43407 .22974 .43324 .22849 .4322 Mtetra
.659 .79 .944 r
.22849 .4322 .22974 .43324 .23159 .43259 .23033 .43151 Mtetra
.602 .765 .958 r
.23033 .43151 .23159 .43259 .23341 .43218 .23216 .43103 Mtetra
.589 .747 .952 r
.23216 .43103 .23341 .43218 .23522 .43182 .23398 .43061 Mtetra
.58 .731 .946 r
.23398 .43061 .23522 .43182 .23704 .43155 .23581 .43022 Mtetra
.587 .712 .93 r
.23581 .43022 .23704 .43155 .23885 .43131 .23763 .42982 Mtetra
.637 .704 .895 r
.23763 .42982 .23885 .43131 .24069 .43067 .23948 .42922 Mtetra
.73 .738 .858 r
.23948 .42922 .24069 .43067 .24264 .42893 .24137 .42809 Mtetra
.856 .836 .826 r
.24137 .42809 .24264 .42893 .24482 .42447 .24334 .42603 Mtetra
.686 .904 .554 r
.24334 .42603 .24482 .42447 .24828 .40501 .24536 .42344 Mtetra
.423 .168 .42 r
.24536 .42344 .24828 .40501 .2665 .21199 .24736 .421 Mtetra
.5 .261 .484 r
.24736 .421 .2665 .21199 .26829 .21069 .24923 .42015 Mtetra
.502 .263 .484 r
.24923 .42015 .26829 .21069 .26997 .21063 .25106 .41987 Mtetra
.25106 .41987 .26997 .21063 .27163 .21092 .25287 .41964 Mtetra
.501 .262 .484 r
.25287 .41964 .27163 .21092 .27336 .21041 .25472 .41908 Mtetra
.25472 .41908 .27336 .21041 .27509 .20991 .25657 .41851 Mtetra
.25657 .41851 .27509 .20991 .27682 .20938 .25843 .41793 Mtetra
.25843 .41793 .27682 .20938 .27855 .20882 .26028 .41734 Mtetra
.26028 .41734 .27855 .20882 .28029 .20823 .26214 .41673 Mtetra
.26214 .41673 .28029 .20823 .28201 .20789 .26398 .41635 Mtetra
.502 .263 .484 r
.26398 .41635 .28201 .20789 .28368 .20817 .26579 .41639 Mtetra
.501 .262 .484 r
.26579 .41639 .28368 .20817 .28544 .20747 .26766 .41567 Mtetra
.495 .257 .483 r
.26766 .41567 .28544 .20747 .28736 .20455 .26972 .41254 Mtetra
0 0 .139 r
.26972 .41254 .28736 .20455 .28938 .20045 .28776 .20542 Mtetra
.794 .789 .291 r
.28776 .20542 .28938 .20045 .2913 .19762 .29008 .19741 Mtetra
.939 .885 .753 r
.29008 .19741 .2913 .19762 .29314 .19576 .29201 .19439 Mtetra
.72 .736 .864 r
.29201 .19439 .29314 .19576 .2949 .19491 .29379 .1934 Mtetra
.631 .684 .882 r
.29379 .1934 .2949 .19491 .29665 .1943 .29553 .19286 Mtetra
.598 .681 .9 r
.29553 .19286 .29665 .1943 .29839 .19378 .29726 .19245 Mtetra
.661 .726 .897 r
.29726 .19245 .29839 .19378 .30014 .19309 .29902 .19178 Mtetra
.656 .727 .902 r
.29902 .19178 .30014 .19309 .3019 .19242 .30077 .19113 Mtetra
.646 .728 .908 r
.30077 .19113 .3019 .19242 .30365 .1918 .30252 .19054 Mtetra
.624 .724 .918 r
.30252 .19054 .30365 .1918 .30539 .19128 .30427 .19002 Mtetra
.626 .726 .919 r
.30427 .19002 .30539 .19128 .30714 .19075 .30601 .1895 Mtetra
.645 .736 .915 r
.30601 .1895 .30714 .19075 .3089 .19013 .30777 .18891 Mtetra
.686 .754 .903 r
.30777 .18891 .3089 .19013 .31067 .18929 .30954 .18813 Mtetra
.696 .766 .906 r
.30954 .18813 .31067 .18929 .31244 .18842 .31131 .18731 Mtetra
.693 .776 .915 r
.31131 .18731 .31244 .18842 .31422 .18757 .31308 .1865 Mtetra
.672 .779 .93 r
.31308 .1865 .31422 .18757 .31599 .18684 .31485 .18579 Mtetra
.667 .783 .935 r
.31485 .18579 .31599 .18684 .31775 .18613 .31662 .1851 Mtetra
.673 .787 .935 r
.31662 .1851 .31775 .18613 .31952 .1854 .31839 .18439 Mtetra
.705 .801 .924 r
.31839 .18439 .31952 .1854 .32131 .18442 .32017 .18354 Mtetra
.672 .818 .953 r
.32017 .18354 .32131 .18442 .32308 .18371 .32194 .18282 Mtetra
.587 .791 .977 r
.32194 .18282 .32308 .18371 .32481 .18361 .32369 .18238 Mtetra
.402 .635 .95 r
.32369 .18238 .32481 .18361 .32642 .18544 .32541 .18248 Mtetra
.347 .37 .743 r
.32541 .18248 .32642 .18544 .32776 .19144 .32709 .1833 Mtetra
.307 .193 .556 r
.32709 .1833 .32776 .19144 .31613 .3975 .32864 .18599 Mtetra
0 0 .187 r
.32864 .18599 .31613 .3975 .31775 .40112 .31702 .39266 Mtetra
0 0 .391 r
.31702 .39266 .31775 .40112 .31952 .40253 .31842 .3997 Mtetra
0 .112 .652 r
.31842 .3997 .31952 .40253 .32136 .40298 .32015 .40181 Mtetra
.512 .719 .966 r
.32015 .40181 .32136 .40298 .32325 .40258 .32203 .4016 Mtetra
.668 .812 .952 r
.32203 .4016 .32325 .40258 .32516 .40187 .32394 .40084 Mtetra
.719 .814 .924 r
.32394 .40084 .32516 .40187 .32708 .40107 .32587 .39985 Mtetra
.606 .747 .944 r
.32587 .39985 .32708 .40107 .32896 .40077 .32777 .39935 Mtetra
.643 .725 .908 r
.32777 .39935 .32896 .40077 .33087 .40018 .32968 .39871 Mtetra
.694 .733 .88 r
.32968 .39871 .33087 .40018 .33281 .39901 .33161 .39779 Mtetra
.785 .792 .859 r
.33161 .39779 .33281 .39901 .33488 .39572 .33358 .3963 Mtetra
.82 .996 .764 r
.33358 .3963 .33488 .39572 .33716 .3888 .33558 .3941 Mtetra
0 0 .11 r
.33558 .3941 .33716 .3888 .35107 .18085 .33768 .39029 Mtetra
0 0 .187 r
.33768 .39029 .35107 .18085 .35312 .17575 .35148 .18356 Mtetra
0 0 0 r
.35148 .18356 .35312 .17575 .35502 .17312 .35381 .17358 Mtetra
.96 .943 .701 r
.35381 .17358 .35502 .17312 .35687 .17144 .35576 .17017 Mtetra
.719 .758 .883 r
.35576 .17017 .35687 .17144 .35866 .17068 .35757 .16919 Mtetra
.602 .68 .897 r
.35757 .16919 .35866 .17068 .36044 .17024 .35935 .16876 Mtetra
.523 .648 .913 r
.35935 .16876 .36044 .17024 .36222 .16994 .36112 .16862 Mtetra
.644 .726 .908 r
.36112 .16862 .36222 .16994 .36401 .1693 .36291 .16801 Mtetra
.657 .736 .908 r
.36291 .16801 .36401 .1693 .36581 .16859 .36471 .16735 Mtetra
.67 .749 .91 r
.36471 .16735 .36581 .16859 .36761 .16782 .36651 .16663 Mtetra
.727 .774 .891 r
.36651 .16663 .36761 .16782 .36944 .16661 .36832 .16562 Mtetra
.711 .81 .927 r
.36832 .16562 .36944 .16661 .37126 .16566 .37014 .16473 Mtetra
.646 .806 .96 r
.37014 .16473 .37126 .16566 .37305 .16521 .37194 .1641 Mtetra
.192 .544 .928 r
.37194 .1641 .37305 .16521 .37472 .16716 .37368 .16454 Mtetra
.253 .342 .762 r
.37368 .16454 .37472 .16716 .37616 .17386 .3754 .16559 Mtetra
.405 .265 .576 r
.3754 .16559 .37616 .17386 .36784 .3796 .3771 .16723 Mtetra
.502 .268 .492 r
.3771 .16723 .36784 .3796 .36966 .38137 .37885 .16773 Mtetra
.505 .271 .493 r
.37885 .16773 .36966 .38137 .37159 .38077 .38066 .16706 Mtetra
.508 .273 .493 r
.38066 .16706 .37159 .38077 .37363 .37803 .38253 .16526 Mtetra
.511 .275 .494 r
.38253 .16526 .37363 .37803 .38515 .17194 .38445 .16223 Mtetra
.618 .412 .58 r
.38445 .16223 .38515 .17194 .38737 .16258 .38635 .15972 Mtetra
.736 .608 .715 r
.38635 .15972 .38737 .16258 .38932 .15901 .38822 .1578 Mtetra
.701 .768 .904 r
.38822 .1578 .38932 .15901 .39115 .1579 .39005 .15693 Mtetra
.627 .793 .962 r
.39005 .15693 .39115 .1579 .39296 .15739 .39186 .15637 Mtetra
.597 .771 .963 r
.39186 .15637 .39296 .15739 .39476 .15712 .39366 .1559 Mtetra
.746 .777 .879 r
.39366 .1559 .39476 .15712 .39659 .15617 .3955 .15477 Mtetra
.711 .738 .872 r
.3955 .15477 .39659 .15617 .39842 .15525 .39733 .1538 Mtetra
.61 .693 .903 r
.39733 .1538 .39842 .15525 .40023 .1546 .39914 .15333 Mtetra
0 .042 .568 r
.39914 .15333 .40023 .1546 .40202 .1548 .40087 .15503 Mtetra
.91 .53 .288 r
.40087 .15503 .40202 .1548 .40377 .15591 .40239 .16161 Mtetra
.962 .674 .44 r
.40239 .16161 .40377 .15591 .40544 .15908 .39579 .36949 Mtetra
.509 .268 .485 r
.39579 .36949 .40544 .15908 .39908 .366 .3976 .37255 Mtetra
.542 .219 .371 r
.3976 .37255 .39908 .366 .40074 .37273 .39949 .37357 Mtetra
.363 0 0 r
.39949 .37357 .40074 .37273 .40259 .37494 .40142 .37381 Mtetra
.433 .694 .974 r
.40142 .37381 .40259 .37494 .40453 .37513 .40336 .37377 Mtetra
.614 .73 .928 r
.40336 .37377 .40453 .37513 .40649 .37451 .40532 .37323 Mtetra
.743 .784 .886 r
.40532 .37323 .40649 .37451 .40848 .37332 .40731 .37204 Mtetra
.895 .79 .737 r
.40731 .37204 .40848 .37332 .41048 .37157 .40937 .36879 Mtetra
.903 .69 .604 r
.40937 .36879 .41048 .37157 .41252 .36895 .41159 .36125 Mtetra
.965 .682 .447 r
.41159 .36125 .41252 .36895 .41463 .36438 .42087 .15129 Mtetra
.514 .278 .494 r
.42087 .15129 .41463 .36438 .42364 .15658 .42285 .14675 Mtetra
.609 .404 .579 r
.42285 .14675 .42364 .15658 .42575 .14778 .42474 .14445 Mtetra
.686 .558 .705 r
.42474 .14445 .42575 .14778 .42768 .14438 .42661 .14293 Mtetra
.693 .727 .876 r
.42661 .14293 .42768 .14438 .42954 .14311 .42846 .14205 Mtetra
.626 .778 .954 r
.42846 .14205 .42954 .14311 .43138 .14256 .43029 .14149 Mtetra
.592 .761 .96 r
.43029 .14149 .43138 .14256 .4332 .14229 .43213 .14104 Mtetra
.673 .756 .913 r
.43213 .14104 .4332 .14229 .43505 .1416 .43398 .14029 Mtetra
.696 .751 .894 r
.43398 .14029 .43505 .1416 .4369 .14075 .43583 .13942 Mtetra
.696 .748 .892 r
.43583 .13942 .4369 .14075 .43875 .13989 .43768 .13855 Mtetra
.724 .754 .876 r
.43768 .13855 .43875 .13989 .4406 .13898 .43954 .1375 Mtetra
.689 .723 .875 r
.43954 .1375 .4406 .13898 .44246 .13818 .44139 .13664 Mtetra
.59 .672 .897 r
.44139 .13664 .44246 .13818 .4443 .13765 .44323 .13624 Mtetra
0 .14 .67 r
.44323 .13624 .4443 .13765 .44612 .13809 .44503 .13781 Mtetra
.915 .52 .223 r
.44503 .13781 .44612 .13809 .44792 .13946 .4467 .14401 Mtetra
.966 .674 .423 r
.4467 .14401 .44792 .13946 .4497 .14197 .44318 .35248 Mtetra
.506 .266 .485 r
.44318 .35248 .4497 .14197 .45151 .1433 .4451 .3545 Mtetra
.501 .262 .484 r
.4451 .3545 .45151 .1433 .45337 .14259 .44709 .35391 Mtetra
.499 .261 .484 r
.44709 .35391 .45337 .14259 .45525 .14103 .4491 .35251 Mtetra
.5 .261 .484 r
.4491 .35251 .45525 .14103 .45714 .13914 .45112 .35118 Mtetra
.45112 .35118 .45714 .13914 .45902 .13787 .45312 .35019 Mtetra
.501 .262 .484 r
.45312 .35019 .45902 .13787 .46087 .13794 .45512 .34976 Mtetra
.505 .265 .484 r
.45512 .34976 .46087 .13794 .45851 .3383 .45708 .35092 Mtetra
.534 .247 .425 r
.45708 .35092 .45851 .3383 .46023 .35095 .45904 .3522 Mtetra
.522 .027 .022 r
.45904 .3522 .46023 .35095 .46216 .354 .46102 .35296 Mtetra
.468 .733 .985 r
.46102 .35296 .46216 .354 .46415 .35441 .46302 .35279 Mtetra
.64 .701 .89 r
.46302 .35279 .46415 .35441 .46616 .35379 .46503 .35212 Mtetra
.67 .706 .875 r
.46503 .35212 .46616 .35379 .46818 .35283 .46704 .35129 Mtetra
.659 .722 .895 r
.46704 .35129 .46818 .35283 .47019 .352 .46906 .35052 Mtetra
.645 .726 .908 r
.46906 .35052 .47019 .352 .47221 .35131 .47107 .34984 Mtetra
.637 .725 .911 r
.47107 .34984 .47221 .35131 .47422 .35064 .47309 .34919 Mtetra
.614 .718 .92 r
.47309 .34919 .47422 .35064 .47624 .35008 .4751 .34864 Mtetra
.601 .715 .924 r
.4751 .34864 .47624 .35008 .47825 .34958 .47712 .34814 Mtetra
.602 .717 .925 r
.47712 .34814 .47825 .34958 .48027 .34907 .47914 .34764 Mtetra
.622 .727 .922 r
.47914 .34764 .48027 .34907 .48229 .34848 .48116 .34706 Mtetra
.637 .734 .919 r
.48116 .34706 .48229 .34848 .48431 .34782 .48318 .34641 Mtetra
.642 .737 .918 r
.48318 .34641 .48431 .34782 .48634 .34714 .48521 .34573 Mtetra
.642 .739 .919 r
.48521 .34573 .48634 .34714 .48836 .34646 .48723 .34506 Mtetra
.642 .739 .92 r
.48723 .34506 .48836 .34646 .49039 .34578 .48926 .34438 Mtetra
.643 .74 .92 r
.48926 .34438 .49039 .34578 .49242 .3451 .49129 .3437 Mtetra
.643 .741 .92 r
.49129 .3437 .49242 .3451 .49445 .34442 .49333 .34302 Mtetra
.644 .741 .92 r
.49333 .34302 .49445 .34442 .49649 .34373 .49536 .34233 Mtetra
.644 .742 .92 r
.49536 .34233 .49649 .34373 .49852 .34304 .49739 .34164 Mtetra
.645 .742 .92 r
.49739 .34164 .49852 .34304 .50055 .34235 .49943 .34095 Mtetra
.49943 .34095 .50055 .34235 .50259 .34166 .50147 .34026 Mtetra
.50147 .34026 .50259 .34166 .50463 .34097 .50351 .33957 Mtetra
.50351 .33957 .50463 .34097 .50667 .34027 .50555 .33887 Mtetra
.646 .742 .919 r
.50555 .33887 .50667 .34027 .50871 .33958 .50759 .33817 Mtetra
.50759 .33817 .50871 .33958 .51076 .33888 .50964 .33748 Mtetra
.50964 .33748 .51076 .33888 .5128 .33818 .51168 .33678 Mtetra
.51168 .33678 .5128 .33818 .51485 .33749 .51373 .33608 Mtetra
.51373 .33608 .51485 .33749 .51689 .33679 .51578 .33538 Mtetra
.51578 .33538 .51689 .33679 .51894 .33609 .51783 .33467 Mtetra
.51783 .33467 .51894 .33609 .52099 .33538 .51988 .33397 Mtetra
.51988 .33397 .52099 .33538 .52305 .33468 .52193 .33327 Mtetra
.52193 .33327 .52305 .33468 .5251 .33398 .52399 .33257 Mtetra
.52399 .33257 .5251 .33398 .52716 .33328 .52604 .33186 Mtetra
.52604 .33186 .52716 .33328 .52921 .33257 .5281 .33116 Mtetra
.5281 .33116 .52921 .33257 .53127 .33187 .53016 .33045 Mtetra
.53016 .33045 .53127 .33187 .53333 .33116 .53222 .32974 Mtetra
.53222 .32974 .53333 .33116 .53539 .33046 .53428 .32904 Mtetra
.53428 .32904 .53539 .33046 .53746 .32975 .53635 .32833 Mtetra
.53635 .32833 .53746 .32975 .53952 .32904 .53841 .32762 Mtetra
.53841 .32762 .53952 .32904 .54159 .32834 .54048 .32691 Mtetra
.54048 .32691 .54159 .32834 .54366 .32763 .54255 .3262 Mtetra
.54255 .3262 .54366 .32763 .54573 .32692 .54462 .32549 Mtetra
.54462 .32549 .54573 .32692 .5478 .32621 .54669 .32478 Mtetra
.54669 .32478 .5478 .32621 .54987 .3255 .54877 .32407 Mtetra
.54877 .32407 .54987 .3255 .55194 .32479 .55084 .32336 Mtetra
.55084 .32336 .55194 .32479 .55402 .32408 .55292 .32265 Mtetra
.55292 .32265 .55402 .32408 .5561 .32337 .555 .32194 Mtetra
.555 .32194 .5561 .32337 .55817 .32265 .55708 .32122 Mtetra
.55708 .32122 .55817 .32265 .56025 .32194 .55916 .32051 Mtetra
.55916 .32051 .56025 .32194 .56234 .32123 .56124 .3198 Mtetra
.56124 .3198 .56234 .32123 .56442 .32051 .56332 .31908 Mtetra
.56332 .31908 .56442 .32051 .5665 .3198 .56541 .31836 Mtetra
.56541 .31836 .5665 .3198 .56859 .31908 .5675 .31765 Mtetra
.647 .742 .919 r
.5675 .31765 .56859 .31908 .57068 .31837 .56959 .31693 Mtetra
.56959 .31693 .57068 .31837 .57277 .31765 .57168 .31621 Mtetra
.57168 .31621 .57277 .31765 .57486 .31693 .57377 .31549 Mtetra
.57377 .31549 .57486 .31693 .57695 .31621 .57586 .31477 Mtetra
.57586 .31477 .57695 .31621 .57905 .31549 .57796 .31405 Mtetra
.57796 .31405 .57905 .31549 .58114 .31477 .58006 .31333 Mtetra
.648 .742 .918 r
.58006 .31333 .58114 .31477 .58324 .31405 .58215 .3126 Mtetra
.58215 .3126 .58324 .31405 .58534 .31332 .58425 .31187 Mtetra
.58425 .31187 .58534 .31332 .58744 .31259 .58636 .31114 Mtetra
.649 .742 .917 r
.58636 .31114 .58744 .31259 .58954 .31186 .58846 .31041 Mtetra
.65 .742 .917 r
.58846 .31041 .58954 .31186 .59165 .31113 .59056 .30967 Mtetra
.65 .741 .916 r
.59056 .30967 .59165 .31113 .59375 .31039 .59267 .30893 Mtetra
.65 .74 .916 r
.59267 .30893 .59375 .31039 .59586 .30966 .59478 .30819 Mtetra
.655 .741 .913 r
.59478 .30819 .59586 .30966 .59797 .30891 .59689 .30742 Mtetra
.667 .745 .908 r
.59689 .30742 .59797 .30891 .60007 .30809 .59899 .3066 Mtetra
.683 .75 .902 r
.59899 .3066 .60007 .30809 .60218 .30718 .6011 .30568 Mtetra
.685 .749 .9 r
.6011 .30568 .60218 .30718 .60429 .30626 .60321 .30475 Mtetra
.676 .744 .902 r
.60321 .30475 .60429 .30626 .6064 .30539 .60532 .30388 Mtetra
.656 .735 .908 r
.60532 .30388 .6064 .30539 .60852 .30463 .60744 .3031 Mtetra
.648 .731 .909 r
.60744 .3031 .60852 .30463 .61063 .3039 .60956 .30237 Mtetra
.645 .729 .91 r
.60956 .30237 .61063 .3039 .61275 .30318 .61168 .30164 Mtetra
.647 .73 .909 r
.61168 .30164 .61275 .30318 .61487 .30244 .6138 .30091 Mtetra
.64 .727 .911 r
.6138 .30091 .61487 .30244 .617 .30173 .61592 .30021 Mtetra
.626 .722 .916 r
.61592 .30021 .617 .30173 .61912 .3011 .61805 .29957 Mtetra
.605 .714 .922 r
.61805 .29957 .61912 .3011 .62126 .30055 .62018 .29904 Mtetra
.603 .714 .923 r
.62018 .29904 .62126 .30055 .62339 .30001 .62232 .29851 Mtetra
.614 .721 .922 r
.62232 .29851 .62339 .30001 .62552 .29942 .62445 .29792 Mtetra
.635 .731 .917 r
.62445 .29792 .62552 .29942 .62766 .29874 .62659 .29725 Mtetra
.642 .735 .917 r
.62659 .29725 .62766 .29874 .62979 .29802 .62872 .29653 Mtetra
.645 .738 .917 r
.62872 .29653 .62979 .29802 .63192 .29729 .63086 .29581 Mtetra
.644 .738 .918 r
.63086 .29581 .63192 .29729 .63406 .29657 .633 .29509 Mtetra
.645 .74 .918 r
.633 .29509 .63406 .29657 .6362 .29584 .63513 .29436 Mtetra
.646 .741 .918 r
.63513 .29436 .6362 .29584 .63834 .2951 .63728 .29363 Mtetra
.647 .742 .918 r
.63728 .29363 .63834 .2951 .64048 .29436 .63942 .29289 Mtetra
.649 .743 .918 r
.63942 .29289 .64048 .29436 .64262 .29361 .64156 .29214 Mtetra
.649 .744 .918 r
.64156 .29214 .64262 .29361 .64476 .29286 .6437 .29139 Mtetra
.649 .744 .919 r
.6437 .29139 .64476 .29286 .64691 .29211 .64585 .29064 Mtetra
.653 .746 .918 r
.64585 .29064 .64691 .29211 .64905 .29133 .648 .28987 Mtetra
.663 .751 .916 r
.648 .28987 .64905 .29133 .6512 .2905 .65015 .28906 Mtetra
.681 .762 .913 r
.65015 .28906 .6512 .2905 .65334 .28955 .65229 .28815 Mtetra
.684 .77 .916 r
.65229 .28815 .65334 .28955 .65548 .28857 .65444 .28722 Mtetra
.68 .777 .924 r
.65444 .28722 .65548 .28857 .65763 .28763 .65658 .28632 Mtetra
.66 .777 .936 r
.65658 .28632 .65763 .28763 .65978 .28681 .65874 .28551 Mtetra
.653 .777 .94 r
.65874 .28551 .65978 .28681 .66193 .28603 .66089 .28474 Mtetra
.649 .778 .942 r
.66089 .28474 .66193 .28603 .66409 .28526 .66305 .28398 Mtetra
.651 .78 .943 r
.66305 .28398 .66409 .28526 .66625 .28449 .66521 .28322 Mtetra
.649 .781 .945 r
.66521 .28322 .66625 .28449 .66841 .28372 .66737 .28246 Mtetra
.646 .783 .947 r
.66737 .28246 .66841 .28372 .67057 .28296 .66954 .28171 Mtetra
.642 .783 .949 r
.66954 .28171 .67057 .28296 .67274 .28221 .6717 .28098 Mtetra
.639 .786 .952 r
.6717 .28098 .67274 .28221 .6749 .28147 .67387 .28025 Mtetra
.625 .782 .957 r
.67387 .28025 .6749 .28147 .67707 .28078 .67605 .27959 Mtetra
.533 .746 .973 r
.67605 .27959 .67707 .28078 .67926 .28029 .67824 .27924 Mtetra
.618 .813 .975 r
.67824 .27924 .67926 .28029 .68143 .27963 .68041 .27857 Mtetra
.776 .862 .913 r
.68041 .27857 .68143 .27963 .68359 .27858 .68255 .27715 Mtetra
.937 .807 .69 r
.68255 .27715 .68359 .27858 .6857 .2766 .68456 .27304 Mtetra
.94 .686 .524 r
.68456 .27304 .6857 .2766 .68776 .27362 .68617 .26154 Mtetra
.972 .662 .351 r
.68617 .26154 .68776 .27362 .68968 .26808 .67726 .0518 Mtetra
.511 .275 .493 r
.67726 .0518 .68968 .26808 .68045 .05639 .67914 .04842 Mtetra
.613 .419 .596 r
.67914 .04842 .68045 .05639 .68214 .0495 .68109 .04642 Mtetra
.678 .574 .731 r
.68109 .04642 .68214 .0495 .68404 .04645 .68308 .04508 Mtetra
.678 .759 .913 r
.68308 .04508 .68404 .04645 .68604 .04539 .6851 .04424 Mtetra
.622 .78 .957 r
.6851 .04424 .68604 .04539 .68807 .04481 .68713 .04363 Mtetra
.601 .763 .957 r
.68713 .04363 .68807 .04481 .69012 .04445 .68917 .0431 Mtetra
.667 .758 .919 r
.68917 .0431 .69012 .04445 .69214 .04368 .69119 .04231 Mtetra
.675 .759 .914 r
.69119 .04231 .69214 .04368 .69417 .04287 .69322 .04148 Mtetra
.684 .758 .908 r
.69322 .04148 .69417 .04287 .69619 .04202 .69524 .0406 Mtetra
.77 .785 .865 r
.69524 .0406 .69619 .04202 .69818 .04063 .69723 .0392 Mtetra
.702 .759 .896 r
.69723 .0392 .69818 .04063 .7002 .03966 .69925 .03822 Mtetra
.51 .668 .934 r
.69925 .03822 .7002 .03966 .70227 .0395 .70132 .03806 Mtetra
.745 .329 0 r
.70132 .03806 .70227 .0395 .70467 .04453 .70371 .04307 Mtetra
.97 .655 .291 r
.70371 .04307 .70467 .04453 .72042 .25995 .71941 .25853 Mtetra
.728 .299 0 r
.71941 .25853 .72042 .25995 .72298 .26484 .72197 .26344 Mtetra
.054 .474 .886 r
.02549 .50081 .02682 .50191 .02835 .50244 .02703 .50135 Mtetra
.647 .76 .931 r
.02703 .50135 .02835 .50244 .03005 .50185 .02873 .50076 Mtetra
.81 .776 .822 r
.02873 .50076 .03005 .50185 .03192 .50014 .0306 .49905 Mtetra
.908 .736 .657 r
.0306 .49905 .03192 .50014 .03442 .49418 .03311 .49305 Mtetra
.937 .686 .534 r
.03311 .49305 .03442 .49418 .06659 .28691 .06538 .28572 Mtetra
.906 .725 .647 r
.06538 .28572 .06659 .28691 .06901 .28075 .0678 .27959 Mtetra
.774 .757 .838 r
.0678 .27959 .06901 .28075 .07072 .27944 .0695 .27829 Mtetra
.636 .732 .918 r
.0695 .27829 .07072 .27944 .07231 .27892 .07109 .27778 Mtetra
.499 .686 .951 r
.07109 .27778 .07231 .27892 .07385 .2788 .07263 .27766 Mtetra
.738 .757 .868 r
.07263 .27766 .07385 .2788 .07552 .27773 .0743 .27665 Mtetra
.691 .758 .903 r
.0743 .27665 .07552 .27773 .07715 .27698 .07592 .27591 Mtetra
.472 .691 .963 r
.07592 .27591 .07715 .27698 .07868 .27694 .07746 .27583 Mtetra
.92 .528 .223 r
.07746 .27583 .07868 .27694 .07955 .28148 .07844 .27962 Mtetra
.94 .684 .522 r
.07844 .27962 .07955 .28148 .05152 .48815 .0505 .48502 Mtetra
.947 .623 .196 r
.0505 .48502 .05152 .48815 .05243 .49321 .05126 .4911 Mtetra
.345 .463 .837 r
.05126 .4911 .05243 .49321 .05405 .49334 .05283 .49159 Mtetra
.624 .648 .854 r
.05283 .49159 .05405 .49334 .05581 .49248 .05454 .49107 Mtetra
.711 .724 .86 r
.05454 .49107 .05581 .49248 .05763 .49115 .05631 .49011 Mtetra
.659 .776 .935 r
.05631 .49011 .05763 .49115 .05936 .49055 .05804 .48947 Mtetra
.655 .766 .931 r
.05804 .48947 .05936 .49055 .06107 .48999 .05977 .48884 Mtetra
.658 .754 .921 r
.05977 .48884 .06107 .48999 .06282 .48924 .0615 .4882 Mtetra
.463 .711 .976 r
.0615 .4882 .06282 .48924 .06463 .48801 .06316 .4881 Mtetra
.286 .787 .84 r
.06316 .4881 .06463 .48801 .06653 .48617 .06486 .48771 Mtetra
0 0 0 r
.06486 .48771 .06653 .48617 .0686 .48309 .06666 .4866 Mtetra
.841 .891 .467 r
.06666 .4866 .0686 .48309 .07329 .46095 .06902 .4814 Mtetra
.962 .715 .516 r
.06902 .4814 .07329 .46095 .10085 .27176 .09919 .27395 Mtetra
.993 .874 .595 r
.09919 .27395 .10085 .27176 .10292 .26796 .10169 .26693 Mtetra
.811 .78 .824 r
.10169 .26693 .10292 .26796 .10463 .26668 .10346 .26532 Mtetra
.642 .7 .888 r
.10346 .26532 .10463 .26668 .10625 .26612 .10507 .26477 Mtetra
.518 .654 .92 r
.10507 .26477 .10625 .26612 .10783 .26587 .10664 .26465 Mtetra
.639 .722 .908 r
.10664 .26465 .10783 .26587 .10947 .26518 .10825 .26412 Mtetra
.67 .76 .918 r
.10825 .26412 .10947 .26518 .11111 .26447 .10989 .26347 Mtetra
.672 .774 .926 r
.10989 .26347 .11111 .26447 .11273 .26394 .11153 .26281 Mtetra
.742 .761 .868 r
.11153 .26281 .11273 .26394 .1143 .26382 .11322 .26176 Mtetra
.67 .621 .791 r
.11322 .26176 .1143 .26382 .11579 .26425 .11488 .26092 Mtetra
.555 .471 .714 r
.11488 .26092 .11579 .26425 .11714 .2658 .11647 .26068 Mtetra
.029 .036 .529 r
.11647 .26068 .11714 .2658 .09382 .45495 .11765 .26349 Mtetra
0 0 0 r
.11765 .26349 .09382 .45495 .09277 .47557 .09237 .46763 Mtetra
0 0 .103 r
.09237 .46763 .09277 .47557 .09405 .47855 .09293 .47604 Mtetra
.205 .331 .771 r
.09293 .47604 .09405 .47855 .0957 .4787 .09447 .47704 Mtetra
.602 .654 .874 r
.09447 .47704 .0957 .4787 .09747 .47789 .0962 .47662 Mtetra
.709 .748 .882 r
.0962 .47662 .09747 .47789 .0993 .47671 .09799 .4757 Mtetra
.681 .789 .931 r
.09799 .4757 .0993 .47671 .10107 .47596 .09976 .47495 Mtetra
.666 .786 .938 r
.09976 .47495 .10107 .47596 .10281 .47543 .10152 .47427 Mtetra
.672 .758 .916 r
.10152 .47427 .10281 .47543 .10455 .47493 .10329 .47356 Mtetra
.661 .72 .892 r
.10329 .47356 .10455 .47493 .1063 .47437 .10505 .47288 Mtetra
.652 .7 .881 r
.10505 .47288 .1063 .47437 .10805 .47377 .10681 .47224 Mtetra
.645 .691 .879 r
.10681 .47224 .10805 .47377 .10981 .47314 .10857 .47163 Mtetra
.627 .687 .887 r
.10857 .47163 .10981 .47314 .11158 .47247 .11032 .4711 Mtetra
.62 .709 .909 r
.11032 .4711 .11158 .47247 .11335 .47179 .11206 .4706 Mtetra
.624 .742 .931 r
.11206 .4706 .11335 .47179 .11511 .47117 .11381 .47009 Mtetra
.522 .728 .968 r
.11381 .47009 .11511 .47117 .11679 .47118 .11553 .46986 Mtetra
.599 .711 .922 r
.11553 .46986 .11679 .47118 .11849 .4711 .11727 .46944 Mtetra
.717 .696 .829 r
.11727 .46944 .11849 .4711 .12027 .47035 .11909 .46834 Mtetra
.861 .698 .678 r
.11909 .46834 .12027 .47035 .12243 .46651 .12132 .46399 Mtetra
.944 .687 .517 r
.12132 .46399 .12243 .46651 .14908 .2617 .14829 .2572 Mtetra
.846 .624 .602 r
.14829 .2572 .14908 .2617 .15211 .24983 .15093 .24859 Mtetra
.835 .754 .774 r
.15093 .24859 .15211 .24983 .15397 .24753 .15277 .24644 Mtetra
.683 .762 .912 r
.15277 .24644 .15397 .24753 .15564 .24682 .15444 .24572 Mtetra
.553 .721 .952 r
.15444 .24572 .15564 .24682 .15725 .2466 .15606 .24545 Mtetra
.706 .757 .892 r
.15606 .24545 .15725 .2466 .15893 .2458 .15775 .24461 Mtetra
.722 .754 .878 r
.15775 .24461 .15893 .2458 .16063 .24488 .15945 .24367 Mtetra
.587 .712 .93 r
.15945 .24367 .16063 .24488 .16225 .24456 .16108 .24331 Mtetra
.783 .312 0 r
.16108 .24331 .16225 .24456 .16354 .24713 .16239 .24564 Mtetra
.949 .685 .502 r
.16239 .24564 .16354 .24713 .14094 .45353 .13992 .45027 Mtetra
.973 .663 .307 r
.13992 .45027 .14094 .45353 .1417 .46167 .14048 .45998 Mtetra
0 .021 .572 r
.14048 .45998 .1417 .46167 .14323 .46314 .14199 .46164 Mtetra
.546 .662 .912 r
.14199 .46164 .14323 .46314 .14499 .46277 .14373 .46142 Mtetra
.758 .749 .844 r
.14373 .46142 .14499 .46277 .14687 .46132 .1456 .46011 Mtetra
.893 .757 .704 r
.1456 .46011 .14687 .46132 .14906 .45712 .14776 .45616 Mtetra
.948 .689 .51 r
.14776 .45616 .14906 .45712 .17441 .24997 .17293 .25132 Mtetra
.981 .781 .562 r
.17293 .25132 .17441 .24997 .17716 .23986 .17593 .23913 Mtetra
.888 .817 .773 r
.17593 .23913 .17716 .23986 .17903 .23749 .17782 .23658 Mtetra
.705 .805 .927 r
.17782 .23658 .17903 .23749 .18071 .23683 .17952 .23577 Mtetra
.558 .734 .958 r
.17952 .23577 .18071 .23683 .18233 .23664 .18116 .23548 Mtetra
.656 .745 .915 r
.18116 .23548 .18233 .23664 .18402 .23597 .18283 .23486 Mtetra
.693 .764 .906 r
.18283 .23486 .18402 .23597 .18573 .23498 .18453 .23409 Mtetra
.519 .756 .982 r
.18453 .23409 .18573 .23498 .18741 .23437 .18616 .23384 Mtetra
.782 .279 0 r
.18616 .23384 .18741 .23437 .18894 .23514 .18755 .23584 Mtetra
.949 .682 .498 r
.18755 .23584 .18894 .23514 .19016 .23873 .1671 .43686 Mtetra
.532 .288 .491 r
.1671 .43686 .19016 .23873 .16956 .44286 .1674 .4499 Mtetra
.582 .269 .403 r
.1674 .4499 .16956 .44286 .17059 .44926 .16894 .4516 Mtetra
.33 0 .088 r
.16894 .4516 .17059 .44926 .17216 .45082 .17072 .45121 Mtetra
.505 .908 .817 r
.17072 .45121 .17216 .45082 .17384 .45132 .17256 .45025 Mtetra
.632 .773 .948 r
.17256 .45025 .17384 .45132 .17557 .45131 .17436 .44968 Mtetra
.565 .65 .892 r
.17436 .44968 .17557 .45131 .17736 .45086 .17612 .4494 Mtetra
.696 .723 .871 r
.17612 .4494 .17736 .45086 .17921 .44979 .17796 .4485 Mtetra
.879 .758 .725 r
.17796 .4485 .17921 .44979 .18122 .4473 .18006 .44514 Mtetra
.95 .688 .504 r
.18006 .44514 .18122 .4473 .18357 .44142 .203 .24324 Mtetra
.543 .302 .501 r
.203 .24324 .18357 .44142 .20673 .23552 .20624 .22785 Mtetra
.656 .455 .6 r
.20624 .22785 .20673 .23552 .209 .2294 .20816 .22504 Mtetra
.6 .464 .667 r
.20816 .22504 .209 .2294 .21088 .22697 .20987 .22424 Mtetra
.561 .514 .76 r
.20987 .22424 .21088 .22697 .21267 .2254 .21153 .22399 Mtetra
.557 .666 .91 r
.21153 .22399 .21267 .2254 .2144 .22447 .21319 .22374 Mtetra
.599 .823 .985 r
.21319 .22374 .2144 .22447 .21608 .224 .21487 .22326 Mtetra
.601 .82 .984 r
.21487 .22326 .21608 .224 .21774 .22372 .21655 .22277 Mtetra
.632 .782 .953 r
.21655 .22277 .21774 .22372 .21941 .22336 .21825 .22222 Mtetra
.654 .753 .923 r
.21825 .22222 .21941 .22336 .22111 .22276 .21994 .22161 Mtetra
.662 .752 .917 r
.21994 .22161 .22111 .22276 .22282 .22212 .22165 .22097 Mtetra
.72 .767 .89 r
.22165 .22097 .22282 .22212 .22455 .22116 .22338 .22004 Mtetra
.743 .776 .879 r
.22338 .22004 .22455 .22116 .2263 .22007 .22513 .21897 Mtetra
.635 .755 .935 r
.22513 .21897 .2263 .22007 .228 .21954 .22683 .21843 Mtetra
0 .035 .527 r
.22683 .21843 .228 .21954 .22948 .22114 .22834 .21983 Mtetra
.958 .668 .445 r
.22834 .21983 .22948 .22114 .21152 .42438 .22753 .24519 Mtetra
0 0 .073 r
.22753 .24519 .21152 .42438 .21209 .43679 .21094 .43451 Mtetra
0 0 .553 r
.21094 .43451 .21209 .43679 .21367 .43877 .2125 .43667 Mtetra
.593 .604 .832 r
.2125 .43667 .21367 .43877 .21548 .43834 .21431 .43626 Mtetra
.691 .648 .803 r
.21431 .43626 .21548 .43834 .21735 .43732 .21618 .43521 Mtetra
.699 .65 .797 r
.21618 .43521 .21735 .43732 .21922 .43624 .21806 .43409 Mtetra
.655 .626 .809 r
.21806 .43409 .21922 .43624 .22107 .4355 .21991 .43329 Mtetra
.648 .618 .806 r
.21991 .43329 .22107 .4355 .22291 .43474 .22176 .43253 Mtetra
.629 .609 .812 r
.22176 .43253 .22291 .43474 .22477 .43392 .2236 .4319 Mtetra
.604 .617 .838 r
.2236 .4319 .22477 .43392 .22663 .43304 .22542 .43143 Mtetra
.602 .671 .889 r
.22542 .43143 .22663 .43304 .22849 .4322 .22724 .43099 Mtetra
.614 .744 .938 r
.22724 .43099 .22849 .4322 .23033 .43151 .22907 .43049 Mtetra
.639 .787 .953 r
.22907 .43049 .23033 .43151 .23216 .43103 .23091 .42987 Mtetra
.647 .763 .934 r
.23091 .42987 .23216 .43103 .23398 .43061 .23276 .42924 Mtetra
.641 .725 .909 r
.23276 .42924 .23398 .43061 .23581 .43022 .2346 .42862 Mtetra
.629 .685 .884 r
.2346 .42862 .23581 .43022 .23763 .42982 .23644 .42806 Mtetra
.625 .66 .864 r
.23644 .42806 .23763 .42982 .23948 .42922 .23828 .4275 Mtetra
.628 .667 .868 r
.23828 .4275 .23948 .42922 .24137 .42809 .24013 .42692 Mtetra
.636 .761 .938 r
.24013 .42692 .24137 .42809 .24334 .42603 .24197 .42633 Mtetra
.292 .786 .759 r
.24197 .42633 .24334 .42603 .24536 .42344 .24382 .42573 Mtetra
.276 0 .05 r
.24382 .42573 .24536 .42344 .24736 .421 .24567 .42514 Mtetra
.385 .036 .245 r
.24567 .42514 .24736 .421 .24923 .42015 .24752 .42456 Mtetra
.393 .05 .26 r
.24752 .42456 .24923 .42015 .25106 .41987 .24937 .42398 Mtetra
.383 .033 .243 r
.24937 .42398 .25106 .41987 .25287 .41964 .25122 .42339 Mtetra
.367 .008 .218 r
.25122 .42339 .25287 .41964 .25472 .41908 .25308 .42278 Mtetra
.363 .003 .213 r
.25308 .42278 .25472 .41908 .25657 .41851 .25494 .42216 Mtetra
.359 0 .208 r
.25494 .42216 .25657 .41851 .25843 .41793 .2568 .42153 Mtetra
.356 0 .203 r
.2568 .42153 .25843 .41793 .26028 .41734 .25866 .42089 Mtetra
.352 0 .198 r
.25866 .42089 .26028 .41734 .26214 .41673 .26053 .42024 Mtetra
.373 .007 .206 r
.26053 .42024 .26214 .41673 .26398 .41635 .26238 .41973 Mtetra
.413 .039 .217 r
.26238 .41973 .26398 .41635 .26579 .41639 .26421 .41949 Mtetra
.316 0 .15 r
.26421 .41949 .26579 .41639 .26766 .41567 .26609 .41878 Mtetra
0 0 0 r
.26609 .41878 .26766 .41567 .26972 .41254 .26807 .41669 Mtetra
.879 .846 .386 r
.26807 .41669 .26972 .41254 .28776 .20542 .27051 .40879 Mtetra
0 0 .116 r
.27051 .40879 .28776 .20542 .29008 .19741 .28876 .19861 Mtetra
.975 .922 .618 r
.28876 .19861 .29008 .19741 .29201 .19439 .29082 .19399 Mtetra
.764 .925 .941 r
.29082 .19399 .29201 .19439 .29379 .1934 .2926 .19285 Mtetra
.558 .853 .997 r
.2926 .19285 .29379 .1934 .29553 .19286 .29434 .19237 Mtetra
.422 .808 .99 r
.29434 .19237 .29553 .19286 .29726 .19245 .29606 .19211 Mtetra
.577 .898 .985 r
.29606 .19211 .29726 .19245 .29902 .19178 .29781 .19149 Mtetra
.569 .904 .979 r
.29781 .19149 .29902 .19178 .30077 .19113 .29957 .19086 Mtetra
.598 .916 .976 r
.29957 .19086 .30077 .19113 .30252 .19054 .30133 .19016 Mtetra
.678 .921 .973 r
.30133 .19016 .30252 .19054 .30427 .19002 .3031 .18931 Mtetra
.707 .86 .955 r
.3031 .18931 .30427 .19002 .30601 .1895 .30487 .18845 Mtetra
.697 .788 .921 r
.30487 .18845 .30601 .1895 .30777 .18891 .30664 .18764 Mtetra
.665 .738 .904 r
.30664 .18764 .30777 .18891 .30954 .18813 .30841 .18695 Mtetra
.658 .753 .921 r
.30841 .18695 .30954 .18813 .31131 .18731 .31017 .1863 Mtetra
.654 .786 .945 r
.31017 .1863 .31131 .18731 .31308 .1865 .31193 .18566 Mtetra
.653 .822 .964 r
.31193 .18566 .31308 .1865 .31485 .18579 .31369 .18501 Mtetra
.653 .833 .97 r
.31369 .18501 .31485 .18579 .31662 .1851 .31546 .18435 Mtetra
.657 .84 .971 r
.31546 .18435 .31662 .1851 .31839 .18439 .31723 .18367 Mtetra
.668 .85 .97 r
.31723 .18367 .31839 .18439 .32017 .18354 .319 .18294 Mtetra
.658 .875 .98 r
.319 .18294 .32017 .18354 .32194 .18282 .32077 .18222 Mtetra
.674 .878 .975 r
.32077 .18222 .32194 .18282 .32369 .18238 .32255 .18145 Mtetra
.752 .824 .908 r
.32255 .18145 .32369 .18238 .32541 .18248 .32435 .18036 Mtetra
.641 .612 .806 r
.32435 .18036 .32541 .18248 .32709 .1833 .32612 .17967 Mtetra
.482 .417 .707 r
.32612 .17967 .32709 .1833 .32864 .18599 .32784 .17993 Mtetra
0 0 .419 r
.32784 .17993 .32864 .18599 .31702 .39266 .32923 .18508 Mtetra
0 0 .17 r
.32923 .18508 .31702 .39266 .31842 .3997 .31743 .39506 Mtetra
0 0 .414 r
.31743 .39506 .31842 .3997 .32015 .40181 .319 .39958 Mtetra
.517 .556 .834 r
.319 .39958 .32015 .40181 .32203 .4016 .32087 .39953 Mtetra
.658 .642 .822 r
.32087 .39953 .32203 .4016 .32394 .40084 .32279 .39871 Mtetra
.695 .652 .803 r
.32279 .39871 .32394 .40084 .32587 .39985 .32473 .3976 Mtetra
.591 .592 .821 r
.32473 .3976 .32587 .39985 .32777 .39935 .32663 .39717 Mtetra
.592 .6 .828 r
.32663 .39717 .32777 .39935 .32968 .39871 .32852 .39674 Mtetra
.599 .627 .851 r
.32852 .39674 .32968 .39871 .33161 .39779 .33043 .39629 Mtetra
.528 .664 .923 r
.33043 .39629 .33161 .39779 .33358 .3963 .33231 .3961 Mtetra
.507 .893 .957 r
.33231 .3961 .33358 .3963 .33558 .3941 .33423 .39546 Mtetra
0 0 0 r
.33423 .39546 .33558 .3941 .33768 .39029 .3362 .39396 Mtetra
.741 .794 .308 r
.3362 .39396 .33768 .39029 .35148 .18356 .33843 .38791 Mtetra
0 0 .161 r
.33843 .38791 .35148 .18356 .35381 .17358 .35247 .17638 Mtetra
.909 .869 .432 r
.35247 .17638 .35381 .17358 .35576 .17017 .3546 .16986 Mtetra
.824 .948 .902 r
.3546 .16986 .35576 .17017 .35757 .16919 .35644 .16837 Mtetra
.676 .835 .96 r
.35644 .16837 .35757 .16919 .35935 .16876 .35824 .16762 Mtetra
.573 .734 .951 r
.35824 .16762 .35935 .16876 .36112 .16862 .36002 .16725 Mtetra
.653 .723 .9 r
.36002 .16725 .36112 .16862 .36291 .16801 .36181 .1666 Mtetra
.642 .712 .898 r
.36181 .1666 .36291 .16801 .36471 .16735 .36361 .166 Mtetra
.64 .721 .906 r
.36361 .166 .36471 .16735 .36651 .16663 .3654 .16541 Mtetra
.664 .752 .915 r
.3654 .16541 .36651 .16663 .36832 .16562 .3672 .16471 Mtetra
.667 .815 .954 r
.3672 .16471 .36832 .16562 .37014 .16473 .36901 .164 Mtetra
.66 .852 .974 r
.36901 .164 .37014 .16473 .37194 .1641 .37081 .16329 Mtetra
.653 .833 .969 r
.37081 .16329 .37194 .1641 .37368 .16454 .37262 .16261 Mtetra
.642 .637 .829 r
.37262 .16261 .37368 .16454 .3754 .16559 .37442 .16194 Mtetra
.6 .491 .702 r
.37442 .16194 .3754 .16559 .3771 .16723 .37623 .16126 Mtetra
.57 .412 .628 r
.37623 .16126 .3771 .16723 .37885 .16773 .37804 .16057 Mtetra
.561 .39 .606 r
.37804 .16057 .37885 .16773 .38066 .16706 .37985 .15986 Mtetra
.561 .389 .606 r
.37985 .15986 .38066 .16706 .38253 .16526 .38166 .15914 Mtetra
.571 .411 .625 r
.38166 .15914 .38253 .16526 .38445 .16223 .38348 .1584 Mtetra
.603 .487 .693 r
.38348 .1584 .38445 .16223 .38635 .15972 .38529 .15765 Mtetra
.65 .625 .811 r
.38529 .15765 .38635 .15972 .38822 .1578 .38711 .1569 Mtetra
.68 .822 .951 r
.38711 .1569 .38822 .1578 .39005 .15693 .38893 .15613 Mtetra
.67 .842 .965 r
.38893 .15613 .39005 .15693 .39186 .15637 .39075 .15539 Mtetra
.664 .803 .949 r
.39075 .15539 .39186 .15637 .39366 .1559 .39257 .15469 Mtetra
.726 .774 .891 r
.39257 .15469 .39366 .1559 .3955 .15477 .3944 .15368 Mtetra
.665 .78 .935 r
.3944 .15368 .3955 .15477 .39733 .1538 .39622 .15298 Mtetra
.365 .71 .986 r
.39622 .15298 .39733 .1538 .39914 .15333 .39802 .15297 Mtetra
.883 .453 .148 r
.39802 .15297 .39914 .15333 .40087 .15503 .39963 .15717 Mtetra
.966 .679 .436 r
.39963 .15717 .40087 .15503 .40239 .16161 .39269 .36814 Mtetra
.513 .272 .486 r
.39269 .36814 .40239 .16161 .39579 .36949 .3944 .37363 Mtetra
.506 .147 .292 r
.3944 .37363 .39579 .36949 .3976 .37255 .39631 .3741 Mtetra
.176 0 0 r
.39631 .3741 .3976 .37255 .39949 .37357 .39827 .37348 Mtetra
.661 .962 .931 r
.39827 .37348 .39949 .37357 .40142 .37381 .40025 .37238 Mtetra
.599 .711 .923 r
.40025 .37238 .40142 .37381 .40336 .37377 .40221 .37191 Mtetra
.645 .666 .855 r
.40221 .37191 .40336 .37377 .40532 .37323 .40418 .3712 Mtetra
.736 .683 .799 r
.40418 .3712 .40532 .37323 .40731 .37204 .40618 .36974 Mtetra
.894 .708 .643 r
.40618 .36974 .40731 .37204 .40937 .36879 .40833 .36424 Mtetra
.968 .685 .444 r
.40833 .36424 .40937 .36879 .41159 .36125 .41791 .15175 Mtetra
.52 .282 .495 r
.41791 .15175 .41159 .36125 .42087 .15129 .41998 .14471 Mtetra
.628 .445 .615 r
.41998 .14471 .42087 .15129 .42285 .14675 .42186 .14287 Mtetra
.602 .485 .693 r
.42186 .14287 .42285 .14675 .42474 .14445 .4237 .14213 Mtetra
.575 .564 .804 r
.4237 .14213 .42474 .14445 .42661 .14293 .42552 .1418 Mtetra
.648 .769 .937 r
.42552 .1418 .42661 .14293 .42846 .14205 .42736 .14116 Mtetra
.664 .824 .96 r
.42736 .14116 .42846 .14205 .43029 .14149 .42921 .14044 Mtetra
.658 .789 .945 r
.42921 .14044 .43029 .14149 .43213 .14104 .43105 .13975 Mtetra
.635 .736 .921 r
.43105 .13975 .43213 .14104 .43398 .14029 .4329 .13917 Mtetra
.621 .763 .947 r
.4329 .13917 .43398 .14029 .43583 .13942 .43474 .13863 Mtetra
.6 .826 .986 r
.43474 .13863 .43583 .13942 .43768 .13855 .43658 .13808 Mtetra
.729 .928 .957 r
.43658 .13808 .43768 .13855 .43954 .1375 .43844 .13703 Mtetra
.694 .919 .97 r
.43844 .13703 .43954 .1375 .44139 .13664 .4403 .1361 Mtetra
.44 .812 .993 r
.4403 .1361 .44139 .13664 .44323 .13624 .44214 .13581 Mtetra
.825 .348 .004 r
.44214 .13581 .44323 .13624 .44503 .13781 .44389 .13892 Mtetra
.97 .678 .419 r
.44389 .13892 .44503 .13781 .4467 .14401 .44009 .34992 Mtetra
.516 .274 .486 r
.44009 .34992 .4467 .14401 .44318 .35248 .44188 .35688 Mtetra
.539 .182 .311 r
.44188 .35688 .44318 .35248 .4451 .3545 .44383 .35774 Mtetra
.355 0 .181 r
.44383 .35774 .4451 .3545 .44709 .35391 .44583 .35715 Mtetra
.269 0 .145 r
.44583 .35715 .44709 .35391 .4491 .35251 .44784 .35607 Mtetra
.328 0 .191 r
.44784 .35607 .4491 .35251 .45112 .35118 .44984 .3552 Mtetra
.367 .017 .233 r
.44984 .3552 .45112 .35118 .45312 .35019 .45185 .35447 Mtetra
.375 .031 .248 r
.45185 .35447 .45312 .35019 .45512 .34976 .45385 .35373 Mtetra
.368 .016 .23 r
.45385 .35373 .45512 .34976 .45708 .35092 .45586 .35301 Mtetra
.244 0 .013 r
.45586 .35301 .45708 .35092 .45904 .3522 .45787 .35232 Mtetra
.372 .839 .827 r
.45787 .35232 .45904 .3522 .46102 .35296 .45987 .35162 Mtetra
.65 .752 .924 r
.45987 .35162 .46102 .35296 .46302 .35279 .46188 .35092 Mtetra
.643 .667 .858 r
.46188 .35092 .46302 .35279 .46503 .35212 .4639 .3502 Mtetra
.641 .661 .853 r
.4639 .3502 .46503 .35212 .46704 .35129 .46591 .34949 Mtetra
.636 .675 .87 r
.46591 .34949 .46704 .35129 .46906 .35052 .46792 .34883 Mtetra
.636 .689 .883 r
.46792 .34883 .46906 .35052 .47107 .34984 .46994 .34818 Mtetra
.641 .697 .886 r
.46994 .34818 .47107 .34984 .47309 .34919 .47195 .3475 Mtetra
.662 .701 .876 r
.47195 .3475 .47309 .34919 .4751 .34864 .47397 .3467 Mtetra
.666 .67 .845 r
.47397 .3467 .4751 .34864 .47712 .34814 .476 .34584 Mtetra
.653 .624 .809 r
.476 .34584 .47712 .34814 .47914 .34764 .47802 .34497 Mtetra
.627 .58 .782 r
.47802 .34497 .47914 .34764 .48116 .34706 .48004 .34423 Mtetra
.611 .56 .772 r
.48004 .34423 .48116 .34706 .48318 .34641 .48207 .34358 Mtetra
.608 .558 .773 r
.48207 .34358 .48318 .34641 .48521 .34573 .48409 .34296 Mtetra
.611 .564 .776 r
.48409 .34296 .48521 .34573 .48723 .34506 .48612 .34231 Mtetra
.615 .568 .778 r
.48612 .34231 .48723 .34506 .48926 .34438 .48815 .34164 Mtetra
.616 .569 .779 r
.48815 .34164 .48926 .34438 .49129 .3437 .49018 .34097 Mtetra
.617 .57 .78 r
.49018 .34097 .49129 .3437 .49333 .34302 .49221 .34029 Mtetra
.617 .571 .78 r
.49221 .34029 .49333 .34302 .49536 .34233 .49424 .33961 Mtetra
.618 .572 .78 r
.49424 .33961 .49536 .34233 .49739 .34164 .49628 .33892 Mtetra
.49628 .33892 .49739 .34164 .49943 .34095 .49832 .33823 Mtetra
.619 .573 .781 r
.49832 .33823 .49943 .34095 .50147 .34026 .50035 .33754 Mtetra
.50035 .33754 .50147 .34026 .50351 .33957 .50239 .33685 Mtetra
.50239 .33685 .50351 .33957 .50555 .33887 .50443 .33615 Mtetra
.50443 .33615 .50555 .33887 .50759 .33817 .50648 .33545 Mtetra
.50648 .33545 .50759 .33817 .50964 .33748 .50852 .33475 Mtetra
.619 .574 .781 r
.50852 .33475 .50964 .33748 .51168 .33678 .51057 .33406 Mtetra
.51057 .33406 .51168 .33678 .51373 .33608 .51261 .33335 Mtetra
.62 .574 .781 r
.51261 .33335 .51373 .33608 .51578 .33538 .51466 .33265 Mtetra
.51466 .33265 .51578 .33538 .51783 .33467 .51671 .33195 Mtetra
.51671 .33195 .51783 .33467 .51988 .33397 .51876 .33125 Mtetra
.51876 .33125 .51988 .33397 .52193 .33327 .52082 .33054 Mtetra
.52082 .33054 .52193 .33327 .52399 .33257 .52287 .32984 Mtetra
.52287 .32984 .52399 .33257 .52604 .33186 .52493 .32913 Mtetra
.52493 .32913 .52604 .33186 .5281 .33116 .52699 .32843 Mtetra
.52699 .32843 .5281 .33116 .53016 .33045 .52905 .32772 Mtetra
.52905 .32772 .53016 .33045 .53222 .32974 .53111 .32701 Mtetra
.53111 .32701 .53222 .32974 .53428 .32904 .53317 .3263 Mtetra
.53317 .3263 .53428 .32904 .53635 .32833 .53524 .3256 Mtetra
.53524 .3256 .53635 .32833 .53841 .32762 .5373 .32489 Mtetra
.5373 .32489 .53841 .32762 .54048 .32691 .53937 .32418 Mtetra
.53937 .32418 .54048 .32691 .54255 .3262 .54144 .32347 Mtetra
.54144 .32347 .54255 .3262 .54462 .32549 .54351 .32276 Mtetra
.54351 .32276 .54462 .32549 .54669 .32478 .54558 .32204 Mtetra
.54558 .32204 .54669 .32478 .54877 .32407 .54765 .32133 Mtetra
.54765 .32133 .54877 .32407 .55084 .32336 .54973 .32062 Mtetra
.54973 .32062 .55084 .32336 .55292 .32265 .5518 .31991 Mtetra
.5518 .31991 .55292 .32265 .555 .32194 .55388 .31919 Mtetra
.55388 .31919 .555 .32194 .55708 .32122 .55596 .31848 Mtetra
.55596 .31848 .55708 .32122 .55916 .32051 .55804 .31776 Mtetra
.55804 .31776 .55916 .32051 .56124 .3198 .56013 .31705 Mtetra
.56013 .31705 .56124 .3198 .56332 .31908 .56221 .31633 Mtetra
.56221 .31633 .56332 .31908 .56541 .31836 .5643 .31561 Mtetra
.5643 .31561 .56541 .31836 .5675 .31765 .56638 .31489 Mtetra
.56638 .31489 .5675 .31765 .56959 .31693 .56847 .31418 Mtetra
.56847 .31418 .56959 .31693 .57168 .31621 .57056 .31345 Mtetra
.57056 .31345 .57168 .31621 .57377 .31549 .57266 .31273 Mtetra
.57266 .31273 .57377 .31549 .57586 .31477 .57475 .31201 Mtetra
.62 .574 .78 r
.57475 .31201 .57586 .31477 .57796 .31405 .57685 .31129 Mtetra
.621 .574 .78 r
.57685 .31129 .57796 .31405 .58006 .31333 .57894 .31056 Mtetra
.57894 .31056 .58006 .31333 .58215 .3126 .58104 .30983 Mtetra
.58104 .30983 .58215 .3126 .58425 .31187 .58314 .30909 Mtetra
.622 .574 .779 r
.58314 .30909 .58425 .31187 .58636 .31114 .58524 .30836 Mtetra
.58524 .30836 .58636 .31114 .58846 .31041 .58735 .30761 Mtetra
.623 .573 .778 r
.58735 .30761 .58846 .31041 .59056 .30967 .58945 .30686 Mtetra
.625 .574 .777 r
.58945 .30686 .59056 .30967 .59267 .30893 .59156 .30609 Mtetra
.627 .573 .774 r
.59156 .30609 .59267 .30893 .59478 .30819 .59366 .3053 Mtetra
.622 .566 .771 r
.59366 .3053 .59478 .30819 .59689 .30742 .59577 .30453 Mtetra
.611 .56 .773 r
.59577 .30453 .59689 .30742 .59899 .3066 .59788 .30385 Mtetra
.598 .564 .787 r
.59788 .30385 .59899 .3066 .6011 .30568 .6 .30329 Mtetra
.603 .598 .819 r
.6 .30329 .6011 .30568 .60321 .30475 .60212 .30274 Mtetra
.619 .648 .857 r
.60212 .30274 .60321 .30475 .60532 .30388 .60424 .30213 Mtetra
.645 .695 .882 r
.60424 .30213 .60532 .30388 .60744 .3031 .60636 .30139 Mtetra
.651 .703 .885 r
.60636 .30139 .60744 .3031 .60956 .30237 .60847 .30063 Mtetra
.647 .698 .883 r
.60847 .30063 .60956 .30237 .61168 .30164 .6106 .29988 Mtetra
.636 .69 .883 r
.6106 .29988 .61168 .30164 .6138 .30091 .61272 .29919 Mtetra
.64 .698 .888 r
.61272 .29919 .6138 .30091 .61592 .30021 .61484 .29848 Mtetra
.653 .702 .883 r
.61484 .29848 .61592 .30021 .61805 .29957 .61697 .2977 Mtetra
.669 .69 .86 r
.61697 .2977 .61805 .29957 .62018 .29904 .61909 .2968 Mtetra
.659 .643 .823 r
.61909 .2968 .62018 .29904 .62232 .29851 .62121 .29589 Mtetra
.64 .598 .791 r
.62121 .29589 .62232 .29851 .62445 .29792 .62334 .29504 Mtetra
.615 .564 .773 r
.62334 .29504 .62445 .29792 .62659 .29725 .62547 .29432 Mtetra
.61 .558 .772 r
.62547 .29432 .62659 .29725 .62872 .29653 .62761 .29364 Mtetra
.61 .561 .774 r
.62761 .29364 .62872 .29653 .63086 .29581 .62975 .29297 Mtetra
.616 .568 .777 r
.62975 .29297 .63086 .29581 .633 .29509 .63188 .29225 Mtetra
.617 .569 .778 r
.63188 .29225 .633 .29509 .63513 .29436 .63402 .29153 Mtetra
.618 .57 .778 r
.63402 .29153 .63513 .29436 .63728 .29363 .63616 .2908 Mtetra
.619 .571 .778 r
.63616 .2908 .63728 .29363 .63942 .29289 .63831 .29006 Mtetra
.62 .572 .778 r
.63831 .29006 .63942 .29289 .64156 .29214 .64045 .28931 Mtetra
.621 .572 .778 r
.64045 .28931 .64156 .29214 .6437 .29139 .64259 .28856 Mtetra
.622 .572 .777 r
.64259 .28856 .6437 .29139 .64585 .29064 .64474 .28779 Mtetra
.622 .572 .776 r
.64474 .28779 .64585 .29064 .648 .28987 .64689 .28703 Mtetra
.623 .572 .776 r
.64689 .28703 .648 .28987 .65015 .28906 .64904 .28625 Mtetra
.625 .576 .78 r
.64904 .28625 .65015 .28906 .65229 .28815 .65119 .28547 Mtetra
.629 .588 .79 r
.65119 .28547 .65229 .28815 .65444 .28722 .65334 .28468 Mtetra
.632 .602 .802 r
.65334 .28468 .65444 .28722 .65658 .28632 .65549 .2839 Mtetra
.635 .615 .813 r
.65549 .2839 .65658 .28632 .65874 .28551 .65765 .28312 Mtetra
.635 .617 .815 r
.65765 .28312 .65874 .28551 .66089 .28474 .6598 .28235 Mtetra
.634 .617 .816 r
.6598 .28235 .66089 .28474 .66305 .28398 .66196 .28158 Mtetra
.632 .615 .815 r
.66196 .28158 .66305 .28398 .66521 .28322 .66412 .28082 Mtetra
.631 .615 .816 r
.66412 .28082 .66521 .28322 .66737 .28246 .66628 .28006 Mtetra
.629 .615 .817 r
.66628 .28006 .66737 .28246 .66954 .28171 .66845 .27933 Mtetra
.626 .614 .819 r
.66845 .27933 .66954 .28171 .6717 .28098 .67062 .27861 Mtetra
.625 .616 .821 r
.67062 .27861 .6717 .28098 .67387 .28025 .67279 .2779 Mtetra
.615 .612 .825 r
.67279 .2779 .67387 .28025 .67605 .27959 .67496 .27727 Mtetra
.54 .575 .839 r
.67496 .27727 .67605 .27959 .67824 .27924 .67716 .27707 Mtetra
.624 .636 .842 r
.67716 .27707 .67824 .27924 .68041 .27857 .67934 .2764 Mtetra
.763 .7 .792 r
.67934 .2764 .68041 .27857 .68255 .27715 .68146 .27461 Mtetra
.941 .72 .575 r
.68146 .27461 .68255 .27715 .68456 .27304 .68328 .26697 Mtetra
.975 .668 .339 r
.68328 .26697 .68456 .27304 .68617 .26154 .67428 .05123 Mtetra
.515 .278 .493 r
.67428 .05123 .68617 .26154 .67726 .0518 .67606 .04588 Mtetra
.605 .44 .631 r
.67606 .04588 .67726 .0518 .67914 .04842 .67805 .04458 Mtetra
.584 .482 .704 r
.67805 .04458 .67914 .04842 .68109 .04642 .68008 .04398 Mtetra
.555 .553 .807 r
.68008 .04398 .68109 .04642 .68308 .04508 .68213 .04373 Mtetra
.637 .745 .926 r
.68213 .04373 .68308 .04508 .6851 .04424 .68415 .04307 Mtetra
.634 .78 .952 r
.68415 .04307 .6851 .04424 .68713 .04363 .68618 .04242 Mtetra
.643 .776 .944 r
.68618 .04242 .68713 .04363 .68917 .0431 .68821 .04173 Mtetra
.67 .757 .915 r
.68821 .04173 .68917 .0431 .69119 .04231 .69024 .04092 Mtetra
.679 .757 .91 r
.69024 .04092 .69119 .04231 .69322 .04148 .69226 .04007 Mtetra
.688 .757 .904 r
.69226 .04007 .69322 .04148 .69524 .0406 .69429 .03917 Mtetra
.771 .782 .862 r
.69429 .03917 .69524 .0406 .69723 .0392 .69628 .03775 Mtetra
.703 .757 .894 r
.69628 .03775 .69723 .0392 .69925 .03822 .6983 .03677 Mtetra
.512 .667 .932 r
.6983 .03677 .69925 .03822 .70132 .03806 .70037 .0366 Mtetra
.742 .326 0 r
.70037 .0366 .70132 .03806 .70371 .04307 .70276 .04158 Mtetra
.97 .655 .291 r
.70276 .04158 .70371 .04307 .71941 .25853 .71839 .25709 Mtetra
.728 .299 0 r
.71839 .25709 .71941 .25853 .72197 .26344 .72095 .26202 Mtetra
.054 .473 .886 r
.02417 .49971 .02549 .50081 .02703 .50135 .0257 .50025 Mtetra
.647 .759 .931 r
.0257 .50025 .02703 .50135 .02873 .50076 .02741 .49966 Mtetra
.81 .775 .821 r
.02741 .49966 .02873 .50076 .0306 .49905 .02928 .49794 Mtetra
.908 .735 .656 r
.02928 .49794 .0306 .49905 .03311 .49305 .0318 .49189 Mtetra
.937 .686 .534 r
.0318 .49189 .03311 .49305 .06538 .28572 .06417 .28448 Mtetra
.904 .724 .648 r
.06417 .28448 .06538 .28572 .0678 .27959 .06658 .27842 Mtetra
.771 .754 .837 r
.06658 .27842 .0678 .27959 .0695 .27829 .06829 .27713 Mtetra
.632 .73 .918 r
.06829 .27713 .0695 .27829 .07109 .27778 .06988 .27663 Mtetra
.495 .684 .951 r
.06988 .27663 .07109 .27778 .07263 .27766 .07141 .27653 Mtetra
.716 .753 .882 r
.07141 .27653 .07263 .27766 .0743 .27665 .07306 .27565 Mtetra
.685 .774 .918 r
.07306 .27565 .0743 .27665 .07592 .27591 .07468 .27495 Mtetra
.541 .741 .968 r
.07468 .27495 .07592 .27591 .07746 .27583 .07624 .27469 Mtetra
.656 .148 0 r
.07624 .27469 .07746 .27583 .07844 .27962 .07753 .2763 Mtetra
.904 .594 .102 r
.07753 .2763 .07844 .27962 .0505 .48502 .07831 .28153 Mtetra
0 0 0 r
.07831 .28153 .0505 .48502 .05126 .4911 .05091 .48327 Mtetra
.062 .008 .477 r
.05091 .48327 .05126 .4911 .05283 .49159 .05197 .48727 Mtetra
.249 .231 .642 r
.05197 .48727 .05283 .49159 .05454 .49107 .05339 .48879 Mtetra
.338 .438 .817 r
.05339 .48879 .05454 .49107 .05631 .49011 .05495 .48935 Mtetra
.572 .808 .988 r
.05495 .48935 .05631 .49011 .05804 .48947 .05665 .48893 Mtetra
.685 .878 .97 r
.05665 .48893 .05804 .48947 .05977 .48884 .0584 .48813 Mtetra
.725 .849 .94 r
.0584 .48813 .05977 .48884 .0615 .4882 .06017 .4872 Mtetra
.386 .685 .978 r
.06017 .4872 .0615 .4882 .06316 .4881 .06181 .48723 Mtetra
.485 .756 .99 r
.06181 .48723 .06316 .4881 .06486 .48771 .06349 .48703 Mtetra
.729 .855 .941 r
.06349 .48703 .06486 .48771 .06666 .4866 .06526 .48608 Mtetra
.928 .781 .677 r
.06526 .48608 .06666 .4866 .06902 .4814 .06762 .48095 Mtetra
.941 .688 .526 r
.06762 .48095 .06902 .4814 .09919 .27395 .09802 .27246 Mtetra
.906 .712 .629 r
.09802 .27246 .09919 .27395 .10169 .26693 .10055 .26532 Mtetra
.768 .699 .787 r
.10055 .26532 .10169 .26693 .10346 .26532 .1023 .26378 Mtetra
.611 .659 .873 r
.1023 .26378 .10346 .26532 .10507 .26477 .10391 .26336 Mtetra
.462 .617 .916 r
.10391 .26336 .10507 .26477 .10664 .26465 .10545 .26339 Mtetra
.611 .707 .913 r
.10545 .26339 .10664 .26465 .10825 .26412 .10705 .26296 Mtetra
.657 .74 .911 r
.10705 .26296 .10825 .26412 .10989 .26347 .10868 .26236 Mtetra
.675 .754 .91 r
.10868 .26236 .10989 .26347 .11153 .26281 .11032 .26168 Mtetra
.75 .764 .864 r
.11032 .26168 .11153 .26281 .11322 .26176 .11202 .26058 Mtetra
.731 .753 .87 r
.11202 .26058 .11322 .26176 .11488 .26092 .1137 .2596 Mtetra
.643 .707 .893 r
.1137 .2596 .11488 .26092 .11647 .26068 .11533 .25905 Mtetra
0 .226 .747 r
.11533 .25905 .11647 .26068 .11765 .26349 .11674 .26015 Mtetra
0 0 .2 r
.11674 .26015 .11765 .26349 .09237 .46763 .11779 .26393 Mtetra
0 0 .018 r
.11779 .26393 .09237 .46763 .09293 .47604 .09274 .46652 Mtetra
0 0 .411 r
.09274 .46652 .09293 .47604 .09447 .47704 .09364 .47231 Mtetra
.225 .2 .62 r
.09364 .47231 .09447 .47704 .0962 .47662 .09508 .47412 Mtetra
.316 .402 .792 r
.09508 .47412 .0962 .47662 .09799 .4757 .09666 .47481 Mtetra
.474 .751 .99 r
.09666 .47481 .09799 .4757 .09976 .47495 .09835 .47463 Mtetra
.588 .898 .986 r
.09835 .47463 .09976 .47495 .10152 .47427 .10011 .474 Mtetra
.673 .927 .972 r
.10011 .474 .10152 .47427 .10329 .47356 .1019 .47314 Mtetra
.68 .904 .975 r
.1019 .47314 .10329 .47356 .10505 .47288 .10368 .47231 Mtetra
.685 .876 .97 r
.10368 .47231 .10505 .47288 .10681 .47224 .10546 .47151 Mtetra
.686 .845 .959 r
.10546 .47151 .10681 .47224 .10857 .47163 .10725 .47072 Mtetra
.602 .792 .972 r
.10725 .47072 .10857 .47163 .11032 .4711 .10899 .47024 Mtetra
.586 .797 .98 r
.10899 .47024 .11032 .4711 .11206 .4706 .11073 .4698 Mtetra
.66 .826 .963 r
.11073 .4698 .11206 .4706 .11381 .47009 .1125 .46912 Mtetra
.784 .808 .872 r
.1125 .46912 .11381 .47009 .11553 .46986 .11435 .46776 Mtetra
.785 .675 .742 r
.11435 .46776 .11553 .46986 .11727 .46944 .11632 .46556 Mtetra
.774 .595 .656 r
.11632 .46556 .11727 .46944 .11909 .46834 .11846 .46187 Mtetra
.94 .682 .519 r
.11846 .46187 .11909 .46834 .12132 .46399 .1443 .26592 Mtetra
.543 .303 .501 r
.1443 .26592 .12132 .46399 .14829 .2572 .14775 .25069 Mtetra
.708 .505 .612 r
.14775 .25069 .14829 .2572 .15093 .24859 .14979 .24697 Mtetra
.769 .703 .789 r
.14979 .24697 .15093 .24859 .15277 .24644 .15156 .24542 Mtetra
.676 .776 .925 r
.15156 .24542 .15277 .24644 .15444 .24572 .15323 .24474 Mtetra
.594 .76 .958 r
.15323 .24474 .15444 .24572 .15606 .24545 .15487 .24433 Mtetra
.736 .768 .879 r
.15487 .24433 .15606 .24545 .15775 .24461 .15657 .24332 Mtetra
.738 .741 .853 r
.15657 .24332 .15775 .24461 .15945 .24367 .15829 .24224 Mtetra
.625 .686 .887 r
.15829 .24224 .15945 .24367 .16108 .24331 .15994 .24175 Mtetra
.654 .205 0 r
.15994 .24175 .16108 .24331 .16239 .24564 .16128 .24384 Mtetra
.949 .685 .502 r
.16128 .24384 .16239 .24564 .13992 .45027 .13894 .44657 Mtetra
.979 .682 .345 r
.13894 .44657 .13992 .45027 .14048 .45998 .13921 .45872 Mtetra
.612 .11 0 r
.13921 .45872 .14048 .45998 .14199 .46164 .14071 .46051 Mtetra
.518 .717 .963 r
.14071 .46051 .14199 .46164 .14373 .46142 .14245 .4603 Mtetra
.771 .786 .865 r
.14245 .4603 .14373 .46142 .1456 .46011 .14431 .45898 Mtetra
.897 .763 .705 r
.14431 .45898 .1456 .46011 .14776 .45616 .14648 .45502 Mtetra
.948 .689 .51 r
.14648 .45502 .14776 .45616 .17293 .25132 .17176 .25001 Mtetra
.933 .713 .581 r
.17176 .25001 .17293 .25132 .17593 .23913 .17475 .23792 Mtetra
.86 .759 .749 r
.17475 .23792 .17593 .23913 .17782 .23658 .17666 .23529 Mtetra
.707 .735 .873 r
.17666 .23529 .17782 .23658 .17952 .23577 .17836 .23441 Mtetra
.547 .669 .917 r
.17836 .23441 .17952 .23577 .18116 .23548 .17999 .23419 Mtetra
.387 .61 .938 r
.17999 .23419 .18116 .23548 .18283 .23486 .18158 .23434 Mtetra
.273 0 0 r
.18158 .23434 .18283 .23486 .18453 .23409 .18312 .23498 Mtetra
.727 .286 .203 r
.18312 .23498 .18453 .23409 .18616 .23384 .18452 .23682 Mtetra
.879 .572 .462 r
.18452 .23682 .18616 .23384 .18755 .23584 .18477 .24914 Mtetra
.933 .664 .505 r
.18477 .24914 .18755 .23584 .1671 .43686 .16459 .44698 Mtetra
.614 .318 .443 r
.16459 .44698 .1671 .43686 .1674 .4499 .16597 .45022 Mtetra
.459 0 0 r
.16597 .45022 .1674 .4499 .16894 .4516 .16763 .45082 Mtetra
.653 .834 .97 r
.16763 .45082 .16894 .4516 .17072 .45121 .16944 .45014 Mtetra
.742 .794 .894 r
.16944 .45014 .17072 .45121 .17256 .45025 .17129 .44904 Mtetra
.642 .748 .926 r
.17129 .44904 .17256 .45025 .17436 .44968 .1731 .44844 Mtetra
.541 .707 .948 r
.1731 .44844 .17436 .44968 .17612 .4494 .17486 .44818 Mtetra
.7 .763 .901 r
.17486 .44818 .17612 .4494 .17796 .4485 .1767 .44731 Mtetra
.889 .766 .719 r
.1767 .44731 .17796 .4485 .18006 .44514 .17881 .44375 Mtetra
.951 .689 .503 r
.17881 .44375 .18006 .44514 .203 .24324 .20237 .23683 Mtetra
.835 .6 .582 r
.20237 .23683 .203 .24324 .20624 .22785 .20514 .22597 Mtetra
.82 .695 .726 r
.20514 .22597 .20624 .22785 .20816 .22504 .20704 .22338 Mtetra
.645 .662 .852 r
.20704 .22338 .20816 .22504 .20987 .22424 .20873 .22276 Mtetra
.498 .627 .908 r
.20873 .22276 .20987 .22424 .21153 .22399 .21037 .2227 Mtetra
.502 .666 .936 r
.21037 .2227 .21153 .22399 .21319 .22374 .21201 .22259 Mtetra
.614 .737 .933 r
.21201 .22259 .21319 .22374 .21487 .22326 .2137 .22213 Mtetra
.625 .745 .933 r
.2137 .22213 .21487 .22326 .21655 .22277 .21538 .22163 Mtetra
.639 .747 .927 r
.21538 .22163 .21655 .22277 .21825 .22222 .21708 .22107 Mtetra
.652 .749 .921 r
.21708 .22107 .21825 .22222 .21994 .22161 .21878 .22047 Mtetra
.662 .753 .918 r
.21878 .22047 .21994 .22161 .22165 .22097 .22048 .21982 Mtetra
.707 .764 .897 r
.22048 .21982 .22165 .22097 .22338 .22004 .22221 .21896 Mtetra
.729 .782 .895 r
.22221 .21896 .22338 .22004 .22513 .21897 .22395 .218 Mtetra
.652 .784 .944 r
.22395 .218 .22513 .21897 .22683 .21843 .22565 .21738 Mtetra
.011 .438 .866 r
.22565 .21738 .22683 .21843 .22834 .21983 .22723 .21801 Mtetra
.859 .457 0 r
.22723 .21801 .22834 .21983 .22753 .24519 .22852 .22172 Mtetra
.979 .716 .462 r
.22852 .22172 .22753 .24519 .21094 .43451 .21055 .42439 Mtetra
.096 .019 .471 r
.21055 .42439 .21094 .43451 .2125 .43667 .2118 .42977 Mtetra
.543 .384 .615 r
.2118 .42977 .2125 .43667 .21431 .43626 .2136 .4294 Mtetra
.609 .432 .618 r
.2136 .4294 .21431 .43626 .21618 .43521 .21551 .42792 Mtetra
.628 .441 .611 r
.21551 .42792 .21618 .43521 .21806 .43409 .21747 .42594 Mtetra
.604 .416 .6 r
.21747 .42594 .21806 .43409 .21991 .43329 .2194 .42425 Mtetra
.553 .371 .588 r
.2194 .42425 .21991 .43329 .22176 .43253 .22124 .42351 Mtetra
.397 .254 .567 r
.22124 .42351 .22176 .43253 .2236 .4319 .22285 .42528 Mtetra
.227 .159 .568 r
.22285 .42528 .2236 .4319 .22542 .43143 .22438 .42797 Mtetra
.178 .237 .687 r
.22438 .42797 .22542 .43143 .22724 .43099 .22602 .42955 Mtetra
.24 .52 .913 r
.22602 .42955 .22724 .43099 .22907 .43049 .22776 .43004 Mtetra
.518 .86 .993 r
.22776 .43004 .22907 .43049 .23091 .42987 .22959 .42956 Mtetra
.605 .912 .98 r
.22959 .42956 .23091 .42987 .23276 .42924 .23144 .42883 Mtetra
.634 .906 .983 r
.23144 .42883 .23276 .42924 .2346 .42862 .2333 .42807 Mtetra
.6 .87 .993 r
.2333 .42807 .2346 .42862 .23644 .42806 .23515 .42745 Mtetra
.595 .859 .993 r
.23515 .42745 .23644 .42806 .23828 .4275 .23699 .42687 Mtetra
.567 .846 .997 r
.23699 .42687 .23828 .4275 .24013 .42692 .23883 .42636 Mtetra
.51 .837 .999 r
.23883 .42636 .24013 .42692 .24197 .42633 .24066 .42595 Mtetra
.46 .847 .982 r
.24066 .42595 .24197 .42633 .24382 .42573 .24249 .42554 Mtetra
.431 .856 .947 r
.24249 .42554 .24382 .42573 .24567 .42514 .24433 .42506 Mtetra
.447 .874 .925 r
.24433 .42506 .24567 .42514 .24752 .42456 .24618 .42449 Mtetra
.469 .884 .929 r
.24618 .42449 .24752 .42456 .24937 .42398 .24804 .42387 Mtetra
.488 .891 .94 r
.24804 .42387 .24937 .42398 .25122 .42339 .2499 .42325 Mtetra
.493 .89 .948 r
.2499 .42325 .25122 .42339 .25308 .42278 .25175 .42263 Mtetra
.509 .897 .951 r
.25175 .42263 .25308 .42278 .25494 .42216 .25362 .42199 Mtetra
.545 .91 .958 r
.25362 .42199 .25494 .42216 .2568 .42153 .25548 .42129 Mtetra
.603 .924 .97 r
.25548 .42129 .2568 .42153 .25866 .42089 .25736 .42051 Mtetra
.639 .914 .98 r
.25736 .42051 .25866 .42089 .26053 .42024 .25924 .41971 Mtetra
.612 .881 .991 r
.25924 .41971 .26053 .42024 .26238 .41973 .2611 .41904 Mtetra
.52 .82 .999 r
.2611 .41904 .26238 .41973 .26421 .41949 .26295 .41866 Mtetra
.647 .831 .971 r
.26295 .41866 .26421 .41949 .26609 .41878 .26482 .41797 Mtetra
.816 .856 .878 r
.26482 .41797 .26609 .41878 .26807 .41669 .26677 .4164 Mtetra
.951 .848 .704 r
.26677 .4164 .26807 .41669 .27051 .40879 .26892 .41226 Mtetra
.993 .842 .482 r
.26892 .41226 .27051 .40879 .28876 .19861 .27163 .40084 Mtetra
0 0 .137 r
.27163 .40084 .28876 .19861 .29082 .19399 .28922 .19868 Mtetra
.258 0 .225 r
.28922 .19868 .29082 .19399 .2926 .19285 .29105 .19706 Mtetra
.436 .092 .282 r
.29105 .19706 .2926 .19285 .29434 .19237 .29277 .19683 Mtetra
.51 .167 .322 r
.29277 .19683 .29434 .19237 .29606 .19211 .29444 .19727 Mtetra
.482 .153 .332 r
.29444 .19727 .29606 .19211 .29781 .19149 .29614 .19738 Mtetra
.422 .109 .327 r
.29614 .19738 .29781 .19149 .29957 .19086 .2979 .19677 Mtetra
.221 0 .248 r
.2979 .19677 .29957 .19086 .30133 .19016 .29979 .19439 Mtetra
0 0 0 r
.29979 .19439 .30133 .19016 .3031 .18931 .30179 .19054 Mtetra
.815 .957 .621 r
.30179 .19054 .3031 .18931 .30487 .18845 .3037 .18778 Mtetra
.861 .865 .841 r
.3037 .18778 .30487 .18845 .30664 .18764 .30555 .1859 Mtetra
.683 .674 .835 r
.30555 .1859 .30664 .18764 .30841 .18695 .30733 .18503 Mtetra
.631 .63 .831 r
.30733 .18503 .30841 .18695 .31017 .1863 .30908 .18444 Mtetra
.607 .626 .844 r
.30908 .18444 .31017 .1863 .31193 .18566 .31083 .18398 Mtetra
.621 .656 .863 r
.31083 .18398 .31193 .18566 .31369 .18501 .31259 .18346 Mtetra
.62 .676 .882 r
.31259 .18346 .31369 .18501 .31546 .18435 .31434 .18296 Mtetra
.629 .706 .902 r
.31434 .18296 .31546 .18435 .31723 .18367 .3161 .18242 Mtetra
.657 .742 .913 r
.3161 .18242 .31723 .18367 .319 .18294 .31787 .18177 Mtetra
.671 .76 .917 r
.31787 .18177 .319 .18294 .32077 .18222 .31964 .18106 Mtetra
.695 .769 .909 r
.31964 .18106 .32077 .18222 .32255 .18145 .32142 .18025 Mtetra
.752 .774 .872 r
.32142 .18025 .32255 .18145 .32435 .18036 .32323 .17909 Mtetra
.702 .75 .889 r
.32323 .17909 .32435 .18036 .32612 .17967 .32502 .17821 Mtetra
.544 .659 .911 r
.32502 .17821 .32612 .17967 .32784 .17993 .32676 .17799 Mtetra
0 0 .519 r
.32676 .17799 .32784 .17993 .32923 .18508 .32835 .18019 Mtetra
.783 .53 0 r
.32835 .18019 .32923 .18508 .31743 .39506 .32957 .18821 Mtetra
0 0 .184 r
.32957 .18821 .31743 .39506 .319 .39958 .31821 .39187 Mtetra
.516 .356 .603 r
.31821 .39187 .319 .39958 .32087 .39953 .32008 .39186 Mtetra
.579 .402 .606 r
.32008 .39186 .32087 .39953 .32279 .39871 .32201 .39077 Mtetra
.548 .377 .602 r
.32201 .39077 .32279 .39871 .32473 .3976 .32391 .39022 Mtetra
.276 .187 .571 r
.32391 .39022 .32473 .3976 .32663 .39717 .32561 .39296 Mtetra
.252 .251 .663 r
.32561 .39296 .32663 .39717 .32852 .39674 .32737 .39465 Mtetra
.228 .406 .831 r
.32737 .39465 .32852 .39674 .33043 .39629 .32919 .3955 Mtetra
.375 .735 .99 r
.32919 .3955 .33043 .39629 .33231 .3961 .33108 .39543 Mtetra
.607 .859 .991 r
.33108 .39543 .33231 .3961 .33423 .39546 .33299 .3948 Mtetra
.784 .893 .922 r
.33299 .3948 .33423 .39546 .3362 .39396 .33495 .39347 Mtetra
.934 .866 .748 r
.33495 .39347 .3362 .39396 .33843 .38791 .33703 .39018 Mtetra
.965 .887 .504 r
.33703 .39018 .33843 .38791 .35247 .17638 .33931 .38327 Mtetra
0 0 .176 r
.33931 .38327 .35247 .17638 .3546 .16986 .35313 .17492 Mtetra
0 0 0 r
.35313 .17492 .3546 .16986 .35644 .16837 .35517 .16986 Mtetra
.668 .878 .505 r
.35517 .16986 .35644 .16837 .35824 .16762 .35708 .16724 Mtetra
.851 .932 .88 r
.35708 .16724 .35824 .16762 .36002 .16725 .35893 .16556 Mtetra
.666 .677 .851 r
.35893 .16556 .36002 .16725 .36181 .1666 .36073 .1648 Mtetra
.602 .635 .856 r
.36073 .1648 .36181 .1666 .36361 .166 .36252 .16436 Mtetra
.565 .642 .885 r
.36252 .16436 .36361 .166 .3654 .16541 .3643 .16408 Mtetra
.642 .726 .909 r
.3643 .16408 .3654 .16541 .3672 .16471 .3661 .16348 Mtetra
.658 .748 .916 r
.3661 .16348 .3672 .16471 .36901 .164 .3679 .16281 Mtetra
.673 .761 .917 r
.3679 .16281 .36901 .164 .37081 .16329 .36971 .16207 Mtetra
.698 .765 .903 r
.36971 .16207 .37081 .16329 .37262 .16261 .37152 .16122 Mtetra
.696 .734 .879 r
.37152 .16122 .37262 .16261 .37442 .16194 .37334 .16034 Mtetra
.686 .699 .856 r
.37334 .16034 .37442 .16194 .37623 .16126 .37515 .15948 Mtetra
.662 .664 .842 r
.37515 .15948 .37623 .16126 .37804 .16057 .37697 .15872 Mtetra
.652 .652 .837 r
.37697 .15872 .37804 .16057 .37985 .15986 .37878 .15801 Mtetra
.643 .648 .84 r
.37878 .15801 .37985 .15986 .38166 .15914 .38059 .15735 Mtetra
.628 .649 .851 r
.38059 .15735 .38166 .15914 .38348 .1584 .3824 .15678 Mtetra
.627 .672 .874 r
.3824 .15678 .38348 .1584 .38529 .15765 .3842 .15623 Mtetra
.632 .707 .9 r
.3842 .15623 .38529 .15765 .38711 .1569 .38601 .15566 Mtetra
.701 .763 .9 r
.38601 .15566 .38711 .1569 .38893 .15613 .38784 .15478 Mtetra
.684 .738 .892 r
.38784 .15478 .38893 .15613 .39075 .15539 .38966 .15398 Mtetra
.629 .708 .903 r
.38966 .15398 .39075 .15539 .39257 .15469 .39147 .15343 Mtetra
.381 .621 .946 r
.39147 .15343 .39257 .15469 .3944 .15368 .39326 .15359 Mtetra
.512 0 0 r
.39326 .15359 .3944 .15368 .39622 .15298 .395 .15458 Mtetra
.765 .352 .268 r
.395 .15458 .39622 .15298 .39802 .15297 .39667 .15757 Mtetra
.963 .675 .44 r
.39667 .15757 .39802 .15297 .39963 .15717 .38969 .36446 Mtetra
.515 .273 .486 r
.38969 .36446 .39963 .15717 .39269 .36814 .39134 .37105 Mtetra
.666 .275 .296 r
.39134 .37105 .39269 .36814 .3944 .37363 .39318 .37325 Mtetra
.071 .611 .851 r
.39318 .37325 .3944 .37363 .39631 .3741 .39511 .37341 Mtetra
.601 .858 .992 r
.39511 .37341 .39631 .3741 .39827 .37348 .39708 .37278 Mtetra
.756 .892 .939 r
.39708 .37278 .39827 .37348 .40025 .37238 .39906 .37158 Mtetra
.833 .874 .874 r
.39906 .37158 .40025 .37238 .40221 .37191 .40107 .36984 Mtetra
.819 .707 .741 r
.40107 .36984 .40221 .37191 .40418 .3712 .40311 .36724 Mtetra
.806 .614 .642 r
.40311 .36724 .40418 .3712 .40618 .36974 .40522 .36273 Mtetra
.965 .682 .447 r
.40522 .36273 .40618 .36974 .40833 .36424 .41485 .15482 Mtetra
.524 .285 .495 r
.41485 .15482 .40833 .36424 .41791 .15175 .41699 .14596 Mtetra
.713 .514 .619 r
.41699 .14596 .41791 .15175 .41998 .14471 .41893 .14256 Mtetra
.713 .649 .784 r
.41893 .14256 .41998 .14471 .42186 .14287 .42078 .1413 Mtetra
.626 .682 .883 r
.42078 .1413 .42186 .14287 .4237 .14213 .42262 .14075 Mtetra
.555 .684 .925 r
.42262 .14075 .4237 .14213 .42552 .1418 .42445 .14046 Mtetra
.692 .747 .893 r
.42445 .14046 .42552 .1418 .42736 .14116 .42629 .13961 Mtetra
.696 .714 .862 r
.42629 .13961 .42736 .14116 .42921 .14044 .42815 .13869 Mtetra
.647 .666 .854 r
.42815 .13869 .42921 .14044 .43105 .13975 .42999 .13801 Mtetra
.367 .524 .881 r
.42999 .13801 .43105 .13975 .4329 .13917 .4318 .13839 Mtetra
.418 0 0 r
.4318 .13839 .4329 .13917 .43474 .13863 .43359 .13968 Mtetra
.743 .289 .173 r
.43359 .13968 .43474 .13863 .43658 .13808 .43535 .14202 Mtetra
.464 .109 .278 r
.43535 .14202 .43658 .13808 .43844 .13703 .43718 .14207 Mtetra
.351 .034 .28 r
.43718 .14207 .43844 .13703 .4403 .1361 .43905 .14091 Mtetra
.443 .11 .304 r
.43905 .14091 .4403 .1361 .44214 .13581 .44089 .14066 Mtetra
.966 .673 .425 r
.44089 .14066 .44214 .13581 .44389 .13892 .43712 .3429 Mtetra
.524 .28 .487 r
.43712 .3429 .44389 .13892 .44009 .34992 .4388 .35366 Mtetra
.685 .313 .336 r
.4388 .35366 .44009 .34992 .44188 .35688 .4407 .35659 Mtetra
0 .454 .71 r
.4407 .35659 .44188 .35688 .44383 .35774 .44267 .35702 Mtetra
.544 .832 .998 r
.44267 .35702 .44383 .35774 .44583 .35715 .44466 .35653 Mtetra
.646 .889 .984 r
.44466 .35653 .44583 .35715 .44784 .35607 .44666 .35572 Mtetra
.561 .905 .975 r
.44666 .35572 .44784 .35607 .44984 .3552 .44867 .355 Mtetra
.507 .898 .947 r
.44867 .355 .44984 .3552 .45185 .35447 .45067 .3543 Mtetra
.522 .908 .94 r
.45067 .3543 .45185 .35447 .45385 .35373 .45268 .35355 Mtetra
.567 .926 .945 r
.45268 .35355 .45385 .35373 .45586 .35301 .45469 .3527 Mtetra
.621 .931 .966 r
.45469 .3527 .45586 .35301 .45787 .35232 .4567 .35181 Mtetra
.656 .913 .979 r
.4567 .35181 .45787 .35232 .45987 .35162 .45872 .35092 Mtetra
.646 .874 .983 r
.45872 .35092 .45987 .35162 .46188 .35092 .46073 .35013 Mtetra
.629 .853 .985 r
.46073 .35013 .46188 .35092 .4639 .3502 .46274 .34942 Mtetra
.619 .851 .987 r
.46274 .34942 .4639 .3502 .46591 .34949 .46475 .34875 Mtetra
.563 .837 .997 r
.46475 .34875 .46591 .34949 .46792 .34883 .46677 .34822 Mtetra
.554 .86 .997 r
.46677 .34822 .46792 .34883 .46994 .34818 .46878 .34765 Mtetra
.635 .904 .984 r
.46878 .34765 .46994 .34818 .47195 .3475 .4708 .34683 Mtetra
.841 .908 .882 r
.4708 .34683 .47195 .3475 .47397 .3467 .47284 .34505 Mtetra
.859 .76 .752 r
.47284 .34505 .47397 .3467 .476 .34584 .47489 .34225 Mtetra
.799 .621 .661 r
.47489 .34225 .476 .34584 .47802 .34497 .47696 .33849 Mtetra
.675 .484 .62 r
.47696 .33849 .47802 .34497 .48004 .34423 .47901 .33567 Mtetra
.557 .379 .596 r
.47901 .33567 .48004 .34423 .48207 .34358 .48104 .33486 Mtetra
.514 .347 .593 r
.48104 .33486 .48207 .34358 .48409 .34296 .48305 .33488 Mtetra
.533 .367 .602 r
.48305 .33488 .48409 .34296 .48612 .34231 .48507 .33457 Mtetra
.55 .383 .607 r
.48507 .33457 .48612 .34231 .48815 .34164 .48709 .33397 Mtetra
.551 .384 .608 r
.48709 .33397 .48815 .34164 .49018 .34097 .48912 .33337 Mtetra
.553 .386 .609 r
.48912 .33337 .49018 .34097 .49221 .34029 .49115 .33274 Mtetra
.554 .387 .61 r
.49115 .33274 .49221 .34029 .49424 .33961 .49318 .33209 Mtetra
.555 .388 .61 r
.49318 .33209 .49424 .33961 .49628 .33892 .49521 .33142 Mtetra
.556 .389 .611 r
.49521 .33142 .49628 .33892 .49832 .33823 .49724 .33075 Mtetra
.556 .39 .611 r
.49724 .33075 .49832 .33823 .50035 .33754 .49928 .33008 Mtetra
.557 .39 .611 r
.49928 .33008 .50035 .33754 .50239 .33685 .50131 .32939 Mtetra
.557 .391 .611 r
.50131 .32939 .50239 .33685 .50443 .33615 .50335 .3287 Mtetra
.557 .391 .612 r
.50335 .3287 .50443 .33615 .50648 .33545 .50539 .32801 Mtetra
.50539 .32801 .50648 .33545 .50852 .33475 .50743 .32732 Mtetra
.50743 .32732 .50852 .33475 .51057 .33406 .50947 .32662 Mtetra
.558 .391 .612 r
.50947 .32662 .51057 .33406 .51261 .33335 .51152 .32593 Mtetra
.51152 .32593 .51261 .33335 .51466 .33265 .51356 .32522 Mtetra
.558 .392 .612 r
.51356 .32522 .51466 .33265 .51671 .33195 .51561 .32452 Mtetra
.51561 .32452 .51671 .33195 .51876 .33125 .51766 .32382 Mtetra
.51766 .32382 .51876 .33125 .52082 .33054 .51971 .32312 Mtetra
.51971 .32312 .52082 .33054 .52287 .32984 .52176 .32241 Mtetra
.52176 .32241 .52287 .32984 .52493 .32913 .52382 .3217 Mtetra
.52382 .3217 .52493 .32913 .52699 .32843 .52587 .321 Mtetra
.52587 .321 .52699 .32843 .52905 .32772 .52793 .32029 Mtetra
.52793 .32029 .52905 .32772 .53111 .32701 .52999 .31958 Mtetra
.52999 .31958 .53111 .32701 .53317 .3263 .53205 .31887 Mtetra
.53205 .31887 .53317 .3263 .53524 .3256 .53411 .31816 Mtetra
.53411 .31816 .53524 .3256 .5373 .32489 .53617 .31745 Mtetra
.53617 .31745 .5373 .32489 .53937 .32418 .53823 .31674 Mtetra
.53823 .31674 .53937 .32418 .54144 .32347 .5403 .31603 Mtetra
.5403 .31603 .54144 .32347 .54351 .32276 .54237 .31531 Mtetra
.54237 .31531 .54351 .32276 .54558 .32204 .54444 .3146 Mtetra
.54444 .3146 .54558 .32204 .54765 .32133 .54651 .31389 Mtetra
.54651 .31389 .54765 .32133 .54973 .32062 .54858 .31317 Mtetra
.54858 .31317 .54973 .32062 .5518 .31991 .55065 .31246 Mtetra
.55065 .31246 .5518 .31991 .55388 .31919 .55273 .31174 Mtetra
.55273 .31174 .55388 .31919 .55596 .31848 .5548 .31102 Mtetra
.5548 .31102 .55596 .31848 .55804 .31776 .55688 .3103 Mtetra
.55688 .3103 .55804 .31776 .56013 .31705 .55896 .30959 Mtetra
.55896 .30959 .56013 .31705 .56221 .31633 .56104 .30886 Mtetra
.56104 .30886 .56221 .31633 .5643 .31561 .56313 .30814 Mtetra
.56313 .30814 .5643 .31561 .56638 .31489 .56521 .30742 Mtetra
.56521 .30742 .56638 .31489 .56847 .31418 .5673 .30669 Mtetra
.5673 .30669 .56847 .31418 .57056 .31345 .56938 .30597 Mtetra
.56938 .30597 .57056 .31345 .57266 .31273 .57147 .30524 Mtetra
.559 .392 .612 r
.57147 .30524 .57266 .31273 .57475 .31201 .57356 .3045 Mtetra
.57356 .3045 .57475 .31201 .57685 .31129 .57566 .30376 Mtetra
.559 .392 .611 r
.57566 .30376 .57685 .31129 .57894 .31056 .57775 .30302 Mtetra
.57775 .30302 .57894 .31056 .58104 .30983 .57984 .30226 Mtetra
.56 .392 .611 r
.57984 .30226 .58104 .30983 .58314 .30909 .58194 .3015 Mtetra
.561 .392 .61 r
.58194 .3015 .58314 .30909 .58524 .30836 .58404 .30071 Mtetra
.562 .393 .61 r
.58404 .30071 .58524 .30836 .58735 .30761 .58614 .2999 Mtetra
.561 .392 .609 r
.58614 .2999 .58735 .30761 .58945 .30686 .58824 .29908 Mtetra
.574 .4 .607 r
.58824 .29908 .58945 .30686 .59156 .30609 .59033 .29801 Mtetra
.589 .407 .603 r
.59033 .29801 .59156 .30609 .59366 .3053 .59242 .29657 Mtetra
.547 .372 .595 r
.59242 .29657 .59366 .3053 .59577 .30453 .59453 .29592 Mtetra
.443 .301 .592 r
.59453 .29592 .59577 .30453 .59788 .30385 .59668 .29718 Mtetra
.324 .243 .609 r
.59668 .29718 .59788 .30385 .6 .30329 .59887 .29955 Mtetra
.307 .321 .712 r
.59887 .29955 .6 .30329 .60212 .30274 .60103 .30096 Mtetra
.357 .539 .897 r
.60103 .30096 .60212 .30274 .60424 .30213 .60318 .30139 Mtetra
.558 .846 .998 r
.60318 .30139 .60424 .30213 .60636 .30139 .6053 .30081 Mtetra
.623 .903 .985 r
.6053 .30081 .60636 .30139 .60847 .30063 .60742 .29998 Mtetra
.629 .892 .987 r
.60742 .29998 .60847 .30063 .6106 .29988 .60954 .29915 Mtetra
.548 .846 .998 r
.60954 .29915 .6106 .29988 .61272 .29919 .61167 .2986 Mtetra
.597 .892 .989 r
.61167 .2986 .61272 .29919 .61484 .29848 .61379 .29784 Mtetra
.759 .93 .944 r
.61379 .29784 .61484 .29848 .61697 .2977 .6159 .29652 Mtetra
.884 .842 .798 r
.6159 .29652 .61697 .2977 .61909 .2968 .61798 .29398 Mtetra
.828 .673 .691 r
.61798 .29398 .61909 .2968 .62121 .29589 .62003 .29057 Mtetra
.743 .547 .628 r
.62003 .29057 .62121 .29589 .62334 .29504 .62206 .28676 Mtetra
.583 .401 .601 r
.62206 .28676 .62334 .29504 .62547 .29432 .62417 .2854 Mtetra
.529 .358 .593 r
.62417 .2854 .62547 .29432 .62761 .29364 .62631 .28512 Mtetra
.52 .355 .598 r
.62631 .28512 .62761 .29364 .62975 .29297 .62847 .28503 Mtetra
.552 .383 .606 r
.62847 .28503 .62975 .29297 .63188 .29225 .6306 .28436 Mtetra
.553 .384 .607 r
.6306 .28436 .63188 .29225 .63402 .29153 .63274 .28367 Mtetra
.554 .386 .607 r
.63274 .28367 .63402 .29153 .63616 .2908 .63488 .28297 Mtetra
.556 .387 .608 r
.63488 .28297 .63616 .2908 .63831 .29006 .63701 .28223 Mtetra
.557 .388 .608 r
.63701 .28223 .63831 .29006 .64045 .28931 .63915 .28147 Mtetra
.558 .389 .607 r
.63915 .28147 .64045 .28931 .64259 .28856 .64129 .28068 Mtetra
.559 .389 .607 r
.64129 .28068 .64259 .28856 .64474 .28779 .64344 .27988 Mtetra
.56 .389 .607 r
.64344 .27988 .64474 .28779 .64689 .28703 .64558 .27906 Mtetra
.56 .389 .606 r
.64558 .27906 .64689 .28703 .64904 .28625 .64772 .27823 Mtetra
.561 .389 .605 r
.64772 .27823 .64904 .28625 .65119 .28547 .64986 .27737 Mtetra
.561 .388 .604 r
.64986 .27737 .65119 .28547 .65334 .28468 .65201 .2765 Mtetra
.56 .386 .603 r
.65201 .2765 .65334 .28468 .65549 .2839 .65415 .27564 Mtetra
.558 .385 .602 r
.65415 .27564 .65549 .2839 .65765 .28312 .6563 .2748 Mtetra
.557 .383 .601 r
.6563 .2748 .65765 .28312 .6598 .28235 .65845 .27398 Mtetra
.556 .382 .601 r
.65845 .27398 .6598 .28235 .66196 .28158 .66061 .27318 Mtetra
.555 .381 .6 r
.66061 .27318 .66196 .28158 .66412 .28082 .66276 .2724 Mtetra
.553 .38 .6 r
.66276 .2724 .66412 .28082 .66628 .28006 .66492 .27164 Mtetra
.551 .378 .6 r
.66492 .27164 .66628 .28006 .66845 .27933 .66708 .27093 Mtetra
.549 .377 .6 r
.66708 .27093 .66845 .27933 .67062 .27861 .66925 .27027 Mtetra
.548 .377 .601 r
.66925 .27027 .67062 .27861 .67279 .2779 .67142 .26964 Mtetra
.54 .372 .602 r
.67142 .26964 .67279 .2779 .67496 .27727 .6736 .26917 Mtetra
.492 .341 .604 r
.6736 .26917 .67496 .27727 .67716 .27707 .67583 .26959 Mtetra
.548 .386 .614 r
.67583 .26959 .67716 .27707 .67934 .2764 .67801 .26904 Mtetra
.656 .46 .607 r
.67801 .26904 .67934 .2764 .68146 .27461 .68008 .26624 Mtetra
.974 .666 .345 r
.68008 .26624 .68146 .27461 .68328 .26697 .6715 .05457 Mtetra
.519 .28 .493 r
.6715 .05457 .68328 .26697 .67428 .05123 .67318 .04715 Mtetra
.762 .579 .65 r
.67318 .04715 .67428 .05123 .67606 .04588 .67507 .04392 Mtetra
.674 .668 .836 r
.67507 .04392 .67606 .04588 .67805 .04458 .67708 .043 Mtetra
.584 .679 .906 r
.67708 .043 .67805 .04458 .68008 .04398 .67912 .04258 Mtetra
.512 .676 .939 r
.67912 .04258 .68008 .04398 .68213 .04373 .68117 .0424 Mtetra
.631 .748 .932 r
.68117 .0424 .68213 .04373 .68415 .04307 .6832 .04177 Mtetra
.644 .759 .932 r
.6832 .04177 .68415 .04307 .68618 .04242 .68523 .04109 Mtetra
.658 .758 .924 r
.68523 .04109 .68618 .04242 .68821 .04173 .68726 .04034 Mtetra
.675 .754 .911 r
.68726 .04034 .68821 .04173 .69024 .04092 .68928 .03951 Mtetra
.682 .753 .905 r
.68928 .03951 .69024 .04092 .69226 .04007 .69131 .03863 Mtetra
.69 .753 .9 r
.69131 .03863 .69226 .04007 .69429 .03917 .69333 .03772 Mtetra
.771 .779 .86 r
.69333 .03772 .69429 .03917 .69628 .03775 .69532 .0363 Mtetra
.703 .755 .892 r
.69532 .0363 .69628 .03775 .6983 .03677 .69734 .03531 Mtetra
.514 .666 .931 r
.69734 .03531 .6983 .03677 .70037 .0366 .69941 .03514 Mtetra
.737 .321 0 r
.69941 .03514 .70037 .0366 .70276 .04158 .7018 .04007 Mtetra
.97 .655 .291 r
.7018 .04007 .70276 .04158 .71839 .25709 .71737 .25563 Mtetra
.728 .301 0 r
.71737 .25563 .71839 .25709 .72095 .26202 .71994 .2606 Mtetra
.055 .471 .886 r
.02284 .4986 .02417 .49971 .0257 .50025 .02438 .49914 Mtetra
.648 .758 .929 r
.02438 .49914 .0257 .50025 .02741 .49966 .02608 .49855 Mtetra
.81 .774 .82 r
.02608 .49855 .02741 .49966 .02928 .49794 .02796 .49682 Mtetra
.908 .734 .655 r
.02796 .49682 .02928 .49794 .0318 .49189 .03049 .4907 Mtetra
.937 .686 .534 r
.03049 .4907 .0318 .49189 .06417 .28448 .06296 .28323 Mtetra
.903 .723 .649 r
.06296 .28323 .06417 .28448 .06658 .27842 .06537 .27724 Mtetra
.769 .753 .838 r
.06537 .27724 .06658 .27842 .06829 .27713 .06707 .27596 Mtetra
.63 .728 .918 r
.06707 .27596 .06829 .27713 .06988 .27663 .06866 .27548 Mtetra
.492 .681 .95 r
.06866 .27548 .06988 .27663 .07141 .27653 .0702 .27538 Mtetra
.686 .746 .897 r
.0702 .27538 .07141 .27653 .07306 .27565 .07182 .27466 Mtetra
.676 .773 .924 r
.07182 .27466 .07306 .27565 .07468 .27495 .07344 .27399 Mtetra
.616 .768 .953 r
.07344 .27399 .07468 .27495 .07624 .27469 .07503 .27354 Mtetra
.456 .667 .953 r
.07503 .27354 .07624 .27469 .07753 .2763 .07655 .27351 Mtetra
.376 .393 .75 r
.07655 .27351 .07753 .2763 .07831 .28153 .078 .27409 Mtetra
.342 .217 .561 r
.078 .27409 .07831 .28153 .05091 .48327 .07925 .27596 Mtetra
0 0 .007 r
.07925 .27596 .05091 .48327 .05197 .48727 .05221 .47532 Mtetra
0 0 .188 r
.05221 .47532 .05197 .48727 .05339 .48879 .05238 .48552 Mtetra
0 0 .475 r
.05238 .48552 .05339 .48879 .05495 .48935 .05365 .48813 Mtetra
.47 .677 .955 r
.05365 .48813 .05495 .48935 .05665 .48893 .0553 .48807 Mtetra
.695 .817 .941 r
.0553 .48807 .05665 .48893 .0584 .48813 .05705 .48727 Mtetra
.754 .822 .905 r
.05705 .48727 .0584 .48813 .06017 .4872 .05885 .48618 Mtetra
.437 .702 .977 r
.05885 .48618 .06017 .4872 .06181 .48723 .0605 .48612 Mtetra
.541 .727 .96 r
.0605 .48612 .06181 .48723 .06349 .48703 .06218 .48586 Mtetra
.729 .766 .882 r
.06218 .48586 .06349 .48703 .06526 .48608 .06397 .48485 Mtetra
.902 .737 .668 r
.06397 .48485 .06526 .48608 .06762 .48095 .06635 .47956 Mtetra
.94 .687 .527 r
.06635 .47956 .06762 .48095 .09802 .27246 .09686 .27093 Mtetra
.903 .711 .633 r
.09686 .27093 .09802 .27246 .10055 .26532 .09935 .26408 Mtetra
.79 .75 .816 r
.09935 .26408 .10055 .26532 .1023 .26378 .10111 .26256 Mtetra
.611 .714 .919 r
.10111 .26256 .1023 .26378 .10391 .26336 .10271 .26213 Mtetra
.44 .646 .946 r
.10271 .26213 .10391 .26336 .10545 .26339 .10425 .26216 Mtetra
.605 .712 .92 r
.10425 .26216 .10545 .26339 .10705 .26296 .10585 .26176 Mtetra
.65 .729 .907 r
.10585 .26176 .10705 .26296 .10868 .26236 .10748 .26118 Mtetra
.666 .739 .905 r
.10748 .26118 .10868 .26236 .11032 .26168 .10911 .26054 Mtetra
.722 .758 .88 r
.10911 .26054 .11032 .26168 .11202 .26058 .11079 .25962 Mtetra
.724 .79 .904 r
.11079 .25962 .11202 .26058 .1137 .2596 .11246 .25872 Mtetra
.676 .8 .941 r
.11246 .25872 .1137 .2596 .11533 .25905 .1141 .25804 Mtetra
.475 .71 .972 r
.1141 .25804 .11533 .25905 .11674 .26015 .11567 .25793 Mtetra
.342 .431 .808 r
.11567 .25793 .11674 .26015 .11779 .26393 .11716 .25847 Mtetra
.291 .215 .596 r
.11716 .25847 .11779 .26393 .09274 .46652 .11849 .26019 Mtetra
.435 .21 .473 r
.11849 .26019 .09274 .46652 .09364 .47231 .11707 .28288 Mtetra
0 0 .023 r
.11707 .28288 .09364 .47231 .09508 .47412 .09412 .4704 Mtetra
0 0 .444 r
.09412 .4704 .09508 .47412 .09666 .47481 .09539 .47346 Mtetra
.283 .559 .929 r
.09539 .47346 .09666 .47481 .09835 .47463 .09702 .47381 Mtetra
.638 .817 .969 r
.09702 .47381 .09835 .47463 .10011 .474 .09877 .47321 Mtetra
.734 .838 .929 r
.09877 .47321 .10011 .474 .1019 .47314 .10057 .47222 Mtetra
.707 .811 .93 r
.10057 .47222 .1019 .47314 .10368 .47231 .10236 .47135 Mtetra
.693 .802 .933 r
.10236 .47135 .10368 .47231 .10546 .47151 .10414 .47055 Mtetra
.69 .803 .935 r
.10414 .47055 .10546 .47151 .10725 .47072 .10593 .46977 Mtetra
.561 .768 .975 r
.10593 .46977 .10725 .47072 .10899 .47024 .10765 .46941 Mtetra
.561 .794 .986 r
.10765 .46941 .10899 .47024 .11073 .4698 .10939 .46902 Mtetra
.705 .84 .947 r
.10939 .46902 .11073 .4698 .1125 .46912 .11118 .46816 Mtetra
.877 .791 .761 r
.11118 .46816 .1125 .46912 .11435 .46776 .11322 .46537 Mtetra
.882 .685 .632 r
.11322 .46537 .11435 .46776 .11632 .46556 .11577 .45845 Mtetra
.939 .681 .52 r
.11577 .45845 .11632 .46556 .11846 .46187 .14289 .25359 Mtetra
.515 .278 .494 r
.14289 .25359 .11846 .46187 .1443 .26592 .14505 .24893 Mtetra
.568 .351 .545 r
.14505 .24893 .1443 .26592 .14775 .25069 .1469 .24677 Mtetra
.662 .517 .676 r
.1469 .24677 .14775 .25069 .14979 .24697 .14866 .24534 Mtetra
.7 .682 .829 r
.14866 .24534 .14979 .24697 .15156 .24542 .15035 .24441 Mtetra
.668 .774 .929 r
.15035 .24441 .15156 .24542 .15323 .24474 .15202 .24375 Mtetra
.638 .773 .945 r
.15202 .24375 .15323 .24474 .15487 .24433 .15367 .24321 Mtetra
.747 .77 .872 r
.15367 .24321 .15487 .24433 .15657 .24332 .15539 .24213 Mtetra
.745 .758 .863 r
.15539 .24213 .15657 .24332 .15829 .24224 .15711 .24104 Mtetra
.629 .728 .919 r
.15711 .24104 .15829 .24224 .15994 .24175 .15876 .24054 Mtetra
.735 .249 0 r
.15876 .24054 .15994 .24175 .16128 .24384 .1601 .2426 Mtetra
.948 .685 .503 r
.1601 .2426 .16128 .24384 .13894 .44657 .13773 .44488 Mtetra
.959 .652 .406 r
.13773 .44488 .13894 .44657 .13921 .45872 .13793 .45753 Mtetra
.641 .132 0 r
.13793 .45753 .13921 .45872 .14071 .46051 .13943 .45934 Mtetra
.515 .711 .96 r
.13943 .45934 .14071 .46051 .14245 .4603 .14116 .45914 Mtetra
.768 .781 .864 r
.14116 .45914 .14245 .4603 .14431 .45898 .14303 .45784 Mtetra
.897 .762 .705 r
.14303 .45784 .14431 .45898 .14648 .45502 .1452 .45388 Mtetra
.948 .689 .51 r
.1452 .45388 .14648 .45502 .17176 .25001 .17058 .24876 Mtetra
.935 .715 .581 r
.17058 .24876 .17176 .25001 .17475 .23792 .17357 .23673 Mtetra
.865 .76 .745 r
.17357 .23673 .17475 .23792 .17666 .23529 .17549 .234 Mtetra
.721 .739 .866 r
.17549 .234 .17666 .23529 .17836 .23441 .1772 .23304 Mtetra
.521 .657 .921 r
.1772 .23304 .17836 .23441 .17999 .23419 .17882 .2329 Mtetra
0 .191 .699 r
.17882 .2329 .17999 .23419 .18158 .23434 .1803 .23402 Mtetra
.891 .489 .251 r
.1803 .23402 .18158 .23434 .18312 .23498 .18148 .23789 Mtetra
.946 .679 .5 r
.18148 .23789 .18312 .23498 .18452 .23682 .1603 .44196 Mtetra
.514 .273 .486 r
.1603 .44196 .18452 .23682 .18477 .24914 .16139 .44764 Mtetra
.505 .265 .484 r
.16139 .44764 .18477 .24914 .16459 .44698 .16295 .44914 Mtetra
.507 .086 .176 r
.16295 .44914 .16459 .44698 .16597 .45022 .16463 .44962 Mtetra
.445 .8 .997 r
.16463 .44962 .16597 .45022 .16763 .45082 .16639 .44936 Mtetra
.67 .716 .883 r
.16639 .44936 .16763 .45082 .16944 .45014 .16821 .44862 Mtetra
.703 .716 .859 r
.16821 .44862 .16944 .45014 .17129 .44904 .17005 .44766 Mtetra
.612 .709 .914 r
.17005 .44766 .17129 .44904 .1731 .44844 .17184 .44718 Mtetra
.531 .701 .948 r
.17184 .44718 .1731 .44844 .17486 .44818 .1736 .44696 Mtetra
.694 .76 .903 r
.1736 .44696 .17486 .44818 .1767 .44731 .17543 .44611 Mtetra
.888 .766 .721 r
.17543 .44611 .1767 .44731 .17881 .44375 .17755 .4426 Mtetra
.951 .69 .503 r
.17755 .4426 .17881 .44375 .20237 .23683 .20114 .23616 Mtetra
.949 .734 .579 r
.20114 .23616 .20237 .23683 .20514 .22597 .20396 .22488 Mtetra
.87 .777 .756 r
.20396 .22488 .20514 .22597 .20704 .22338 .20586 .22226 Mtetra
.66 .758 .923 r
.20586 .22226 .20704 .22338 .20873 .22276 .20756 .22163 Mtetra
.474 .686 .959 r
.20756 .22163 .20873 .22276 .21037 .2227 .2092 .22155 Mtetra
.497 .691 .955 r
.2092 .22155 .21037 .2227 .21201 .22259 .21084 .22142 Mtetra
.617 .733 .929 r
.21084 .22142 .21201 .22259 .2137 .22213 .21253 .22095 Mtetra
.626 .735 .925 r
.21253 .22095 .2137 .22213 .21538 .22163 .21421 .22044 Mtetra
.638 .738 .921 r
.21421 .22044 .21538 .22163 .21708 .22107 .21591 .21989 Mtetra
.65 .743 .917 r
.21591 .21989 .21708 .22107 .21878 .22047 .21761 .21929 Mtetra
.661 .747 .914 r
.21761 .21929 .21878 .22047 .22048 .21982 .21931 .21864 Mtetra
.689 .755 .902 r
.21931 .21864 .22048 .21982 .22221 .21896 .22103 .21787 Mtetra
.707 .775 .905 r
.22103 .21787 .22221 .21896 .22395 .218 .22276 .21702 Mtetra
.673 .791 .937 r
.22276 .21702 .22395 .218 .22565 .21738 .22447 .21633 Mtetra
.49 .711 .969 r
.22447 .21633 .22565 .21738 .22723 .21801 .22613 .21619 Mtetra
.242 .431 .848 r
.22613 .21619 .22723 .21801 .22852 .22172 .22772 .21685 Mtetra
.372 .294 .637 r
.22772 .21685 .22852 .22172 .21055 .42439 .22926 .21798 Mtetra
.501 .266 .491 r
.22926 .21798 .21055 .42439 .2118 .42977 .23084 .21872 Mtetra
.504 .27 .492 r
.23084 .21872 .2118 .42977 .2136 .4294 .23256 .21799 Mtetra
.506 .271 .492 r
.23256 .21799 .2136 .4294 .21551 .42792 .23433 .2168 Mtetra
.23433 .2168 .21551 .42792 .21747 .42594 .23613 .21533 Mtetra
.23613 .21533 .21747 .42594 .2194 .42425 .23792 .21396 Mtetra
.504 .269 .492 r
.23792 .21396 .2194 .42425 .22124 .42351 .23963 .21341 Mtetra
.496 .263 .49 r
.23963 .21341 .22124 .42351 .22285 .42528 .24105 .21593 Mtetra
0 0 .122 r
.24105 .21593 .22285 .42528 .22438 .42797 .2236 .42175 Mtetra
0 0 .33 r
.2236 .42175 .22438 .42797 .22602 .42955 .22485 .42756 Mtetra
0 .16 .701 r
.22485 .42756 .22602 .42955 .22776 .43004 .22649 .4291 Mtetra
.549 .776 .983 r
.22649 .4291 .22776 .43004 .22959 .42956 .22831 .42874 Mtetra
.688 .84 .956 r
.22831 .42874 .22959 .42956 .23144 .42883 .23017 .42792 Mtetra
.703 .826 .941 r
.23017 .42792 .23144 .42883 .2333 .42807 .23204 .42704 Mtetra
.642 .788 .952 r
.23204 .42704 .2333 .42807 .23515 .42745 .23389 .42641 Mtetra
.637 .784 .952 r
.23389 .42641 .23515 .42745 .23699 .42687 .23573 .4258 Mtetra
.62 .774 .954 r
.23573 .4258 .23699 .42687 .23883 .42636 .23758 .42525 Mtetra
.596 .759 .956 r
.23758 .42525 .23883 .42636 .24066 .42595 .23941 .42479 Mtetra
.598 .75 .95 r
.23941 .42479 .24066 .42595 .24249 .42554 .24125 .42433 Mtetra
.613 .746 .94 r
.24125 .42433 .24249 .42554 .24433 .42506 .2431 .42382 Mtetra
.636 .747 .928 r
.2431 .42382 .24433 .42506 .24618 .42449 .24495 .42322 Mtetra
.643 .746 .924 r
.24495 .42322 .24618 .42449 .24804 .42387 .24681 .4226 Mtetra
.645 .745 .922 r
.24681 .4226 .24804 .42387 .2499 .42325 .24866 .42196 Mtetra
.643 .742 .921 r
.24866 .42196 .2499 .42325 .25175 .42263 .25052 .42134 Mtetra
.649 .742 .917 r
.25052 .42134 .25175 .42263 .25362 .42199 .25239 .42068 Mtetra
.662 .744 .911 r
.25239 .42068 .25362 .42199 .25548 .42129 .25426 .41997 Mtetra
.68 .747 .902 r
.25426 .41997 .25548 .42129 .25736 .42051 .25613 .41917 Mtetra
.682 .745 .899 r
.25613 .41917 .25736 .42051 .25924 .41971 .25801 .41836 Mtetra
.664 .737 .905 r
.25801 .41836 .25924 .41971 .2611 .41904 .25989 .41763 Mtetra
.619 .713 .913 r
.25989 .41763 .2611 .41904 .26295 .41866 .26175 .41711 Mtetra
.647 .701 .886 r
.26175 .41711 .26295 .41866 .26482 .41797 .26362 .41645 Mtetra
.72 .728 .856 r
.26362 .41645 .26482 .41797 .26677 .4164 .26552 .41535 Mtetra
.845 .812 .818 r
.26552 .41535 .26677 .4164 .26892 .41226 .26751 .4133 Mtetra
.82 .978 .685 r
.26751 .4133 .26892 .41226 .27163 .40084 .26953 .4107 Mtetra
.329 .059 .344 r
.26953 .4107 .27163 .40084 .28922 .19868 .27156 .40807 Mtetra
.499 .26 .483 r
.27156 .40807 .28922 .19868 .29105 .19706 .27346 .40708 Mtetra
.5 .261 .483 r
.27346 .40708 .29105 .19706 .29277 .19683 .27532 .40669 Mtetra
.501 .262 .483 r
.27532 .40669 .29277 .19683 .29444 .19727 .27715 .40663 Mtetra
.502 .262 .483 r
.27715 .40663 .29444 .19727 .29614 .19738 .27897 .40673 Mtetra
.5 .26 .483 r
.27897 .40673 .29614 .19738 .2979 .19677 .28085 .40605 Mtetra
.495 .256 .482 r
.28085 .40605 .2979 .19677 .29979 .19439 .2829 .40315 Mtetra
0 0 .148 r
.2829 .40315 .29979 .19439 .30179 .19054 .30016 .19591 Mtetra
.75 .758 .248 r
.30016 .19591 .30179 .19054 .3037 .18778 .30248 .1877 Mtetra
.948 .899 .744 r
.30248 .1877 .3037 .18778 .30555 .1859 .30443 .18457 Mtetra
.725 .746 .868 r
.30443 .18457 .30555 .1859 .30733 .18503 .30621 .18355 Mtetra
.63 .69 .887 r
.30621 .18355 .30733 .18503 .30908 .18444 .30797 .18301 Mtetra
.576 .677 .909 r
.30797 .18301 .30908 .18444 .31083 .18398 .30971 .18268 Mtetra
.622 .719 .915 r
.30971 .18268 .31083 .18398 .31259 .18346 .31146 .18217 Mtetra
.617 .718 .918 r
.31146 .18217 .31259 .18346 .31434 .18296 .31322 .18168 Mtetra
.624 .723 .918 r
.31322 .18168 .31434 .18296 .3161 .18242 .31498 .18116 Mtetra
.651 .737 .912 r
.31498 .18116 .3161 .18242 .31787 .18177 .31674 .18054 Mtetra
.664 .745 .911 r
.31674 .18054 .31787 .18177 .31964 .18106 .31852 .17985 Mtetra
.683 .756 .907 r
.31852 .17985 .31964 .18106 .32142 .18025 .32029 .17908 Mtetra
.725 .776 .893 r
.32029 .17908 .32142 .18025 .32323 .17909 .32209 .1781 Mtetra
.703 .805 .928 r
.32209 .1781 .32323 .17909 .32502 .17821 .32387 .17725 Mtetra
.613 .786 .964 r
.32387 .17725 .32502 .17821 .32676 .17799 .32564 .17674 Mtetra
.202 .518 .916 r
.32564 .17674 .32676 .17799 .32835 .18019 .32734 .17723 Mtetra
.286 .333 .736 r
.32734 .17723 .32835 .18019 .32957 .18821 .32901 .17827 Mtetra
.441 .277 .562 r
.32901 .17827 .32957 .18821 .31821 .39187 .33066 .17958 Mtetra
.505 .27 .492 r
.33066 .17958 .31821 .39187 .32008 .39186 .33247 .17847 Mtetra
.33247 .17847 .32008 .39186 .32201 .39077 .33427 .17756 Mtetra
.501 .267 .491 r
.33427 .17756 .32201 .39077 .32391 .39022 .33598 .17804 Mtetra
0 0 .195 r
.33598 .17804 .32391 .39022 .32561 .39296 .32491 .38353 Mtetra
0 0 .356 r
.32491 .38353 .32561 .39296 .32737 .39465 .32626 .39181 Mtetra
0 .03 .597 r
.32626 .39181 .32737 .39465 .32919 .3955 .32799 .39426 Mtetra
.455 .679 .961 r
.32799 .39426 .32919 .3955 .33108 .39543 .32987 .39421 Mtetra
.661 .766 .928 r
.32987 .39421 .33108 .39543 .33299 .3948 .33179 .39349 Mtetra
.751 .773 .872 r
.33179 .39349 .33299 .3948 .33495 .39347 .33375 .39224 Mtetra
.787 .792 .857 r
.33375 .39224 .33495 .39347 .33703 .39018 .33572 .39073 Mtetra
.832 .997 .768 r
.33572 .39073 .33703 .39018 .33931 .38327 .33773 .38849 Mtetra
0 0 .099 r
.33773 .38849 .33931 .38327 .35313 .17492 .33984 .38465 Mtetra
0 0 .187 r
.33984 .38465 .35313 .17492 .35517 .16986 .35354 .17779 Mtetra
0 0 0 r
.35354 .17779 .35517 .16986 .35708 .16724 .35587 .16772 Mtetra
.96 .944 .698 r
.35587 .16772 .35708 .16724 .35893 .16556 .35782 .16428 Mtetra
.719 .758 .883 r
.35782 .16428 .35893 .16556 .36073 .1648 .35964 .1633 Mtetra
.601 .679 .896 r
.35964 .1633 .36073 .1648 .36252 .16436 .36142 .16287 Mtetra
.517 .643 .912 r
.36142 .16287 .36252 .16436 .3643 .16408 .3632 .16274 Mtetra
.636 .721 .909 r
.3632 .16274 .3643 .16408 .3661 .16348 .36499 .16216 Mtetra
.648 .731 .909 r
.36499 .16216 .3661 .16348 .3679 .16281 .36679 .16154 Mtetra
.661 .743 .911 r
.36679 .16154 .3679 .16281 .36971 .16207 .3686 .16085 Mtetra
.687 .76 .908 r
.3686 .16085 .36971 .16207 .37152 .16122 .37041 .16006 Mtetra
.694 .773 .912 r
.37041 .16006 .37152 .16122 .37334 .16034 .37223 .15923 Mtetra
.693 .782 .919 r
.37223 .15923 .37334 .16034 .37515 .15948 .37404 .1584 Mtetra
.676 .785 .931 r
.37404 .1584 .37515 .15948 .37697 .15872 .37585 .15766 Mtetra
.668 .786 .937 r
.37585 .15766 .37697 .15872 .37878 .15801 .37767 .15695 Mtetra
.659 .783 .94 r
.37767 .15695 .37878 .15801 .38059 .15735 .37948 .15627 Mtetra
.643 .775 .944 r
.37948 .15627 .38059 .15735 .3824 .15678 .38129 .15566 Mtetra
.64 .766 .94 r
.38129 .15566 .3824 .15678 .3842 .15623 .3831 .15506 Mtetra
.644 .758 .932 r
.3831 .15506 .3842 .15623 .38601 .15566 .38491 .15444 Mtetra
.735 .775 .885 r
.38491 .15444 .38601 .15566 .38784 .15478 .38675 .15338 Mtetra
.693 .732 .881 r
.38675 .15338 .38784 .15478 .38966 .15398 .38857 .15252 Mtetra
.581 .679 .907 r
.38857 .15252 .38966 .15398 .39147 .15343 .39038 .15215 Mtetra
0 0 .493 r
.39038 .15215 .39147 .15343 .39326 .15359 .39208 .15404 Mtetra
.917 .554 .326 r
.39208 .15404 .39326 .15359 .395 .15458 .39352 .1621 Mtetra
.96 .671 .444 r
.39352 .1621 .395 .15458 .39667 .15757 .38638 .36807 Mtetra
.507 .266 .484 r
.38638 .36807 .39667 .15757 .38969 .36446 .38819 .37087 Mtetra
.54 .215 .366 r
.38819 .37087 .38969 .36446 .39134 .37105 .39008 .37186 Mtetra
.359 0 0 r
.39008 .37186 .39134 .37105 .39318 .37325 .392 .3721 Mtetra
.439 .693 .973 r
.392 .3721 .39318 .37325 .39511 .37341 .39394 .37205 Mtetra
.616 .731 .928 r
.39394 .37205 .39511 .37341 .39708 .37278 .3959 .3715 Mtetra
.745 .785 .885 r
.3959 .3715 .39708 .37278 .39906 .37158 .39789 .37029 Mtetra
.895 .79 .736 r
.39789 .37029 .39906 .37158 .40107 .36984 .39996 .36703 Mtetra
.902 .689 .604 r
.39996 .36703 .40107 .36984 .40311 .36724 .40219 .35946 Mtetra
.964 .682 .448 r
.40219 .35946 .40311 .36724 .40522 .36273 .4121 .14952 Mtetra
.513 .277 .493 r
.4121 .14952 .40522 .36273 .41485 .15482 .41408 .14498 Mtetra
.609 .404 .578 r
.41408 .14498 .41485 .15482 .41699 .14596 .41598 .14266 Mtetra
.688 .561 .705 r
.41598 .14266 .41699 .14596 .41893 .14256 .41785 .14112 Mtetra
.695 .73 .877 r
.41785 .14112 .41893 .14256 .42078 .1413 .41969 .14023 Mtetra
.63 .777 .951 r
.41969 .14023 .42078 .1413 .42262 .14075 .42153 .13965 Mtetra
.594 .758 .957 r
.42153 .13965 .42262 .14075 .42445 .14046 .42336 .1392 Mtetra
.728 .769 .886 r
.42336 .1392 .42445 .14046 .42629 .13961 .42522 .13816 Mtetra
.711 .733 .868 r
.42522 .13816 .42629 .13961 .42815 .13869 .42707 .13717 Mtetra
.621 .689 .892 r
.42707 .13717 .42815 .13869 .42999 .13801 .42891 .13664 Mtetra
0 .128 .657 r
.42891 .13664 .42999 .13801 .4318 .13839 .43069 .13821 Mtetra
.914 .52 .234 r
.43069 .13821 .4318 .13839 .43359 .13968 .43232 .14437 Mtetra
.965 .674 .427 r
.43232 .14437 .43359 .13968 .43535 .14202 .42779 .35269 Mtetra
.505 .264 .484 r
.42779 .35269 .43535 .14202 .43718 .14207 .4297 .35428 Mtetra
.5 .26 .483 r
.4297 .35428 .43718 .14207 .43905 .14091 .4317 .35351 Mtetra
.499 .26 .483 r
.4317 .35351 .43905 .14091 .44089 .14066 .4337 .35242 Mtetra
.503 .263 .483 r
.4337 .35242 .44089 .14066 .43712 .3429 .43564 .35346 Mtetra
.539 .242 .413 r
.43564 .35346 .43712 .3429 .4388 .35366 .43758 .35475 Mtetra
.521 .014 0 r
.43758 .35475 .4388 .35366 .4407 .35659 .43953 .35553 Mtetra
.436 .711 .981 r
.43953 .35553 .4407 .35659 .44267 .35702 .44152 .35545 Mtetra
.605 .694 .906 r
.44152 .35545 .44267 .35702 .44466 .35653 .44351 .35494 Mtetra
.642 .706 .894 r
.44351 .35494 .44466 .35653 .44666 .35572 .44551 .35427 Mtetra
.641 .728 .912 r
.44551 .35427 .44666 .35572 .44867 .355 .44752 .3536 Mtetra
.645 .739 .918 r
.44752 .3536 .44867 .355 .45067 .3543 .44952 .35292 Mtetra
.656 .746 .916 r
.44952 .35292 .45067 .3543 .45268 .35355 .45153 .35218 Mtetra
.671 .755 .913 r
.45153 .35218 .45268 .35355 .45469 .3527 .45354 .35137 Mtetra
.68 .764 .915 r
.45354 .35137 .45469 .3527 .4567 .35181 .45555 .35053 Mtetra
.679 .772 .921 r
.45555 .35053 .4567 .35181 .45872 .35092 .45757 .34968 Mtetra
.66 .774 .934 r
.45757 .34968 .45872 .35092 .46073 .35013 .45958 .34893 Mtetra
.645 .775 .942 r
.45958 .34893 .46073 .35013 .46274 .34942 .46159 .34823 Mtetra
.64 .776 .946 r
.46159 .34823 .46274 .34942 .46475 .34875 .46361 .34756 Mtetra
.569 .749 .962 r
.46361 .34756 .46475 .34875 .46677 .34822 .46562 .34714 Mtetra
.584 .779 .972 r
.46562 .34714 .46677 .34822 .46878 .34765 .46763 .34665 Mtetra
.703 .834 .945 r
.46763 .34665 .46878 .34765 .4708 .34683 .46966 .3457 Mtetra
.895 .823 .768 r
.46966 .3457 .4708 .34683 .47284 .34505 .47171 .34284 Mtetra
.921 .72 .613 r
.47171 .34284 .47284 .34505 .47489 .34225 .47383 .33608 Mtetra
.97 .682 .423 r
.47383 .33608 .47489 .34225 .47696 .33849 .47911 .12531 Mtetra
.512 .276 .493 r
.47911 .12531 .47696 .33849 .47901 .33567 .48105 .12102 Mtetra
.505 .27 .492 r
.48105 .12102 .47901 .33567 .48104 .33486 .48294 .12011 Mtetra
.503 .268 .491 r
.48294 .12011 .48104 .33486 .48305 .33488 .48482 .12005 Mtetra
.503 .269 .492 r
.48482 .12005 .48305 .33488 .48507 .33457 .48671 .11976 Mtetra
.504 .269 .492 r
.48671 .11976 .48507 .33457 .48709 .33397 .48859 .11912 Mtetra
.48859 .11912 .48709 .33397 .48912 .33337 .49049 .11848 Mtetra
.49049 .11848 .48912 .33337 .49115 .33274 .49238 .11783 Mtetra
.49238 .11783 .49115 .33274 .49318 .33209 .49427 .11715 Mtetra
.49427 .11715 .49318 .33209 .49521 .33142 .49617 .11646 Mtetra
.49617 .11646 .49521 .33142 .49724 .33075 .49806 .11576 Mtetra
.49806 .11576 .49724 .33075 .49928 .33008 .49996 .11505 Mtetra
.49996 .11505 .49928 .33008 .50131 .32939 .50186 .11434 Mtetra
.50186 .11434 .50131 .32939 .50335 .3287 .50376 .11363 Mtetra
.50376 .11363 .50335 .3287 .50539 .32801 .50567 .11291 Mtetra
.50567 .11291 .50539 .32801 .50743 .32732 .50757 .11218 Mtetra
.50757 .11218 .50743 .32732 .50947 .32662 .50948 .11146 Mtetra
.50948 .11146 .50947 .32662 .51152 .32593 .51138 .11073 Mtetra
.51138 .11073 .51152 .32593 .51356 .32522 .51329 .11001 Mtetra
.51329 .11001 .51356 .32522 .51561 .32452 .5152 .10928 Mtetra
.5152 .10928 .51561 .32452 .51766 .32382 .51711 .10855 Mtetra
.51711 .10855 .51766 .32382 .51971 .32312 .51902 .10781 Mtetra
.51902 .10781 .51971 .32312 .52176 .32241 .52094 .10708 Mtetra
.52094 .10708 .52176 .32241 .52382 .3217 .52285 .10635 Mtetra
.52285 .10635 .52382 .3217 .52587 .321 .52477 .10561 Mtetra
.52477 .10561 .52587 .321 .52793 .32029 .52668 .10488 Mtetra
.52668 .10488 .52793 .32029 .52999 .31958 .5286 .10414 Mtetra
.5286 .10414 .52999 .31958 .53205 .31887 .53052 .10341 Mtetra
.53052 .10341 .53205 .31887 .53411 .31816 .53244 .10267 Mtetra
.53244 .10267 .53411 .31816 .53617 .31745 .53437 .10193 Mtetra
.53437 .10193 .53617 .31745 .53823 .31674 .53629 .10119 Mtetra
.53629 .10119 .53823 .31674 .5403 .31603 .53822 .10045 Mtetra
.53822 .10045 .5403 .31603 .54237 .31531 .54014 .09971 Mtetra
.54014 .09971 .54237 .31531 .54444 .3146 .54207 .09897 Mtetra
.54207 .09897 .54444 .3146 .54651 .31389 .544 .09823 Mtetra
.544 .09823 .54651 .31389 .54858 .31317 .54593 .09749 Mtetra
.54593 .09749 .54858 .31317 .55065 .31246 .54786 .09675 Mtetra
.54786 .09675 .55065 .31246 .55273 .31174 .5498 .096 Mtetra
.5498 .096 .55273 .31174 .5548 .31102 .55173 .09526 Mtetra
.55173 .09526 .5548 .31102 .55688 .3103 .55367 .09451 Mtetra
.55367 .09451 .55688 .3103 .55896 .30959 .55561 .09377 Mtetra
.55561 .09377 .55896 .30959 .56104 .30886 .55754 .09302 Mtetra
.55754 .09302 .56104 .30886 .56313 .30814 .55948 .09227 Mtetra
.55948 .09227 .56313 .30814 .56521 .30742 .56143 .09152 Mtetra
.56143 .09152 .56521 .30742 .5673 .30669 .56337 .09077 Mtetra
.56337 .09077 .5673 .30669 .56938 .30597 .56531 .09001 Mtetra
.56531 .09001 .56938 .30597 .57147 .30524 .56726 .08926 Mtetra
.56726 .08926 .57147 .30524 .57356 .3045 .56921 .08849 Mtetra
.56921 .08849 .57356 .3045 .57566 .30376 .57115 .08773 Mtetra
.57115 .08773 .57566 .30376 .57775 .30302 .5731 .08695 Mtetra
.5731 .08695 .57775 .30302 .57984 .30226 .57505 .08617 Mtetra
.504 .27 .492 r
.57505 .08617 .57984 .30226 .58194 .3015 .57701 .08538 Mtetra
.57701 .08538 .58194 .3015 .58404 .30071 .57896 .08456 Mtetra
.57896 .08456 .58404 .30071 .58614 .2999 .58091 .08372 Mtetra
.58091 .08372 .58614 .2999 .58824 .29908 .58287 .08288 Mtetra
.505 .27 .492 r
.58287 .08288 .58824 .29908 .59033 .29801 .58482 .08174 Mtetra
.506 .271 .492 r
.58482 .08174 .59033 .29801 .59242 .29657 .58676 .08029 Mtetra
.504 .269 .492 r
.58676 .08029 .59242 .29657 .59453 .29592 .58872 .07968 Mtetra
.497 .264 .491 r
.58872 .07968 .59453 .29592 .59668 .29718 .59076 .08222 Mtetra
0 0 .323 r
.59076 .08222 .59668 .29718 .59887 .29955 .59767 .29302 Mtetra
0 0 .513 r
.59767 .29302 .59887 .29955 .60103 .30096 .59993 .29861 Mtetra
.093 .292 .773 r
.59993 .29861 .60103 .30096 .60318 .30139 .6021 .30019 Mtetra
.561 .755 .968 r
.6021 .30019 .60318 .30139 .6053 .30081 .60423 .29977 Mtetra
.682 .832 .955 r
.60423 .29977 .6053 .30081 .60742 .29998 .60635 .29886 Mtetra
.68 .818 .95 r
.60635 .29886 .60742 .29998 .60954 .29915 .60847 .29797 Mtetra
.562 .757 .97 r
.60847 .29797 .60954 .29915 .61167 .2986 .6106 .29754 Mtetra
.656 .821 .963 r
.6106 .29754 .61167 .2986 .61379 .29784 .61273 .29674 Mtetra
.833 .855 .862 r
.61273 .29674 .61379 .29784 .6159 .29652 .61483 .29488 Mtetra
.937 .774 .655 r
.61483 .29488 .6159 .29652 .61798 .29398 .61683 .28996 Mtetra
.976 .676 .365 r
.61683 .28996 .61798 .29398 .62003 .29057 .61274 .08348 Mtetra
.532 .29 .494 r
.61274 .08348 .62003 .29057 .62206 .28676 .61434 .07028 Mtetra
.506 .271 .492 r
.61434 .07028 .62206 .28676 .62417 .2854 .6163 .0688 Mtetra
.503 .269 .492 r
.6163 .0688 .62417 .2854 .62631 .28512 .61829 .06842 Mtetra
.503 .268 .492 r
.61829 .06842 .62631 .28512 .62847 .28503 .6203 .06836 Mtetra
.504 .269 .492 r
.6203 .06836 .62847 .28503 .6306 .28436 .62228 .06765 Mtetra
.62228 .06765 .6306 .28436 .63274 .28367 .62427 .06694 Mtetra
.62427 .06694 .63274 .28367 .63488 .28297 .62626 .06622 Mtetra
.62626 .06622 .63488 .28297 .63701 .28223 .62825 .06545 Mtetra
.62825 .06545 .63701 .28223 .63915 .28147 .63024 .06467 Mtetra
.63024 .06467 .63915 .28147 .64129 .28068 .63223 .06387 Mtetra
.504 .27 .492 r
.63223 .06387 .64129 .28068 .64344 .27988 .63422 .06306 Mtetra
.63422 .06306 .64344 .27988 .64558 .27906 .63621 .06224 Mtetra
.63621 .06224 .64558 .27906 .64772 .27823 .6382 .06141 Mtetra
.6382 .06141 .64772 .27823 .64986 .27737 .6402 .06057 Mtetra
.6402 .06057 .64986 .27737 .65201 .2765 .64219 .05974 Mtetra
.64219 .05974 .65201 .2765 .65415 .27564 .64419 .05891 Mtetra
.64419 .05891 .65415 .27564 .6563 .2748 .64619 .05809 Mtetra
.504 .269 .492 r
.64619 .05809 .6563 .2748 .65845 .27398 .64819 .05729 Mtetra
.64819 .05729 .65845 .27398 .66061 .27318 .65019 .05649 Mtetra
.65019 .05649 .66061 .27318 .66276 .2724 .6522 .05571 Mtetra
.6522 .05571 .66276 .2724 .66492 .27164 .6542 .05494 Mtetra
.6542 .05494 .66492 .27164 .66708 .27093 .65621 .05419 Mtetra
.65621 .05419 .66708 .27093 .66925 .27027 .65822 .05346 Mtetra
.65822 .05346 .66925 .27027 .67142 .26964 .66024 .05275 Mtetra
.66024 .05275 .67142 .26964 .6736 .26917 .66226 .05212 Mtetra
.503 .269 .492 r
.66226 .05212 .6736 .26917 .67583 .26959 .6643 .05187 Mtetra
.504 .269 .492 r
.6643 .05187 .67583 .26959 .67801 .26904 .66632 .05129 Mtetra
.506 .27 .492 r
.66632 .05129 .67801 .26904 .68008 .26624 .66831 .04985 Mtetra
.509 .273 .492 r
.66831 .04985 .68008 .26624 .6715 .05457 .67021 .04688 Mtetra
.635 .437 .597 r
.67021 .04688 .6715 .05457 .67318 .04715 .67215 .04446 Mtetra
.737 .63 .74 r
.67215 .04446 .67318 .04715 .67507 .04392 .67411 .04265 Mtetra
.657 .769 .932 r
.67411 .04265 .67507 .04392 .67708 .043 .67613 .04191 Mtetra
.579 .773 .971 r
.67613 .04191 .67708 .043 .67912 .04258 .67817 .04143 Mtetra
.55 .747 .969 r
.67817 .04143 .67912 .04258 .68117 .0424 .68021 .04107 Mtetra
.637 .749 .929 r
.68021 .04107 .68117 .0424 .6832 .04177 .68224 .04041 Mtetra
.651 .75 .922 r
.68224 .04041 .6832 .04177 .68523 .04109 .68427 .03969 Mtetra
.664 .749 .914 r
.68427 .03969 .68523 .04109 .68726 .04034 .6863 .03891 Mtetra
.678 .75 .905 r
.6863 .03891 .68726 .04034 .68928 .03951 .68832 .03806 Mtetra
.685 .749 .901 r
.68832 .03806 .68928 .03951 .69131 .03863 .69035 .03717 Mtetra
.691 .75 .896 r
.69035 .03717 .69131 .03863 .69333 .03772 .69237 .03624 Mtetra
.77 .776 .858 r
.69237 .03624 .69333 .03772 .69532 .0363 .69437 .03482 Mtetra
.702 .752 .89 r
.69437 .03482 .69532 .0363 .69734 .03531 .69639 .03383 Mtetra
.516 .665 .929 r
.69639 .03383 .69734 .03531 .69941 .03514 .69846 .03365 Mtetra
.731 .315 0 r
.69846 .03365 .69941 .03514 .7018 .04007 .70084 .03852 Mtetra
.97 .655 .291 r
.70084 .03852 .7018 .04007 .71737 .25563 .71635 .25415 Mtetra
.728 .303 0 r
.71635 .25415 .71737 .25563 .71994 .2606 .71892 .25917 Mtetra
.055 .469 .885 r
.02152 .49748 .02284 .4986 .02438 .49914 .02305 .49802 Mtetra
.648 .756 .928 r
.02305 .49802 .02438 .49914 .02608 .49855 .02476 .49743 Mtetra
.81 .773 .818 r
.02476 .49743 .02608 .49855 .02796 .49682 .02664 .49568 Mtetra
.908 .733 .653 r
.02664 .49568 .02796 .49682 .03049 .4907 .02919 .48945 Mtetra
.937 .686 .534 r
.02919 .48945 .03049 .4907 .06296 .28323 .06177 .28189 Mtetra
.899 .719 .65 r
.06177 .28189 .06296 .28323 .06537 .27724 .06416 .27602 Mtetra
.764 .747 .837 r
.06416 .27602 .06537 .27724 .06707 .27596 .06586 .27477 Mtetra
.625 .721 .915 r
.06586 .27477 .06707 .27596 .06866 .27548 .06745 .2743 Mtetra
.488 .674 .947 r
.06745 .2743 .06866 .27548 .0702 .27538 .06898 .27421 Mtetra
.653 .735 .909 r
.06898 .27421 .0702 .27538 .07182 .27466 .07058 .27363 Mtetra
.665 .765 .925 r
.07058 .27363 .07182 .27466 .07344 .27399 .0722 .27301 Mtetra
.666 .774 .93 r
.0722 .27301 .07344 .27399 .07503 .27354 .07381 .27238 Mtetra
.743 .756 .863 r
.07381 .27238 .07503 .27354 .07655 .27351 .07549 .27133 Mtetra
.654 .601 .783 r
.07549 .27133 .07655 .27351 .078 .27409 .07712 .27057 Mtetra
.535 .448 .704 r
.07712 .27057 .078 .27409 .07925 .27596 .07866 .27046 Mtetra
0 0 .444 r
.07866 .27046 .07925 .27596 .05221 .47532 .07968 .27404 Mtetra
0 0 0 r
.07968 .27404 .05221 .47532 .05238 .48552 .05178 .47942 Mtetra
0 0 .107 r
.05178 .47942 .05238 .48552 .05365 .48813 .05249 .48589 Mtetra
.315 .429 .819 r
.05249 .48589 .05365 .48813 .0553 .48807 .05405 .48649 Mtetra
.612 .67 .881 r
.05405 .48649 .0553 .48807 .05705 .48727 .05575 .48603 Mtetra
.709 .75 .884 r
.05575 .48603 .05705 .48727 .05885 .48618 .05752 .48512 Mtetra
.5 .724 .972 r
.05752 .48512 .05885 .48618 .0605 .48612 .05919 .48495 Mtetra
.607 .737 .937 r
.05919 .48495 .0605 .48612 .06218 .48586 .0609 .4845 Mtetra
.743 .738 .847 r
.0609 .4845 .06218 .48586 .06397 .48485 .06271 .48331 Mtetra
.887 .721 .671 r
.06271 .48331 .06397 .48485 .06635 .47956 .06506 .47832 Mtetra
.94 .687 .527 r
.06506 .47832 .06635 .47956 .09686 .27093 .09544 .27132 Mtetra
.961 .789 .623 r
.09544 .27132 .09686 .27093 .09935 .26408 .09803 .26377 Mtetra
.866 .894 .853 r
.09803 .26377 .09935 .26408 .10111 .26256 .09982 .26199 Mtetra
.68 .865 .969 r
.09982 .26199 .10111 .26256 .10271 .26213 .10146 .26127 Mtetra
.545 .767 .98 r
.10146 .26127 .10271 .26213 .10425 .26216 .10305 .26097 Mtetra
.633 .728 .916 r
.10305 .26097 .10425 .26216 .10585 .26176 .10466 .26046 Mtetra
.643 .712 .898 r
.10466 .26046 .10585 .26176 .10748 .26118 .10629 .25991 Mtetra
.643 .716 .901 r
.10629 .25991 .10748 .26118 .10911 .26054 .10791 .25936 Mtetra
.668 .74 .904 r
.10791 .25936 .10911 .26054 .11079 .25962 .10955 .25871 Mtetra
.68 .796 .936 r
.10955 .25871 .11079 .25962 .11246 .25872 .11119 .25802 Mtetra
.678 .839 .961 r
.11119 .25802 .11246 .25872 .1141 .25804 .11284 .25732 Mtetra
.756 .841 .916 r
.11284 .25732 .1141 .25804 .11567 .25793 .11453 .25629 Mtetra
.685 .673 .833 r
.11453 .25629 .11567 .25793 .11716 .25847 .1162 .25546 Mtetra
.555 .488 .735 r
.1162 .25546 .11716 .25847 .11849 .26019 .11779 .25524 Mtetra
0 .019 .524 r
.11779 .25524 .11849 .26019 .11707 .28288 .11897 .25807 Mtetra
.97 .717 .495 r
.11897 .25807 .11707 .28288 .09412 .4704 .09366 .46283 Mtetra
0 0 .091 r
.09366 .46283 .09412 .4704 .09539 .47346 .09425 .47105 Mtetra
.237 .363 .789 r
.09425 .47105 .09539 .47346 .09702 .47381 .09581 .47192 Mtetra
.634 .639 .838 r
.09581 .47192 .09702 .47381 .09877 .47321 .09757 .47131 Mtetra
.705 .666 .809 r
.09757 .47131 .09877 .47321 .10057 .47222 .09938 .47023 Mtetra
.637 .63 .826 r
.09938 .47023 .10057 .47222 .10236 .47135 .10114 .4696 Mtetra
.6 .643 .865 r
.10114 .4696 .10236 .47135 .10414 .47055 .10288 .46918 Mtetra
.603 .703 .914 r
.10288 .46918 .10414 .47055 .10593 .46977 .10461 .46875 Mtetra
.465 .719 .979 r
.10461 .46875 .10593 .46977 .10765 .46941 .10631 .46863 Mtetra
.53 .795 .994 r
.10631 .46863 .10765 .46941 .10939 .46902 .10804 .4683 Mtetra
.741 .853 .932 r
.10804 .4683 .10939 .46902 .11118 .46816 .10985 .46727 Mtetra
.91 .774 .699 r
.10985 .46727 .11118 .46816 .11322 .46537 .11207 .46304 Mtetra
.944 .687 .518 r
.11207 .46304 .11322 .46537 .11577 .45845 .13963 .25631 Mtetra
.527 .289 .497 r
.13963 .25631 .11577 .45845 .14289 .25359 .14238 .24691 Mtetra
.645 .456 .613 r
.14238 .24691 .14289 .25359 .14505 .24893 .14423 .24475 Mtetra
.595 .465 .673 r
.14423 .24475 .14505 .24893 .1469 .24677 .1459 .24405 Mtetra
.558 .511 .758 r
.1459 .24405 .1469 .24677 .14866 .24534 .14751 .24382 Mtetra
.62 .669 .876 r
.14751 .24382 .14866 .24534 .15035 .24441 .14915 .24335 Mtetra
.667 .766 .924 r
.14915 .24335 .15035 .24441 .15202 .24375 .15081 .2427 Mtetra
.662 .765 .927 r
.15081 .2427 .15202 .24375 .15367 .24321 .15248 .24207 Mtetra
.718 .762 .887 r
.15248 .24207 .15367 .24321 .15539 .24213 .15417 .24116 Mtetra
.704 .792 .919 r
.15417 .24116 .15539 .24213 .15711 .24104 .15586 .24036 Mtetra
.474 .784 .998 r
.15586 .24036 .15711 .24104 .15876 .24054 .15747 .24013 Mtetra
.839 .38 .111 r
.15747 .24013 .15876 .24054 .1601 .2426 .15877 .24264 Mtetra
.947 .683 .503 r
.15877 .24264 .1601 .2426 .13773 .44488 .13595 .44789 Mtetra
.848 .528 .446 r
.13595 .44789 .13773 .44488 .13793 .45753 .13663 .45653 Mtetra
.624 .092 0 r
.13663 .45653 .13793 .45753 .13943 .45934 .13815 .45815 Mtetra
.513 .706 .958 r
.13815 .45815 .13943 .45934 .14116 .45914 .13988 .45797 Mtetra
.761 .777 .866 r
.13988 .45797 .14116 .45914 .14303 .45784 .14174 .45671 Mtetra
.897 .763 .707 r
.14174 .45671 .14303 .45784 .1452 .45388 .14392 .45279 Mtetra
.948 .689 .51 r
.14392 .45279 .1452 .45388 .17058 .24876 .16937 .24778 Mtetra
.94 .722 .579 r
.16937 .24778 .17058 .24876 .17357 .23673 .17239 .23555 Mtetra
.869 .761 .741 r
.17239 .23555 .17357 .23673 .17549 .234 .17431 .23274 Mtetra
.732 .745 .862 r
.17431 .23274 .17549 .234 .1772 .23304 .17604 .2317 Mtetra
.497 .653 .928 r
.17604 .2317 .1772 .23304 .17882 .2329 .17765 .23162 Mtetra
.713 .232 0 r
.17765 .23162 .17882 .2329 .1803 .23402 .17902 .2337 Mtetra
.949 .683 .498 r
.17902 .2337 .1803 .23402 .18148 .23789 .1583 .43198 Mtetra
.539 .294 .492 r
.1583 .43198 .18148 .23789 .1603 .44196 .15818 .44839 Mtetra
.587 .268 .396 r
.15818 .44839 .1603 .44196 .16139 .44764 .15971 .4501 Mtetra
.318 0 .091 r
.15971 .4501 .16139 .44764 .16295 .44914 .1615 .44963 Mtetra
.524 .914 .794 r
.1615 .44963 .16295 .44914 .16463 .44962 .16334 .44857 Mtetra
.722 .796 .91 r
.16334 .44857 .16463 .44962 .16639 .44936 .16518 .4476 Mtetra
.652 .666 .851 r
.16518 .4476 .16639 .44936 .16821 .44862 .16699 .4469 Mtetra
.652 .673 .857 r
.16699 .4469 .16821 .44862 .17005 .44766 .16881 .44622 Mtetra
.561 .679 .918 r
.16881 .44622 .17005 .44766 .17184 .44718 .17057 .44593 Mtetra
.52 .697 .95 r
.17057 .44593 .17184 .44718 .1736 .44696 .17233 .44573 Mtetra
.688 .759 .906 r
.17233 .44573 .1736 .44696 .17543 .44611 .17416 .44492 Mtetra
.884 .768 .728 r
.17416 .44492 .17543 .44611 .17755 .4426 .17626 .44156 Mtetra
.952 .69 .503 r
.17626 .44156 .17755 .4426 .20114 .23616 .19964 .23801 Mtetra
.987 .783 .543 r
.19964 .23801 .20114 .23616 .20396 .22488 .20274 .22415 Mtetra
.897 .816 .76 r
.20274 .22415 .20396 .22488 .20586 .22226 .20466 .22139 Mtetra
.688 .812 .942 r
.20466 .22139 .20586 .22226 .20756 .22163 .20637 .22064 Mtetra
.51 .733 .974 r
.20637 .22064 .20756 .22163 .2092 .22155 .20802 .22043 Mtetra
.53 .714 .957 r
.20802 .22043 .2092 .22155 .21084 .22142 .20968 .22021 Mtetra
.624 .73 .923 r
.20968 .22021 .21084 .22142 .21253 .22095 .21136 .21972 Mtetra
.627 .726 .919 r
.21136 .21972 .21253 .22095 .21421 .22044 .21305 .21921 Mtetra
.637 .729 .915 r
.21305 .21921 .21421 .22044 .21591 .21989 .21474 .21866 Mtetra
.649 .734 .912 r
.21474 .21866 .21591 .21989 .21761 .21929 .21644 .21806 Mtetra
.659 .738 .909 r
.21644 .21806 .21761 .21929 .21931 .21864 .21815 .21743 Mtetra
.671 .743 .905 r
.21815 .21743 .21931 .21864 .22103 .21787 .21986 .21674 Mtetra
.683 .761 .911 r
.21986 .21674 .22103 .21787 .22276 .21702 .22158 .216 Mtetra
.688 .784 .923 r
.22158 .216 .22276 .21702 .22447 .21633 .2233 .21524 Mtetra
.684 .77 .917 r
.2233 .21524 .22447 .21633 .22613 .21619 .22502 .2145 Mtetra
.662 .666 .843 r
.22502 .2145 .22613 .21619 .22772 .21685 .22674 .21378 Mtetra
.62 .527 .727 r
.22674 .21378 .22772 .21685 .22926 .21798 .22846 .21305 Mtetra
.587 .442 .651 r
.22846 .21305 .22926 .21798 .23084 .21872 .23018 .2123 Mtetra
.572 .405 .617 r
.23018 .2123 .23084 .21872 .23256 .21799 .23191 .21151 Mtetra
.571 .404 .616 r
.23191 .21151 .23256 .21799 .23433 .2168 .23364 .21074 Mtetra
.587 .421 .624 r
.23364 .21074 .23433 .2168 .23613 .21533 .23538 .20979 Mtetra
.6 .439 .635 r
.23538 .20979 .23613 .21533 .23792 .21396 .23714 .20875 Mtetra
.568 .422 .643 r
.23714 .20875 .23792 .21396 .23963 .21341 .23885 .20819 Mtetra
.398 .302 .63 r
.23885 .20819 .23963 .21341 .24105 .21593 .24041 .20922 Mtetra
0 0 .132 r
.24041 .20922 .24105 .21593 .2236 .42175 .24132 .21726 Mtetra
0 0 .106 r
.24132 .21726 .2236 .42175 .22485 .42756 .22379 .42427 Mtetra
0 0 .512 r
.22379 .42427 .22485 .42756 .22649 .4291 .22531 .42712 Mtetra
.557 .601 .853 r
.22531 .42712 .22649 .4291 .22831 .42874 .22712 .42688 Mtetra
.681 .669 .832 r
.22712 .42688 .22831 .42874 .23017 .42792 .22899 .42596 Mtetra
.69 .662 .818 r
.22899 .42596 .23017 .42792 .23204 .42704 .23087 .42496 Mtetra
.631 .624 .826 r
.23087 .42496 .23204 .42704 .23389 .42641 .23272 .42433 Mtetra
.631 .625 .826 r
.23272 .42433 .23389 .42641 .23573 .4258 .23457 .4237 Mtetra
.629 .622 .824 r
.23457 .4237 .23573 .4258 .23758 .42525 .23642 .42307 Mtetra
.625 .611 .817 r
.23642 .42307 .23758 .42525 .23941 .42479 .23827 .42246 Mtetra
.621 .596 .803 r
.23827 .42246 .23941 .42479 .24125 .42433 .24012 .42186 Mtetra
.618 .581 .79 r
.24012 .42186 .24125 .42433 .2431 .42382 .24197 .42124 Mtetra
.617 .573 .782 r
.24197 .42124 .2431 .42382 .24495 .42322 .24383 .42062 Mtetra
.617 .571 .779 r
.24383 .42062 .24495 .42322 .24681 .4226 .24568 .42 Mtetra
.62 .572 .779 r
.24568 .42 .24681 .4226 .24866 .42196 .24754 .41935 Mtetra
.624 .573 .777 r
.24754 .41935 .24866 .42196 .25052 .42134 .24941 .41867 Mtetra
.62 .567 .774 r
.24941 .41867 .25052 .42134 .25239 .42068 .25127 .41801 Mtetra
.61 .562 .775 r
.25127 .41801 .25239 .42068 .25426 .41997 .25313 .41743 Mtetra
.596 .564 .789 r
.25313 .41743 .25426 .41997 .25613 .41917 .25498 .41695 Mtetra
.6 .596 .82 r
.25498 .41695 .25613 .41917 .25801 .41836 .25683 .41648 Mtetra
.614 .642 .855 r
.25683 .41648 .25801 .41836 .25989 .41763 .25869 .41596 Mtetra
.637 .679 .873 r
.25869 .41596 .25989 .41763 .26175 .41711 .26056 .41534 Mtetra
.641 .668 .86 r
.26056 .41534 .26175 .41711 .26362 .41645 .26243 .41468 Mtetra
.644 .67 .86 r
.26243 .41468 .26362 .41645 .26552 .41535 .2643 .41402 Mtetra
.65 .737 .913 r
.2643 .41402 .26552 .41535 .26751 .4133 .26617 .41335 Mtetra
.435 .874 .885 r
.26617 .41335 .26751 .4133 .26953 .4107 .26805 .4127 Mtetra
.227 0 0 r
.26805 .4127 .26953 .4107 .27156 .40807 .26992 .41206 Mtetra
.376 .022 .232 r
.26992 .41206 .27156 .40807 .27346 .40708 .2718 .41145 Mtetra
.387 .043 .255 r
.2718 .41145 .27346 .40708 .27532 .40669 .27367 .41084 Mtetra
.394 .044 .248 r
.27367 .41084 .27532 .40669 .27715 .40663 .27554 .41033 Mtetra
.421 .056 .238 r
.27554 .41033 .27715 .40663 .27897 .40673 .27739 .4101 Mtetra
.334 0 .177 r
.27739 .4101 .27897 .40673 .28085 .40605 .27928 .4094 Mtetra
.055 0 .041 r
.27928 .4094 .28085 .40605 .2829 .40315 .28126 .40745 Mtetra
.828 .823 .345 r
.28126 .40745 .2829 .40315 .30016 .19591 .28366 .39994 Mtetra
0 0 .124 r
.28366 .39994 .30016 .19591 .30248 .1877 .30115 .18908 Mtetra
.973 .918 .594 r
.30115 .18908 .30248 .1877 .30443 .18457 .30323 .18417 Mtetra
.764 .927 .941 r
.30323 .18417 .30443 .18457 .30621 .18355 .30503 .18302 Mtetra
.555 .857 .997 r
.30503 .18302 .30621 .18355 .30797 .18301 .30678 .18253 Mtetra
.431 .814 .99 r
.30678 .18253 .30797 .18301 .30971 .18268 .30852 .18225 Mtetra
.67 .911 .977 r
.30852 .18225 .30971 .18268 .31146 .18217 .3103 .18143 Mtetra
.693 .854 .959 r
.3103 .18143 .31146 .18217 .31322 .18168 .31208 .18062 Mtetra
.687 .786 .926 r
.31208 .18062 .31322 .18168 .31498 .18116 .31385 .17984 Mtetra
.661 .729 .9 r
.31385 .17984 .31498 .18116 .31674 .18054 .31562 .17917 Mtetra
.654 .719 .896 r
.31562 .17917 .31674 .18054 .31852 .17985 .31739 .17852 Mtetra
.654 .726 .902 r
.31739 .17852 .31852 .17985 .32029 .17908 .31917 .17787 Mtetra
.665 .751 .915 r
.31917 .17787 .32029 .17908 .32209 .1781 .32094 .17719 Mtetra
.665 .81 .953 r
.32094 .17719 .32209 .1781 .32387 .17725 .32272 .17649 Mtetra
.66 .842 .97 r
.32272 .17649 .32387 .17725 .32564 .17674 .3245 .17579 Mtetra
.665 .804 .949 r
.3245 .17579 .32564 .17674 .32734 .17723 .32627 .1751 Mtetra
.64 .612 .805 r
.32627 .1751 .32734 .17723 .32901 .17827 .32805 .17441 Mtetra
.602 .484 .691 r
.32805 .17441 .32901 .17827 .33066 .17958 .32984 .17367 Mtetra
.6 .434 .628 r
.32984 .17367 .33066 .17958 .33247 .17847 .33165 .17252 Mtetra
.574 .414 .627 r
.33165 .17252 .33247 .17847 .33427 .17756 .33344 .17176 Mtetra
.507 .37 .629 r
.33344 .17176 .33427 .17756 .33598 .17804 .33517 .17188 Mtetra
0 0 .455 r
.33517 .17188 .33598 .17804 .32491 .38353 .33661 .17666 Mtetra
0 0 .171 r
.33661 .17666 .32491 .38353 .32626 .39181 .32527 .38709 Mtetra
0 0 .374 r
.32527 .38709 .32626 .39181 .32799 .39426 .32684 .39203 Mtetra
.453 .522 .839 r
.32684 .39203 .32799 .39426 .32987 .39421 .32871 .39224 Mtetra
.622 .638 .845 r
.32871 .39224 .32987 .39421 .33179 .39349 .33062 .39165 Mtetra
.686 .682 .84 r
.33062 .39165 .33179 .39349 .33375 .39224 .33256 .3907 Mtetra
.532 .661 .919 r
.33256 .3907 .33375 .39224 .33572 .39073 .33445 .3905 Mtetra
.52 .896 .962 r
.33445 .3905 .33572 .39073 .33773 .38849 .33638 .38985 Mtetra
0 0 0 r
.33638 .38985 .33773 .38849 .33984 .38465 .33835 .38836 Mtetra
.727 .786 .298 r
.33835 .38836 .33984 .38465 .35354 .17779 .34058 .38235 Mtetra
0 0 .161 r
.34058 .38235 .35354 .17779 .35587 .16772 .35453 .17055 Mtetra
.911 .867 .43 r
.35453 .17055 .35587 .16772 .35782 .16428 .35666 .16393 Mtetra
.824 .941 .903 r
.35666 .16393 .35782 .16428 .35964 .1633 .35851 .16244 Mtetra
.672 .827 .958 r
.35851 .16244 .35964 .1633 .36142 .16287 .36031 .1617 Mtetra
.564 .727 .951 r
.36031 .1617 .36142 .16287 .3632 .16274 .36209 .16137 Mtetra
.647 .72 .901 r
.36209 .16137 .3632 .16274 .36499 .16216 .36389 .16074 Mtetra
.636 .707 .898 r
.36389 .16074 .36499 .16216 .36679 .16154 .36569 .16016 Mtetra
.632 .714 .906 r
.36569 .16016 .36679 .16154 .3686 .16085 .36749 .1596 Mtetra
.65 .742 .917 r
.36749 .1596 .3686 .16085 .37041 .16006 .3693 .15896 Mtetra
.655 .775 .938 r
.3693 .15896 .37041 .16006 .37223 .15923 .3711 .15831 Mtetra
.656 .812 .958 r
.3711 .15831 .37223 .15923 .37404 .1584 .37291 .15763 Mtetra
.653 .842 .973 r
.37291 .15763 .37404 .1584 .37585 .15766 .37472 .15694 Mtetra
.654 .855 .977 r
.37472 .15694 .37585 .15766 .37767 .15695 .37654 .15624 Mtetra
.66 .858 .975 r
.37654 .15624 .37767 .15695 .37948 .15627 .37835 .15551 Mtetra
.672 .851 .968 r
.37835 .15551 .37948 .15627 .38129 .15566 .38017 .15475 Mtetra
.68 .823 .952 r
.38017 .15475 .38129 .15566 .3831 .15506 .38199 .15398 Mtetra
.683 .789 .93 r
.38199 .15398 .3831 .15506 .38491 .15444 .38381 .15321 Mtetra
.763 .779 .866 r
.38381 .15321 .38491 .15444 .38675 .15338 .38566 .15195 Mtetra
.702 .731 .873 r
.38566 .15195 .38675 .15338 .38857 .15252 .38749 .15103 Mtetra
.538 .656 .912 r
.38749 .15103 .38857 .15252 .39038 .15215 .38928 .15082 Mtetra
.852 .423 0 r
.38928 .15082 .39038 .15215 .39208 .15404 .3909 .15479 Mtetra
.967 .681 .436 r
.3909 .15479 .39208 .15404 .39352 .1621 .3833 .3662 Mtetra
.513 .271 .485 r
.3833 .3662 .39352 .1621 .38638 .36807 .38497 .37203 Mtetra
.499 .135 .28 r
.38497 .37203 .38638 .36807 .38819 .37087 .38689 .37244 Mtetra
.158 0 0 r
.38689 .37244 .38819 .37087 .39008 .37186 .38885 .37176 Mtetra
.685 .968 .929 r
.38885 .37176 .39008 .37186 .392 .3721 .39083 .37059 Mtetra
.594 .697 .915 r
.39083 .37059 .392 .3721 .39394 .37205 .39279 .37015 Mtetra
.64 .659 .853 r
.39279 .37015 .39394 .37205 .3959 .3715 .39475 .36946 Mtetra
.734 .681 .799 r
.39475 .36946 .3959 .3715 .39789 .37029 .39675 .36802 Mtetra
.896 .709 .641 r
.39675 .36802 .39789 .37029 .39996 .36703 .39891 .36243 Mtetra
.967 .685 .445 r
.39891 .36243 .39996 .36703 .40219 .35946 .40913 .14982 Mtetra
.519 .281 .494 r
.40913 .14982 .40219 .35946 .4121 .14952 .41121 .14288 Mtetra
.625 .441 .614 r
.41121 .14288 .4121 .14952 .41408 .14498 .41309 .14108 Mtetra
.6 .483 .692 r
.41309 .14108 .41408 .14498 .41598 .14266 .41493 .14034 Mtetra
.574 .565 .805 r
.41493 .14034 .41598 .14266 .41785 .14112 .41676 .14001 Mtetra
.654 .776 .938 r
.41676 .14001 .41785 .14112 .41969 .14023 .4186 .13934 Mtetra
.668 .827 .96 r
.4186 .13934 .41969 .14023 .42153 .13965 .42044 .1386 Mtetra
.66 .791 .944 r
.42044 .1386 .42153 .13965 .42336 .1392 .42228 .13791 Mtetra
.715 .762 .89 r
.42228 .13791 .42336 .1392 .42522 .13816 .42414 .13694 Mtetra
.671 .762 .919 r
.42414 .13694 .42522 .13816 .42707 .13717 .42598 .1362 Mtetra
.442 .72 .984 r
.42598 .1362 .42707 .13717 .42891 .13664 .42781 .13611 Mtetra
.843 .378 .027 r
.42781 .13611 .42891 .13664 .43069 .13821 .42953 .1395 Mtetra
.969 .679 .423 r
.42953 .1395 .43069 .13821 .43232 .14437 .42469 .3507 Mtetra
.515 .272 .485 r
.42469 .3507 .43232 .14437 .42779 .35269 .42645 .35727 Mtetra
.527 .175 .313 r
.42645 .35727 .42779 .35269 .4297 .35428 .42839 .358 Mtetra
.368 .007 .214 r
.42839 .358 .4297 .35428 .4317 .35351 .43038 .35737 Mtetra
.304 0 .198 r
.43038 .35737 .4317 .35351 .4337 .35242 .43239 .35627 Mtetra
.352 0 .216 r
.43239 .35627 .4337 .35242 .43564 .35346 .43439 .35549 Mtetra
.245 0 .001 r
.43439 .35549 .43564 .35346 .43758 .35475 .43638 .35484 Mtetra
.386 .848 .842 r
.43638 .35484 .43758 .35475 .43953 .35553 .43838 .35415 Mtetra
.673 .753 .911 r
.43838 .35415 .43953 .35553 .44152 .35545 .44038 .35333 Mtetra
.663 .648 .825 r
.44038 .35333 .44152 .35545 .44351 .35494 .44239 .35245 Mtetra
.65 .606 .791 r
.44239 .35245 .44351 .35494 .44551 .35427 .44439 .35157 Mtetra
.629 .578 .778 r
.44439 .35157 .44551 .35427 .44752 .3536 .4464 .3508 Mtetra
.617 .564 .773 r
.4464 .3508 .44752 .3536 .44952 .35292 .4484 .35012 Mtetra
.613 .562 .773 r
.4484 .35012 .44952 .35292 .45153 .35218 .45041 .34945 Mtetra
.618 .57 .778 r
.45041 .34945 .45153 .35218 .45354 .35137 .45242 .34877 Mtetra
.623 .582 .788 r
.45242 .34877 .45354 .35137 .45555 .35053 .45443 .34807 Mtetra
.626 .597 .801 r
.45443 .34807 .45555 .35053 .45757 .34968 .45644 .34737 Mtetra
.627 .612 .815 r
.45644 .34737 .45757 .34968 .45958 .34893 .45845 .34669 Mtetra
.628 .62 .823 r
.45845 .34669 .45958 .34893 .46159 .34823 .46046 .34602 Mtetra
.629 .622 .825 r
.46046 .34602 .46159 .34823 .46361 .34756 .46248 .34534 Mtetra
.563 .589 .837 r
.46248 .34534 .46361 .34756 .46562 .34714 .46449 .34504 Mtetra
.584 .613 .847 r
.46449 .34504 .46562 .34714 .46763 .34665 .4665 .34464 Mtetra
.694 .673 .825 r
.4665 .34464 .46763 .34665 .46966 .3457 .46853 .34355 Mtetra
.88 .72 .68 r
.46853 .34355 .46966 .3457 .47171 .34284 .47061 .33937 Mtetra
.972 .685 .42 r
.47061 .33937 .47171 .34284 .47383 .33608 .47611 .12813 Mtetra
.526 .286 .495 r
.47611 .12813 .47383 .33608 .47911 .12531 .47815 .11782 Mtetra
.642 .444 .6 r
.47815 .11782 .47911 .12531 .48105 .12102 .48006 .11536 Mtetra
.582 .427 .636 r
.48006 .11536 .48105 .12102 .48294 .12011 .48195 .11452 Mtetra
.547 .404 .639 r
.48195 .11452 .48294 .12011 .48482 .12005 .48383 .11415 Mtetra
.555 .404 .631 r
.48383 .11415 .48482 .12005 .48671 .11976 .48571 .11365 Mtetra
.566 .408 .627 r
.48571 .11365 .48671 .11976 .48859 .11912 .4876 .11296 Mtetra
.565 .407 .626 r
.4876 .11296 .48859 .11912 .49049 .11848 .48949 .11228 Mtetra
.566 .407 .625 r
.48949 .11228 .49049 .11848 .49238 .11783 .49138 .11158 Mtetra
.566 .406 .624 r
.49138 .11158 .49238 .11783 .49427 .11715 .49327 .11087 Mtetra
.566 .406 .623 r
.49327 .11087 .49427 .11715 .49617 .11646 .49517 .11016 Mtetra
.49517 .11016 .49617 .11646 .49806 .11576 .49706 .10944 Mtetra
.566 .405 .622 r
.49706 .10944 .49806 .11576 .49996 .11505 .49896 .10872 Mtetra
.49896 .10872 .49996 .11505 .50186 .11434 .50086 .108 Mtetra
.50086 .108 .50186 .11434 .50376 .11363 .50275 .10727 Mtetra
.50275 .10727 .50376 .11363 .50567 .11291 .50465 .10655 Mtetra
.50465 .10655 .50567 .11291 .50757 .11218 .50656 .10582 Mtetra
.50656 .10582 .50757 .11218 .50948 .11146 .50846 .10509 Mtetra
.50846 .10509 .50948 .11146 .51138 .11073 .51036 .10436 Mtetra
.566 .405 .621 r
.51036 .10436 .51138 .11073 .51329 .11001 .51227 .10362 Mtetra
.51227 .10362 .51329 .11001 .5152 .10928 .51418 .10289 Mtetra
.51418 .10289 .5152 .10928 .51711 .10855 .51608 .10216 Mtetra
.51608 .10216 .51711 .10855 .51902 .10781 .51799 .10142 Mtetra
.51799 .10142 .51902 .10781 .52094 .10708 .5199 .10069 Mtetra
.5199 .10069 .52094 .10708 .52285 .10635 .52182 .09995 Mtetra
.52182 .09995 .52285 .10635 .52477 .10561 .52373 .09921 Mtetra
.52373 .09921 .52477 .10561 .52668 .10488 .52565 .09848 Mtetra
.52565 .09848 .52668 .10488 .5286 .10414 .52756 .09774 Mtetra
.52756 .09774 .5286 .10414 .53052 .10341 .52948 .097 Mtetra
.566 .404 .621 r
.52948 .097 .53052 .10341 .53244 .10267 .5314 .09626 Mtetra
.5314 .09626 .53244 .10267 .53437 .10193 .53332 .09552 Mtetra
.53332 .09552 .53437 .10193 .53629 .10119 .53524 .09478 Mtetra
.53524 .09478 .53629 .10119 .53822 .10045 .53716 .09404 Mtetra
.53716 .09404 .53822 .10045 .54014 .09971 .53909 .0933 Mtetra
.53909 .0933 .54014 .09971 .54207 .09897 .54101 .09256 Mtetra
.54101 .09256 .54207 .09897 .544 .09823 .54294 .09181 Mtetra
.566 .405 .621 r
.54294 .09181 .544 .09823 .54593 .09749 .54487 .09107 Mtetra
.54487 .09107 .54593 .09749 .54786 .09675 .5468 .09033 Mtetra
.5468 .09033 .54786 .09675 .5498 .096 .54873 .08958 Mtetra
.54873 .08958 .5498 .096 .55173 .09526 .55066 .08884 Mtetra
.55066 .08884 .55173 .09526 .55367 .09451 .55259 .08809 Mtetra
.567 .405 .621 r
.55259 .08809 .55367 .09451 .55561 .09377 .55453 .08735 Mtetra
.55453 .08735 .55561 .09377 .55754 .09302 .55647 .0866 Mtetra
.55647 .0866 .55754 .09302 .55948 .09227 .5584 .08585 Mtetra
.5584 .08585 .55948 .09227 .56143 .09152 .56034 .0851 Mtetra
.56034 .0851 .56143 .09152 .56337 .09077 .56228 .08435 Mtetra
.56228 .08435 .56337 .09077 .56531 .09001 .56423 .0836 Mtetra
.567 .405 .622 r
.56423 .0836 .56531 .09001 .56726 .08926 .56617 .08285 Mtetra
.56617 .08285 .56726 .08926 .56921 .08849 .56811 .08209 Mtetra
.567 .406 .622 r
.56811 .08209 .56921 .08849 .57115 .08773 .57006 .08133 Mtetra
.57006 .08133 .57115 .08773 .5731 .08695 .57201 .08057 Mtetra
.568 .406 .622 r
.57201 .08057 .5731 .08695 .57505 .08617 .57395 .07981 Mtetra
.568 .407 .623 r
.57395 .07981 .57505 .08617 .57701 .08538 .5759 .07903 Mtetra
.569 .408 .623 r
.5759 .07903 .57701 .08538 .57896 .08456 .57785 .07825 Mtetra
.57 .409 .624 r
.57785 .07825 .57896 .08456 .58091 .08372 .57981 .07746 Mtetra
.57 .41 .625 r
.57981 .07746 .58091 .08372 .58287 .08288 .58176 .07667 Mtetra
.581 .418 .625 r
.58176 .07667 .58287 .08288 .58482 .08174 .58371 .07571 Mtetra
.594 .43 .629 r
.58371 .07571 .58482 .08174 .58676 .08029 .58566 .07458 Mtetra
.567 .417 .637 r
.58566 .07458 .58676 .08029 .58872 .07968 .58762 .07392 Mtetra
.443 .333 .634 r
.58762 .07392 .58872 .07968 .59076 .08222 .58961 .07478 Mtetra
0 0 .407 r
.58961 .07478 .59076 .08222 .59767 .29302 .59178 .08296 Mtetra
0 0 .315 r
.59178 .08296 .59767 .29302 .59993 .29861 .5988 .29497 Mtetra
0 .108 .63 r
.5988 .29497 .59993 .29861 .6021 .30019 .601 .29798 Mtetra
.556 .593 .846 r
.601 .29798 .6021 .30019 .60423 .29977 .60314 .29769 Mtetra
.674 .668 .836 r
.60314 .29769 .60423 .29977 .60635 .29886 .60525 .29672 Mtetra
.67 .658 .83 r
.60525 .29672 .60635 .29886 .60847 .29797 .60737 .29576 Mtetra
.56 .595 .846 r
.60737 .29576 .60847 .29797 .6106 .29754 .60951 .29545 Mtetra
.653 .657 .841 r
.60951 .29545 .6106 .29754 .61273 .29674 .61163 .29462 Mtetra
.816 .719 .758 r
.61163 .29462 .61273 .29674 .61483 .29488 .61371 .29218 Mtetra
.947 .709 .545 r
.61371 .29218 .61483 .29488 .61683 .28996 .61557 .28214 Mtetra
.974 .672 .371 r
.61557 .28214 .61683 .28996 .61274 .08348 .61133 .06856 Mtetra
.619 .39 .548 r
.61133 .06856 .61274 .08348 .61434 .07028 .61321 .06431 Mtetra
.598 .433 .63 r
.61321 .06431 .61434 .07028 .6163 .0688 .61517 .06314 Mtetra
.56 .414 .639 r
.61517 .06314 .6163 .0688 .61829 .06842 .61716 .06258 Mtetra
.546 .401 .635 r
.61716 .06258 .61829 .06842 .6203 .06836 .61915 .0622 Mtetra
.568 .41 .627 r
.61915 .0622 .6203 .06836 .62228 .06765 .62113 .06145 Mtetra
.567 .409 .627 r
.62113 .06145 .62228 .06765 .62427 .06694 .62311 .06071 Mtetra
.567 .409 .626 r
.62311 .06071 .62427 .06694 .62626 .06622 .6251 .05997 Mtetra
.569 .409 .626 r
.6251 .05997 .62626 .06622 .62825 .06545 .62709 .0592 Mtetra
.569 .41 .626 r
.62709 .0592 .62825 .06545 .63024 .06467 .62907 .05843 Mtetra
.57 .41 .626 r
.62907 .05843 .63024 .06467 .63223 .06387 .63106 .05764 Mtetra
.57 .411 .626 r
.63106 .05764 .63223 .06387 .63422 .06306 .63305 .05686 Mtetra
.57 .411 .627 r
.63305 .05686 .63422 .06306 .63621 .06224 .63504 .05606 Mtetra
.571 .412 .627 r
.63504 .05606 .63621 .06224 .6382 .06141 .63703 .05527 Mtetra
.571 .413 .628 r
.63703 .05527 .6382 .06141 .6402 .06057 .63903 .05448 Mtetra
.572 .414 .629 r
.63903 .05448 .6402 .06057 .64219 .05974 .64102 .05369 Mtetra
.572 .415 .63 r
.64102 .05369 .64219 .05974 .64419 .05891 .64302 .0529 Mtetra
.572 .416 .631 r
.64302 .0529 .64419 .05891 .64619 .05809 .64502 .05211 Mtetra
.572 .416 .632 r
.64502 .05211 .64619 .05809 .64819 .05729 .64702 .05133 Mtetra
.572 .417 .632 r
.64702 .05133 .64819 .05729 .65019 .05649 .64902 .05055 Mtetra
.572 .417 .633 r
.64902 .05055 .65019 .05649 .6522 .05571 .65102 .04977 Mtetra
.65102 .04977 .6522 .05571 .6542 .05494 .65302 .049 Mtetra
.571 .417 .633 r
.65302 .049 .6542 .05494 .65621 .05419 .65503 .04824 Mtetra
.571 .416 .633 r
.65503 .04824 .65621 .05419 .65822 .05346 .65704 .04748 Mtetra
.57 .415 .632 r
.65704 .04748 .65822 .05346 .66024 .05275 .65905 .04673 Mtetra
.568 .413 .631 r
.65905 .04673 .66024 .05275 .66226 .05212 .66106 .046 Mtetra
.566 .41 .629 r
.66106 .046 .66226 .05212 .6643 .05187 .66307 .04528 Mtetra
.561 .4 .62 r
.66307 .04528 .6643 .05187 .66632 .05129 .66509 .04458 Mtetra
.561 .398 .618 r
.66509 .04458 .66632 .05129 .66831 .04985 .66711 .04387 Mtetra
.569 .415 .632 r
.66711 .04387 .66831 .04985 .67021 .04688 .66913 .04314 Mtetra
.599 .495 .707 r
.66913 .04314 .67021 .04688 .67215 .04446 .67115 .0424 Mtetra
.638 .64 .835 r
.67115 .0424 .67215 .04446 .67411 .04265 .67317 .04169 Mtetra
.627 .821 .975 r
.67317 .04169 .67411 .04265 .67613 .04191 .6752 .04102 Mtetra
.618 .835 .983 r
.6752 .04102 .67613 .04191 .67817 .04143 .67722 .04036 Mtetra
.634 .802 .963 r
.67722 .04036 .67817 .04143 .68021 .04107 .67925 .03969 Mtetra
.649 .747 .921 r
.67925 .03969 .68021 .04107 .68224 .04041 .68128 .03898 Mtetra
.656 .741 .912 r
.68128 .03898 .68224 .04041 .68427 .03969 .68331 .03824 Mtetra
.665 .74 .906 r
.68331 .03824 .68427 .03969 .6863 .03891 .68534 .03744 Mtetra
.68 .744 .899 r
.68534 .03744 .6863 .03891 .68832 .03806 .68736 .03658 Mtetra
.685 .744 .895 r
.68736 .03658 .68832 .03806 .69035 .03717 .68939 .03568 Mtetra
.691 .745 .892 r
.68939 .03568 .69035 .03717 .69237 .03624 .69141 .03474 Mtetra
.768 .772 .856 r
.69141 .03474 .69237 .03624 .69437 .03482 .69341 .03332 Mtetra
.701 .749 .888 r
.69341 .03332 .69437 .03482 .69639 .03383 .69543 .03234 Mtetra
.518 .663 .927 r
.69543 .03234 .69639 .03383 .69846 .03365 .6975 .03216 Mtetra
.722 .307 0 r
.6975 .03216 .69846 .03365 .70084 .03852 .69988 .03694 Mtetra
.97 .655 .291 r
.69988 .03694 .70084 .03852 .71635 .25415 .71533 .25262 Mtetra
.728 .306 0 r
.71533 .25262 .71635 .25415 .71892 .25917 .7179 .25772 Mtetra
.043 .458 .879 r
.0202 .49634 .02152 .49748 .02305 .49802 .02172 .49691 Mtetra
.649 .756 .928 r
.02172 .49691 .02305 .49802 .02476 .49743 .02343 .49631 Mtetra
.814 .772 .814 r
.02343 .49631 .02476 .49743 .02664 .49568 .02532 .49451 Mtetra
.91 .728 .643 r
.02532 .49451 .02664 .49568 .02919 .48945 .02796 .48768 Mtetra
.936 .686 .534 r
.02796 .48768 .02919 .48945 .06177 .28189 .06068 .27982 Mtetra
.869 .685 .651 r
.06068 .27982 .06177 .28189 .06416 .27602 .06301 .27442 Mtetra
.728 .688 .812 r
.06301 .27442 .06416 .27602 .06586 .27477 .06469 .27329 Mtetra
.592 .662 .886 r
.06469 .27329 .06586 .27477 .06745 .2743 .06626 .27295 Mtetra
.445 .621 .926 r
.06626 .27295 .06745 .2743 .06898 .27421 .06777 .27299 Mtetra
.63 .72 .911 r
.06777 .27299 .06898 .27421 .07058 .27363 .06936 .2725 Mtetra
.655 .743 .914 r
.06936 .2725 .07058 .27363 .0722 .27301 .07097 .27192 Mtetra
.672 .754 .912 r
.07097 .27192 .0722 .27301 .07381 .27238 .07259 .27126 Mtetra
.753 .762 .86 r
.07259 .27126 .07381 .27238 .07549 .27133 .07427 .27014 Mtetra
.72 .747 .873 r
.07427 .27014 .07549 .27133 .07712 .27057 .07593 .26922 Mtetra
.62 .693 .896 r
.07593 .26922 .07712 .27057 .07866 .27046 .07753 .26877 Mtetra
0 .049 .605 r
.07753 .26877 .07866 .27046 .07968 .27404 .07885 .2702 Mtetra
.757 .494 0 r
.07885 .2702 .07968 .27404 .05178 .47942 .07972 .27479 Mtetra
0 0 0 r
.07972 .27479 .05178 .47942 .05249 .48589 .05218 .47774 Mtetra
.015 0 .453 r
.05218 .47774 .05249 .48589 .05405 .48649 .05318 .48219 Mtetra
.231 .22 .639 r
.05318 .48219 .05405 .48649 .05575 .48603 .0546 .48377 Mtetra
.331 .437 .818 r
.0546 .48377 .05575 .48603 .05752 .48512 .05616 .48433 Mtetra
.404 .737 .992 r
.05616 .48433 .05752 .48512 .05919 .48495 .05782 .48425 Mtetra
.648 .841 .975 r
.05782 .48425 .05919 .48495 .0609 .4845 .05955 .4836 Mtetra
.779 .816 .881 r
.05955 .4836 .0609 .4845 .06271 .48331 .06138 .48231 Mtetra
.876 .776 .747 r
.06138 .48231 .06271 .48331 .06506 .47832 .06345 .47931 Mtetra
.978 .842 .641 r
.06345 .47931 .06506 .47832 .09544 .27132 .066 .47286 Mtetra
0 0 0 r
.066 .47286 .09544 .27132 .09803 .26377 .09591 .26913 Mtetra
.09591 .26913 .09803 .26377 .09982 .26199 .09819 .26385 Mtetra
.713 .91 .551 r
.09819 .26385 .09982 .26199 .10146 .26127 .10009 .26126 Mtetra
.858 .949 .873 r
.10009 .26126 .10146 .26127 .10305 .26097 .10187 .25959 Mtetra
.694 .713 .863 r
.10187 .25959 .10305 .26097 .10466 .26046 .10353 .25878 Mtetra
.61 .639 .854 r
.10353 .25878 .10466 .26046 .10629 .25991 .10513 .25834 Mtetra
.57 .64 .881 r
.10513 .25834 .10629 .25991 .10791 .25936 .10672 .25807 Mtetra
.636 .712 .901 r
.10672 .25807 .10791 .25936 .10955 .25871 .10834 .25755 Mtetra
.668 .744 .907 r
.10834 .25755 .10955 .25871 .11119 .25802 .10998 .2569 Mtetra
.682 .755 .906 r
.10998 .2569 .11119 .25802 .11284 .25732 .11163 .25619 Mtetra
.746 .763 .867 r
.11163 .25619 .11284 .25732 .11453 .25629 .11333 .25511 Mtetra
.726 .753 .874 r
.11333 .25511 .11453 .25629 .1162 .25546 .11502 .25415 Mtetra
.636 .708 .898 r
.11502 .25415 .1162 .25546 .11779 .25524 .11664 .25362 Mtetra
0 .114 .658 r
.11664 .25362 .11779 .25524 .11897 .25807 .11803 .25495 Mtetra
.836 .52 0 r
.11803 .25495 .11897 .25807 .09366 .46283 .119 .25944 Mtetra
0 0 .016 r
.119 .25944 .09366 .46283 .09425 .47105 .09396 .46221 Mtetra
.339 .207 .55 r
.09396 .46221 .09425 .47105 .09581 .47192 .09533 .46449 Mtetra
.571 .397 .607 r
.09533 .46449 .09581 .47192 .09757 .47131 .09712 .46362 Mtetra
.58 .402 .604 r
.09712 .46362 .09757 .47131 .09938 .47023 .09893 .46253 Mtetra
.321 .206 .563 r
.09893 .46253 .09938 .47023 .10114 .4696 .10033 .46469 Mtetra
.187 .168 .603 r
.10033 .46469 .10114 .4696 .10288 .46918 .10175 .46674 Mtetra
.116 .283 .758 r
.10175 .46674 .10288 .46918 .10461 .46875 .10328 .4679 Mtetra
.085 .546 .905 r
.10328 .4679 .10461 .46875 .10631 .46863 .10491 .46828 Mtetra
.412 .824 .974 r
.10491 .46828 .10631 .46863 .10804 .4683 .10664 .46797 Mtetra
.76 .926 .943 r
.10664 .46797 .10804 .4683 .10985 .46727 .10847 .46682 Mtetra
.93 .807 .701 r
.10847 .46682 .10985 .46727 .11207 .46304 .1107 .4625 Mtetra
.946 .689 .517 r
.1107 .4625 .11207 .46304 .13963 .25631 .13849 .25468 Mtetra
.917 .707 .603 r
.13849 .25468 .13963 .25631 .14238 .24691 .14125 .24525 Mtetra
.804 .707 .758 r
.14125 .24525 .14238 .24691 .14423 .24475 .14308 .24319 Mtetra
.633 .669 .866 r
.14308 .24319 .14423 .24475 .1459 .24405 .14473 .24265 Mtetra
.483 .633 .92 r
.14473 .24265 .1459 .24405 .14751 .24382 .14632 .24262 Mtetra
.624 .727 .921 r
.14632 .24262 .14751 .24382 .14915 .24335 .14796 .24213 Mtetra
.682 .741 .896 r
.14796 .24213 .14915 .24335 .15081 .2427 .14963 .2414 Mtetra
.638 .714 .902 r
.14963 .2414 .15081 .2427 .15248 .24207 .15129 .24086 Mtetra
.447 .656 .95 r
.15129 .24086 .15248 .24207 .15417 .24116 .15287 .24087 Mtetra
.429 0 0 r
.15287 .24087 .15417 .24116 .15586 .24036 .15437 .2416 Mtetra
.733 .318 .262 r
.15437 .2416 .15586 .24036 .15747 .24013 .15572 .24365 Mtetra
.942 .677 .506 r
.15572 .24365 .15747 .24013 .15877 .24264 .1341 .43731 Mtetra
.537 .292 .491 r
.1341 .43731 .15877 .24264 .13595 .44789 .13392 .45302 Mtetra
.668 .338 .406 r
.13392 .45302 .13595 .44789 .13663 .45653 .13527 .456 Mtetra
.478 0 0 r
.13527 .456 .13663 .45653 .13815 .45815 .13686 .45699 Mtetra
.469 .694 .965 r
.13686 .45699 .13815 .45815 .13988 .45797 .13859 .45691 Mtetra
.73 .793 .902 r
.13859 .45691 .13988 .45797 .14174 .45671 .14042 .45589 Mtetra
.908 .794 .724 r
.14042 .45589 .14174 .45671 .14392 .45279 .14256 .45225 Mtetra
.949 .69 .51 r
.14256 .45225 .14392 .45279 .16937 .24778 .16765 .25115 Mtetra
.994 .791 .526 r
.16765 .25115 .16937 .24778 .17239 .23555 .17119 .23444 Mtetra
.877 .768 .738 r
.17119 .23444 .17239 .23555 .17431 .23274 .17313 .23152 Mtetra
.738 .754 .865 r
.17313 .23152 .17431 .23274 .17604 .2317 .17486 .23046 Mtetra
.485 .665 .942 r
.17486 .23046 .17604 .2317 .17765 .23162 .17648 .23038 Mtetra
.764 .288 0 r
.17648 .23038 .17765 .23162 .17902 .2337 .17783 .23265 Mtetra
.95 .685 .498 r
.17783 .23265 .17902 .2337 .1583 .43198 .15638 .43659 Mtetra
.844 .535 .466 r
.15638 .43659 .1583 .43198 .15818 .44839 .15681 .44799 Mtetra
.664 .11 0 r
.15681 .44799 .15818 .44839 .15971 .4501 .15838 .44945 Mtetra
.646 .86 .981 r
.15838 .44945 .15971 .4501 .1615 .44963 .16019 .44876 Mtetra
.781 .833 .892 r
.16019 .44876 .1615 .44963 .16334 .44857 .16206 .44745 Mtetra
.745 .788 .888 r
.16206 .44745 .16334 .44857 .16518 .4476 .16392 .44633 Mtetra
.667 .746 .909 r
.16392 .44633 .16518 .4476 .16699 .4469 .16573 .44561 Mtetra
.655 .739 .911 r
.16573 .44561 .16699 .4469 .16881 .44622 .16754 .44495 Mtetra
.542 .705 .945 r
.16754 .44495 .16881 .44622 .17057 .44593 .16931 .44469 Mtetra
.51 .698 .954 r
.16931 .44469 .17057 .44593 .17233 .44573 .17107 .44452 Mtetra
.686 .761 .909 r
.17107 .44452 .17233 .44573 .17416 .44492 .17289 .44372 Mtetra
.885 .767 .727 r
.17289 .44372 .17416 .44492 .17626 .44156 .175 .44034 Mtetra
.951 .69 .503 r
.175 .44034 .17626 .44156 .19964 .23801 .19853 .23615 Mtetra
.929 .701 .572 r
.19853 .23615 .19964 .23801 .20274 .22415 .20157 .22289 Mtetra
.864 .757 .743 r
.20157 .22289 .20274 .22415 .20466 .22139 .20349 .22014 Mtetra
.683 .74 .895 r
.20349 .22014 .20466 .22139 .20637 .22064 .2052 .21939 Mtetra
.535 .689 .938 r
.2052 .21939 .20637 .22064 .20802 .22043 .20685 .21918 Mtetra
.543 .692 .936 r
.20685 .21918 .20802 .22043 .20968 .22021 .20851 .21895 Mtetra
.628 .721 .914 r
.20851 .21895 .20968 .22021 .21136 .21972 .2102 .21844 Mtetra
.63 .72 .911 r
.2102 .21844 .21136 .21972 .21305 .21921 .21189 .21792 Mtetra
.638 .72 .907 r
.21189 .21792 .21305 .21921 .21474 .21866 .21358 .21736 Mtetra
.648 .722 .902 r
.21358 .21736 .21474 .21866 .21644 .21806 .21528 .21677 Mtetra
.656 .724 .899 r
.21528 .21677 .21644 .21806 .21815 .21743 .21699 .21613 Mtetra
.663 .727 .897 r
.21699 .21613 .21815 .21743 .21986 .21674 .2187 .21547 Mtetra
.671 .735 .898 r
.2187 .21547 .21986 .21674 .22158 .216 .22041 .21477 Mtetra
.682 .746 .899 r
.22041 .21477 .22158 .216 .2233 .21524 .22213 .21403 Mtetra
.701 .752 .892 r
.22213 .21403 .2233 .21524 .22502 .2145 .22386 .21318 Mtetra
.712 .739 .873 r
.22386 .21318 .22502 .2145 .22674 .21378 .2256 .21226 Mtetra
.702 .705 .85 r
.2256 .21226 .22674 .21378 .22846 .21305 .22734 .21134 Mtetra
.683 .673 .834 r
.22734 .21134 .22846 .21305 .23018 .2123 .22907 .21049 Mtetra
.665 .654 .829 r
.22907 .21049 .23018 .2123 .23191 .21151 .2308 .20973 Mtetra
.66 .654 .834 r
.2308 .20973 .23191 .21151 .23364 .21074 .23252 .209 Mtetra
.681 .669 .832 r
.23252 .209 .23364 .21074 .23538 .20979 .23426 .20816 Mtetra
.699 .688 .836 r
.23426 .20816 .23538 .20979 .23714 .20875 .23601 .20723 Mtetra
.645 .685 .873 r
.23601 .20723 .23714 .20875 .23885 .20819 .23772 .20662 Mtetra
.303 .512 .894 r
.23772 .20662 .23885 .20819 .24041 .20922 .23934 .20705 Mtetra
.645 .272 0 r
.23934 .20705 .24041 .20922 .24132 .21726 .24073 .20992 Mtetra
.964 .694 .475 r
.24073 .20992 .24132 .21726 .22379 .42427 .22415 .40583 Mtetra
0 0 .313 r
.22415 .40583 .22379 .42427 .22531 .42712 .22462 .41985 Mtetra
.509 .355 .607 r
.22462 .41985 .22531 .42712 .22712 .42688 .2264 .41993 Mtetra
.593 .42 .616 r
.2264 .41993 .22712 .42688 .22899 .42596 .22829 .41871 Mtetra
.601 .423 .612 r
.22829 .41871 .22899 .42596 .23087 .42496 .23021 .41728 Mtetra
.555 .384 .604 r
.23021 .41728 .23087 .42496 .23272 .42433 .23206 .41663 Mtetra
.555 .383 .604 r
.23206 .41663 .23272 .42433 .23457 .4237 .23391 .41598 Mtetra
.553 .382 .604 r
.23391 .41598 .23457 .4237 .23642 .42307 .23575 .41536 Mtetra
.55 .38 .604 r
.23575 .41536 .23642 .42307 .23827 .42246 .2376 .41479 Mtetra
.2376 .41479 .23827 .42246 .24012 .42186 .23944 .41423 Mtetra
.551 .382 .605 r
.23944 .41423 .24012 .42186 .24197 .42124 .24129 .41364 Mtetra
.554 .384 .605 r
.24129 .41364 .24197 .42124 .24383 .42062 .24314 .41301 Mtetra
.555 .384 .605 r
.24314 .41301 .24383 .42062 .24568 .42 .245 .41237 Mtetra
.568 .394 .606 r
.245 .41237 .24568 .42 .24754 .41935 .24687 .41151 Mtetra
.587 .406 .604 r
.24687 .41151 .24754 .41935 .24941 .41867 .24878 .41023 Mtetra
.545 .369 .594 r
.24878 .41023 .24941 .41867 .25127 .41801 .25063 .40969 Mtetra
.431 .286 .582 r
.25063 .40969 .25127 .41801 .25313 .41743 .25234 .4109 Mtetra
.265 .19 .582 r
.25234 .4109 .25313 .41743 .25498 .41695 .25394 .41331 Mtetra
.232 .264 .689 r
.25394 .41331 .25498 .41695 .25683 .41648 .25563 .41478 Mtetra
.277 .496 .889 r
.25563 .41478 .25683 .41648 .25869 .41596 .2574 .41531 Mtetra
.555 .841 .998 r
.2574 .41531 .25869 .41596 .26056 .41534 .25926 .41483 Mtetra
.63 .89 .987 r
.25926 .41483 .26056 .41534 .26243 .41468 .26114 .4141 Mtetra
.639 .88 .986 r
.26114 .4141 .26243 .41468 .2643 .41402 .26302 .41338 Mtetra
.545 .838 .999 r
.26302 .41338 .2643 .41402 .26617 .41335 .26488 .41291 Mtetra
.499 .856 .991 r
.26488 .41291 .26617 .41335 .26805 .4127 .26674 .41245 Mtetra
.459 .865 .961 r
.26674 .41245 .26805 .4127 .26992 .41206 .2686 .41195 Mtetra
.457 .877 .932 r
.2686 .41195 .26992 .41206 .2718 .41145 .27048 .41137 Mtetra
.48 .889 .932 r
.27048 .41137 .2718 .41145 .27367 .41084 .27235 .41073 Mtetra
.487 .891 .94 r
.27235 .41073 .27367 .41084 .27554 .41033 .27423 .41009 Mtetra
.461 .867 .96 r
.27423 .41009 .27554 .41033 .27739 .4101 .27611 .40958 Mtetra
.661 .897 .98 r
.27611 .40958 .27739 .4101 .27928 .4094 .278 .40876 Mtetra
.826 .886 .887 r
.278 .40876 .27928 .4094 .28126 .40745 .27996 .40715 Mtetra
.952 .852 .706 r
.27996 .40715 .28126 .40745 .28366 .39994 .2821 .40307 Mtetra
.992 .847 .487 r
.2821 .40307 .28366 .39994 .30115 .18908 .28473 .39248 Mtetra
0 0 .144 r
.28473 .39248 .30115 .18908 .30323 .18417 .30165 .18898 Mtetra
.321 0 .255 r
.30165 .18898 .30323 .18417 .30503 .18302 .30346 .18774 Mtetra
.441 .106 .301 r
.30346 .18774 .30503 .18302 .30678 .18253 .3052 .1875 Mtetra
.346 .025 .271 r
.3052 .1875 .30678 .18253 .30852 .18225 .307 .1864 Mtetra
0 0 0 r
.307 .1864 .30852 .18225 .3103 .18143 .30899 .18269 Mtetra
.793 .949 .608 r
.30899 .18269 .3103 .18143 .31208 .18062 .3109 .17998 Mtetra
.863 .873 .843 r
.3109 .17998 .31208 .18062 .31385 .17984 .31276 .1781 Mtetra
.682 .673 .835 r
.31276 .1781 .31385 .17984 .31562 .17917 .31454 .17723 Mtetra
.63 .628 .829 r
.31454 .17723 .31562 .17917 .31739 .17852 .31631 .17663 Mtetra
.606 .623 .842 r
.31631 .17663 .31739 .17852 .31917 .17787 .31807 .17617 Mtetra
.621 .655 .862 r
.31807 .17617 .31917 .17787 .32094 .17719 .31983 .17565 Mtetra
.625 .682 .883 r
.31983 .17565 .32094 .17719 .32272 .17649 .3216 .17512 Mtetra
.645 .716 .9 r
.3216 .17512 .32272 .17649 .3245 .17579 .32337 .17451 Mtetra
.695 .748 .892 r
.32337 .17451 .3245 .17579 .32627 .1751 .32516 .17367 Mtetra
.697 .724 .871 r
.32516 .17367 .32627 .1751 .32805 .17441 .32696 .17278 Mtetra
.691 .694 .848 r
.32696 .17278 .32805 .17441 .32984 .17367 .32875 .17189 Mtetra
.705 .679 .822 r
.32875 .17189 .32984 .17367 .33165 .17252 .33056 .17085 Mtetra
.664 .677 .853 r
.33056 .17085 .33165 .17252 .33344 .17176 .33234 .1701 Mtetra
.533 .622 .886 r
.33234 .1701 .33344 .17176 .33517 .17188 .33409 .16994 Mtetra
0 .051 .616 r
.33409 .16994 .33517 .17188 .33661 .17666 .33572 .17183 Mtetra
0 0 .183 r
.33572 .17183 .33661 .17666 .32527 .38709 .33706 .17835 Mtetra
0 0 .185 r
.33706 .17835 .32527 .38709 .32684 .39203 .326 .38485 Mtetra
.195 .132 .554 r
.326 .38485 .32684 .39203 .32871 .39224 .32767 .38818 Mtetra
.314 .3 .684 r
.32767 .38818 .32871 .39224 .33062 .39165 .32947 .38948 Mtetra
.386 .492 .844 r
.32947 .38948 .33062 .39165 .33256 .3907 .33133 .38991 Mtetra
.381 .737 .991 r
.33133 .38991 .33256 .3907 .33445 .3905 .33321 .38983 Mtetra
.609 .86 .991 r
.33321 .38983 .33445 .3905 .33638 .38985 .33514 .38919 Mtetra
.782 .894 .923 r
.33514 .38919 .33638 .38985 .33835 .38836 .3371 .38786 Mtetra
.934 .865 .747 r
.3371 .38786 .33835 .38836 .34058 .38235 .33918 .38455 Mtetra
.969 .886 .508 r
.33918 .38455 .34058 .38235 .35453 .17055 .34147 .37758 Mtetra
0 0 .175 r
.34147 .37758 .35453 .17055 .35666 .16393 .3552 .1689 Mtetra
0 0 0 r
.3552 .1689 .35666 .16393 .35851 .16244 .35724 .16391 Mtetra
.664 .877 .507 r
.35724 .16391 .35851 .16244 .36031 .1617 .35915 .16133 Mtetra
.848 .933 .882 r
.35915 .16133 .36031 .1617 .36209 .16137 .36101 .15966 Mtetra
.664 .675 .85 r
.36101 .15966 .36209 .16137 .36389 .16074 .36282 .15891 Mtetra
.598 .629 .853 r
.36282 .15891 .36389 .16074 .36569 .16016 .36461 .15848 Mtetra
.559 .633 .881 r
.36461 .15848 .36569 .16016 .36749 .1596 .36639 .15822 Mtetra
.636 .716 .905 r
.36639 .15822 .36749 .1596 .3693 .15896 .36819 .15764 Mtetra
.648 .73 .909 r
.36819 .15764 .3693 .15896 .3711 .15831 .37 .15701 Mtetra
.656 .738 .91 r
.37 .15701 .3711 .15831 .37291 .15763 .37181 .15634 Mtetra
.658 .74 .91 r
.37181 .15634 .37291 .15763 .37472 .15694 .37362 .15567 Mtetra
.664 .744 .91 r
.37362 .15567 .37472 .15694 .37654 .15624 .37543 .15497 Mtetra
.67 .747 .909 r
.37543 .15497 .37654 .15624 .37835 .15551 .37725 .15424 Mtetra
.674 .749 .907 r
.37725 .15424 .37835 .15551 .38017 .15475 .37907 .15349 Mtetra
.681 .752 .905 r
.37907 .15349 .38017 .15475 .38199 .15398 .38089 .15271 Mtetra
.688 .753 .901 r
.38089 .15271 .38199 .15398 .38381 .15321 .38271 .15189 Mtetra
.779 .768 .843 r
.38271 .15189 .38381 .15321 .38566 .15195 .38457 .15046 Mtetra
.722 .728 .855 r
.38457 .15046 .38566 .15195 .38749 .15103 .3864 .14939 Mtetra
.573 .647 .885 r
.3864 .14939 .38749 .15103 .38928 .15082 .38821 .14907 Mtetra
.813 .404 0 r
.38821 .14907 .38928 .15082 .3909 .15479 .38982 .15309 Mtetra
.969 .684 .433 r
.38982 .15309 .3909 .15479 .3833 .3662 .38209 .36563 Mtetra
.911 .509 .197 r
.38209 .36563 .3833 .3662 .38497 .37203 .38376 .37139 Mtetra
.041 .552 .874 r
.38376 .37139 .38497 .37203 .38689 .37244 .38568 .37177 Mtetra
.663 .88 .979 r
.38568 .37177 .38689 .37244 .38885 .37176 .38765 .37094 Mtetra
.812 .872 .891 r
.38765 .37094 .38885 .37176 .39083 .37059 .38965 .36938 Mtetra
.813 .805 .844 r
.38965 .36938 .39083 .37059 .39279 .37015 .39166 .36763 Mtetra
.788 .664 .726 r
.39166 .36763 .39279 .37015 .39475 .36946 .3937 .36514 Mtetra
.787 .594 .64 r
.3937 .36514 .39475 .36946 .39675 .36802 .39581 .36084 Mtetra
.964 .682 .449 r
.39581 .36084 .39675 .36802 .39891 .36243 .40606 .15291 Mtetra
.523 .284 .494 r
.40606 .15291 .39891 .36243 .40913 .14982 .40821 .14414 Mtetra
.716 .518 .62 r
.40821 .14414 .40913 .14982 .41121 .14288 .41016 .14074 Mtetra
.71 .648 .786 r
.41016 .14074 .41121 .14288 .41309 .14108 .41202 .13951 Mtetra
.623 .681 .884 r
.41202 .13951 .41309 .14108 .41493 .14034 .41385 .13897 Mtetra
.552 .684 .927 r
.41385 .13897 .41493 .14034 .41676 .14001 .41567 .13869 Mtetra
.698 .752 .893 r
.41567 .13869 .41676 .14001 .4186 .13934 .41752 .13781 Mtetra
.7 .718 .863 r
.41752 .13781 .4186 .13934 .42044 .1386 .41937 .13687 Mtetra
.649 .669 .856 r
.41937 .13687 .42044 .1386 .42228 .13791 .42121 .13618 Mtetra
.469 .583 .886 r
.42121 .13618 .42228 .13791 .42414 .13694 .42303 .13624 Mtetra
0 .286 .693 r
.42303 .13624 .42414 .13694 .42598 .1362 .42482 .13715 Mtetra
.768 .318 .182 r
.42482 .13715 .42598 .1362 .42781 .13611 .42656 .13979 Mtetra
.966 .675 .427 r
.42656 .13979 .42781 .13611 .42953 .1395 .42168 .34569 Mtetra
.519 .275 .485 r
.42168 .34569 .42953 .1395 .42469 .3507 .42336 .35446 Mtetra
.664 .291 .33 r
.42336 .35446 .42469 .3507 .42645 .35727 .42525 .357 Mtetra
0 .496 .736 r
.42525 .357 .42645 .35727 .42839 .358 .42721 .35733 Mtetra
.538 .84 .999 r
.42721 .35733 .42839 .358 .43038 .35737 .4292 .35684 Mtetra
.647 .904 .982 r
.4292 .35684 .43038 .35737 .43239 .35627 .4312 .356 Mtetra
.533 .901 .964 r
.4312 .356 .43239 .35627 .43439 .35549 .43319 .3553 Mtetra
.543 .914 .949 r
.43319 .3553 .43439 .35549 .43638 .35484 .43519 .35452 Mtetra
.682 .947 .959 r
.43519 .35452 .43638 .35484 .43838 .35415 .4372 .35347 Mtetra
.861 .898 .859 r
.4372 .35347 .43838 .35415 .44038 .35333 .43924 .35149 Mtetra
.849 .738 .74 r
.43924 .35149 .44038 .35333 .44239 .35245 .4413 .34863 Mtetra
.79 .609 .656 r
.4413 .34863 .44239 .35245 .44439 .35157 .44338 .34483 Mtetra
.661 .471 .617 r
.44338 .34483 .44439 .35157 .4464 .3508 .44543 .34223 Mtetra
.557 .379 .595 r
.44543 .34223 .4464 .3508 .4484 .35012 .44743 .34141 Mtetra
.517 .349 .592 r
.44743 .34141 .4484 .35012 .45041 .34945 .44942 .34135 Mtetra
.541 .372 .601 r
.44942 .34135 .45041 .34945 .45242 .34877 .45142 .34088 Mtetra
.554 .383 .604 r
.45142 .34088 .45242 .34877 .45443 .34807 .45343 .34019 Mtetra
.553 .383 .604 r
.45343 .34019 .45443 .34807 .45644 .34737 .45543 .33952 Mtetra
.552 .382 .605 r
.45543 .33952 .45644 .34737 .45845 .34669 .45744 .33887 Mtetra
.551 .382 .605 r
.45744 .33887 .45845 .34669 .46046 .34602 .45945 .33825 Mtetra
.552 .383 .606 r
.45945 .33825 .46046 .34602 .46248 .34534 .46146 .33762 Mtetra
.506 .351 .605 r
.46146 .33762 .46248 .34534 .46449 .34504 .46346 .33776 Mtetra
.523 .368 .613 r
.46346 .33776 .46449 .34504 .4665 .34464 .46546 .33764 Mtetra
.598 .425 .618 r
.46546 .33764 .4665 .34464 .46853 .34355 .46749 .33627 Mtetra
.854 .6 .554 r
.46749 .33627 .46853 .34355 .47061 .33937 .46972 .3237 Mtetra
.961 .67 .436 r
.46972 .3237 .47061 .33937 .47611 .12813 .47516 .1199 Mtetra
.697 .478 .586 r
.47516 .1199 .47611 .12813 .47815 .11782 .47711 .11548 Mtetra
.757 .655 .749 r
.47711 .11548 .47815 .11782 .48006 .11536 .47901 .11365 Mtetra
.666 .683 .857 r
.47901 .11365 .48006 .11536 .48195 .11452 .4809 .11285 Mtetra
.602 .663 .882 r
.4809 .11285 .48195 .11452 .48383 .11415 .48278 .11239 Mtetra
.623 .658 .864 r
.48278 .11239 .48383 .11415 .48571 .11365 .48466 .11183 Mtetra
.645 .66 .85 r
.48466 .11183 .48571 .11365 .4876 .11296 .48655 .11114 Mtetra
.48655 .11114 .4876 .11296 .48949 .11228 .48844 .11044 Mtetra
.646 .66 .849 r
.48844 .11044 .48949 .11228 .49138 .11158 .49033 .10974 Mtetra
.648 .66 .848 r
.49033 .10974 .49138 .11158 .49327 .11087 .49223 .10903 Mtetra
.649 .66 .847 r
.49223 .10903 .49327 .11087 .49517 .11016 .49412 .10832 Mtetra
.49412 .10832 .49517 .11016 .49706 .10944 .49602 .1076 Mtetra
.65 .66 .847 r
.49602 .1076 .49706 .10944 .49896 .10872 .49791 .10688 Mtetra
.65 .66 .846 r
.49791 .10688 .49896 .10872 .50086 .108 .49981 .10615 Mtetra
.49981 .10615 .50086 .108 .50275 .10727 .50171 .10542 Mtetra
.50171 .10542 .50275 .10727 .50465 .10655 .50361 .1047 Mtetra
.651 .66 .846 r
.50361 .1047 .50465 .10655 .50656 .10582 .50551 .10397 Mtetra
.50551 .10397 .50656 .10582 .50846 .10509 .50742 .10323 Mtetra
.50742 .10323 .50846 .10509 .51036 .10436 .50932 .1025 Mtetra
.50932 .1025 .51036 .10436 .51227 .10362 .51123 .10177 Mtetra
.51123 .10177 .51227 .10362 .51418 .10289 .51313 .10103 Mtetra
.51313 .10103 .51418 .10289 .51608 .10216 .51504 .1003 Mtetra
.51504 .1003 .51608 .10216 .51799 .10142 .51695 .09956 Mtetra
.51695 .09956 .51799 .10142 .5199 .10069 .51887 .09883 Mtetra
.51887 .09883 .5199 .10069 .52182 .09995 .52078 .09809 Mtetra
.52078 .09809 .52182 .09995 .52373 .09921 .52269 .09735 Mtetra
.52269 .09735 .52373 .09921 .52565 .09848 .52461 .09661 Mtetra
.52461 .09661 .52565 .09848 .52756 .09774 .52652 .09588 Mtetra
.52652 .09588 .52756 .09774 .52948 .097 .52844 .09514 Mtetra
.52844 .09514 .52948 .097 .5314 .09626 .53036 .0944 Mtetra
.53036 .0944 .5314 .09626 .53332 .09552 .53228 .09365 Mtetra
.53228 .09365 .53332 .09552 .53524 .09478 .5342 .09291 Mtetra
.5342 .09291 .53524 .09478 .53716 .09404 .53613 .09217 Mtetra
.53613 .09217 .53716 .09404 .53909 .0933 .53805 .09143 Mtetra
.53805 .09143 .53909 .0933 .54101 .09256 .53998 .09069 Mtetra
.53998 .09069 .54101 .09256 .54294 .09181 .54191 .08994 Mtetra
.54191 .08994 .54294 .09181 .54487 .09107 .54384 .0892 Mtetra
.54384 .0892 .54487 .09107 .5468 .09033 .54577 .08845 Mtetra
.54577 .08845 .5468 .09033 .54873 .08958 .5477 .08771 Mtetra
.5477 .08771 .54873 .08958 .55066 .08884 .54963 .08696 Mtetra
.54963 .08696 .55066 .08884 .55259 .08809 .55156 .08622 Mtetra
.55156 .08622 .55259 .08809 .55453 .08735 .5535 .08547 Mtetra
.5535 .08547 .55453 .08735 .55647 .0866 .55544 .08472 Mtetra
.55544 .08472 .55647 .0866 .5584 .08585 .55738 .08397 Mtetra
.55738 .08397 .5584 .08585 .56034 .0851 .55932 .08322 Mtetra
.652 .66 .846 r
.55932 .08322 .56034 .0851 .56228 .08435 .56126 .08247 Mtetra
.56126 .08247 .56228 .08435 .56423 .0836 .5632 .08172 Mtetra
.5632 .08172 .56423 .0836 .56617 .08285 .56514 .08096 Mtetra
.652 .661 .845 r
.56514 .08096 .56617 .08285 .56811 .08209 .56709 .08021 Mtetra
.653 .661 .845 r
.56709 .08021 .56811 .08209 .57006 .08133 .56903 .07945 Mtetra
.56903 .07945 .57006 .08133 .57201 .08057 .57098 .07869 Mtetra
.57098 .07869 .57201 .08057 .57395 .07981 .57293 .07792 Mtetra
.654 .662 .845 r
.57293 .07792 .57395 .07981 .5759 .07903 .57488 .07715 Mtetra
.656 .663 .845 r
.57488 .07715 .5759 .07903 .57785 .07825 .57683 .07637 Mtetra
.658 .664 .845 r
.57683 .07637 .57785 .07825 .57981 .07746 .57878 .07558 Mtetra
.657 .665 .846 r
.57878 .07558 .57981 .07746 .58176 .07667 .58074 .07479 Mtetra
.676 .673 .84 r
.58074 .07479 .58176 .07667 .58371 .07571 .58269 .07389 Mtetra
.697 .689 .839 r
.58269 .07389 .58371 .07571 .58566 .07458 .58464 .07286 Mtetra
.647 .682 .869 r
.58464 .07286 .58566 .07458 .58762 .07392 .5866 .07215 Mtetra
.406 .55 .886 r
.5866 .07215 .58762 .07392 .58961 .07478 .58859 .07243 Mtetra
0 0 .572 r
.58859 .07243 .58961 .07478 .59178 .08296 .59063 .07531 Mtetra
.977 .676 .333 r
.59063 .07531 .59178 .08296 .5988 .29497 .59735 .27789 Mtetra
.039 0 .445 r
.59735 .27789 .5988 .29497 .601 .29798 .59978 .29066 Mtetra
.512 .362 .615 r
.59978 .29066 .601 .29798 .60314 .29769 .60192 .29072 Mtetra
.588 .419 .62 r
.60192 .29072 .60314 .29769 .60525 .29672 .60403 .28952 Mtetra
.584 .413 .616 r
.60403 .28952 .60525 .29672 .60737 .29576 .60614 .28835 Mtetra
.51 .36 .613 r
.60614 .28835 .60737 .29576 .60951 .29545 .60828 .28843 Mtetra
.57 .406 .62 r
.60828 .28843 .60951 .29545 .61163 .29462 .6104 .28753 Mtetra
.715 .503 .601 r
.6104 .28753 .61163 .29462 .61371 .29218 .61243 .28326 Mtetra
.974 .671 .374 r
.61243 .28326 .61371 .29218 .61557 .28214 .60846 .07155 Mtetra
.516 .278 .492 r
.60846 .07155 .61557 .28214 .61133 .06856 .61028 .06527 Mtetra
.775 .614 .68 r
.61028 .06527 .61133 .06856 .61321 .06431 .61219 .06244 Mtetra
.695 .684 .836 r
.61219 .06244 .61321 .06431 .61517 .06314 .61416 .06141 Mtetra
.628 .673 .874 r
.61416 .06141 .61517 .06314 .61716 .06258 .61615 .0608 Mtetra
.604 .655 .873 r
.61615 .0608 .61716 .06258 .61915 .0622 .61814 .0603 Mtetra
.648 .661 .848 r
.61814 .0603 .61915 .0622 .62113 .06145 .62012 .05955 Mtetra
.648 .66 .848 r
.62012 .05955 .62113 .06145 .62311 .06071 .62211 .05881 Mtetra
.649 .66 .847 r
.62211 .05881 .62311 .06071 .6251 .05997 .62409 .05805 Mtetra
.652 .66 .846 r
.62409 .05805 .6251 .05997 .62709 .0592 .62608 .05728 Mtetra
.653 .661 .845 r
.62608 .05728 .62709 .0592 .62907 .05843 .62806 .0565 Mtetra
.654 .661 .844 r
.62806 .0565 .62907 .05843 .63106 .05764 .63005 .05572 Mtetra
.655 .661 .843 r
.63005 .05572 .63106 .05764 .63305 .05686 .63204 .05492 Mtetra
.656 .66 .843 r
.63204 .05492 .63305 .05686 .63504 .05606 .63403 .05413 Mtetra
.655 .659 .842 r
.63403 .05413 .63504 .05606 .63703 .05527 .63603 .05333 Mtetra
.654 .659 .842 r
.63603 .05333 .63703 .05527 .63903 .05448 .63802 .05253 Mtetra
.63802 .05253 .63903 .05448 .64102 .05369 .64002 .05174 Mtetra
.653 .659 .843 r
.64002 .05174 .64102 .05369 .64302 .0529 .64201 .05096 Mtetra
.64201 .05096 .64302 .0529 .64502 .05211 .64401 .05017 Mtetra
.652 .659 .844 r
.64401 .05017 .64502 .05211 .64702 .05133 .64601 .04939 Mtetra
.64601 .04939 .64702 .05133 .64902 .05055 .64801 .04861 Mtetra
.651 .659 .845 r
.64801 .04861 .64902 .05055 .65102 .04977 .65002 .04783 Mtetra
.65 .659 .845 r
.65002 .04783 .65102 .04977 .65302 .049 .65202 .04706 Mtetra
.65 .658 .845 r
.65202 .04706 .65302 .049 .65503 .04824 .65403 .0463 Mtetra
.649 .658 .845 r
.65403 .0463 .65503 .04824 .65704 .04748 .65604 .04554 Mtetra
.647 .657 .845 r
.65604 .04554 .65704 .04748 .65905 .04673 .65805 .04478 Mtetra
.646 .656 .845 r
.65805 .04478 .65905 .04673 .66106 .046 .66006 .04404 Mtetra
.646 .654 .844 r
.66006 .04404 .66106 .046 .66307 .04528 .66207 .04329 Mtetra
.64 .647 .841 r
.66207 .04329 .66307 .04528 .66509 .04458 .66409 .04257 Mtetra
.631 .641 .841 r
.66409 .04257 .66509 .04458 .66711 .04387 .66611 .04189 Mtetra
.611 .635 .85 r
.66611 .04189 .66711 .04387 .66913 .04314 .66814 .04134 Mtetra
.608 .658 .874 r
.66814 .04134 .66913 .04314 .67115 .0424 .67017 .04082 Mtetra
.611 .692 .901 r
.67017 .04082 .67115 .0424 .67317 .04169 .6722 .04028 Mtetra
.634 .734 .92 r
.6722 .04028 .67317 .04169 .6752 .04102 .67423 .03964 Mtetra
.644 .742 .921 r
.67423 .03964 .6752 .04102 .67722 .04036 .67626 .03895 Mtetra
.651 .741 .915 r
.67626 .03895 .67722 .04036 .67925 .03969 .67829 .03823 Mtetra
.654 .733 .908 r
.67829 .03823 .67925 .03969 .68128 .03898 .68031 .03749 Mtetra
.66 .732 .902 r
.68031 .03749 .68128 .03898 .68331 .03824 .68234 .03672 Mtetra
.668 .731 .897 r
.68234 .03672 .68331 .03824 .68534 .03744 .68437 .03591 Mtetra
.679 .733 .891 r
.68437 .03591 .68534 .03744 .68736 .03658 .6864 .03503 Mtetra
.684 .734 .888 r
.6864 .03503 .68736 .03658 .68939 .03568 .68842 .03414 Mtetra
.689 .736 .887 r
.68842 .03414 .68939 .03568 .69141 .03474 .69045 .03321 Mtetra
.764 .765 .853 r
.69045 .03321 .69141 .03474 .69341 .03332 .69244 .0318 Mtetra
.699 .743 .885 r
.69244 .0318 .69341 .03332 .69543 .03234 .69447 .03081 Mtetra
.52 .659 .923 r
.69447 .03081 .69543 .03234 .6975 .03216 .69654 .03063 Mtetra
.709 .295 0 r
.69654 .03063 .6975 .03216 .69988 .03694 .69891 .03531 Mtetra
.97 .655 .291 r
.69891 .03531 .69988 .03694 .71533 .25262 .7143 .25105 Mtetra
.729 .311 0 r
.7143 .25105 .71533 .25262 .7179 .25772 .71688 .25625 Mtetra
.043 .454 .878 r
.01887 .49518 .0202 .49634 .02172 .49691 .0204 .49576 Mtetra
.65 .751 .923 r
.0204 .49576 .02172 .49691 .02343 .49631 .02211 .49515 Mtetra
.813 .768 .811 r
.02211 .49515 .02343 .49631 .02532 .49451 .024 .49334 Mtetra
.911 .727 .641 r
.024 .49334 .02532 .49451 .02796 .48768 .02668 .48631 Mtetra
.936 .686 .534 r
.02668 .48631 .02796 .48768 .06068 .27982 .05949 .27848 Mtetra
.894 .722 .66 r
.05949 .27848 .06068 .27982 .06301 .27442 .06179 .27319 Mtetra
.747 .744 .849 r
.06179 .27319 .06301 .27442 .06469 .27329 .06348 .27208 Mtetra
.588 .706 .925 r
.06348 .27208 .06469 .27329 .06626 .27295 .06505 .27173 Mtetra
.425 .64 .946 r
.06505 .27173 .06626 .27295 .06777 .27299 .06656 .27178 Mtetra
.625 .719 .914 r
.06656 .27178 .06777 .27299 .06936 .2725 .06815 .27131 Mtetra
.648 .73 .909 r
.06815 .27131 .06936 .2725 .07097 .27192 .06975 .27075 Mtetra
.665 .739 .906 r
.06975 .27075 .07097 .27192 .07259 .27126 .07137 .27012 Mtetra
.725 .757 .878 r
.07137 .27012 .07259 .27126 .07427 .27014 .07303 .26919 Mtetra
.718 .789 .908 r
.07303 .26919 .07427 .27014 .07593 .26922 .07468 .26834 Mtetra
.661 .793 .945 r
.07468 .26834 .07593 .26922 .07753 .26877 .07629 .26772 Mtetra
.418 .675 .968 r
.07629 .26772 .07753 .26877 .07885 .2702 .07782 .26773 Mtetra
.31 .382 .775 r
.07782 .26773 .07885 .2702 .07972 .27479 .07925 .26842 Mtetra
.275 .183 .566 r
.07925 .26842 .07972 .27479 .05218 .47774 .08048 .27047 Mtetra
0 0 .006 r
.08048 .27047 .05218 .47774 .05318 .48219 .05345 .46999 Mtetra
0 0 .181 r
.05345 .46999 .05318 .48219 .0546 .48377 .05359 .48046 Mtetra
0 0 .475 r
.05359 .48046 .0546 .48377 .05616 .48433 .05486 .48309 Mtetra
.375 .629 .953 r
.05486 .48309 .05616 .48433 .05782 .48425 .05649 .48322 Mtetra
.672 .783 .932 r
.05649 .48322 .05782 .48425 .05955 .4836 .05823 .48252 Mtetra
.766 .785 .869 r
.05823 .48252 .05955 .4836 .06138 .48231 .06005 .48127 Mtetra
.783 .791 .859 r
.06005 .48127 .06138 .48231 .06345 .47931 .0619 .47988 Mtetra
.845 .997 .826 r
.0619 .47988 .06345 .47931 .066 .47286 .06382 .47793 Mtetra
0 0 .027 r
.06382 .47793 .066 .47286 .09591 .26913 .06593 .47465 Mtetra
0 0 .011 r
.06593 .47465 .09591 .26913 .09819 .26385 .09506 .2765 Mtetra
0 0 0 r
.09506 .2765 .09819 .26385 .10009 .26126 .09858 .26226 Mtetra
.964 .935 .702 r
.09858 .26226 .10009 .26126 .10187 .25959 .10063 .25862 Mtetra
.773 .792 .868 r
.10063 .25862 .10187 .25959 .10353 .25878 .10235 .2574 Mtetra
.618 .69 .895 r
.10235 .2574 .10353 .25878 .10513 .25834 .10396 .25695 Mtetra
.524 .649 .914 r
.10396 .25695 .10513 .25834 .10672 .25807 .10553 .2568 Mtetra
.623 .711 .909 r
.10553 .2568 .10672 .25807 .10834 .25755 .10714 .25633 Mtetra
.659 .731 .903 r
.10714 .25633 .10834 .25755 .10998 .2569 .10878 .25572 Mtetra
.672 .741 .902 r
.10878 .25572 .10998 .2569 .11163 .25619 .11042 .25505 Mtetra
.719 .759 .884 r
.11042 .25505 .11163 .25619 .11333 .25511 .1121 .25414 Mtetra
.718 .791 .909 r
.1121 .25414 .11333 .25511 .11502 .25415 .11377 .25328 Mtetra
.667 .801 .947 r
.11377 .25328 .11502 .25415 .11664 .25362 .11541 .25263 Mtetra
.27 .613 .957 r
.11541 .25263 .11664 .25362 .11803 .25495 .11694 .25285 Mtetra
.164 .339 .794 r
.11694 .25285 .11803 .25495 .119 .25944 .11839 .25374 Mtetra
.347 .251 .602 r
.11839 .25374 .119 .25944 .09396 .46221 .11976 .25517 Mtetra
.503 .268 .491 r
.11976 .25517 .09396 .46221 .09533 .46449 .12138 .25482 Mtetra
.504 .269 .491 r
.12138 .25482 .09533 .46449 .09712 .46362 .12307 .2538 Mtetra
.502 .267 .49 r
.12307 .2538 .09712 .46362 .09893 .46253 .12468 .25355 Mtetra
.471 .241 .482 r
.12468 .25355 .09893 .46253 .10033 .46469 .12484 .26441 Mtetra
0 0 .025 r
.12484 .26441 .10033 .46469 .10175 .46674 .10076 .46315 Mtetra
0 0 .347 r
.10076 .46315 .10175 .46674 .10328 .4679 .102 .46659 Mtetra
0 .336 .808 r
.102 .46659 .10328 .4679 .10491 .46828 .10357 .46746 Mtetra
.52 .782 .992 r
.10357 .46746 .10491 .46828 .10664 .46797 .1053 .46716 Mtetra
.776 .838 .899 r
.1053 .46716 .10664 .46797 .10847 .46682 .10714 .46591 Mtetra
.909 .774 .701 r
.10714 .46591 .10847 .46682 .1107 .4625 .10936 .46172 Mtetra
.945 .689 .517 r
.10936 .46172 .1107 .4625 .13849 .25468 .13708 .25512 Mtetra
.964 .764 .585 r
.13708 .25512 .13849 .25468 .14125 .24525 .14002 .24433 Mtetra
.856 .796 .792 r
.14002 .24433 .14125 .24525 .14308 .24319 .14187 .24218 Mtetra
.65 .771 .938 r
.14187 .24218 .14308 .24319 .14473 .24265 .14352 .2416 Mtetra
.462 .695 .968 r
.14352 .2416 .14473 .24265 .14632 .24262 .14511 .24152 Mtetra
.663 .757 .921 r
.14511 .24152 .14632 .24262 .14796 .24213 .14677 .24089 Mtetra
.699 .74 .882 r
.14677 .24089 .14796 .24213 .14963 .2414 .14846 .24006 Mtetra
.606 .695 .906 r
.14846 .24006 .14963 .2414 .15129 .24086 .1501 .23965 Mtetra
0 .111 .617 r
.1501 .23965 .15129 .24086 .15287 .24087 .15154 .24086 Mtetra
.898 .532 .336 r
.15154 .24086 .15287 .24087 .15437 .2416 .15252 .24585 Mtetra
.941 .677 .507 r
.15252 .24585 .15437 .2416 .15572 .24365 .12946 .44992 Mtetra
.51 .268 .485 r
.12946 .44992 .15572 .24365 .1341 .43731 .13068 .45395 Mtetra
.526 .254 .444 r
.13068 .45395 .1341 .43731 .13392 .45302 .13224 .45512 Mtetra
.486 .061 .157 r
.13224 .45512 .13392 .45302 .13527 .456 .13391 .45549 Mtetra
.047 .578 .861 r
.13391 .45549 .13527 .456 .13686 .45699 .13559 .45573 Mtetra
.497 .685 .951 r
.13559 .45573 .13686 .45699 .13859 .45691 .13732 .4556 Mtetra
.703 .748 .886 r
.13732 .4556 .13859 .45691 .14042 .45589 .13914 .4547 Mtetra
.887 .762 .719 r
.13914 .4547 .14042 .45589 .14256 .45225 .14127 .45113 Mtetra
.948 .689 .51 r
.14127 .45113 .14256 .45225 .16765 .25115 .16641 .25038 Mtetra
.946 .716 .559 r
.16641 .25038 .16765 .25115 .17119 .23444 .17001 .23326 Mtetra
.873 .76 .735 r
.17001 .23326 .17119 .23444 .17313 .23152 .17195 .23032 Mtetra
.741 .76 .868 r
.17195 .23032 .17313 .23152 .17486 .23046 .17368 .22926 Mtetra
.485 .676 .949 r
.17368 .22926 .17486 .23046 .17648 .23038 .17529 .22917 Mtetra
.756 .276 0 r
.17529 .22917 .17648 .23038 .17783 .23265 .17665 .23137 Mtetra
.95 .685 .497 r
.17665 .23137 .17783 .23265 .15638 .43659 .15523 .43428 Mtetra
.968 .66 .381 r
.15523 .43428 .15638 .43659 .15681 .44799 .15555 .44666 Mtetra
0 .036 .547 r
.15555 .44666 .15681 .44799 .15838 .44945 .15711 .44816 Mtetra
.657 .74 .911 r
.15711 .44816 .15838 .44945 .16019 .44876 .15892 .44749 Mtetra
.761 .765 .856 r
.15892 .44749 .16019 .44876 .16206 .44745 .16079 .4462 Mtetra
.738 .764 .874 r
.16079 .4462 .16206 .44745 .16392 .44633 .16265 .44508 Mtetra
.666 .75 .913 r
.16265 .44508 .16392 .44633 .16573 .44561 .16447 .44437 Mtetra
.654 .748 .919 r
.16447 .44437 .16573 .44561 .16754 .44495 .16627 .44372 Mtetra
.536 .708 .951 r
.16627 .44372 .16754 .44495 .16931 .44469 .16804 .44347 Mtetra
.504 .698 .956 r
.16804 .44347 .16931 .44469 .17107 .44452 .1698 .44331 Mtetra
.685 .762 .91 r
.1698 .44331 .17107 .44452 .17289 .44372 .17162 .44251 Mtetra
.885 .767 .726 r
.17162 .44251 .17289 .44372 .175 .44034 .17373 .43912 Mtetra
.951 .69 .503 r
.17373 .43912 .175 .44034 .19853 .23615 .1974 .2344 Mtetra
.93 .704 .575 r
.1974 .2344 .19853 .23615 .20157 .22289 .2004 .22164 Mtetra
.864 .758 .744 r
.2004 .22164 .20157 .22289 .20349 .22014 .20232 .2189 Mtetra
.684 .741 .895 r
.20232 .2189 .20349 .22014 .2052 .21939 .20403 .21814 Mtetra
.54 .691 .937 r
.20403 .21814 .2052 .21939 .20685 .21918 .20569 .21792 Mtetra
.55 .692 .933 r
.20569 .21792 .20685 .21918 .20851 .21895 .20735 .21767 Mtetra
.632 .719 .91 r
.20735 .21767 .20851 .21895 .2102 .21844 .20904 .21714 Mtetra
.634 .717 .907 r
.20904 .21714 .2102 .21844 .21189 .21792 .21073 .2166 Mtetra
.64 .716 .903 r
.21073 .2166 .21189 .21792 .21358 .21736 .21243 .21604 Mtetra
.649 .717 .898 r
.21243 .21604 .21358 .21736 .21528 .21677 .21413 .21544 Mtetra
.655 .719 .895 r
.21413 .21544 .21528 .21677 .21699 .21613 .21583 .21481 Mtetra
.66 .721 .894 r
.21583 .21481 .21699 .21613 .2187 .21547 .21754 .21416 Mtetra
.665 .725 .894 r
.21754 .21416 .2187 .21547 .22041 .21477 .21925 .21348 Mtetra
.674 .731 .893 r
.21925 .21348 .22041 .21477 .22213 .21403 .22097 .21276 Mtetra
.691 .741 .89 r
.22097 .21276 .22213 .21403 .22386 .21318 .2227 .21197 Mtetra
.706 .753 .889 r
.2227 .21197 .22386 .21318 .2256 .21226 .22443 .2111 Mtetra
.707 .763 .895 r
.22443 .2111 .2256 .21226 .22734 .21134 .22617 .21023 Mtetra
.697 .77 .908 r
.22617 .21023 .22734 .21134 .22907 .21049 .2279 .20942 Mtetra
.681 .774 .921 r
.2279 .20942 .22907 .21049 .2308 .20973 .22962 .20868 Mtetra
.675 .778 .928 r
.22962 .20868 .2308 .20973 .23252 .209 .23134 .20798 Mtetra
.69 .786 .924 r
.23134 .20798 .23252 .209 .23426 .20816 .23307 .20721 Mtetra
.704 .804 .927 r
.23307 .20721 .23426 .20816 .23601 .20723 .23481 .20638 Mtetra
.659 .816 .959 r
.23481 .20638 .23601 .20723 .23772 .20662 .23653 .20572 Mtetra
.464 .736 .986 r
.23653 .20572 .23772 .20662 .23934 .20705 .2382 .20558 Mtetra
.134 .43 .87 r
.2382 .20558 .23934 .20705 .24073 .20992 .2398 .20627 Mtetra
.287 .284 .682 r
.2398 .20627 .24073 .20992 .22415 .40583 .24135 .2075 Mtetra
.499 .264 .49 r
.24135 .2075 .22415 .40583 .22462 .41985 .24291 .20858 Mtetra
.503 .268 .491 r
.24291 .20858 .22462 .41985 .2264 .41993 .24462 .20817 Mtetra
.504 .269 .491 r
.24462 .20817 .2264 .41993 .22829 .41871 .24638 .2072 Mtetra
.24638 .2072 .22829 .41871 .23021 .41728 .24814 .2062 Mtetra
.503 .268 .491 r
.24814 .2062 .23021 .41728 .23206 .41663 .24988 .20551 Mtetra
.24988 .20551 .23206 .41663 .23391 .41598 .25161 .20483 Mtetra
.25161 .20483 .23391 .41598 .23575 .41536 .25335 .20417 Mtetra
.25335 .20417 .23575 .41536 .2376 .41479 .25508 .20353 Mtetra
.25508 .20353 .2376 .41479 .23944 .41423 .25682 .2029 Mtetra
.25682 .2029 .23944 .41423 .24129 .41364 .25855 .20224 Mtetra
.25855 .20224 .24129 .41364 .24314 .41301 .26029 .20156 Mtetra
.26029 .20156 .24314 .41301 .245 .41237 .26204 .20088 Mtetra
.504 .269 .491 r
.26204 .20088 .245 .41237 .24687 .41151 .2638 .19993 Mtetra
.505 .269 .491 r
.2638 .19993 .24687 .41151 .24878 .41023 .2656 .19861 Mtetra
.503 .268 .491 r
.2656 .19861 .24878 .41023 .25063 .40969 .26733 .19808 Mtetra
.496 .262 .489 r
.26733 .19808 .25063 .40969 .25234 .4109 .26884 .20028 Mtetra
0 0 .143 r
.26884 .20028 .25234 .4109 .25394 .41331 .25316 .40664 Mtetra
0 0 .367 r
.25316 .40664 .25394 .41331 .25563 .41478 .25448 .41251 Mtetra
0 .138 .683 r
.25448 .41251 .25563 .41478 .2574 .41531 .25615 .41424 Mtetra
.548 .751 .971 r
.25615 .41424 .2574 .41531 .25926 .41483 .258 .41391 Mtetra
.68 .823 .952 r
.258 .41391 .25926 .41483 .26114 .4141 .25988 .41311 Mtetra
.698 .813 .937 r
.25988 .41311 .26114 .4141 .26302 .41338 .26177 .41224 Mtetra
.607 .76 .952 r
.26177 .41224 .26302 .41338 .26488 .41291 .26364 .41173 Mtetra
.609 .753 .947 r
.26364 .41173 .26488 .41291 .26674 .41245 .2655 .41123 Mtetra
.619 .748 .938 r
.2655 .41123 .26674 .41245 .2686 .41195 .26737 .41069 Mtetra
.637 .746 .928 r
.26737 .41069 .2686 .41195 .27048 .41137 .26925 .41008 Mtetra
.648 .746 .921 r
.26925 .41008 .27048 .41137 .27235 .41073 .27113 .40942 Mtetra
.653 .745 .918 r
.27113 .40942 .27235 .41073 .27423 .41009 .27301 .40874 Mtetra
.648 .736 .914 r
.27301 .40874 .27423 .41009 .27611 .40958 .2749 .40809 Mtetra
.678 .722 .883 r
.2749 .40809 .27611 .40958 .278 .40876 .27679 .40727 Mtetra
.735 .739 .854 r
.27679 .40727 .278 .40876 .27996 .40715 .27872 .40607 Mtetra
.845 .81 .816 r
.27872 .40607 .27996 .40715 .2821 .40307 .28071 .40399 Mtetra
.84 .984 .704 r
.28071 .40399 .2821 .40307 .28473 .39248 .28275 .40138 Mtetra
.311 .037 .326 r
.28275 .40138 .28473 .39248 .30165 .18898 .28478 .39882 Mtetra
.5 .26 .482 r
.28478 .39882 .30165 .18898 .30346 .18774 .28664 .39855 Mtetra
.499 .259 .482 r
.28664 .39855 .30346 .18774 .3052 .1875 .28852 .39804 Mtetra
.495 .256 .481 r
.28852 .39804 .3052 .1875 .307 .1864 .29054 .39562 Mtetra
0 0 .153 r
.29054 .39562 .307 .1864 .30899 .18269 .30736 .18834 Mtetra
.722 .738 .222 r
.30736 .18834 .30899 .18269 .3109 .17998 .30968 .17996 Mtetra
.952 .904 .738 r
.30968 .17996 .3109 .17998 .31276 .1781 .31164 .17675 Mtetra
.726 .746 .867 r
.31164 .17675 .31276 .1781 .31454 .17723 .31343 .17572 Mtetra
.63 .687 .885 r
.31343 .17572 .31454 .17723 .31631 .17663 .3152 .17516 Mtetra
.573 .671 .906 r
.3152 .17516 .31631 .17663 .31807 .17617 .31695 .17484 Mtetra
.621 .715 .913 r
.31695 .17484 .31807 .17617 .31983 .17565 .31871 .17434 Mtetra
.62 .717 .916 r
.31871 .17434 .31983 .17565 .3216 .17512 .32047 .17383 Mtetra
.636 .728 .915 r
.32047 .17383 .3216 .17512 .32337 .17451 .32225 .17326 Mtetra
.684 .751 .902 r
.32225 .17326 .32337 .17451 .32516 .17367 .32403 .17248 Mtetra
.696 .765 .905 r
.32403 .17248 .32516 .17367 .32696 .17278 .32582 .17165 Mtetra
.7 .776 .911 r
.32582 .17165 .32696 .17278 .32875 .17189 .32762 .1708 Mtetra
.711 .789 .912 r
.32762 .1708 .32875 .17189 .33056 .17085 .32941 .1699 Mtetra
.677 .809 .946 r
.32941 .1699 .33056 .17085 .33234 .1701 .3312 .16916 Mtetra
.591 .784 .972 r
.3312 .16916 .33234 .1701 .33409 .16994 .33297 .16871 Mtetra
.386 .628 .949 r
.33297 .16871 .33409 .16994 .33572 .17183 .33471 .16884 Mtetra
.33 .359 .741 r
.33471 .16884 .33572 .17183 .33706 .17835 .33639 .16972 Mtetra
.312 .192 .551 r
.33639 .16972 .33706 .17835 .326 .38485 .33797 .17249 Mtetra
0 0 .191 r
.33797 .17249 .326 .38485 .32767 .38818 .32691 .37972 Mtetra
0 0 .407 r
.32691 .37972 .32767 .38818 .32947 .38948 .32837 .38651 Mtetra
0 .118 .652 r
.32837 .38651 .32947 .38948 .33133 .38991 .33012 .38866 Mtetra
.458 .681 .961 r
.33012 .38866 .33133 .38991 .33321 .38983 .33201 .3886 Mtetra
.662 .766 .927 r
.33201 .3886 .33321 .38983 .33514 .38919 .33394 .38787 Mtetra
.752 .774 .871 r
.33394 .38787 .33514 .38919 .3371 .38786 .3359 .3866 Mtetra
.789 .79 .853 r
.3359 .3866 .3371 .38786 .33918 .38455 .33788 .38506 Mtetra
.845 .997 .773 r
.33788 .38506 .33918 .38455 .34147 .37758 .3399 .38278 Mtetra
0 0 .092 r
.3399 .38278 .34147 .37758 .3552 .1689 .34201 .37889 Mtetra
0 0 .187 r
.34201 .37889 .3552 .1689 .35724 .16391 .35561 .17173 Mtetra
0 0 0 r
.35561 .17173 .35724 .16391 .35915 .16133 .35794 .1618 Mtetra
.96 .944 .697 r
.35794 .1618 .35915 .16133 .36101 .15966 .3599 .15836 Mtetra
.72 .756 .881 r
.3599 .15836 .36101 .15966 .36282 .15891 .36172 .15737 Mtetra
.599 .673 .893 r
.36172 .15737 .36282 .15891 .36461 .15848 .36351 .15695 Mtetra
.513 .635 .907 r
.36351 .15695 .36461 .15848 .36639 .15822 .36529 .15683 Mtetra
.631 .711 .905 r
.36529 .15683 .36639 .15822 .36819 .15764 .36709 .15627 Mtetra
.642 .719 .904 r
.36709 .15627 .36819 .15764 .37 .15701 .3689 .15566 Mtetra
.649 .727 .905 r
.3689 .15566 .37 .15701 .37181 .15634 .3707 .15502 Mtetra
.655 .733 .907 r
.3707 .15502 .37181 .15634 .37362 .15567 .37251 .15436 Mtetra
.662 .739 .907 r
.37251 .15436 .37362 .15567 .37543 .15497 .37433 .15367 Mtetra
.669 .742 .905 r
.37433 .15367 .37543 .15497 .37725 .15424 .37615 .15294 Mtetra
.676 .745 .903 r
.37615 .15294 .37725 .15424 .37907 .15349 .37797 .15218 Mtetra
.683 .745 .898 r
.37797 .15218 .37907 .15349 .38089 .15271 .37979 .15138 Mtetra
.69 .745 .893 r
.37979 .15138 .38089 .15271 .38271 .15189 .38161 .15055 Mtetra
.778 .765 .841 r
.38161 .15055 .38271 .15189 .38457 .15046 .38347 .14911 Mtetra
.73 .753 .871 r
.38347 .14911 .38457 .15046 .3864 .14939 .38531 .14804 Mtetra
.57 .695 .926 r
.38531 .14804 .3864 .14939 .38821 .14907 .38711 .1477 Mtetra
.842 .411 0 r
.38711 .1477 .38821 .14907 .38982 .15309 .38873 .15157 Mtetra
.969 .684 .434 r
.38873 .15157 .38982 .15309 .38209 .36563 .38093 .36397 Mtetra
.909 .519 .102 r
.38093 .36397 .38209 .36563 .38376 .37139 .38258 .36998 Mtetra
.208 .512 .912 r
.38258 .36998 .38376 .37139 .38568 .37177 .38449 .37054 Mtetra
.66 .772 .932 r
.38449 .37054 .38568 .37177 .38765 .37094 .38646 .36981 Mtetra
.813 .818 .854 r
.38646 .36981 .38765 .37094 .38965 .36938 .38847 .3681 Mtetra
.902 .787 .725 r
.38847 .3681 .38965 .36938 .39166 .36763 .39055 .36461 Mtetra
.902 .682 .595 r
.39055 .36461 .39166 .36763 .3937 .36514 .39283 .35632 Mtetra
.963 .68 .451 r
.39283 .35632 .3937 .36514 .39581 .36084 .40332 .14747 Mtetra
.512 .275 .492 r
.40332 .14747 .39581 .36084 .40606 .15291 .4053 .14316 Mtetra
.609 .404 .579 r
.4053 .14316 .40606 .15291 .40821 .14414 .4072 .14086 Mtetra
.689 .562 .706 r
.4072 .14086 .40821 .14414 .41016 .14074 .40907 .13931 Mtetra
.692 .731 .88 r
.40907 .13931 .41016 .14074 .41202 .13951 .41092 .13844 Mtetra
.624 .775 .953 r
.41092 .13844 .41202 .13951 .41385 .13897 .41275 .13788 Mtetra
.59 .758 .959 r
.41275 .13788 .41385 .13897 .41567 .13869 .41458 .13743 Mtetra
.732 .772 .885 r
.41458 .13743 .41567 .13869 .41752 .13781 .41644 .13637 Mtetra
.714 .736 .869 r
.41644 .13637 .41752 .13781 .41937 .13687 .41829 .13536 Mtetra
.625 .693 .893 r
.41829 .13536 .41937 .13687 .42121 .13618 .42013 .13482 Mtetra
0 .199 .716 r
.42013 .13482 .42121 .13618 .42303 .13624 .4219 .13618 Mtetra
.897 .488 .213 r
.4219 .13618 .42303 .13624 .42482 .13715 .42355 .14138 Mtetra
.966 .675 .429 r
.42355 .14138 .42482 .13715 .42656 .13979 .41836 .35051 Mtetra
.508 .267 .483 r
.41836 .35051 .42656 .13979 .42168 .34569 .42019 .35435 Mtetra
.541 .234 .396 r
.42019 .35435 .42168 .34569 .42336 .35446 .42212 .35556 Mtetra
.427 0 0 r
.42212 .35556 .42336 .35446 .42525 .357 .42408 .35593 Mtetra
.471 .729 .982 r
.42408 .35593 .42525 .357 .42721 .35733 .42605 .35577 Mtetra
.602 .695 .908 r
.42605 .35577 .42721 .35733 .4292 .35684 .42804 .35528 Mtetra
.646 .712 .896 r
.42804 .35528 .4292 .35684 .4312 .356 .43004 .35458 Mtetra
.602 .72 .927 r
.43004 .35458 .4312 .356 .43319 .3553 .43203 .35409 Mtetra
.639 .77 .943 r
.43203 .35409 .43319 .3553 .43519 .35452 .43403 .35342 Mtetra
.742 .821 .913 r
.43403 .35342 .43519 .35452 .4372 .35347 .43604 .35227 Mtetra
.901 .806 .745 r
.43604 .35227 .4372 .35347 .43924 .35149 .43811 .34908 Mtetra
.918 .708 .603 r
.43811 .34908 .43924 .35149 .4413 .34863 .44029 .34167 Mtetra
.968 .682 .434 r
.44029 .34167 .4413 .34863 .44338 .34483 .44776 .13136 Mtetra
.51 .273 .492 r
.44776 .13136 .44338 .34483 .44543 .34223 .44971 .12776 Mtetra
.504 .268 .491 r
.44971 .12776 .44543 .34223 .44743 .34141 .45158 .1269 Mtetra
.502 .267 .49 r
.45158 .1269 .44743 .34141 .44942 .34135 .45343 .12683 Mtetra
.503 .268 .491 r
.45343 .12683 .44942 .34135 .45142 .34088 .4553 .12639 Mtetra
.4553 .12639 .45142 .34088 .45343 .34019 .45717 .12569 Mtetra
.45717 .12569 .45343 .34019 .45543 .33952 .45905 .12501 Mtetra
.45905 .12501 .45543 .33952 .45744 .33887 .46092 .12433 Mtetra
.46092 .12433 .45744 .33887 .45945 .33825 .4628 .12366 Mtetra
.4628 .12366 .45945 .33825 .46146 .33762 .46467 .123 Mtetra
.502 .267 .491 r
.46467 .123 .46146 .33762 .46346 .33776 .46655 .12267 Mtetra
.46655 .12267 .46346 .33776 .46546 .33764 .46842 .12231 Mtetra
.504 .269 .491 r
.46842 .12231 .46546 .33764 .46749 .33627 .47031 .12133 Mtetra
.508 .271 .491 r
.47031 .12133 .46749 .33627 .46972 .3237 .47223 .11873 Mtetra
.508 .272 .492 r
.47223 .11873 .46972 .3237 .47516 .1199 .47415 .11602 Mtetra
.709 .552 .674 r
.47415 .11602 .47516 .1199 .47711 .11548 .47605 .11389 Mtetra
.741 .729 .84 r
.47605 .11389 .47711 .11548 .47901 .11365 .47795 .11264 Mtetra
.664 .807 .952 r
.47795 .11264 .47901 .11365 .4809 .11285 .47983 .11191 Mtetra
.612 .802 .973 r
.47983 .11191 .4809 .11285 .48278 .11239 .48172 .11135 Mtetra
.635 .79 .956 r
.48172 .11135 .48278 .11239 .48466 .11183 .4836 .11073 Mtetra
.655 .786 .944 r
.4836 .11073 .48466 .11183 .48655 .11114 .48549 .11004 Mtetra
.656 .786 .944 r
.48549 .11004 .48655 .11114 .48844 .11044 .48738 .10934 Mtetra
.658 .786 .943 r
.48738 .10934 .48844 .11044 .49033 .10974 .48928 .10864 Mtetra
.66 .787 .942 r
.48928 .10864 .49033 .10974 .49223 .10903 .49117 .10793 Mtetra
.661 .787 .942 r
.49117 .10793 .49223 .10903 .49412 .10832 .49306 .10721 Mtetra
.662 .787 .941 r
.49306 .10721 .49412 .10832 .49602 .1076 .49496 .10649 Mtetra
.662 .788 .941 r
.49496 .10649 .49602 .1076 .49791 .10688 .49686 .10577 Mtetra
.663 .788 .941 r
.49686 .10577 .49791 .10688 .49981 .10615 .49876 .10504 Mtetra
.49876 .10504 .49981 .10615 .50171 .10542 .50066 .10431 Mtetra
.50066 .10431 .50171 .10542 .50361 .1047 .50256 .10359 Mtetra
.664 .788 .941 r
.50256 .10359 .50361 .1047 .50551 .10397 .50446 .10285 Mtetra
.50446 .10285 .50551 .10397 .50742 .10323 .50637 .10212 Mtetra
.50637 .10212 .50742 .10323 .50932 .1025 .50827 .10139 Mtetra
.50827 .10139 .50932 .1025 .51123 .10177 .51018 .10065 Mtetra
.51018 .10065 .51123 .10177 .51313 .10103 .51209 .09992 Mtetra
.51209 .09992 .51313 .10103 .51504 .1003 .514 .09918 Mtetra
.664 .788 .94 r
.514 .09918 .51504 .1003 .51695 .09956 .51591 .09845 Mtetra
.51591 .09845 .51695 .09956 .51887 .09883 .51782 .09771 Mtetra
.51782 .09771 .51887 .09883 .52078 .09809 .51974 .09697 Mtetra
.51974 .09697 .52078 .09809 .52269 .09735 .52165 .09623 Mtetra
.52165 .09623 .52269 .09735 .52461 .09661 .52357 .09549 Mtetra
.52357 .09549 .52461 .09661 .52652 .09588 .52549 .09475 Mtetra
.52549 .09475 .52652 .09588 .52844 .09514 .52741 .09401 Mtetra
.52741 .09401 .52844 .09514 .53036 .0944 .52933 .09327 Mtetra
.52933 .09327 .53036 .0944 .53228 .09365 .53125 .09253 Mtetra
.53125 .09253 .53228 .09365 .5342 .09291 .53317 .09179 Mtetra
.53317 .09179 .5342 .09291 .53613 .09217 .5351 .09104 Mtetra
.5351 .09104 .53613 .09217 .53805 .09143 .53702 .0903 Mtetra
.665 .788 .94 r
.53702 .0903 .53805 .09143 .53998 .09069 .53895 .08956 Mtetra
.53895 .08956 .53998 .09069 .54191 .08994 .54088 .08881 Mtetra
.54088 .08881 .54191 .08994 .54384 .0892 .54281 .08807 Mtetra
.54281 .08807 .54384 .0892 .54577 .08845 .54474 .08732 Mtetra
.54474 .08732 .54577 .08845 .5477 .08771 .54667 .08658 Mtetra
.54667 .08658 .5477 .08771 .54963 .08696 .5486 .08583 Mtetra
.5486 .08583 .54963 .08696 .55156 .08622 .55054 .08508 Mtetra
.55054 .08508 .55156 .08622 .5535 .08547 .55248 .08433 Mtetra
.55248 .08433 .5535 .08547 .55544 .08472 .55441 .08358 Mtetra
.55441 .08358 .55544 .08472 .55738 .08397 .55635 .08283 Mtetra
.665 .789 .94 r
.55635 .08283 .55738 .08397 .55932 .08322 .5583 .08208 Mtetra
.5583 .08208 .55932 .08322 .56126 .08247 .56024 .08133 Mtetra
.56024 .08133 .56126 .08247 .5632 .08172 .56218 .08058 Mtetra
.666 .789 .94 r
.56218 .08058 .5632 .08172 .56514 .08096 .56413 .07982 Mtetra
.56413 .07982 .56514 .08096 .56709 .08021 .56607 .07906 Mtetra
.56607 .07906 .56709 .08021 .56903 .07945 .56802 .0783 Mtetra
.667 .789 .939 r
.56802 .0783 .56903 .07945 .57098 .07869 .56997 .07754 Mtetra
.668 .789 .939 r
.56997 .07754 .57098 .07869 .57293 .07792 .57192 .07677 Mtetra
.669 .79 .939 r
.57192 .07677 .57293 .07792 .57488 .07715 .57387 .076 Mtetra
.671 .79 .938 r
.57387 .076 .57488 .07715 .57683 .07637 .57582 .07522 Mtetra
.673 .791 .938 r
.57582 .07522 .57683 .07637 .57878 .07558 .57778 .07443 Mtetra
.673 .792 .938 r
.57778 .07443 .57878 .07558 .58074 .07479 .57973 .07364 Mtetra
.688 .797 .932 r
.57973 .07364 .58074 .07479 .58269 .07389 .58169 .07279 Mtetra
.704 .812 .932 r
.58169 .07279 .58269 .07389 .58464 .07286 .58364 .07186 Mtetra
.662 .819 .959 r
.58364 .07186 .58464 .07286 .5866 .07215 .5856 .0711 Mtetra
.511 .744 .979 r
.5856 .0711 .5866 .07215 .58859 .07243 .58757 .07084 Mtetra
.249 .485 .887 r
.58757 .07084 .58859 .07243 .59063 .07531 .58957 .07149 Mtetra
.337 .323 .697 r
.58957 .07149 .59063 .07531 .59735 .27789 .59158 .07275 Mtetra
.499 .265 .49 r
.59158 .07275 .59735 .27789 .59978 .29066 .59359 .07402 Mtetra
.503 .268 .491 r
.59359 .07402 .59978 .29066 .60192 .29072 .59557 .07362 Mtetra
.504 .269 .491 r
.59557 .07362 .60192 .29072 .60403 .28952 .59754 .07256 Mtetra
.504 .268 .491 r
.59754 .07256 .60403 .28952 .60614 .28835 .59951 .07158 Mtetra
.502 .267 .491 r
.59951 .07158 .60614 .28835 .60828 .28843 .60149 .07126 Mtetra
.503 .268 .491 r
.60149 .07126 .60828 .28843 .6104 .28753 .60347 .07046 Mtetra
.506 .27 .491 r
.60347 .07046 .6104 .28753 .61243 .28326 .60541 .06845 Mtetra
.508 .272 .491 r
.60541 .06845 .61243 .28326 .60846 .07155 .60732 .06541 Mtetra
.662 .474 .619 r
.60732 .06541 .60846 .07155 .61028 .06527 .60925 .06299 Mtetra
.751 .666 .767 r
.60925 .06299 .61028 .06527 .61219 .06244 .6112 .06127 Mtetra
.691 .798 .931 r
.6112 .06127 .61219 .06244 .61416 .06141 .61318 .06039 Mtetra
.634 .808 .966 r
.61318 .06039 .61416 .06141 .61615 .0608 .61516 .05973 Mtetra
.621 .792 .964 r
.61516 .05973 .61615 .0608 .61814 .0603 .61715 .05912 Mtetra
.66 .785 .94 r
.61715 .05912 .61814 .0603 .62012 .05955 .61913 .05837 Mtetra
.661 .785 .94 r
.61913 .05837 .62012 .05955 .62211 .05881 .62112 .05762 Mtetra
.663 .785 .939 r
.62112 .05762 .62211 .05881 .62409 .05805 .62311 .05686 Mtetra
.667 .785 .937 r
.62311 .05686 .62409 .05805 .62608 .05728 .62509 .05608 Mtetra
.669 .784 .935 r
.62509 .05608 .62608 .05728 .62806 .0565 .62708 .0553 Mtetra
.671 .784 .934 r
.62708 .0553 .62806 .0565 .63005 .05572 .62907 .0545 Mtetra
.672 .783 .933 r
.62907 .0545 .63005 .05572 .63204 .05492 .63106 .0537 Mtetra
.673 .782 .931 r
.63106 .0537 .63204 .05492 .63403 .05413 .63305 .0529 Mtetra
.672 .781 .931 r
.63305 .0529 .63403 .05413 .63603 .05333 .63505 .05209 Mtetra
.671 .779 .931 r
.63505 .05209 .63603 .05333 .63802 .05253 .63704 .05129 Mtetra
.67 .778 .93 r
.63704 .05129 .63802 .05253 .64002 .05174 .63904 .0505 Mtetra
.669 .777 .93 r
.63904 .0505 .64002 .05174 .64201 .05096 .64104 .04971 Mtetra
.668 .776 .931 r
.64104 .04971 .64201 .05096 .64401 .05017 .64304 .04892 Mtetra
.667 .776 .931 r
.64304 .04892 .64401 .05017 .64601 .04939 .64504 .04814 Mtetra
.666 .776 .931 r
.64504 .04814 .64601 .04939 .64801 .04861 .64704 .04736 Mtetra
.665 .775 .932 r
.64704 .04736 .64801 .04861 .65002 .04783 .64905 .04659 Mtetra
.664 .775 .932 r
.64905 .04659 .65002 .04783 .65202 .04706 .65105 .04581 Mtetra
.663 .775 .932 r
.65105 .04581 .65202 .04706 .65403 .0463 .65306 .04505 Mtetra
.662 .774 .933 r
.65306 .04505 .65403 .0463 .65604 .04554 .65507 .04428 Mtetra
.66 .774 .933 r
.65507 .04428 .65604 .04554 .65805 .04478 .65708 .04353 Mtetra
.659 .773 .933 r
.65708 .04353 .65805 .04478 .66006 .04404 .65909 .04278 Mtetra
.66 .772 .933 r
.65909 .04278 .66006 .04404 .66207 .04329 .66111 .04202 Mtetra
.654 .769 .933 r
.66111 .04202 .66207 .04329 .66409 .04257 .66313 .04129 Mtetra
.644 .763 .935 r
.66313 .04129 .66409 .04257 .66611 .04189 .66515 .0406 Mtetra
.62 .749 .939 r
.66515 .0406 .66611 .04189 .66814 .04134 .66717 .04001 Mtetra
.615 .74 .935 r
.66717 .04001 .66814 .04134 .67017 .04082 .6692 .03944 Mtetra
.619 .735 .929 r
.6692 .03944 .67017 .04082 .6722 .04028 .67123 .03886 Mtetra
.641 .736 .918 r
.67123 .03886 .6722 .04028 .67423 .03964 .67326 .03819 Mtetra
.65 .734 .911 r
.67326 .03819 .67423 .03964 .67626 .03895 .67529 .03747 Mtetra
.656 .732 .905 r
.67529 .03747 .67626 .03895 .67829 .03823 .67732 .03672 Mtetra
.658 .729 .901 r
.67732 .03672 .67829 .03823 .68031 .03749 .67934 .03596 Mtetra
.663 .727 .897 r
.67934 .03596 .68031 .03749 .68234 .03672 .68137 .03517 Mtetra
.669 .726 .892 r
.68137 .03517 .68234 .03672 .68437 .03591 .6834 .03435 Mtetra
.679 .729 .888 r
.6834 .03435 .68437 .03591 .6864 .03503 .68543 .03347 Mtetra
.682 .73 .886 r
.68543 .03347 .6864 .03503 .68842 .03414 .68745 .03258 Mtetra
.687 .733 .885 r
.68745 .03258 .68842 .03414 .69045 .03321 .68948 .03165 Mtetra
.761 .762 .853 r
.68948 .03165 .69045 .03321 .69244 .0318 .69148 .03026 Mtetra
.697 .741 .885 r
.69148 .03026 .69244 .0318 .69447 .03081 .6935 .02928 Mtetra
.521 .659 .922 r
.6935 .02928 .69447 .03081 .69654 .03063 .69558 .0291 Mtetra
.698 .283 0 r
.69558 .0291 .69654 .03063 .69891 .03531 .69794 .03365 Mtetra
.97 .655 .291 r
.69794 .03365 .69891 .03531 .7143 .25105 .71327 .24943 Mtetra
.732 .318 0 r
.71327 .24943 .7143 .25105 .71688 .25625 .71585 .25476 Mtetra
.067 .465 .886 r
.01755 .49399 .01887 .49518 .0204 .49576 .01908 .49455 Mtetra
.652 .743 .916 r
.01908 .49455 .0204 .49576 .02211 .49515 .02079 .49394 Mtetra
.808 .761 .81 r
.02079 .49394 .02211 .49515 .024 .49334 .02268 .49216 Mtetra
.907 .731 .653 r
.02268 .49216 .024 .49334 .02668 .48631 .02524 .48595 Mtetra
.937 .687 .533 r
.02524 .48595 .02668 .48631 .05949 .27848 .05805 .27869 Mtetra
.954 .801 .654 r
.05805 .27869 .05949 .27848 .06179 .27319 .06046 .27279 Mtetra
.82 .889 .893 r
.06046 .27279 .06179 .27319 .06348 .27208 .06218 .27141 Mtetra
.654 .837 .971 r
.06218 .27141 .06348 .27208 .06505 .27173 .06379 .2708 Mtetra
.525 .743 .975 r
.06379 .2708 .06505 .27173 .06656 .27178 .06534 .27057 Mtetra
.641 .723 .908 r
.06534 .27057 .06656 .27178 .06815 .27131 .06694 .27003 Mtetra
.64 .711 .899 r
.06694 .27003 .06815 .27131 .06975 .27075 .06854 .2695 Mtetra
.642 .717 .903 r
.06854 .2695 .06975 .27075 .07137 .27012 .07014 .26896 Mtetra
.668 .741 .905 r
.07014 .26896 .07137 .27012 .07303 .26919 .07176 .26832 Mtetra
.676 .799 .941 r
.07176 .26832 .07303 .26919 .07468 .26834 .07339 .26765 Mtetra
.672 .838 .963 r
.07339 .26765 .07468 .26834 .07629 .26772 .07501 .26698 Mtetra
.759 .833 .909 r
.07501 .26698 .07629 .26772 .07782 .26773 .07669 .26593 Mtetra
.667 .646 .819 r
.07669 .26593 .07782 .26773 .07925 .26842 .07833 .26518 Mtetra
.534 .462 .72 r
.07833 .26518 .07925 .26842 .08048 .27047 .07988 .26507 Mtetra
0 0 .447 r
.07988 .26507 .08048 .27047 .05345 .46999 .0809 .26858 Mtetra
0 0 0 r
.0809 .26858 .05345 .46999 .05359 .48046 .053 .47428 Mtetra
0 0 .102 r
.053 .47428 .05359 .48046 .05486 .48309 .0537 .48086 Mtetra
.287 .416 .818 r
.0537 .48086 .05486 .48309 .05649 .48322 .05525 .48152 Mtetra
.606 .651 .868 r
.05525 .48152 .05649 .48322 .05823 .48252 .05696 .48108 Mtetra
.7 .719 .864 r
.05696 .48108 .05823 .48252 .06005 .48127 .05873 .48018 Mtetra
.526 .728 .966 r
.05873 .48018 .06005 .48127 .0619 .47988 .06041 .47995 Mtetra
.374 .839 .882 r
.06041 .47995 .0619 .47988 .06382 .47793 .06213 .47946 Mtetra
0 0 0 r
.06213 .47946 .06382 .47793 .06593 .47465 .06395 .47826 Mtetra
.777 .864 .426 r
.06395 .47826 .06593 .47465 .09506 .2765 .06628 .47341 Mtetra
0 0 0 r
.06628 .47341 .09506 .2765 .09858 .26226 .09662 .26647 Mtetra
.956 .886 .493 r
.09662 .26647 .09858 .26226 .10063 .25862 .09927 .25853 Mtetra
.879 .926 .851 r
.09927 .25853 .10063 .25862 .10235 .2574 .10108 .25667 Mtetra
.696 .834 .949 r
.10108 .25667 .10235 .2574 .10396 .25695 .10273 .25591 Mtetra
.574 .741 .955 r
.10273 .25591 .10396 .25695 .10553 .2568 .10432 .25557 Mtetra
.642 .724 .908 r
.10432 .25557 .10553 .2568 .10714 .25633 .10595 .25503 Mtetra
.652 .713 .893 r
.10595 .25503 .10714 .25633 .10878 .25572 .10758 .25443 Mtetra
.649 .716 .897 r
.10758 .25443 .10878 .25572 .11042 .25505 .10922 .25385 Mtetra
.662 .736 .905 r
.10922 .25385 .11042 .25505 .1121 .25414 .11086 .25322 Mtetra
.669 .791 .94 r
.11086 .25322 .1121 .25414 .11377 .25328 .1125 .25257 Mtetra
.665 .837 .966 r
.1125 .25257 .11377 .25328 .11541 .25263 .11415 .25192 Mtetra
.663 .834 .966 r
.11415 .25192 .11541 .25263 .11694 .25285 .11579 .25127 Mtetra
.654 .671 .854 r
.11579 .25127 .11694 .25285 .11839 .25374 .11744 .25063 Mtetra
.61 .516 .723 r
.11744 .25063 .11839 .25374 .11976 .25517 .11909 .24999 Mtetra
.605 .447 .642 r
.11909 .24999 .11976 .25517 .12138 .25482 .12078 .24898 Mtetra
.584 .421 .627 r
.12078 .24898 .12138 .25482 .12307 .2538 .12246 .24813 Mtetra
.538 .39 .628 r
.12246 .24813 .12307 .2538 .12468 .25355 .12406 .24788 Mtetra
.101 .072 .536 r
.12406 .24788 .12468 .25355 .12484 .26441 .12526 .25066 Mtetra
.96 .702 .502 r
.12526 .25066 .12484 .26441 .10076 .46315 .10021 .45619 Mtetra
.71 .534 0 r
.10021 .45619 .10076 .46315 .102 .46659 .10084 .46432 Mtetra
0 .196 .72 r
.10084 .46432 .102 .46659 .10357 .46746 .10235 .46571 Mtetra
.565 .629 .875 r
.10235 .46571 .10357 .46746 .1053 .46716 .10407 .46544 Mtetra
.742 .698 .809 r
.10407 .46544 .1053 .46716 .10714 .46591 .10593 .46409 Mtetra
.867 .71 .685 r
.10593 .46409 .10714 .46591 .10936 .46172 .10815 .45987 Mtetra
.944 .688 .517 r
.10815 .45987 .10936 .46172 .13708 .25512 .13583 .25431 Mtetra
.938 .728 .593 r
.13583 .25431 .13708 .25512 .14002 .24433 .13875 .2437 Mtetra
.878 .833 .799 r
.13875 .2437 .14002 .24433 .14187 .24218 .14061 .24146 Mtetra
.684 .84 .958 r
.14061 .24146 .14187 .24218 .14352 .2416 .14229 .24073 Mtetra
.519 .762 .985 r
.14229 .24073 .14352 .2416 .14511 .24152 .1439 .24048 Mtetra
.708 .779 .907 r
.1439 .24048 .14511 .24152 .14677 .24089 .14559 .23965 Mtetra
.715 .744 .875 r
.14559 .23965 .14677 .24089 .14846 .24006 .14728 .23874 Mtetra
.574 .686 .917 r
.14728 .23874 .14846 .24006 .1501 .23965 .14891 .23843 Mtetra
.821 .36 0 r
.14891 .23843 .1501 .23965 .15154 .24086 .15019 .24095 Mtetra
.946 .683 .505 r
.15019 .24095 .15154 .24086 .15252 .24585 .12674 .44656 Mtetra
.52 .277 .487 r
.12674 .44656 .15252 .24585 .12946 .44992 .1274 .45511 Mtetra
.571 .238 .365 r
.1274 .45511 .12946 .44992 .13068 .45395 .12896 .45635 Mtetra
.307 0 .077 r
.12896 .45635 .13068 .45395 .13224 .45512 .13072 .45588 Mtetra
.392 .824 .67 r
.13072 .45588 .13224 .45512 .13391 .45549 .13255 .45485 Mtetra
.611 .852 .989 r
.13255 .45485 .13391 .45549 .13559 .45573 .13433 .45427 Mtetra
.613 .695 .901 r
.13433 .45427 .13559 .45573 .13732 .4556 .1361 .45379 Mtetra
.712 .681 .818 r
.1361 .45379 .13732 .4556 .13914 .4547 .13795 .45267 Mtetra
.855 .699 .688 r
.13795 .45267 .13914 .4547 .14127 .45113 .14013 .44869 Mtetra
.947 .687 .511 r
.14013 .44869 .14127 .45113 .16641 .25038 .16605 .24202 Mtetra
.796 .56 .581 r
.16605 .24202 .16641 .25038 .17001 .23326 .16884 .23191 Mtetra
.856 .744 .739 r
.16884 .23191 .17001 .23326 .17195 .23032 .17076 .22917 Mtetra
.741 .766 .873 r
.17076 .22917 .17195 .23032 .17368 .22926 .17249 .22811 Mtetra
.496 .692 .955 r
.17249 .22811 .17368 .22926 .17529 .22917 .17411 .22798 Mtetra
.721 .23 0 r
.17411 .22798 .17529 .22917 .17665 .23137 .17548 .23001 Mtetra
.951 .685 .497 r
.17548 .23001 .17665 .23137 .15523 .43428 .15467 .42681 Mtetra
.978 .718 .314 r
.15467 .42681 .15523 .43428 .15555 .44666 .15434 .4449 Mtetra
0 .032 .586 r
.15434 .4449 .15555 .44666 .15711 .44816 .15588 .44659 Mtetra
.626 .684 .884 r
.15588 .44659 .15711 .44816 .15892 .44749 .15767 .44605 Mtetra
.735 .735 .851 r
.15767 .44605 .15892 .44749 .16079 .4462 .15953 .44489 Mtetra
.722 .753 .877 r
.15953 .44489 .16079 .4462 .16265 .44508 .16138 .44386 Mtetra
.662 .754 .918 r
.16138 .44386 .16265 .44508 .16447 .44437 .16319 .44317 Mtetra
.655 .755 .923 r
.16319 .44317 .16447 .44437 .16627 .44372 .165 .44251 Mtetra
.534 .713 .954 r
.165 .44251 .16627 .44372 .16804 .44347 .16677 .44226 Mtetra
.5 .699 .958 r
.16677 .44226 .16804 .44347 .1698 .44331 .16852 .44211 Mtetra
.686 .763 .911 r
.16852 .44211 .1698 .44331 .17162 .44251 .17035 .44131 Mtetra
.886 .766 .725 r
.17035 .44131 .17162 .44251 .17373 .43912 .17247 .43787 Mtetra
.951 .69 .503 r
.17247 .43787 .17373 .43912 .1974 .2344 .1963 .23247 Mtetra
.925 .7 .578 r
.1963 .23247 .1974 .2344 .2004 .22164 .19923 .22035 Mtetra
.861 .754 .743 r
.19923 .22035 .2004 .22164 .20232 .2189 .20115 .21762 Mtetra
.686 .737 .89 r
.20115 .21762 .20232 .2189 .20403 .21814 .20287 .21686 Mtetra
.55 .687 .93 r
.20287 .21686 .20403 .21814 .20569 .21792 .20452 .21661 Mtetra
.56 .688 .925 r
.20452 .21661 .20569 .21792 .20735 .21767 .20619 .21633 Mtetra
.636 .712 .902 r
.20619 .21633 .20735 .21767 .20904 .21714 .20788 .21579 Mtetra
.637 .709 .899 r
.20788 .21579 .20904 .21714 .21073 .2166 .20957 .21523 Mtetra
.642 .708 .895 r
.20957 .21523 .21073 .2166 .21243 .21604 .21127 .21466 Mtetra
.649 .708 .891 r
.21127 .21466 .21243 .21604 .21413 .21544 .21298 .21405 Mtetra
.653 .709 .888 r
.21298 .21405 .21413 .21544 .21583 .21481 .21468 .21342 Mtetra
.658 .711 .887 r
.21468 .21342 .21583 .21481 .21754 .21416 .21639 .21277 Mtetra
.662 .713 .886 r
.21639 .21277 .21754 .21416 .21925 .21348 .2181 .21211 Mtetra
.665 .715 .886 r
.2181 .21211 .21925 .21348 .22097 .21276 .21982 .21142 Mtetra
.668 .722 .89 r
.21982 .21142 .22097 .21276 .2227 .21197 .22153 .21073 Mtetra
.671 .742 .903 r
.22153 .21073 .2227 .21197 .22443 .2111 .22325 .21003 Mtetra
.674 .775 .926 r
.22325 .21003 .22443 .2111 .22617 .21023 .22497 .20933 Mtetra
.672 .808 .948 r
.22497 .20933 .22617 .21023 .2279 .20942 .22669 .20864 Mtetra
.666 .831 .963 r
.22669 .20864 .2279 .20942 .22962 .20868 .22841 .20795 Mtetra
.664 .841 .968 r
.22841 .20795 .22962 .20868 .23134 .20798 .23013 .20726 Mtetra
.667 .846 .968 r
.23013 .20726 .23134 .20798 .23307 .20721 .23185 .20656 Mtetra
.667 .861 .973 r
.23185 .20656 .23307 .20721 .23481 .20638 .23358 .20585 Mtetra
.656 .882 .981 r
.23358 .20585 .23481 .20638 .23653 .20572 .23531 .20513 Mtetra
.654 .87 .98 r
.23531 .20513 .23653 .20572 .2382 .20558 .23703 .20444 Mtetra
.664 .759 .921 r
.23703 .20444 .2382 .20558 .2398 .20627 .23876 .20378 Mtetra
.627 .57 .771 r
.23876 .20378 .2398 .20627 .24135 .2075 .24048 .20312 Mtetra
.588 .456 .669 r
.24048 .20312 .24135 .2075 .24291 .20858 .24221 .20244 Mtetra
.569 .407 .622 r
.24221 .20244 .24291 .20858 .24462 .20817 .24394 .20174 Mtetra
.566 .401 .617 r
.24394 .20174 .24462 .20817 .24638 .2072 .24567 .20103 Mtetra
.568 .406 .622 r
.24567 .20103 .24638 .2072 .24814 .2062 .24741 .20034 Mtetra
.57 .412 .628 r
.24741 .20034 .24814 .2062 .24988 .20551 .24914 .19966 Mtetra
.569 .412 .628 r
.24914 .19966 .24988 .20551 .25161 .20483 .25087 .19898 Mtetra
.25087 .19898 .25161 .20483 .25335 .20417 .25261 .19832 Mtetra
.569 .411 .628 r
.25261 .19832 .25335 .20417 .25508 .20353 .25434 .19765 Mtetra
.568 .411 .628 r
.25434 .19765 .25508 .20353 .25682 .2029 .25608 .19699 Mtetra
.569 .41 .627 r
.25608 .19699 .25682 .2029 .25855 .20224 .25781 .19632 Mtetra
.569 .411 .627 r
.25781 .19632 .25855 .20224 .26029 .20156 .25955 .19564 Mtetra
.569 .41 .627 r
.25955 .19564 .26029 .20156 .26204 .20088 .26129 .19496 Mtetra
.579 .418 .627 r
.26129 .19496 .26204 .20088 .2638 .19993 .26305 .19414 Mtetra
.595 .431 .63 r
.26305 .19414 .2638 .19993 .2656 .19861 .26482 .19311 Mtetra
.566 .416 .636 r
.26482 .19311 .2656 .19861 .26733 .19808 .26655 .19252 Mtetra
.437 .323 .626 r
.26655 .19252 .26733 .19808 .26884 .20028 .26817 .19329 Mtetra
0 0 .254 r
.26817 .19329 .26884 .20028 .25316 .40664 .26925 .20049 Mtetra
0 0 .126 r
.26925 .20049 .25316 .40664 .25448 .41251 .25344 .40894 Mtetra
0 0 .473 r
.25344 .40894 .25448 .41251 .25615 .41424 .25498 .41222 Mtetra
.54 .59 .853 r
.25498 .41222 .25615 .41424 .258 .41391 .25681 .41204 Mtetra
.675 .67 .837 r
.25681 .41204 .258 .41391 .25988 .41311 .2587 .41117 Mtetra
.698 .67 .819 r
.2587 .41117 .25988 .41311 .26177 .41224 .26061 .41011 Mtetra
.632 .622 .822 r
.26061 .41011 .26177 .41224 .26364 .41173 .26249 .40945 Mtetra
.63 .606 .808 r
.26249 .40945 .26364 .41173 .2655 .41123 .26436 .40879 Mtetra
.627 .591 .794 r
.26436 .40879 .2655 .41123 .26737 .41069 .26624 .40812 Mtetra
.625 .579 .782 r
.26624 .40812 .26737 .41069 .26925 .41008 .26812 .40743 Mtetra
.62 .57 .777 r
.26812 .40743 .26925 .41008 .27113 .40942 .27001 .40677 Mtetra
.611 .565 .779 r
.27001 .40677 .27113 .40942 .27301 .40874 .27188 .40618 Mtetra
.596 .564 .789 r
.27188 .40618 .27301 .40874 .2749 .40809 .27375 .40569 Mtetra
.598 .58 .804 r
.27375 .40569 .2749 .40809 .27679 .40727 .27562 .40521 Mtetra
.612 .622 .836 r
.27562 .40521 .27679 .40727 .27872 .40607 .2775 .40468 Mtetra
.646 .728 .909 r
.2775 .40468 .27872 .40607 .28071 .40399 .27939 .40403 Mtetra
.456 .884 .895 r
.27939 .40403 .28071 .40399 .28275 .40138 .28128 .40334 Mtetra
.234 0 0 r
.28128 .40334 .28275 .40138 .28478 .39882 .28317 .40274 Mtetra
.426 .067 .25 r
.28317 .40274 .28478 .39882 .28664 .39855 .28502 .40252 Mtetra
.365 .012 .225 r
.28502 .40252 .28664 .39855 .28852 .39804 .28692 .40186 Mtetra
.143 0 .114 r
.28692 .40186 .28852 .39804 .29054 .39562 .2889 .40002 Mtetra
.789 .804 .316 r
.2889 .40002 .29054 .39562 .30736 .18834 .29128 .39274 Mtetra
0 0 .128 r
.29128 .39274 .30736 .18834 .30968 .17996 .30835 .18143 Mtetra
.973 .914 .581 r
.30835 .18143 .30968 .17996 .31164 .17675 .31045 .1763 Mtetra
.771 .92 .937 r
.31045 .1763 .31164 .17675 .31343 .17572 .31225 .17512 Mtetra
.57 .851 .997 r
.31225 .17512 .31343 .17572 .3152 .17516 .31402 .17462 Mtetra
.435 .804 .994 r
.31402 .17462 .3152 .17516 .31695 .17484 .31576 .17436 Mtetra
.668 .902 .978 r
.31576 .17436 .31695 .17484 .31871 .17434 .31755 .17356 Mtetra
.689 .847 .959 r
.31755 .17356 .31871 .17434 .32047 .17383 .31933 .17276 Mtetra
.684 .785 .927 r
.31933 .17276 .32047 .17383 .32225 .17326 .32112 .172 Mtetra
.659 .741 .91 r
.32112 .172 .32225 .17326 .32403 .17248 .3229 .17133 Mtetra
.655 .761 .928 r
.3229 .17133 .32403 .17248 .32582 .17165 .32468 .17068 Mtetra
.655 .799 .952 r
.32468 .17068 .32582 .17165 .32762 .1708 .32646 .17002 Mtetra
.669 .843 .967 r
.32646 .17002 .32762 .1708 .32941 .1699 .32824 .1693 Mtetra
.658 .876 .98 r
.32824 .1693 .32941 .1699 .3312 .16916 .33003 .16856 Mtetra
.665 .879 .978 r
.33003 .16856 .3312 .16916 .33297 .16871 .33182 .16781 Mtetra
.756 .834 .911 r
.33182 .16781 .33297 .16871 .33471 .16884 .33364 .16669 Mtetra
.643 .613 .804 r
.33364 .16669 .33471 .16884 .33639 .16972 .33543 .16598 Mtetra
.5 .424 .702 r
.33543 .16598 .33639 .16972 .33797 .17249 .33717 .1661 Mtetra
0 0 .45 r
.33717 .1661 .33797 .17249 .32691 .37972 .33861 .17105 Mtetra
0 0 .175 r
.33861 .17105 .32691 .37972 .32837 .38651 .32738 .38163 Mtetra
0 0 .4 r
.32738 .38163 .32837 .38651 .33012 .38866 .32897 .38646 Mtetra
.459 .53 .843 r
.32897 .38646 .33012 .38866 .33201 .3886 .33084 .38663 Mtetra
.627 .642 .846 r
.33084 .38663 .33201 .3886 .33394 .38787 .33276 .38601 Mtetra
.692 .683 .837 r
.33276 .38601 .33394 .38787 .3359 .3866 .33471 .38501 Mtetra
.537 .656 .912 r
.33471 .38501 .3359 .3866 .33788 .38506 .33661 .38479 Mtetra
.53 .897 .968 r
.33661 .38479 .33788 .38506 .3399 .38278 .33854 .38414 Mtetra
0 0 0 r
.33854 .38414 .3399 .38278 .34201 .37889 .34052 .38268 Mtetra
.714 .777 .287 r
.34052 .38268 .34201 .37889 .35561 .17173 .34276 .37665 Mtetra
0 0 .161 r
.34276 .37665 .35561 .17173 .35794 .1618 .3566 .16457 Mtetra
.916 .869 .436 r
.3566 .16457 .35794 .1618 .3599 .15836 .35874 .15795 Mtetra
.824 .932 .902 r
.35874 .15795 .3599 .15836 .36172 .15737 .36059 .15645 Mtetra
.668 .816 .955 r
.36059 .15645 .36172 .15737 .36351 .15695 .3624 .15574 Mtetra
.558 .717 .947 r
.3624 .15574 .36351 .15695 .36529 .15683 .36418 .15542 Mtetra
.642 .713 .899 r
.36418 .15542 .36529 .15683 .36709 .15627 .36599 .15481 Mtetra
.634 .702 .895 r
.36599 .15481 .36709 .15627 .3689 .15566 .36779 .15423 Mtetra
.632 .706 .899 r
.36779 .15423 .3689 .15566 .3707 .15502 .3696 .15366 Mtetra
.651 .725 .903 r
.3696 .15366 .3707 .15502 .37251 .15436 .37141 .15302 Mtetra
.659 .731 .902 r
.37141 .15302 .37251 .15436 .37433 .15367 .37323 .15233 Mtetra
.667 .735 .901 r
.37323 .15233 .37433 .15367 .37615 .15294 .37504 .15161 Mtetra
.685 .742 .894 r
.37504 .15161 .37615 .15294 .37797 .15218 .37687 .1508 Mtetra
.685 .734 .888 r
.37687 .1508 .37797 .15218 .37979 .15138 .37869 .14998 Mtetra
.679 .729 .888 r
.37869 .14998 .37979 .15138 .38161 .15055 .38051 .14919 Mtetra
.739 .754 .865 r
.38051 .14919 .38161 .15055 .38347 .14911 .38236 .14806 Mtetra
.685 .795 .932 r
.38236 .14806 .38347 .14911 .38531 .14804 .38418 .14727 Mtetra
.388 .736 .991 r
.38418 .14727 .38531 .14804 .38711 .1477 .38598 .14719 Mtetra
.886 .456 .134 r
.38598 .14719 .38711 .1477 .38873 .15157 .38757 .15141 Mtetra
.968 .682 .435 r
.38757 .15141 .38873 .15157 .38093 .36397 .37974 .36278 Mtetra
.906 .5 .12 r
.37974 .36278 .38093 .36397 .38258 .36998 .38142 .36826 Mtetra
.185 .44 .869 r
.38142 .36826 .38258 .36998 .38449 .37054 .38332 .36904 Mtetra
.616 .707 .91 r
.38332 .36904 .38449 .37054 .38646 .36981 .38527 .36849 Mtetra
.8 .79 .843 r
.38527 .36849 .38646 .36981 .38847 .3681 .38728 .36682 Mtetra
.936 .769 .65 r
.38728 .36682 .38847 .3681 .39055 .36461 .38945 .36136 Mtetra
.968 .687 .446 r
.38945 .36136 .39055 .36461 .39283 .35632 .40032 .14836 Mtetra
.519 .281 .493 r
.40032 .14836 .39283 .35632 .40332 .14747 .40244 .14099 Mtetra
.626 .444 .616 r
.40244 .14099 .40332 .14747 .4053 .14316 .40432 .13921 Mtetra
.596 .479 .69 r
.40432 .13921 .4053 .14316 .4072 .14086 .40615 .1385 Mtetra
.565 .556 .803 r
.40615 .1385 .4072 .14086 .40907 .13931 .40797 .13822 Mtetra
.647 .777 .943 r
.40797 .13822 .40907 .13931 .41092 .13844 .40981 .13758 Mtetra
.659 .83 .965 r
.40981 .13758 .41092 .13844 .41275 .13788 .41165 .13687 Mtetra
.655 .797 .951 r
.41165 .13687 .41275 .13788 .41458 .13743 .41349 .13619 Mtetra
.723 .772 .892 r
.41349 .13619 .41458 .13743 .41644 .13637 .41535 .13518 Mtetra
.68 .771 .92 r
.41535 .13518 .41644 .13637 .41829 .13536 .41719 .13441 Mtetra
.458 .73 .985 r
.41719 .13441 .41829 .13536 .42013 .13482 .41902 .13427 Mtetra
.842 .377 .025 r
.41902 .13427 .42013 .13482 .4219 .13618 .42072 .13763 Mtetra
.968 .679 .426 r
.42072 .13763 .4219 .13618 .42355 .14138 .41525 .34876 Mtetra
.514 .271 .484 r
.41525 .34876 .42355 .14138 .41836 .35051 .41698 .35544 Mtetra
.526 .18 .323 r
.41698 .35544 .41836 .35051 .42019 .35435 .41892 .35618 Mtetra
.231 0 0 r
.41892 .35618 .42019 .35435 .42212 .35556 .42091 .35559 Mtetra
.615 .955 .901 r
.42091 .35559 .42212 .35556 .42408 .35593 .42291 .35449 Mtetra
.687 .746 .896 r
.42291 .35449 .42408 .35593 .42605 .35577 .42491 .35359 Mtetra
.653 .637 .821 r
.42491 .35359 .42605 .35577 .42804 .35528 .42691 .35276 Mtetra
.644 .601 .79 r
.42691 .35276 .42804 .35528 .43004 .35458 .42891 .35192 Mtetra
.563 .546 .793 r
.42891 .35192 .43004 .35458 .43203 .35409 .4309 .35161 Mtetra
.586 .575 .807 r
.4309 .35161 .43203 .35409 .43403 .35342 .43289 .35117 Mtetra
.691 .647 .801 r
.43289 .35117 .43403 .35342 .43604 .35227 .4349 .35004 Mtetra
.886 .714 .663 r
.4349 .35004 .43604 .35227 .43811 .34908 .43702 .34534 Mtetra
.971 .685 .431 r
.43702 .34534 .43811 .34908 .44029 .34167 .44476 .13278 Mtetra
.521 .282 .493 r
.44476 .13278 .44029 .34167 .44776 .13136 .44684 .12426 Mtetra
.635 .444 .606 r
.44684 .12426 .44776 .13136 .44971 .12776 .44874 .12209 Mtetra
.579 .424 .635 r
.44874 .12209 .44971 .12776 .45158 .1269 .45061 .12129 Mtetra
.546 .402 .637 r
.45061 .12129 .45158 .1269 .45343 .12683 .45247 .12093 Mtetra
.559 .407 .63 r
.45247 .12093 .45343 .12683 .4553 .12639 .45434 .12036 Mtetra
.568 .41 .628 r
.45434 .12036 .4553 .12639 .45717 .12569 .45621 .11965 Mtetra
.567 .41 .627 r
.45621 .11965 .45717 .12569 .45905 .12501 .45808 .11895 Mtetra
.45808 .11895 .45905 .12501 .46092 .12433 .45996 .11825 Mtetra
.567 .409 .627 r
.45996 .11825 .46092 .12433 .4628 .12366 .46183 .11755 Mtetra
.566 .408 .626 r
.46183 .11755 .4628 .12366 .46467 .123 .46371 .11685 Mtetra
.565 .407 .625 r
.46371 .11685 .46467 .123 .46655 .12267 .46558 .11617 Mtetra
.561 .399 .618 r
.46558 .11617 .46655 .12267 .46842 .12231 .46746 .1155 Mtetra
.559 .393 .613 r
.46746 .1155 .46842 .12231 .47031 .12133 .46934 .11482 Mtetra
.564 .4 .618 r
.46934 .11482 .47031 .12133 .47223 .11873 .47122 .11411 Mtetra
.586 .452 .666 r
.47122 .11411 .47223 .11873 .47415 .11602 .47311 .11339 Mtetra
.626 .568 .769 r
.47311 .11339 .47415 .11602 .47605 .11389 .47499 .11266 Mtetra
.656 .76 .926 r
.47499 .11266 .47605 .11389 .47795 .11264 .47687 .11197 Mtetra
.622 .866 .989 r
.47687 .11197 .47795 .11264 .47983 .11191 .47876 .1113 Mtetra
.611 .876 .991 r
.47876 .1113 .47983 .11191 .48172 .11135 .48065 .11064 Mtetra
.629 .861 .986 r
.48065 .11064 .48172 .11135 .4836 .11073 .48254 .10996 Mtetra
.639 .852 .981 r
.48254 .10996 .4836 .11073 .48549 .11004 .48443 .10927 Mtetra
.641 .853 .981 r
.48443 .10927 .48549 .11004 .48738 .10934 .48632 .10858 Mtetra
.643 .853 .98 r
.48632 .10858 .48738 .10934 .48928 .10864 .48821 .10787 Mtetra
.645 .854 .98 r
.48821 .10787 .48928 .10864 .49117 .10793 .49011 .10716 Mtetra
.646 .854 .979 r
.49011 .10716 .49117 .10793 .49306 .10721 .492 .10644 Mtetra
.647 .855 .979 r
.492 .10644 .49306 .10721 .49496 .10649 .4939 .10572 Mtetra
.648 .855 .979 r
.4939 .10572 .49496 .10649 .49686 .10577 .4958 .105 Mtetra
.649 .856 .979 r
.4958 .105 .49686 .10577 .49876 .10504 .4977 .10427 Mtetra
.4977 .10427 .49876 .10504 .50066 .10431 .4996 .10355 Mtetra
.65 .856 .978 r
.4996 .10355 .50066 .10431 .50256 .10359 .50151 .10281 Mtetra
.50151 .10281 .50256 .10359 .50446 .10285 .50341 .10208 Mtetra
.50341 .10208 .50446 .10285 .50637 .10212 .50532 .10135 Mtetra
.50532 .10135 .50637 .10212 .50827 .10139 .50722 .10062 Mtetra
.651 .856 .978 r
.50722 .10062 .50827 .10139 .51018 .10065 .50913 .09988 Mtetra
.50913 .09988 .51018 .10065 .51209 .09992 .51104 .09915 Mtetra
.651 .857 .978 r
.51104 .09915 .51209 .09992 .514 .09918 .51295 .09841 Mtetra
.51295 .09841 .514 .09918 .51591 .09845 .51486 .09767 Mtetra
.51486 .09767 .51591 .09845 .51782 .09771 .51678 .09693 Mtetra
.51678 .09693 .51782 .09771 .51974 .09697 .51869 .09619 Mtetra
.51869 .09619 .51974 .09697 .52165 .09623 .52061 .09545 Mtetra
.52061 .09545 .52165 .09623 .52357 .09549 .52253 .09471 Mtetra
.52253 .09471 .52357 .09549 .52549 .09475 .52445 .09397 Mtetra
.52445 .09397 .52549 .09475 .52741 .09401 .52637 .09323 Mtetra
.52637 .09323 .52741 .09401 .52933 .09327 .52829 .09249 Mtetra
.52829 .09249 .52933 .09327 .53125 .09253 .53021 .09175 Mtetra
.53021 .09175 .53125 .09253 .53317 .09179 .53214 .091 Mtetra
.53214 .091 .53317 .09179 .5351 .09104 .53406 .09026 Mtetra
.53406 .09026 .5351 .09104 .53702 .0903 .53599 .08952 Mtetra
.53599 .08952 .53702 .0903 .53895 .08956 .53792 .08877 Mtetra
.53792 .08877 .53895 .08956 .54088 .08881 .53985 .08803 Mtetra
.53985 .08803 .54088 .08881 .54281 .08807 .54178 .08728 Mtetra
.54178 .08728 .54281 .08807 .54474 .08732 .54371 .08653 Mtetra
.54371 .08653 .54474 .08732 .54667 .08658 .54565 .08579 Mtetra
.54565 .08579 .54667 .08658 .5486 .08583 .54758 .08504 Mtetra
.54758 .08504 .5486 .08583 .55054 .08508 .54952 .08429 Mtetra
.54952 .08429 .55054 .08508 .55248 .08433 .55146 .08354 Mtetra
.652 .857 .978 r
.55146 .08354 .55248 .08433 .55441 .08358 .55339 .08279 Mtetra
.55339 .08279 .55441 .08358 .55635 .08283 .55534 .08204 Mtetra
.55534 .08204 .55635 .08283 .5583 .08208 .55728 .08129 Mtetra
.55728 .08129 .5583 .08208 .56024 .08133 .55922 .08053 Mtetra
.55922 .08053 .56024 .08133 .56218 .08058 .56117 .07978 Mtetra
.653 .857 .978 r
.56117 .07978 .56218 .08058 .56413 .07982 .56311 .07902 Mtetra
.653 .857 .977 r
.56311 .07902 .56413 .07982 .56607 .07906 .56506 .07826 Mtetra
.654 .857 .977 r
.56506 .07826 .56607 .07906 .56802 .0783 .56701 .0775 Mtetra
.655 .857 .977 r
.56701 .0775 .56802 .0783 .56997 .07754 .56896 .07674 Mtetra
.656 .857 .977 r
.56896 .07674 .56997 .07754 .57192 .07677 .57091 .07597 Mtetra
.657 .858 .976 r
.57091 .07597 .57192 .07677 .57387 .076 .57286 .0752 Mtetra
.659 .858 .976 r
.57286 .0752 .57387 .076 .57582 .07522 .57482 .07442 Mtetra
.661 .859 .975 r
.57482 .07442 .57582 .07522 .57778 .07443 .57677 .07363 Mtetra
.662 .86 .975 r
.57677 .07363 .57778 .07443 .57973 .07364 .57873 .07284 Mtetra
.666 .861 .974 r
.57873 .07284 .57973 .07364 .58169 .07279 .58068 .07203 Mtetra
.666 .872 .976 r
.58068 .07203 .58169 .07279 .58364 .07186 .58264 .07121 Mtetra
.654 .89 .982 r
.58264 .07121 .58364 .07186 .5856 .0711 .5846 .07039 Mtetra
.653 .878 .982 r
.5846 .07039 .5856 .0711 .58757 .07084 .58656 .0696 Mtetra
.664 .772 .93 r
.58656 .0696 .58757 .07084 .58957 .07149 .58853 .06885 Mtetra
.627 .573 .774 r
.58853 .06885 .58957 .07149 .59158 .07275 .59049 .0681 Mtetra
.587 .455 .668 r
.59049 .0681 .59158 .07275 .59359 .07402 .59246 .06734 Mtetra
.566 .401 .617 r
.59246 .06734 .59359 .07402 .59557 .07362 .59443 .06654 Mtetra
.563 .394 .61 r
.59443 .06654 .59557 .07362 .59754 .07256 .5964 .06575 Mtetra
.564 .398 .614 r
.5964 .06575 .59754 .07256 .59951 .07158 .59837 .06498 Mtetra
.563 .4 .618 r
.59837 .06498 .59951 .07158 .60149 .07126 .60034 .06424 Mtetra
.56 .392 .611 r
.60034 .06424 .60149 .07126 .60347 .07046 .60231 .06351 Mtetra
.561 .394 .612 r
.60231 .06351 .60347 .07046 .60541 .06845 .60429 .06276 Mtetra
.575 .423 .638 r
.60429 .06276 .60541 .06845 .60732 .06541 .60627 .06198 Mtetra
.61 .515 .721 r
.60627 .06198 .60732 .06541 .60925 .06299 .60824 .0612 Mtetra
.654 .679 .861 r
.60824 .0612 .60925 .06299 .6112 .06127 .61022 .06044 Mtetra
.64 .85 .98 r
.61022 .06044 .6112 .06127 .61318 .06039 .6122 .05972 Mtetra
.62 .877 .99 r
.6122 .05972 .61318 .06039 .61516 .05973 .61419 .059 Mtetra
.629 .869 .987 r
.61419 .059 .61516 .05973 .61715 .05912 .61617 .05828 Mtetra
.647 .851 .978 r
.61617 .05828 .61715 .05912 .61913 .05837 .61816 .05753 Mtetra
.651 .852 .977 r
.61816 .05753 .61913 .05837 .62112 .05762 .62014 .05677 Mtetra
.655 .852 .975 r
.62014 .05677 .62112 .05762 .62311 .05686 .62213 .05599 Mtetra
.659 .851 .974 r
.62213 .05599 .62311 .05686 .62509 .05608 .62412 .05521 Mtetra
.662 .85 .972 r
.62412 .05521 .62509 .05608 .62708 .0553 .62611 .05441 Mtetra
.666 .85 .97 r
.62611 .05441 .62708 .0553 .62907 .0545 .6281 .05361 Mtetra
.67 .848 .968 r
.6281 .05361 .62907 .0545 .63106 .0537 .63009 .05278 Mtetra
.671 .845 .966 r
.63009 .05278 .63106 .0537 .63305 .0529 .63208 .05196 Mtetra
.671 .841 .965 r
.63208 .05196 .63305 .0529 .63505 .05209 .63408 .05114 Mtetra
.668 .837 .965 r
.63408 .05114 .63505 .05209 .63704 .05129 .63607 .05034 Mtetra
.666 .835 .964 r
.63607 .05034 .63704 .05129 .63904 .0505 .63807 .04954 Mtetra
.665 .833 .964 r
.63807 .04954 .63904 .0505 .64104 .04971 .64007 .04874 Mtetra
.664 .832 .964 r
.64007 .04874 .64104 .04971 .64304 .04892 .64207 .04795 Mtetra
.662 .831 .964 r
.64207 .04795 .64304 .04892 .64504 .04814 .64407 .04717 Mtetra
.661 .831 .965 r
.64407 .04717 .64504 .04814 .64704 .04736 .64608 .04639 Mtetra
.66 .83 .965 r
.64608 .04639 .64704 .04736 .64905 .04659 .64808 .04561 Mtetra
.658 .83 .966 r
.64808 .04561 .64905 .04659 .65105 .04581 .65009 .04484 Mtetra
.657 .829 .966 r
.65009 .04484 .65105 .04581 .65306 .04505 .6521 .04407 Mtetra
.656 .829 .966 r
.6521 .04407 .65306 .04505 .65507 .04428 .65411 .04331 Mtetra
.654 .828 .967 r
.65411 .04331 .65507 .04428 .65708 .04353 .65612 .04255 Mtetra
.653 .828 .967 r
.65612 .04255 .65708 .04353 .65909 .04278 .65814 .04179 Mtetra
.651 .827 .968 r
.65814 .04179 .65909 .04278 .66111 .04202 .66015 .04105 Mtetra
.649 .828 .969 r
.66015 .04105 .66111 .04202 .66313 .04129 .66217 .04031 Mtetra
.648 .826 .968 r
.66217 .04031 .66313 .04129 .66515 .0406 .66419 .03957 Mtetra
.647 .816 .964 r
.66419 .03957 .66515 .0406 .66717 .04001 .66621 .03884 Mtetra
.651 .788 .947 r
.66621 .03884 .66717 .04001 .6692 .03944 .66824 .03812 Mtetra
.653 .758 .926 r
.66824 .03812 .6692 .03944 .67123 .03886 .67026 .03739 Mtetra
.653 .731 .907 r
.67026 .03739 .67123 .03886 .67326 .03819 .67229 .03665 Mtetra
.654 .722 .899 r
.67229 .03665 .67326 .03819 .67529 .03747 .67431 .03591 Mtetra
.657 .719 .894 r
.67431 .03591 .67529 .03747 .67732 .03672 .67634 .03515 Mtetra
.661 .719 .892 r
.67634 .03515 .67732 .03672 .67934 .03596 .67837 .03437 Mtetra
.665 .717 .888 r
.67837 .03437 .67934 .03596 .68137 .03517 .6804 .03357 Mtetra
.669 .717 .885 r
.6804 .03357 .68137 .03517 .6834 .03435 .68243 .03273 Mtetra
.677 .72 .881 r
.68243 .03273 .6834 .03435 .68543 .03347 .68445 .03186 Mtetra
.679 .721 .881 r
.68445 .03186 .68543 .03347 .68745 .03258 .68648 .03097 Mtetra
.684 .724 .881 r
.68648 .03097 .68745 .03258 .68948 .03165 .68851 .03006 Mtetra
.756 .754 .851 r
.68851 .03006 .68948 .03165 .69148 .03026 .69051 .02869 Mtetra
.694 .734 .881 r
.69051 .02869 .69148 .03026 .6935 .02928 .69254 .02772 Mtetra
.524 .655 .918 r
.69254 .02772 .6935 .02928 .69558 .0291 .69461 .02753 Mtetra
.676 .264 0 r
.69461 .02753 .69558 .0291 .69794 .03365 .69697 .03192 Mtetra
.97 .656 .29 r
.69697 .03192 .69794 .03365 .71327 .24943 .71223 .24772 Mtetra
.733 .326 0 r
.71223 .24772 .71327 .24943 .71585 .25476 .71482 .25325 Mtetra
.145 .504 .91 r
.01624 .49276 .01755 .49399 .01908 .49455 .01778 .49325 Mtetra
.654 .725 .901 r
.01778 .49325 .01908 .49455 .02079 .49394 .01949 .49262 Mtetra
.786 .746 .816 r
.01949 .49262 .02079 .49394 .02268 .49216 .02135 .49102 Mtetra
.878 .754 .722 r
.02135 .49102 .02268 .49216 .02524 .48595 .0235 .48756 Mtetra
.981 .818 .608 r
.0235 .48756 .02524 .48595 .05805 .27869 .02646 .47868 Mtetra
0 0 0 r
.02646 .47868 .05805 .27869 .06046 .27279 .05846 .27677 Mtetra
.05846 .27677 .06046 .27279 .06218 .27141 .06058 .27279 Mtetra
.777 .967 .669 r
.06058 .27279 .06218 .27141 .06379 .2708 .06243 .27054 Mtetra
.837 .911 .887 r
.06243 .27054 .06379 .2708 .06534 .27057 .06417 .26904 Mtetra
.667 .682 .854 r
.06417 .26904 .06534 .27057 .06694 .27003 .0658 .26835 Mtetra
.601 .635 .857 r
.0658 .26835 .06694 .27003 .06854 .2695 .06738 .26797 Mtetra
.565 .642 .885 r
.06738 .26797 .06854 .2695 .07014 .26896 .06894 .26771 Mtetra
.644 .719 .903 r
.06894 .26771 .07014 .26896 .07176 .26832 .07054 .26717 Mtetra
.666 .743 .907 r
.07054 .26717 .07176 .26832 .07339 .26765 .07216 .26653 Mtetra
.681 .752 .905 r
.07216 .26653 .07339 .26765 .07501 .26698 .07379 .26583 Mtetra
.75 .759 .86 r
.07379 .26583 .07501 .26698 .07669 .26593 .07548 .26473 Mtetra
.718 .745 .873 r
.07548 .26473 .07669 .26593 .07833 .26518 .07714 .26382 Mtetra
.616 .691 .897 r
.07714 .26382 .07833 .26518 .07988 .26507 .07873 .26337 Mtetra
0 .053 .609 r
.07873 .26337 .07988 .26507 .0809 .26858 .08006 .2648 Mtetra
.777 .506 0 r
.08006 .2648 .0809 .26858 .053 .47428 .08093 .26945 Mtetra
0 0 0 r
.08093 .26945 .053 .47428 .0537 .48086 .05336 .47283 Mtetra
.017 0 .456 r
.05336 .47283 .0537 .48086 .05525 .48152 .05438 .47719 Mtetra
.237 .224 .64 r
.05438 .47719 .05525 .48152 .05696 .48108 .05581 .47875 Mtetra
.33 .428 .811 r
.05581 .47875 .05696 .48108 .05873 .48018 .05737 .47933 Mtetra
.314 .683 .978 r
.05737 .47933 .05873 .48018 .06041 .47995 .05901 .47941 Mtetra
.556 .849 .998 r
.05901 .47941 .06041 .47995 .06213 .47946 .06073 .47894 Mtetra
.757 .888 .937 r
.06073 .47894 .06213 .47946 .06395 .47826 .06254 .47784 Mtetra
.905 .844 .773 r
.06254 .47784 .06395 .47826 .06628 .47341 .06459 .475 Mtetra
.987 .884 .635 r
.06459 .475 .06628 .47341 .09662 .26647 .06707 .46901 Mtetra
0 0 0 r
.06707 .46901 .09662 .26647 .09927 .25853 .09711 .26421 Mtetra
.09711 .26421 .09927 .25853 .10108 .25667 .09945 .25851 Mtetra
.732 .919 .563 r
.09945 .25851 .10108 .25667 .10273 .25591 .10136 .25587 Mtetra
.862 .943 .87 r
.10136 .25587 .10273 .25591 .10432 .25557 .10315 .25417 Mtetra
.717 .716 .848 r
.10315 .25417 .10432 .25557 .10595 .25503 .10483 .2532 Mtetra
.641 .634 .828 r
.10483 .2532 .10595 .25503 .10758 .25443 .10647 .25259 Mtetra
.605 .617 .837 r
.10647 .25259 .10758 .25443 .10922 .25385 .10808 .25216 Mtetra
.614 .642 .854 r
.10808 .25216 .10922 .25385 .11086 .25322 .10969 .25171 Mtetra
.621 .67 .876 r
.10969 .25171 .11086 .25322 .1125 .25257 .11132 .25124 Mtetra
.634 .704 .896 r
.11132 .25124 .1125 .25257 .11415 .25192 .11294 .25072 Mtetra
.683 .742 .895 r
.11294 .25072 .11415 .25192 .11579 .25127 .1146 .24999 Mtetra
.698 .731 .876 r
.1146 .24999 .11579 .25127 .11744 .25063 .11627 .24917 Mtetra
.691 .702 .855 r
.11627 .24917 .11744 .25063 .11909 .24999 .11794 .24834 Mtetra
.704 .681 .825 r
.11794 .24834 .11909 .24999 .12078 .24898 .11963 .24739 Mtetra
.68 .68 .843 r
.11963 .24739 .12078 .24898 .12246 .24813 .1213 .2466 Mtetra
.591 .657 .883 r
.1213 .2466 .12246 .24813 .12406 .24788 .12291 .24624 Mtetra
0 .068 .618 r
.12291 .24624 .12406 .24788 .12526 .25066 .12429 .24767 Mtetra
.897 .57 .079 r
.12429 .24767 .12526 .25066 .10021 .45619 .12521 .25271 Mtetra
0 0 .017 r
.12521 .25271 .10021 .45619 .10084 .46432 .10041 .45646 Mtetra
.197 .112 .526 r
.10041 .45646 .10084 .46432 .10235 .46571 .10168 .45965 Mtetra
.521 .378 .628 r
.10168 .45965 .10235 .46571 .10407 .46544 .10337 .45959 Mtetra
.639 .467 .634 r
.10337 .45959 .10407 .46544 .10593 .46409 .10528 .45784 Mtetra
.808 .585 .6 r
.10528 .45784 .10593 .46409 .10815 .45987 .10803 .44948 Mtetra
.935 .677 .521 r
.10803 .44948 .10815 .45987 .13583 .25431 .13542 .2469 Mtetra
.719 .506 .6 r
.13542 .2469 .13583 .25431 .13875 .2437 .13759 .24221 Mtetra
.791 .724 .789 r
.13759 .24221 .13875 .2437 .14061 .24146 .13939 .2405 Mtetra
.68 .789 .932 r
.13939 .2405 .14061 .24146 .14229 .24073 .14106 .2398 Mtetra
.578 .767 .969 r
.14106 .2398 .14229 .24073 .1439 .24048 .14269 .23943 Mtetra
.725 .779 .895 r
.14269 .23943 .1439 .24048 .14559 .23965 .14439 .2385 Mtetra
.725 .762 .882 r
.14439 .2385 .14559 .23965 .14728 .23874 .14609 .23755 Mtetra
.57 .711 .937 r
.14609 .23755 .14728 .23874 .14891 .23843 .14771 .23723 Mtetra
.856 .41 .013 r
.14771 .23723 .14891 .23843 .15019 .24095 .14896 .24005 Mtetra
.947 .684 .504 r
.14896 .24005 .15019 .24095 .12674 .44656 .12519 .44749 Mtetra
.887 .549 .404 r
.12519 .44749 .12674 .44656 .1274 .45511 .12602 .45471 Mtetra
.561 0 0 r
.12602 .45471 .1274 .45511 .12896 .45635 .12759 .45582 Mtetra
.608 .87 .992 r
.12759 .45582 .12896 .45635 .13072 .45588 .12937 .45521 Mtetra
.794 .866 .902 r
.12937 .45521 .13072 .45588 .13255 .45485 .13124 .45386 Mtetra
.814 .807 .844 r
.13124 .45386 .13255 .45485 .13433 .45427 .13315 .45219 Mtetra
.786 .679 .746 r
.13315 .45219 .13433 .45427 .1361 .45379 .13512 .45002 Mtetra
.773 .597 .661 r
.13512 .45002 .1361 .45379 .13795 .45267 .13726 .4465 Mtetra
.874 .633 .571 r
.13726 .4465 .13795 .45267 .14013 .44869 .14094 .42976 Mtetra
.929 .666 .519 r
.14094 .42976 .14013 .44869 .16605 .24202 .16565 .23407 Mtetra
.69 .48 .596 r
.16565 .23407 .16605 .24202 .16884 .23191 .16772 .2301 Mtetra
.794 .694 .754 r
.16772 .2301 .16884 .23191 .17076 .22917 .16956 .22807 Mtetra
.738 .776 .884 r
.16956 .22807 .17076 .22917 .17249 .22811 .17128 .22706 Mtetra
.521 .722 .965 r
.17128 .22706 .17249 .22811 .17411 .22798 .17292 .22684 Mtetra
.717 .221 0 r
.17292 .22684 .17411 .22798 .17548 .23001 .1743 .22882 Mtetra
.95 .685 .497 r
.1743 .22882 .17548 .23001 .15467 .42681 .15333 .42622 Mtetra
.945 .648 .443 r
.15333 .42622 .15467 .42681 .15434 .4449 .15305 .44378 Mtetra
.598 .079 0 r
.15305 .44378 .15434 .4449 .15588 .44659 .15459 .44545 Mtetra
.629 .758 .94 r
.15459 .44545 .15588 .44659 .15767 .44605 .15638 .44489 Mtetra
.751 .783 .879 r
.15638 .44489 .15767 .44605 .15953 .44489 .15825 .44372 Mtetra
.729 .777 .891 r
.15825 .44372 .15953 .44489 .16138 .44386 .1601 .44268 Mtetra
.663 .761 .923 r
.1601 .44268 .16138 .44386 .16319 .44317 .16191 .44198 Mtetra
.656 .758 .925 r
.16191 .44198 .16319 .44317 .165 .44251 .16372 .44132 Mtetra
.53 .715 .957 r
.16372 .44132 .165 .44251 .16677 .44226 .16549 .44108 Mtetra
.496 .702 .961 r
.16549 .44108 .16677 .44226 .16852 .44211 .16725 .44092 Mtetra
.691 .768 .91 r
.16725 .44092 .16852 .44211 .17035 .44131 .16908 .44009 Mtetra
.89 .764 .716 r
.16908 .44009 .17035 .44131 .17247 .43787 .17122 .43645 Mtetra
.951 .689 .503 r
.17122 .43645 .17247 .43787 .1963 .23247 .19542 .2285 Mtetra
.873 .646 .592 r
.19542 .2285 .1963 .23247 .19923 .22035 .19812 .21858 Mtetra
.829 .707 .73 r
.19812 .21858 .19923 .22035 .20115 .21762 .20003 .21595 Mtetra
.674 .673 .841 r
.20003 .21595 .20115 .21762 .20287 .21686 .20174 .21517 Mtetra
.571 .629 .871 r
.20174 .21517 .20287 .21686 .20452 .21661 .2034 .21489 Mtetra
.578 .627 .864 r
.2034 .21489 .20452 .21661 .20619 .21633 .20507 .21457 Mtetra
.633 .645 .845 r
.20507 .21457 .20619 .21633 .20788 .21579 .20677 .214 Mtetra
.633 .642 .841 r
.20677 .214 .20788 .21579 .20957 .21523 .20846 .21342 Mtetra
.636 .641 .838 r
.20846 .21342 .20957 .21523 .21127 .21466 .21016 .21283 Mtetra
.64 .64 .835 r
.21016 .21283 .21127 .21466 .21298 .21405 .21187 .21221 Mtetra
.642 .64 .833 r
.21187 .21221 .21298 .21405 .21468 .21342 .21357 .21158 Mtetra
.644 .641 .832 r
.21357 .21158 .21468 .21342 .21639 .21277 .21528 .21093 Mtetra
.646 .642 .832 r
.21528 .21093 .21639 .21277 .2181 .21211 .21699 .21028 Mtetra
.648 .644 .832 r
.21699 .21028 .2181 .21211 .21982 .21142 .21871 .20961 Mtetra
.651 .647 .833 r
.21871 .20961 .21982 .21142 .22153 .21073 .22042 .20893 Mtetra
.653 .65 .834 r
.22042 .20893 .22153 .21073 .22325 .21003 .22214 .20824 Mtetra
.65 .65 .837 r
.22214 .20824 .22325 .21003 .22497 .20933 .22386 .20757 Mtetra
.639 .649 .844 r
.22386 .20757 .22497 .20933 .22669 .20864 .22557 .20697 Mtetra
.625 .656 .86 r
.22557 .20697 .22669 .20864 .22841 .20795 .22727 .20644 Mtetra
.627 .681 .882 r
.22727 .20644 .22841 .20795 .23013 .20726 .22898 .20592 Mtetra
.64 .714 .901 r
.22898 .20592 .23013 .20726 .23185 .20656 .23069 .20535 Mtetra
.662 .744 .911 r
.23069 .20535 .23185 .20656 .23358 .20585 .23241 .20469 Mtetra
.675 .759 .914 r
.23241 .20469 .23358 .20585 .23531 .20513 .23414 .20398 Mtetra
.692 .763 .906 r
.23414 .20398 .23531 .20513 .23703 .20444 .23587 .20319 Mtetra
.703 .748 .886 r
.23587 .20319 .23703 .20444 .23876 .20378 .23762 .20232 Mtetra
.695 .713 .862 r
.23762 .20232 .23876 .20378 .24048 .20312 .23936 .20146 Mtetra
.677 .678 .844 r
.23936 .20146 .24048 .20312 .24221 .20244 .2411 .20065 Mtetra
.657 .654 .835 r
.2411 .20065 .24221 .20244 .24394 .20174 .24284 .19993 Mtetra
.651 .65 .836 r
.24284 .19993 .24394 .20174 .24567 .20103 .24457 .19925 Mtetra
.65 .652 .839 r
.24457 .19925 .24567 .20103 .24741 .20034 .2463 .19858 Mtetra
.652 .656 .841 r
.2463 .19858 .24741 .20034 .24914 .19966 .24803 .1979 Mtetra
.651 .656 .842 r
.24803 .1979 .24914 .19966 .25087 .19898 .24976 .19723 Mtetra
.65 .656 .842 r
.24976 .19723 .25087 .19898 .25261 .19832 .2515 .19656 Mtetra
.649 .656 .843 r
.2515 .19656 .25261 .19832 .25434 .19765 .25323 .19589 Mtetra
.649 .655 .843 r
.25323 .19589 .25434 .19765 .25608 .19699 .25497 .19523 Mtetra
.649 .655 .842 r
.25497 .19523 .25608 .19699 .25781 .19632 .25671 .19456 Mtetra
.65 .656 .843 r
.25671 .19456 .25781 .19632 .25955 .19564 .25844 .19388 Mtetra
.65 .658 .844 r
.25844 .19388 .25955 .19564 .26129 .19496 .26018 .19321 Mtetra
.668 .665 .838 r
.26018 .19321 .26129 .19496 .26305 .19414 .26193 .19244 Mtetra
.694 .681 .834 r
.26193 .19244 .26305 .19414 .26482 .19311 .2637 .19152 Mtetra
.645 .678 .867 r
.2637 .19152 .26482 .19311 .26655 .19252 .26544 .19089 Mtetra
.385 .55 .895 r
.26544 .19089 .26655 .19252 .26817 .19329 .2671 .19116 Mtetra
0 0 .349 r
.2671 .19116 .26817 .19329 .26925 .20049 .26855 .19392 Mtetra
.966 .693 .466 r
.26855 .19392 .26925 .20049 .25344 .40894 .25408 .38544 Mtetra
0 0 .268 r
.25408 .38544 .25344 .40894 .25498 .41222 .25423 .40515 Mtetra
.501 .352 .61 r
.25423 .40515 .25498 .41222 .25681 .41204 .25603 .40534 Mtetra
.589 .42 .62 r
.25603 .40534 .25681 .41204 .2587 .41117 .25793 .40423 Mtetra
.608 .431 .617 r
.25793 .40423 .2587 .41117 .26061 .41011 .25988 .40273 Mtetra
.559 .39 .609 r
.25988 .40273 .26061 .41011 .26249 .40945 .26175 .40204 Mtetra
.559 .39 .608 r
.26175 .40204 .26249 .40945 .26436 .40879 .26363 .40133 Mtetra
.567 .395 .608 r
.26363 .40133 .26436 .40879 .26624 .40812 .26552 .40047 Mtetra
.589 .409 .606 r
.26552 .40047 .26624 .40812 .26812 .40743 .26745 .39919 Mtetra
.548 .374 .597 r
.26745 .39919 .26812 .40743 .27001 .40677 .26932 .39858 Mtetra
.451 .302 .587 r
.26932 .39858 .27001 .40677 .27188 .40618 .27108 .39951 Mtetra
.281 .199 .583 r
.27108 .39951 .27188 .40618 .27375 .40569 .27272 .40185 Mtetra
.247 .264 .682 r
.27272 .40185 .27375 .40569 .27562 .40521 .27444 .40335 Mtetra
.244 .452 .864 r
.27444 .40335 .27562 .40521 .2775 .40468 .27622 .40403 Mtetra
.447 .797 .998 r
.27622 .40403 .2775 .40468 .27939 .40403 .27808 .40376 Mtetra
.488 .877 .967 r
.27808 .40376 .27939 .40403 .28128 .40334 .27996 .40321 Mtetra
.498 .895 .942 r
.27996 .40321 .28128 .40334 .28317 .40274 .28186 .40256 Mtetra
.417 .851 .938 r
.28186 .40256 .28317 .40274 .28502 .40252 .28374 .40208 Mtetra
.646 .908 .981 r
.28374 .40208 .28502 .40252 .28692 .40186 .28564 .40127 Mtetra
.821 .899 .896 r
.28564 .40127 .28692 .40186 .2889 .40002 .2876 .39969 Mtetra
.951 .853 .709 r
.2876 .39969 .2889 .40002 .29128 .39274 .28975 .39566 Mtetra
.993 .849 .492 r
.28975 .39566 .29128 .39274 .30835 .18143 .29234 .38544 Mtetra
0 0 .146 r
.29234 .38544 .30835 .18143 .31045 .1763 .30888 .18103 Mtetra
.31 0 .246 r
.30888 .18103 .31045 .1763 .31225 .17512 .3107 .17975 Mtetra
.438 .101 .295 r
.3107 .17975 .31225 .17512 .31402 .17462 .31245 .1795 Mtetra
.366 .041 .275 r
.31245 .1795 .31402 .17462 .31576 .17436 .31425 .1786 Mtetra
0 0 0 r
.31425 .1786 .31576 .17436 .31755 .17356 .31624 .17488 Mtetra
.77 .937 .588 r
.31624 .17488 .31755 .17356 .31933 .17276 .31816 .17218 Mtetra
.865 .884 .848 r
.31816 .17218 .31933 .17276 .32112 .172 .32002 .1703 Mtetra
.662 .673 .85 r
.32002 .1703 .32112 .172 .3229 .17133 .3218 .16956 Mtetra
.607 .64 .858 r
.3218 .16956 .3229 .17133 .32468 .17068 .32357 .1691 Mtetra
.585 .658 .888 r
.32357 .1691 .32468 .17068 .32646 .17002 .32533 .16873 Mtetra
.653 .734 .909 r
.32533 .16873 .32646 .17002 .32824 .1693 .32712 .16809 Mtetra
.667 .754 .916 r
.32712 .16809 .32824 .1693 .33003 .16856 .3289 .16738 Mtetra
.688 .766 .911 r
.3289 .16738 .33003 .16856 .33182 .16781 .3307 .16659 Mtetra
.756 .776 .869 r
.3307 .16659 .33182 .16781 .33364 .16669 .33252 .16539 Mtetra
.708 .749 .884 r
.33252 .16539 .33364 .16669 .33543 .16598 .33432 .16446 Mtetra
.576 .667 .9 r
.33432 .16446 .33543 .16598 .33717 .1661 .33609 .16413 Mtetra
0 .063 .627 r
.33609 .16413 .33717 .1661 .33861 .17105 .33772 .166 Mtetra
0 0 .189 r
.33772 .166 .33861 .17105 .32738 .38163 .33906 .17269 Mtetra
0 0 .185 r
.33906 .17269 .32738 .38163 .32897 .38646 .32812 .37934 Mtetra
.206 .141 .559 r
.32812 .37934 .32897 .38646 .33084 .38663 .3298 .38255 Mtetra
.324 .306 .685 r
.3298 .38255 .33084 .38663 .33276 .38601 .33161 .3838 Mtetra
.397 .494 .841 r
.33161 .3838 .33276 .38601 .33471 .38501 .33348 .3842 Mtetra
.387 .737 .991 r
.33348 .3842 .33471 .38501 .33661 .38479 .33537 .38411 Mtetra
.61 .858 .99 r
.33537 .38411 .33661 .38479 .33854 .38414 .3373 .38347 Mtetra
.78 .893 .924 r
.3373 .38347 .33854 .38414 .34052 .38268 .33927 .38215 Mtetra
.934 .862 .745 r
.33927 .38215 .34052 .38268 .34276 .37665 .34136 .3788 Mtetra
.974 .883 .51 r
.34136 .3788 .34276 .37665 .3566 .16457 .34366 .37164 Mtetra
0 0 .175 r
.34366 .37164 .3566 .16457 .35874 .15795 .35729 .16272 Mtetra
0 0 0 r
.35729 .16272 .35874 .15795 .36059 .15645 .35933 .15788 Mtetra
.667 .883 .519 r
.35933 .15788 .36059 .15645 .3624 .15574 .36124 .15533 Mtetra
.845 .931 .885 r
.36124 .15533 .3624 .15574 .36418 .15542 .3631 .15369 Mtetra
.664 .672 .848 r
.3631 .15369 .36418 .15542 .36599 .15481 .36491 .15293 Mtetra
.599 .624 .848 r
.36491 .15293 .36599 .15481 .36779 .15423 .36671 .15249 Mtetra
.563 .627 .873 r
.36671 .15249 .36779 .15423 .3696 .15366 .3685 .15221 Mtetra
.639 .706 .894 r
.3685 .15221 .3696 .15366 .37141 .15302 .37031 .15161 Mtetra
.655 .719 .895 r
.37031 .15161 .37141 .15302 .37323 .15233 .37212 .15094 Mtetra
.665 .725 .893 r
.37212 .15094 .37323 .15233 .37504 .15161 .37394 .15022 Mtetra
.707 .739 .876 r
.37394 .15022 .37504 .15161 .37687 .1508 .37577 .14927 Mtetra
.684 .71 .869 r
.37577 .14927 .37687 .1508 .37869 .14998 .3776 .14844 Mtetra
.632 .688 .884 r
.3776 .14844 .37869 .14998 .38051 .14919 .37941 .14786 Mtetra
.412 .624 .94 r
.37941 .14786 .38051 .14919 .38236 .14806 .38119 .14796 Mtetra
.47 0 0 r
.38119 .14796 .38236 .14806 .38418 .14727 .38294 .14885 Mtetra
.744 .324 .251 r
.38294 .14885 .38418 .14727 .38598 .14719 .38461 .15148 Mtetra
.963 .676 .441 r
.38461 .15148 .38598 .14719 .38757 .15141 .37683 .3572 Mtetra
.516 .272 .484 r
.37683 .3572 .38757 .15141 .37974 .36278 .3784 .36483 Mtetra
.702 .286 .254 r
.3784 .36483 .37974 .36278 .38142 .36826 .38022 .3672 Mtetra
.071 .495 .896 r
.38022 .3672 .38142 .36826 .38332 .36904 .38213 .3678 Mtetra
.566 .735 .955 r
.38213 .3678 .38332 .36904 .38527 .36849 .38408 .36742 Mtetra
.782 .826 .887 r
.38408 .36742 .38527 .36849 .38728 .36682 .38608 .36601 Mtetra
.956 .799 .647 r
.38608 .36601 .38728 .36682 .38945 .36136 .38826 .36046 Mtetra
.97 .69 .443 r
.38826 .36046 .38945 .36136 .40032 .14836 .39926 .14628 Mtetra
.921 .712 .603 r
.39926 .14628 .40032 .14836 .40244 .14099 .40137 .13911 Mtetra
.765 .696 .786 r
.40137 .13911 .40244 .14099 .40432 .13921 .40324 .13749 Mtetra
.618 .657 .865 r
.40324 .13749 .40432 .13921 .40615 .1385 .40507 .13696 Mtetra
.499 .629 .91 r
.40507 .13696 .40615 .1385 .40797 .13822 .40688 .13688 Mtetra
.662 .737 .906 r
.40688 .13688 .40797 .13822 .40981 .13758 .40872 .13618 Mtetra
.674 .731 .893 r
.40872 .13618 .40981 .13758 .41165 .13687 .41057 .13541 Mtetra
.626 .702 .9 r
.41057 .13541 .41165 .13687 .41349 .13619 .4124 .13486 Mtetra
.437 .639 .941 r
.4124 .13486 .41349 .13619 .41535 .13518 .41422 .1349 Mtetra
.366 0 0 r
.41422 .1349 .41535 .13518 .41719 .13441 .41601 .13569 Mtetra
.737 .295 .203 r
.41601 .13569 .41719 .13441 .41902 .13427 .41774 .13808 Mtetra
.966 .675 .429 r
.41774 .13808 .41902 .13427 .42072 .13763 .41225 .34398 Mtetra
.518 .274 .484 r
.41225 .34398 .42072 .13763 .41525 .34876 .4139 .35271 Mtetra
.656 .287 .334 r
.4139 .35271 .41525 .34876 .41698 .35544 .41577 .3552 Mtetra
0 .569 .78 r
.41577 .3552 .41698 .35544 .41892 .35618 .41773 .35537 Mtetra
.652 .853 .977 r
.41773 .35537 .41892 .35618 .42091 .35559 .41973 .3546 Mtetra
.776 .846 .905 r
.41973 .3546 .42091 .35559 .42291 .35449 .42174 .35325 Mtetra
.837 .808 .822 r
.42174 .35325 .42291 .35449 .42491 .35359 .42378 .35121 Mtetra
.811 .684 .724 r
.42378 .35121 .42491 .35359 .42691 .35276 .42584 .34847 Mtetra
.762 .58 .651 r
.42584 .34847 .42691 .35276 .42891 .35192 .42792 .34495 Mtetra
.591 .419 .618 r
.42792 .34495 .42891 .35192 .4309 .35161 .42993 .34373 Mtetra
.525 .362 .603 r
.42993 .34373 .4309 .35161 .43289 .35117 .43191 .34354 Mtetra
.578 .403 .608 r
.43191 .34354 .43289 .35117 .4349 .35004 .43392 .34242 Mtetra
.967 .681 .437 r
.43392 .34242 .4349 .35004 .43702 .34534 .44144 .14556 Mtetra
.547 .303 .497 r
.44144 .14556 .43702 .34534 .44476 .13278 .44383 .12614 Mtetra
.719 .507 .603 r
.44383 .12614 .44476 .13278 .44684 .12426 .44579 .12202 Mtetra
.747 .658 .762 r
.44579 .12202 .44684 .12426 .44874 .12209 .44768 .12036 Mtetra
.663 .679 .855 r
.44768 .12036 .44874 .12209 .45061 .12129 .44955 .11959 Mtetra
.605 .658 .875 r
.44955 .11959 .45061 .12129 .45247 .12093 .45141 .11912 Mtetra
.632 .655 .854 r
.45141 .11912 .45247 .12093 .45434 .12036 .45328 .1185 Mtetra
.648 .655 .844 r
.45328 .1185 .45434 .12036 .45621 .11965 .45515 .11779 Mtetra
.647 .655 .844 r
.45515 .11779 .45621 .11965 .45808 .11895 .45702 .11709 Mtetra
.647 .654 .843 r
.45702 .11709 .45808 .11895 .45996 .11825 .4589 .11638 Mtetra
.647 .654 .842 r
.4589 .11638 .45996 .11825 .46183 .11755 .46077 .11567 Mtetra
.646 .653 .842 r
.46077 .11567 .46183 .11755 .46371 .11685 .46265 .11497 Mtetra
.647 .652 .841 r
.46265 .11497 .46371 .11685 .46558 .11617 .46453 .11426 Mtetra
.644 .647 .839 r
.46453 .11426 .46558 .11617 .46746 .1155 .46641 .11356 Mtetra
.638 .642 .838 r
.46641 .11356 .46746 .1155 .46934 .11482 .46829 .11289 Mtetra
.621 .635 .843 r
.46829 .11289 .46934 .11482 .47122 .11411 .47017 .11232 Mtetra
.612 .649 .863 r
.47017 .11232 .47122 .11411 .47311 .11339 .47205 .11181 Mtetra
.612 .681 .891 r
.47205 .11181 .47311 .11339 .47499 .11266 .47393 .1113 Mtetra
.632 .727 .916 r
.47393 .1113 .47499 .11266 .47687 .11197 .47581 .11071 Mtetra
.649 .752 .925 r
.47581 .11071 .47687 .11197 .47876 .1113 .4777 .11005 Mtetra
.656 .756 .923 r
.4777 .11005 .47876 .1113 .48065 .11064 .47959 .10935 Mtetra
.656 .75 .919 r
.47959 .10935 .48065 .11064 .48254 .10996 .48148 .10866 Mtetra
.656 .747 .917 r
.48148 .10866 .48254 .10996 .48443 .10927 .48337 .10796 Mtetra
.658 .747 .916 r
.48337 .10796 .48443 .10927 .48632 .10858 .48526 .10726 Mtetra
.659 .746 .915 r
.48526 .10726 .48632 .10858 .48821 .10787 .48716 .10655 Mtetra
.66 .746 .914 r
.48716 .10655 .48821 .10787 .49011 .10716 .48905 .10584 Mtetra
.661 .746 .913 r
.48905 .10584 .49011 .10716 .492 .10644 .49095 .10512 Mtetra
.49095 .10512 .492 .10644 .4939 .10572 .49285 .1044 Mtetra
.662 .746 .912 r
.49285 .1044 .4939 .10572 .4958 .105 .49475 .10367 Mtetra
.49475 .10367 .4958 .105 .4977 .10427 .49665 .10294 Mtetra
.663 .746 .912 r
.49665 .10294 .4977 .10427 .4996 .10355 .49855 .10221 Mtetra
.49855 .10221 .4996 .10355 .50151 .10281 .50045 .10148 Mtetra
.50045 .10148 .50151 .10281 .50341 .10208 .50236 .10075 Mtetra
.50236 .10075 .50341 .10208 .50532 .10135 .50427 .10001 Mtetra
.50427 .10001 .50532 .10135 .50722 .10062 .50617 .09928 Mtetra
.663 .746 .911 r
.50617 .09928 .50722 .10062 .50913 .09988 .50808 .09854 Mtetra
.50808 .09854 .50913 .09988 .51104 .09915 .50999 .09781 Mtetra
.50999 .09781 .51104 .09915 .51295 .09841 .51191 .09707 Mtetra
.664 .746 .911 r
.51191 .09707 .51295 .09841 .51486 .09767 .51382 .09633 Mtetra
.51382 .09633 .51486 .09767 .51678 .09693 .51573 .09559 Mtetra
.51573 .09559 .51678 .09693 .51869 .09619 .51765 .09485 Mtetra
.51765 .09485 .51869 .09619 .52061 .09545 .51957 .09411 Mtetra
.51957 .09411 .52061 .09545 .52253 .09471 .52149 .09337 Mtetra
.52149 .09337 .52253 .09471 .52445 .09397 .52341 .09263 Mtetra
.52341 .09263 .52445 .09397 .52637 .09323 .52533 .09188 Mtetra
.52533 .09188 .52637 .09323 .52829 .09249 .52725 .09114 Mtetra
.52725 .09114 .52829 .09249 .53021 .09175 .52917 .0904 Mtetra
.52917 .0904 .53021 .09175 .53214 .091 .5311 .08965 Mtetra
.5311 .08965 .53214 .091 .53406 .09026 .53303 .08891 Mtetra
.53303 .08891 .53406 .09026 .53599 .08952 .53495 .08816 Mtetra
.53495 .08816 .53599 .08952 .53792 .08877 .53688 .08742 Mtetra
.53688 .08742 .53792 .08877 .53985 .08803 .53881 .08667 Mtetra
.53881 .08667 .53985 .08803 .54178 .08728 .54075 .08592 Mtetra
.54075 .08592 .54178 .08728 .54371 .08653 .54268 .08518 Mtetra
.54268 .08518 .54371 .08653 .54565 .08579 .54461 .08443 Mtetra
.54461 .08443 .54565 .08579 .54758 .08504 .54655 .08368 Mtetra
.54655 .08368 .54758 .08504 .54952 .08429 .54849 .08293 Mtetra
.54849 .08293 .54952 .08429 .55146 .08354 .55043 .08218 Mtetra
.55043 .08218 .55146 .08354 .55339 .08279 .55237 .08143 Mtetra
.55237 .08143 .55339 .08279 .55534 .08204 .55431 .08068 Mtetra
.55431 .08068 .55534 .08204 .55728 .08129 .55625 .07992 Mtetra
.55625 .07992 .55728 .08129 .55922 .08053 .5582 .07917 Mtetra
.5582 .07917 .55922 .08053 .56117 .07978 .56014 .07841 Mtetra
.665 .746 .911 r
.56014 .07841 .56117 .07978 .56311 .07902 .56209 .07766 Mtetra
.665 .747 .911 r
.56209 .07766 .56311 .07902 .56506 .07826 .56404 .0769 Mtetra
.56404 .0769 .56506 .07826 .56701 .0775 .56599 .07614 Mtetra
.666 .747 .911 r
.56599 .07614 .56701 .0775 .56896 .07674 .56794 .07537 Mtetra
.667 .748 .911 r
.56794 .07537 .56896 .07674 .57091 .07597 .56989 .0746 Mtetra
.56989 .0746 .57091 .07597 .57286 .0752 .57184 .07383 Mtetra
.668 .749 .911 r
.57184 .07383 .57286 .0752 .57482 .07442 .5738 .07305 Mtetra
.669 .75 .911 r
.5738 .07305 .57482 .07442 .57677 .07363 .57575 .07227 Mtetra
.671 .751 .911 r
.57575 .07227 .57677 .07363 .57873 .07284 .57771 .07148 Mtetra
.671 .752 .911 r
.57771 .07148 .57873 .07284 .58068 .07203 .57967 .07069 Mtetra
.671 .755 .914 r
.57967 .07069 .58068 .07203 .58264 .07121 .58163 .0699 Mtetra
.678 .763 .915 r
.58163 .0699 .58264 .07121 .5846 .07039 .58359 .06908 Mtetra
.691 .767 .91 r
.58359 .06908 .5846 .07039 .58656 .0696 .58555 .06819 Mtetra
.705 .755 .891 r
.58555 .06819 .58656 .0696 .58853 .06885 .58751 .06721 Mtetra
.696 .717 .865 r
.58751 .06721 .58853 .06885 .59049 .0681 .58947 .06624 Mtetra
.677 .678 .843 r
.58947 .06624 .59049 .0681 .59246 .06734 .59144 .06533 Mtetra
.656 .65 .832 r
.59144 .06533 .59246 .06734 .59443 .06654 .5934 .06452 Mtetra
.65 .645 .832 r
.5934 .06452 .59443 .06654 .5964 .06575 .59537 .06374 Mtetra
.648 .646 .835 r
.59537 .06374 .5964 .06575 .59837 .06498 .59735 .06298 Mtetra
.649 .649 .836 r
.59735 .06298 .59837 .06498 .60034 .06424 .59932 .06222 Mtetra
.643 .642 .835 r
.59932 .06222 .60034 .06424 .60231 .06351 .60129 .06148 Mtetra
.632 .637 .837 r
.60129 .06148 .60231 .06351 .60429 .06276 .60327 .06081 Mtetra
.616 .639 .85 r
.60327 .06081 .60429 .06276 .60627 .06198 .60525 .06024 Mtetra
.616 .667 .877 r
.60525 .06024 .60627 .06198 .60824 .0612 .60724 .05969 Mtetra
.625 .707 .905 r
.60724 .05969 .60824 .0612 .61022 .06044 .60922 .05909 Mtetra
.65 .747 .921 r
.60922 .05909 .61022 .06044 .6122 .05972 .61121 .05839 Mtetra
.658 .755 .922 r
.61121 .05839 .6122 .05972 .61419 .059 .61319 .05765 Mtetra
.663 .753 .917 r
.61319 .05765 .61419 .059 .61617 .05828 .61517 .05689 Mtetra
.662 .747 .913 r
.61517 .05689 .61617 .05828 .61816 .05753 .61716 .05614 Mtetra
.664 .746 .911 r
.61716 .05614 .61816 .05753 .62014 .05677 .61915 .05537 Mtetra
.666 .745 .91 r
.61915 .05537 .62014 .05677 .62213 .05599 .62114 .05459 Mtetra
.666 .744 .909 r
.62114 .05459 .62213 .05599 .62412 .05521 .62313 .0538 Mtetra
.672 .748 .907 r
.62313 .0538 .62412 .05521 .62611 .05441 .62512 .05299 Mtetra
.684 .75 .902 r
.62512 .05299 .62611 .05441 .6281 .05361 .62711 .05212 Mtetra
.7 .746 .887 r
.62711 .05212 .6281 .05361 .63009 .05278 .62909 .05115 Mtetra
.695 .72 .869 r
.62909 .05115 .63009 .05278 .63208 .05196 .63108 .05018 Mtetra
.682 .693 .854 r
.63108 .05018 .63208 .05196 .63408 .05114 .63307 .04925 Mtetra
.662 .669 .846 r
.63307 .04925 .63408 .05114 .63607 .05034 .63507 .04841 Mtetra
.656 .663 .845 r
.63507 .04841 .63607 .05034 .63807 .04954 .63706 .04761 Mtetra
.653 .662 .846 r
.63706 .04761 .63807 .04954 .64007 .04874 .63907 .04683 Mtetra
.655 .664 .847 r
.63907 .04683 .64007 .04874 .64207 .04795 .64107 .04604 Mtetra
.653 .664 .847 r
.64107 .04604 .64207 .04795 .64407 .04717 .64307 .04525 Mtetra
.652 .663 .848 r
.64307 .04525 .64407 .04717 .64608 .04639 .64507 .04447 Mtetra
.64507 .04447 .64608 .04639 .64808 .04561 .64708 .04369 Mtetra
.651 .663 .848 r
.64708 .04369 .64808 .04561 .65009 .04484 .64909 .04292 Mtetra
.65 .662 .848 r
.64909 .04292 .65009 .04484 .6521 .04407 .6511 .04215 Mtetra
.65 .662 .849 r
.6511 .04215 .6521 .04407 .65411 .04331 .65311 .04139 Mtetra
.649 .661 .849 r
.65311 .04139 .65411 .04331 .65612 .04255 .65512 .04062 Mtetra
.648 .661 .848 r
.65512 .04062 .65612 .04255 .65814 .04179 .65714 .03986 Mtetra
.647 .66 .848 r
.65714 .03986 .65814 .04179 .66015 .04105 .65915 .03911 Mtetra
.647 .658 .847 r
.65915 .03911 .66015 .04105 .66217 .04031 .66117 .03836 Mtetra
.645 .656 .846 r
.66117 .03836 .66217 .04031 .66419 .03957 .66319 .03761 Mtetra
.644 .654 .845 r
.66319 .03761 .66419 .03957 .66621 .03884 .66521 .03687 Mtetra
.643 .652 .844 r
.66521 .03687 .66621 .03884 .66824 .03812 .66724 .03613 Mtetra
.643 .651 .843 r
.66724 .03613 .66824 .03812 .67026 .03739 .66926 .03538 Mtetra
.644 .65 .841 r
.66926 .03538 .67026 .03739 .67229 .03665 .67129 .03463 Mtetra
.645 .648 .838 r
.67129 .03463 .67229 .03665 .67431 .03591 .67331 .03387 Mtetra
.647 .647 .836 r
.67331 .03387 .67431 .03591 .67634 .03515 .67534 .03309 Mtetra
.649 .646 .833 r
.67534 .03309 .67634 .03515 .67837 .03437 .67737 .0323 Mtetra
.651 .646 .832 r
.67737 .0323 .67837 .03437 .6804 .03357 .6794 .03149 Mtetra
.654 .647 .83 r
.6794 .03149 .6804 .03357 .68243 .03273 .68143 .03066 Mtetra
.66 .65 .829 r
.68143 .03066 .68243 .03273 .68445 .03186 .68345 .0298 Mtetra
.661 .652 .83 r
.68345 .0298 .68445 .03186 .68648 .03097 .68548 .02893 Mtetra
.665 .655 .831 r
.68548 .02893 .68648 .03097 .68851 .03006 .68751 .02803 Mtetra
.725 .685 .812 r
.68751 .02803 .68851 .03006 .69051 .02869 .68952 .02671 Mtetra
.675 .668 .836 r
.68952 .02671 .69051 .02869 .69254 .02772 .69155 .02576 Mtetra
.541 .603 .865 r
.69155 .02576 .69254 .02772 .69461 .02753 .69362 .02555 Mtetra
0 0 .42 r
.69362 .02555 .69461 .02753 .69697 .03192 .69595 .02948 Mtetra
.97 .656 .288 r
.69595 .02948 .69697 .03192 .71223 .24772 .71115 .24539 Mtetra
.694 .331 0 r
.71115 .24539 .71223 .24772 .71482 .25325 .71379 .25169 Mtetra
.235 .556 .933 r
.01492 .49152 .01624 .49276 .01778 .49325 .01648 .49188 Mtetra
.657 .717 .893 r
.01648 .49188 .01778 .49325 .01949 .49262 .0182 .49123 Mtetra
.762 .736 .83 r
.0182 .49123 .01949 .49262 .02135 .49102 .02002 .48988 Mtetra
.782 .771 .844 r
.02002 .48988 .02135 .49102 .0235 .48756 .02186 .48845 Mtetra
.855 .997 .782 r
.02186 .48845 .0235 .48756 .02646 .47868 .02381 .48624 Mtetra
.014 0 .152 r
.02381 .48624 .02646 .47868 .05846 .27677 .02605 .4822 Mtetra
0 0 0 r
.02605 .4822 .05846 .27677 .06058 .27279 .05831 .27852 Mtetra
.82 .835 .365 r
.05831 .27852 .06058 .27279 .06243 .27054 .06096 .27101 Mtetra
.948 .914 .748 r
.06096 .27101 .06243 .27054 .06417 .26904 .06295 .26789 Mtetra
.725 .754 .875 r
.06295 .26789 .06417 .26904 .0658 .26835 .06461 .26695 Mtetra
.599 .677 .895 r
.06461 .26695 .0658 .26835 .06738 .26797 .06619 .26657 Mtetra
.511 .643 .915 r
.06619 .26657 .06738 .26797 .06894 .26771 .06772 .26647 Mtetra
.634 .716 .907 r
.06772 .26647 .06894 .26771 .07054 .26717 .06932 .26596 Mtetra
.657 .73 .903 r
.06932 .26596 .07054 .26717 .07216 .26653 .07094 .26535 Mtetra
.671 .74 .902 r
.07094 .26535 .07216 .26653 .07379 .26583 .07256 .26469 Mtetra
.723 .757 .879 r
.07256 .26469 .07379 .26583 .07548 .26473 .07423 .26376 Mtetra
.715 .788 .909 r
.07423 .26376 .07548 .26473 .07714 .26382 .07588 .26292 Mtetra
.656 .791 .946 r
.07588 .26292 .07714 .26382 .07873 .26337 .0775 .26232 Mtetra
.406 .669 .967 r
.0775 .26232 .07873 .26337 .08006 .2648 .07903 .26235 Mtetra
.291 .373 .775 r
.07903 .26235 .08006 .2648 .08093 .26945 .08045 .26308 Mtetra
.261 .172 .562 r
.08045 .26308 .08093 .26945 .05336 .47283 .08168 .26521 Mtetra
0 0 .006 r
.08168 .26521 .05336 .47283 .05438 .47719 .05462 .46516 Mtetra
0 0 .188 r
.05462 .46516 .05438 .47719 .05581 .47875 .0548 .4754 Mtetra
0 0 .476 r
.0548 .4754 .05581 .47875 .05737 .47933 .05607 .47805 Mtetra
.298 .582 .94 r
.05607 .47805 .05737 .47933 .05901 .47941 .05768 .47833 Mtetra
.632 .764 .942 r
.05768 .47833 .05901 .47941 .06073 .47894 .05941 .47778 Mtetra
.742 .771 .876 r
.05941 .47778 .06073 .47894 .06254 .47784 .06122 .47668 Mtetra
.781 .773 .845 r
.06122 .47668 .06254 .47784 .06459 .475 .06308 .47524 Mtetra
.886 .964 .84 r
.06308 .47524 .06459 .475 .06707 .46901 .06502 .47315 Mtetra
0 0 0 r
.06502 .47315 .06707 .46901 .09711 .26421 .06717 .46963 Mtetra
0 0 .009 r
.06717 .46963 .09711 .26421 .09945 .25851 .0963 .27127 Mtetra
.69 .701 .172 r
.0963 .27127 .09945 .25851 .10136 .25587 .09985 .25684 Mtetra
.964 .932 .702 r
.09985 .25684 .10136 .25587 .10315 .25417 .10191 .25316 Mtetra
.79 .788 .85 r
.10191 .25316 .10315 .25417 .10483 .2532 .10365 .25179 Mtetra
.656 .698 .877 r
.10365 .25179 .10483 .2532 .10647 .25259 .10529 .25117 Mtetra
.574 .667 .901 r
.10529 .25117 .10647 .25259 .10808 .25216 .10688 .25087 Mtetra
.604 .7 .912 r
.10688 .25087 .10808 .25216 .10969 .25171 .10849 .25046 Mtetra
.615 .713 .915 r
.10849 .25046 .10969 .25171 .11132 .25124 .11011 .25002 Mtetra
.623 .721 .917 r
.11011 .25002 .11132 .25124 .11294 .25072 .11173 .24954 Mtetra
.671 .743 .904 r
.11173 .24954 .11294 .25072 .1146 .24999 .11338 .24887 Mtetra
.692 .758 .902 r
.11338 .24887 .1146 .24999 .11627 .24917 .11505 .2481 Mtetra
.696 .77 .908 r
.11505 .2481 .11627 .24917 .11794 .24834 .11671 .24733 Mtetra
.707 .781 .909 r
.11671 .24733 .11794 .24834 .11963 .24739 .11839 .2465 Mtetra
.686 .804 .938 r
.11839 .2465 .11963 .24739 .1213 .2466 .12005 .24578 Mtetra
.612 .802 .973 r
.12005 .24578 .1213 .2466 .12291 .24624 .12168 .2453 Mtetra
.158 .559 .93 r
.12168 .2453 .12291 .24624 .12429 .24767 .1232 .24565 Mtetra
.027 .261 .761 r
.1232 .24565 .12429 .24767 .12521 .25271 .12463 .24675 Mtetra
.291 .205 .583 r
.12463 .24675 .12521 .25271 .10041 .45646 .12596 .24861 Mtetra
.497 .262 .488 r
.12596 .24861 .10041 .45646 .10168 .45965 .12736 .24996 Mtetra
.501 .265 .489 r
.12736 .24996 .10168 .45965 .10337 .45959 .12894 .24993 Mtetra
.505 .269 .49 r
.12894 .24993 .10337 .45959 .10528 .45784 .13071 .24842 Mtetra
.508 .272 .491 r
.13071 .24842 .10528 .45784 .10803 .44948 .13266 .24548 Mtetra
.13266 .24548 .10803 .44948 .13542 .2469 .13459 .24279 Mtetra
.697 .534 .663 r
.13459 .24279 .13542 .2469 .13759 .24221 .13643 .24072 Mtetra
.735 .711 .828 r
.13643 .24072 .13759 .24221 .13939 .2405 .13815 .23957 Mtetra
.673 .794 .939 r
.13815 .23957 .13939 .2405 .14106 .2398 .13982 .2389 Mtetra
.627 .789 .96 r
.13982 .2389 .14106 .2398 .14269 .23943 .14147 .23838 Mtetra
.74 .783 .887 r
.14147 .23838 .14269 .23943 .14439 .2385 .14318 .23737 Mtetra
.73 .766 .882 r
.14318 .23737 .14439 .2385 .14609 .23755 .14489 .23639 Mtetra
.577 .721 .941 r
.14489 .23639 .14609 .23755 .14771 .23723 .14652 .23605 Mtetra
.851 .401 .002 r
.14652 .23605 .14771 .23723 .14896 .24005 .14777 .2388 Mtetra
.948 .685 .504 r
.14777 .2388 .14896 .24005 .12519 .44749 .12393 .44605 Mtetra
.95 .61 .332 r
.12393 .44605 .12519 .44749 .12602 .45471 .12473 .45346 Mtetra
0 .134 .63 r
.12473 .45346 .12602 .45471 .12759 .45582 .12629 .4547 Mtetra
.616 .757 .946 r
.12629 .4547 .12759 .45582 .12937 .45521 .12806 .45419 Mtetra
.789 .805 .865 r
.12806 .45419 .12937 .45521 .13124 .45386 .12994 .45276 Mtetra
.874 .778 .753 r
.12994 .45276 .13124 .45386 .13315 .45219 .132 .44986 Mtetra
.88 .689 .639 r
.132 .44986 .13315 .45219 .13512 .45002 .13447 .44356 Mtetra
.942 .682 .514 r
.13447 .44356 .13512 .45002 .13726 .4465 .16069 .23763 Mtetra
.515 .277 .493 r
.16069 .23763 .13726 .4465 .14094 .42976 .16293 .2322 Mtetra
.507 .271 .491 r
.16293 .2322 .14094 .42976 .16565 .23407 .16481 .22985 Mtetra
.662 .508 .666 r
.16481 .22985 .16565 .23407 .16772 .2301 .1666 .2283 Mtetra
.738 .678 .793 r
.1666 .2283 .16772 .2301 .16956 .22807 .16836 .22699 Mtetra
.73 .778 .891 r
.16836 .22699 .16956 .22807 .17128 .22706 .17008 .22602 Mtetra
.556 .741 .962 r
.17008 .22602 .17128 .22706 .17292 .22684 .17172 .22572 Mtetra
.706 .206 0 r
.17172 .22572 .17292 .22684 .1743 .22882 .17311 .22764 Mtetra
.95 .685 .497 r
.17311 .22764 .1743 .22882 .15333 .42622 .15199 .42563 Mtetra
.945 .646 .441 r
.15199 .42563 .15333 .42622 .15305 .44378 .15176 .44264 Mtetra
.594 .074 0 r
.15176 .44264 .15305 .44378 .15459 .44545 .1533 .44431 Mtetra
.629 .759 .94 r
.1533 .44431 .15459 .44545 .15638 .44489 .1551 .44375 Mtetra
.752 .785 .88 r
.1551 .44375 .15638 .44489 .15825 .44372 .15696 .44257 Mtetra
.73 .782 .894 r
.15696 .44257 .15825 .44372 .1601 .44268 .15882 .44153 Mtetra
.664 .768 .927 r
.15882 .44153 .1601 .44268 .16191 .44198 .16063 .44083 Mtetra
.658 .765 .929 r
.16063 .44083 .16191 .44198 .16372 .44132 .16244 .44015 Mtetra
.533 .722 .96 r
.16244 .44015 .16372 .44132 .16549 .44108 .16421 .4399 Mtetra
.501 .706 .962 r
.16421 .4399 .16549 .44108 .16725 .44092 .16597 .43973 Mtetra
.695 .768 .908 r
.16597 .43973 .16725 .44092 .16908 .44009 .1678 .43888 Mtetra
.892 .763 .714 r
.1678 .43888 .16908 .44009 .17122 .43645 .16995 .43517 Mtetra
.951 .689 .503 r
.16995 .43517 .17122 .43645 .19542 .2285 .19429 .22674 Mtetra
.921 .707 .596 r
.19429 .22674 .19542 .2285 .19812 .21858 .19695 .21726 Mtetra
.855 .751 .748 r
.19695 .21726 .19812 .21858 .20003 .21595 .19886 .21465 Mtetra
.689 .733 .884 r
.19886 .21465 .20003 .21595 .20174 .21517 .20058 .21385 Mtetra
.57 .69 .922 r
.20058 .21385 .20174 .21517 .2034 .21489 .20224 .21355 Mtetra
.58 .69 .917 r
.20224 .21355 .2034 .21489 .20507 .21457 .20391 .21321 Mtetra
.645 .71 .895 r
.20391 .21321 .20507 .21457 .20677 .214 .20561 .21262 Mtetra
.645 .708 .893 r
.20561 .21262 .20677 .214 .20846 .21342 .20731 .21203 Mtetra
.648 .706 .889 r
.20731 .21203 .20846 .21342 .21016 .21283 .20901 .21143 Mtetra
.652 .706 .887 r
.20901 .21143 .21016 .21283 .21187 .21221 .21071 .2108 Mtetra
.654 .705 .885 r
.21071 .2108 .21187 .21221 .21357 .21158 .21242 .21016 Mtetra
.656 .706 .884 r
.21242 .21016 .21357 .21158 .21528 .21093 .21413 .20952 Mtetra
.657 .706 .884 r
.21413 .20952 .21528 .21093 .21699 .21028 .21584 .20887 Mtetra
.658 .708 .884 r
.21584 .20887 .21699 .21028 .21871 .20961 .21755 .20821 Mtetra
.66 .71 .885 r
.21755 .20821 .21871 .20961 .22042 .20893 .21927 .20755 Mtetra
.661 .714 .887 r
.21927 .20755 .22042 .20893 .22214 .20824 .22098 .20688 Mtetra
.657 .716 .892 r
.22098 .20688 .22214 .20824 .22386 .20757 .2227 .20623 Mtetra
.643 .715 .9 r
.2227 .20623 .22386 .20757 .22557 .20697 .22441 .20565 Mtetra
.624 .713 .909 r
.22441 .20565 .22557 .20697 .22727 .20644 .22611 .20515 Mtetra
.623 .716 .913 r
.22611 .20515 .22727 .20644 .22898 .20592 .22782 .20465 Mtetra
.636 .724 .912 r
.22782 .20465 .22898 .20592 .23069 .20535 .22953 .20409 Mtetra
.656 .734 .907 r
.22953 .20409 .23069 .20535 .23241 .20469 .23125 .20346 Mtetra
.669 .742 .905 r
.23125 .20346 .23241 .20469 .23414 .20398 .23297 .20277 Mtetra
.685 .751 .902 r
.23297 .20277 .23414 .20398 .23587 .20319 .23471 .202 Mtetra
.699 .76 .899 r
.23471 .202 .23587 .20319 .23762 .20232 .23645 .20117 Mtetra
.7 .767 .904 r
.23645 .20117 .23762 .20232 .23936 .20146 .23819 .20034 Mtetra
.691 .771 .913 r
.23819 .20034 .23936 .20146 .2411 .20065 .23993 .19956 Mtetra
.673 .771 .924 r
.23993 .19956 .2411 .20065 .24284 .19993 .24166 .19885 Mtetra
.667 .771 .928 r
.24166 .19885 .24284 .19993 .24457 .19925 .24339 .19817 Mtetra
.665 .772 .929 r
.24339 .19817 .24457 .19925 .2463 .19858 .24512 .1975 Mtetra
.666 .773 .929 r
.24512 .1975 .2463 .19858 .24803 .1979 .24686 .19683 Mtetra
.665 .773 .93 r
.24686 .19683 .24803 .1979 .24976 .19723 .24859 .19615 Mtetra
.664 .773 .931 r
.24859 .19615 .24976 .19723 .2515 .19656 .25033 .19549 Mtetra
.663 .773 .932 r
.25033 .19549 .2515 .19656 .25323 .19589 .25206 .19482 Mtetra
.663 .774 .932 r
.25206 .19482 .25323 .19589 .25497 .19523 .2538 .19416 Mtetra
.662 .774 .932 r
.2538 .19416 .25497 .19523 .25671 .19456 .25553 .1935 Mtetra
.663 .776 .933 r
.25553 .1935 .25671 .19456 .25844 .19388 .25727 .19283 Mtetra
.663 .777 .934 r
.25727 .19283 .25844 .19388 .26018 .19321 .25901 .19216 Mtetra
.677 .782 .929 r
.25901 .19216 .26018 .19321 .26193 .19244 .26076 .19144 Mtetra
.698 .797 .926 r
.26076 .19144 .26193 .19244 .2637 .19152 .26251 .19062 Mtetra
.659 .81 .956 r
.26251 .19062 .2637 .19152 .26544 .19089 .26426 .18996 Mtetra
.499 .747 .984 r
.26426 .18996 .26544 .19089 .2671 .19116 .26596 .18975 Mtetra
.113 .431 .872 r
.26596 .18975 .2671 .19116 .26855 .19392 .26759 .19045 Mtetra
.257 .277 .69 r
.26759 .19045 .26855 .19392 .25408 .38544 .26917 .19174 Mtetra
.497 .263 .489 r
.26917 .19174 .25408 .38544 .25423 .40515 .27075 .19314 Mtetra
.501 .266 .49 r
.27075 .19314 .25423 .40515 .25603 .40534 .27247 .19283 Mtetra
.503 .267 .49 r
.27247 .19283 .25603 .40534 .25793 .40423 .27425 .19184 Mtetra
.503 .268 .49 r
.27425 .19184 .25793 .40423 .25988 .40273 .27604 .19072 Mtetra
.503 .267 .49 r
.27604 .19072 .25988 .40273 .26175 .40204 .27781 .18997 Mtetra
.27781 .18997 .26175 .40204 .26363 .40133 .27957 .18923 Mtetra
.27957 .18923 .26363 .40133 .26552 .40047 .28135 .1883 Mtetra
.504 .268 .49 r
.28135 .1883 .26552 .40047 .26745 .39919 .28316 .18691 Mtetra
.502 .267 .49 r
.28316 .18691 .26745 .39919 .26932 .39858 .28492 .1863 Mtetra
.496 .262 .488 r
.28492 .1863 .26932 .39858 .27108 .39951 .28649 .18807 Mtetra
0 0 .156 r
.28649 .18807 .27108 .39951 .27272 .40185 .27197 .39455 Mtetra
0 0 .367 r
.27197 .39455 .27272 .40185 .27444 .40335 .2733 .40091 Mtetra
0 .086 .644 r
.2733 .40091 .27444 .40335 .27622 .40403 .27498 .40289 Mtetra
.478 .711 .972 r
.27498 .40289 .27622 .40403 .27808 .40376 .27683 .40275 Mtetra
.64 .797 .958 r
.27683 .40275 .27808 .40376 .27996 .40321 .27872 .4021 Mtetra
.69 .792 .928 r
.27872 .4021 .27996 .40321 .28186 .40256 .28063 .40126 Mtetra
.642 .744 .922 r
.28063 .40126 .28186 .40256 .28374 .40208 .28252 .40062 Mtetra
.68 .729 .888 r
.28252 .40062 .28374 .40208 .28564 .40127 .28443 .39979 Mtetra
.736 .743 .857 r
.28443 .39979 .28564 .40127 .2876 .39969 .28637 .39859 Mtetra
.845 .808 .815 r
.28637 .39859 .2876 .39969 .28975 .39566 .28837 .39649 Mtetra
.857 .988 .718 r
.28837 .39649 .28975 .39566 .29234 .38544 .29041 .39386 Mtetra
.286 .011 .31 r
.29041 .39386 .29234 .38544 .30888 .18103 .29246 .39116 Mtetra
.499 .258 .481 r
.29246 .39116 .30888 .18103 .3107 .17975 .29433 .39088 Mtetra
.498 .258 .481 r
.29433 .39088 .3107 .17975 .31245 .1795 .29621 .39042 Mtetra
.495 .255 .48 r
.29621 .39042 .31245 .1795 .31425 .1786 .29822 .38825 Mtetra
0 0 .158 r
.29822 .38825 .31425 .1786 .31624 .17488 .31457 .18119 Mtetra
0 0 0 r
.31457 .18119 .31624 .17488 .31816 .17218 .31693 .17226 Mtetra
.956 .913 .731 r
.31693 .17226 .31816 .17218 .32002 .1703 .31889 .16898 Mtetra
.708 .746 .882 r
.31889 .16898 .32002 .1703 .3218 .16956 .32069 .16805 Mtetra
.598 .677 .896 r
.32069 .16805 .3218 .16956 .32357 .1691 .32246 .16764 Mtetra
.538 .659 .914 r
.32246 .16764 .32357 .1691 .32533 .16873 .32421 .16743 Mtetra
.646 .731 .911 r
.32421 .16743 .32533 .16873 .32712 .16809 .32599 .16681 Mtetra
.658 .741 .911 r
.32599 .16681 .32712 .16809 .3289 .16738 .32777 .16615 Mtetra
.677 .753 .908 r
.32777 .16615 .3289 .16738 .3307 .16659 .32957 .1654 Mtetra
.731 .775 .888 r
.32957 .1654 .3307 .16659 .33252 .16539 .33138 .16437 Mtetra
.712 .803 .922 r
.33138 .16437 .33252 .16539 .33432 .16446 .33318 .16347 Mtetra
.639 .789 .954 r
.33318 .16347 .33432 .16446 .33609 .16413 .33497 .16287 Mtetra
.4 .631 .947 r
.33497 .16287 .33609 .16413 .33772 .166 .33671 .16298 Mtetra
.33 .357 .738 r
.33671 .16298 .33772 .166 .33906 .17269 .3384 .16386 Mtetra
.315 .192 .549 r
.3384 .16386 .33906 .17269 .32812 .37934 .33999 .16665 Mtetra
0 0 .191 r
.33999 .16665 .32812 .37934 .3298 .38255 .32904 .37398 Mtetra
0 0 .411 r
.32904 .37398 .3298 .38255 .33161 .3838 .33051 .38077 Mtetra
0 .119 .651 r
.33051 .38077 .33161 .3838 .33348 .3842 .33227 .38293 Mtetra
.459 .679 .96 r
.33227 .38293 .33348 .3842 .33537 .38411 .33416 .38287 Mtetra
.662 .765 .927 r
.33416 .38287 .33537 .38411 .3373 .38347 .3361 .38213 Mtetra
.753 .774 .87 r
.3361 .38213 .3373 .38347 .33927 .38215 .33807 .38085 Mtetra
.79 .786 .848 r
.33807 .38085 .33927 .38215 .34136 .3788 .34005 .37928 Mtetra
.856 .997 .776 r
.34005 .37928 .34136 .3788 .34366 .37164 .34208 .37694 Mtetra
0 0 .092 r
.34208 .37694 .34366 .37164 .35729 .16272 .34421 .37296 Mtetra
0 0 .186 r
.34421 .37296 .35729 .16272 .35933 .15788 .35773 .16522 Mtetra
0 0 0 r
.35773 .16522 .35933 .15788 .36124 .15533 .36003 .15577 Mtetra
.959 .944 .701 r
.36003 .15577 .36124 .15533 .3631 .15369 .36199 .15236 Mtetra
.722 .753 .877 r
.36199 .15236 .3631 .15369 .36491 .15293 .36382 .15134 Mtetra
.602 .669 .887 r
.36382 .15134 .36491 .15293 .36671 .15249 .36561 .1509 Mtetra
.523 .632 .9 r
.36561 .1509 .36671 .15249 .3685 .15221 .3674 .15076 Mtetra
.639 .705 .895 r
.3674 .15076 .3685 .15221 .37031 .15161 .36921 .15016 Mtetra
.653 .711 .891 r
.36921 .15016 .37031 .15161 .37212 .15094 .37102 .14949 Mtetra
.66 .715 .889 r
.37102 .14949 .37212 .15094 .37394 .15022 .37284 .14879 Mtetra
.727 .74 .862 r
.37284 .14879 .37394 .15022 .37577 .14927 .37468 .14772 Mtetra
.685 .707 .864 r
.37468 .14772 .37577 .14927 .3776 .14844 .3765 .14686 Mtetra
.579 .661 .894 r
.3765 .14686 .3776 .14844 .37941 .14786 .37831 .14651 Mtetra
0 0 .51 r
.37831 .14651 .37941 .14786 .38119 .14796 .38 .1484 Mtetra
.915 .548 .321 r
.38 .1484 .38119 .14796 .38294 .14885 .38143 .15605 Mtetra
.96 .672 .445 r
.38143 .15605 .38294 .14885 .38461 .15148 .37342 .36225 Mtetra
.505 .264 .482 r
.37342 .36225 .38461 .15148 .37683 .3572 .37522 .36497 Mtetra
.531 .219 .383 r
.37522 .36497 .37683 .3572 .3784 .36483 .3771 .36592 Mtetra
.385 0 0 r
.3771 .36592 .3784 .36483 .38022 .3672 .37902 .36614 Mtetra
.276 .626 .961 r
.37902 .36614 .38022 .3672 .38213 .3678 .38094 .36638 Mtetra
.567 .702 .932 r
.38094 .36638 .38213 .3678 .38408 .36742 .3829 .36603 Mtetra
.746 .768 .871 r
.3829 .36603 .38408 .36742 .38608 .36601 .38489 .36478 Mtetra
.938 .774 .652 r
.38489 .36478 .38608 .36601 .38826 .36046 .38706 .35939 Mtetra
.97 .69 .443 r
.38706 .35939 .38826 .36046 .39926 .14628 .39814 .14538 Mtetra
.962 .766 .592 r
.39814 .14538 .39926 .14628 .40137 .13911 .40026 .13795 Mtetra
.815 .801 .838 r
.40026 .13795 .40137 .13911 .40324 .13749 .40214 .13628 Mtetra
.627 .748 .934 r
.40214 .13628 .40324 .13749 .40507 .13696 .40397 .13572 Mtetra
.484 .681 .953 r
.40397 .13572 .40507 .13696 .40688 .13688 .40579 .13561 Mtetra
.696 .759 .901 r
.40579 .13561 .40688 .13688 .40872 .13618 .40763 .13475 Mtetra
.686 .729 .883 r
.40763 .13475 .40872 .13618 .41057 .13541 .40948 .13391 Mtetra
.587 .679 .904 r
.40948 .13391 .41057 .13541 .4124 .13486 .41131 .13351 Mtetra
0 .128 .653 r
.41131 .13351 .4124 .13486 .41422 .1349 .41307 .13504 Mtetra
.903 .508 .253 r
.41307 .13504 .41422 .1349 .41601 .13569 .41468 .1409 Mtetra
.964 .674 .432 r
.41468 .1409 .41601 .13569 .41774 .13808 .40889 .34904 Mtetra
.507 .265 .482 r
.40889 .34904 .41774 .13808 .41225 .34398 .41072 .35263 Mtetra
.54 .232 .394 r
.41072 .35263 .41225 .34398 .4139 .35271 .41264 .35383 Mtetra
.411 0 0 r
.41264 .35383 .4139 .35271 .41577 .3552 .41459 .35414 Mtetra
.469 .731 .984 r
.41459 .35414 .41577 .3552 .41773 .35537 .41656 .35397 Mtetra
.647 .74 .917 r
.41656 .35397 .41773 .35537 .41973 .3546 .41856 .35328 Mtetra
.762 .787 .873 r
.41856 .35328 .41973 .3546 .42174 .35325 .42057 .35194 Mtetra
.901 .79 .728 r
.42057 .35194 .42174 .35325 .42378 .35121 .42266 .3485 Mtetra
.916 .696 .59 r
.42266 .3485 .42378 .35121 .42584 .34847 .4249 .34008 Mtetra
.966 .68 .44 r
.4249 .34008 .42584 .34847 .42792 .34495 .43334 .13118 Mtetra
.507 .271 .49 r
.43334 .13118 .42792 .34495 .42993 .34373 .43527 .12845 Mtetra
.502 .266 .49 r
.43527 .12845 .42993 .34373 .43191 .34354 .43712 .1279 Mtetra
.501 .266 .49 r
.43712 .1279 .43191 .34354 .43392 .34242 .43898 .12761 Mtetra
.506 .27 .49 r
.43898 .12761 .43392 .34242 .44144 .14556 .44089 .1252 Mtetra
.563 .339 .534 r
.44089 .1252 .44144 .14556 .44383 .12614 .44281 .12258 Mtetra
.716 .567 .686 r
.44281 .12258 .44383 .12614 .44579 .12202 .44472 .12051 Mtetra
.736 .737 .852 r
.44472 .12051 .44579 .12202 .44768 .12036 .4466 .11933 Mtetra
.668 .802 .947 r
.4466 .11933 .44768 .12036 .44955 .11959 .44847 .1186 Mtetra
.624 .795 .964 r
.44847 .1186 .44955 .11959 .45141 .11912 .45033 .11801 Mtetra
.649 .781 .944 r
.45033 .11801 .45141 .11912 .45328 .1185 .4522 .11735 Mtetra
.662 .776 .934 r
.4522 .11735 .45328 .1185 .45515 .11779 .45407 .11664 Mtetra
.662 .775 .933 r
.45407 .11664 .45515 .11779 .45702 .11709 .45595 .11592 Mtetra
.662 .774 .932 r
.45595 .11592 .45702 .11709 .4589 .11638 .45782 .11521 Mtetra
.662 .773 .932 r
.45782 .11521 .4589 .11638 .46077 .11567 .4597 .1145 Mtetra
.661 .772 .932 r
.4597 .1145 .46077 .11567 .46265 .11497 .46158 .11379 Mtetra
.662 .771 .931 r
.46158 .11379 .46265 .11497 .46453 .11426 .46346 .11307 Mtetra
.659 .77 .931 r
.46346 .11307 .46453 .11426 .46641 .11356 .46534 .11237 Mtetra
.653 .766 .932 r
.46534 .11237 .46641 .11356 .46829 .11289 .46722 .11169 Mtetra
.632 .757 .937 r
.46722 .11169 .46829 .11289 .47017 .11232 .4691 .1111 Mtetra
.618 .747 .938 r
.4691 .1111 .47017 .11232 .47205 .11181 .47098 .11056 Mtetra
.617 .742 .935 r
.47098 .11056 .47205 .11181 .47393 .1113 .47286 .11002 Mtetra
.636 .743 .926 r
.47286 .11002 .47393 .1113 .47581 .11071 .47475 .10941 Mtetra
.651 .745 .918 r
.47475 .10941 .47581 .11071 .4777 .11005 .47663 .10873 Mtetra
.657 .745 .915 r
.47663 .10873 .4777 .11005 .47959 .10935 .47852 .10803 Mtetra
.657 .744 .914 r
.47852 .10803 .47959 .10935 .48148 .10866 .48042 .10733 Mtetra
.657 .743 .913 r
.48042 .10733 .48148 .10866 .48337 .10796 .48231 .10663 Mtetra
.658 .742 .912 r
.48231 .10663 .48337 .10796 .48526 .10726 .4842 .10592 Mtetra
.659 .742 .911 r
.4842 .10592 .48526 .10726 .48716 .10655 .4861 .1052 Mtetra
.66 .741 .91 r
.4861 .1052 .48716 .10655 .48905 .10584 .48799 .10449 Mtetra
.661 .741 .91 r
.48799 .10449 .48905 .10584 .49095 .10512 .48989 .10376 Mtetra
.661 .741 .909 r
.48989 .10376 .49095 .10512 .49285 .1044 .49179 .10304 Mtetra
.662 .741 .909 r
.49179 .10304 .49285 .1044 .49475 .10367 .49369 .10231 Mtetra
.49369 .10231 .49475 .10367 .49665 .10294 .49559 .10158 Mtetra
.662 .741 .908 r
.49559 .10158 .49665 .10294 .49855 .10221 .4975 .10085 Mtetra
.4975 .10085 .49855 .10221 .50045 .10148 .4994 .10012 Mtetra
.663 .741 .908 r
.4994 .10012 .50045 .10148 .50236 .10075 .50131 .09938 Mtetra
.50131 .09938 .50236 .10075 .50427 .10001 .50322 .09865 Mtetra
.50322 .09865 .50427 .10001 .50617 .09928 .50512 .09791 Mtetra
.50512 .09791 .50617 .09928 .50808 .09854 .50703 .09718 Mtetra
.50703 .09718 .50808 .09854 .50999 .09781 .50895 .09644 Mtetra
.50895 .09644 .50999 .09781 .51191 .09707 .51086 .0957 Mtetra
.51086 .0957 .51191 .09707 .51382 .09633 .51277 .09496 Mtetra
.51277 .09496 .51382 .09633 .51573 .09559 .51469 .09422 Mtetra
.51469 .09422 .51573 .09559 .51765 .09485 .51661 .09348 Mtetra
.51661 .09348 .51765 .09485 .51957 .09411 .51852 .09274 Mtetra
.51852 .09274 .51957 .09411 .52149 .09337 .52044 .09199 Mtetra
.52044 .09199 .52149 .09337 .52341 .09263 .52236 .09125 Mtetra
.52236 .09125 .52341 .09263 .52533 .09188 .52429 .09051 Mtetra
.52429 .09051 .52533 .09188 .52725 .09114 .52621 .08976 Mtetra
.52621 .08976 .52725 .09114 .52917 .0904 .52813 .08902 Mtetra
.52813 .08902 .52917 .0904 .5311 .08965 .53006 .08827 Mtetra
.53006 .08827 .5311 .08965 .53303 .08891 .53199 .08753 Mtetra
.53199 .08753 .53303 .08891 .53495 .08816 .53392 .08678 Mtetra
.53392 .08678 .53495 .08816 .53688 .08742 .53585 .08604 Mtetra
.53585 .08604 .53688 .08742 .53881 .08667 .53778 .08529 Mtetra
.53778 .08529 .53881 .08667 .54075 .08592 .53971 .08454 Mtetra
.53971 .08454 .54075 .08592 .54268 .08518 .54165 .08379 Mtetra
.54165 .08379 .54268 .08518 .54461 .08443 .54358 .08304 Mtetra
.54358 .08304 .54461 .08443 .54655 .08368 .54552 .08229 Mtetra
.54552 .08229 .54655 .08368 .54849 .08293 .54746 .08154 Mtetra
.54746 .08154 .54849 .08293 .55043 .08218 .5494 .08079 Mtetra
.664 .741 .908 r
.5494 .08079 .55043 .08218 .55237 .08143 .55134 .08004 Mtetra
.55134 .08004 .55237 .08143 .55431 .08068 .55328 .07929 Mtetra
.55328 .07929 .55431 .08068 .55625 .07992 .55522 .07853 Mtetra
.55522 .07853 .55625 .07992 .5582 .07917 .55717 .07778 Mtetra
.55717 .07778 .5582 .07917 .56014 .07841 .55912 .07702 Mtetra
.664 .741 .907 r
.55912 .07702 .56014 .07841 .56209 .07766 .56106 .07626 Mtetra
.56106 .07626 .56209 .07766 .56404 .0769 .56301 .0755 Mtetra
.665 .742 .907 r
.56301 .0755 .56404 .0769 .56599 .07614 .56496 .07474 Mtetra
.56496 .07474 .56599 .07614 .56794 .07537 .56692 .07398 Mtetra
.666 .743 .907 r
.56692 .07398 .56794 .07537 .56989 .0746 .56887 .07321 Mtetra
.56887 .07321 .56989 .0746 .57184 .07383 .57082 .07244 Mtetra
.667 .744 .908 r
.57082 .07244 .57184 .07383 .5738 .07305 .57278 .07167 Mtetra
.668 .745 .908 r
.57278 .07167 .5738 .07305 .57575 .07227 .57474 .07089 Mtetra
.669 .746 .908 r
.57474 .07089 .57575 .07227 .57771 .07148 .5767 .0701 Mtetra
.669 .747 .909 r
.5767 .0701 .57771 .07148 .57967 .07069 .57866 .06931 Mtetra
.669 .748 .91 r
.57866 .06931 .57967 .07069 .58163 .0699 .58062 .06853 Mtetra
.674 .751 .909 r
.58062 .06853 .58163 .0699 .58359 .06908 .58258 .06772 Mtetra
.687 .758 .906 r
.58258 .06772 .58359 .06908 .58555 .06819 .58454 .06685 Mtetra
.702 .767 .902 r
.58454 .06685 .58555 .06819 .58751 .06721 .5865 .0659 Mtetra
.702 .772 .906 r
.5865 .0659 .58751 .06721 .58947 .06624 .58846 .06495 Mtetra
.693 .774 .914 r
.58846 .06495 .58947 .06624 .59144 .06533 .59043 .06406 Mtetra
.674 .771 .923 r
.59043 .06406 .59144 .06533 .5934 .06452 .5924 .06326 Mtetra
.667 .769 .926 r
.5924 .06326 .5934 .06452 .59537 .06374 .59437 .06248 Mtetra
.664 .769 .928 r
.59437 .06248 .59537 .06374 .59735 .06298 .59634 .06172 Mtetra
.666 .77 .927 r
.59634 .06172 .59735 .06298 .59932 .06222 .59832 .06095 Mtetra
.66 .767 .929 r
.59832 .06095 .59932 .06222 .60129 .06148 .60029 .06021 Mtetra
.646 .761 .932 r
.60029 .06021 .60129 .06148 .60327 .06081 .60227 .05953 Mtetra
.625 .749 .936 r
.60227 .05953 .60327 .06081 .60525 .06024 .60425 .05893 Mtetra
.622 .743 .933 r
.60425 .05893 .60525 .06024 .60724 .05969 .60624 .05834 Mtetra
.631 .741 .927 r
.60624 .05834 .60724 .05969 .60922 .05909 .60822 .05772 Mtetra
.653 .745 .917 r
.60822 .05772 .60922 .05909 .61121 .05839 .61021 .05701 Mtetra
.66 .746 .913 r
.61021 .05701 .61121 .05839 .61319 .05765 .61219 .05626 Mtetra
.664 .745 .911 r
.61219 .05626 .61319 .05765 .61517 .05689 .61418 .05549 Mtetra
.663 .743 .91 r
.61418 .05549 .61517 .05689 .61716 .05614 .61616 .05472 Mtetra
.666 .743 .907 r
.61616 .05472 .61716 .05614 .61915 .05537 .61815 .05394 Mtetra
.668 .742 .906 r
.61815 .05394 .61915 .05537 .62114 .05459 .62014 .05315 Mtetra
.668 .74 .904 r
.62014 .05315 .62114 .05459 .62313 .0538 .62213 .05235 Mtetra
.673 .741 .901 r
.62213 .05235 .62313 .0538 .62512 .05299 .62412 .05153 Mtetra
.684 .743 .896 r
.62412 .05153 .62512 .05299 .62711 .05212 .62611 .05065 Mtetra
.702 .748 .888 r
.62611 .05065 .62711 .05212 .62909 .05115 .6281 .04967 Mtetra
.702 .747 .887 r
.6281 .04967 .62909 .05115 .63108 .05018 .63009 .04869 Mtetra
.694 .743 .889 r
.63009 .04869 .63108 .05018 .63307 .04925 .63208 .04775 Mtetra
.675 .735 .895 r
.63208 .04775 .63307 .04925 .63507 .04841 .63407 .04691 Mtetra
.669 .731 .896 r
.63407 .04691 .63507 .04841 .63706 .04761 .63607 .0461 Mtetra
.665 .728 .896 r
.63607 .0461 .63706 .04761 .63907 .04683 .63807 .04531 Mtetra
.666 .728 .896 r
.63807 .04531 .63907 .04683 .64107 .04604 .64008 .04452 Mtetra
.664 .727 .896 r
.64008 .04452 .64107 .04604 .64307 .04525 .64208 .04373 Mtetra
.663 .726 .896 r
.64208 .04373 .64307 .04525 .64507 .04447 .64409 .04295 Mtetra
.662 .726 .897 r
.64409 .04295 .64507 .04447 .64708 .04369 .64609 .04217 Mtetra
.661 .725 .897 r
.64609 .04217 .64708 .04369 .64909 .04292 .6481 .0414 Mtetra
.66 .725 .897 r
.6481 .0414 .64909 .04292 .6511 .04215 .65011 .04063 Mtetra
.66 .725 .898 r
.65011 .04063 .6511 .04215 .65311 .04139 .65213 .03986 Mtetra
.659 .725 .898 r
.65213 .03986 .65311 .04139 .65512 .04062 .65414 .0391 Mtetra
.65414 .0391 .65512 .04062 .65714 .03986 .65616 .03834 Mtetra
.658 .724 .898 r
.65616 .03834 .65714 .03986 .65915 .03911 .65817 .03758 Mtetra
.657 .723 .897 r
.65817 .03758 .65915 .03911 .66117 .03836 .66019 .03682 Mtetra
.657 .722 .897 r
.66019 .03682 .66117 .03836 .66319 .03761 .66221 .03606 Mtetra
.656 .72 .896 r
.66221 .03606 .66319 .03761 .66521 .03687 .66423 .03531 Mtetra
.656 .718 .895 r
.66423 .03531 .66521 .03687 .66724 .03613 .66626 .03456 Mtetra
.656 .716 .893 r
.66626 .03456 .66724 .03613 .66926 .03538 .66828 .0338 Mtetra
.657 .715 .891 r
.66828 .0338 .66926 .03538 .67129 .03463 .67031 .03303 Mtetra
.659 .714 .889 r
.67031 .03303 .67129 .03463 .67331 .03387 .67233 .03226 Mtetra
.66 .713 .887 r
.67233 .03226 .67331 .03387 .67534 .03309 .67436 .03147 Mtetra
.663 .712 .885 r
.67436 .03147 .67534 .03309 .67737 .0323 .67639 .03068 Mtetra
.665 .713 .884 r
.67639 .03068 .67737 .0323 .6794 .03149 .67842 .02986 Mtetra
.668 .714 .882 r
.67842 .02986 .6794 .03149 .68143 .03066 .68045 .02903 Mtetra
.673 .716 .881 r
.68045 .02903 .68143 .03066 .68345 .0298 .68248 .02818 Mtetra
.675 .718 .881 r
.68248 .02818 .68345 .0298 .68548 .02893 .68451 .02731 Mtetra
.678 .721 .881 r
.68451 .02731 .68548 .02893 .68751 .02803 .68654 .02643 Mtetra
.746 .749 .855 r
.68654 .02643 .68751 .02803 .68952 .02671 .68855 .02512 Mtetra
.688 .73 .882 r
.68855 .02512 .68952 .02671 .69155 .02576 .69058 .02419 Mtetra
.53 .657 .916 r
.69058 .02419 .69155 .02576 .69362 .02555 .69265 .02397 Mtetra
0 0 .372 r
.69265 .02397 .69362 .02555 .69595 .02948 .69497 .02774 Mtetra
.97 .656 .29 r
.69497 .02774 .69595 .02948 .71115 .24539 .71009 .24344 Mtetra
.769 .381 0 r
.71009 .24344 .71115 .24539 .71379 .25169 .71276 .25011 Mtetra
.346 .619 .953 r
.0136 .4903 .01492 .49152 .01648 .49188 .01519 .49048 Mtetra
.66 .712 .886 r
.01519 .49048 .01648 .49188 .0182 .49123 .01691 .48981 Mtetra
.731 .726 .846 r
.01691 .48981 .0182 .49123 .02002 .48988 .0187 .4887 Mtetra
.481 .691 .96 r
.0187 .4887 .02002 .48988 .02186 .48845 .02033 .4886 Mtetra
.359 .832 .855 r
.02033 .4886 .02186 .48845 .02381 .48624 .02203 .48809 Mtetra
0 0 0 r
.02203 .48809 .02381 .48624 .02605 .4822 .02385 .48678 Mtetra
.84 .871 .428 r
.02385 .48678 .02605 .4822 .05831 .27852 .02643 .48046 Mtetra
0 0 0 r
.02643 .48046 .05831 .27852 .06096 .27101 .05922 .27327 Mtetra
.983 .907 .609 r
.05922 .27327 .06096 .27101 .06295 .26789 .0616 .26751 Mtetra
.824 .894 .892 r
.0616 .26751 .06295 .26789 .06461 .26695 .06333 .26611 Mtetra
.664 .803 .95 r
.06333 .26611 .06461 .26695 .06619 .26657 .06495 .26548 Mtetra
.549 .719 .952 r
.06495 .26548 .06619 .26657 .06772 .26647 .06651 .26522 Mtetra
.647 .721 .902 r
.06651 .26522 .06772 .26647 .06932 .26596 .06812 .26466 Mtetra
.648 .712 .894 r
.06812 .26466 .06932 .26596 .07094 .26535 .06973 .26409 Mtetra
.649 .718 .899 r
.06973 .26409 .07094 .26535 .07256 .26469 .07134 .26352 Mtetra
.666 .739 .904 r
.07134 .26352 .07256 .26469 .07423 .26376 .07296 .26287 Mtetra
.672 .796 .941 r
.07296 .26287 .07423 .26376 .07588 .26292 .07459 .26222 Mtetra
.665 .835 .965 r
.07459 .26222 .07588 .26292 .0775 .26232 .07622 .26157 Mtetra
.754 .833 .912 r
.07622 .26157 .0775 .26232 .07903 .26235 .0779 .26055 Mtetra
.665 .646 .821 r
.0779 .26055 .07903 .26235 .08045 .26308 .07954 .2598 Mtetra
.532 .459 .719 r
.07954 .2598 .08045 .26308 .08168 .26521 .08109 .25971 Mtetra
0 0 .453 r
.08109 .25971 .08168 .26521 .05462 .46516 .08212 .2632 Mtetra
0 0 0 r
.08212 .2632 .05462 .46516 .0548 .4754 .0542 .46926 Mtetra
0 0 .102 r
.0542 .46926 .0548 .4754 .05607 .47805 .05491 .47582 Mtetra
.275 .41 .818 r
.05491 .47582 .05607 .47805 .05768 .47833 .05646 .4765 Mtetra
.607 .636 .853 r
.05646 .4765 .05768 .47833 .05941 .47778 .05818 .47605 Mtetra
.691 .679 .834 r
.05818 .47605 .05941 .47778 .06122 .47668 .05996 .47513 Mtetra
.563 .658 .9 r
.05996 .47513 .06122 .47668 .06308 .47524 .06165 .47486 Mtetra
.541 .871 .993 r
.06165 .47486 .06308 .47524 .06502 .47315 .06338 .47435 Mtetra
0 0 0 r
.06338 .47435 .06502 .47315 .06717 .46963 .0652 .47314 Mtetra
.803 .879 .448 r
.0652 .47314 .06717 .46963 .0963 .27127 .06755 .46823 Mtetra
0 0 0 r
.06755 .46823 .0963 .27127 .09985 .25684 .09794 .26073 Mtetra
.964 .89 .51 r
.09794 .26073 .09985 .25684 .10191 .25316 .10056 .25301 Mtetra
.869 .921 .86 r
.10056 .25301 .10191 .25316 .10365 .25179 .10235 .25123 Mtetra
.643 .863 .982 r
.10235 .25123 .10365 .25179 .10529 .25117 .10399 .25061 Mtetra
.427 .79 .996 r
.10399 .25061 .10529 .25117 .10688 .25087 .10557 .25041 Mtetra
.617 .877 .99 r
.10557 .25041 .10688 .25087 .10849 .25046 .10721 .24982 Mtetra
.681 .853 .965 r
.10721 .24982 .10849 .25046 .11011 .25002 .10887 .2491 Mtetra
.683 .796 .935 r
.10887 .2491 .11011 .25002 .11173 .24954 .11052 .24839 Mtetra
.662 .747 .913 r
.11052 .24839 .11173 .24954 .11338 .24887 .11216 .24776 Mtetra
.653 .753 .923 r
.11216 .24776 .11338 .24887 .11505 .2481 .11381 .24717 Mtetra
.65 .786 .947 r
.11381 .24717 .11505 .2481 .11671 .24733 .11545 .24658 Mtetra
.656 .828 .966 r
.11545 .24658 .11671 .24733 .11839 .2465 .11709 .24596 Mtetra
.647 .868 .982 r
.11709 .24596 .11839 .2465 .12005 .24578 .11875 .24532 Mtetra
.634 .881 .987 r
.11875 .24532 .12005 .24578 .12168 .2453 .1204 .24469 Mtetra
.631 .851 .983 r
.1204 .24469 .12168 .2453 .1232 .24565 .12204 .2441 Mtetra
.638 .673 .867 r
.12204 .2441 .1232 .24565 .12463 .24675 .12368 .24355 Mtetra
.596 .504 .72 r
.12368 .24355 .12463 .24675 .12596 .24861 .12533 .243 Mtetra
.564 .41 .631 r
.12533 .243 .12596 .24861 .12736 .24996 .12697 .24243 Mtetra
.551 .376 .597 r
.12697 .24243 .12736 .24996 .12894 .24993 .12862 .24186 Mtetra
.549 .369 .59 r
.12862 .24186 .12894 .24993 .13071 .24842 .13027 .24126 Mtetra
.557 .384 .603 r
.13027 .24126 .13071 .24842 .13266 .24548 .13193 .24063 Mtetra
.581 .437 .651 r
.13193 .24063 .13266 .24548 .13459 .24279 .13359 .23997 Mtetra
.62 .54 .742 r
.13359 .23997 .13459 .24279 .13643 .24072 .13526 .2393 Mtetra
.661 .701 .876 r
.13526 .2393 .13643 .24072 .13815 .23957 .13692 .23864 Mtetra
.667 .792 .941 r
.13692 .23864 .13815 .23957 .13982 .2389 .13859 .23799 Mtetra
.669 .797 .943 r
.13859 .23799 .13982 .2389 .14147 .23838 .14025 .23732 Mtetra
.75 .782 .879 r
.14025 .23732 .14147 .23838 .14318 .23737 .14197 .23624 Mtetra
.733 .768 .881 r
.14197 .23624 .14318 .23737 .14489 .23639 .14368 .23525 Mtetra
.588 .728 .94 r
.14368 .23525 .14489 .23639 .14652 .23605 .14532 .23487 Mtetra
.827 .365 0 r
.14532 .23487 .14652 .23605 .14777 .2388 .14659 .23741 Mtetra
.948 .685 .504 r
.14659 .23741 .14777 .2388 .12393 .44605 .12282 .44347 Mtetra
.967 .643 .304 r
.12282 .44347 .12393 .44605 .12473 .45346 .12349 .4518 Mtetra
0 .081 .623 r
.12349 .4518 .12473 .45346 .12629 .4547 .12502 .4533 Mtetra
.565 .689 .923 r
.12502 .4533 .12629 .4547 .12806 .45419 .12677 .453 Mtetra
.775 .776 .853 r
.12677 .453 .12806 .45419 .12994 .45276 .12865 .45161 Mtetra
.898 .76 .7 r
.12865 .45161 .12994 .45276 .132 .44986 .13085 .44749 Mtetra
.947 .687 .512 r
.13085 .44749 .132 .44986 .13447 .44356 .15733 .24103 Mtetra
.529 .289 .496 r
.15733 .24103 .13447 .44356 .16069 .23763 .16023 .23021 Mtetra
.646 .449 .603 r
.16023 .23021 .16069 .23763 .16293 .2322 .16213 .22775 Mtetra
.598 .46 .664 r
.16213 .22775 .16293 .2322 .16481 .22985 .16382 .22695 Mtetra
.568 .506 .745 r
.16382 .22695 .16481 .22985 .1666 .2283 .16546 .22663 Mtetra
.667 .669 .842 r
.16546 .22663 .1666 .2283 .16836 .22699 .16716 .2259 Mtetra
.721 .774 .895 r
.16716 .2259 .16836 .22699 .17008 .22602 .16887 .22498 Mtetra
.585 .748 .955 r
.16887 .22498 .17008 .22602 .17172 .22572 .17052 .22459 Mtetra
.695 .194 0 r
.17052 .22459 .17172 .22572 .17311 .22764 .17191 .22648 Mtetra
.95 .685 .497 r
.17191 .22648 .17311 .22764 .15199 .42563 .15059 .4255 Mtetra
.938 .637 .442 r
.15059 .4255 .15199 .42563 .15176 .44264 .15047 .44154 Mtetra
.598 .075 0 r
.15047 .44154 .15176 .44264 .1533 .44431 .15201 .44319 Mtetra
.628 .763 .944 r
.15201 .44319 .1533 .44431 .1551 .44375 .15381 .44264 Mtetra
.752 .79 .884 r
.15381 .44264 .1551 .44375 .15696 .44257 .15567 .44146 Mtetra
.732 .788 .898 r
.15567 .44146 .15696 .44257 .15882 .44153 .15752 .44042 Mtetra
.666 .775 .931 r
.15752 .44042 .15882 .44153 .16063 .44083 .15934 .43971 Mtetra
.661 .772 .932 r
.15934 .43971 .16063 .44083 .16244 .44015 .16115 .43902 Mtetra
.545 .733 .962 r
.16115 .43902 .16244 .44015 .16421 .4399 .16293 .43873 Mtetra
.518 .714 .961 r
.16293 .43873 .16421 .4399 .16597 .43973 .16469 .43851 Mtetra
.694 .763 .905 r
.16469 .43851 .16597 .43973 .1678 .43888 .16653 .43766 Mtetra
.886 .766 .724 r
.16653 .43766 .1678 .43888 .16995 .43517 .16865 .4342 Mtetra
.952 .69 .503 r
.16865 .4342 .16995 .43517 .19429 .22674 .19275 .22882 Mtetra
.993 .804 .546 r
.19275 .22882 .19429 .22674 .19695 .21726 .19568 .21685 Mtetra
.914 .857 .771 r
.19568 .21685 .19695 .21726 .19886 .21465 .19761 .21411 Mtetra
.691 .885 .969 r
.19761 .21411 .19886 .21465 .20058 .21385 .19933 .2133 Mtetra
.473 .815 .999 r
.19933 .2133 .20058 .21385 .20224 .21355 .20099 .21301 Mtetra
.49 .824 .999 r
.20099 .21301 .20224 .21355 .20391 .21321 .20266 .21267 Mtetra
.615 .869 .99 r
.20266 .21267 .20391 .21321 .20561 .21262 .20436 .21208 Mtetra
.617 .868 .99 r
.20436 .21208 .20561 .21262 .20731 .21203 .20606 .21148 Mtetra
.623 .869 .989 r
.20606 .21148 .20731 .21203 .20901 .21143 .20777 .21087 Mtetra
.63 .87 .987 r
.20777 .21087 .20901 .21143 .21071 .2108 .20947 .21025 Mtetra
.633 .871 .986 r
.20947 .21025 .21071 .2108 .21242 .21016 .21118 .20961 Mtetra
.635 .871 .986 r
.21118 .20961 .21242 .21016 .21413 .20952 .21289 .20897 Mtetra
.636 .872 .986 r
.21289 .20897 .21413 .20952 .21584 .20887 .2146 .20832 Mtetra
.635 .873 .986 r
.2146 .20832 .21584 .20887 .21755 .20821 .21631 .20768 Mtetra
.628 .873 .988 r
.21631 .20768 .21755 .20821 .21927 .20755 .21803 .20705 Mtetra
.619 .878 .99 r
.21803 .20705 .21927 .20755 .22098 .20688 .21974 .20643 Mtetra
.62 .887 .989 r
.21974 .20643 .22098 .20688 .2227 .20623 .22145 .20578 Mtetra
.646 .895 .984 r
.22145 .20578 .2227 .20623 .22441 .20565 .22318 .20508 Mtetra
.684 .879 .971 r
.22318 .20508 .22441 .20565 .22611 .20515 .22491 .20429 Mtetra
.694 .823 .944 r
.22491 .20429 .22611 .20515 .22782 .20465 .22664 .2035 Mtetra
.68 .762 .913 r
.22664 .2035 .22782 .20465 .22953 .20409 .22837 .20277 Mtetra
.66 .724 .896 r
.22837 .20277 .22953 .20409 .23125 .20346 .23009 .20211 Mtetra
.656 .718 .894 r
.23009 .20211 .23125 .20346 .23297 .20277 .23181 .20146 Mtetra
.659 .727 .9 r
.23181 .20146 .23297 .20277 .23471 .202 .23354 .20081 Mtetra
.666 .75 .913 r
.23354 .20081 .23471 .202 .23645 .20117 .23527 .20013 Mtetra
.668 .779 .933 r
.23527 .20013 .23645 .20117 .23819 .20034 .23699 .19945 Mtetra
.667 .81 .952 r
.23699 .19945 .23819 .20034 .23993 .19956 .23872 .19876 Mtetra
.664 .83 .963 r
.23872 .19876 .23993 .19956 .24166 .19885 .24046 .19808 Mtetra
.662 .835 .966 r
.24046 .19808 .24166 .19885 .24339 .19817 .24219 .1974 Mtetra
.661 .834 .966 r
.24219 .1974 .24339 .19817 .24512 .1975 .24392 .19672 Mtetra
.659 .833 .966 r
.24392 .19672 .24512 .1975 .24686 .19683 .24565 .19605 Mtetra
.658 .833 .967 r
.24565 .19605 .24686 .19683 .24859 .19615 .24739 .19538 Mtetra
.656 .833 .968 r
.24739 .19538 .24859 .19615 .25033 .19549 .24912 .19471 Mtetra
.655 .834 .969 r
.24912 .19471 .25033 .19549 .25206 .19482 .25086 .19405 Mtetra
.653 .834 .97 r
.25086 .19405 .25206 .19482 .2538 .19416 .2526 .1934 Mtetra
.652 .835 .971 r
.2526 .1934 .2538 .19416 .25553 .1935 .25433 .19274 Mtetra
.65 .837 .972 r
.25433 .19274 .25553 .1935 .25727 .19283 .25607 .19209 Mtetra
.65 .84 .973 r
.25607 .19209 .25727 .19283 .25901 .19216 .25781 .19144 Mtetra
.655 .844 .973 r
.25781 .19144 .25901 .19216 .26076 .19144 .25955 .19077 Mtetra
.659 .857 .975 r
.25955 .19077 .26076 .19144 .26251 .19062 .2613 .19007 Mtetra
.649 .879 .983 r
.2613 .19007 .26251 .19062 .26426 .18996 .26305 .18937 Mtetra
.647 .871 .983 r
.26305 .18937 .26426 .18996 .26596 .18975 .26479 .18869 Mtetra
.659 .776 .936 r
.26479 .18869 .26596 .18975 .26759 .19045 .26654 .18804 Mtetra
.627 .578 .78 r
.26654 .18804 .26759 .19045 .26917 .19174 .26829 .18738 Mtetra
.587 .457 .67 r
.26829 .18738 .26917 .19174 .27075 .19314 .27004 .18671 Mtetra
.566 .401 .617 r
.27004 .18671 .27075 .19314 .27247 .19283 .27179 .186 Mtetra
.563 .394 .61 r
.27179 .186 .27247 .19283 .27425 .19184 .27355 .18527 Mtetra
.566 .399 .614 r
.27355 .18527 .27425 .19184 .27604 .19072 .2753 .18455 Mtetra
.569 .407 .622 r
.2753 .18455 .27604 .19072 .27781 .18997 .27706 .18383 Mtetra
.568 .407 .622 r
.27706 .18383 .27781 .18997 .27957 .18923 .27882 .18312 Mtetra
.575 .412 .623 r
.27882 .18312 .27957 .18923 .28135 .1883 .28058 .18232 Mtetra
.594 .427 .626 r
.28058 .18232 .28135 .1883 .28316 .18691 .28237 .18125 Mtetra
.568 .414 .633 r
.28237 .18125 .28316 .18691 .28492 .1863 .28413 .18061 Mtetra
.461 .338 .626 r
.28413 .18061 .28492 .1863 .28649 .18807 .28579 .18118 Mtetra
0 0 .334 r
.28579 .18118 .28649 .18807 .27197 .39455 .287 .18753 Mtetra
0 0 .137 r
.287 .18753 .27197 .39455 .2733 .40091 .27226 .39711 Mtetra
0 0 .434 r
.27226 .39711 .2733 .40091 .27498 .40289 .27381 .4008 Mtetra
.532 .58 .849 r
.27381 .4008 .27498 .40289 .27683 .40275 .27566 .40066 Mtetra
.662 .642 .819 r
.27566 .40066 .27683 .40275 .27872 .4021 .27757 .39981 Mtetra
.682 .63 .792 r
.27757 .39981 .27872 .4021 .28063 .40126 .27949 .39875 Mtetra
.602 .573 .795 r
.27949 .39875 .28063 .40126 .28252 .40062 .28137 .39823 Mtetra
.605 .586 .805 r
.28137 .39823 .28252 .40062 .28443 .39979 .28326 .39771 Mtetra
.617 .623 .834 r
.28326 .39771 .28443 .39979 .28637 .39859 .28515 .39714 Mtetra
.647 .721 .902 r
.28515 .39714 .28637 .39859 .28837 .39649 .28705 .39647 Mtetra
.48 .894 .914 r
.28705 .39647 .28837 .39649 .29041 .39386 .28895 .39578 Mtetra
.22 0 0 r
.28895 .39578 .29041 .39386 .29246 .39116 .29085 .39516 Mtetra
.428 .07 .253 r
.29085 .39516 .29246 .39116 .29433 .39088 .29272 .39495 Mtetra
.372 .019 .231 r
.29272 .39495 .29433 .39088 .29621 .39042 .29462 .39432 Mtetra
.177 0 .134 r
.29462 .39432 .29621 .39042 .29822 .38825 .2966 .3926 Mtetra
.742 .782 .289 r
.2966 .3926 .29822 .38825 .31457 .18119 .29894 .3858 Mtetra
0 0 .131 r
.29894 .3858 .31457 .18119 .31693 .17226 .31559 .17404 Mtetra
.967 .906 .548 r
.31559 .17404 .31693 .17226 .31889 .16898 .31771 .16847 Mtetra
.804 .912 .913 r
.31771 .16847 .31889 .16898 .32069 .16805 .31954 .16711 Mtetra
.655 .804 .955 r
.31954 .16711 .32069 .16805 .32246 .16764 .32132 .16645 Mtetra
.568 .725 .948 r
.32132 .16645 .32246 .16764 .32421 .16743 .32308 .16611 Mtetra
.655 .731 .905 r
.32308 .16611 .32421 .16743 .32599 .16681 .32486 .16546 Mtetra
.648 .722 .902 r
.32486 .16546 .32599 .16681 .32777 .16615 .32665 .16483 Mtetra
.65 .73 .907 r
.32665 .16483 .32777 .16615 .32957 .1654 .32843 .16419 Mtetra
.674 .759 .915 r
.32843 .16419 .32957 .1654 .33138 .16437 .33023 .16346 Mtetra
.676 .818 .951 r
.33023 .16346 .33138 .16437 .33318 .16347 .33202 .16271 Mtetra
.677 .851 .966 r
.33202 .16271 .33318 .16347 .33497 .16287 .33382 .16195 Mtetra
.759 .831 .908 r
.33382 .16195 .33497 .16287 .33671 .16298 .33564 .16081 Mtetra
.646 .614 .803 r
.33564 .16081 .33671 .16298 .3384 .16386 .33744 .16007 Mtetra
.507 .427 .7 r
.33744 .16007 .3384 .16386 .33999 .16665 .33919 .16014 Mtetra
0 0 .462 r
.33919 .16014 .33999 .16665 .32904 .37398 .34064 .16496 Mtetra
0 0 .175 r
.34064 .16496 .32904 .37398 .33051 .38077 .32953 .37577 Mtetra
0 0 .393 r
.32953 .37577 .33051 .38077 .33227 .38293 .33111 .38073 Mtetra
.463 .534 .844 r
.33111 .38073 .33227 .38293 .33416 .38287 .33299 .38088 Mtetra
.632 .643 .844 r
.33299 .38088 .33416 .38287 .3361 .38213 .33492 .38024 Mtetra
.697 .681 .831 r
.33492 .38024 .3361 .38213 .33807 .38085 .33688 .37918 Mtetra
.537 .643 .902 r
.33688 .37918 .33807 .38085 .34005 .37928 .33879 .37897 Mtetra
.534 .894 .974 r
.33879 .37897 .34005 .37928 .34208 .37694 .34073 .37833 Mtetra
0 0 0 r
.34073 .37833 .34208 .37694 .34421 .37296 .34271 .37689 Mtetra
.698 .764 .271 r
.34271 .37689 .34421 .37296 .35773 .16522 .34495 .37077 Mtetra
0 0 .162 r
.34495 .37077 .35773 .16522 .36003 .15577 .3587 .15837 Mtetra
.925 .875 .45 r
.3587 .15837 .36003 .15577 .36199 .15236 .36083 .15187 Mtetra
.826 .919 .899 r
.36083 .15187 .36199 .15236 .36382 .15134 .36269 .15036 Mtetra
.668 .804 .948 r
.36269 .15036 .36382 .15134 .36561 .1509 .3645 .14964 Mtetra
.565 .711 .94 r
.3645 .14964 .36561 .1509 .3674 .15076 .3663 .14931 Mtetra
.653 .712 .891 r
.3663 .14931 .3674 .15076 .36921 .15016 .36811 .14865 Mtetra
.649 .7 .883 r
.36811 .14865 .36921 .15016 .37102 .14949 .36992 .14799 Mtetra
.647 .701 .886 r
.36992 .14799 .37102 .14949 .37284 .14879 .37174 .14735 Mtetra
.74 .741 .852 r
.37174 .14735 .37284 .14879 .37468 .14772 .37358 .14617 Mtetra
.687 .709 .865 r
.37358 .14617 .37468 .14772 .3765 .14686 .37541 .14531 Mtetra
.527 .64 .905 r
.37541 .14531 .3765 .14686 .37831 .14651 .37721 .14515 Mtetra
.857 .432 0 r
.37721 .14515 .37831 .14651 .38 .1484 .37879 .14919 Mtetra
.966 .681 .438 r
.37879 .14919 .38 .1484 .38143 .15605 .37031 .36076 Mtetra
.511 .268 .483 r
.37031 .36076 .38143 .15605 .37342 .36225 .37196 .36652 Mtetra
.493 .136 .288 r
.37196 .36652 .37342 .36225 .37522 .36497 .37387 .36688 Mtetra
.208 0 0 r
.37387 .36688 .37522 .36497 .3771 .36592 .37584 .3662 Mtetra
.566 .936 .831 r
.37584 .3662 .3771 .36592 .37902 .36614 .37782 .36504 Mtetra
.551 .756 .972 r
.37782 .36504 .37902 .36614 .38094 .36638 .37977 .36467 Mtetra
.633 .682 .879 r
.37977 .36467 .38094 .36638 .3829 .36603 .38174 .36404 Mtetra
.732 .687 .807 r
.38174 .36404 .3829 .36603 .38489 .36478 .38374 .36265 Mtetra
.903 .718 .642 r
.38374 .36265 .38489 .36478 .38706 .35939 .38592 .35701 Mtetra
.969 .688 .445 r
.38592 .35701 .38706 .35939 .39814 .14538 .39704 .14401 Mtetra
.944 .747 .605 r
.39704 .14401 .39814 .14538 .40026 .13795 .39915 .13707 Mtetra
.839 .852 .854 r
.39915 .13707 .40026 .13795 .40214 .13628 .40103 .13534 Mtetra
.657 .814 .959 r
.40103 .13534 .40214 .13628 .40397 .13572 .40287 .13465 Mtetra
.532 .739 .97 r
.40287 .13465 .40397 .13572 .40579 .13561 .40469 .13437 Mtetra
.731 .774 .887 r
.40469 .13437 .40579 .13561 .40763 .13475 .40654 .13331 Mtetra
.698 .733 .878 r
.40654 .13331 .40763 .13475 .40948 .13391 .4084 .1324 Mtetra
.55 .662 .911 r
.4084 .1324 .40948 .13391 .41131 .13351 .41022 .13215 Mtetra
.77 .322 0 r
.41022 .13215 .41131 .13351 .41307 .13504 .41192 .1354 Mtetra
.969 .68 .426 r
.41192 .1354 .41307 .13504 .41468 .1409 .4058 .34675 Mtetra
.514 .27 .483 r
.4058 .34675 .41468 .1409 .40889 .34904 .40749 .35379 Mtetra
.522 .172 .314 r
.40749 .35379 .40889 .34904 .41072 .35263 .40943 .35448 Mtetra
.217 0 0 r
.40943 .35448 .41072 .35263 .41264 .35383 .41142 .35384 Mtetra
.637 .962 .905 r
.41142 .35384 .41264 .35383 .41459 .35414 .41342 .3527 Mtetra
.573 .703 .93 r
.41342 .3527 .41459 .35414 .41656 .35397 .4154 .35231 Mtetra
.602 .68 .896 r
.4154 .35231 .41656 .35397 .41856 .35328 .41739 .35182 Mtetra
.737 .759 .871 r
.41739 .35182 .41856 .35328 .42057 .35194 .4194 .35061 Mtetra
.931 .776 .666 r
.4194 .35061 .42057 .35194 .42266 .3485 .42153 .34573 Mtetra
.971 .687 .434 r
.42153 .34573 .42266 .3485 .4249 .34008 .43033 .13263 Mtetra
.52 .281 .492 r
.43033 .13263 .4249 .34008 .43334 .13118 .43243 .12439 Mtetra
.634 .446 .611 r
.43243 .12439 .43334 .13118 .43527 .12845 .43433 .12236 Mtetra
.568 .409 .626 r
.43433 .12236 .43527 .12845 .43712 .1279 .43619 .12163 Mtetra
.535 .383 .622 r
.43619 .12163 .43712 .1279 .43898 .12761 .43804 .12136 Mtetra
.556 .398 .623 r
.43804 .12136 .43898 .12761 .44089 .1252 .4399 .1208 Mtetra
.588 .46 .673 r
.4399 .1208 .44089 .1252 .44281 .12258 .44177 .12008 Mtetra
.63 .58 .779 r
.44177 .12008 .44281 .12258 .44472 .12051 .44363 .11935 Mtetra
.662 .774 .932 r
.44363 .11935 .44472 .12051 .4466 .11933 .4455 .11864 Mtetra
.641 .865 .983 r
.4455 .11864 .4466 .11933 .44847 .1186 .44737 .11793 Mtetra
.638 .871 .985 r
.44737 .11793 .44847 .1186 .45033 .11801 .44924 .11723 Mtetra
.651 .849 .976 r
.44924 .11723 .45033 .11801 .4522 .11735 .45111 .11651 Mtetra
.656 .839 .971 r
.45111 .11651 .4522 .11735 .45407 .11664 .45299 .11579 Mtetra
.656 .838 .97 r
.45299 .11579 .45407 .11664 .45595 .11592 .45486 .11507 Mtetra
.656 .836 .969 r
.45486 .11507 .45595 .11592 .45782 .11521 .45674 .11435 Mtetra
.656 .835 .969 r
.45674 .11435 .45782 .11521 .4597 .1145 .45862 .11363 Mtetra
.655 .834 .969 r
.45862 .11363 .4597 .1145 .46158 .11379 .4605 .11291 Mtetra
.653 .832 .969 r
.4605 .11291 .46158 .11379 .46346 .11307 .46238 .1122 Mtetra
.651 .833 .97 r
.46238 .1122 .46346 .11307 .46534 .11237 .46426 .1115 Mtetra
.65 .832 .97 r
.46426 .1115 .46534 .11237 .46722 .11169 .46614 .1108 Mtetra
.649 .827 .969 r
.46614 .1108 .46722 .11169 .4691 .1111 .46802 .11011 Mtetra
.652 .807 .958 r
.46802 .11011 .4691 .1111 .47098 .11056 .46991 .10942 Mtetra
.655 .778 .939 r
.46991 .10942 .47098 .11056 .47286 .11002 .47179 .10873 Mtetra
.655 .749 .919 r
.47179 .10873 .47286 .11002 .47475 .10941 .47368 .10803 Mtetra
.655 .734 .908 r
.47368 .10803 .47475 .10941 .47663 .10873 .47557 .10734 Mtetra
.656 .731 .905 r
.47557 .10734 .47663 .10873 .47852 .10803 .47746 .10664 Mtetra
.657 .732 .905 r
.47746 .10664 .47852 .10803 .48042 .10733 .47935 .10594 Mtetra
.658 .732 .905 r
.47935 .10594 .48042 .10733 .48231 .10663 .48125 .10523 Mtetra
.658 .732 .904 r
.48125 .10523 .48231 .10663 .4842 .10592 .48314 .10451 Mtetra
.659 .731 .903 r
.48314 .10451 .4842 .10592 .4861 .1052 .48504 .1038 Mtetra
.66 .731 .902 r
.48504 .1038 .4861 .1052 .48799 .10449 .48694 .10307 Mtetra
.66 .73 .901 r
.48694 .10307 .48799 .10449 .48989 .10376 .48883 .10235 Mtetra
.661 .73 .901 r
.48883 .10235 .48989 .10376 .49179 .10304 .49073 .10162 Mtetra
.49073 .10162 .49179 .10304 .49369 .10231 .49264 .10089 Mtetra
.661 .73 .9 r
.49264 .10089 .49369 .10231 .49559 .10158 .49454 .10016 Mtetra
.49454 .10016 .49559 .10158 .4975 .10085 .49644 .09943 Mtetra
.662 .73 .9 r
.49644 .09943 .4975 .10085 .4994 .10012 .49835 .09869 Mtetra
.49835 .09869 .4994 .10012 .50131 .09938 .50026 .09796 Mtetra
.50026 .09796 .50131 .09938 .50322 .09865 .50216 .09722 Mtetra
.50216 .09722 .50322 .09865 .50512 .09791 .50407 .09648 Mtetra
.50407 .09648 .50512 .09791 .50703 .09718 .50598 .09574 Mtetra
.50598 .09574 .50703 .09718 .50895 .09644 .5079 .09501 Mtetra
.5079 .09501 .50895 .09644 .51086 .0957 .50981 .09427 Mtetra
.50981 .09427 .51086 .0957 .51277 .09496 .51173 .09352 Mtetra
.51173 .09352 .51277 .09496 .51469 .09422 .51364 .09278 Mtetra
.51364 .09278 .51469 .09422 .51661 .09348 .51556 .09204 Mtetra
.51556 .09204 .51661 .09348 .51852 .09274 .51748 .0913 Mtetra
.51748 .0913 .51852 .09274 .52044 .09199 .5194 .09056 Mtetra
.5194 .09056 .52044 .09199 .52236 .09125 .52132 .08981 Mtetra
.52132 .08981 .52236 .09125 .52429 .09051 .52324 .08907 Mtetra
.52324 .08907 .52429 .09051 .52621 .08976 .52517 .08832 Mtetra
.52517 .08832 .52621 .08976 .52813 .08902 .52709 .08758 Mtetra
.52709 .08758 .52813 .08902 .53006 .08827 .52902 .08683 Mtetra
.52902 .08683 .53006 .08827 .53199 .08753 .53095 .08608 Mtetra
.53095 .08608 .53199 .08753 .53392 .08678 .53288 .08534 Mtetra
.53288 .08534 .53392 .08678 .53585 .08604 .53481 .08459 Mtetra
.53481 .08459 .53585 .08604 .53778 .08529 .53674 .08384 Mtetra
.53674 .08384 .53778 .08529 .53971 .08454 .53868 .08309 Mtetra
.53868 .08309 .53971 .08454 .54165 .08379 .54061 .08234 Mtetra
.54061 .08234 .54165 .08379 .54358 .08304 .54255 .08159 Mtetra
.54255 .08159 .54358 .08304 .54552 .08229 .54449 .08084 Mtetra
.662 .73 .899 r
.54449 .08084 .54552 .08229 .54746 .08154 .54642 .08009 Mtetra
.54642 .08009 .54746 .08154 .5494 .08079 .54837 .07934 Mtetra
.54837 .07934 .5494 .08079 .55134 .08004 .55031 .07859 Mtetra
.663 .73 .899 r
.55031 .07859 .55134 .08004 .55328 .07929 .55225 .07783 Mtetra
.55225 .07783 .55328 .07929 .55522 .07853 .5542 .07708 Mtetra
.5542 .07708 .55522 .07853 .55717 .07778 .55614 .07632 Mtetra
.55614 .07632 .55717 .07778 .55912 .07702 .55809 .07556 Mtetra
.55809 .07556 .55912 .07702 .56106 .07626 .56004 .07481 Mtetra
.663 .73 .9 r
.56004 .07481 .56106 .07626 .56301 .0755 .56199 .07405 Mtetra
.664 .731 .9 r
.56199 .07405 .56301 .0755 .56496 .07474 .56394 .07329 Mtetra
.56394 .07329 .56496 .07474 .56692 .07398 .56589 .07252 Mtetra
.56589 .07252 .56692 .07398 .56887 .07321 .56785 .07176 Mtetra
.665 .732 .9 r
.56785 .07176 .56887 .07321 .57082 .07244 .5698 .07099 Mtetra
.665 .733 .9 r
.5698 .07099 .57082 .07244 .57278 .07167 .57176 .07021 Mtetra
.666 .734 .9 r
.57176 .07021 .57278 .07167 .57474 .07089 .57372 .06944 Mtetra
.667 .735 .9 r
.57372 .06944 .57474 .07089 .5767 .0701 .57568 .06866 Mtetra
.668 .736 .901 r
.57568 .06866 .5767 .0701 .57866 .06931 .57764 .06787 Mtetra
.669 .737 .901 r
.57764 .06787 .57866 .06931 .58062 .06853 .5796 .06708 Mtetra
.669 .736 .9 r
.5796 .06708 .58062 .06853 .58258 .06772 .58156 .06629 Mtetra
.67 .739 .902 r
.58156 .06629 .58258 .06772 .58454 .06685 .58353 .06549 Mtetra
.672 .753 .912 r
.58353 .06549 .58454 .06685 .5865 .0659 .58549 .06469 Mtetra
.673 .782 .932 r
.58549 .06469 .5865 .0659 .58846 .06495 .58746 .0639 Mtetra
.67 .811 .951 r
.58746 .0639 .58846 .06495 .59043 .06406 .58943 .0631 Mtetra
.665 .831 .963 r
.58943 .0631 .59043 .06406 .5924 .06326 .5914 .06232 Mtetra
.662 .835 .966 r
.5914 .06232 .5924 .06326 .59437 .06248 .59337 .06154 Mtetra
.66 .833 .966 r
.59337 .06154 .59437 .06248 .59634 .06172 .59534 .06077 Mtetra
.658 .831 .967 r
.59534 .06077 .59634 .06172 .59832 .06095 .59732 .06002 Mtetra
.655 .833 .968 r
.59732 .06002 .59832 .06095 .60029 .06021 .5993 .05926 Mtetra
.654 .83 .968 r
.5993 .05926 .60029 .06021 .60227 .05953 .60127 .05852 Mtetra
.655 .817 .962 r
.60127 .05852 .60227 .05953 .60425 .05893 .60325 .05778 Mtetra
.658 .789 .944 r
.60325 .05778 .60425 .05893 .60624 .05834 .60524 .05704 Mtetra
.659 .759 .924 r
.60524 .05704 .60624 .05834 .60822 .05772 .60722 .05629 Mtetra
.659 .737 .908 r
.60722 .05629 .60822 .05772 .61021 .05701 .6092 .05554 Mtetra
.66 .732 .903 r
.6092 .05554 .61021 .05701 .61219 .05626 .61119 .05479 Mtetra
.662 .732 .902 r
.61119 .05479 .61219 .05626 .61418 .05549 .61317 .05402 Mtetra
.665 .734 .901 r
.61317 .05402 .61418 .05549 .61616 .05472 .61516 .05324 Mtetra
.667 .733 .899 r
.61516 .05324 .61616 .05472 .61815 .05394 .61715 .05245 Mtetra
.67 .733 .897 r
.61715 .05245 .61815 .05394 .62014 .05315 .61914 .05164 Mtetra
.675 .732 .893 r
.61914 .05164 .62014 .05315 .62213 .05235 .62113 .05081 Mtetra
.671 .724 .889 r
.62113 .05081 .62213 .05235 .62412 .05153 .62312 .04998 Mtetra
.663 .72 .892 r
.62312 .04998 .62412 .05153 .62611 .05065 .62511 .0492 Mtetra
.645 .73 .911 r
.62511 .0492 .62611 .05065 .6281 .04967 .62711 .04851 Mtetra
.641 .784 .95 r
.62711 .04851 .6281 .04967 .63009 .04869 .62911 .04784 Mtetra
.634 .846 .981 r
.62911 .04784 .63009 .04869 .63208 .04775 .63112 .04713 Mtetra
.64 .896 .985 r
.63112 .04713 .63208 .04775 .63407 .04691 .63311 .04632 Mtetra
.642 .903 .983 r
.63311 .04632 .63407 .04691 .63607 .0461 .63511 .04548 Mtetra
.646 .9 .983 r
.63511 .04548 .63607 .0461 .63807 .04531 .63712 .04465 Mtetra
.64 .89 .985 r
.63712 .04465 .63807 .04531 .64008 .04452 .63912 .04385 Mtetra
.638 .888 .986 r
.63912 .04385 .64008 .04452 .64208 .04373 .64112 .04306 Mtetra
.635 .887 .986 r
.64112 .04306 .64208 .04373 .64409 .04295 .64313 .04228 Mtetra
.633 .886 .987 r
.64313 .04228 .64409 .04295 .64609 .04217 .64514 .0415 Mtetra
.631 .885 .987 r
.64514 .0415 .64609 .04217 .6481 .0414 .64715 .04073 Mtetra
.629 .885 .988 r
.64715 .04073 .6481 .0414 .65011 .04063 .64916 .03997 Mtetra
.628 .886 .988 r
.64916 .03997 .65011 .04063 .65213 .03986 .65118 .0392 Mtetra
.627 .886 .988 r
.65118 .0392 .65213 .03986 .65414 .0391 .65319 .03844 Mtetra
.626 .886 .988 r
.65319 .03844 .65414 .0391 .65616 .03834 .65521 .03767 Mtetra
.625 .886 .988 r
.65521 .03767 .65616 .03834 .65817 .03758 .65723 .03691 Mtetra
.624 .886 .988 r
.65723 .03691 .65817 .03758 .66019 .03682 .65925 .03615 Mtetra
.625 .886 .988 r
.65925 .03615 .66019 .03682 .66221 .03606 .66127 .03539 Mtetra
.625 .885 .988 r
.66127 .03539 .66221 .03606 .66423 .03531 .66329 .03463 Mtetra
.627 .884 .988 r
.66329 .03463 .66423 .03531 .66626 .03456 .66532 .03387 Mtetra
.629 .883 .988 r
.66532 .03387 .66626 .03456 .66828 .0338 .66734 .0331 Mtetra
.632 .882 .987 r
.66734 .0331 .66828 .0338 .67031 .03303 .66937 .03233 Mtetra
.635 .882 .986 r
.66937 .03233 .67031 .03303 .67233 .03226 .6714 .03154 Mtetra
.639 .882 .986 r
.6714 .03154 .67233 .03226 .67436 .03147 .67343 .03075 Mtetra
.644 .883 .985 r
.67343 .03075 .67436 .03147 .67639 .03068 .67546 .02995 Mtetra
.648 .883 .983 r
.67546 .02995 .67639 .03068 .67842 .02986 .67749 .02913 Mtetra
.653 .884 .982 r
.67749 .02913 .67842 .02986 .68045 .02903 .67952 .0283 Mtetra
.662 .887 .98 r
.67952 .0283 .68045 .02903 .68248 .02818 .68155 .02743 Mtetra
.665 .887 .979 r
.68155 .02743 .68248 .02818 .68451 .02731 .68358 .02656 Mtetra
.67 .888 .977 r
.68358 .02656 .68451 .02731 .68654 .02643 .68562 .02567 Mtetra
.776 .916 .933 r
.68562 .02567 .68654 .02643 .68855 .02512 .68762 .02434 Mtetra
.687 .888 .972 r
.68762 .02434 .68855 .02512 .69058 .02419 .68966 .0234 Mtetra
.422 .765 .996 r
.68966 .0234 .69058 .02419 .69265 .02397 .69173 .02321 Mtetra
.774 .305 0 r
.69173 .02321 .69265 .02397 .69497 .02774 .69407 .02732 Mtetra
.97 .655 .294 r
.69407 .02732 .69497 .02774 .71009 .24344 .7091 .24265 Mtetra
.838 .397 0 r
.7091 .24265 .71009 .24344 .71276 .25011 .71172 .24856 Mtetra
.487 .699 .963 r
.01227 .48916 .0136 .4903 .01519 .49048 .0139 .48903 Mtetra
.661 .706 .881 r
.0139 .48903 .01519 .49048 .01691 .48981 .01562 .48836 Mtetra
.704 .716 .858 r
.01562 .48836 .01691 .48981 .0187 .4887 .01738 .48743 Mtetra
.433 .651 .951 r
.01738 .48743 .0187 .4887 .02033 .4886 .019 .48746 Mtetra
.543 .722 .956 r
.019 .48746 .02033 .4886 .02203 .48809 .02066 .4872 Mtetra
.706 .81 .93 r
.02066 .4872 .02203 .48809 .02385 .48678 .02241 .48635 Mtetra
.912 .822 .745 r
.02241 .48635 .02385 .48678 .02643 .48046 .02454 .48303 Mtetra
.994 .862 .594 r
.02454 .48303 .02643 .48046 .05922 .27327 .02742 .47473 Mtetra
0 0 0 r
.02742 .47473 .05922 .27327 .0616 .26751 .05961 .27146 Mtetra
.05961 .27146 .0616 .26751 .06333 .26611 .06173 .26743 Mtetra
.788 .973 .682 r
.06173 .26743 .06333 .26611 .06495 .26548 .06359 .26519 Mtetra
.838 .906 .884 r
.06359 .26519 .06495 .26548 .06651 .26522 .06534 .26368 Mtetra
.693 .687 .84 r
.06534 .26368 .06651 .26522 .06812 .26466 .06699 .26283 Mtetra
.633 .629 .828 r
.06699 .26283 .06812 .26466 .06973 .26409 .0686 .26227 Mtetra
.601 .617 .839 r
.0686 .26227 .06973 .26409 .07134 .26352 .07019 .26186 Mtetra
.618 .647 .856 r
.07019 .26186 .07134 .26352 .07296 .26287 .07179 .2614 Mtetra
.625 .675 .878 r
.07179 .2614 .07296 .26287 .07459 .26222 .07339 .26091 Mtetra
.638 .708 .897 r
.07339 .26091 .07459 .26222 .07622 .26157 .075 .26038 Mtetra
.74 .752 .862 r
.075 .26038 .07622 .26157 .0779 .26055 .07668 .25933 Mtetra
.716 .744 .874 r
.07668 .25933 .0779 .26055 .07954 .2598 .07835 .25843 Mtetra
.618 .69 .895 r
.07835 .25843 .07954 .2598 .08109 .25971 .07995 .25797 Mtetra
0 .062 .618 r
.07995 .25797 .08109 .25971 .08212 .2632 .08128 .2594 Mtetra
.785 .513 0 r
.08128 .2594 .08212 .2632 .0542 .46926 .08214 .26413 Mtetra
0 0 0 r
.08214 .26413 .0542 .46926 .05491 .47582 .05455 .46791 Mtetra
.018 0 .459 r
.05455 .46791 .05491 .47582 .05646 .4765 .05559 .47218 Mtetra
.246 .231 .643 r
.05559 .47218 .05646 .4765 .05818 .47605 .05703 .47369 Mtetra
.343 .434 .811 r
.05703 .47369 .05818 .47605 .05996 .47513 .0586 .47424 Mtetra
.338 .688 .98 r
.0586 .47424 .05996 .47513 .06165 .47486 .06025 .47429 Mtetra
.564 .849 .997 r
.06025 .47429 .06165 .47486 .06338 .47435 .06197 .47381 Mtetra
.76 .885 .935 r
.06197 .47381 .06338 .47435 .0652 .47314 .06379 .4727 Mtetra
.911 .834 .757 r
.06379 .4727 .0652 .47314 .06755 .46823 .06588 .46959 Mtetra
.985 .851 .627 r
.06588 .46959 .06755 .46823 .09794 .26073 .06849 .46272 Mtetra
0 0 0 r
.06849 .46272 .09794 .26073 .10056 .25301 .09845 .25825 Mtetra
.036 0 .118 r
.09845 .25825 .10056 .25301 .10235 .25123 .10039 .25548 Mtetra
.408 .065 .269 r
.10039 .25548 .10235 .25123 .10399 .25061 .102 .25508 Mtetra
.44 .101 .293 r
.102 .25508 .10399 .25061 .10557 .25041 .10359 .25489 Mtetra
0 0 0 r
.10359 .25489 .10557 .25041 .10721 .24982 .10556 .25187 Mtetra
.711 .896 .521 r
.10556 .25187 .10721 .24982 .10887 .2491 .1075 .24907 Mtetra
.894 .926 .833 r
.1075 .24907 .10887 .2491 .11052 .24839 .10933 .24702 Mtetra
.715 .721 .854 r
.10933 .24702 .11052 .24839 .11216 .24776 .11102 .24606 Mtetra
.618 .643 .853 r
.11102 .24606 .11216 .24776 .11381 .24717 .11265 .24559 Mtetra
.576 .643 .88 r
.11265 .24559 .11381 .24717 .11545 .24658 .11425 .24529 Mtetra
.624 .709 .906 r
.11425 .24529 .11545 .24658 .11709 .24596 .11588 .2448 Mtetra
.653 .744 .916 r
.11588 .2448 .11709 .24596 .11875 .24532 .11753 .24421 Mtetra
.666 .756 .917 r
.11753 .24421 .11875 .24532 .1204 .24469 .11918 .24356 Mtetra
.686 .758 .906 r
.11918 .24356 .1204 .24469 .12204 .2441 .12084 .24283 Mtetra
.689 .732 .883 r
.12084 .24283 .12204 .2441 .12368 .24355 .12252 .24205 Mtetra
.678 .695 .858 r
.12252 .24205 .12368 .24355 .12533 .243 .12419 .2413 Mtetra
.655 .658 .841 r
.12419 .2413 .12533 .243 .12697 .24243 .12585 .24063 Mtetra
.639 .638 .833 r
.12585 .24063 .12697 .24243 .12862 .24186 .1275 .24003 Mtetra
.629 .632 .834 r
.1275 .24003 .12862 .24186 .13027 .24126 .12914 .23948 Mtetra
.612 .63 .845 r
.12914 .23948 .13027 .24126 .13193 .24063 .13078 .23902 Mtetra
.604 .652 .87 r
.13078 .23902 .13193 .24063 .13359 .23997 .13241 .23861 Mtetra
.609 .694 .903 r
.13241 .23861 .13359 .23997 .13526 .2393 .13404 .23818 Mtetra
.645 .75 .925 r
.13404 .23818 .13526 .2393 .13692 .23864 .1357 .23761 Mtetra
.672 .774 .927 r
.1357 .23761 .13692 .23864 .13859 .23799 .13737 .23694 Mtetra
.683 .773 .919 r
.13737 .23694 .13859 .23799 .14025 .23732 .13904 .23622 Mtetra
.753 .775 .87 r
.13904 .23622 .14025 .23732 .14197 .23624 .14077 .2351 Mtetra
.735 .766 .877 r
.14077 .2351 .14197 .23624 .14368 .23525 .14248 .23408 Mtetra
.593 .725 .936 r
.14248 .23408 .14368 .23525 .14532 .23487 .14411 .2337 Mtetra
.829 .367 0 r
.14411 .2337 .14532 .23487 .14659 .23741 .14539 .23624 Mtetra
.948 .684 .504 r
.14539 .23624 .14659 .23741 .12282 .44347 .12151 .44243 Mtetra
.944 .611 .367 r
.12151 .44243 .12282 .44347 .12349 .4518 .12219 .45069 Mtetra
.556 .031 0 r
.12219 .45069 .12349 .4518 .12502 .4533 .12371 .45221 Mtetra
.543 .738 .966 r
.12371 .45221 .12502 .4533 .12677 .453 .12546 .45191 Mtetra
.786 .795 .86 r
.12546 .45191 .12677 .453 .12865 .45161 .12734 .45048 Mtetra
.907 .758 .684 r
.12734 .45048 .12865 .45161 .13085 .44749 .12962 .44585 Mtetra
.947 .688 .512 r
.12962 .44585 .13085 .44749 .15733 .24103 .15662 .23584 Mtetra
.825 .602 .601 r
.15662 .23584 .15733 .24103 .16023 .23021 .15917 .22789 Mtetra
.771 .648 .725 r
.15917 .22789 .16023 .23021 .16213 .22775 .16103 .22578 Mtetra
.615 .61 .823 r
.16103 .22578 .16213 .22775 .16382 .22695 .16269 .22528 Mtetra
.483 .588 .883 r
.16269 .22528 .16382 .22695 .16546 .22663 .16429 .22529 Mtetra
.64 .709 .897 r
.16429 .22529 .16546 .22663 .16716 .2259 .16596 .22473 Mtetra
.716 .761 .888 r
.16596 .22473 .16716 .2259 .16887 .22498 .16767 .22382 Mtetra
.593 .729 .939 r
.16767 .22382 .16887 .22498 .17052 .22459 .16933 .22343 Mtetra
.729 .238 0 r
.16933 .22343 .17052 .22459 .17191 .22648 .1707 .22548 Mtetra
.95 .684 .498 r
.1707 .22548 .17191 .22648 .15059 .4255 .1487 .42958 Mtetra
.853 .543 .462 r
.1487 .42958 .15059 .4255 .15047 .44154 .14911 .44103 Mtetra
.651 .094 0 r
.14911 .44103 .15047 .44154 .15201 .44319 .15067 .44249 Mtetra
.649 .851 .977 r
.15067 .44249 .15201 .44319 .15381 .44264 .15248 .4418 Mtetra
.783 .84 .895 r
.15248 .4418 .15381 .44264 .15567 .44146 .15436 .44048 Mtetra
.752 .815 .902 r
.15436 .44048 .15567 .44146 .15752 .44042 .15623 .43935 Mtetra
.671 .784 .934 r
.15623 .43935 .15752 .44042 .15934 .43971 .15805 .43862 Mtetra
.659 .777 .936 r
.15805 .43862 .15934 .43971 .16115 .43902 .15986 .43793 Mtetra
.579 .754 .961 r
.15986 .43793 .16115 .43902 .16293 .43873 .16165 .43753 Mtetra
.562 .727 .952 r
.16165 .43753 .16293 .43873 .16469 .43851 .16342 .4372 Mtetra
.675 .743 .902 r
.16342 .4372 .16469 .43851 .16653 .43766 .16525 .43644 Mtetra
.849 .774 .779 r
.16525 .43644 .16653 .43766 .16865 .4342 .16726 .43404 Mtetra
.958 .8 .644 r
.16726 .43404 .16865 .4342 .19275 .22882 .16969 .42777 Mtetra
0 0 .039 r
.16969 .42777 .19275 .22882 .19568 .21685 .19377 .2224 Mtetra
0 0 0 r
.19377 .2224 .19568 .21685 .19761 .21411 .19591 .21765 Mtetra
.308 0 .185 r
.19591 .21765 .19761 .21411 .19933 .2133 .19764 .2168 Mtetra
.451 .086 .254 r
.19764 .2168 .19933 .2133 .20099 .21301 .19928 .21681 Mtetra
.45 .094 .269 r
.19928 .21681 .20099 .21301 .20266 .21267 .20092 .21677 Mtetra
.388 .042 .252 r
.20092 .21677 .20266 .21267 .20436 .21208 .20261 .21624 Mtetra
.388 .044 .255 r
.20261 .21624 .20436 .21208 .20606 .21148 .20431 .21571 Mtetra
.386 .044 .257 r
.20431 .21571 .20606 .21148 .20777 .21087 .20601 .21515 Mtetra
.384 .043 .258 r
.20601 .21515 .20777 .21087 .20947 .21025 .20772 .21456 Mtetra
.384 .043 .259 r
.20772 .21456 .20947 .21025 .21118 .20961 .20943 .21396 Mtetra
.385 .045 .261 r
.20943 .21396 .21118 .20961 .21289 .20897 .21113 .21336 Mtetra
.387 .048 .264 r
.21113 .21336 .21289 .20897 .2146 .20832 .21284 .21277 Mtetra
.388 .05 .266 r
.21284 .21277 .2146 .20832 .21631 .20768 .21455 .21217 Mtetra
.428 .088 .286 r
.21455 .21217 .21631 .20768 .21803 .20705 .21624 .21187 Mtetra
.459 .124 .311 r
.21624 .21187 .21803 .20705 .21974 .20643 .2179 .2118 Mtetra
.38 .061 .293 r
.2179 .2118 .21974 .20643 .22145 .20578 .21964 .21096 Mtetra
.084 0 .154 r
.21964 .21096 .22145 .20578 .22318 .20508 .22157 .20824 Mtetra
0 0 0 r
.22157 .20824 .22318 .20508 .22491 .20429 .22355 .20493 Mtetra
.897 .988 .76 r
.22355 .20493 .22491 .20429 .22664 .2035 .22545 .20248 Mtetra
.809 .801 .845 r
.22545 .20248 .22664 .2035 .22837 .20277 .22726 .20093 Mtetra
.665 .652 .827 r
.22726 .20093 .22837 .20277 .23009 .20211 .22899 .20016 Mtetra
.625 .621 .827 r
.22899 .20016 .23009 .20211 .23181 .20146 .23071 .1996 Mtetra
.625 .632 .837 r
.23071 .1996 .23181 .20146 .23354 .20081 .23242 .19905 Mtetra
.651 .656 .842 r
.23242 .19905 .23354 .20081 .23527 .20013 .23415 .19838 Mtetra
.23415 .19838 .23527 .20013 .23699 .19945 .23588 .1977 Mtetra
.651 .658 .843 r
.23588 .1977 .23699 .19945 .23872 .19876 .23761 .19703 Mtetra
.652 .659 .844 r
.23761 .19703 .23872 .19876 .24046 .19808 .23934 .19635 Mtetra
.652 .66 .845 r
.23934 .19635 .24046 .19808 .24219 .1974 .24107 .19567 Mtetra
.651 .661 .846 r
.24107 .19567 .24219 .1974 .24392 .19672 .2428 .195 Mtetra
.651 .661 .847 r
.2428 .195 .24392 .19672 .24565 .19605 .24454 .19433 Mtetra
.65 .662 .848 r
.24454 .19433 .24565 .19605 .24739 .19538 .24627 .19366 Mtetra
.24627 .19366 .24739 .19538 .24912 .19471 .24801 .19299 Mtetra
.651 .662 .848 r
.24801 .19299 .24912 .19471 .25086 .19405 .24974 .19233 Mtetra
.646 .659 .848 r
.24974 .19233 .25086 .19405 .2526 .1934 .25148 .19168 Mtetra
.636 .657 .853 r
.25148 .19168 .2526 .1934 .25433 .19274 .25321 .19109 Mtetra
.62 .659 .866 r
.25321 .19109 .25433 .19274 .25607 .19209 .25494 .19058 Mtetra
.621 .681 .886 r
.25494 .19058 .25607 .19209 .25781 .19144 .25667 .19008 Mtetra
.632 .711 .903 r
.25667 .19008 .25781 .19144 .25955 .19077 .2584 .18953 Mtetra
.655 .741 .913 r
.2584 .18953 .25955 .19077 .2613 .19007 .26014 .18889 Mtetra
.67 .756 .915 r
.26014 .18889 .2613 .19007 .26305 .18937 .26189 .18819 Mtetra
.686 .761 .908 r
.26189 .18819 .26305 .18937 .26479 .18869 .26364 .18742 Mtetra
.701 .748 .888 r
.26364 .18742 .26479 .18869 .26654 .18804 .26541 .18655 Mtetra
.694 .712 .863 r
.26541 .18655 .26654 .18804 .26829 .18738 .26717 .18568 Mtetra
.677 .676 .841 r
.26717 .18568 .26829 .18738 .27004 .18671 .26893 .18486 Mtetra
.656 .649 .831 r
.26893 .18486 .27004 .18671 .27179 .186 .27069 .18413 Mtetra
.651 .645 .831 r
.27069 .18413 .27179 .186 .27355 .18527 .27244 .18342 Mtetra
.65 .647 .834 r
.27244 .18342 .27355 .18527 .2753 .18455 .2742 .18273 Mtetra
.654 .652 .836 r
.2742 .18273 .2753 .18455 .27706 .18383 .27596 .18202 Mtetra
.653 .653 .838 r
.27596 .18202 .27706 .18383 .27882 .18312 .27771 .18132 Mtetra
.664 .659 .834 r
.27771 .18132 .27882 .18312 .28058 .18232 .27948 .18055 Mtetra
.693 .675 .828 r
.27948 .18055 .28058 .18232 .28237 .18125 .28126 .1796 Mtetra
.649 .674 .86 r
.28126 .1796 .28237 .18125 .28413 .18061 .28302 .17895 Mtetra
.439 .574 .892 r
.28302 .17895 .28413 .18061 .28579 .18118 .28471 .17908 Mtetra
0 0 .407 r
.28471 .17908 .28579 .18118 .287 .18753 .28621 .18166 Mtetra
.944 .672 .209 r
.28621 .18166 .287 .18753 .27226 .39711 .28684 .19547 Mtetra
0 0 .153 r
.28684 .19547 .27226 .39711 .27381 .4008 .27305 .39356 Mtetra
.522 .365 .609 r
.27305 .39356 .27381 .4008 .27566 .40066 .27489 .39344 Mtetra
.578 .406 .612 r
.27489 .39344 .27566 .40066 .27757 .39981 .27681 .39241 Mtetra
.529 .368 .607 r
.27681 .39241 .27757 .39981 .27949 .39875 .27867 .39217 Mtetra
.295 .212 .589 r
.27867 .39217 .27949 .39875 .28137 .39823 .28034 .39437 Mtetra
.263 .275 .684 r
.28034 .39437 .28137 .39823 .28326 .39771 .28208 .3958 Mtetra
.255 .453 .861 r
.28208 .3958 .28326 .39771 .28515 .39714 .28387 .39647 Mtetra
.449 .796 .998 r
.28387 .39647 .28515 .39714 .28705 .39647 .28574 .3962 Mtetra
.484 .875 .967 r
.28574 .3962 .28705 .39647 .28895 .39578 .28764 .39566 Mtetra
.496 .895 .939 r
.28764 .39566 .28895 .39578 .29085 .39516 .28954 .395 Mtetra
.396 .842 .928 r
.28954 .395 .29085 .39516 .29272 .39495 .29143 .39453 Mtetra
.633 .909 .982 r
.29143 .39453 .29272 .39495 .29462 .39432 .29334 .39374 Mtetra
.807 .904 .909 r
.29334 .39374 .29462 .39432 .2966 .3926 .29531 .39226 Mtetra
.945 .866 .73 r
.29531 .39226 .2966 .3926 .29894 .3858 .29742 .38863 Mtetra
.975 .87 .487 r
.29742 .38863 .29894 .3858 .31559 .17404 .29987 .38024 Mtetra
0 0 .147 r
.29987 .38024 .31559 .17404 .31771 .16847 .3162 .17262 Mtetra
0 0 0 r
.3162 .17262 .31771 .16847 .31954 .16711 .31824 .1683 Mtetra
.728 .935 .606 r
.31824 .1683 .31954 .16711 .32132 .16645 .32014 .16592 Mtetra
.829 .904 .891 r
.32014 .16592 .32132 .16645 .32308 .16611 .32198 .16439 Mtetra
.659 .671 .85 r
.32198 .16439 .32308 .16611 .32486 .16546 .32377 .16366 Mtetra
.602 .636 .857 r
.32377 .16366 .32486 .16546 .32665 .16483 .32554 .16322 Mtetra
.578 .653 .887 r
.32554 .16322 .32665 .16483 .32843 .16419 .32731 .16288 Mtetra
.654 .732 .907 r
.32731 .16288 .32843 .16419 .33023 .16346 .3291 .16222 Mtetra
.669 .752 .913 r
.3291 .16222 .33023 .16346 .33202 .16271 .33089 .16151 Mtetra
.689 .763 .908 r
.33089 .16151 .33202 .16271 .33382 .16195 .33269 .1607 Mtetra
.758 .772 .865 r
.33269 .1607 .33382 .16195 .33564 .16081 .33452 .15947 Mtetra
.71 .746 .88 r
.33452 .15947 .33564 .16081 .33744 .16007 .33633 .15853 Mtetra
.587 .668 .895 r
.33633 .15853 .33744 .16007 .33919 .16014 .33811 .15815 Mtetra
0 .075 .636 r
.33811 .15815 .33919 .16014 .34064 .16496 .33975 .15999 Mtetra
0 0 .21 r
.33975 .15999 .34064 .16496 .32953 .37577 .34111 .16642 Mtetra
0 0 .185 r
.34111 .16642 .32953 .37577 .33111 .38073 .33027 .37338 Mtetra
.239 .161 .563 r
.33027 .37338 .33111 .38073 .33299 .38088 .33197 .3764 Mtetra
.362 .315 .671 r
.33197 .3764 .33299 .38088 .33492 .38024 .3338 .37754 Mtetra
.439 .469 .794 r
.3338 .37754 .33492 .38024 .33688 .37918 .33567 .37788 Mtetra
.402 .645 .955 r
.33567 .37788 .33688 .37918 .33879 .37897 .33756 .37797 Mtetra
.582 .786 .976 r
.33756 .37797 .33879 .37897 .34073 .37833 .33949 .37749 Mtetra
.751 .862 .93 r
.33949 .37749 .34073 .37833 .34271 .37689 .34146 .37633 Mtetra
.934 .86 .744 r
.34146 .37633 .34271 .37689 .34495 .37077 .34355 .37296 Mtetra
.977 .878 .506 r
.34355 .37296 .34495 .37077 .3587 .15837 .34588 .36547 Mtetra
0 0 .174 r
.34588 .36547 .3587 .15837 .36083 .15187 .3594 .1563 Mtetra
0 0 0 r
.3594 .1563 .36083 .15187 .36269 .15036 .36143 .15168 Mtetra
.684 .9 .546 r
.36143 .15168 .36269 .15036 .3645 .14964 .36334 .1492 Mtetra
.843 .925 .886 r
.36334 .1492 .3645 .14964 .3663 .14931 .36521 .14757 Mtetra
.673 .675 .844 r
.36521 .14757 .3663 .14931 .36811 .14865 .36703 .14674 Mtetra
.613 .629 .843 r
.36703 .14674 .36811 .14865 .36992 .14799 .36884 .14623 Mtetra
.583 .634 .868 r
.36884 .14623 .36992 .14799 .37174 .14735 .37064 .14587 Mtetra
.734 .734 .851 r
.37064 .14587 .37174 .14735 .37358 .14617 .37248 .14472 Mtetra
.689 .725 .877 r
.37248 .14472 .37358 .14617 .37541 .14531 .37431 .14387 Mtetra
.514 .654 .922 r
.37431 .14387 .37541 .14531 .37721 .14515 .3761 .14372 Mtetra
.877 .464 .031 r
.3761 .14372 .37721 .14515 .37879 .14919 .37767 .14821 Mtetra
.968 .683 .436 r
.37767 .14821 .37879 .14919 .37031 .36076 .36906 .36069 Mtetra
.893 .484 .219 r
.36906 .36069 .37031 .36076 .37196 .36652 .37073 .36592 Mtetra
.086 .593 .891 r
.37073 .36592 .37196 .36652 .37387 .36688 .37265 .3662 Mtetra
.672 .88 .976 r
.37265 .3662 .37387 .36688 .37584 .3662 .37462 .36534 Mtetra
.811 .866 .888 r
.37462 .36534 .37584 .3662 .37782 .36504 .37663 .36377 Mtetra
.806 .797 .843 r
.37663 .36377 .37782 .36504 .37977 .36467 .37864 .36205 Mtetra
.779 .654 .725 r
.37864 .36205 .37977 .36467 .38174 .36404 .38069 .35964 Mtetra
.776 .586 .642 r
.38069 .35964 .38174 .36404 .38374 .36265 .3828 .35562 Mtetra
.964 .683 .451 r
.3828 .35562 .38374 .36265 .38592 .35701 .39383 .14958 Mtetra
.525 .285 .493 r
.39383 .14958 .38592 .35701 .39704 .14401 .3961 .13912 Mtetra
.744 .549 .631 r
.3961 .13912 .39704 .14401 .39915 .13707 .39806 .13554 Mtetra
.757 .737 .833 r
.39806 .13554 .39915 .13707 .40103 .13534 .39992 .1342 Mtetra
.659 .772 .933 r
.39992 .1342 .40103 .13534 .40287 .13465 .40176 .13351 Mtetra
.588 .748 .953 r
.40176 .13351 .40287 .13465 .40469 .13437 .40359 .13307 Mtetra
.757 .773 .866 r
.40359 .13307 .40469 .13437 .40654 .13331 .40546 .13183 Mtetra
.722 .734 .861 r
.40546 .13183 .40654 .13331 .4084 .1324 .40731 .13077 Mtetra
.585 .656 .886 r
.40731 .13077 .4084 .1324 .41022 .13215 .40915 .13039 Mtetra
.704 .289 0 r
.40915 .13039 .41022 .13215 .41192 .1354 .41084 .13368 Mtetra
.971 .683 .423 r
.41084 .13368 .41192 .1354 .4058 .34675 .40459 .34628 Mtetra
.921 .532 .229 r
.40459 .34628 .4058 .34675 .40749 .35379 .40629 .35317 Mtetra
0 .479 .815 r
.40629 .35317 .40749 .35379 .40943 .35448 .40823 .3537 Mtetra
.672 .864 .972 r
.40823 .3537 .40943 .35448 .41142 .35384 .41023 .35285 Mtetra
.776 .845 .904 r
.41023 .35285 .41142 .35384 .41342 .3527 .41224 .3515 Mtetra
.535 .732 .965 r
.41224 .3515 .41342 .3527 .4154 .35231 .41422 .35119 Mtetra
.532 .747 .974 r
.41422 .35119 .4154 .35231 .41739 .35182 .4162 .35088 Mtetra
.724 .845 .939 r
.4162 .35088 .41739 .35182 .4194 .35061 .41821 .34982 Mtetra
.955 .817 .667 r
.41821 .34982 .4194 .35061 .42153 .34573 .42035 .34495 Mtetra
.972 .689 .431 r
.42035 .34495 .42153 .34573 .43033 .13263 .42926 .13074 Mtetra
.939 .722 .583 r
.42926 .13074 .43033 .13263 .43243 .12439 .43136 .12252 Mtetra
.802 .711 .765 r
.43136 .12252 .43243 .12439 .43433 .12236 .43326 .12046 Mtetra
.653 .652 .837 r
.43326 .12046 .43433 .12236 .43619 .12163 .43513 .11972 Mtetra
.559 .606 .856 r
.43513 .11972 .43619 .12163 .43804 .12136 .43698 .11945 Mtetra
.591 .623 .852 r
.43698 .11945 .43804 .12136 .4399 .1208 .43883 .11904 Mtetra
.612 .653 .866 r
.43883 .11904 .4399 .1208 .44177 .12008 .44069 .11853 Mtetra
.621 .689 .892 r
.44069 .11853 .44177 .12008 .44363 .11935 .44255 .11799 Mtetra
.667 .738 .903 r
.44255 .11799 .44363 .11935 .4455 .11864 .44442 .11725 Mtetra
.689 .74 .89 r
.44442 .11725 .4455 .11864 .44737 .11793 .4463 .11639 Mtetra
.688 .716 .87 r
.4463 .11639 .44737 .11793 .44924 .11723 .44818 .11551 Mtetra
.667 .683 .856 r
.44818 .11551 .44924 .11723 .45111 .11651 .45005 .11471 Mtetra
.654 .667 .85 r
.45005 .11471 .45111 .11651 .45299 .11579 .45192 .11397 Mtetra
.651 .663 .849 r
.45192 .11397 .45299 .11579 .45486 .11507 .4538 .11325 Mtetra
.651 .664 .849 r
.4538 .11325 .45486 .11507 .45674 .11435 .45568 .11253 Mtetra
.651 .663 .849 r
.45568 .11253 .45674 .11435 .45862 .11363 .45756 .1118 Mtetra
.65 .662 .848 r
.45756 .1118 .45862 .11363 .4605 .11291 .45943 .11108 Mtetra
.649 .661 .847 r
.45943 .11108 .4605 .11291 .46238 .1122 .46132 .11036 Mtetra
.648 .659 .847 r
.46132 .11036 .46238 .1122 .46426 .1115 .4632 .10965 Mtetra
.647 .658 .846 r
.4632 .10965 .46426 .1115 .46614 .1108 .46508 .10894 Mtetra
.646 .656 .845 r
.46508 .10894 .46614 .1108 .46802 .11011 .46696 .10823 Mtetra
.645 .654 .845 r
.46696 .10823 .46802 .11011 .46991 .10942 .46885 .10754 Mtetra
.644 .653 .844 r
.46885 .10754 .46991 .10942 .47179 .10873 .47074 .10684 Mtetra
.645 .653 .843 r
.47074 .10684 .47179 .10873 .47368 .10803 .47263 .10614 Mtetra
.645 .652 .842 r
.47263 .10614 .47368 .10803 .47557 .10734 .47452 .10543 Mtetra
.645 .65 .841 r
.47452 .10543 .47557 .10734 .47746 .10664 .47641 .10472 Mtetra
.646 .649 .839 r
.47641 .10472 .47746 .10664 .47935 .10594 .4783 .10401 Mtetra
.646 .648 .838 r
.4783 .10401 .47935 .10594 .48125 .10523 .48019 .10329 Mtetra
.646 .647 .837 r
.48019 .10329 .48125 .10523 .48314 .10451 .48209 .10257 Mtetra
.48209 .10257 .48314 .10451 .48504 .1038 .48398 .10185 Mtetra
.647 .647 .836 r
.48398 .10185 .48504 .1038 .48694 .10307 .48588 .10112 Mtetra
.647 .646 .835 r
.48588 .10112 .48694 .10307 .48883 .10235 .48778 .10039 Mtetra
.48778 .10039 .48883 .10235 .49073 .10162 .48968 .09966 Mtetra
.48968 .09966 .49073 .10162 .49264 .10089 .49158 .09893 Mtetra
.49158 .09893 .49264 .10089 .49454 .10016 .49349 .0982 Mtetra
.647 .645 .834 r
.49349 .0982 .49454 .10016 .49644 .09943 .49539 .09746 Mtetra
.49539 .09746 .49644 .09943 .49835 .09869 .4973 .09672 Mtetra
.4973 .09672 .49835 .09869 .50026 .09796 .49921 .09599 Mtetra
.49921 .09599 .50026 .09796 .50216 .09722 .50112 .09525 Mtetra
.50112 .09525 .50216 .09722 .50407 .09648 .50303 .09451 Mtetra
.50303 .09451 .50407 .09648 .50598 .09574 .50494 .09377 Mtetra
.648 .645 .834 r
.50494 .09377 .50598 .09574 .5079 .09501 .50685 .09303 Mtetra
.50685 .09303 .5079 .09501 .50981 .09427 .50876 .09229 Mtetra
.50876 .09229 .50981 .09427 .51173 .09352 .51068 .09155 Mtetra
.51068 .09155 .51173 .09352 .51364 .09278 .5126 .0908 Mtetra
.5126 .0908 .51364 .09278 .51556 .09204 .51451 .09006 Mtetra
.51451 .09006 .51556 .09204 .51748 .0913 .51643 .08932 Mtetra
.51643 .08932 .51748 .0913 .5194 .09056 .51835 .08857 Mtetra
.51835 .08857 .5194 .09056 .52132 .08981 .52028 .08783 Mtetra
.52028 .08783 .52132 .08981 .52324 .08907 .5222 .08708 Mtetra
.5222 .08708 .52324 .08907 .52517 .08832 .52412 .08634 Mtetra
.52412 .08634 .52517 .08832 .52709 .08758 .52605 .08559 Mtetra
.52605 .08559 .52709 .08758 .52902 .08683 .52798 .08484 Mtetra
.52798 .08484 .52902 .08683 .53095 .08608 .52991 .0841 Mtetra
.52991 .0841 .53095 .08608 .53288 .08534 .53184 .08335 Mtetra
.53184 .08335 .53288 .08534 .53481 .08459 .53377 .0826 Mtetra
.53377 .0826 .53481 .08459 .53674 .08384 .5357 .08185 Mtetra
.5357 .08185 .53674 .08384 .53868 .08309 .53764 .0811 Mtetra
.53764 .0811 .53868 .08309 .54061 .08234 .53957 .08035 Mtetra
.53957 .08035 .54061 .08234 .54255 .08159 .54151 .0796 Mtetra
.54151 .0796 .54255 .08159 .54449 .08084 .54345 .07885 Mtetra
.54345 .07885 .54449 .08084 .54642 .08009 .54539 .07809 Mtetra
.54539 .07809 .54642 .08009 .54837 .07934 .54733 .07734 Mtetra
.54733 .07734 .54837 .07934 .55031 .07859 .54927 .07659 Mtetra
.54927 .07659 .55031 .07859 .55225 .07783 .55121 .07583 Mtetra
.55121 .07583 .55225 .07783 .5542 .07708 .55316 .07508 Mtetra
.55316 .07508 .5542 .07708 .55614 .07632 .55511 .07432 Mtetra
.648 .646 .834 r
.55511 .07432 .55614 .07632 .55809 .07556 .55705 .07356 Mtetra
.55705 .07356 .55809 .07556 .56004 .07481 .559 .07281 Mtetra
.559 .07281 .56004 .07481 .56199 .07405 .56095 .07205 Mtetra
.56095 .07205 .56199 .07405 .56394 .07329 .56291 .07129 Mtetra
.649 .646 .834 r
.56291 .07129 .56394 .07329 .56589 .07252 .56486 .07052 Mtetra
.649 .647 .834 r
.56486 .07052 .56589 .07252 .56785 .07176 .56681 .06976 Mtetra
.56681 .06976 .56785 .07176 .5698 .07099 .56877 .06899 Mtetra
.65 .648 .835 r
.56877 .06899 .5698 .07099 .57176 .07021 .57073 .06822 Mtetra
.65 .649 .835 r
.57073 .06822 .57176 .07021 .57372 .06944 .57269 .06745 Mtetra
.651 .649 .836 r
.57269 .06745 .57372 .06944 .57568 .06866 .57465 .06667 Mtetra
.651 .65 .836 r
.57465 .06667 .57568 .06866 .57764 .06787 .57661 .0659 Mtetra
.652 .652 .837 r
.57661 .0659 .57764 .06787 .5796 .06708 .57857 .06511 Mtetra
.653 .653 .838 r
.57857 .06511 .5796 .06708 .58156 .06629 .58053 .06433 Mtetra
.654 .655 .839 r
.58053 .06433 .58156 .06629 .58353 .06549 .5825 .06354 Mtetra
.655 .657 .84 r
.5825 .06354 .58353 .06549 .58549 .06469 .58447 .06275 Mtetra
.58447 .06275 .58549 .06469 .58746 .0639 .58643 .06195 Mtetra
.654 .657 .841 r
.58643 .06195 .58746 .0639 .58943 .0631 .5884 .06117 Mtetra
.653 .657 .842 r
.5884 .06117 .58943 .0631 .5914 .06232 .59037 .06039 Mtetra
.652 .658 .843 r
.59037 .06039 .5914 .06232 .59337 .06154 .59235 .05961 Mtetra
.651 .658 .844 r
.59235 .05961 .59337 .06154 .59534 .06077 .59432 .05884 Mtetra
.65 .658 .844 r
.59432 .05884 .59534 .06077 .59732 .06002 .5963 .05808 Mtetra
.649 .657 .844 r
.5963 .05808 .59732 .06002 .5993 .05926 .59827 .05732 Mtetra
.648 .656 .844 r
.59827 .05732 .5993 .05926 .60127 .05852 .60025 .05657 Mtetra
.647 .654 .844 r
.60025 .05657 .60127 .05852 .60325 .05778 .60223 .05582 Mtetra
.646 .654 .843 r
.60223 .05582 .60325 .05778 .60524 .05704 .60421 .05508 Mtetra
.647 .653 .842 r
.60421 .05508 .60524 .05704 .60722 .05629 .6062 .05433 Mtetra
.648 .653 .841 r
.6062 .05433 .60722 .05629 .6092 .05554 .60818 .05357 Mtetra
.649 .652 .84 r
.60818 .05357 .6092 .05554 .61119 .05479 .61017 .0528 Mtetra
.65 .652 .839 r
.61017 .0528 .61119 .05479 .61317 .05402 .61215 .05203 Mtetra
.652 .652 .837 r
.61215 .05203 .61317 .05402 .61516 .05324 .61414 .05124 Mtetra
.652 .651 .836 r
.61414 .05124 .61516 .05324 .61715 .05245 .61613 .05044 Mtetra
.66 .654 .833 r
.61613 .05044 .61715 .05245 .61914 .05164 .61812 .0496 Mtetra
.677 .658 .824 r
.61812 .0496 .61914 .05164 .62113 .05081 .62011 .04863 Mtetra
.647 .629 .819 r
.62011 .04863 .62113 .05081 .62312 .04998 .6221 .04784 Mtetra
.571 .594 .837 r
.6221 .04784 .62312 .04998 .62511 .0492 .62411 .04749 Mtetra
.242 .462 .872 r
.62411 .04749 .62511 .0492 .62711 .04851 .62616 .04823 Mtetra
.534 0 0 r
.62616 .04823 .62711 .04851 .62911 .04784 .62824 .04975 Mtetra
.67 .222 .179 r
.62824 .04975 .62911 .04784 .63112 .04713 .63035 .05181 Mtetra
.445 .104 .291 r
.63035 .05181 .63112 .04713 .63311 .04632 .63237 .05163 Mtetra
.365 .051 .293 r
.63237 .05163 .63311 .04632 .63511 .04548 .63437 .05046 Mtetra
.33 .016 .273 r
.63437 .05046 .63511 .04548 .63712 .04465 .63635 .04904 Mtetra
.373 .038 .262 r
.63635 .04904 .63712 .04465 .63912 .04385 .63836 .04821 Mtetra
.374 .037 .26 r
.63836 .04821 .63912 .04385 .64112 .04306 .64037 .04739 Mtetra
.376 .038 .26 r
.64037 .04739 .64112 .04306 .64313 .04228 .64238 .0466 Mtetra
.38 .042 .26 r
.64238 .0466 .64313 .04228 .64514 .0415 .6444 .04584 Mtetra
.383 .044 .262 r
.6444 .04584 .64514 .0415 .64715 .04073 .64641 .04511 Mtetra
.385 .047 .264 r
.64641 .04511 .64715 .04073 .64916 .03997 .64843 .04439 Mtetra
.385 .048 .266 r
.64843 .04439 .64916 .03997 .65118 .0392 .65045 .04365 Mtetra
.387 .05 .268 r
.65045 .04365 .65118 .0392 .65319 .03844 .65248 .04292 Mtetra
.388 .052 .27 r
.65248 .04292 .65319 .03844 .65521 .03767 .6545 .0422 Mtetra
.389 .054 .271 r
.6545 .0422 .65521 .03767 .65723 .03691 .65652 .04147 Mtetra
.39 .055 .273 r
.65652 .04147 .65723 .03691 .65925 .03615 .65855 .04074 Mtetra
.39 .056 .274 r
.65855 .04074 .65925 .03615 .66127 .03539 .66058 .04001 Mtetra
.391 .058 .276 r
.66058 .04001 .66127 .03539 .66329 .03463 .66261 .03928 Mtetra
.391 .058 .277 r
.66261 .03928 .66329 .03463 .66532 .03387 .66464 .03854 Mtetra
.39 .058 .278 r
.66464 .03854 .66532 .03387 .66734 .0331 .66667 .03778 Mtetra
.389 .058 .278 r
.66667 .03778 .66734 .0331 .66937 .03233 .66871 .03702 Mtetra
.387 .057 .278 r
.66871 .03702 .66937 .03233 .6714 .03154 .67074 .03623 Mtetra
.385 .054 .277 r
.67074 .03623 .6714 .03154 .67343 .03075 .67277 .03542 Mtetra
.381 .051 .275 r
.67277 .03542 .67343 .03075 .67546 .02995 .67481 .03457 Mtetra
.377 .047 .273 r
.67481 .03457 .67546 .02995 .67749 .02913 .67684 .0337 Mtetra
.371 .041 .269 r
.67684 .0337 .67749 .02913 .67952 .0283 .67887 .03278 Mtetra
.362 .031 .263 r
.67887 .03278 .67952 .0283 .68155 .02743 .6809 .0318 Mtetra
.356 .023 .257 r
.6809 .0318 .68155 .02743 .68358 .02656 .68293 .0308 Mtetra
.346 .012 .249 r
.68293 .0308 .68358 .02656 .68562 .02567 .68496 .02975 Mtetra
.238 0 .213 r
.68496 .02975 .68562 .02567 .68762 .02434 .68694 .0279 Mtetra
.305 0 .201 r
.68694 .0279 .68762 .02434 .68966 .0234 .68897 .02678 Mtetra
.457 .077 .229 r
.68897 .02678 .68966 .0234 .69173 .02321 .69107 .0269 Mtetra
.97 .652 .307 r
.69107 .0269 .69173 .02321 .69407 .02732 .70521 .23085 Mtetra
.524 .277 .482 r
.70521 .23085 .69407 .02732 .7091 .24265 .70826 .24421 Mtetra
.725 .253 .128 r
.70826 .24421 .7091 .24265 .71172 .24856 .71069 .24709 Mtetra
.604 .746 .945 r
.01093 .48804 .01227 .48916 .0139 .48903 .01261 .4876 Mtetra
.664 .709 .881 r
.01261 .4876 .0139 .48903 .01562 .48836 .01433 .48691 Mtetra
.678 .711 .873 r
.01433 .48691 .01562 .48836 .01738 .48743 .01607 .48614 Mtetra
.514 .682 .942 r
.01607 .48614 .01738 .48743 .019 .48746 .01772 .48598 Mtetra
.566 .669 .908 r
.01772 .48598 .019 .48746 .02066 .4872 .01938 .4857 Mtetra
.645 .693 .88 r
.01938 .4857 .02066 .4872 .02241 .48635 .0211 .48509 Mtetra
.778 .756 .833 r
.0211 .48509 .02241 .48635 .02454 .48303 .02294 .48364 Mtetra
.897 .98 .806 r
.02294 .48364 .02454 .48303 .02742 .47473 .02492 .4813 Mtetra
0 0 .043 r
.02492 .4813 .02742 .47473 .05961 .27146 .0272 .47696 Mtetra
0 0 0 r
.0272 .47696 .05961 .27146 .06173 .26743 .05949 .27301 Mtetra
.824 .839 .372 r
.05949 .27301 .06173 .26743 .06359 .26519 .06212 .26564 Mtetra
.948 .912 .748 r
.06212 .26564 .06359 .26519 .06534 .26368 .06411 .26251 Mtetra
.749 .755 .858 r
.06411 .26251 .06534 .26368 .06699 .26283 .0658 .2614 Mtetra
.64 .688 .879 r
.0658 .2614 .06699 .26283 .0686 .26227 .06741 .26085 Mtetra
.565 .663 .904 r
.06741 .26085 .0686 .26227 .07019 .26186 .06898 .26059 Mtetra
.611 .705 .911 r
.06898 .26059 .07019 .26186 .07179 .2614 .07057 .26016 Mtetra
.617 .714 .915 r
.07057 .26016 .07179 .2614 .07339 .26091 .07217 .25971 Mtetra
.629 .725 .916 r
.07217 .25971 .07339 .26091 .075 .26038 .07377 .25922 Mtetra
.713 .752 .883 r
.07377 .25922 .075 .26038 .07668 .25933 .07543 .25834 Mtetra
.712 .784 .908 r
.07543 .25834 .07668 .25933 .07835 .25843 .07709 .2575 Mtetra
.658 .787 .943 r
.07709 .2575 .07835 .25843 .07995 .25797 .07871 .25689 Mtetra
.398 .66 .965 r
.07871 .25689 .07995 .25797 .08128 .2594 .08024 .25695 Mtetra
.273 .363 .773 r
.08024 .25695 .08128 .2594 .08214 .26413 .08167 .25771 Mtetra
.249 .162 .558 r
.08167 .25771 .08214 .26413 .05455 .46791 .08289 .25993 Mtetra
0 0 .005 r
.08289 .25993 .05455 .46791 .05559 .47218 .05579 .46038 Mtetra
0 0 .198 r
.05579 .46038 .05559 .47218 .05703 .47369 .05602 .4703 Mtetra
0 0 .487 r
.05602 .4703 .05703 .47369 .0586 .47424 .0573 .47292 Mtetra
.305 .578 .937 r
.0573 .47292 .0586 .47424 .06025 .47429 .05892 .4732 Mtetra
.636 .763 .94 r
.05892 .4732 .06025 .47429 .06197 .47381 .06065 .47263 Mtetra
.743 .769 .874 r
.06065 .47263 .06197 .47381 .06379 .4727 .06247 .47152 Mtetra
.814 .771 .813 r
.06247 .47152 .06379 .4727 .06588 .46959 .06438 .46969 Mtetra
.912 .926 .81 r
.06438 .46969 .06588 .46959 .06849 .46272 .06639 .46722 Mtetra
0 0 0 r
.06639 .46722 .06849 .46272 .09845 .25825 .06848 .46412 Mtetra
.496 .256 .479 r
.06848 .46412 .09845 .25825 .10039 .25548 .07026 .46325 Mtetra
.498 .257 .48 r
.07026 .46325 .10039 .25548 .102 .25508 .07195 .46304 Mtetra
.496 .255 .479 r
.07195 .46304 .102 .25508 .10359 .25489 .07376 .46198 Mtetra
.457 .222 .468 r
.07376 .46198 .10359 .25489 .10556 .25187 .07761 .44607 Mtetra
0 0 0 r
.07761 .44607 .10556 .25187 .1075 .24907 .10599 .25007 Mtetra
.972 .917 .687 r
.10599 .25007 .1075 .24907 .10933 .24702 .1081 .24602 Mtetra
.79 .792 .854 r
.1081 .24602 .10933 .24702 .11102 .24606 .10984 .24466 Mtetra
.625 .69 .891 r
.10984 .24466 .11102 .24606 .11265 .24559 .11147 .24417 Mtetra
.528 .65 .912 r
.11147 .24417 .11265 .24559 .11425 .24529 .11305 .24401 Mtetra
.607 .707 .915 r
.11305 .24401 .11425 .24529 .11588 .2448 .11467 .24359 Mtetra
.645 .731 .911 r
.11467 .24359 .11588 .2448 .11753 .24421 .11632 .24302 Mtetra
.656 .739 .911 r
.11632 .24302 .11753 .24421 .11918 .24356 .11796 .24241 Mtetra
.676 .751 .907 r
.11796 .24241 .11918 .24356 .12084 .24283 .11963 .24172 Mtetra
.685 .761 .909 r
.11963 .24172 .12084 .24283 .12252 .24205 .12129 .24098 Mtetra
.684 .768 .915 r
.12129 .24098 .12252 .24205 .12419 .2413 .12296 .24026 Mtetra
.666 .771 .928 r
.12296 .24026 .12419 .2413 .12585 .24063 .12462 .23961 Mtetra
.651 .771 .937 r
.12462 .23961 .12585 .24063 .1275 .24003 .12627 .23902 Mtetra
.638 .77 .943 r
.12627 .23902 .1275 .24003 .12914 .23948 .12791 .23848 Mtetra
.613 .763 .951 r
.12791 .23848 .12914 .23948 .13078 .23902 .12955 .23801 Mtetra
.601 .759 .954 r
.12955 .23801 .13078 .23902 .13241 .23861 .13118 .23758 Mtetra
.609 .758 .95 r
.13118 .23758 .13241 .23861 .13404 .23818 .13282 .23713 Mtetra
.652 .766 .933 r
.13282 .23713 .13404 .23818 .1357 .23761 .13448 .23654 Mtetra
.678 .767 .918 r
.13448 .23654 .1357 .23761 .13737 .23694 .13615 .23584 Mtetra
.687 .764 .91 r
.13615 .23584 .13737 .23694 .13904 .23622 .13783 .23509 Mtetra
.755 .771 .866 r
.13783 .23509 .13904 .23622 .14077 .2351 .13956 .23395 Mtetra
.737 .765 .875 r
.13956 .23395 .14077 .2351 .14248 .23408 .14127 .23292 Mtetra
.595 .726 .936 r
.14127 .23292 .14248 .23408 .14411 .2337 .14291 .23252 Mtetra
.83 .368 0 r
.14291 .23252 .14411 .2337 .14539 .23624 .14418 .23507 Mtetra
.948 .684 .504 r
.14418 .23507 .14539 .23624 .12151 .44243 .1202 .44134 Mtetra
.945 .612 .365 r
.1202 .44134 .12151 .44243 .12219 .45069 .12089 .44956 Mtetra
.548 .025 0 r
.12089 .44956 .12219 .45069 .12371 .45221 .12241 .45107 Mtetra
.547 .731 .96 r
.12241 .45107 .12371 .45221 .12546 .45191 .12416 .45077 Mtetra
.782 .785 .855 r
.12416 .45077 .12546 .45191 .12734 .45048 .12604 .44934 Mtetra
.906 .757 .685 r
.12604 .44934 .12734 .45048 .12962 .44585 .12831 .44473 Mtetra
.948 .689 .511 r
.12831 .44473 .12962 .44585 .15662 .23584 .1554 .23477 Mtetra
.93 .732 .614 r
.1554 .23477 .15662 .23584 .15917 .22789 .15797 .22674 Mtetra
.841 .77 .784 r
.15797 .22674 .15917 .22789 .16103 .22578 .15983 .22461 Mtetra
.628 .737 .926 r
.15983 .22461 .16103 .22578 .16269 .22528 .16149 .2241 Mtetra
.44 .661 .955 r
.16149 .2241 .16269 .22528 .16429 .22529 .1631 .2241 Mtetra
.641 .738 .919 r
.1631 .2241 .16429 .22529 .16596 .22473 .16477 .22354 Mtetra
.713 .756 .886 r
.16477 .22354 .16596 .22473 .16767 .22382 .16648 .22264 Mtetra
.59 .722 .935 r
.16648 .22264 .16767 .22382 .16933 .22343 .16813 .22226 Mtetra
.738 .25 0 r
.16813 .22226 .16933 .22343 .1707 .22548 .1695 .22435 Mtetra
.95 .685 .498 r
.1695 .22435 .1707 .22548 .1487 .42958 .14733 .42913 Mtetra
.938 .618 .407 r
.14733 .42913 .1487 .42958 .14911 .44103 .1478 .44 Mtetra
.527 0 0 r
.1478 .44 .14911 .44103 .15067 .44249 .14937 .44143 Mtetra
.66 .784 .94 r
.14937 .44143 .15067 .44249 .15248 .4418 .15118 .44075 Mtetra
.772 .802 .877 r
.15118 .44075 .15248 .4418 .15436 .44048 .15306 .43944 Mtetra
.749 .803 .896 r
.15306 .43944 .15436 .44048 .15623 .43935 .15493 .43831 Mtetra
.673 .791 .937 r
.15493 .43831 .15623 .43935 .15805 .43862 .15675 .43757 Mtetra
.661 .787 .941 r
.15675 .43757 .15805 .43862 .15986 .43793 .15856 .43688 Mtetra
.617 .773 .955 r
.15856 .43688 .15986 .43793 .16165 .43753 .16036 .43635 Mtetra
.603 .745 .944 r
.16036 .43635 .16165 .43753 .16342 .4372 .16215 .43588 Mtetra
.653 .737 .911 r
.16215 .43588 .16342 .4372 .16525 .43644 .16397 .43522 Mtetra
.773 .778 .857 r
.16397 .43522 .16525 .43644 .16726 .43404 .16587 .43385 Mtetra
.897 .915 .827 r
.16587 .43385 .16726 .43404 .16969 .42777 .16787 .43156 Mtetra
0 0 0 r
.16787 .43156 .16969 .42777 .19377 .2224 .16993 .42866 Mtetra
.493 .253 .479 r
.16993 .42866 .19377 .2224 .19591 .21765 .17193 .42635 Mtetra
.497 .256 .48 r
.17193 .42635 .19591 .21765 .19764 .2168 .17374 .4257 Mtetra
.498 .258 .48 r
.17374 .4257 .19764 .2168 .19928 .21681 .1755 .42564 Mtetra
.498 .257 .48 r
.1755 .42564 .19928 .21681 .20092 .21677 .17728 .42542 Mtetra
.497 .257 .48 r
.17728 .42542 .20092 .21677 .20261 .21624 .17909 .42488 Mtetra
.17909 .42488 .20261 .21624 .20431 .21571 .1809 .42432 Mtetra
.497 .256 .48 r
.1809 .42432 .20431 .21571 .20601 .21515 .18272 .42375 Mtetra
.18272 .42375 .20601 .21515 .20772 .21456 .18454 .42316 Mtetra
.18454 .42316 .20772 .21456 .20943 .21396 .18636 .42257 Mtetra
.18636 .42257 .20943 .21396 .21113 .21336 .18818 .42199 Mtetra
.497 .257 .48 r
.18818 .42199 .21113 .21336 .21284 .21277 .19 .42142 Mtetra
.497 .256 .48 r
.19 .42142 .21284 .21277 .21455 .21217 .19182 .42084 Mtetra
.498 .257 .48 r
.19182 .42084 .21455 .21217 .21624 .21187 .19361 .42069 Mtetra
.499 .258 .48 r
.19361 .42069 .21624 .21187 .2179 .2118 .19537 .42071 Mtetra
.496 .256 .48 r
.19537 .42071 .2179 .2118 .21964 .21096 .19723 .41979 Mtetra
.487 .248 .477 r
.19723 .41979 .21964 .21096 .22157 .20824 .1995 .41485 Mtetra
0 0 .081 r
.1995 .41485 .22157 .20824 .22355 .20493 .22198 .20769 Mtetra
.925 .9 .498 r
.22198 .20769 .22355 .20493 .22545 .20248 .22421 .20191 Mtetra
.896 .854 .792 r
.22421 .20191 .22545 .20248 .22726 .20093 .22611 .19949 Mtetra
.698 .717 .864 r
.22611 .19949 .22726 .20093 .22899 .20016 .22786 .19861 Mtetra
.617 .673 .881 r
.22786 .19861 .22899 .20016 .23071 .1996 .22956 .19813 Mtetra
.61 .683 .893 r
.22956 .19813 .23071 .1996 .23242 .19905 .23127 .19768 Mtetra
.66 .716 .89 r
.23127 .19768 .23242 .19905 .23415 .19838 .233 .19701 Mtetra
.659 .718 .891 r
.233 .19701 .23415 .19838 .23588 .1977 .23472 .19634 Mtetra
.66 .72 .893 r
.23472 .19634 .23588 .1977 .23761 .19703 .23645 .19568 Mtetra
.662 .722 .894 r
.23645 .19568 .23761 .19703 .23934 .19635 .23818 .19501 Mtetra
.662 .723 .894 r
.23818 .19501 .23934 .19635 .24107 .19567 .23992 .19433 Mtetra
.661 .723 .895 r
.23992 .19433 .24107 .19567 .2428 .195 .24165 .19366 Mtetra
.661 .724 .896 r
.24165 .19366 .2428 .195 .24454 .19433 .24338 .19299 Mtetra
.66 .724 .896 r
.24338 .19299 .24454 .19433 .24627 .19366 .24512 .19233 Mtetra
.66 .724 .897 r
.24512 .19233 .24627 .19366 .24801 .19299 .24685 .19166 Mtetra
.659 .725 .898 r
.24685 .19166 .24801 .19299 .24974 .19233 .24859 .191 Mtetra
.654 .724 .9 r
.24859 .191 .24974 .19233 .25148 .19168 .25033 .19036 Mtetra
.641 .721 .906 r
.25033 .19036 .25148 .19168 .25321 .19109 .25206 .18978 Mtetra
.62 .716 .914 r
.25206 .18978 .25321 .19109 .25494 .19058 .25378 .18928 Mtetra
.617 .717 .917 r
.25378 .18928 .25494 .19058 .25667 .19008 .25551 .18879 Mtetra
.628 .723 .915 r
.25551 .18879 .25667 .19008 .2584 .18953 .25724 .18826 Mtetra
.651 .734 .91 r
.25724 .18826 .2584 .18953 .26014 .18889 .25898 .18764 Mtetra
.665 .741 .907 r
.25898 .18764 .26014 .18889 .26189 .18819 .26073 .18695 Mtetra
.68 .749 .903 r
.26073 .18695 .26189 .18819 .26364 .18742 .26248 .1862 Mtetra
.697 .757 .899 r
.26248 .1862 .26364 .18742 .26541 .18655 .26425 .18537 Mtetra
.699 .764 .902 r
.26425 .18537 .26541 .18655 .26717 .18568 .26601 .18452 Mtetra
.692 .767 .909 r
.26601 .18452 .26717 .18568 .26893 .18486 .26777 .18372 Mtetra
.674 .767 .92 r
.26777 .18372 .26893 .18486 .27069 .18413 .26953 .183 Mtetra
.668 .767 .924 r
.26953 .183 .27069 .18413 .27244 .18342 .27128 .18231 Mtetra
.667 .768 .926 r
.27128 .18231 .27244 .18342 .2742 .18273 .27304 .18162 Mtetra
.669 .771 .926 r
.27304 .18162 .2742 .18273 .27596 .18202 .27479 .18092 Mtetra
.668 .772 .928 r
.27479 .18092 .27596 .18202 .27771 .18132 .27655 .18022 Mtetra
.677 .776 .925 r
.27655 .18022 .27771 .18132 .27948 .18055 .27831 .17949 Mtetra
.699 .788 .92 r
.27831 .17949 .27948 .18055 .28126 .1796 .28008 .17866 Mtetra
.662 .803 .951 r
.28008 .17866 .28126 .1796 .28302 .17895 .28184 .17799 Mtetra
.528 .753 .979 r
.28184 .17799 .28302 .17895 .28471 .17908 .28357 .17771 Mtetra
.129 .45 .882 r
.28357 .17771 .28471 .17908 .28621 .18166 .28523 .17837 Mtetra
.25 .284 .702 r
.28523 .17837 .28621 .18166 .28684 .19547 .28684 .17962 Mtetra
.462 .268 .53 r
.28684 .17962 .28684 .19547 .27305 .39356 .28845 .18094 Mtetra
.502 .266 .489 r
.28845 .18094 .27305 .39356 .27489 .39344 .29025 .17987 Mtetra
.29025 .17987 .27489 .39344 .27681 .39241 .29203 .17904 Mtetra
.496 .261 .488 r
.29203 .17904 .27681 .39241 .27867 .39217 .29365 .18034 Mtetra
0 0 .16 r
.29365 .18034 .27867 .39217 .28034 .39437 .27958 .38697 Mtetra
0 0 .377 r
.27958 .38697 .28034 .39437 .28208 .3958 .28094 .39329 Mtetra
0 .082 .64 r
.28094 .39329 .28208 .3958 .28387 .39647 .28263 .39533 Mtetra
.473 .708 .972 r
.28263 .39533 .28387 .39647 .28574 .3962 .28449 .3952 Mtetra
.636 .799 .961 r
.28449 .3952 .28574 .3962 .28764 .39566 .28639 .39456 Mtetra
.69 .796 .931 r
.28639 .39456 .28764 .39566 .28954 .395 .28831 .39371 Mtetra
.638 .747 .927 r
.28831 .39371 .28954 .395 .29143 .39453 .29021 .39308 Mtetra
.677 .732 .892 r
.29021 .39308 .29143 .39453 .29334 .39374 .29213 .39226 Mtetra
.726 .743 .865 r
.29213 .39226 .29334 .39374 .29531 .39226 .29407 .39113 Mtetra
.81 .809 .85 r
.29407 .39113 .29531 .39226 .29742 .38863 .29605 .38945 Mtetra
.83 .988 .721 r
.29605 .38945 .29742 .38863 .29987 .38024 .29809 .38698 Mtetra
0 0 .151 r
.29809 .38698 .29987 .38024 .3162 .17262 .30027 .38245 Mtetra
0 0 .154 r
.30027 .38245 .3162 .17262 .31824 .1683 .31663 .17377 Mtetra
0 0 0 r
.31663 .17377 .31824 .1683 .32014 .16592 .3189 .16612 Mtetra
.95 .936 .742 r
.3189 .16612 .32014 .16592 .32198 .16439 .32085 .16305 Mtetra
.706 .744 .882 r
.32085 .16305 .32198 .16439 .32377 .16366 .32266 .16214 Mtetra
.594 .673 .895 r
.32266 .16214 .32377 .16366 .32554 .16322 .32442 .16173 Mtetra
.531 .652 .912 r
.32442 .16173 .32554 .16322 .32731 .16288 .32618 .16155 Mtetra
.646 .727 .907 r
.32618 .16155 .32731 .16288 .3291 .16222 .32797 .16092 Mtetra
.66 .737 .907 r
.32797 .16092 .3291 .16222 .33089 .16151 .32976 .16024 Mtetra
.678 .749 .905 r
.32976 .16024 .33089 .16151 .33269 .1607 .33156 .15948 Mtetra
.733 .772 .884 r
.33156 .15948 .33269 .1607 .33452 .15947 .33338 .15842 Mtetra
.715 .8 .917 r
.33338 .15842 .33452 .15947 .33633 .15853 .33519 .1575 Mtetra
.647 .787 .949 r
.33519 .1575 .33633 .15853 .33811 .15815 .33698 .15687 Mtetra
.404 .631 .947 r
.33698 .15687 .33811 .15815 .33975 .15999 .33873 .15697 Mtetra
.339 .364 .74 r
.33873 .15697 .33975 .15999 .34111 .16642 .34043 .15782 Mtetra
.33 .206 .555 r
.34043 .15782 .34111 .16642 .33027 .37338 .34204 .16034 Mtetra
0 0 .196 r
.34204 .16034 .33027 .37338 .33197 .3764 .33131 .36611 Mtetra
0 0 .392 r
.33131 .36611 .33197 .3764 .3338 .37754 .33271 .37417 Mtetra
0 .098 .628 r
.33271 .37417 .3338 .37754 .33567 .37788 .33446 .37655 Mtetra
.386 .63 .951 r
.33446 .37655 .33567 .37788 .33756 .37797 .33635 .37668 Mtetra
.62 .745 .936 r
.33635 .37668 .33756 .37797 .33949 .37749 .33829 .37612 Mtetra
.729 .764 .88 r
.33829 .37612 .33949 .37749 .34146 .37633 .34025 .37499 Mtetra
.788 .781 .846 r
.34025 .37499 .34146 .37633 .34355 .37296 .34225 .37341 Mtetra
.869 .995 .775 r
.34225 .37341 .34355 .37296 .34588 .36547 .34429 .371 Mtetra
0 0 .094 r
.34429 .371 .34588 .36547 .3594 .1563 .34643 .36677 Mtetra
0 0 .184 r
.34643 .36677 .3594 .1563 .36143 .15168 .35988 .15815 Mtetra
0 0 0 r
.35988 .15815 .36143 .15168 .36334 .1492 .36214 .14957 Mtetra
.958 .943 .709 r
.36214 .14957 .36334 .1492 .36521 .14757 .3641 .14622 Mtetra
.731 .753 .87 r
.3641 .14622 .36521 .14757 .36703 .14674 .36593 .14514 Mtetra
.616 .673 .881 r
.36593 .14514 .36703 .14674 .36884 .14623 .36774 .14463 Mtetra
.546 .642 .896 r
.36774 .14463 .36884 .14623 .37064 .14587 .36953 .1444 Mtetra
.731 .736 .855 r
.36953 .1444 .37064 .14587 .37248 .14472 .37138 .14328 Mtetra
.688 .727 .88 r
.37138 .14328 .37248 .14472 .37431 .14387 .37321 .14244 Mtetra
.515 .658 .924 r
.37321 .14244 .37431 .14387 .3761 .14372 .375 .14229 Mtetra
.865 .447 .004 r
.375 .14229 .3761 .14372 .37767 .14821 .37658 .14655 Mtetra
.969 .684 .435 r
.37658 .14655 .37767 .14821 .36906 .36069 .36789 .35901 Mtetra
.895 .498 .067 r
.36789 .35901 .36906 .36069 .37073 .36592 .36954 .3645 Mtetra
.254 .539 .922 r
.36954 .3645 .37073 .36592 .37265 .3662 .37145 .36497 Mtetra
.668 .774 .929 r
.37145 .36497 .37265 .3662 .37462 .36534 .37342 .36419 Mtetra
.815 .816 .85 r
.37342 .36419 .37462 .36534 .37663 .36377 .37544 .36245 Mtetra
.901 .784 .722 r
.37544 .36245 .37663 .36377 .37864 .36205 .37754 .35891 Mtetra
.9 .679 .594 r
.37754 .35891 .37864 .36205 .38069 .35964 .37986 .35051 Mtetra
.962 .68 .453 r
.37986 .35051 .38069 .35964 .3828 .35562 .3912 .14188 Mtetra
.51 .272 .49 r
.3912 .14188 .3828 .35562 .39383 .14958 .39319 .13774 Mtetra
.589 .379 .564 r
.39319 .13774 .39383 .14958 .3961 .13912 .39509 .13552 Mtetra
.675 .541 .694 r
.39509 .13552 .3961 .13912 .39806 .13554 .39697 .13401 Mtetra
.701 .718 .862 r
.39697 .13401 .39806 .13554 .39992 .1342 .39882 .13306 Mtetra
.659 .774 .934 r
.39882 .13306 .39992 .1342 .40176 .13351 .40066 .13237 Mtetra
.633 .765 .942 r
.40066 .13237 .40176 .13351 .40359 .13307 .40249 .13178 Mtetra
.763 .774 .862 r
.40249 .13178 .40359 .13307 .40546 .13183 .40436 .13049 Mtetra
.731 .758 .874 r
.40436 .13049 .40546 .13183 .40731 .13077 .40622 .1294 Mtetra
.588 .705 .924 r
.40622 .1294 .40731 .13077 .40915 .13039 .40805 .129 Mtetra
.756 .307 0 r
.40805 .129 .40915 .13039 .41084 .13368 .40975 .13216 Mtetra
.971 .683 .424 r
.40975 .13216 .41084 .13368 .40459 .34628 .40343 .34449 Mtetra
.924 .548 .139 r
.40343 .34449 .40459 .34628 .40629 .35317 .40511 .35175 Mtetra
.206 .51 .911 r
.40511 .35175 .40629 .35317 .40823 .3537 .40705 .35232 Mtetra
.671 .753 .912 r
.40705 .35232 .40823 .3537 .41023 .35285 .40905 .35152 Mtetra
.755 .783 .876 r
.40905 .35152 .41023 .35285 .41224 .3515 .41106 .35021 Mtetra
.529 .713 .956 r
.41106 .35021 .41224 .3515 .41422 .35119 .41304 .34995 Mtetra
.533 .723 .961 r
.41304 .34995 .41422 .35119 .4162 .35088 .41502 .34966 Mtetra
.714 .793 .913 r
.41502 .34966 .4162 .35088 .41821 .34982 .41703 .34864 Mtetra
.936 .788 .673 r
.41703 .34864 .41821 .34982 .42035 .34495 .41916 .34391 Mtetra
.972 .689 .432 r
.41916 .34391 .42035 .34495 .42926 .13074 .42814 .1301 Mtetra
.976 .77 .562 r
.42814 .1301 .42926 .13074 .43136 .12252 .43027 .12137 Mtetra
.853 .81 .806 r
.43027 .12137 .43136 .12252 .43326 .12046 .43217 .11928 Mtetra
.671 .772 .926 r
.43217 .11928 .43326 .12046 .43513 .11972 .43404 .11853 Mtetra
.535 .718 .957 r
.43404 .11853 .43513 .11972 .43698 .11945 .43589 .11826 Mtetra
.589 .74 .948 r
.43589 .11826 .43698 .11945 .43883 .11904 .43775 .11782 Mtetra
.621 .748 .937 r
.43775 .11782 .43883 .11904 .44069 .11853 .43961 .11727 Mtetra
.63 .744 .93 r
.43961 .11727 .44069 .11853 .44255 .11799 .44147 .11669 Mtetra
.675 .753 .909 r
.44147 .11669 .44255 .11799 .44442 .11725 .44334 .11592 Mtetra
.696 .754 .897 r
.44334 .11592 .44442 .11725 .4463 .11639 .44522 .11503 Mtetra
.697 .75 .892 r
.44522 .11503 .4463 .11639 .44818 .11551 .4471 .11413 Mtetra
.68 .741 .897 r
.4471 .11413 .44818 .11551 .45005 .11471 .44897 .11332 Mtetra
.668 .734 .9 r
.44897 .11332 .45005 .11471 .45192 .11397 .45085 .11257 Mtetra
.663 .731 .9 r
.45085 .11257 .45192 .11397 .4538 .11325 .45273 .11184 Mtetra
.663 .729 .898 r
.45273 .11184 .4538 .11325 .45568 .11253 .4546 .1111 Mtetra
.663 .727 .897 r
.4546 .1111 .45568 .11253 .45756 .1118 .45648 .11037 Mtetra
.662 .726 .897 r
.45648 .11037 .45756 .1118 .45943 .11108 .45836 .10964 Mtetra
.661 .725 .896 r
.45836 .10964 .45943 .11108 .46132 .11036 .46025 .10892 Mtetra
.66 .723 .896 r
.46025 .10892 .46132 .11036 .4632 .10965 .46213 .1082 Mtetra
.659 .722 .896 r
.46213 .1082 .4632 .10965 .46508 .10894 .46401 .10748 Mtetra
.657 .72 .895 r
.46401 .10748 .46508 .10894 .46696 .10823 .4659 .10677 Mtetra
.656 .719 .894 r
.4659 .10677 .46696 .10823 .46885 .10754 .46778 .10606 Mtetra
.656 .717 .893 r
.46778 .10606 .46885 .10754 .47074 .10684 .46967 .10535 Mtetra
.656 .716 .892 r
.46967 .10535 .47074 .10684 .47263 .10614 .47156 .10464 Mtetra
.657 .715 .891 r
.47156 .10464 .47263 .10614 .47452 .10543 .47345 .10393 Mtetra
.657 .714 .89 r
.47345 .10393 .47452 .10543 .47641 .10472 .47534 .10321 Mtetra
.657 .713 .889 r
.47534 .10321 .47641 .10472 .4783 .10401 .47724 .10249 Mtetra
.658 .712 .888 r
.47724 .10249 .4783 .10401 .48019 .10329 .47913 .10177 Mtetra
.658 .711 .887 r
.47913 .10177 .48019 .10329 .48209 .10257 .48103 .10104 Mtetra
.48103 .10104 .48209 .10257 .48398 .10185 .48292 .10032 Mtetra
.659 .711 .886 r
.48292 .10032 .48398 .10185 .48588 .10112 .48482 .09959 Mtetra
.659 .71 .886 r
.48482 .09959 .48588 .10112 .48778 .10039 .48672 .09886 Mtetra
.48672 .09886 .48778 .10039 .48968 .09966 .48863 .09812 Mtetra
.659 .71 .885 r
.48863 .09812 .48968 .09966 .49158 .09893 .49053 .09739 Mtetra
.49053 .09739 .49158 .09893 .49349 .0982 .49243 .09665 Mtetra
.49243 .09665 .49349 .0982 .49539 .09746 .49434 .09592 Mtetra
.49434 .09592 .49539 .09746 .4973 .09672 .49624 .09518 Mtetra
.66 .71 .885 r
.49624 .09518 .4973 .09672 .49921 .09599 .49815 .09444 Mtetra
.49815 .09444 .49921 .09599 .50112 .09525 .50006 .0937 Mtetra
.50006 .0937 .50112 .09525 .50303 .09451 .50197 .09296 Mtetra
.50197 .09296 .50303 .09451 .50494 .09377 .50388 .09222 Mtetra
.66 .709 .885 r
.50388 .09222 .50494 .09377 .50685 .09303 .5058 .09148 Mtetra
.66 .709 .884 r
.5058 .09148 .50685 .09303 .50876 .09229 .50771 .09074 Mtetra
.50771 .09074 .50876 .09229 .51068 .09155 .50963 .08999 Mtetra
.50963 .08999 .51068 .09155 .5126 .0908 .51155 .08925 Mtetra
.51155 .08925 .5126 .0908 .51451 .09006 .51347 .08851 Mtetra
.51347 .08851 .51451 .09006 .51643 .08932 .51539 .08776 Mtetra
.51539 .08776 .51643 .08932 .51835 .08857 .51731 .08701 Mtetra
.51731 .08701 .51835 .08857 .52028 .08783 .51923 .08627 Mtetra
.51923 .08627 .52028 .08783 .5222 .08708 .52115 .08552 Mtetra
.52115 .08552 .5222 .08708 .52412 .08634 .52308 .08478 Mtetra
.52308 .08478 .52412 .08634 .52605 .08559 .52501 .08403 Mtetra
.52501 .08403 .52605 .08559 .52798 .08484 .52694 .08328 Mtetra
.52694 .08328 .52798 .08484 .52991 .0841 .52887 .08253 Mtetra
.52887 .08253 .52991 .0841 .53184 .08335 .5308 .08178 Mtetra
.5308 .08178 .53184 .08335 .53377 .0826 .53273 .08103 Mtetra
.53273 .08103 .53377 .0826 .5357 .08185 .53466 .08028 Mtetra
.53466 .08028 .5357 .08185 .53764 .0811 .5366 .07953 Mtetra
.5366 .07953 .53764 .0811 .53957 .08035 .53853 .07878 Mtetra
.53853 .07878 .53957 .08035 .54151 .0796 .54047 .07803 Mtetra
.54047 .07803 .54151 .0796 .54345 .07885 .54241 .07728 Mtetra
.66 .71 .884 r
.54241 .07728 .54345 .07885 .54539 .07809 .54435 .07652 Mtetra
.54435 .07652 .54539 .07809 .54733 .07734 .54629 .07577 Mtetra
.54629 .07577 .54733 .07734 .54927 .07659 .54824 .07501 Mtetra
.54824 .07501 .54927 .07659 .55121 .07583 .55018 .07426 Mtetra
.55018 .07426 .55121 .07583 .55316 .07508 .55213 .0735 Mtetra
.55213 .0735 .55316 .07508 .55511 .07432 .55407 .07275 Mtetra
.55407 .07275 .55511 .07432 .55705 .07356 .55602 .07199 Mtetra
.55602 .07199 .55705 .07356 .559 .07281 .55797 .07123 Mtetra
.66 .71 .885 r
.55797 .07123 .559 .07281 .56095 .07205 .55992 .07047 Mtetra
.661 .71 .885 r
.55992 .07047 .56095 .07205 .56291 .07129 .56188 .06971 Mtetra
.56188 .06971 .56291 .07129 .56486 .07052 .56383 .06895 Mtetra
.661 .711 .885 r
.56383 .06895 .56486 .07052 .56681 .06976 .56579 .06818 Mtetra
.56579 .06818 .56681 .06976 .56877 .06899 .56774 .06742 Mtetra
.662 .712 .885 r
.56774 .06742 .56877 .06899 .57073 .06822 .5697 .06665 Mtetra
.5697 .06665 .57073 .06822 .57269 .06745 .57166 .06588 Mtetra
.662 .713 .886 r
.57166 .06588 .57269 .06745 .57465 .06667 .57362 .06511 Mtetra
.663 .714 .886 r
.57362 .06511 .57465 .06667 .57661 .0659 .57559 .06433 Mtetra
.663 .715 .886 r
.57559 .06433 .57661 .0659 .57857 .06511 .57755 .06356 Mtetra
.664 .716 .887 r
.57755 .06356 .57857 .06511 .58053 .06433 .57951 .06278 Mtetra
.664 .717 .888 r
.57951 .06278 .58053 .06433 .5825 .06354 .58148 .06199 Mtetra
.665 .719 .889 r
.58148 .06199 .5825 .06354 .58447 .06275 .58345 .06121 Mtetra
.665 .72 .89 r
.58345 .06121 .58447 .06275 .58643 .06195 .58542 .06042 Mtetra
.665 .721 .891 r
.58542 .06042 .58643 .06195 .5884 .06117 .58739 .05964 Mtetra
.663 .722 .892 r
.58739 .05964 .5884 .06117 .59037 .06039 .58936 .05886 Mtetra
.663 .722 .893 r
.58936 .05886 .59037 .06039 .59235 .05961 .59133 .05809 Mtetra
.662 .722 .894 r
.59133 .05809 .59235 .05961 .59432 .05884 .59331 .05732 Mtetra
.661 .722 .894 r
.59331 .05732 .59432 .05884 .5963 .05808 .59528 .05656 Mtetra
.661 .721 .894 r
.59528 .05656 .5963 .05808 .59827 .05732 .59726 .05579 Mtetra
.66 .72 .894 r
.59726 .05579 .59827 .05732 .60025 .05657 .59924 .05503 Mtetra
.659 .719 .893 r
.59924 .05503 .60025 .05657 .60223 .05582 .60122 .05428 Mtetra
.658 .718 .892 r
.60122 .05428 .60223 .05582 .60421 .05508 .6032 .05352 Mtetra
.659 .717 .891 r
.6032 .05352 .60421 .05508 .6062 .05433 .60519 .05276 Mtetra
.66 .716 .89 r
.60519 .05276 .6062 .05433 .60818 .05357 .60717 .052 Mtetra
.661 .715 .889 r
.60717 .052 .60818 .05357 .61017 .0528 .60916 .05123 Mtetra
.663 .715 .887 r
.60916 .05123 .61017 .0528 .61215 .05203 .61115 .05044 Mtetra
.665 .715 .886 r
.61115 .05044 .61215 .05203 .61414 .05124 .61313 .04964 Mtetra
.665 .714 .885 r
.61313 .04964 .61414 .05124 .61613 .05044 .61512 .04884 Mtetra
.68 .72 .879 r
.61512 .04884 .61613 .05044 .61812 .0496 .61711 .04797 Mtetra
.712 .728 .862 r
.61711 .04797 .61812 .0496 .62011 .04863 .6191 .04689 Mtetra
.655 .687 .868 r
.6191 .04689 .62011 .04863 .6221 .04784 .62109 .04612 Mtetra
.463 .594 .897 r
.62109 .04612 .6221 .04784 .62411 .04749 .62311 .04618 Mtetra
0 0 .434 r
.62311 .04618 .62411 .04749 .62616 .04823 .62524 .04895 Mtetra
.974 .663 .333 r
.62524 .04895 .62616 .04823 .62824 .04975 .63448 .25115 Mtetra
.528 .28 .482 r
.63448 .25115 .62824 .04975 .63035 .05181 .6372 .26627 Mtetra
.499 .258 .48 r
.6372 .26627 .63035 .05181 .63237 .05163 .63939 .2664 Mtetra
.496 .256 .48 r
.63939 .2664 .63237 .05163 .63437 .05046 .64154 .26528 Mtetra
.495 .255 .479 r
.64154 .26528 .63437 .05046 .63635 .04904 .64367 .26369 Mtetra
.497 .256 .48 r
.64367 .26369 .63635 .04904 .63836 .04821 .64584 .2629 Mtetra
.64584 .2629 .63836 .04821 .64037 .04739 .648 .26212 Mtetra
.648 .26212 .64037 .04739 .64238 .0466 .65017 .26135 Mtetra
.65017 .26135 .64238 .0466 .6444 .04584 .65234 .26063 Mtetra
.65234 .26063 .6444 .04584 .64641 .04511 .65452 .25993 Mtetra
.65452 .25993 .64641 .04511 .64843 .04439 .6567 .25924 Mtetra
.6567 .25924 .64843 .04439 .65045 .04365 .65887 .25853 Mtetra
.65887 .25853 .65045 .04365 .65248 .04292 .66105 .25782 Mtetra
.66105 .25782 .65248 .04292 .6545 .0422 .66323 .25711 Mtetra
.66323 .25711 .6545 .0422 .65652 .04147 .66542 .25639 Mtetra
.66542 .25639 .65652 .04147 .65855 .04074 .6676 .25567 Mtetra
.6676 .25567 .65855 .04074 .66058 .04001 .66979 .25495 Mtetra
.66979 .25495 .66058 .04001 .66261 .03928 .67197 .25422 Mtetra
.67197 .25422 .66261 .03928 .66464 .03854 .67416 .25348 Mtetra
.67416 .25348 .66464 .03854 .66667 .03778 .67635 .25273 Mtetra
.67635 .25273 .66667 .03778 .66871 .03702 .67854 .25198 Mtetra
.67854 .25198 .66871 .03702 .67074 .03623 .68074 .25121 Mtetra
.68074 .25121 .67074 .03623 .67277 .03542 .68293 .25042 Mtetra
.68293 .25042 .67277 .03542 .67481 .03457 .68512 .24962 Mtetra
.68512 .24962 .67481 .03457 .67684 .0337 .68732 .24879 Mtetra
.68732 .24879 .67684 .0337 .67887 .03278 .68951 .24793 Mtetra
.68951 .24793 .67887 .03278 .6809 .0318 .69171 .24703 Mtetra
.69171 .24703 .6809 .0318 .68293 .0308 .6939 .24609 Mtetra
.6939 .24609 .68293 .0308 .68496 .02975 .69609 .2451 Mtetra
.496 .255 .48 r
.69609 .2451 .68496 .02975 .68694 .0279 .69825 .24355 Mtetra
.496 .256 .48 r
.69825 .24355 .68694 .0279 .68897 .02678 .70043 .24233 Mtetra
.498 .257 .48 r
.70043 .24233 .68897 .02678 .69107 .0269 .70266 .24196 Mtetra
.502 .26 .48 r
.70266 .24196 .69107 .0269 .70521 .23085 .70503 .24376 Mtetra
.525 .232 .413 r
.70503 .24376 .70521 .23085 .70826 .24421 .70736 .24501 Mtetra
.428 0 0 r
.70736 .24501 .70826 .24421 .71069 .24709 .70966 .24564 Mtetra
.678 .768 .919 r
.00958 .48695 .01093 .48804 .01261 .4876 .01131 .48622 Mtetra
.668 .719 .886 r
.01131 .48622 .01261 .4876 .01433 .48691 .01304 .48552 Mtetra
.659 .713 .888 r
.01304 .48552 .01433 .48691 .01607 .48614 .01476 .48485 Mtetra
.625 .722 .916 r
.01476 .48485 .01607 .48614 .01772 .48598 .01646 .48434 Mtetra
.615 .663 .873 r
.01646 .48434 .01772 .48598 .01938 .4857 .01815 .48387 Mtetra
.614 .637 .85 r
.01815 .48387 .01938 .4857 .0211 .48509 .01985 .48339 Mtetra
.494 .602 .89 r
.01985 .48339 .0211 .48509 .02294 .48364 .02148 .48335 Mtetra
.491 .866 .98 r
.02148 .48335 .02294 .48364 .02492 .4813 .02317 .4829 Mtetra
0 0 0 r
.02317 .4829 .02492 .4813 .0272 .47696 .02499 .48162 Mtetra
.837 .868 .422 r
.02499 .48162 .0272 .47696 .05949 .27301 .02759 .47523 Mtetra
0 0 0 r
.02759 .47523 .05949 .27301 .06212 .26564 .0604 .26777 Mtetra
.984 .906 .615 r
.0604 .26777 .06212 .26564 .06411 .26251 .06277 .2621 Mtetra
.812 .892 .901 r
.06277 .2621 .06411 .26251 .0658 .2614 .0645 .26077 Mtetra
.614 .838 .985 r
.0645 .26077 .0658 .2614 .06741 .26085 .0661 .26025 Mtetra
.414 .773 .995 r
.0661 .26025 .06741 .26085 .06898 .26059 .06765 .26009 Mtetra
.641 .873 .984 r
.06765 .26009 .06898 .26059 .07057 .26016 .06927 .25947 Mtetra
.678 .839 .961 r
.06927 .25947 .07057 .26016 .07217 .25971 .0709 .25877 Mtetra
.681 .789 .931 r
.0709 .25877 .07217 .25971 .07377 .25922 .07254 .25808 Mtetra
.673 .749 .908 r
.07254 .25808 .07377 .25922 .07543 .25834 .07417 .25741 Mtetra
.67 .788 .937 r
.07417 .25741 .07543 .25834 .07709 .2575 .0758 .25676 Mtetra
.659 .826 .963 r
.0758 .25676 .07709 .2575 .07871 .25689 .07743 .25613 Mtetra
.748 .832 .916 r
.07743 .25613 .07871 .25689 .08024 .25695 .07911 .25514 Mtetra
.662 .645 .823 r
.07911 .25514 .08024 .25695 .08167 .25771 .08075 .25441 Mtetra
.53 .456 .718 r
.08075 .25441 .08167 .25771 .08289 .25993 .0823 .25432 Mtetra
0 0 .46 r
.0823 .25432 .08289 .25993 .05579 .46038 .08335 .25778 Mtetra
0 0 0 r
.08335 .25778 .05579 .46038 .05602 .4703 .05542 .4641 Mtetra
0 0 .105 r
.05542 .4641 .05602 .4703 .0573 .47292 .05613 .47069 Mtetra
.272 .409 .818 r
.05613 .47069 .0573 .47292 .05892 .4732 .05769 .47138 Mtetra
.614 .64 .852 r
.05769 .47138 .05892 .4732 .06065 .47263 .05942 .47089 Mtetra
.695 .679 .831 r
.05942 .47089 .06065 .47263 .06247 .47152 .06121 .46993 Mtetra
.662 .69 .865 r
.06121 .46993 .06247 .47152 .06438 .46969 .06297 .46922 Mtetra
.633 .884 .987 r
.06297 .46922 .06438 .46969 .06639 .46722 .06472 .46854 Mtetra
.023 0 0 r
.06472 .46854 .06639 .46722 .06848 .46412 .06648 .46785 Mtetra
.421 .058 .239 r
.06648 .46785 .06848 .46412 .07026 .46325 .06817 .46765 Mtetra
.408 .061 .262 r
.06817 .46765 .07026 .46325 .07195 .46304 .06989 .46725 Mtetra
.291 0 .194 r
.06989 .46725 .07195 .46304 .07376 .46198 .07171 .46618 Mtetra
0 0 0 r
.07171 .46618 .07376 .46198 .07761 .44607 .07401 .46158 Mtetra
.959 .709 .514 r
.07401 .46158 .07761 .44607 .10599 .25007 .10402 .25437 Mtetra
.965 .882 .494 r
.10402 .25437 .10599 .25007 .1081 .24602 .10674 .24585 Mtetra
.886 .909 .837 r
.10674 .24585 .1081 .24602 .10984 .24466 .10858 .24385 Mtetra
.693 .821 .944 r
.10858 .24385 .10984 .24466 .11147 .24417 .11024 .2431 Mtetra
.562 .732 .955 r
.11024 .2431 .11147 .24417 .11305 .24401 .11184 .2428 Mtetra
.626 .724 .918 r
.11184 .2428 .11305 .24401 .11467 .24359 .11348 .2423 Mtetra
.642 .717 .902 r
.11348 .2423 .11467 .24359 .11632 .24302 .11512 .24175 Mtetra
.636 .716 .905 r
.11512 .24175 .11632 .24302 .11796 .24241 .11676 .24121 Mtetra
.641 .732 .915 r
.11676 .24121 .11796 .24241 .11963 .24172 .1184 .24066 Mtetra
.644 .761 .934 r
.1184 .24066 .11963 .24172 .12129 .24098 .12004 .2401 Mtetra
.64 .795 .957 r
.12004 .2401 .12129 .24098 .12296 .24026 .12169 .23954 Mtetra
.63 .827 .976 r
.12169 .23954 .12296 .24026 .12462 .23961 .12333 .23898 Mtetra
.623 .845 .984 r
.12333 .23898 .12462 .23961 .12627 .23902 .12498 .23842 Mtetra
.621 .851 .986 r
.12498 .23842 .12627 .23902 .12791 .23848 .12663 .23785 Mtetra
.623 .848 .985 r
.12663 .23785 .12791 .23848 .12955 .23801 .12828 .23729 Mtetra
.637 .83 .975 r
.12828 .23729 .12955 .23801 .13118 .23758 .12994 .23671 Mtetra
.653 .802 .954 r
.12994 .23671 .13118 .23758 .13282 .23713 .13159 .2361 Mtetra
.673 .774 .926 r
.13159 .2361 .13282 .23713 .13448 .23654 .13326 .23542 Mtetra
.683 .761 .91 r
.13326 .23542 .13448 .23654 .13615 .23584 .13494 .2347 Mtetra
.687 .757 .905 r
.13494 .2347 .13615 .23584 .13783 .23509 .13662 .23395 Mtetra
.756 .768 .863 r
.13662 .23395 .13783 .23509 .13956 .23395 .13835 .23279 Mtetra
.738 .765 .874 r
.13835 .23279 .13956 .23395 .14127 .23292 .14007 .23175 Mtetra
.596 .727 .935 r
.14007 .23175 .14127 .23292 .14291 .23252 .14171 .23136 Mtetra
.831 .37 0 r
.14171 .23136 .14291 .23252 .14418 .23507 .14298 .23391 Mtetra
.948 .684 .504 r
.14298 .23391 .14418 .23507 .1202 .44134 .11889 .44028 Mtetra
.944 .611 .364 r
.11889 .44028 .1202 .44134 .12089 .44956 .11958 .44842 Mtetra
.531 .008 0 r
.11958 .44842 .12089 .44956 .12241 .45107 .12111 .4499 Mtetra
.558 .729 .954 r
.12111 .4499 .12241 .45107 .12416 .45077 .12286 .44958 Mtetra
.776 .777 .854 r
.12286 .44958 .12416 .45077 .12604 .44934 .12474 .44818 Mtetra
.897 .761 .702 r
.12474 .44818 .12604 .44934 .12831 .44473 .12695 .44414 Mtetra
.948 .69 .511 r
.12695 .44414 .12831 .44473 .1554 .23477 .15358 .23866 Mtetra
.999 .841 .517 r
.15358 .23866 .1554 .23477 .15797 .22674 .15662 .22682 Mtetra
.924 .924 .791 r
.15662 .22682 .15797 .22674 .15983 .22461 .15853 .22429 Mtetra
.69 .923 .97 r
.15853 .22429 .15983 .22461 .16149 .2241 .16023 .22344 Mtetra
.537 .816 .997 r
.16023 .22344 .16149 .2241 .1631 .2241 .16188 .22307 Mtetra
.688 .781 .922 r
.16188 .22307 .1631 .2241 .16477 .22354 .16357 .22232 Mtetra
.712 .752 .884 r
.16357 .22232 .16477 .22354 .16648 .22264 .16529 .22143 Mtetra
.583 .716 .934 r
.16529 .22143 .16648 .22264 .16813 .22226 .16694 .22107 Mtetra
.677 .179 0 r
.16694 .22107 .16813 .22226 .1695 .22435 .16833 .22294 Mtetra
.951 .685 .497 r
.16833 .22294 .1695 .22435 .14733 .42913 .14694 .42025 Mtetra
.954 .715 .259 r
.14694 .42025 .14733 .42913 .1478 .44 .14662 .43787 Mtetra
0 .054 .619 r
.14662 .43787 .1478 .44 .14937 .44143 .14815 .43964 Mtetra
.59 .64 .868 r
.14815 .43964 .14937 .44143 .15118 .44075 .14992 .43924 Mtetra
.708 .722 .861 r
.14992 .43924 .15118 .44075 .15306 .43944 .15177 .43826 Mtetra
.711 .773 .901 r
.15177 .43826 .15306 .43944 .15493 .43831 .15361 .43732 Mtetra
.667 .8 .946 r
.15361 .43732 .15493 .43831 .15675 .43757 .15543 .4366 Mtetra
.668 .804 .948 r
.15543 .4366 .15675 .43757 .15856 .43688 .15725 .43588 Mtetra
.651 .794 .951 r
.15725 .43588 .15856 .43688 .16036 .43635 .15907 .43522 Mtetra
.636 .765 .941 r
.15907 .43522 .16036 .43635 .16215 .43588 .16088 .43463 Mtetra
.633 .742 .927 r
.16088 .43463 .16215 .43588 .16397 .43522 .16268 .43406 Mtetra
.637 .759 .936 r
.16268 .43406 .16397 .43522 .16587 .43385 .1645 .43346 Mtetra
.575 .89 .989 r
.1645 .43346 .16587 .43385 .16787 .43156 .16631 .43285 Mtetra
.079 0 0 r
.16631 .43285 .16787 .43156 .16993 .42866 .16813 .43224 Mtetra
.355 0 .195 r
.16813 .43224 .16993 .42866 .17193 .42635 .16994 .43165 Mtetra
.408 .079 .292 r
.16994 .43165 .17193 .42635 .17374 .4257 .17175 .4311 Mtetra
.41 .082 .295 r
.17175 .4311 .17374 .4257 .1755 .42564 .17356 .43054 Mtetra
.397 .061 .275 r
.17356 .43054 .1755 .42564 .17728 .42542 .17538 .42996 Mtetra
.384 .041 .255 r
.17538 .42996 .17728 .42542 .17909 .42488 .1772 .42935 Mtetra
.38 .036 .251 r
.1772 .42935 .17909 .42488 .1809 .42432 .17903 .42872 Mtetra
.378 .032 .247 r
.17903 .42872 .1809 .42432 .18272 .42375 .18085 .4281 Mtetra
.377 .03 .244 r
.18085 .4281 .18272 .42375 .18454 .42316 .18268 .42747 Mtetra
.376 .028 .242 r
.18268 .42747 .18454 .42316 .18636 .42257 .18451 .42684 Mtetra
.376 .028 .241 r
.18451 .42684 .18636 .42257 .18818 .42199 .18634 .42623 Mtetra
.376 .027 .239 r
.18634 .42623 .18818 .42199 .19 .42142 .18817 .42562 Mtetra
.374 .024 .236 r
.18817 .42562 .19 .42142 .19182 .42084 .19 .42501 Mtetra
.406 .053 .25 r
.19 .42501 .19182 .42084 .19361 .42069 .19181 .42463 Mtetra
.417 .058 .245 r
.19181 .42463 .19361 .42069 .19537 .42071 .19361 .42436 Mtetra
.318 0 .18 r
.19361 .42436 .19537 .42071 .19723 .41979 .19546 .42355 Mtetra
0 0 0 r
.19546 .42355 .19723 .41979 .1995 .41485 .19752 .42077 Mtetra
.945 .842 .407 r
.19752 .42077 .1995 .41485 .22198 .20769 .20051 .40865 Mtetra
0 0 .065 r
.20051 .40865 .22198 .20769 .22421 .20191 .22288 .20233 Mtetra
.962 .919 .718 r
.22288 .20233 .22421 .20191 .22611 .19949 .22488 .19884 Mtetra
.737 .872 .943 r
.22488 .19884 .22611 .19949 .22786 .19861 .22664 .19787 Mtetra
.562 .81 .992 r
.22664 .19787 .22786 .19861 .22956 .19813 .22834 .19746 Mtetra
.524 .813 .998 r
.22834 .19746 .22956 .19813 .23127 .19768 .23003 .1971 Mtetra
.639 .871 .985 r
.23003 .1971 .23127 .19768 .233 .19701 .23176 .19645 Mtetra
.635 .872 .986 r
.23176 .19645 .233 .19701 .23472 .19634 .23349 .19579 Mtetra
.636 .875 .986 r
.23349 .19579 .23472 .19634 .23645 .19568 .23522 .19514 Mtetra
.639 .878 .985 r
.23522 .19514 .23645 .19568 .23818 .19501 .23695 .19447 Mtetra
.23695 .19447 .23818 .19501 .23992 .19433 .23868 .1938 Mtetra
.638 .879 .986 r
.23868 .1938 .23992 .19433 .24165 .19366 .24042 .19313 Mtetra
.637 .879 .986 r
.24042 .19313 .24165 .19366 .24338 .19299 .24215 .19246 Mtetra
.635 .879 .987 r
.24215 .19246 .24338 .19299 .24512 .19233 .24389 .1918 Mtetra
.628 .878 .988 r
.24389 .1918 .24512 .19233 .24685 .19166 .24562 .19115 Mtetra
.618 .878 .99 r
.24562 .19115 .24685 .19166 .24859 .191 .24736 .19052 Mtetra
.617 .885 .989 r
.24736 .19052 .24859 .191 .25033 .19036 .2491 .18988 Mtetra
.636 .89 .986 r
.2491 .18988 .25033 .19036 .25206 .18978 .25084 .1892 Mtetra
.672 .878 .975 r
.25084 .1892 .25206 .18978 .25378 .18928 .25259 .18844 Mtetra
.685 .826 .951 r
.25259 .18844 .25378 .18928 .25551 .18879 .25434 .18767 Mtetra
.677 .769 .92 r
.25434 .18767 .25551 .18879 .25724 .18826 .25609 .18694 Mtetra
.659 .728 .9 r
.25609 .18694 .25724 .18826 .25898 .18764 .25783 .18628 Mtetra
.655 .72 .897 r
.25783 .18628 .25898 .18764 .26073 .18695 .25958 .18563 Mtetra
.657 .727 .901 r
.25958 .18563 .26073 .18695 .26248 .1862 .26132 .18498 Mtetra
.665 .748 .912 r
.26132 .18498 .26248 .1862 .26425 .18537 .26307 .1843 Mtetra
.667 .777 .932 r
.26307 .1843 .26425 .18537 .26601 .18452 .26483 .18361 Mtetra
.667 .808 .951 r
.26483 .18361 .26601 .18452 .26777 .18372 .26658 .18291 Mtetra
.663 .831 .964 r
.26658 .18291 .26777 .18372 .26953 .183 .26833 .18222 Mtetra
.662 .836 .967 r
.26833 .18222 .26953 .183 .27128 .18231 .27009 .18153 Mtetra
.661 .837 .967 r
.27009 .18153 .27128 .18231 .27304 .18162 .27184 .18084 Mtetra
.66 .836 .967 r
.27184 .18084 .27304 .18162 .27479 .18092 .2736 .18015 Mtetra
.66 .838 .969 r
.2736 .18015 .27479 .18092 .27655 .18022 .27536 .17946 Mtetra
.66 .84 .969 r
.27536 .17946 .27655 .18022 .27831 .17949 .27712 .17877 Mtetra
.66 .849 .972 r
.27712 .17877 .27831 .17949 .28008 .17866 .27888 .17807 Mtetra
.649 .873 .982 r
.27888 .17807 .28008 .17866 .28184 .17799 .28064 .17737 Mtetra
.647 .869 .982 r
.28064 .17737 .28184 .17799 .28357 .17771 .2824 .17668 Mtetra
.66 .787 .942 r
.2824 .17668 .28357 .17771 .28523 .17837 .28417 .17602 Mtetra
.629 .586 .787 r
.28417 .17602 .28523 .17837 .28684 .17962 .28593 .17536 Mtetra
.597 .467 .674 r
.28593 .17536 .28684 .17962 .28845 .18094 .2877 .17459 Mtetra
.591 .42 .619 r
.2877 .17459 .28845 .18094 .29025 .17987 .2895 .17349 Mtetra
.564 .4 .618 r
.2895 .17349 .29025 .17987 .29203 .17904 .29127 .17281 Mtetra
.475 .338 .615 r
.29127 .17281 .29203 .17904 .29365 .18034 .29295 .17326 Mtetra
0 0 .36 r
.29295 .17326 .29365 .18034 .27958 .38697 .29419 .17945 Mtetra
0 0 .141 r
.29419 .17945 .27958 .38697 .28094 .39329 .2799 .38945 Mtetra
0 0 .42 r
.2799 .38945 .28094 .39329 .28263 .39533 .28146 .39328 Mtetra
.525 .583 .855 r
.28146 .39328 .28263 .39533 .28449 .3952 .28332 .39316 Mtetra
.662 .648 .826 r
.28332 .39316 .28449 .3952 .28639 .39456 .28523 .39232 Mtetra
.686 .638 .796 r
.28523 .39232 .28639 .39456 .28831 .39371 .28717 .39123 Mtetra
.604 .578 .798 r
.28717 .39123 .28831 .39371 .29021 .39308 .28906 .3907 Mtetra
.608 .589 .806 r
.28906 .3907 .29021 .39308 .29213 .39226 .29096 .39015 Mtetra
.609 .617 .834 r
.29096 .39015 .29213 .39226 .29407 .39113 .29286 .38962 Mtetra
.542 .672 .922 r
.29286 .38962 .29407 .39113 .29605 .38945 .29474 .38938 Mtetra
.5 .9 .93 r
.29474 .38938 .29605 .38945 .29809 .38698 .29665 .38867 Mtetra
0 0 0 r
.29665 .38867 .29809 .38698 .30027 .38245 .29864 .38692 Mtetra
.732 .774 .278 r
.29864 .38692 .30027 .38245 .31663 .17377 .30098 .38003 Mtetra
0 0 .135 r
.30098 .38003 .31663 .17377 .3189 .16612 .31755 .16804 Mtetra
.955 .906 .532 r
.31755 .16804 .3189 .16612 .32085 .16305 .31967 .1625 Mtetra
.801 .904 .913 r
.31967 .1625 .32085 .16305 .32266 .16214 .3215 .16116 Mtetra
.65 .796 .953 r
.3215 .16116 .32266 .16214 .32442 .16173 .32329 .16052 Mtetra
.56 .716 .946 r
.32329 .16052 .32442 .16173 .32618 .16155 .32505 .1602 Mtetra
.654 .727 .903 r
.32505 .1602 .32618 .16155 .32797 .16092 .32684 .15954 Mtetra
.649 .719 .899 r
.32684 .15954 .32797 .16092 .32976 .16024 .32863 .1589 Mtetra
.653 .728 .904 r
.32863 .1589 .32976 .16024 .33156 .15948 .33043 .15825 Mtetra
.676 .756 .911 r
.33043 .15825 .33156 .15948 .33338 .15842 .33223 .15749 Mtetra
.681 .816 .948 r
.33223 .15749 .33338 .15842 .33519 .1575 .33403 .15673 Mtetra
.681 .849 .963 r
.33403 .15673 .33519 .1575 .33698 .15687 .33583 .15595 Mtetra
.765 .833 .904 r
.33583 .15595 .33698 .15687 .33873 .15697 .33766 .15477 Mtetra
.65 .612 .798 r
.33766 .15477 .33873 .15697 .34043 .15782 .33947 .15399 Mtetra
.515 .43 .698 r
.33947 .15399 .34043 .15782 .34204 .16034 .34122 .154 Mtetra
0 0 .458 r
.34122 .154 .34204 .16034 .33131 .36611 .34269 .1588 Mtetra
0 0 .17 r
.34269 .1588 .33131 .36611 .33271 .37417 .33166 .37021 Mtetra
0 0 .288 r
.33166 .37021 .33271 .37417 .33446 .37655 .33325 .37523 Mtetra
.423 .652 .954 r
.33325 .37523 .33446 .37655 .33635 .37668 .33515 .37527 Mtetra
.667 .739 .904 r
.33515 .37527 .33635 .37668 .33829 .37612 .3371 .37449 Mtetra
.73 .727 .848 r
.3371 .37449 .33829 .37612 .34025 .37499 .33907 .37328 Mtetra
.543 .641 .897 r
.33907 .37328 .34025 .37499 .34225 .37341 .34098 .37305 Mtetra
.546 .891 .982 r
.34098 .37305 .34225 .37341 .34429 .371 .34293 .37241 Mtetra
0 0 0 r
.34293 .37241 .34429 .371 .34643 .36677 .34491 .37097 Mtetra
.677 .745 .246 r
.34491 .37097 .34643 .36677 .35988 .15815 .34718 .36462 Mtetra
0 0 .164 r
.34718 .36462 .35988 .15815 .36214 .14957 .36082 .15186 Mtetra
.939 .885 .477 r
.36082 .15186 .36214 .14957 .3641 .14622 .36294 .14564 Mtetra
.83 .905 .891 r
.36294 .14564 .3641 .14622 .36593 .14514 .3648 .1441 Mtetra
.676 .796 .938 r
.3648 .1441 .36593 .14514 .36774 .14463 .36663 .14334 Mtetra
.58 .713 .934 r
.36663 .14334 .36774 .14463 .36953 .1444 .36843 .14296 Mtetra
.736 .741 .856 r
.36843 .14296 .36953 .1444 .37138 .14328 .37027 .14182 Mtetra
.684 .721 .878 r
.37027 .14182 .37138 .14328 .37321 .14244 .3721 .14098 Mtetra
.515 .654 .921 r
.3721 .14098 .37321 .14244 .375 .14229 .3739 .14084 Mtetra
.831 .401 0 r
.3739 .14084 .375 .14229 .37658 .14655 .3755 .14461 Mtetra
.969 .684 .435 r
.3755 .14461 .37658 .14655 .36789 .35901 .36676 .35637 Mtetra
.868 .51 .012 r
.36676 .35637 .36789 .35901 .36954 .3645 .36837 .36265 Mtetra
.201 .431 .859 r
.36837 .36265 .36954 .3645 .37145 .36497 .37026 .36345 Mtetra
.624 .71 .908 r
.37026 .36345 .37145 .36497 .37342 .36419 .37222 .36287 Mtetra
.807 .79 .836 r
.37222 .36287 .37342 .36419 .37544 .36245 .37424 .36111 Mtetra
.936 .764 .643 r
.37424 .36111 .37544 .36245 .37754 .35891 .37645 .35538 Mtetra
.967 .687 .448 r
.37645 .35538 .37754 .35891 .37986 .35051 .38821 .14209 Mtetra
.516 .277 .491 r
.38821 .14209 .37986 .35051 .3912 .14188 .39034 .13515 Mtetra
.618 .435 .612 r
.39034 .13515 .3912 .14188 .39319 .13774 .39222 .13346 Mtetra
.587 .462 .677 r
.39222 .13346 .39319 .13774 .39509 .13552 .39405 .13278 Mtetra
.558 .52 .769 r
.39405 .13278 .39509 .13552 .39697 .13401 .39587 .13251 Mtetra
.644 .703 .89 r
.39587 .13251 .39697 .13401 .39882 .13306 .39771 .13187 Mtetra
.663 .766 .927 r
.39771 .13187 .39882 .13306 .40066 .13237 .39955 .13116 Mtetra
.659 .762 .926 r
.39955 .13116 .40066 .13237 .40249 .13178 .40139 .13047 Mtetra
.732 .765 .88 r
.40139 .13047 .40249 .13178 .40436 .13049 .40325 .1294 Mtetra
.694 .794 .927 r
.40325 .1294 .40436 .13049 .40622 .1294 .4051 .12855 Mtetra
.461 .757 .994 r
.4051 .12855 .40622 .1294 .40805 .129 .40693 .12836 Mtetra
.843 .378 .015 r
.40693 .12836 .40805 .129 .40975 .13216 .40862 .13175 Mtetra
.97 .681 .425 r
.40862 .13175 .40975 .13216 .40343 .34449 .40224 .34329 Mtetra
.923 .534 .166 r
.40224 .34329 .40343 .34449 .40511 .35175 .40395 .34999 Mtetra
.239 .47 .88 r
.40395 .34999 .40511 .35175 .40705 .35232 .40588 .35067 Mtetra
.632 .693 .889 r
.40588 .35067 .40705 .35232 .40905 .35152 .40787 .35003 Mtetra
.724 .752 .874 r
.40787 .35003 .40905 .35152 .41106 .35021 .40988 .34889 Mtetra
.583 .731 .944 r
.40988 .34889 .41106 .35021 .41304 .34995 .41187 .34845 Mtetra
.616 .713 .915 r
.41187 .34845 .41304 .34995 .41502 .34966 .41386 .34789 Mtetra
.73 .716 .838 r
.41386 .34789 .41502 .34966 .41703 .34864 .41588 .34662 Mtetra
.9 .728 .66 r
.41588 .34662 .41703 .34864 .41916 .34391 .41802 .3417 Mtetra
.971 .687 .433 r
.41802 .3417 .41916 .34391 .42814 .1301 .42705 .12869 Mtetra
.953 .742 .58 r
.42705 .12869 .42814 .1301 .43027 .12137 .42916 .12052 Mtetra
.869 .857 .827 r
.42916 .12052 .43027 .12137 .43217 .11928 .43107 .11847 Mtetra
.663 .847 .971 r
.43107 .11847 .43217 .11928 .43404 .11853 .43294 .11772 Mtetra
.499 .786 .996 r
.43294 .11772 .43404 .11853 .43589 .11826 .43479 .11742 Mtetra
.613 .825 .981 r
.43479 .11742 .43589 .11826 .43775 .11782 .43665 .11684 Mtetra
.663 .81 .954 r
.43665 .11684 .43775 .11782 .43961 .11727 .43852 .11611 Mtetra
.661 .773 .933 r
.43852 .11611 .43961 .11727 .44147 .11669 .44039 .1154 Mtetra
.646 .744 .921 r
.44039 .1154 .44147 .11669 .44334 .11592 .44226 .11475 Mtetra
.638 .766 .94 r
.44226 .11475 .44334 .11592 .44522 .11503 .44413 .11413 Mtetra
.632 .819 .972 r
.44413 .11413 .44522 .11503 .4471 .11413 .446 .1135 Mtetra
.633 .876 .987 r
.446 .1135 .4471 .11413 .44897 .11332 .44787 .11279 Mtetra
.637 .898 .985 r
.44787 .11279 .44897 .11332 .45085 .11257 .44975 .11203 Mtetra
.643 .898 .984 r
.44975 .11203 .45085 .11257 .45273 .11184 .45163 .11126 Mtetra
.642 .89 .985 r
.45163 .11126 .45273 .11184 .4546 .1111 .45351 .1105 Mtetra
.639 .885 .986 r
.45351 .1105 .4546 .1111 .45648 .11037 .45539 .10976 Mtetra
.638 .884 .986 r
.45539 .10976 .45648 .11037 .45836 .10964 .45727 .10903 Mtetra
.636 .882 .986 r
.45727 .10903 .45836 .10964 .46025 .10892 .45916 .1083 Mtetra
.635 .881 .986 r
.45916 .1083 .46025 .10892 .46213 .1082 .46104 .10757 Mtetra
.634 .88 .987 r
.46104 .10757 .46213 .1082 .46401 .10748 .46292 .10685 Mtetra
.634 .879 .987 r
.46292 .10685 .46401 .10748 .4659 .10677 .46481 .10613 Mtetra
.634 .878 .987 r
.46481 .10613 .4659 .10677 .46778 .10606 .4667 .10542 Mtetra
.634 .876 .986 r
.4667 .10542 .46778 .10606 .46967 .10535 .46859 .1047 Mtetra
.635 .875 .986 r
.46859 .1047 .46967 .10535 .47156 .10464 .47048 .10398 Mtetra
.636 .874 .986 r
.47048 .10398 .47156 .10464 .47345 .10393 .47237 .10326 Mtetra
.637 .874 .986 r
.47237 .10326 .47345 .10393 .47534 .10321 .47426 .10254 Mtetra
.638 .873 .985 r
.47426 .10254 .47534 .10321 .47724 .10249 .47616 .10182 Mtetra
.639 .873 .985 r
.47616 .10182 .47724 .10249 .47913 .10177 .47805 .10109 Mtetra
.64 .873 .985 r
.47805 .10109 .47913 .10177 .48103 .10104 .47995 .10037 Mtetra
.47995 .10037 .48103 .10104 .48292 .10032 .48185 .09964 Mtetra
.641 .873 .984 r
.48185 .09964 .48292 .10032 .48482 .09959 .48375 .09891 Mtetra
.48375 .09891 .48482 .09959 .48672 .09886 .48565 .09817 Mtetra
.642 .873 .984 r
.48565 .09817 .48672 .09886 .48863 .09812 .48756 .09744 Mtetra
.48756 .09744 .48863 .09812 .49053 .09739 .48946 .0967 Mtetra
.48946 .0967 .49053 .09739 .49243 .09665 .49136 .09597 Mtetra
.643 .873 .984 r
.49136 .09597 .49243 .09665 .49434 .09592 .49327 .09523 Mtetra
.49327 .09523 .49434 .09592 .49624 .09518 .49518 .09449 Mtetra
.49518 .09449 .49624 .09518 .49815 .09444 .49709 .09375 Mtetra
.49709 .09375 .49815 .09444 .50006 .0937 .499 .09301 Mtetra
.499 .09301 .50006 .0937 .50197 .09296 .50091 .09227 Mtetra
.50091 .09227 .50197 .09296 .50388 .09222 .50283 .09153 Mtetra
.50283 .09153 .50388 .09222 .5058 .09148 .50474 .09079 Mtetra
.50474 .09079 .5058 .09148 .50771 .09074 .50666 .09004 Mtetra
.50666 .09004 .50771 .09074 .50963 .08999 .50857 .0893 Mtetra
.50857 .0893 .50963 .08999 .51155 .08925 .51049 .08855 Mtetra
.51049 .08855 .51155 .08925 .51347 .08851 .51241 .08781 Mtetra
.51241 .08781 .51347 .08851 .51539 .08776 .51433 .08706 Mtetra
.51433 .08706 .51539 .08776 .51731 .08701 .51626 .08632 Mtetra
.51626 .08632 .51731 .08701 .51923 .08627 .51818 .08557 Mtetra
.51818 .08557 .51923 .08627 .52115 .08552 .52011 .08482 Mtetra
.52011 .08482 .52115 .08552 .52308 .08478 .52203 .08408 Mtetra
.52203 .08408 .52308 .08478 .52501 .08403 .52396 .08333 Mtetra
.52396 .08333 .52501 .08403 .52694 .08328 .52589 .08258 Mtetra
.52589 .08258 .52694 .08328 .52887 .08253 .52782 .08183 Mtetra
.644 .873 .984 r
.52782 .08183 .52887 .08253 .5308 .08178 .52976 .08108 Mtetra
.52976 .08108 .5308 .08178 .53273 .08103 .53169 .08033 Mtetra
.53169 .08033 .53273 .08103 .53466 .08028 .53362 .07958 Mtetra
.53362 .07958 .53466 .08028 .5366 .07953 .53556 .07882 Mtetra
.53556 .07882 .5366 .07953 .53853 .07878 .5375 .07807 Mtetra
.5375 .07807 .53853 .07878 .54047 .07803 .53944 .07732 Mtetra
.53944 .07732 .54047 .07803 .54241 .07728 .54138 .07657 Mtetra
.54138 .07657 .54241 .07728 .54435 .07652 .54332 .07581 Mtetra
.54332 .07581 .54435 .07652 .54629 .07577 .54526 .07506 Mtetra
.54526 .07506 .54629 .07577 .54824 .07501 .54721 .0743 Mtetra
.54721 .0743 .54824 .07501 .55018 .07426 .54915 .07355 Mtetra
.54915 .07355 .55018 .07426 .55213 .0735 .5511 .07279 Mtetra
.5511 .07279 .55213 .0735 .55407 .07275 .55305 .07203 Mtetra
.55305 .07203 .55407 .07275 .55602 .07199 .555 .07127 Mtetra
.555 .07127 .55602 .07199 .55797 .07123 .55695 .07051 Mtetra
.55695 .07051 .55797 .07123 .55992 .07047 .5589 .06975 Mtetra
.5589 .06975 .55992 .07047 .56188 .06971 .56086 .06899 Mtetra
.645 .873 .984 r
.56086 .06899 .56188 .06971 .56383 .06895 .56281 .06823 Mtetra
.645 .874 .984 r
.56281 .06823 .56383 .06895 .56579 .06818 .56477 .06746 Mtetra
.56477 .06746 .56579 .06818 .56774 .06742 .56673 .0667 Mtetra
.645 .874 .983 r
.56673 .0667 .56774 .06742 .5697 .06665 .56869 .06593 Mtetra
.646 .875 .983 r
.56869 .06593 .5697 .06665 .57166 .06588 .57065 .06516 Mtetra
.57065 .06516 .57166 .06588 .57362 .06511 .57261 .06439 Mtetra
.57261 .06439 .57362 .06511 .57559 .06433 .57458 .06362 Mtetra
.646 .876 .983 r
.57458 .06362 .57559 .06433 .57755 .06356 .57654 .06284 Mtetra
.646 .877 .983 r
.57654 .06284 .57755 .06356 .57951 .06278 .57851 .06207 Mtetra
.646 .877 .984 r
.57851 .06207 .57951 .06278 .58148 .06199 .58048 .06129 Mtetra
.646 .878 .984 r
.58048 .06129 .58148 .06199 .58345 .06121 .58244 .06051 Mtetra
.645 .879 .984 r
.58244 .06051 .58345 .06121 .58542 .06042 .58441 .05973 Mtetra
.643 .881 .985 r
.58441 .05973 .58542 .06042 .58739 .05964 .58639 .05895 Mtetra
.641 .881 .985 r
.58639 .05895 .58739 .05964 .58936 .05886 .58836 .05818 Mtetra
.64 .881 .985 r
.58836 .05818 .58936 .05886 .59133 .05809 .59033 .0574 Mtetra
.639 .881 .986 r
.59033 .0574 .59133 .05809 .59331 .05732 .59231 .05663 Mtetra
.638 .881 .986 r
.59231 .05663 .59331 .05732 .59528 .05656 .59429 .05587 Mtetra
.638 .88 .986 r
.59429 .05587 .59528 .05656 .59726 .05579 .59627 .0551 Mtetra
.637 .88 .986 r
.59627 .0551 .59726 .05579 .59924 .05503 .59825 .05434 Mtetra
.637 .879 .986 r
.59825 .05434 .59924 .05503 .60122 .05428 .60023 .05357 Mtetra
.639 .877 .986 r
.60023 .05357 .60122 .05428 .6032 .05352 .60221 .05281 Mtetra
.64 .876 .985 r
.60221 .05281 .6032 .05352 .60519 .05276 .6042 .05204 Mtetra
.643 .875 .984 r
.6042 .05204 .60519 .05276 .60717 .052 .60619 .05127 Mtetra
.645 .875 .984 r
.60619 .05127 .60717 .052 .60916 .05123 .60817 .05049 Mtetra
.649 .875 .983 r
.60817 .05049 .60916 .05123 .61115 .05044 .61016 .0497 Mtetra
.654 .876 .981 r
.61016 .0497 .61115 .05044 .61313 .04964 .61215 .04889 Mtetra
.654 .874 .981 r
.61215 .04889 .61313 .04964 .61512 .04884 .61414 .04809 Mtetra
.687 .884 .971 r
.61414 .04809 .61512 .04884 .61711 .04797 .61613 .04717 Mtetra
.756 .894 .94 r
.61613 .04717 .61711 .04797 .6191 .04689 .61811 .04597 Mtetra
.65 .838 .972 r
.61811 .04597 .6191 .04689 .62109 .04612 .62011 .04522 Mtetra
.121 .546 .919 r
.62011 .04522 .62109 .04612 .62311 .04618 .62215 .04571 Mtetra
.899 .485 .107 r
.62215 .04571 .62311 .04618 .62524 .04895 .62441 .05262 Mtetra
.972 .661 .34 r
.62441 .05262 .62524 .04895 .63448 .25115 .63401 .26666 Mtetra
.577 .283 .432 r
.63401 .26666 .63448 .25115 .6372 .26627 .63633 .27024 Mtetra
.425 .06 .239 r
.63633 .27024 .6372 .26627 .63939 .2664 .63851 .27002 Mtetra
.323 0 .189 r
.63851 .27002 .63939 .2664 .64154 .26528 .64067 .26907 Mtetra
.297 0 .192 r
.64067 .26907 .64154 .26528 .64367 .26369 .64282 .26786 Mtetra
.37 .02 .234 r
.64282 .26786 .64367 .26369 .64584 .2629 .64499 .2671 Mtetra
.37 .021 .236 r
.64499 .2671 .64584 .2629 .648 .26212 .64716 .26634 Mtetra
.372 .023 .238 r
.64716 .26634 .648 .26212 .65017 .26135 .64934 .26558 Mtetra
.375 .026 .239 r
.64934 .26558 .65017 .26135 .65234 .26063 .65152 .26485 Mtetra
.376 .026 .238 r
.65152 .26485 .65234 .26063 .65452 .25993 .65369 .26412 Mtetra
.375 .025 .237 r
.65369 .26412 .65452 .25993 .6567 .25924 .65587 .2634 Mtetra
.374 .023 .235 r
.65587 .2634 .6567 .25924 .65887 .25853 .65806 .26267 Mtetra
.373 .021 .234 r
.65806 .26267 .65887 .25853 .66105 .25782 .66024 .26194 Mtetra
.372 .02 .232 r
.66024 .26194 .66105 .25782 .66323 .25711 .66242 .2612 Mtetra
.37 .018 .231 r
.66242 .2612 .66323 .25711 .66542 .25639 .66461 .26046 Mtetra
.369 .016 .229 r
.66461 .26046 .66542 .25639 .6676 .25567 .6668 .25972 Mtetra
.368 .015 .228 r
.6668 .25972 .6676 .25567 .66979 .25495 .66899 .25897 Mtetra
.367 .013 .226 r
.66899 .25897 .66979 .25495 .67197 .25422 .67118 .25822 Mtetra
.366 .012 .225 r
.67118 .25822 .67197 .25422 .67416 .25348 .67337 .25747 Mtetra
.365 .011 .224 r
.67337 .25747 .67416 .25348 .67635 .25273 .67557 .25671 Mtetra
.364 .01 .223 r
.67557 .25671 .67635 .25273 .67854 .25198 .67776 .25595 Mtetra
.364 .009 .223 r
.67776 .25595 .67854 .25198 .68074 .25121 .67996 .25518 Mtetra
.363 .009 .223 r
.67996 .25518 .68074 .25121 .68293 .25042 .68216 .25441 Mtetra
.68216 .25441 .68293 .25042 .68512 .24962 .68436 .25363 Mtetra
.363 .01 .225 r
.68436 .25363 .68512 .24962 .68732 .24879 .68656 .25284 Mtetra
.363 .011 .227 r
.68656 .25284 .68732 .24879 .68951 .24793 .68877 .25204 Mtetra
.364 .013 .23 r
.68877 .25204 .68951 .24793 .69171 .24703 .69097 .25123 Mtetra
.365 .017 .235 r
.69097 .25123 .69171 .24703 .6939 .24609 .69317 .2504 Mtetra
.366 .021 .24 r
.69317 .2504 .6939 .24609 .69609 .2451 .69538 .24955 Mtetra
.366 .024 .247 r
.69538 .24955 .69609 .2451 .69825 .24355 .69758 .24865 Mtetra
.382 .053 .277 r
.69758 .24865 .69825 .24355 .70043 .24233 .69979 .24774 Mtetra
.389 .064 .289 r
.69979 .24774 .70043 .24233 .70266 .24196 .70199 .24682 Mtetra
.38 .046 .268 r
.70199 .24682 .70266 .24196 .70503 .24376 .7042 .24595 Mtetra
.232 0 .023 r
.7042 .24595 .70503 .24376 .70736 .24501 .70642 .24508 Mtetra
.395 .851 .813 r
.70642 .24508 .70736 .24501 .70966 .24564 .70863 .24421 Mtetra
.705 .776 .907 r
.00823 .48586 .00958 .48695 .01131 .48622 .00998 .48501 Mtetra
.679 .748 .903 r
.00998 .48501 .01131 .48622 .01304 .48552 .01171 .48426 Mtetra
.657 .737 .908 r
.01171 .48426 .01304 .48552 .01476 .48485 .01343 .48362 Mtetra
.643 .736 .917 r
.01343 .48362 .01476 .48485 .01646 .48434 .01514 .48304 Mtetra
.623 .718 .914 r
.01514 .48304 .01646 .48434 .01815 .48387 .01684 .48253 Mtetra
.604 .707 .917 r
.01684 .48253 .01815 .48387 .01985 .48339 .01853 .4821 Mtetra
.396 .632 .949 r
.01853 .4821 .01985 .48339 .02148 .48335 .02014 .4822 Mtetra
.52 .712 .959 r
.02014 .4822 .02148 .48335 .02317 .4829 .0218 .482 Mtetra
.696 .809 .935 r
.0218 .482 .02317 .4829 .02499 .48162 .02355 .48119 Mtetra
.916 .815 .732 r
.02355 .48119 .02499 .48162 .02759 .47523 .02572 .47759 Mtetra
.99 .832 .591 r
.02572 .47759 .02759 .47523 .0604 .26777 .02881 .46793 Mtetra
0 0 0 r
.02881 .46793 .0604 .26777 .06277 .2621 .06076 .26615 Mtetra
.183 0 .139 r
.06076 .26615 .06277 .2621 .0645 .26077 .06251 .26463 Mtetra
.423 .071 .26 r
.06251 .26463 .0645 .26077 .0661 .26025 .06407 .26441 Mtetra
.436 .09 .279 r
.06407 .26441 .0661 .26025 .06765 .26009 .06563 .26424 Mtetra
0 0 0 r
.06563 .26424 .06765 .26009 .06927 .25947 .06761 .26119 Mtetra
.772 .945 .607 r
.06761 .26119 .06927 .25947 .0709 .25877 .06953 .25859 Mtetra
.883 .902 .838 r
.06953 .25859 .0709 .25877 .07254 .25808 .07135 .25663 Mtetra
.713 .707 .843 r
.07135 .25663 .07254 .25808 .07417 .25741 .07303 .25567 Mtetra
.648 .648 .836 r
.07303 .25567 .07417 .25741 .0758 .25676 .07465 .25504 Mtetra
.621 .64 .848 r
.07465 .25504 .0758 .25676 .07743 .25613 .07626 .25455 Mtetra
.701 .686 .833 r
.07626 .25455 .07743 .25613 .07911 .25514 .07793 .25363 Mtetra
.679 .69 .854 r
.07793 .25363 .07911 .25514 .08075 .25441 .07958 .25287 Mtetra
.582 .65 .883 r
.07958 .25287 .08075 .25441 .0823 .25432 .08116 .25255 Mtetra
0 .048 .608 r
.08116 .25255 .0823 .25432 .08335 .25778 .08249 .25402 Mtetra
.805 .527 0 r
.08249 .25402 .08335 .25778 .05542 .4641 .08334 .25885 Mtetra
0 0 0 r
.08334 .25885 .05542 .4641 .05613 .47069 .05576 .46285 Mtetra
.024 0 .463 r
.05576 .46285 .05613 .47069 .05769 .47138 .05682 .46704 Mtetra
.258 .238 .645 r
.05682 .46704 .05769 .47138 .05942 .47089 .05827 .4685 Mtetra
.354 .438 .809 r
.05827 .4685 .05942 .47089 .06121 .46993 .05985 .46902 Mtetra
.499 .756 .987 r
.05985 .46902 .06121 .46993 .06297 .46922 .06154 .46879 Mtetra
.59 .882 .992 r
.06154 .46879 .06297 .46922 .06472 .46854 .06329 .4682 Mtetra
.65 .91 .98 r
.06329 .4682 .06472 .46854 .06648 .46785 .06506 .46743 Mtetra
.459 .835 .989 r
.06506 .46743 .06648 .46785 .06817 .46765 .06677 .46708 Mtetra
.559 .846 .998 r
.06677 .46708 .06817 .46765 .06989 .46725 .0685 .46661 Mtetra
.724 .866 .948 r
.0685 .46661 .06989 .46725 .07171 .46618 .0703 .46566 Mtetra
.899 .838 .776 r
.0703 .46566 .07171 .46618 .07401 .46158 .07235 .46288 Mtetra
.984 .871 .64 r
.07235 .46288 .07401 .46158 .10402 .25437 .07485 .45683 Mtetra
0 0 0 r
.07485 .45683 .10402 .25437 .10674 .24585 .10461 .25136 Mtetra
.10461 .25136 .10674 .24585 .10858 .24385 .10695 .24567 Mtetra
.717 .913 .558 r
.10695 .24567 .10858 .24385 .11024 .2431 .10887 .24309 Mtetra
.856 .952 .875 r
.10887 .24309 .11024 .2431 .11184 .2428 .11066 .24142 Mtetra
.718 .723 .854 r
.11066 .24142 .11184 .2428 .11348 .2423 .11235 .24045 Mtetra
.637 .631 .828 r
.11235 .24045 .11348 .2423 .11512 .24175 .114 .23985 Mtetra
.596 .609 .835 r
.114 .23985 .11512 .24175 .11676 .24121 .11562 .23946 Mtetra
.601 .63 .852 r
.11562 .23946 .11676 .24121 .1184 .24066 .11724 .23906 Mtetra
.603 .652 .871 r
.11724 .23906 .1184 .24066 .12004 .2401 .11887 .23865 Mtetra
.602 .675 .892 r
.11887 .23865 .12004 .2401 .12169 .23954 .12049 .23824 Mtetra
.621 .71 .909 r
.12049 .23824 .12169 .23954 .12333 .23898 .12213 .23776 Mtetra
.635 .729 .916 r
.12213 .23776 .12333 .23898 .12498 .23842 .12377 .23723 Mtetra
.642 .737 .917 r
.12377 .23723 .12498 .23842 .12663 .23785 .12542 .23667 Mtetra
.641 .738 .919 r
.12542 .23667 .12663 .23785 .12828 .23729 .12707 .23612 Mtetra
.644 .741 .919 r
.12707 .23612 .12828 .23729 .12994 .23671 .12872 .23556 Mtetra
.653 .746 .918 r
.12872 .23556 .12994 .23671 .13159 .2361 .13038 .23495 Mtetra
.671 .752 .911 r
.13038 .23495 .13159 .2361 .13326 .23542 .13205 .23428 Mtetra
.683 .755 .906 r
.13205 .23428 .13326 .23542 .13494 .2347 .13373 .23354 Mtetra
.688 .756 .903 r
.13373 .23354 .13494 .2347 .13662 .23395 .13541 .23279 Mtetra
.757 .767 .861 r
.13541 .23279 .13662 .23395 .13835 .23279 .13714 .23162 Mtetra
.739 .762 .871 r
.13714 .23162 .13835 .23279 .14007 .23175 .13886 .23057 Mtetra
.59 .722 .935 r
.13886 .23057 .14007 .23175 .14171 .23136 .1405 .23019 Mtetra
.857 .409 .018 r
.1405 .23019 .14171 .23136 .14298 .23391 .14174 .23299 Mtetra
.947 .684 .504 r
.14174 .23299 .14298 .23391 .11889 .44028 .1174 .44065 Mtetra
.903 .562 .389 r
.1174 .44065 .11889 .44028 .11958 .44842 .11821 .44782 Mtetra
.558 0 0 r
.11821 .44782 .11958 .44842 .12111 .4499 .11977 .44902 Mtetra
.611 .805 .974 r
.11977 .44902 .12111 .4499 .12286 .44958 .12155 .44849 Mtetra
.786 .795 .86 r
.12155 .44849 .12286 .44958 .12474 .44818 .12343 .44706 Mtetra
.869 .777 .758 r
.12343 .44706 .12474 .44818 .12695 .44414 .12549 .44426 Mtetra
.962 .82 .658 r
.12549 .44426 .12695 .44414 .15358 .23866 .1279 .43851 Mtetra
0 0 .008 r
.1279 .43851 .15358 .23866 .15662 .22682 .15453 .23299 Mtetra
0 0 0 r
.15453 .23299 .15662 .22682 .15853 .22429 .1569 .22666 Mtetra
.1569 .22666 .15853 .22429 .16023 .22344 .15882 .22405 Mtetra
.776 .996 .803 r
.15882 .22405 .16023 .22344 .16188 .22307 .16062 .22236 Mtetra
.791 .852 .896 r
.16062 .22236 .16188 .22307 .16357 .22232 .16238 .2211 Mtetra
.706 .749 .885 r
.16238 .2211 .16357 .22232 .16529 .22143 .16409 .22023 Mtetra
.578 .716 .937 r
.16409 .22023 .16529 .22143 .16694 .22107 .16574 .21988 Mtetra
0 .3 .776 r
.16574 .21988 .16694 .22107 .16833 .22294 .16725 .22077 Mtetra
.804 .42 0 r
.16725 .22077 .16833 .22294 .14694 .42025 .16846 .22415 Mtetra
0 0 .03 r
.16846 .22415 .14694 .42025 .14662 .43787 .14644 .42712 Mtetra
0 0 .373 r
.14644 .42712 .14662 .43787 .14815 .43964 .14733 .43437 Mtetra
.249 .203 .609 r
.14733 .43437 .14815 .43964 .14992 .43924 .14884 .43627 Mtetra
.345 .381 .755 r
.14884 .43627 .14992 .43924 .15177 .43826 .15049 .43701 Mtetra
.471 .68 .957 r
.15049 .43701 .15177 .43826 .15361 .43732 .15223 .43693 Mtetra
.575 .888 .99 r
.15223 .43693 .15361 .43732 .15543 .4366 .15404 .43632 Mtetra
.644 .924 .975 r
.15404 .43632 .15543 .4366 .15725 .43588 .15587 .4355 Mtetra
.639 .908 .982 r
.15587 .4355 .15725 .43588 .15907 .43522 .1577 .43473 Mtetra
.602 .88 .992 r
.1577 .43473 .15907 .43522 .16088 .43463 .15952 .4341 Mtetra
.588 .869 .994 r
.15952 .4341 .16088 .43463 .16268 .43406 .16133 .43352 Mtetra
.543 .852 .998 r
.16133 .43352 .16268 .43406 .1645 .43346 .16312 .43304 Mtetra
.472 .843 .989 r
.16312 .43304 .1645 .43346 .16631 .43285 .16492 .43264 Mtetra
.402 .838 .946 r
.16492 .43264 .16631 .43285 .16813 .43224 .16671 .43224 Mtetra
.365 .832 .887 r
.16671 .43224 .16813 .43224 .16994 .43165 .16851 .43176 Mtetra
.378 .843 .862 r
.16851 .43176 .16994 .43165 .17175 .4311 .17033 .43119 Mtetra
.42 .866 .879 r
.17033 .43119 .17175 .4311 .17356 .43054 .17215 .43057 Mtetra
.497 .902 .916 r
.17215 .43057 .17356 .43054 .17538 .42996 .17398 .42987 Mtetra
.575 .926 .952 r
.17398 .42987 .17538 .42996 .1772 .42935 .17582 .42909 Mtetra
.621 .923 .974 r
.17582 .42909 .1772 .42935 .17903 .42872 .17767 .4283 Mtetra
.627 .901 .986 r
.17767 .4283 .17903 .42872 .18085 .4281 .1795 .42757 Mtetra
.612 .879 .991 r
.1795 .42757 .18085 .4281 .18268 .42747 .18134 .42692 Mtetra
.605 .872 .992 r
.18134 .42692 .18268 .42747 .18451 .42684 .18316 .42629 Mtetra
.601 .871 .993 r
.18316 .42629 .18451 .42684 .18634 .42623 .18499 .42568 Mtetra
.602 .871 .993 r
.18499 .42568 .18634 .42623 .18817 .42562 .18683 .42506 Mtetra
.603 .869 .992 r
.18683 .42506 .18817 .42562 .19 .42501 .18866 .42444 Mtetra
.534 .845 .999 r
.18866 .42444 .19 .42501 .19181 .42463 .19048 .42398 Mtetra
.507 .821 1 r
.19048 .42398 .19181 .42463 .19361 .42436 .19229 .42361 Mtetra
.665 .849 .97 r
.19229 .42361 .19361 .42436 .19546 .42355 .19414 .42286 Mtetra
.86 .86 .839 r
.19414 .42286 .19546 .42355 .19752 .42077 .19611 .42085 Mtetra
.965 .848 .676 r
.19611 .42085 .19752 .42077 .20051 .40865 .19839 .41594 Mtetra
.963 .701 .489 r
.19839 .41594 .20051 .40865 .22288 .20233 .22052 .21285 Mtetra
0 0 .014 r
.22052 .21285 .22288 .20233 .22488 .19884 .2232 .20275 Mtetra
.259 0 .18 r
.2232 .20275 .22488 .19884 .22664 .19787 .22498 .20152 Mtetra
.431 .07 .25 r
.22498 .20152 .22664 .19787 .22834 .19746 .22666 .20138 Mtetra
.455 .1 .274 r
.22666 .20138 .22834 .19746 .23003 .1971 .22832 .20138 Mtetra
.378 .036 .253 r
.22832 .20138 .23003 .1971 .23176 .19645 .23005 .20075 Mtetra
.38 .039 .256 r
.23005 .20075 .23176 .19645 .23349 .19579 .23178 .20013 Mtetra
.379 .039 .257 r
.23178 .20013 .23349 .19579 .23522 .19514 .23351 .1995 Mtetra
.376 .036 .256 r
.23351 .1995 .23522 .19514 .23695 .19447 .23524 .19884 Mtetra
.375 .036 .256 r
.23524 .19884 .23695 .19447 .23868 .1938 .23698 .19817 Mtetra
.376 .036 .256 r
.23698 .19817 .23868 .1938 .24042 .19313 .23872 .1975 Mtetra
.377 .037 .257 r
.23872 .1975 .24042 .19313 .24215 .19246 .24046 .19685 Mtetra
.377 .038 .258 r
.24046 .19685 .24215 .19246 .24389 .1918 .2422 .19619 Mtetra
.408 .067 .272 r
.2422 .19619 .24389 .1918 .24562 .19115 .24391 .19576 Mtetra
.452 .113 .299 r
.24391 .19576 .24562 .19115 .24736 .19052 .2456 .19567 Mtetra
.387 .062 .288 r
.2456 .19567 .24736 .19052 .2491 .18988 .24735 .19492 Mtetra
.144 0 .178 r
.24735 .19492 .2491 .18988 .25084 .1892 .24925 .19257 Mtetra
0 0 0 r
.24925 .19257 .25084 .1892 .25259 .18844 .25124 .18927 Mtetra
.869 .989 .724 r
.25124 .18927 .25259 .18844 .25434 .18767 .25315 .18677 Mtetra
.827 .827 .847 r
.25315 .18677 .25434 .18767 .25609 .18694 .25498 .18512 Mtetra
.67 .657 .829 r
.25498 .18512 .25609 .18694 .25783 .18628 .25674 .18431 Mtetra
.627 .622 .826 r
.25674 .18431 .25783 .18628 .25958 .18563 .25848 .18373 Mtetra
.621 .627 .836 r
.25848 .18373 .25958 .18563 .26132 .18498 .26021 .18319 Mtetra
.65 .654 .841 r
.26021 .18319 .26132 .18498 .26307 .1843 .26196 .18251 Mtetra
.26196 .18251 .26307 .1843 .26483 .18361 .26371 .18182 Mtetra
.65 .656 .842 r
.26371 .18182 .26483 .18361 .26658 .18291 .26547 .18114 Mtetra
.651 .657 .843 r
.26547 .18114 .26658 .18291 .26833 .18222 .26722 .18045 Mtetra
.651 .658 .844 r
.26722 .18045 .26833 .18222 .27009 .18153 .26898 .17977 Mtetra
.651 .66 .845 r
.26898 .17977 .27009 .18153 .27184 .18084 .27073 .17909 Mtetra
.652 .661 .846 r
.27073 .17909 .27184 .18084 .2736 .18015 .27249 .17839 Mtetra
.649 .659 .846 r
.27249 .17839 .2736 .18015 .27536 .17946 .27425 .17772 Mtetra
.64 .658 .851 r
.27425 .17772 .27536 .17946 .27712 .17877 .276 .1771 Mtetra
.623 .66 .866 r
.276 .1771 .27712 .17877 .27888 .17807 .27775 .17657 Mtetra
.628 .689 .888 r
.27775 .17657 .27888 .17807 .28064 .17737 .2795 .17603 Mtetra
.652 .724 .901 r
.2795 .17603 .28064 .17737 .2824 .17668 .28126 .17539 Mtetra
.696 .745 .89 r
.28126 .17539 .2824 .17668 .28417 .17602 .28303 .17454 Mtetra
.694 .716 .866 r
.28303 .17454 .28417 .17602 .28593 .17536 .28482 .17366 Mtetra
.69 .684 .839 r
.28482 .17366 .28593 .17536 .2877 .17459 .2866 .17276 Mtetra
.696 .669 .819 r
.2866 .17276 .2877 .17459 .2895 .17349 .28839 .17176 Mtetra
.65 .664 .85 r
.28839 .17176 .2895 .17349 .29127 .17281 .29016 .17108 Mtetra
.461 .577 .884 r
.29016 .17108 .29127 .17281 .29295 .17326 .29187 .17116 Mtetra
0 0 .42 r
.29187 .17116 .29295 .17326 .29419 .17945 .29339 .17372 Mtetra
.943 .669 .207 r
.29339 .17372 .29419 .17945 .2799 .38945 .29406 .18746 Mtetra
0 0 .155 r
.29406 .18746 .2799 .38945 .28146 .39328 .28066 .38618 Mtetra
.52 .365 .611 r
.28066 .38618 .28146 .39328 .28332 .39316 .28252 .38608 Mtetra
.579 .408 .614 r
.28252 .38608 .28332 .39316 .28523 .39232 .28445 .38506 Mtetra
.54 .378 .61 r
.28445 .38506 .28523 .39232 .28717 .39123 .28633 .38465 Mtetra
.301 .216 .591 r
.28633 .38465 .28717 .39123 .28906 .3907 .28802 .3868 Mtetra
.275 .282 .685 r
.28802 .3868 .28906 .3907 .29096 .39015 .28978 .38819 Mtetra
.264 .45 .857 r
.28978 .38819 .29096 .39015 .29286 .38962 .29159 .38886 Mtetra
.395 .751 .993 r
.29159 .38886 .29286 .38962 .29474 .38938 .29346 .38873 Mtetra
.621 .868 .989 r
.29346 .38873 .29474 .38938 .29665 .38867 .29537 .38805 Mtetra
.804 .899 .909 r
.29537 .38805 .29665 .38867 .29864 .38692 .29734 .38659 Mtetra
.946 .87 .731 r
.29734 .38659 .29864 .38692 .30098 .38003 .29946 .38298 Mtetra
.971 .868 .478 r
.29946 .38298 .30098 .38003 .31755 .16804 .30192 .37447 Mtetra
0 0 .147 r
.30192 .37447 .31755 .16804 .31967 .1625 .31817 .16654 Mtetra
0 0 0 r
.31817 .16654 .31967 .1625 .3215 .16116 .3202 .16233 Mtetra
.723 .934 .608 r
.3202 .16233 .3215 .16116 .32329 .16052 .3221 .15998 Mtetra
.827 .905 .893 r
.3221 .15998 .32329 .16052 .32505 .1602 .32395 .15846 Mtetra
.659 .669 .848 r
.32395 .15846 .32505 .1602 .32684 .15954 .32575 .15772 Mtetra
.604 .635 .855 r
.32575 .15772 .32684 .15954 .32863 .1589 .32753 .15727 Mtetra
.581 .651 .884 r
.32753 .15727 .32863 .1589 .33043 .15825 .3293 .15691 Mtetra
.657 .731 .904 r
.3293 .15691 .33043 .15825 .33223 .15749 .33109 .15624 Mtetra
.673 .75 .909 r
.33109 .15624 .33223 .15749 .33403 .15673 .33289 .1555 Mtetra
.692 .761 .904 r
.33289 .1555 .33403 .15673 .33583 .15595 .3347 .15467 Mtetra
.779 .773 .848 r
.3347 .15467 .33583 .15595 .33766 .15477 .33655 .15327 Mtetra
.709 .721 .859 r
.33655 .15327 .33766 .15477 .33947 .15399 .33837 .15229 Mtetra
.533 .619 .883 r
.33837 .15229 .33947 .15399 .34122 .154 .34013 .15212 Mtetra
.869 .477 .006 r
.34013 .15212 .34122 .154 .34269 .1588 .34161 .15677 Mtetra
.967 .685 .446 r
.34161 .15677 .34269 .1588 .33166 .37021 .33043 .3693 Mtetra
.908 .499 .159 r
.33043 .3693 .33166 .37021 .33325 .37523 .33201 .37448 Mtetra
.381 .75 .991 r
.33201 .37448 .33325 .37523 .33515 .37527 .33391 .37437 Mtetra
.708 .843 .947 r
.33391 .37437 .33515 .37527 .3371 .37449 .33587 .37341 Mtetra
.778 .821 .887 r
.33587 .37341 .3371 .37449 .33907 .37328 .33785 .37204 Mtetra
.5 .705 .962 r
.33785 .37204 .33907 .37328 .34098 .37305 .33977 .37185 Mtetra
.581 .748 .957 r
.33977 .37185 .34098 .37305 .34293 .37241 .3417 .37141 Mtetra
.718 .828 .933 r
.3417 .37141 .34293 .37241 .34491 .37097 .34366 .37041 Mtetra
.937 .858 .737 r
.34366 .37041 .34491 .37097 .34718 .36462 .34577 .36692 Mtetra
.984 .865 .497 r
.34577 .36692 .34718 .36462 .36082 .15186 .34814 .35858 Mtetra
0 0 .174 r
.34814 .35858 .36082 .15186 .36294 .14564 .36154 .14953 Mtetra
0 0 0 r
.36154 .14953 .36294 .14564 .3648 .1441 .36355 .14526 Mtetra
.713 .925 .59 r
.36355 .14526 .3648 .1441 .36663 .14334 .36547 .14286 Mtetra
.842 .92 .885 r
.36547 .14286 .36663 .14334 .36843 .14296 .36734 .14123 Mtetra
.748 .705 .811 r
.36734 .14123 .36843 .14296 .37027 .14182 .36919 .13985 Mtetra
.662 .645 .823 r
.36919 .13985 .37027 .14182 .3721 .14098 .37102 .13904 Mtetra
.508 .573 .856 r
.37102 .13904 .3721 .14098 .3739 .14084 .37281 .13899 Mtetra
.732 .324 0 r
.37281 .13899 .3739 .14084 .3755 .14461 .37443 .14241 Mtetra
.969 .685 .435 r
.37443 .14241 .3755 .14461 .36676 .35637 .36561 .35399 Mtetra
.916 .556 .111 r
.36561 .35399 .36676 .35637 .36837 .36265 .36718 .36126 Mtetra
.014 .39 .848 r
.36718 .36126 .36837 .36265 .37026 .36345 .36906 .36217 Mtetra
.614 .748 .941 r
.36906 .36217 .37026 .36345 .37222 .36287 .37102 .36162 Mtetra
.815 .801 .839 r
.37102 .36162 .37222 .36287 .37424 .36111 .37305 .35982 Mtetra
.943 .762 .629 r
.37305 .35982 .37424 .36111 .37645 .35538 .37528 .3535 Mtetra
.969 .689 .446 r
.37528 .3535 .37645 .35538 .38821 .14209 .38717 .13935 Mtetra
.886 .68 .619 r
.38717 .13935 .38821 .14209 .39034 .13515 .38926 .13318 Mtetra
.746 .68 .787 r
.38926 .13318 .39034 .13515 .39222 .13346 .39113 .1317 Mtetra
.607 .648 .865 r
.39113 .1317 .39222 .13346 .39405 .13278 .39296 .13122 Mtetra
.49 .623 .909 r
.39296 .13122 .39405 .13278 .39587 .13251 .39477 .13117 Mtetra
.659 .736 .907 r
.39477 .13117 .39587 .13251 .39771 .13187 .39661 .13047 Mtetra
.671 .73 .894 r
.39661 .13047 .39771 .13187 .39955 .13116 .39846 .12971 Mtetra
.626 .704 .902 r
.39846 .12971 .39955 .13116 .40139 .13047 .40029 .12916 Mtetra
.443 .647 .945 r
.40029 .12916 .40139 .13047 .40325 .1294 .40211 .12917 Mtetra
.347 0 0 r
.40211 .12917 .40325 .1294 .4051 .12855 .4039 .12988 Mtetra
.715 .269 .191 r
.4039 .12988 .4051 .12855 .40693 .12836 .40563 .13202 Mtetra
.965 .676 .431 r
.40563 .13202 .40693 .12836 .40862 .13175 .39937 .33546 Mtetra
.521 .275 .483 r
.39937 .33546 .40862 .13175 .40224 .34329 .40089 .34634 Mtetra
.691 .303 .306 r
.40089 .34634 .40224 .34329 .40395 .34999 .40275 .34906 Mtetra
.112 .55 .916 r
.40275 .34906 .40395 .34999 .40588 .35067 .4047 .34952 Mtetra
.573 .759 .966 r
.4047 .34952 .40588 .35067 .40787 .35003 .40668 .34908 Mtetra
.716 .843 .943 r
.40668 .34908 .40787 .35003 .40988 .34889 .40868 .34807 Mtetra
.811 .877 .894 r
.40868 .34807 .40988 .34889 .41187 .34845 .41071 .3465 Mtetra
.814 .72 .761 r
.41071 .3465 .41187 .34845 .41386 .34789 .41277 .34414 Mtetra
.796 .615 .656 r
.41277 .34414 .41386 .34789 .41588 .34662 .41487 .34026 Mtetra
.967 .683 .439 r
.41487 .34026 .41588 .34662 .41802 .3417 .42364 .14134 Mtetra
.544 .299 .495 r
.42364 .14134 .41802 .3417 .42705 .12869 .42612 .12274 Mtetra
.727 .521 .612 r
.42612 .12274 .42705 .12869 .42916 .12052 .42809 .11885 Mtetra
.772 .726 .811 r
.42809 .11885 .42916 .12052 .43107 .11847 .42998 .1173 Mtetra
.668 .774 .929 r
.42998 .1173 .43107 .11847 .43294 .11772 .43184 .11656 Mtetra
.59 .749 .953 r
.43184 .11656 .43294 .11772 .43479 .11742 .4337 .11612 Mtetra
.694 .758 .901 r
.4337 .11612 .43479 .11742 .43665 .11684 .43557 .11525 Mtetra
.697 .713 .861 r
.43557 .11525 .43665 .11684 .43852 .11611 .43745 .1143 Mtetra
.647 .662 .851 r
.43745 .1143 .43852 .11611 .44039 .1154 .43932 .1136 Mtetra
.409 .544 .88 r
.43932 .1136 .44039 .1154 .44226 .11475 .44116 .11386 Mtetra
0 .22 .675 r
.44116 .11386 .44226 .11475 .44413 .11413 .44298 .11501 Mtetra
.721 .245 .116 r
.44298 .11501 .44413 .11413 .446 .1135 .44478 .11709 Mtetra
.56 .186 .288 r
.44478 .11709 .446 .1135 .44787 .11279 .44662 .11813 Mtetra
.405 .082 .301 r
.44662 .11813 .44787 .11279 .44975 .11203 .4485 .11746 Mtetra
.334 .023 .28 r
.4485 .11746 .44975 .11203 .45163 .11126 .45039 .11608 Mtetra
.357 .031 .269 r
.45039 .11608 .45163 .11126 .45351 .1105 .45229 .11509 Mtetra
.377 .043 .267 r
.45229 .11509 .45351 .1105 .45539 .10976 .45417 .11431 Mtetra
.377 .042 .265 r
.45417 .11431 .45539 .10976 .45727 .10903 .45606 .11355 Mtetra
.379 .043 .265 r
.45606 .11355 .45727 .10903 .45916 .1083 .45795 .11281 Mtetra
.381 .045 .265 r
.45795 .11281 .45916 .1083 .46104 .10757 .45983 .11209 Mtetra
.382 .046 .266 r
.45983 .11209 .46104 .10757 .46292 .10685 .46172 .11138 Mtetra
.383 .047 .267 r
.46172 .11138 .46292 .10685 .46481 .10613 .46362 .11067 Mtetra
.385 .049 .268 r
.46362 .11067 .46481 .10613 .4667 .10542 .46551 .10997 Mtetra
.385 .05 .269 r
.46551 .10997 .4667 .10542 .46859 .1047 .4674 .10928 Mtetra
.386 .051 .27 r
.4674 .10928 .46859 .1047 .47048 .10398 .4693 .10858 Mtetra
.4693 .10858 .47048 .10398 .47237 .10326 .47119 .10788 Mtetra
.386 .052 .271 r
.47119 .10788 .47237 .10326 .47426 .10254 .47309 .10717 Mtetra
.386 .052 .272 r
.47309 .10717 .47426 .10254 .47616 .10182 .47499 .10647 Mtetra
.386 .053 .273 r
.47499 .10647 .47616 .10182 .47805 .10109 .47689 .10576 Mtetra
.47689 .10576 .47805 .10109 .47995 .10037 .47879 .10504 Mtetra
.47879 .10504 .47995 .10037 .48185 .09964 .48069 .10432 Mtetra
.386 .053 .274 r
.48069 .10432 .48185 .09964 .48375 .09891 .4826 .1036 Mtetra
.386 .054 .274 r
.4826 .1036 .48375 .09891 .48565 .09817 .48451 .10287 Mtetra
.48451 .10287 .48565 .09817 .48756 .09744 .48641 .10215 Mtetra
.386 .054 .275 r
.48641 .10215 .48756 .09744 .48946 .0967 .48832 .10142 Mtetra
.48832 .10142 .48946 .0967 .49136 .09597 .49023 .10068 Mtetra
.49023 .10068 .49136 .09597 .49327 .09523 .49214 .09995 Mtetra
.49214 .09995 .49327 .09523 .49518 .09449 .49406 .09921 Mtetra
.49406 .09921 .49518 .09449 .49709 .09375 .49597 .09847 Mtetra
.49597 .09847 .49709 .09375 .499 .09301 .49789 .09774 Mtetra
.49789 .09774 .499 .09301 .50091 .09227 .4998 .097 Mtetra
.4998 .097 .50091 .09227 .50283 .09153 .50172 .09625 Mtetra
.50172 .09625 .50283 .09153 .50474 .09079 .50364 .09551 Mtetra
.50364 .09551 .50474 .09079 .50666 .09004 .50556 .09477 Mtetra
.50556 .09477 .50666 .09004 .50857 .0893 .50748 .09403 Mtetra
.50748 .09403 .50857 .0893 .51049 .08855 .50941 .09328 Mtetra
.50941 .09328 .51049 .08855 .51241 .08781 .51133 .09254 Mtetra
.51133 .09254 .51241 .08781 .51433 .08706 .51326 .09179 Mtetra
.51326 .09179 .51433 .08706 .51626 .08632 .51519 .09104 Mtetra
.51519 .09104 .51626 .08632 .51818 .08557 .51712 .0903 Mtetra
.51712 .0903 .51818 .08557 .52011 .08482 .51905 .08955 Mtetra
.51905 .08955 .52011 .08482 .52203 .08408 .52098 .0888 Mtetra
.52098 .0888 .52203 .08408 .52396 .08333 .52291 .08805 Mtetra
.52291 .08805 .52396 .08333 .52589 .08258 .52485 .0873 Mtetra
.52485 .0873 .52589 .08258 .52782 .08183 .52678 .08655 Mtetra
.52678 .08655 .52782 .08183 .52976 .08108 .52872 .0858 Mtetra
.52872 .0858 .52976 .08108 .53169 .08033 .53066 .08505 Mtetra
.53066 .08505 .53169 .08033 .53362 .07958 .5326 .0843 Mtetra
.5326 .0843 .53362 .07958 .53556 .07882 .53454 .08355 Mtetra
.53454 .08355 .53556 .07882 .5375 .07807 .53648 .08279 Mtetra
.53648 .08279 .5375 .07807 .53944 .07732 .53843 .08204 Mtetra
.53843 .08204 .53944 .07732 .54138 .07657 .54037 .08129 Mtetra
.54037 .08129 .54138 .07657 .54332 .07581 .54232 .08053 Mtetra
.54232 .08053 .54332 .07581 .54526 .07506 .54427 .07978 Mtetra
.54427 .07978 .54526 .07506 .54721 .0743 .54622 .07902 Mtetra
.385 .054 .275 r
.54622 .07902 .54721 .0743 .54915 .07355 .54817 .07826 Mtetra
.54817 .07826 .54915 .07355 .5511 .07279 .55012 .0775 Mtetra
.55012 .0775 .5511 .07279 .55305 .07203 .55207 .07674 Mtetra
.385 .053 .275 r
.55207 .07674 .55305 .07203 .555 .07127 .55403 .07598 Mtetra
.55403 .07598 .555 .07127 .55695 .07051 .55599 .07522 Mtetra
.55599 .07522 .55695 .07051 .5589 .06975 .55794 .07445 Mtetra
.55794 .07445 .5589 .06975 .56086 .06899 .5599 .07369 Mtetra
.384 .052 .274 r
.5599 .07369 .56086 .06899 .56281 .06823 .56186 .07292 Mtetra
.56186 .07292 .56281 .06823 .56477 .06746 .56383 .07215 Mtetra
.56383 .07215 .56477 .06746 .56673 .0667 .56579 .07138 Mtetra
.383 .051 .273 r
.56579 .07138 .56673 .0667 .56869 .06593 .56775 .0706 Mtetra
.383 .05 .273 r
.56775 .0706 .56869 .06593 .57065 .06516 .56972 .06982 Mtetra
.382 .05 .272 r
.56972 .06982 .57065 .06516 .57261 .06439 .57169 .06904 Mtetra
.381 .049 .272 r
.57169 .06904 .57261 .06439 .57458 .06362 .57365 .06825 Mtetra
.381 .048 .271 r
.57365 .06825 .57458 .06362 .57654 .06284 .57562 .06746 Mtetra
.38 .047 .27 r
.57562 .06746 .57654 .06284 .57851 .06207 .5776 .06667 Mtetra
.38 .046 .269 r
.5776 .06667 .57851 .06207 .58048 .06129 .57957 .06587 Mtetra
.379 .046 .269 r
.57957 .06587 .58048 .06129 .58244 .06051 .58154 .06508 Mtetra
.379 .045 .268 r
.58154 .06508 .58244 .06051 .58441 .05973 .58352 .06428 Mtetra
.379 .045 .267 r
.58352 .06428 .58441 .05973 .58639 .05895 .58549 .06349 Mtetra
.58549 .06349 .58639 .05895 .58836 .05818 .58747 .0627 Mtetra
.58747 .0627 .58836 .05818 .59033 .0574 .58945 .06192 Mtetra
.38 .045 .266 r
.58945 .06192 .59033 .0574 .59231 .05663 .59143 .06115 Mtetra
.59143 .06115 .59231 .05663 .59429 .05587 .59342 .06038 Mtetra
.381 .045 .266 r
.59342 .06038 .59429 .05587 .59627 .0551 .5954 .05961 Mtetra
.381 .046 .266 r
.5954 .05961 .59627 .0551 .59825 .05434 .59739 .05885 Mtetra
.381 .046 .267 r
.59739 .05885 .59825 .05434 .60023 .05357 .59937 .05808 Mtetra
.381 .046 .266 r
.59937 .05808 .60023 .05357 .60221 .05281 .60136 .05732 Mtetra
.38 .045 .266 r
.60136 .05732 .60221 .05281 .6042 .05204 .60335 .05654 Mtetra
.379 .044 .266 r
.60335 .05654 .6042 .05204 .60619 .05127 .60534 .05576 Mtetra
.377 .042 .265 r
.60534 .05576 .60619 .05127 .60817 .05049 .60734 .05496 Mtetra
.374 .039 .263 r
.60734 .05496 .60817 .05049 .61016 .0497 .60933 .05414 Mtetra
.369 .034 .26 r
.60933 .05414 .61016 .0497 .61215 .04889 .61132 .05328 Mtetra
.367 .031 .258 r
.61132 .05328 .61215 .04889 .61414 .04809 .61332 .05241 Mtetra
.338 .006 .247 r
.61332 .05241 .61414 .04809 .61613 .04717 .6153 .05131 Mtetra
.257 0 .215 r
.6153 .05131 .61613 .04717 .61811 .04597 .61727 .04966 Mtetra
.356 .002 .219 r
.61727 .04966 .61811 .04597 .62011 .04522 .61928 .0489 Mtetra
.622 .236 .292 r
.61928 .0489 .62011 .04522 .62215 .04571 .62137 .05087 Mtetra
.972 .66 .344 r
.62137 .05087 .62215 .04571 .62441 .05262 .63064 .26193 Mtetra
.509 .265 .48 r
.63064 .26193 .62441 .05262 .63401 .26666 .63302 .26768 Mtetra
.649 .137 .015 r
.63302 .26768 .63401 .26666 .63633 .27024 .63528 .26948 Mtetra
.483 .814 1 r
.63528 .26948 .63633 .27024 .63851 .27002 .63746 .26908 Mtetra
.667 .857 .972 r
.63746 .26908 .63851 .27002 .64067 .26907 .63962 .26819 Mtetra
.706 .88 .962 r
.63962 .26819 .64067 .26907 .64282 .26786 .64178 .26712 Mtetra
.613 .876 .991 r
.64178 .26712 .64282 .26786 .64499 .2671 .64395 .26635 Mtetra
.608 .872 .992 r
.64395 .26635 .64499 .2671 .64716 .26634 .64613 .2656 Mtetra
.589 .867 .994 r
.64613 .2656 .64716 .26634 .64934 .26558 .6483 .2649 Mtetra
.537 .855 .997 r
.6483 .2649 .64934 .26558 .65152 .26485 .65049 .26432 Mtetra
.497 .862 .986 r
.65049 .26432 .65152 .26485 .65369 .26412 .65267 .26375 Mtetra
.465 .868 .961 r
.65267 .26375 .65369 .26412 .65587 .2634 .65486 .26314 Mtetra
.469 .882 .935 r
.65486 .26314 .65587 .2634 .65806 .26267 .65705 .26244 Mtetra
.473 .886 .929 r
.65705 .26244 .65806 .26267 .66024 .26194 .65923 .2617 Mtetra
.48 .89 .93 r
.65923 .2617 .66024 .26194 .66242 .2612 .66142 .26095 Mtetra
.48 .889 .933 r
.66142 .26095 .66242 .2612 .66461 .26046 .66361 .26021 Mtetra
.482 .89 .934 r
.66361 .26021 .66461 .26046 .6668 .25972 .6658 .25946 Mtetra
.484 .891 .934 r
.6658 .25946 .6668 .25972 .66899 .25897 .66799 .25871 Mtetra
.486 .891 .935 r
.66799 .25871 .66899 .25897 .67118 .25822 .67018 .25796 Mtetra
.488 .892 .936 r
.67018 .25796 .67118 .25822 .67337 .25747 .67238 .25721 Mtetra
.49 .893 .936 r
.67238 .25721 .67337 .25747 .67557 .25671 .67457 .25645 Mtetra
.492 .894 .937 r
.67457 .25645 .67557 .25671 .67776 .25595 .67677 .25568 Mtetra
.494 .895 .937 r
.67677 .25568 .67776 .25595 .67996 .25518 .67897 .25492 Mtetra
.495 .896 .937 r
.67897 .25492 .67996 .25518 .68216 .25441 .68117 .25414 Mtetra
.497 .896 .937 r
.68117 .25414 .68216 .25441 .68436 .25363 .68338 .25337 Mtetra
.499 .898 .936 r
.68338 .25337 .68436 .25363 .68656 .25284 .68558 .25258 Mtetra
.501 .899 .935 r
.68558 .25258 .68656 .25284 .68877 .25204 .68778 .25179 Mtetra
.501 .9 .934 r
.68778 .25179 .68877 .25204 .69097 .25123 .68999 .25098 Mtetra
.504 .902 .931 r
.68999 .25098 .69097 .25123 .69317 .2504 .6922 .25017 Mtetra
.506 .904 .927 r
.6922 .25017 .69317 .2504 .69538 .24955 .69441 .24933 Mtetra
.497 .901 .922 r
.69441 .24933 .69538 .24955 .69758 .24865 .69662 .2485 Mtetra
.493 .902 .901 r
.69662 .2485 .69758 .24865 .69979 .24774 .69882 .24762 Mtetra
.516 .915 .893 r
.69882 .24762 .69979 .24774 .70199 .24682 .70103 .24665 Mtetra
.631 .96 .904 r
.70103 .24665 .70199 .24682 .7042 .24595 .70322 .24542 Mtetra
.727 .954 .948 r
.70322 .24542 .7042 .24595 .70642 .24508 .70541 .24411 Mtetra
.753 .884 .938 r
.70541 .24411 .70642 .24508 .70863 .24421 .7076 .2428 Mtetra
.709 .776 .904 r
.00688 .48477 .00823 .48586 .00998 .48501 .00863 .48389 Mtetra
.689 .768 .912 r
.00863 .48389 .00998 .48501 .01171 .48426 .01037 .48311 Mtetra
.668 .758 .918 r
.01037 .48311 .01171 .48426 .01343 .48362 .0121 .48243 Mtetra
.656 .748 .918 r
.0121 .48243 .01343 .48362 .01514 .48304 .01382 .48179 Mtetra
.635 .733 .919 r
.01382 .48179 .01514 .48304 .01684 .48253 .01553 .48124 Mtetra
.612 .718 .921 r
.01553 .48124 .01684 .48253 .01853 .4821 .01722 .48078 Mtetra
.484 .665 .943 r
.01722 .48078 .01853 .4821 .02014 .4822 .01886 .4807 Mtetra
.546 .659 .91 r
.01886 .4807 .02014 .4822 .0218 .482 .02052 .48048 Mtetra
.632 .688 .884 r
.02052 .48048 .0218 .482 .02355 .48119 .02223 .47993 Mtetra
.81 .757 .804 r
.02223 .47993 .02355 .48119 .02572 .47759 .02414 .47809 Mtetra
.92 .955 .795 r
.02414 .47809 .02572 .47759 .02881 .46793 .02616 .47549 Mtetra
.123 0 .204 r
.02616 .47549 .02881 .46793 .06076 .26615 .02829 .47217 Mtetra
.497 .256 .479 r
.02829 .47217 .06076 .26615 .06251 .26463 .02996 .47195 Mtetra
.02996 .47195 .06251 .26463 .06407 .26441 .03159 .47192 Mtetra
.495 .254 .478 r
.03159 .47192 .06407 .26441 .06563 .26424 .0334 .47079 Mtetra
0 0 0 r
.0334 .47079 .06563 .26424 .06761 .26119 .06474 .27109 Mtetra
.765 .765 .257 r
.06474 .27109 .06761 .26119 .06953 .25859 .06803 .25924 Mtetra
.962 .902 .716 r
.06803 .25924 .06953 .25859 .07135 .25663 .07011 .25554 Mtetra
.77 .773 .855 r
.07011 .25554 .07135 .25663 .07303 .25567 .07183 .2543 Mtetra
.655 .704 .883 r
.07183 .2543 .07303 .25567 .07465 .25504 .07345 .25369 Mtetra
.586 .684 .909 r
.07345 .25369 .07465 .25504 .07626 .25455 .07504 .25335 Mtetra
.686 .741 .893 r
.07504 .25335 .07626 .25455 .07793 .25363 .07668 .25261 Mtetra
.678 .773 .922 r
.07668 .25261 .07793 .25363 .07958 .25287 .07832 .25192 Mtetra
.61 .771 .957 r
.07832 .25192 .07958 .25287 .08116 .25255 .07992 .25147 Mtetra
.364 .643 .962 r
.07992 .25147 .08116 .25255 .08249 .25402 .08145 .25158 Mtetra
.257 .355 .772 r
.08145 .25158 .08249 .25402 .08334 .25885 .08288 .25238 Mtetra
.246 .16 .556 r
.08288 .25238 .08334 .25885 .05576 .46285 .0841 .25461 Mtetra
0 0 .005 r
.0841 .25461 .05576 .46285 .05682 .46704 .05702 .45518 Mtetra
0 0 .203 r
.05702 .45518 .05682 .46704 .05827 .4685 .05727 .46506 Mtetra
0 0 .492 r
.05727 .46506 .05827 .4685 .05985 .46902 .05855 .46768 Mtetra
.374 .612 .943 r
.05855 .46768 .05985 .46902 .06154 .46879 .06019 .46784 Mtetra
.65 .795 .952 r
.06019 .46784 .06154 .46879 .06329 .4682 .06194 .46721 Mtetra
.724 .8 .912 r
.06194 .46721 .06329 .4682 .06506 .46743 .06374 .46625 Mtetra
.63 .747 .932 r
.06374 .46625 .06506 .46743 .06677 .46708 .06548 .46571 Mtetra
.63 .713 .907 r
.06548 .46571 .06677 .46708 .0685 .46661 .06722 .46516 Mtetra
.681 .717 .877 r
.06722 .46516 .0685 .46661 .0703 .46566 .069 .46437 Mtetra
.77 .757 .84 r
.069 .46437 .0703 .46566 .07235 .46288 .07086 .46297 Mtetra
.891 .945 .838 r
.07086 .46297 .07235 .46288 .07485 .45683 .07283 .46082 Mtetra
0 0 0 r
.07283 .46082 .07485 .45683 .10461 .25136 .07499 .45721 Mtetra
0 0 .012 r
.07499 .45721 .10461 .25136 .10695 .24567 .10387 .25815 Mtetra
0 0 0 r
.10387 .25815 .10695 .24567 .10887 .24309 .10735 .24412 Mtetra
.963 .937 .697 r
.10735 .24412 .10887 .24309 .11066 .24142 .10941 .24043 Mtetra
.798 .794 .849 r
.10941 .24043 .11066 .24142 .11235 .24045 .11117 .239 Mtetra
.653 .694 .875 r
.11117 .239 .11235 .24045 .114 .23985 .11282 .23838 Mtetra
.567 .658 .898 r
.11282 .23838 .114 .23985 .11562 .23946 .11443 .2381 Mtetra
.589 .686 .909 r
.11443 .2381 .11562 .23946 .11724 .23906 .11604 .23775 Mtetra
.598 .699 .914 r
.11604 .23775 .11724 .23906 .11887 .23865 .11767 .23735 Mtetra
.594 .701 .918 r
.11767 .23735 .11887 .23865 .12049 .23824 .11929 .23697 Mtetra
.615 .713 .915 r
.11929 .23697 .12049 .23824 .12213 .23776 .12092 .23652 Mtetra
.63 .722 .913 r
.12092 .23652 .12213 .23776 .12377 .23723 .12256 .23601 Mtetra
.638 .728 .913 r
.12256 .23601 .12377 .23723 .12542 .23667 .12421 .23546 Mtetra
.638 .731 .915 r
.12421 .23546 .12542 .23667 .12707 .23612 .12586 .23492 Mtetra
.642 .734 .915 r
.12586 .23492 .12707 .23612 .12872 .23556 .12751 .23436 Mtetra
.652 .738 .913 r
.12751 .23436 .12872 .23556 .13038 .23495 .12917 .23376 Mtetra
.669 .744 .906 r
.12917 .23376 .13038 .23495 .13205 .23428 .13084 .23309 Mtetra
.681 .748 .902 r
.13084 .23309 .13205 .23428 .13373 .23354 .13252 .23236 Mtetra
.686 .75 .9 r
.13252 .23236 .13373 .23354 .13541 .23279 .1342 .23161 Mtetra
.756 .764 .859 r
.1342 .23161 .13541 .23279 .13714 .23162 .13593 .23045 Mtetra
.738 .762 .872 r
.13593 .23045 .13714 .23162 .13886 .23057 .13765 .2294 Mtetra
.587 .723 .938 r
.13765 .2294 .13886 .23057 .1405 .23019 .13929 .22903 Mtetra
.862 .416 .03 r
.13929 .22903 .1405 .23019 .14174 .23299 .14052 .23188 Mtetra
.948 .684 .504 r
.14052 .23188 .14174 .23299 .1174 .44065 .11606 .43974 Mtetra
.937 .591 .344 r
.11606 .43974 .1174 .44065 .11821 .44782 .11689 .44675 Mtetra
0 .184 .647 r
.11689 .44675 .11821 .44782 .11977 .44902 .11847 .44783 Mtetra
.647 .754 .927 r
.11847 .44783 .11977 .44902 .12155 .44849 .12026 .4472 Mtetra
.765 .763 .851 r
.12026 .4472 .12155 .44849 .12343 .44706 .12213 .44586 Mtetra
.795 .779 .838 r
.12213 .44586 .12343 .44706 .12549 .44426 .12404 .44428 Mtetra
.875 .954 .856 r
.12404 .44428 .12549 .44426 .1279 .43851 .126 .44229 Mtetra
0 0 0 r
.126 .44229 .1279 .43851 .15453 .23299 .1281 .43915 Mtetra
.47 .233 .472 r
.1281 .43915 .15453 .23299 .1569 .22666 .13114 .42823 Mtetra
0 0 .028 r
.13114 .42823 .1569 .22666 .15882 .22405 .15723 .22606 Mtetra
.926 .94 .587 r
.15723 .22606 .15882 .22405 .16062 .22236 .15935 .22177 Mtetra
.862 .857 .834 r
.15935 .22177 .16062 .22236 .16238 .2211 .16119 .21987 Mtetra
.701 .747 .887 r
.16119 .21987 .16238 .2211 .16409 .22023 .16289 .21903 Mtetra
.575 .714 .937 r
.16289 .21903 .16409 .22023 .16574 .21988 .16454 .21869 Mtetra
.45 .664 .954 r
.16454 .21869 .16574 .21988 .16725 .22077 .16616 .21867 Mtetra
.372 .468 .829 r
.16616 .21867 .16725 .22077 .16846 .22415 .16772 .21909 Mtetra
.32 .249 .619 r
.16772 .21909 .16846 .22415 .14644 .42712 .16917 .22052 Mtetra
.477 .244 .482 r
.16917 .22052 .14644 .42712 .14733 .43437 .16988 .22828 Mtetra
0 0 .061 r
.16988 .22828 .14733 .43437 .14884 .43627 .14795 .4316 Mtetra
0 0 .44 r
.14795 .4316 .14884 .43627 .15049 .43701 .14926 .43527 Mtetra
.132 .402 .851 r
.14926 .43527 .15049 .43701 .15223 .43693 .15091 .43606 Mtetra
.6 .807 .979 r
.15091 .43606 .15223 .43693 .15404 .43632 .1527 .43555 Mtetra
.711 .85 .948 r
.1527 .43555 .15404 .43632 .15587 .4355 .15455 .43464 Mtetra
.696 .83 .947 r
.15455 .43464 .15587 .4355 .1577 .43473 .15638 .43379 Mtetra
.645 .804 .96 r
.15638 .43379 .1577 .43473 .15952 .4341 .1582 .43315 Mtetra
.636 .8 .961 r
.1582 .43315 .15952 .4341 .16133 .43352 .16001 .43254 Mtetra
.609 .787 .967 r
.16001 .43254 .16133 .43352 .16312 .43304 .16182 .43202 Mtetra
.587 .772 .968 r
.16182 .43202 .16312 .43304 .16492 .43264 .16362 .43157 Mtetra
.591 .765 .962 r
.16362 .43157 .16492 .43264 .16671 .43224 .16542 .43112 Mtetra
.612 .763 .951 r
.16542 .43112 .16671 .43224 .16851 .43176 .16722 .43061 Mtetra
.635 .763 .94 r
.16722 .43061 .16851 .43176 .17033 .43119 .16904 .43002 Mtetra
.649 .762 .932 r
.16904 .43002 .17033 .43119 .17215 .43057 .17087 .42937 Mtetra
.669 .764 .921 r
.17087 .42937 .17215 .43057 .17398 .42987 .1727 .42864 Mtetra
.684 .763 .911 r
.1727 .42864 .17398 .42987 .17582 .42909 .17455 .42784 Mtetra
.686 .758 .907 r
.17455 .42784 .17582 .42909 .17767 .4283 .17639 .42702 Mtetra
.672 .75 .909 r
.17639 .42702 .17767 .4283 .1795 .42757 .17823 .42627 Mtetra
.654 .741 .914 r
.17823 .42627 .1795 .42757 .18134 .42692 .18007 .4256 Mtetra
.646 .736 .915 r
.18007 .4256 .18134 .42692 .18316 .42629 .1819 .42496 Mtetra
.644 .734 .914 r
.1819 .42496 .18316 .42629 .18499 .42568 .18373 .42433 Mtetra
.644 .732 .913 r
.18373 .42433 .18499 .42568 .18683 .42506 .18556 .4237 Mtetra
.643 .73 .912 r
.18556 .4237 .18683 .42506 .18866 .42444 .1874 .42308 Mtetra
.621 .722 .919 r
.1874 .42308 .18866 .42444 .19048 .42398 .18922 .42255 Mtetra
.608 .705 .913 r
.18922 .42255 .19048 .42398 .19229 .42361 .19104 .42207 Mtetra
.652 .703 .885 r
.19104 .42207 .19229 .42361 .19414 .42286 .19289 .42139 Mtetra
.751 .742 .844 r
.19289 .42139 .19414 .42286 .19611 .42085 .1948 .42008 Mtetra
.873 .841 .811 r
.1948 .42008 .19611 .42085 .19839 .41594 .1968 .4178 Mtetra
.715 .902 .532 r
.1968 .4178 .19839 .41594 .22052 .21285 .19888 .41485 Mtetra
.491 .251 .477 r
.19888 .41485 .22052 .21285 .2232 .20275 .20093 .41214 Mtetra
.495 .254 .478 r
.20093 .41214 .2232 .20275 .22498 .20152 .2028 .41121 Mtetra
.497 .256 .479 r
.2028 .41121 .22498 .20152 .22666 .20138 .2046 .41096 Mtetra
.2046 .41096 .22666 .20138 .22832 .20138 .20641 .41071 Mtetra
.496 .255 .479 r
.20641 .41071 .22832 .20138 .23005 .20075 .20825 .41011 Mtetra
.20825 .41011 .23005 .20075 .23178 .20013 .21009 .4095 Mtetra
.21009 .4095 .23178 .20013 .23351 .1995 .21194 .40888 Mtetra
.21194 .40888 .23351 .1995 .23524 .19884 .21379 .40824 Mtetra
.21379 .40824 .23524 .19884 .23698 .19817 .21564 .40759 Mtetra
.21564 .40759 .23698 .19817 .23872 .1975 .21749 .40695 Mtetra
.21749 .40695 .23872 .1975 .24046 .19685 .21935 .40631 Mtetra
.21935 .40631 .24046 .19685 .2422 .19619 .2212 .40567 Mtetra
.497 .256 .479 r
.2212 .40567 .2422 .19619 .24391 .19576 .22303 .40537 Mtetra
.498 .256 .479 r
.22303 .40537 .24391 .19576 .2456 .19567 .22482 .40544 Mtetra
.496 .255 .479 r
.22482 .40544 .2456 .19567 .24735 .19492 .2267 .40462 Mtetra
.488 .248 .477 r
.2267 .40462 .24735 .19492 .24925 .19257 .22887 .40055 Mtetra
0 0 .103 r
.22887 .40055 .24925 .19257 .25124 .18927 .24964 .19273 Mtetra
.873 .865 .418 r
.24964 .19273 .25124 .18927 .25315 .18677 .25191 .18637 Mtetra
.918 .872 .777 r
.25191 .18637 .25315 .18677 .25498 .18512 .25384 .18368 Mtetra
.707 .724 .863 r
.25384 .18368 .25498 .18512 .25674 .18431 .25561 .18274 Mtetra
.624 .675 .878 r
.25561 .18274 .25674 .18431 .25848 .18373 .25734 .18222 Mtetra
.603 .676 .892 r
.25734 .18222 .25848 .18373 .26021 .18319 .25907 .18178 Mtetra
.66 .714 .889 r
.25907 .18178 .26021 .18319 .26196 .18251 .26082 .1811 Mtetra
.659 .715 .89 r
.26082 .1811 .26196 .18251 .26371 .18182 .26257 .18043 Mtetra
.659 .717 .891 r
.26257 .18043 .26371 .18182 .26547 .18114 .26432 .17976 Mtetra
.66 .719 .892 r
.26432 .17976 .26547 .18114 .26722 .18045 .26607 .17908 Mtetra
.66 .72 .893 r
.26607 .17908 .26722 .18045 .26898 .17977 .26783 .1784 Mtetra
.66 .721 .894 r
.26783 .1784 .26898 .17977 .27073 .17909 .26959 .17772 Mtetra
.661 .723 .895 r
.26959 .17772 .27073 .17909 .27249 .17839 .27134 .17704 Mtetra
.657 .723 .898 r
.27134 .17704 .27249 .17839 .27425 .17772 .2731 .17638 Mtetra
.645 .721 .904 r
.2731 .17638 .27425 .17772 .276 .1771 .27485 .17577 Mtetra
.621 .715 .914 r
.27485 .17577 .276 .1771 .27775 .17657 .2766 .17526 Mtetra
.623 .72 .916 r
.2766 .17526 .27775 .17657 .2795 .17603 .27835 .17474 Mtetra
.645 .732 .913 r
.27835 .17474 .2795 .17603 .28126 .17539 .28011 .17414 Mtetra
.689 .752 .9 r
.28011 .17414 .28126 .17539 .28303 .17454 .28188 .17334 Mtetra
.697 .762 .902 r
.28188 .17334 .28303 .17454 .28482 .17366 .28366 .17249 Mtetra
.7 .77 .906 r
.28366 .17249 .28482 .17366 .2866 .17276 .28544 .17164 Mtetra
.704 .781 .912 r
.28544 .17164 .2866 .17276 .28839 .17176 .28722 .17078 Mtetra
.664 .798 .946 r
.28722 .17078 .28839 .17176 .29016 .17108 .28899 .17009 Mtetra
.536 .753 .976 r
.28899 .17009 .29016 .17108 .29187 .17116 .29073 .1698 Mtetra
.119 .446 .881 r
.29073 .1698 .29187 .17116 .29339 .17372 .2924 .17047 Mtetra
.233 .277 .703 r
.2924 .17047 .29339 .17372 .29406 .18746 .29402 .17177 Mtetra
.453 .261 .529 r
.29402 .17177 .29406 .18746 .28066 .38618 .29562 .17327 Mtetra
.501 .265 .488 r
.29562 .17327 .28066 .38618 .28252 .38608 .29743 .17218 Mtetra
.29743 .17218 .28252 .38608 .28445 .38506 .29923 .17129 Mtetra
.496 .261 .487 r
.29923 .17129 .28445 .38506 .28633 .38465 .30088 .17236 Mtetra
0 0 .164 r
.30088 .17236 .28633 .38465 .28802 .3868 .28726 .37915 Mtetra
0 0 .383 r
.28726 .37915 .28802 .3868 .28978 .38819 .28864 .38557 Mtetra
0 .084 .639 r
.28864 .38557 .28978 .38819 .29159 .38886 .29035 .38765 Mtetra
.474 .697 .966 r
.29035 .38765 .29159 .38886 .29346 .38873 .29222 .38753 Mtetra
.67 .773 .927 r
.29222 .38753 .29346 .38873 .29537 .38805 .29414 .38676 Mtetra
.757 .778 .871 r
.29414 .38676 .29537 .38805 .29734 .38659 .2961 .38546 Mtetra
.81 .811 .851 r
.2961 .38546 .29734 .38659 .29946 .38298 .29809 .38379 Mtetra
.838 .989 .721 r
.29809 .38379 .29946 .38298 .30192 .37447 .30013 .38127 Mtetra
0 0 .147 r
.30013 .38127 .30192 .37447 .31817 .16654 .30232 .37663 Mtetra
0 0 .154 r
.30232 .37663 .31817 .16654 .3202 .16233 .3186 .16773 Mtetra
0 0 0 r
.3186 .16773 .3202 .16233 .3221 .15998 .32087 .16018 Mtetra
.951 .937 .741 r
.32087 .16018 .3221 .15998 .32395 .15846 .32282 .1571 Mtetra
.706 .742 .88 r
.32282 .1571 .32395 .15846 .32575 .15772 .32463 .15618 Mtetra
.596 .672 .893 r
.32463 .15618 .32575 .15772 .32753 .15727 .32641 .15576 Mtetra
.533 .65 .91 r
.32641 .15576 .32753 .15727 .3293 .15691 .32817 .15557 Mtetra
.651 .727 .905 r
.32817 .15557 .3293 .15691 .33109 .15624 .32996 .15492 Mtetra
.664 .736 .903 r
.32996 .15492 .33109 .15624 .33289 .1555 .33176 .15421 Mtetra
.683 .748 .901 r
.33176 .15421 .33289 .1555 .3347 .15467 .33357 .15342 Mtetra
.777 .777 .853 r
.33357 .15342 .3347 .15467 .33655 .15327 .33541 .15204 Mtetra
.716 .77 .895 r
.33541 .15204 .33655 .15327 .33837 .15229 .33723 .15109 Mtetra
.491 .692 .957 r
.33723 .15109 .33837 .15229 .34013 .15212 .339 .15095 Mtetra
.908 .503 .128 r
.339 .15095 .34013 .15212 .34161 .15677 .34046 .15583 Mtetra
.966 .684 .447 r
.34046 .15583 .34161 .15677 .33043 .3693 .32919 .36836 Mtetra
.903 .49 .142 r
.32919 .36836 .33043 .3693 .33201 .37448 .33078 .37333 Mtetra
.48 .714 .973 r
.33078 .37333 .33201 .37448 .33391 .37437 .33269 .37317 Mtetra
.712 .79 .912 r
.33269 .37317 .33391 .37437 .33587 .37341 .33465 .37218 Mtetra
.776 .796 .87 r
.33465 .37218 .33587 .37341 .33785 .37204 .33664 .37076 Mtetra
.573 .731 .949 r
.33664 .37076 .33785 .37204 .33977 .37185 .33857 .37036 Mtetra
.607 .706 .914 r
.33857 .37036 .33977 .37185 .3417 .37141 .3405 .36986 Mtetra
.669 .719 .886 r
.3405 .36986 .3417 .37141 .34366 .37041 .34246 .36906 Mtetra
.795 .781 .84 r
.34246 .36906 .34366 .37041 .34577 .36692 .34446 .3674 Mtetra
.885 .991 .763 r
.34446 .3674 .34577 .36692 .34814 .35858 .34651 .36482 Mtetra
0 0 .119 r
.34651 .36482 .34814 .35858 .36154 .14953 .34869 .36011 Mtetra
0 0 .182 r
.34869 .36011 .36154 .14953 .36355 .14526 .36208 .15048 Mtetra
0 0 0 r
.36208 .15048 .36355 .14526 .36547 .14286 .36427 .1431 Mtetra
.956 .94 .723 r
.36427 .1431 .36547 .14286 .36734 .14123 .36622 .13987 Mtetra
.796 .767 .827 r
.36622 .13987 .36734 .14123 .36919 .13985 .36809 .13826 Mtetra
.674 .699 .866 r
.36809 .13826 .36919 .13985 .37102 .13904 .36992 .13747 Mtetra
.457 .604 .908 r
.36992 .13747 .37102 .13904 .37281 .13899 .37171 .13752 Mtetra
.78 .34 0 r
.37171 .13752 .37281 .13899 .37443 .14241 .37333 .14081 Mtetra
.969 .684 .435 r
.37333 .14081 .37443 .14241 .36561 .35399 .36445 .35207 Mtetra
.936 .572 .176 r
.36445 .35207 .36561 .35399 .36718 .36126 .36598 .35987 Mtetra
0 .368 .834 r
.36598 .35987 .36718 .36126 .36906 .36217 .36787 .36084 Mtetra
.608 .735 .935 r
.36787 .36084 .36906 .36217 .37102 .36162 .36982 .36031 Mtetra
.809 .792 .836 r
.36982 .36031 .37102 .36162 .37305 .35982 .37185 .35854 Mtetra
.943 .763 .63 r
.37185 .35854 .37305 .35982 .37528 .3535 .37408 .35229 Mtetra
.969 .69 .445 r
.37408 .35229 .37528 .3535 .38717 .13935 .38606 .13819 Mtetra
.947 .762 .62 r
.38606 .13819 .38717 .13935 .38926 .13318 .38815 .13194 Mtetra
.793 .788 .848 r
.38815 .13194 .38926 .13318 .39113 .1317 .39003 .13044 Mtetra
.612 .734 .932 r
.39003 .13044 .39113 .1317 .39296 .13122 .39185 .12994 Mtetra
.472 .668 .949 r
.39185 .12994 .39296 .13122 .39477 .13117 .39367 .12986 Mtetra
.691 .754 .9 r
.39367 .12986 .39477 .13117 .39661 .13047 .39551 .12902 Mtetra
.68 .725 .884 r
.39551 .12902 .39661 .13047 .39846 .12971 .39736 .1282 Mtetra
.581 .677 .906 r
.39736 .1282 .39846 .12971 .40029 .12916 .39919 .12783 Mtetra
0 .105 .63 r
.39919 .12783 .40029 .12916 .40211 .12917 .40094 .1294 Mtetra
.901 .508 .261 r
.40094 .1294 .40211 .12917 .4039 .12988 .40252 .13529 Mtetra
.964 .674 .434 r
.40252 .13529 .4039 .12988 .40563 .13202 .39586 .3433 Mtetra
.505 .262 .48 r
.39586 .3433 .40563 .13202 .39937 .33546 .39768 .3467 Mtetra
.528 .233 .411 r
.39768 .3467 .39937 .33546 .40089 .34634 .3996 .34782 Mtetra
.435 0 .008 r
.3996 .34782 .40089 .34634 .40275 .34906 .40155 .34814 Mtetra
.312 .679 .977 r
.40155 .34814 .40275 .34906 .4047 .34952 .40351 .34824 Mtetra
.561 .729 .954 r
.40351 .34824 .4047 .34952 .40668 .34908 .40549 .34786 Mtetra
.715 .794 .914 r
.40549 .34786 .40668 .34908 .40868 .34807 .4075 .34684 Mtetra
.89 .804 .758 r
.4075 .34684 .40868 .34807 .41071 .3465 .40958 .34387 Mtetra
.9 .697 .619 r
.40958 .34387 .41071 .3465 .41277 .34414 .41178 .33733 Mtetra
.967 .682 .44 r
.41178 .33733 .41277 .34414 .41487 .34026 .42117 .12658 Mtetra
.511 .273 .489 r
.42117 .12658 .41487 .34026 .42364 .14134 .42319 .12126 Mtetra
.559 .336 .533 r
.42319 .12126 .42364 .14134 .42612 .12274 .42511 .1188 Mtetra
.672 .528 .68 r
.42511 .1188 .42612 .12274 .42809 .11885 .42701 .11718 Mtetra
.707 .704 .845 r
.42701 .11718 .42809 .11885 .42998 .1173 .42888 .11614 Mtetra
.665 .775 .932 r
.42888 .11614 .42998 .1173 .43184 .11656 .43075 .11541 Mtetra
.632 .766 .944 r
.43075 .11541 .43184 .11656 .4337 .11612 .43261 .11482 Mtetra
.728 .769 .886 r
.43261 .11482 .4337 .11612 .43557 .11525 .43449 .11376 Mtetra
.715 .735 .867 r
.43449 .11376 .43557 .11525 .43745 .1143 .43637 .11273 Mtetra
.627 .689 .888 r
.43637 .11273 .43745 .1143 .43932 .1136 .43824 .11215 Mtetra
0 .224 .739 r
.43824 .11215 .43932 .1136 .44116 .11386 .44005 .11351 Mtetra
.905 .495 .184 r
.44005 .11351 .44116 .11386 .44298 .11501 .44175 .11902 Mtetra
.968 .674 .418 r
.44175 .11902 .44298 .11501 .44478 .11709 .43783 .32828 Mtetra
.502 .26 .48 r
.43783 .32828 .44478 .11709 .44662 .11813 .43976 .33067 Mtetra
.496 .255 .479 r
.43976 .33067 .44662 .11813 .4485 .11746 .44177 .33011 Mtetra
.494 .254 .478 r
.44177 .33011 .4485 .11746 .45039 .11608 .44381 .32868 Mtetra
.495 .254 .478 r
.44381 .32868 .45039 .11608 .45229 .11509 .44584 .32763 Mtetra
.496 .255 .479 r
.44584 .32763 .45229 .11509 .45417 .11431 .44786 .32689 Mtetra
.44786 .32689 .45417 .11431 .45606 .11355 .44988 .32615 Mtetra
.44988 .32615 .45606 .11355 .45795 .11281 .45191 .32543 Mtetra
.45191 .32543 .45795 .11281 .45983 .11209 .45393 .32473 Mtetra
.45393 .32473 .45983 .11209 .46172 .11138 .45596 .32403 Mtetra
.45596 .32403 .46172 .11138 .46362 .11067 .45799 .32334 Mtetra
.45799 .32334 .46362 .11067 .46551 .10997 .46002 .32265 Mtetra
.46002 .32265 .46551 .10997 .4674 .10928 .46205 .32197 Mtetra
.46205 .32197 .4674 .10928 .4693 .10858 .46408 .32128 Mtetra
.46408 .32128 .4693 .10858 .47119 .10788 .46612 .32059 Mtetra
.46612 .32059 .47119 .10788 .47309 .10717 .46815 .3199 Mtetra
.46815 .3199 .47309 .10717 .47499 .10647 .47019 .3192 Mtetra
.47019 .3192 .47499 .10647 .47689 .10576 .47223 .31851 Mtetra
.47223 .31851 .47689 .10576 .47879 .10504 .47427 .31781 Mtetra
.47427 .31781 .47879 .10504 .48069 .10432 .47631 .3171 Mtetra
.47631 .3171 .48069 .10432 .4826 .1036 .47836 .3164 Mtetra
.47836 .3164 .4826 .1036 .48451 .10287 .4804 .3157 Mtetra
.4804 .3157 .48451 .10287 .48641 .10215 .48245 .31499 Mtetra
.48245 .31499 .48641 .10215 .48832 .10142 .4845 .31428 Mtetra
.4845 .31428 .48832 .10142 .49023 .10068 .48655 .31357 Mtetra
.48655 .31357 .49023 .10068 .49214 .09995 .4886 .31286 Mtetra
.4886 .31286 .49214 .09995 .49406 .09921 .49065 .31214 Mtetra
.49065 .31214 .49406 .09921 .49597 .09847 .49271 .31143 Mtetra
.49271 .31143 .49597 .09847 .49789 .09774 .49476 .31071 Mtetra
.49476 .31071 .49789 .09774 .4998 .097 .49682 .31 Mtetra
.49682 .31 .4998 .097 .50172 .09625 .49888 .30928 Mtetra
.49888 .30928 .50172 .09625 .50364 .09551 .50094 .30856 Mtetra
.50094 .30856 .50364 .09551 .50556 .09477 .50301 .30784 Mtetra
.50301 .30784 .50556 .09477 .50748 .09403 .50507 .30712 Mtetra
.50507 .30712 .50748 .09403 .50941 .09328 .50714 .3064 Mtetra
.50714 .3064 .50941 .09328 .51133 .09254 .5092 .30568 Mtetra
.5092 .30568 .51133 .09254 .51326 .09179 .51127 .30496 Mtetra
.51127 .30496 .51326 .09179 .51519 .09104 .51334 .30424 Mtetra
.51334 .30424 .51519 .09104 .51712 .0903 .51541 .30352 Mtetra
.51541 .30352 .51712 .0903 .51905 .08955 .51749 .3028 Mtetra
.51749 .3028 .51905 .08955 .52098 .0888 .51956 .30207 Mtetra
.51956 .30207 .52098 .0888 .52291 .08805 .52164 .30135 Mtetra
.52164 .30135 .52291 .08805 .52485 .0873 .52372 .30062 Mtetra
.52372 .30062 .52485 .0873 .52678 .08655 .5258 .2999 Mtetra
.5258 .2999 .52678 .08655 .52872 .0858 .52788 .29917 Mtetra
.52788 .29917 .52872 .0858 .53066 .08505 .52996 .29845 Mtetra
.52996 .29845 .53066 .08505 .5326 .0843 .53205 .29772 Mtetra
.53205 .29772 .5326 .0843 .53454 .08355 .53413 .29699 Mtetra
.53413 .29699 .53454 .08355 .53648 .08279 .53622 .29626 Mtetra
.53622 .29626 .53648 .08279 .53843 .08204 .53831 .29554 Mtetra
.53831 .29554 .53843 .08204 .54037 .08129 .5404 .29481 Mtetra
.5404 .29481 .54037 .08129 .54232 .08053 .54249 .29408 Mtetra
.54249 .29408 .54232 .08053 .54427 .07978 .54459 .29335 Mtetra
.54459 .29335 .54427 .07978 .54622 .07902 .54668 .29261 Mtetra
.54668 .29261 .54622 .07902 .54817 .07826 .54878 .29188 Mtetra
.54878 .29188 .54817 .07826 .55012 .0775 .55088 .29115 Mtetra
.55088 .29115 .55012 .0775 .55207 .07674 .55298 .29042 Mtetra
.55298 .29042 .55207 .07674 .55403 .07598 .55508 .28968 Mtetra
.55508 .28968 .55403 .07598 .55599 .07522 .55718 .28894 Mtetra
.55718 .28894 .55599 .07522 .55794 .07445 .55929 .28821 Mtetra
.55929 .28821 .55794 .07445 .5599 .07369 .5614 .28747 Mtetra
.5614 .28747 .5599 .07369 .56186 .07292 .5635 .28673 Mtetra
.5635 .28673 .56186 .07292 .56383 .07215 .56561 .28599 Mtetra
.56561 .28599 .56383 .07215 .56579 .07138 .56773 .28524 Mtetra
.56773 .28524 .56579 .07138 .56775 .0706 .56984 .2845 Mtetra
.56984 .2845 .56775 .0706 .56972 .06982 .57195 .28375 Mtetra
.57195 .28375 .56972 .06982 .57169 .06904 .57407 .283 Mtetra
.57407 .283 .57169 .06904 .57365 .06825 .57619 .28225 Mtetra
.57619 .28225 .57365 .06825 .57562 .06746 .57831 .2815 Mtetra
.57831 .2815 .57562 .06746 .5776 .06667 .58043 .28074 Mtetra
.58043 .28074 .5776 .06667 .57957 .06587 .58255 .27999 Mtetra
.58255 .27999 .57957 .06587 .58154 .06508 .58468 .27923 Mtetra
.58468 .27923 .58154 .06508 .58352 .06428 .5868 .27847 Mtetra
.5868 .27847 .58352 .06428 .58549 .06349 .58893 .27772 Mtetra
.58893 .27772 .58549 .06349 .58747 .0627 .59106 .27696 Mtetra
.59106 .27696 .58747 .0627 .58945 .06192 .59319 .27621 Mtetra
.59319 .27621 .58945 .06192 .59143 .06115 .59532 .27546 Mtetra
.59532 .27546 .59143 .06115 .59342 .06038 .59745 .27471 Mtetra
.59745 .27471 .59342 .06038 .5954 .05961 .59959 .27397 Mtetra
.59959 .27397 .5954 .05961 .59739 .05885 .60173 .27322 Mtetra
.60173 .27322 .59739 .05885 .59937 .05808 .60387 .27248 Mtetra
.60387 .27248 .59937 .05808 .60136 .05732 .60601 .27173 Mtetra
.60601 .27173 .60136 .05732 .60335 .05654 .60815 .27098 Mtetra
.60815 .27098 .60335 .05654 .60534 .05576 .61029 .27022 Mtetra
.61029 .27022 .60534 .05576 .60734 .05496 .61244 .26945 Mtetra
.61244 .26945 .60734 .05496 .60933 .05414 .61459 .26866 Mtetra
.61459 .26866 .60933 .05414 .61132 .05328 .61673 .26785 Mtetra
.61673 .26785 .61132 .05328 .61332 .05241 .61888 .26704 Mtetra
.61888 .26704 .61332 .05241 .6153 .05131 .62103 .26609 Mtetra
.495 .254 .478 r
.62103 .26609 .6153 .05131 .61727 .04966 .62316 .26478 Mtetra
.496 .255 .479 r
.62316 .26478 .61727 .04966 .61928 .0489 .62532 .26398 Mtetra
.498 .257 .479 r
.62532 .26398 .61928 .0489 .62137 .05087 .62751 .26442 Mtetra
.501 .259 .479 r
.62751 .26442 .62137 .05087 .63064 .26193 .62976 .26628 Mtetra
.554 .182 .29 r
.62976 .26628 .63064 .26193 .63302 .26768 .63199 .26748 Mtetra
.138 0 0 r
.63199 .26748 .63302 .26768 .63528 .26948 .6342 .26791 Mtetra
.61 .716 .921 r
.6342 .26791 .63528 .26948 .63746 .26908 .63637 .26733 Mtetra
.66 .71 .885 r
.63637 .26733 .63746 .26908 .63962 .26819 .63854 .26649 Mtetra
.676 .725 .886 r
.63854 .26649 .63962 .26819 .64178 .26712 .6407 .26556 Mtetra
.648 .735 .913 r
.6407 .26556 .64178 .26712 .64395 .26635 .64288 .2648 Mtetra
.642 .734 .915 r
.64288 .2648 .64395 .26635 .64613 .2656 .64505 .26406 Mtetra
.63 .73 .92 r
.64505 .26406 .64613 .2656 .6483 .2649 .64723 .26338 Mtetra
.603 .722 .928 r
.64723 .26338 .6483 .2649 .65049 .26432 .64942 .26282 Mtetra
.6 .724 .932 r
.64942 .26282 .65049 .26432 .65267 .26375 .65161 .26227 Mtetra
.608 .732 .934 r
.65161 .26227 .65267 .26375 .65486 .26314 .6538 .26169 Mtetra
.633 .747 .93 r
.6538 .26169 .65486 .26314 .65705 .26244 .65598 .26099 Mtetra
.64 .752 .93 r
.65598 .26099 .65705 .26244 .65923 .2617 .65817 .26026 Mtetra
.643 .755 .93 r
.65817 .26026 .65923 .2617 .66142 .26095 .66036 .25952 Mtetra
.641 .755 .931 r
.66036 .25952 .66142 .26095 .66361 .26021 .66255 .25878 Mtetra
.643 .756 .931 r
.66255 .25878 .66361 .26021 .6658 .25946 .66474 .25803 Mtetra
.66474 .25803 .6658 .25946 .66799 .25871 .66693 .25728 Mtetra
.644 .757 .931 r
.66693 .25728 .66799 .25871 .67018 .25796 .66913 .25653 Mtetra
.645 .757 .931 r
.66913 .25653 .67018 .25796 .67238 .25721 .67132 .25577 Mtetra
.646 .758 .931 r
.67132 .25577 .67238 .25721 .67457 .25645 .67352 .25501 Mtetra
.67352 .25501 .67457 .25645 .67677 .25568 .67572 .25425 Mtetra
.647 .758 .93 r
.67572 .25425 .67677 .25568 .67897 .25492 .67792 .25348 Mtetra
.648 .759 .93 r
.67792 .25348 .67897 .25492 .68117 .25414 .68012 .25271 Mtetra
.649 .759 .93 r
.68012 .25271 .68117 .25414 .68338 .25337 .68233 .25193 Mtetra
.65 .76 .929 r
.68233 .25193 .68338 .25337 .68558 .25258 .68453 .25114 Mtetra
.652 .761 .929 r
.68453 .25114 .68558 .25258 .68778 .25179 .68674 .25035 Mtetra
.653 .761 .929 r
.68674 .25035 .68778 .25179 .68999 .25098 .68895 .24954 Mtetra
.656 .763 .928 r
.68895 .24954 .68999 .25098 .6922 .25017 .69115 .24873 Mtetra
.66 .764 .927 r
.69115 .24873 .6922 .25017 .69441 .24933 .69336 .24789 Mtetra
.659 .764 .928 r
.69336 .24789 .69441 .24933 .69662 .2485 .69557 .24706 Mtetra
.669 .768 .925 r
.69557 .24706 .69662 .2485 .69882 .24762 .69779 .24618 Mtetra
.685 .775 .919 r
.69779 .24618 .69882 .24762 .70103 .24665 .69999 .24522 Mtetra
.731 .792 .901 r
.69999 .24522 .70103 .24665 .70322 .24542 .70219 .24399 Mtetra
.743 .798 .896 r
.70219 .24399 .70322 .24542 .70541 .24411 .70438 .24269 Mtetra
.745 .8 .897 r
.70438 .24269 .70541 .24411 .7076 .2428 .70657 .24138 Mtetra
.692 .772 .913 r
.00553 .48368 .00688 .48477 .00863 .48389 .00727 .48288 Mtetra
.696 .789 .922 r
.00727 .48288 .00863 .48389 .01037 .48311 .00901 .48208 Mtetra
.691 .783 .921 r
.00901 .48208 .01037 .48311 .0121 .48243 .01076 .48129 Mtetra
.665 .76 .921 r
.01076 .48129 .0121 .48243 .01382 .48179 .01248 .48062 Mtetra
.649 .749 .923 r
.01248 .48062 .01382 .48179 .01553 .48124 .0142 .48001 Mtetra
.632 .735 .922 r
.0142 .48001 .01553 .48124 .01722 .48078 .0159 .47947 Mtetra
.604 .712 .921 r
.0159 .47947 .01722 .48078 .01886 .4807 .0176 .47904 Mtetra
.597 .653 .876 r
.0176 .47904 .01886 .4807 .02052 .48048 .01928 .47864 Mtetra
.596 .628 .854 r
.01928 .47864 .02052 .48048 .02223 .47993 .02097 .47823 Mtetra
.613 .655 .867 r
.02097 .47823 .02223 .47993 .02414 .47809 .02268 .47776 Mtetra
.524 .874 .988 r
.02268 .47776 .02414 .47809 .02616 .47549 .02438 .47727 Mtetra
.209 0 0 r
.02438 .47727 .02616 .47549 .02829 .47217 .02609 .47676 Mtetra
.463 .119 .297 r
.02609 .47676 .02829 .47217 .02996 .47195 .02772 .47678 Mtetra
.421 .082 .283 r
.02772 .47678 .02996 .47195 .03159 .47192 .02941 .47643 Mtetra
.294 0 .206 r
.02941 .47643 .03159 .47192 .0334 .47079 .03121 .47531 Mtetra
.728 .821 .361 r
.03121 .47531 .0334 .47079 .06474 .27109 .03366 .46989 Mtetra
0 0 0 r
.03366 .46989 .06474 .27109 .06803 .25924 .06621 .26204 Mtetra
.986 .896 .577 r
.06621 .26204 .06803 .25924 .07011 .25554 .06875 .25523 Mtetra
.839 .904 .883 r
.06875 .25523 .07011 .25554 .07183 .2543 .07051 .25371 Mtetra
.633 .852 .983 r
.07051 .25371 .07183 .2543 .07345 .25369 .07213 .25312 Mtetra
.429 .789 .996 r
.07213 .25312 .07345 .25369 .07504 .25335 .0737 .25292 Mtetra
.65 .89 .983 r
.0737 .25292 .07504 .25335 .07668 .25261 .07533 .25225 Mtetra
.671 .906 .977 r
.07533 .25225 .07668 .25261 .07832 .25192 .07698 .2515 Mtetra
.668 .894 .978 r
.07698 .2515 .07832 .25192 .07992 .25147 .07863 .25077 Mtetra
.754 .847 .921 r
.07863 .25077 .07992 .25147 .08145 .25158 .08032 .24976 Mtetra
.663 .645 .822 r
.08032 .24976 .08145 .25158 .08288 .25238 .08197 .24901 Mtetra
.53 .454 .715 r
.08197 .24901 .08288 .25238 .0841 .25461 .08352 .24892 Mtetra
0 0 .469 r
.08352 .24892 .0841 .25461 .05702 .45518 .08458 .25232 Mtetra
0 0 0 r
.08458 .25232 .05702 .45518 .05727 .46506 .05667 .4588 Mtetra
0 0 .102 r
.05667 .4588 .05727 .46506 .05855 .46768 .05737 .46547 Mtetra
.265 .408 .82 r
.05737 .46547 .05855 .46768 .06019 .46784 .05894 .46616 Mtetra
.624 .665 .869 r
.05894 .46616 .06019 .46784 .06194 .46721 .06067 .46564 Mtetra
.707 .706 .847 r
.06067 .46564 .06194 .46721 .06374 .46625 .06248 .46464 Mtetra
.657 .686 .866 r
.06248 .46464 .06374 .46625 .06548 .46571 .06424 .46395 Mtetra
.64 .661 .854 r
.06424 .46395 .06548 .46571 .06722 .46516 .06599 .46333 Mtetra
.643 .652 .844 r
.06599 .46333 .06722 .46516 .069 .46437 .06775 .46268 Mtetra
.555 .636 .886 r
.06775 .46268 .069 .46437 .07086 .46297 .06945 .46244 Mtetra
.545 .849 .998 r
.06945 .46244 .07086 .46297 .07283 .46082 .07118 .46198 Mtetra
0 0 0 r
.07118 .46198 .07283 .46082 .07499 .45721 .07301 .46083 Mtetra
.75 .851 .41 r
.07301 .46083 .07499 .45721 .10387 .25815 .07534 .45609 Mtetra
0 0 0 r
.07534 .45609 .10387 .25815 .10735 .24412 .10541 .24818 Mtetra
.96 .887 .498 r
.10541 .24818 .10735 .24412 .10941 .24043 .10806 .24023 Mtetra
.878 .91 .847 r
.10806 .24023 .10941 .24043 .11117 .239 .10989 .23833 Mtetra
.651 .843 .974 r
.10989 .23833 .11117 .239 .11282 .23838 .11154 .2377 Mtetra
.442 .772 .997 r
.11154 .2377 .11282 .23838 .11443 .2381 .11313 .23752 Mtetra
.587 .846 .994 r
.11313 .23752 .11443 .2381 .11604 .23775 .11476 .23703 Mtetra
.656 .836 .969 r
.11476 .23703 .11604 .23775 .11767 .23735 .11642 .23639 Mtetra
.658 .785 .942 r
.11642 .23639 .11767 .23735 .11929 .23697 .11808 .23577 Mtetra
.641 .733 .916 r
.11808 .23577 .11929 .23697 .12092 .23652 .11972 .23522 Mtetra
.63 .712 .906 r
.11972 .23522 .12092 .23652 .12256 .23601 .12137 .23471 Mtetra
.628 .712 .907 r
.12137 .23471 .12256 .23601 .12421 .23546 .12301 .2342 Mtetra
.634 .72 .91 r
.12301 .2342 .12421 .23546 .12586 .23492 .12466 .23367 Mtetra
.641 .726 .91 r
.12466 .23367 .12586 .23492 .12751 .23436 .12631 .23312 Mtetra
.65 .729 .907 r
.12631 .23312 .12751 .23436 .12917 .23376 .12797 .23253 Mtetra
.666 .735 .901 r
.12797 .23253 .12917 .23376 .13084 .23309 .12963 .23186 Mtetra
.677 .74 .898 r
.12963 .23186 .13084 .23309 .13252 .23236 .13131 .23115 Mtetra
.682 .744 .898 r
.13131 .23115 .13252 .23236 .1342 .23161 .13299 .23041 Mtetra
.75 .76 .861 r
.13299 .23041 .1342 .23161 .13593 .23045 .13472 .22928 Mtetra
.735 .763 .876 r
.13472 .22928 .13593 .23045 .13765 .2294 .13644 .22826 Mtetra
.592 .731 .94 r
.13644 .22826 .13765 .2294 .13929 .22903 .13808 .22787 Mtetra
.826 .362 0 r
.13808 .22787 .13929 .22903 .14052 .23188 .13935 .23038 Mtetra
.948 .685 .504 r
.13935 .23038 .14052 .23188 .11606 .43974 .11504 .43633 Mtetra
.966 .653 .261 r
.11504 .43633 .11606 .43974 .11689 .44675 .11569 .44475 Mtetra
0 .232 .75 r
.11569 .44475 .11689 .44675 .11847 .44783 .11724 .446 Mtetra
.604 .64 .859 r
.11724 .446 .11847 .44783 .12026 .4472 .11901 .44554 Mtetra
.701 .697 .844 r
.11901 .44554 .12026 .4472 .12213 .44586 .12084 .44456 Mtetra
.621 .727 .922 r
.12084 .44456 .12213 .44586 .12404 .44428 .12262 .44404 Mtetra
.428 .847 .959 r
.12262 .44404 .12404 .44428 .126 .44229 .12439 .44363 Mtetra
0 0 0 r
.12439 .44363 .126 .44229 .1281 .43915 .12623 .44257 Mtetra
.12623 .44257 .1281 .43915 .13114 .42823 .12842 .43872 Mtetra
.96 .704 .504 r
.12842 .43872 .13114 .42823 .15723 .22606 .15511 .23245 Mtetra
.925 .844 .397 r
.15511 .23245 .15723 .22606 .15935 .22177 .15808 .22116 Mtetra
.894 .835 .78 r
.15808 .22116 .15935 .22177 .16119 .21987 .15999 .21863 Mtetra
.697 .746 .889 r
.15999 .21863 .16119 .21987 .16289 .21903 .1617 .21781 Mtetra
.572 .712 .937 r
.1617 .21781 .16289 .21903 .16454 .21869 .16334 .21749 Mtetra
.673 .746 .905 r
.16334 .21749 .16454 .21869 .16616 .21867 .16504 .21679 Mtetra
.68 .65 .813 r
.16504 .21679 .16616 .21867 .16772 .21909 .16675 .21591 Mtetra
.569 .49 .727 r
.16675 .21591 .16772 .21909 .16917 .22052 .16841 .21556 Mtetra
.233 .191 .603 r
.16841 .21556 .16917 .22052 .16988 .22828 .16981 .21742 Mtetra
.962 .699 .489 r
.16981 .21742 .16988 .22828 .14795 .4316 .14829 .4164 Mtetra
0 0 .079 r
.14829 .4164 .14795 .4316 .14926 .43527 .14814 .43255 Mtetra
0 .126 .663 r
.14814 .43255 .14926 .43527 .15091 .43606 .14968 .43432 Mtetra
.597 .65 .874 r
.14968 .43432 .15091 .43606 .1527 .43555 .15146 .43389 Mtetra
.704 .701 .845 r
.15146 .43389 .1527 .43555 .15455 .43464 .15332 .43288 Mtetra
.687 .684 .841 r
.15332 .43288 .15455 .43464 .15638 .43379 .15517 .43196 Mtetra
.639 .657 .851 r
.15517 .43196 .15638 .43379 .1582 .43315 .15698 .43132 Mtetra
.15698 .43132 .1582 .43315 .16001 .43254 .1588 .43068 Mtetra
.636 .652 .849 r
.1588 .43068 .16001 .43254 .16182 .43202 .16062 .43005 Mtetra
.63 .637 .838 r
.16062 .43005 .16182 .43202 .16362 .43157 .16243 .42944 Mtetra
.626 .617 .821 r
.16243 .42944 .16362 .43157 .16542 .43112 .16425 .42883 Mtetra
.625 .6 .805 r
.16425 .42883 .16542 .43112 .16722 .43061 .16607 .4282 Mtetra
.625 .589 .794 r
.16607 .4282 .16722 .43061 .16904 .43002 .16789 .42755 Mtetra
.622 .583 .789 r
.16789 .42755 .16904 .43002 .17087 .42937 .16972 .42691 Mtetra
.615 .58 .791 r
.16972 .42691 .17087 .42937 .1727 .42864 .17154 .42632 Mtetra
.612 .591 .805 r
.17154 .42632 .1727 .42864 .17455 .42784 .17336 .42576 Mtetra
.618 .619 .83 r
.17336 .42576 .17455 .42784 .17639 .42702 .17518 .4252 Mtetra
.632 .656 .856 r
.17518 .4252 .17639 .42702 .17823 .42627 .177 .4246 Mtetra
.645 .682 .87 r
.177 .4246 .17823 .42627 .18007 .4256 .17883 .42394 Mtetra
.648 .684 .87 r
.17883 .42394 .18007 .4256 .1819 .42496 .18067 .42327 Mtetra
.645 .678 .867 r
.18067 .42327 .1819 .42496 .18373 .42433 .1825 .42261 Mtetra
.64 .672 .865 r
.1825 .42261 .18373 .42433 .18556 .4237 .18434 .42197 Mtetra
.638 .67 .864 r
.18434 .42197 .18556 .4237 .1874 .42308 .18617 .42134 Mtetra
.634 .668 .865 r
.18617 .42134 .1874 .42308 .18922 .42255 .18801 .42073 Mtetra
.63 .656 .857 r
.18801 .42073 .18922 .42255 .19104 .42207 .18984 .42013 Mtetra
.628 .64 .843 r
.18984 .42013 .19104 .42207 .19289 .42139 .19168 .41953 Mtetra
.635 .653 .85 r
.19168 .41953 .19289 .42139 .1948 .42008 .19352 .4189 Mtetra
.652 .764 .931 r
.19352 .4189 .1948 .42008 .1968 .4178 .19536 .41823 Mtetra
.281 .774 .714 r
.19536 .41823 .1968 .4178 .19888 .41485 .19721 .41757 Mtetra
.29 0 .094 r
.19721 .41757 .19888 .41485 .20093 .41214 .19905 .41693 Mtetra
.391 .052 .266 r
.19905 .41693 .20093 .41214 .2028 .41121 .20089 .41632 Mtetra
.399 .066 .28 r
.20089 .41632 .2028 .41121 .2046 .41096 .20274 .41572 Mtetra
.39 .05 .265 r
.20274 .41572 .2046 .41096 .20641 .41071 .20458 .41511 Mtetra
.377 .031 .245 r
.20458 .41511 .20641 .41071 .20825 .41011 .20643 .41449 Mtetra
.376 .029 .243 r
.20643 .41449 .20825 .41011 .21009 .4095 .20828 .41385 Mtetra
.374 .026 .241 r
.20828 .41385 .21009 .4095 .21194 .40888 .21013 .41321 Mtetra
.372 .024 .239 r
.21013 .41321 .21194 .40888 .21379 .40824 .21199 .41256 Mtetra
.21199 .41256 .21379 .40824 .21564 .40759 .21384 .41191 Mtetra
.21384 .41191 .21564 .40759 .21749 .40695 .2157 .41126 Mtetra
.373 .024 .239 r
.2157 .41126 .21749 .40695 .21935 .40631 .21756 .41062 Mtetra
.372 .023 .238 r
.21756 .41062 .21935 .40631 .2212 .40567 .21942 .40997 Mtetra
.397 .046 .249 r
.21942 .40997 .2212 .40567 .22303 .40537 .22126 .4095 Mtetra
.422 .066 .253 r
.22126 .4095 .22303 .40537 .22482 .40544 .22309 .40925 Mtetra
.334 0 .196 r
.22309 .40925 .22482 .40544 .2267 .40462 .22496 .40848 Mtetra
0 0 .031 r
.22496 .40848 .2267 .40462 .22887 .40055 .22699 .40607 Mtetra
.876 .828 .355 r
.22699 .40607 .22887 .40055 .24964 .19273 .22969 .39628 Mtetra
0 0 .085 r
.22969 .39628 .24964 .19273 .25191 .18637 .25057 .18701 Mtetra
.973 .917 .68 r
.25057 .18701 .25191 .18637 .25384 .18368 .25262 .183 Mtetra
.754 .871 .933 r
.25262 .183 .25384 .18368 .25561 .18274 .2544 .18193 Mtetra
.587 .809 .984 r
.2544 .18193 .25561 .18274 .25734 .18222 .25613 .18147 Mtetra
.519 .797 .996 r
.25613 .18147 .25734 .18222 .25907 .18178 .25785 .18114 Mtetra
.645 .862 .981 r
.25785 .18114 .25907 .18178 .26082 .1811 .2596 .18047 Mtetra
.641 .862 .983 r
.2596 .18047 .26082 .1811 .26257 .18043 .26135 .17981 Mtetra
.64 .865 .983 r
.26135 .17981 .26257 .18043 .26432 .17976 .26311 .17915 Mtetra
.643 .868 .983 r
.26311 .17915 .26432 .17976 .26607 .17908 .26486 .17847 Mtetra
.642 .869 .984 r
.26486 .17847 .26607 .17908 .26783 .1784 .26661 .1778 Mtetra
.638 .869 .985 r
.26661 .1778 .26783 .1784 .26959 .17772 .26837 .17714 Mtetra
.629 .869 .987 r
.26837 .17714 .26959 .17772 .27134 .17704 .27013 .17649 Mtetra
.628 .877 .988 r
.27013 .17649 .27134 .17704 .2731 .17638 .27188 .17584 Mtetra
.639 .882 .986 r
.27188 .17584 .2731 .17638 .27485 .17577 .27364 .17515 Mtetra
.669 .873 .976 r
.27364 .17515 .27485 .17577 .2766 .17526 .27541 .17439 Mtetra
.682 .825 .952 r
.27541 .17439 .2766 .17526 .27835 .17474 .27718 .17363 Mtetra
.677 .775 .924 r
.27718 .17363 .27835 .17474 .28011 .17414 .27895 .1729 Mtetra
.661 .746 .912 r
.27895 .1729 .28011 .17414 .28188 .17334 .28072 .17222 Mtetra
.659 .769 .931 r
.28072 .17222 .28188 .17334 .28366 .17249 .28248 .17156 Mtetra
.658 .805 .953 r
.28248 .17156 .28366 .17249 .28544 .17164 .28425 .17089 Mtetra
.66 .844 .971 r
.28425 .17089 .28544 .17164 .28722 .17078 .28602 .17019 Mtetra
.647 .875 .983 r
.28602 .17019 .28722 .17078 .28899 .17009 .28779 .16949 Mtetra
.645 .872 .983 r
.28779 .16949 .28899 .17009 .29073 .1698 .28956 .1688 Mtetra
.657 .793 .947 r
.28956 .1688 .29073 .1698 .2924 .17047 .29133 .16814 Mtetra
.628 .589 .79 r
.29133 .16814 .2924 .17047 .29402 .17177 .2931 .16748 Mtetra
.594 .465 .674 r
.2931 .16748 .29402 .17177 .29562 .17327 .29488 .16672 Mtetra
.59 .417 .615 r
.29488 .16672 .29562 .17327 .29743 .17218 .29669 .16559 Mtetra
.564 .397 .614 r
.29669 .16559 .29743 .17218 .29923 .17129 .29847 .16487 Mtetra
.485 .343 .612 r
.29847 .16487 .29923 .17129 .30088 .17236 .30017 .1652 Mtetra
0 0 .398 r
.30017 .1652 .30088 .17236 .28726 .37915 .30147 .17097 Mtetra
0 0 .145 r
.30147 .17097 .28726 .37915 .28864 .38557 .28762 .38149 Mtetra
0 0 .401 r
.28762 .38149 .28864 .38557 .29035 .38765 .28917 .38562 Mtetra
.485 .566 .863 r
.28917 .38562 .29035 .38765 .29222 .38753 .29103 .38565 Mtetra
.647 .662 .851 r
.29103 .38565 .29222 .38753 .29414 .38676 .29295 .38493 Mtetra
.691 .686 .84 r
.29295 .38493 .29414 .38676 .2961 .38546 .29488 .38394 Mtetra
.544 .67 .92 r
.29488 .38394 .2961 .38546 .29809 .38379 .29677 .38368 Mtetra
.513 .904 .937 r
.29677 .38368 .29809 .38379 .30013 .38127 .29869 .38297 Mtetra
0 0 0 r
.29869 .38297 .30013 .38127 .30232 .37663 .30068 .38124 Mtetra
.713 .762 .262 r
.30068 .38124 .30232 .37663 .3186 .16773 .30304 .37432 Mtetra
0 0 .136 r
.30304 .37432 .3186 .16773 .32087 .16018 .31951 .16207 Mtetra
.958 .906 .534 r
.31951 .16207 .32087 .16018 .32282 .1571 .32164 .15649 Mtetra
.799 .895 .912 r
.32164 .15649 .32282 .1571 .32463 .15618 .32348 .15516 Mtetra
.647 .789 .95 r
.32348 .15516 .32463 .15618 .32641 .15576 .32527 .15452 Mtetra
.556 .712 .945 r
.32527 .15452 .32641 .15576 .32817 .15557 .32704 .15422 Mtetra
.66 .73 .902 r
.32704 .15422 .32817 .15557 .32996 .15492 .32884 .15353 Mtetra
.655 .722 .898 r
.32884 .15353 .32996 .15492 .33176 .15421 .33064 .15286 Mtetra
.66 .731 .902 r
.33064 .15286 .33176 .15421 .33357 .15342 .33244 .15217 Mtetra
.753 .774 .87 r
.33244 .15217 .33357 .15342 .33541 .15204 .33427 .15098 Mtetra
.691 .793 .928 r
.33427 .15098 .33541 .15204 .33723 .15109 .33608 .15017 Mtetra
.4 .709 .985 r
.33608 .15017 .33723 .15109 .339 .15095 .33784 .15014 Mtetra
.905 .493 .155 r
.33784 .15014 .339 .15095 .34046 .15583 .33931 .15481 Mtetra
.966 .684 .447 r
.33931 .15481 .34046 .15583 .32919 .36836 .32803 .3662 Mtetra
.864 .479 0 r
.32803 .3662 .32919 .36836 .33078 .37333 .32961 .37134 Mtetra
.473 .566 .869 r
.32961 .37134 .33078 .37333 .33269 .37317 .3315 .3714 Mtetra
.654 .682 .864 r
.3315 .3714 .33269 .37317 .33465 .37218 .33345 .37065 Mtetra
.73 .741 .861 r
.33345 .37065 .33465 .37218 .33664 .37076 .33542 .36947 Mtetra
.65 .755 .927 r
.33542 .36947 .33664 .37076 .33857 .37036 .33737 .36878 Mtetra
.653 .709 .889 r
.33737 .36878 .33857 .37036 .3405 .36986 .33932 .36806 Mtetra
.654 .679 .861 r
.33932 .36806 .3405 .36986 .34246 .36906 .34127 .3673 Mtetra
.552 .641 .892 r
.34127 .3673 .34246 .36906 .34446 .3674 .3432 .36703 Mtetra
.558 .897 .981 r
.3432 .36703 .34446 .3674 .34651 .36482 .34515 .36636 Mtetra
0 0 0 r
.34515 .36636 .34651 .36482 .34869 .36011 .34714 .36485 Mtetra
.34714 .36485 .34869 .36011 .36208 .15048 .34944 .35787 Mtetra
0 0 .166 r
.34944 .35787 .36208 .15048 .36427 .1431 .36298 .14488 Mtetra
.958 .901 .526 r
.36298 .14488 .36427 .1431 .36622 .13987 .36507 .13922 Mtetra
.861 .885 .853 r
.36507 .13922 .36622 .13987 .36809 .13826 .36696 .13736 Mtetra
.683 .827 .953 r
.36696 .13736 .36809 .13826 .36992 .13747 .36879 .13657 Mtetra
.273 .646 .966 r
.36879 .13657 .36992 .13747 .37171 .13752 .37056 .13675 Mtetra
.855 .401 .031 r
.37056 .13675 .37171 .13752 .37333 .14081 .37217 .14026 Mtetra
.968 .682 .437 r
.37217 .14026 .37333 .14081 .36445 .35207 .36321 .35152 Mtetra
.926 .543 .245 r
.36321 .35152 .36445 .35207 .36598 .35987 .36478 .3585 Mtetra
0 .379 .84 r
.36478 .3585 .36598 .35987 .36787 .36084 .36667 .35944 Mtetra
.602 .722 .929 r
.36667 .35944 .36787 .36084 .36982 .36031 .36863 .35894 Mtetra
.798 .783 .838 r
.36863 .35894 .36982 .36031 .37185 .35854 .37065 .35725 Mtetra
.939 .766 .641 r
.37065 .35725 .37185 .35854 .37408 .35229 .37286 .35141 Mtetra
.97 .69 .445 r
.37286 .35141 .37408 .35229 .38606 .13819 .3849 .13782 Mtetra
.976 .8 .6 r
.3849 .13782 .38606 .13819 .38815 .13194 .38702 .13107 Mtetra
.829 .853 .864 r
.38702 .13107 .38815 .13194 .39003 .13044 .3889 .12943 Mtetra
.642 .795 .956 r
.3889 .12943 .39003 .13044 .39185 .12994 .39074 .12879 Mtetra
.511 .716 .965 r
.39074 .12879 .39185 .12994 .39367 .12986 .39256 .12858 Mtetra
.723 .767 .888 r
.39256 .12858 .39367 .12986 .39551 .12902 .39442 .12756 Mtetra
.689 .728 .88 r
.39442 .12756 .39551 .12902 .39736 .1282 .39627 .1267 Mtetra
.534 .656 .914 r
.39627 .1267 .39736 .1282 .39919 .12783 .39809 .12649 Mtetra
.802 .358 0 r
.39809 .12649 .39919 .12783 .40094 .1294 .39976 .12996 Mtetra
.968 .68 .428 r
.39976 .12996 .40094 .1294 .40252 .13529 .39273 .34175 Mtetra
.511 .267 .481 r
.39273 .34175 .40252 .13529 .39586 .3433 .39442 .34833 Mtetra
.515 .168 .318 r
.39442 .34833 .39586 .3433 .39768 .3467 .39635 .34896 Mtetra
.261 0 .031 r
.39635 .34896 .39768 .3467 .3996 .34782 .39834 .34831 Mtetra
.457 .871 .731 r
.39834 .34831 .3996 .34782 .40155 .34814 .40035 .34717 Mtetra
.564 .791 .984 r
.40035 .34717 .40155 .34814 .40351 .34824 .40233 .34671 Mtetra
.624 .712 .909 r
.40233 .34671 .40351 .34824 .40549 .34786 .40432 .34612 Mtetra
.735 .72 .837 r
.40432 .34612 .40549 .34786 .4075 .34684 .40634 .34481 Mtetra
.9 .727 .658 r
.40634 .34481 .4075 .34684 .40958 .34387 .4085 .33983 Mtetra
.969 .685 .437 r
.4085 .33983 .40958 .34387 .41178 .33733 .41817 .12691 Mtetra
.518 .278 .49 r
.41817 .12691 .41178 .33733 .42117 .12658 .4203 .11877 Mtetra
.619 .424 .597 r
.4203 .11877 .42117 .12658 .42319 .12126 .42221 .11672 Mtetra
.592 .458 .668 r
.42221 .11672 .42319 .12126 .42511 .1188 .42407 .11592 Mtetra
.569 .518 .759 r
.42407 .11592 .42511 .1188 .42701 .11718 .42593 .11556 Mtetra
.637 .686 .879 r
.42593 .11556 .42701 .11718 .42888 .11614 .42779 .11494 Mtetra
.666 .768 .926 r
.42779 .11494 .42888 .11614 .43075 .11541 .42966 .11421 Mtetra
.658 .765 .928 r
.42966 .11421 .43075 .11541 .43261 .11482 .43152 .11351 Mtetra
.72 .765 .889 r
.43152 .11351 .43261 .11482 .43449 .11376 .4334 .11249 Mtetra
.69 .765 .908 r
.4334 .11249 .43449 .11376 .43637 .11273 .43528 .11164 Mtetra
.506 .729 .973 r
.43528 .11164 .43637 .11273 .43824 .11215 .43713 .11142 Mtetra
.795 .31 0 r
.43713 .11142 .43824 .11215 .44005 .11351 .4389 .11439 Mtetra
.97 .678 .414 r
.4389 .11439 .44005 .11351 .44175 .11902 .43469 .32607 Mtetra
.512 .268 .481 r
.43469 .32607 .44175 .11902 .43783 .32828 .43648 .33342 Mtetra
.537 .19 .326 r
.43648 .33342 .43783 .32828 .43976 .33067 .43845 .33437 Mtetra
.364 0 .204 r
.43845 .33437 .43976 .33067 .44177 .33011 .44047 .33376 Mtetra
.284 0 .169 r
.44047 .33376 .44177 .33011 .44381 .32868 .4425 .33265 Mtetra
.335 0 .208 r
.4425 .33265 .44381 .32868 .44584 .32763 .44453 .33176 Mtetra
.365 .012 .227 r
.44453 .33176 .44584 .32763 .44786 .32689 .44656 .33104 Mtetra
.365 .013 .228 r
.44656 .33104 .44786 .32689 .44988 .32615 .44859 .33032 Mtetra
.367 .016 .23 r
.44859 .33032 .44988 .32615 .45191 .32543 .45061 .3296 Mtetra
.368 .017 .231 r
.45061 .3296 .45191 .32543 .45393 .32473 .45264 .3289 Mtetra
.369 .017 .231 r
.45264 .3289 .45393 .32473 .45596 .32403 .45468 .3282 Mtetra
.45468 .3282 .45596 .32403 .45799 .32334 .45671 .32749 Mtetra
.368 .016 .23 r
.45671 .32749 .45799 .32334 .46002 .32265 .45874 .32679 Mtetra
.368 .016 .229 r
.45874 .32679 .46002 .32265 .46205 .32197 .46078 .32609 Mtetra
.367 .015 .228 r
.46078 .32609 .46205 .32197 .46408 .32128 .46282 .32539 Mtetra
.367 .014 .228 r
.46282 .32539 .46408 .32128 .46612 .32059 .46486 .32468 Mtetra
.366 .013 .227 r
.46486 .32468 .46612 .32059 .46815 .3199 .4669 .32398 Mtetra
.366 .012 .226 r
.4669 .32398 .46815 .3199 .47019 .3192 .46894 .32328 Mtetra
.365 .012 .225 r
.46894 .32328 .47019 .3192 .47223 .31851 .47098 .32257 Mtetra
.365 .011 .224 r
.47098 .32257 .47223 .31851 .47427 .31781 .47303 .32186 Mtetra
.365 .01 .224 r
.47303 .32186 .47427 .31781 .47631 .3171 .47508 .32115 Mtetra
.364 .01 .223 r
.47508 .32115 .47631 .3171 .47836 .3164 .47712 .32044 Mtetra
.364 .009 .223 r
.47712 .32044 .47836 .3164 .4804 .3157 .47917 .31973 Mtetra
.47917 .31973 .4804 .3157 .48245 .31499 .48123 .31902 Mtetra
.364 .009 .222 r
.48123 .31902 .48245 .31499 .4845 .31428 .48328 .31831 Mtetra
.363 .009 .222 r
.48328 .31831 .4845 .31428 .48655 .31357 .48533 .31759 Mtetra
.363 .008 .222 r
.48533 .31759 .48655 .31357 .4886 .31286 .48739 .31688 Mtetra
.48739 .31688 .4886 .31286 .49065 .31214 .48945 .31616 Mtetra
.48945 .31616 .49065 .31214 .49271 .31143 .49151 .31545 Mtetra
.49151 .31545 .49271 .31143 .49476 .31071 .49357 .31473 Mtetra
.49357 .31473 .49476 .31071 .49682 .31 .49563 .31401 Mtetra
.363 .008 .221 r
.49563 .31401 .49682 .31 .49888 .30928 .49769 .3133 Mtetra
.49769 .3133 .49888 .30928 .50094 .30856 .49976 .31258 Mtetra
.49976 .31258 .50094 .30856 .50301 .30784 .50183 .31186 Mtetra
.50183 .31186 .50301 .30784 .50507 .30712 .5039 .31114 Mtetra
.5039 .31114 .50507 .30712 .50714 .3064 .50597 .31042 Mtetra
.50597 .31042 .50714 .3064 .5092 .30568 .50804 .3097 Mtetra
.50804 .3097 .5092 .30568 .51127 .30496 .51011 .30898 Mtetra
.51011 .30898 .51127 .30496 .51334 .30424 .51219 .30825 Mtetra
.51219 .30825 .51334 .30424 .51541 .30352 .51426 .30753 Mtetra
.51426 .30753 .51541 .30352 .51749 .3028 .51634 .30681 Mtetra
.51634 .30681 .51749 .3028 .51956 .30207 .51842 .30608 Mtetra
.51842 .30608 .51956 .30207 .52164 .30135 .5205 .30536 Mtetra
.5205 .30536 .52164 .30135 .52372 .30062 .52259 .30463 Mtetra
.52259 .30463 .52372 .30062 .5258 .2999 .52467 .30391 Mtetra
.52467 .30391 .5258 .2999 .52788 .29917 .52676 .30318 Mtetra
.52676 .30318 .52788 .29917 .52996 .29845 .52884 .30246 Mtetra
.52884 .30246 .52996 .29845 .53205 .29772 .53093 .30173 Mtetra
.53093 .30173 .53205 .29772 .53413 .29699 .53302 .301 Mtetra
.53302 .301 .53413 .29699 .53622 .29626 .53512 .30027 Mtetra
.53512 .30027 .53622 .29626 .53831 .29554 .53721 .29955 Mtetra
.53721 .29955 .53831 .29554 .5404 .29481 .5393 .29882 Mtetra
.5393 .29882 .5404 .29481 .54249 .29408 .5414 .29809 Mtetra
.5414 .29809 .54249 .29408 .54459 .29335 .5435 .29736 Mtetra
.5435 .29736 .54459 .29335 .54668 .29261 .5456 .29662 Mtetra
.5456 .29662 .54668 .29261 .54878 .29188 .5477 .29589 Mtetra
.5477 .29589 .54878 .29188 .55088 .29115 .54981 .29516 Mtetra
.54981 .29516 .55088 .29115 .55298 .29042 .55191 .29443 Mtetra
.363 .008 .222 r
.55191 .29443 .55298 .29042 .55508 .28968 .55402 .29369 Mtetra
.55402 .29369 .55508 .28968 .55718 .28894 .55613 .29296 Mtetra
.55613 .29296 .55718 .28894 .55929 .28821 .55824 .29222 Mtetra
.55824 .29222 .55929 .28821 .5614 .28747 .56035 .29149 Mtetra
.56035 .29149 .5614 .28747 .5635 .28673 .56246 .29075 Mtetra
.56246 .29075 .5635 .28673 .56561 .28599 .56458 .29001 Mtetra
.363 .009 .222 r
.56458 .29001 .56561 .28599 .56773 .28524 .56669 .28927 Mtetra
.363 .009 .223 r
.56669 .28927 .56773 .28524 .56984 .2845 .56881 .28853 Mtetra
.56881 .28853 .56984 .2845 .57195 .28375 .57093 .28779 Mtetra
.364 .01 .224 r
.57093 .28779 .57195 .28375 .57407 .283 .57305 .28705 Mtetra
.57305 .28705 .57407 .283 .57619 .28225 .57517 .28631 Mtetra
.364 .01 .225 r
.57517 .28631 .57619 .28225 .57831 .2815 .5773 .28557 Mtetra
.364 .011 .225 r
.5773 .28557 .57831 .2815 .58043 .28074 .57942 .28482 Mtetra
.365 .012 .226 r
.57942 .28482 .58043 .28074 .58255 .27999 .58155 .28408 Mtetra
.365 .012 .227 r
.58155 .28408 .58255 .27999 .58468 .27923 .58368 .28333 Mtetra
.366 .013 .227 r
.58368 .28333 .58468 .27923 .5868 .27847 .58581 .28259 Mtetra
.366 .014 .228 r
.58581 .28259 .5868 .27847 .58893 .27772 .58794 .28184 Mtetra
.366 .014 .229 r
.58794 .28184 .58893 .27772 .59106 .27696 .59008 .28109 Mtetra
.367 .015 .229 r
.59008 .28109 .59106 .27696 .59319 .27621 .59221 .28035 Mtetra
.367 .015 .23 r
.59221 .28035 .59319 .27621 .59532 .27546 .59435 .2796 Mtetra
.367 .016 .23 r
.59435 .2796 .59532 .27546 .59745 .27471 .59649 .27885 Mtetra
.59649 .27885 .59745 .27471 .59959 .27397 .59863 .27811 Mtetra
.59863 .27811 .59959 .27397 .60173 .27322 .60077 .27736 Mtetra
.60077 .27736 .60173 .27322 .60387 .27248 .60292 .27662 Mtetra
.367 .015 .23 r
.60292 .27662 .60387 .27248 .60601 .27173 .60506 .27587 Mtetra
.60506 .27587 .60601 .27173 .60815 .27098 .60721 .27512 Mtetra
.60721 .27512 .60815 .27098 .61029 .27022 .60936 .27436 Mtetra
.60936 .27436 .61029 .27022 .61244 .26945 .61151 .27361 Mtetra
.367 .016 .231 r
.61151 .27361 .61244 .26945 .61459 .26866 .61366 .27285 Mtetra
.367 .017 .232 r
.61366 .27285 .61459 .26866 .61673 .26785 .61582 .27208 Mtetra
.368 .018 .234 r
.61582 .27208 .61673 .26785 .61888 .26704 .61797 .27131 Mtetra
.368 .02 .237 r
.61797 .27131 .61888 .26704 .62103 .26609 .62013 .27052 Mtetra
.371 .027 .245 r
.62013 .27052 .62103 .26609 .62316 .26478 .62229 .26972 Mtetra
.385 .05 .269 r
.62229 .26972 .62316 .26478 .62532 .26398 .62444 .26892 Mtetra
.387 .052 .27 r
.62444 .26892 .62532 .26398 .62751 .26442 .62661 .26814 Mtetra
.355 0 .203 r
.62661 .26814 .62751 .26442 .62976 .26628 .62877 .26741 Mtetra
.07 0 0 r
.62877 .26741 .62976 .26628 .63199 .26748 .63094 .26669 Mtetra
.611 .864 .991 r
.63094 .26669 .63199 .26748 .6342 .26791 .6331 .26595 Mtetra
.644 .673 .863 r
.6331 .26595 .6342 .26791 .63637 .26733 .63527 .26517 Mtetra
.64 .648 .842 r
.63527 .26517 .63637 .26733 .63854 .26649 .63744 .26438 Mtetra
.639 .654 .849 r
.63744 .26438 .63854 .26649 .6407 .26556 .63961 .26361 Mtetra
.635 .672 .868 r
.63961 .26361 .6407 .26556 .64288 .2648 .64179 .26289 Mtetra
.636 .678 .873 r
.64179 .26289 .64288 .2648 .64505 .26406 .64397 .26216 Mtetra
.64 .681 .873 r
.64397 .26216 .64505 .26406 .64723 .26338 .64614 .26141 Mtetra
.649 .676 .862 r
.64614 .26141 .64723 .26338 .64942 .26282 .64832 .2606 Mtetra
.643 .643 .835 r
.64832 .2606 .64942 .26282 .65161 .26227 .6505 .25978 Mtetra
.632 .611 .811 r
.6505 .25978 .65161 .26227 .6538 .26169 .65268 .25899 Mtetra
.618 .585 .794 r
.65268 .25899 .6538 .26169 .65598 .26099 .65486 .25827 Mtetra
.615 .581 .793 r
.65486 .25827 .65598 .26099 .65817 .26026 .65705 .25756 Mtetra
.615 .583 .795 r
.65705 .25756 .65817 .26026 .66036 .25952 .65924 .25685 Mtetra
.619 .589 .798 r
.65924 .25685 .66036 .25952 .66255 .25878 .66143 .25612 Mtetra
.62 .591 .798 r
.66143 .25612 .66255 .25878 .66474 .25803 .66363 .25538 Mtetra
.621 .592 .799 r
.66363 .25538 .66474 .25803 .66693 .25728 .66582 .25464 Mtetra
.622 .593 .799 r
.66582 .25464 .66693 .25728 .66913 .25653 .66801 .25389 Mtetra
.623 .593 .8 r
.66801 .25389 .66913 .25653 .67132 .25577 .67021 .25313 Mtetra
.624 .594 .8 r
.67021 .25313 .67132 .25577 .67352 .25501 .67241 .25237 Mtetra
.67241 .25237 .67352 .25501 .67572 .25425 .67461 .25161 Mtetra
.625 .595 .8 r
.67461 .25161 .67572 .25425 .67792 .25348 .67681 .25084 Mtetra
.626 .595 .799 r
.67681 .25084 .67792 .25348 .68012 .25271 .67901 .25006 Mtetra
.67901 .25006 .68012 .25271 .68233 .25193 .68122 .24928 Mtetra
.627 .596 .799 r
.68122 .24928 .68233 .25193 .68453 .25114 .68342 .24849 Mtetra
.629 .596 .798 r
.68342 .24849 .68453 .25114 .68674 .25035 .68563 .24769 Mtetra
.63 .596 .797 r
.68563 .24769 .68674 .25035 .68895 .24954 .68783 .24687 Mtetra
.632 .596 .796 r
.68783 .24687 .68895 .24954 .69115 .24873 .69004 .24604 Mtetra
.634 .597 .794 r
.69004 .24604 .69115 .24873 .69336 .24789 .69225 .24519 Mtetra
.64 .599 .792 r
.69225 .24519 .69336 .24789 .69557 .24706 .69446 .24429 Mtetra
.639 .592 .786 r
.69446 .24429 .69557 .24706 .69779 .24618 .69667 .24338 Mtetra
.637 .589 .784 r
.69667 .24338 .69779 .24618 .69999 .24522 .69888 .24248 Mtetra
.63 .59 .791 r
.69888 .24248 .69999 .24522 .70219 .24399 .70109 .24164 Mtetra
.64 .632 .826 r
.70109 .24164 .70219 .24399 .70438 .24269 .70331 .24081 Mtetra
.656 .695 .874 r
.70331 .24081 .70438 .24269 .70657 .24138 .70553 .23996 Mtetra
.639 .858 .983 r
.0041 .48307 .00553 .48368 .00727 .48288 .00582 .48244 Mtetra
.734 .897 .953 r
.00582 .48244 .00727 .48288 .00901 .48208 .00759 .48145 Mtetra
.77 .863 .918 r
.00759 .48145 .00901 .48208 .01076 .48129 .00939 .48028 Mtetra
.688 .787 .926 r
.00939 .48028 .01076 .48129 .01248 .48062 .01113 .47951 Mtetra
.664 .766 .926 r
.01113 .47951 .01248 .48062 .0142 .48001 .01286 .47885 Mtetra
.641 .749 .927 r
.01286 .47885 .0142 .48001 .0159 .47947 .01457 .47827 Mtetra
.624 .738 .929 r
.01457 .47827 .0159 .47947 .0176 .47904 .01628 .47776 Mtetra
.598 .716 .927 r
.01628 .47776 .0176 .47904 .01928 .47864 .01797 .47734 Mtetra
.565 .702 .933 r
.01797 .47734 .01928 .47864 .02097 .47823 .01964 .47703 Mtetra
.469 .683 .959 r
.01964 .47703 .02097 .47823 .02268 .47776 .02128 .47696 Mtetra
.397 .733 .991 r
.02128 .47696 .02268 .47776 .02438 .47727 .02293 .47688 Mtetra
.314 .767 .955 r
.02293 .47688 .02438 .47727 .02609 .47676 .02458 .47673 Mtetra
.082 .642 .769 r
.02458 .47673 .02609 .47676 .02772 .47678 .02623 .47665 Mtetra
.392 .837 .935 r
.02623 .47665 .02772 .47678 .02941 .47643 .02792 .47626 Mtetra
.686 .939 .964 r
.02792 .47626 .02941 .47643 .03121 .47531 .0297 .47534 Mtetra
.928 .882 .768 r
.0297 .47534 .03121 .47531 .03366 .46989 .0318 .47228 Mtetra
.983 .907 .608 r
.0318 .47228 .03366 .46989 .06621 .26204 .03436 .46612 Mtetra
0 0 0 r
.03436 .46612 .06621 .26204 .06875 .25523 .06629 .2623 Mtetra
.184 0 .234 r
.06629 .2623 .06875 .25523 .07051 .25371 .06823 .2596 Mtetra
.453 .135 .336 r
.06823 .2596 .07051 .25371 .07213 .25312 .0698 .2594 Mtetra
.468 .154 .35 r
.0698 .2594 .07213 .25312 .0737 .25292 .07135 .25934 Mtetra
0 0 .073 r
.07135 .25934 .0737 .25292 .07533 .25225 .07348 .25529 Mtetra
0 0 0 r
.07348 .25529 .07533 .25225 .07698 .2515 .07549 .25214 Mtetra
.896 .985 .793 r
.07549 .25214 .07698 .2515 .07863 .25077 .07736 .24989 Mtetra
.808 .807 .85 r
.07736 .24989 .07863 .25077 .08032 .24976 .07911 .24841 Mtetra
.713 .725 .859 r
.07911 .24841 .08032 .24976 .08197 .24901 .08079 .24748 Mtetra
.583 .654 .885 r
.08079 .24748 .08197 .24901 .08352 .24892 .08238 .24715 Mtetra
0 .073 .629 r
.08238 .24715 .08352 .24892 .08458 .25232 .08372 .24857 Mtetra
.799 .521 0 r
.08372 .24857 .08458 .25232 .05667 .4588 .08459 .25335 Mtetra
0 0 0 r
.08459 .25335 .05667 .4588 .05737 .46547 .057 .45765 Mtetra
.019 0 .461 r
.057 .45765 .05737 .46547 .05894 .46616 .05806 .46185 Mtetra
.264 .244 .648 r
.05806 .46185 .05894 .46616 .06067 .46564 .05952 .46327 Mtetra
.37 .451 .814 r
.05952 .46327 .06067 .46564 .06248 .46464 .06111 .46373 Mtetra
.566 .782 .98 r
.06111 .46373 .06248 .46464 .06424 .46395 .06283 .46335 Mtetra
.68 .869 .97 r
.06283 .46335 .06424 .46395 .06599 .46333 .06461 .46256 Mtetra
.722 .842 .938 r
.06461 .46256 .06599 .46333 .06775 .46268 .06641 .46162 Mtetra
.53 .739 .971 r
.06641 .46162 .06775 .46268 .06945 .46244 .06811 .46136 Mtetra
.541 .739 .967 r
.06811 .46136 .06945 .46244 .07118 .46198 .06982 .46107 Mtetra
.684 .812 .944 r
.06982 .46107 .07118 .46198 .07301 .46083 .0716 .46031 Mtetra
.904 .833 .766 r
.0716 .46031 .07301 .46083 .07534 .45609 .07368 .45736 Mtetra
.984 .849 .627 r
.07368 .45736 .07534 .45609 .10541 .24818 .0763 .45048 Mtetra
0 0 0 r
.0763 .45048 .10541 .24818 .10806 .24023 .10599 .2453 Mtetra
0 0 .074 r
.10599 .2453 .10806 .24023 .10989 .23833 .10796 .24232 Mtetra
.402 .051 .252 r
.10796 .24232 .10989 .23833 .11154 .2377 .10958 .24194 Mtetra
.45 .104 .286 r
.10958 .24194 .11154 .2377 .11313 .23752 .11116 .24187 Mtetra
0 0 .026 r
.11116 .24187 .11313 .23752 .11476 .23703 .1131 .23918 Mtetra
.663 .867 .484 r
.1131 .23918 .11476 .23703 .11642 .23639 .11504 .23642 Mtetra
.894 .938 .836 r
.11504 .23642 .11642 .23639 .11808 .23577 .11689 .23438 Mtetra
.715 .721 .854 r
.11689 .23438 .11808 .23577 .11972 .23522 .11859 .23342 Mtetra
.604 .625 .845 r
.11859 .23342 .11972 .23522 .12137 .23471 .12022 .23299 Mtetra
.557 .616 .867 r
.12022 .23299 .12137 .23471 .12301 .2342 .12183 .23276 Mtetra
.602 .678 .894 r
.12183 .23276 .12301 .2342 .12466 .23367 .12346 .23235 Mtetra
.636 .71 .9 r
.12346 .23235 .12466 .23367 .12631 .23312 .12511 .23181 Mtetra
.648 .717 .898 r
.12511 .23181 .12631 .23312 .12797 .23253 .12677 .23122 Mtetra
.659 .721 .894 r
.12677 .23122 .12797 .23253 .12963 .23186 .12843 .23058 Mtetra
.668 .727 .894 r
.12843 .23058 .12963 .23186 .13131 .23115 .1301 .2299 Mtetra
.675 .735 .896 r
.1301 .2299 .13131 .23115 .13299 .23041 .13178 .22919 Mtetra
.73 .752 .87 r
.13178 .22919 .13299 .23041 .13472 .22928 .1335 .22818 Mtetra
.726 .773 .89 r
.1335 .22818 .13472 .22928 .13644 .22826 .13521 .22723 Mtetra
.626 .765 .946 r
.13521 .22723 .13644 .22826 .13808 .22787 .13686 .22672 Mtetra
0 .16 .65 r
.13686 .22672 .13808 .22787 .13935 .23038 .13831 .22782 Mtetra
.892 .54 .059 r
.13831 .22782 .13935 .23038 .11504 .43633 .13933 .23236 Mtetra
0 0 .026 r
.13933 .23236 .11504 .43633 .11569 .44475 .11527 .43647 Mtetra
.03 0 .463 r
.11527 .43647 .11569 .44475 .11724 .446 .11641 .441 Mtetra
.32 .261 .633 r
.11641 .441 .11724 .446 .11901 .44554 .11795 .44239 Mtetra
.411 .408 .746 r
.11795 .44239 .11901 .44554 .12084 .44456 .1196 .4429 Mtetra
.36 .548 .902 r
.1196 .4429 .12084 .44456 .12262 .44404 .12128 .44319 Mtetra
.433 .746 .993 r
.12128 .44319 .12262 .44404 .12439 .44363 .12301 .44306 Mtetra
.715 .886 .959 r
.12301 .44306 .12439 .44363 .12623 .44257 .12484 .44211 Mtetra
.927 .825 .725 r
.12484 .44211 .12623 .44257 .12842 .43872 .12702 .43835 Mtetra
.949 .69 .51 r
.12702 .43835 .12842 .43872 .15511 .23245 .15381 .23197 Mtetra
.95 .734 .576 r
.15381 .23197 .15511 .23245 .15808 .22116 .15693 .21954 Mtetra
.83 .719 .742 r
.15693 .21954 .15808 .22116 .15999 .21863 .15883 .21706 Mtetra
.658 .68 .86 r
.15883 .21706 .15999 .21863 .1617 .21781 .16052 .21638 Mtetra
.533 .654 .913 r
.16052 .21638 .1617 .21781 .16334 .21749 .16215 .2162 Mtetra
.663 .728 .898 r
.16215 .2162 .16334 .21749 .16504 .21679 .16384 .21554 Mtetra
.728 .75 .87 r
.16384 .21554 .16504 .21679 .16675 .21591 .16557 .21453 Mtetra
.655 .711 .889 r
.16557 .21453 .16675 .21591 .16841 .21556 .16726 .2139 Mtetra
.099 .374 .837 r
.16726 .2139 .16841 .21556 .16981 .21742 .16878 .2147 Mtetra
.747 .41 0 r
.16878 .2147 .16981 .21742 .14829 .4164 .16997 .21837 Mtetra
0 0 .033 r
.16997 .21837 .14829 .4164 .14814 .43255 .1479 .42227 Mtetra
.081 .002 .457 r
.1479 .42227 .14814 .43255 .14968 .43432 .14902 .42757 Mtetra
.533 .377 .615 r
.14902 .42757 .14968 .43432 .15146 .43389 .15079 .4273 Mtetra
.604 .432 .621 r
.15079 .4273 .15146 .43389 .15332 .43288 .15268 .42595 Mtetra
.592 .419 .615 r
.15268 .42595 .15332 .43288 .15517 .43196 .15456 .42473 Mtetra
.557 .389 .609 r
.15456 .42473 .15517 .43196 .15698 .43132 .15638 .42406 Mtetra
.557 .388 .609 r
.15638 .42406 .15698 .43132 .1588 .43068 .1582 .42339 Mtetra
.555 .387 .608 r
.1582 .42339 .1588 .43068 .16062 .43005 .16001 .42275 Mtetra
.553 .385 .608 r
.16001 .42275 .16062 .43005 .16243 .42944 .16182 .42215 Mtetra
.552 .384 .608 r
.16182 .42215 .16243 .42944 .16425 .42883 .16364 .42155 Mtetra
.573 .4 .609 r
.16364 .42155 .16425 .42883 .16607 .4282 .16549 .42061 Mtetra
.579 .401 .605 r
.16549 .42061 .16607 .4282 .16789 .42755 .16736 .41952 Mtetra
.533 .362 .596 r
.16736 .41952 .16789 .42755 .16972 .42691 .16915 .41917 Mtetra
.391 .26 .58 r
.16915 .41917 .16972 .42691 .17154 .42632 .17074 .42066 Mtetra
.26 .202 .6 r
.17074 .42066 .17154 .42632 .17336 .42576 .17228 .42266 Mtetra
.221 .292 .725 r
.17228 .42266 .17336 .42576 .17518 .4252 .17391 .42386 Mtetra
.341 .6 .943 r
.17391 .42386 .17518 .4252 .177 .4246 .17564 .42409 Mtetra
.565 .867 .996 r
.17564 .42409 .177 .4246 .17883 .42394 .17746 .42354 Mtetra
.64 .907 .982 r
.17746 .42354 .17883 .42394 .18067 .42327 .17931 .42276 Mtetra
.65 .892 .983 r
.17931 .42276 .18067 .42327 .1825 .42261 .18116 .422 Mtetra
.619 .866 .989 r
.18116 .422 .1825 .42261 .18434 .42197 .183 .42135 Mtetra
.617 .864 .989 r
.183 .42135 .18434 .42197 .18617 .42134 .18483 .42071 Mtetra
.618 .863 .989 r
.18483 .42071 .18617 .42134 .18801 .42073 .18667 .42007 Mtetra
.618 .857 .989 r
.18667 .42007 .18801 .42073 .18984 .42013 .18851 .41944 Mtetra
.609 .849 .989 r
.18851 .41944 .18984 .42013 .19168 .41953 .19034 .41884 Mtetra
.577 .84 .995 r
.19034 .41884 .19168 .41953 .19352 .4189 .19217 .41833 Mtetra
.521 .841 .999 r
.19217 .41833 .19352 .4189 .19536 .41823 .194 .41789 Mtetra
.463 .853 .978 r
.194 .41789 .19536 .41823 .19721 .41757 .19582 .41745 Mtetra
.422 .858 .93 r
.19582 .41745 .19721 .41757 .19905 .41693 .19765 .41695 Mtetra
.425 .867 .898 r
.19765 .41695 .19905 .41693 .20089 .41632 .19949 .41635 Mtetra
.441 .875 .9 r
.19949 .41635 .20089 .41632 .20274 .41572 .20134 .41572 Mtetra
.458 .883 .911 r
.20134 .41572 .20274 .41572 .20458 .41511 .20319 .41508 Mtetra
.467 .886 .92 r
.20319 .41508 .20458 .41511 .20643 .41449 .20504 .41445 Mtetra
.474 .888 .923 r
.20504 .41445 .20643 .41449 .20828 .41385 .20689 .41381 Mtetra
.476 .889 .925 r
.20689 .41381 .20828 .41385 .21013 .41321 .20875 .41316 Mtetra
.475 .889 .925 r
.20875 .41316 .21013 .41321 .21199 .41256 .2106 .41252 Mtetra
.486 .894 .925 r
.2106 .41252 .21199 .41256 .21384 .41191 .21246 .41186 Mtetra
.521 .909 .934 r
.21246 .41186 .21384 .41191 .2157 .41126 .21433 .41114 Mtetra
.58 .927 .954 r
.21433 .41114 .2157 .41126 .21756 .41062 .2162 .41034 Mtetra
.621 .924 .974 r
.2162 .41034 .21756 .41062 .21942 .40997 .21808 .40954 Mtetra
.581 .888 .99 r
.21808 .40954 .21942 .40997 .22126 .4095 .21994 .4089 Mtetra
.503 .831 .999 r
.21994 .4089 .22126 .4095 .22309 .40925 .22178 .4085 Mtetra
.652 .852 .977 r
.22178 .4085 .22309 .40925 .22496 .40848 .22365 .40778 Mtetra
.841 .87 .863 r
.22365 .40778 .22496 .40848 .22699 .40607 .22562 .40599 Mtetra
.962 .85 .685 r
.22562 .40599 .22699 .40607 .22969 .39628 .22785 .40136 Mtetra
.964 .699 .482 r
.22785 .40136 .22969 .39628 .25057 .18701 .24756 .20589 Mtetra
0 0 .049 r
.24756 .20589 .25057 .18701 .25262 .183 .25099 .18689 Mtetra
.226 0 .163 r
.25099 .18689 .25262 .183 .2544 .18193 .2528 .18549 Mtetra
.411 .046 .232 r
.2528 .18549 .2544 .18193 .25613 .18147 .25452 .18523 Mtetra
.457 .097 .265 r
.25452 .18523 .25613 .18147 .25785 .18114 .25621 .18527 Mtetra
.37 .024 .242 r
.25621 .18527 .25785 .18114 .2596 .18047 .25796 .18463 Mtetra
.373 .028 .245 r
.25796 .18463 .2596 .18047 .26135 .17981 .25971 .18399 Mtetra
.373 .029 .246 r
.25971 .18399 .26135 .17981 .26311 .17915 .26147 .18336 Mtetra
.371 .027 .246 r
.26147 .18336 .26311 .17915 .26486 .17847 .26322 .1827 Mtetra
.371 .028 .247 r
.26322 .1827 .26486 .17847 .26661 .1778 .26498 .18204 Mtetra
.393 .048 .257 r
.26498 .18204 .26661 .1778 .26837 .17714 .26673 .18153 Mtetra
.446 .101 .286 r
.26673 .18153 .26837 .17714 .27013 .17649 .26844 .18142 Mtetra
.388 .058 .28 r
.26844 .18142 .27013 .17649 .27188 .17584 .2702 .18073 Mtetra
.186 0 .192 r
.2702 .18073 .27188 .17584 .27364 .17515 .27208 .17867 Mtetra
0 0 0 r
.27208 .17867 .27364 .17515 .27541 .17439 .27407 .17537 Mtetra
.836 .98 .687 r
.27407 .17537 .27541 .17439 .27718 .17363 .27599 .17285 Mtetra
.843 .85 .849 r
.27599 .17285 .27718 .17363 .27895 .1729 .27784 .1711 Mtetra
.677 .667 .833 r
.27784 .1711 .27895 .1729 .28072 .17222 .27962 .17025 Mtetra
.629 .626 .828 r
.27962 .17025 .28072 .17222 .28248 .17156 .28138 .16965 Mtetra
.608 .624 .841 r
.28138 .16965 .28248 .17156 .28425 .17089 .28313 .16917 Mtetra
.62 .654 .862 r
.28313 .16917 .28425 .17089 .28602 .17019 .28489 .16865 Mtetra
.624 .683 .885 r
.28489 .16865 .28602 .17019 .28779 .16949 .28665 .16812 Mtetra
.646 .719 .901 r
.28665 .16812 .28779 .16949 .28956 .1688 .28841 .1675 Mtetra
.693 .746 .892 r
.28841 .1675 .28956 .1688 .29133 .16814 .2902 .16666 Mtetra
.694 .718 .867 r
.2902 .16666 .29133 .16814 .2931 .16748 .29199 .16578 Mtetra
.69 .685 .84 r
.29199 .16578 .2931 .16748 .29488 .16672 .29378 .16487 Mtetra
.7 .67 .817 r
.29378 .16487 .29488 .16672 .29669 .16559 .29558 .16384 Mtetra
.656 .665 .847 r
.29558 .16384 .29669 .16559 .29847 .16487 .29736 .16312 Mtetra
.496 .592 .88 r
.29736 .16312 .29847 .16487 .30017 .1652 .29909 .16308 Mtetra
0 0 .541 r
.29909 .16308 .30017 .1652 .30147 .17097 .30066 .16526 Mtetra
.792 .557 0 r
.30066 .16526 .30147 .17097 .28762 .38149 .30171 .17439 Mtetra
0 0 .157 r
.30171 .17439 .28762 .38149 .28917 .38562 .28832 .37913 Mtetra
.222 .162 .574 r
.28832 .37913 .28917 .38562 .29103 .38565 .28998 .38183 Mtetra
.339 .329 .701 r
.28998 .38183 .29103 .38565 .29295 .38493 .29177 .38288 Mtetra
.412 .524 .862 r
.29177 .38288 .29295 .38493 .29488 .38394 .29361 .38316 Mtetra
.398 .751 .993 r
.29361 .38316 .29488 .38394 .29677 .38368 .29549 .38303 Mtetra
.623 .868 .989 r
.29549 .38303 .29677 .38368 .29869 .38297 .29741 .38234 Mtetra
.804 .899 .91 r
.29741 .38234 .29869 .38297 .30068 .38124 .29939 .38088 Mtetra
.946 .867 .729 r
.29939 .38088 .30068 .38124 .30304 .37432 .30152 .37723 Mtetra
.976 .866 .481 r
.30152 .37723 .30304 .37432 .31951 .16207 .304 .36848 Mtetra
0 0 .147 r
.304 .36848 .31951 .16207 .32164 .15649 .32015 .16042 Mtetra
0 0 0 r
.32015 .16042 .32164 .15649 .32348 .15516 .32218 .1563 Mtetra
.719 .935 .613 r
.32218 .1563 .32348 .15516 .32527 .15452 .32408 .15399 Mtetra
.826 .907 .895 r
.32408 .15399 .32527 .15452 .32704 .15422 .32594 .15248 Mtetra
.662 .671 .848 r
.32594 .15248 .32704 .15422 .32884 .15353 .32774 .15172 Mtetra
.607 .639 .856 r
.32774 .15172 .32884 .15353 .33064 .15286 .32952 .15125 Mtetra
.586 .657 .886 r
.32952 .15125 .33064 .15286 .33244 .15217 .3313 .15087 Mtetra
.724 .757 .879 r
.3313 .15087 .33244 .15217 .33427 .15098 .33313 .14985 Mtetra
.685 .777 .921 r
.33313 .14985 .33427 .15098 .33608 .15017 .33494 .14906 Mtetra
.535 .728 .963 r
.33494 .14906 .33608 .15017 .33784 .15014 .33671 .14878 Mtetra
.545 .076 0 r
.33671 .14878 .33784 .15014 .33931 .15481 .33835 .15076 Mtetra
.832 .543 0 r
.33835 .15076 .33931 .15481 .32803 .3662 .33965 .1583 Mtetra
0 0 .18 r
.33965 .1583 .32803 .3662 .32961 .37134 .32874 .36426 Mtetra
.227 .157 .565 r
.32874 .36426 .32961 .37134 .3315 .3714 .33046 .36723 Mtetra
.345 .317 .684 r
.33046 .36723 .3315 .3714 .33345 .37065 .33229 .36837 Mtetra
.428 .506 .837 r
.33229 .36837 .33345 .37065 .33542 .36947 .33418 .36865 Mtetra
.608 .834 .986 r
.33418 .36865 .33542 .36947 .33737 .36878 .33612 .36804 Mtetra
.695 .874 .965 r
.33612 .36804 .33737 .36878 .33932 .36806 .33808 .36712 Mtetra
.728 .841 .934 r
.33808 .36712 .33932 .36806 .34127 .3673 .34005 .36606 Mtetra
.512 .712 .962 r
.34005 .36606 .34127 .3673 .3432 .36703 .34198 .36584 Mtetra
.587 .753 .957 r
.34198 .36584 .3432 .36703 .34515 .36636 .34391 .36538 Mtetra
.725 .833 .932 r
.34391 .36538 .34515 .36636 .34714 .36485 .34589 .36433 Mtetra
.95 .849 .708 r
.34589 .36433 .34714 .36485 .34944 .35787 .34803 .3603 Mtetra
.999 .818 .483 r
.34803 .3603 .34944 .35787 .36298 .14488 .35063 .34786 Mtetra
0 0 .174 r
.35063 .34786 .36298 .14488 .36507 .13922 .3637 .14257 Mtetra
0 0 0 r
.3637 .14257 .36507 .13922 .36696 .13736 .36563 .14 Mtetra
.255 0 .09 r
.36563 .14 .36696 .13736 .36879 .13657 .36746 .13917 Mtetra
.524 .119 .216 r
.36746 .13917 .36879 .13657 .37056 .13675 .36922 .13981 Mtetra
.878 .539 .405 r
.36922 .13981 .37056 .13675 .37217 .14026 .37046 .15049 Mtetra
.956 .667 .449 r
.37046 .15049 .37217 .14026 .36321 .35152 .36182 .3539 Mtetra
.75 .355 .304 r
.36182 .3539 .36321 .35152 .36478 .3585 .36357 .35732 Mtetra
.093 .486 .897 r
.36357 .35732 .36478 .3585 .36667 .35944 .36547 .35795 Mtetra
.597 .704 .919 r
.36547 .35795 .36667 .35944 .36863 .35894 .36743 .35748 Mtetra
.778 .766 .842 r
.36743 .35748 .36863 .35894 .37065 .35725 .36944 .35592 Mtetra
.938 .764 .64 r
.36944 .35592 .37065 .35725 .37286 .35141 .37167 .35008 Mtetra
.969 .689 .446 r
.37167 .35008 .37286 .35141 .3849 .13782 .38379 .13645 Mtetra
.943 .748 .611 r
.38379 .13645 .3849 .13782 .38702 .13107 .38591 .12974 Mtetra
.801 .775 .829 r
.38591 .12974 .38702 .13107 .3889 .12943 .3878 .12811 Mtetra
.644 .735 .915 r
.3878 .12811 .3889 .12943 .39074 .12879 .38963 .12747 Mtetra
.526 .686 .94 r
.38963 .12747 .39074 .12879 .39256 .12858 .39145 .12726 Mtetra
.726 .761 .881 r
.39145 .12726 .39256 .12858 .39442 .12756 .39331 .12621 Mtetra
.695 .747 .891 r
.39331 .12621 .39442 .12756 .39627 .1267 .39516 .12533 Mtetra
.52 .674 .934 r
.39516 .12533 .39627 .1267 .39809 .12649 .39698 .12515 Mtetra
.841 .409 0 r
.39698 .12515 .39809 .12649 .39976 .12996 .39863 .12908 Mtetra
.97 .682 .426 r
.39863 .12908 .39976 .12996 .39273 .34175 .39147 .3421 Mtetra
.889 .487 .25 r
.39147 .3421 .39273 .34175 .39442 .34833 .39319 .34782 Mtetra
0 .463 .776 r
.39319 .34782 .39442 .34833 .39635 .34896 .39513 .34832 Mtetra
.65 .888 .983 r
.39513 .34832 .39635 .34896 .39834 .34831 .39713 .34751 Mtetra
.807 .88 .899 r
.39713 .34751 .39834 .34831 .40035 .34717 .39915 .34596 Mtetra
.808 .813 .855 r
.39915 .34596 .40035 .34717 .40233 .34671 .40119 .34427 Mtetra
.782 .67 .74 r
.40119 .34427 .40233 .34671 .40432 .34612 .40324 .34199 Mtetra
.779 .594 .651 r
.40324 .34199 .40432 .34612 .40634 .34481 .40535 .33819 Mtetra
.967 .682 .441 r
.40535 .33819 .40634 .34481 .4085 .33983 .41499 .1322 Mtetra
.527 .285 .492 r
.41499 .1322 .4085 .33983 .41817 .12691 .41727 .12014 Mtetra
.702 .494 .603 r
.41727 .12014 .41817 .12691 .4203 .11877 .41924 .11643 Mtetra
.716 .637 .768 r
.41924 .11643 .4203 .11877 .42221 .11672 .42113 .11504 Mtetra
.623 .671 .875 r
.42113 .11504 .42221 .11672 .42407 .11592 .42298 .11448 Mtetra
.546 .676 .923 r
.42298 .11448 .42407 .11592 .42593 .11556 .42483 .11422 Mtetra
.682 .748 .901 r
.42483 .11422 .42593 .11556 .42779 .11494 .4267 .1134 Mtetra
.7 .723 .867 r
.4267 .1134 .42779 .11494 .42966 .11421 .42858 .11245 Mtetra
.653 .672 .856 r
.42858 .11245 .42966 .11421 .43152 .11351 .43045 .11173 Mtetra
.505 .599 .881 r
.43045 .11173 .43152 .11351 .4334 .11249 .4323 .11165 Mtetra
0 .404 .814 r
.4323 .11165 .4334 .11249 .43528 .11164 .43412 .11239 Mtetra
.748 .273 .118 r
.43412 .11239 .43528 .11164 .43713 .11142 .4359 .11471 Mtetra
.968 .675 .418 r
.4359 .11471 .43713 .11142 .4389 .11439 .43163 .32124 Mtetra
.517 .271 .481 r
.43163 .32124 .4389 .11439 .43469 .32607 .43334 .33105 Mtetra
.643 .288 .354 r
.43334 .33105 .43469 .32607 .43648 .33342 .43526 .33373 Mtetra
.275 0 0 r
.43526 .33373 .43648 .33342 .43845 .33437 .43725 .33404 Mtetra
.513 .888 .97 r
.43725 .33404 .43845 .33437 .44047 .33376 .43927 .3334 Mtetra
.658 .937 .967 r
.43927 .3334 .44047 .33376 .4425 .33265 .44131 .33241 Mtetra
.568 .922 .955 r
.44131 .33241 .4425 .33265 .44453 .33176 .44333 .33158 Mtetra
.496 .896 .938 r
.44333 .33158 .44453 .33176 .44656 .33104 .44536 .33087 Mtetra
.495 .896 .936 r
.44536 .33087 .44656 .33104 .44859 .33032 .44739 .33015 Mtetra
.489 .894 .934 r
.44739 .33015 .44859 .33032 .45061 .3296 .44942 .32945 Mtetra
.485 .892 .932 r
.44942 .32945 .45061 .3296 .45264 .3289 .45145 .32874 Mtetra
.484 .891 .932 r
.45145 .32874 .45264 .3289 .45468 .3282 .45349 .32804 Mtetra
.483 .891 .932 r
.45349 .32804 .45468 .3282 .45671 .32749 .45552 .32733 Mtetra
.45552 .32733 .45671 .32749 .45874 .32679 .45756 .32663 Mtetra
.484 .891 .932 r
.45756 .32663 .45874 .32679 .46078 .32609 .45959 .32593 Mtetra
.484 .891 .933 r
.45959 .32593 .46078 .32609 .46282 .32539 .46163 .32522 Mtetra
.485 .892 .933 r
.46163 .32522 .46282 .32539 .46486 .32468 .46368 .32451 Mtetra
.486 .892 .934 r
.46368 .32451 .46486 .32468 .4669 .32398 .46572 .32381 Mtetra
.487 .892 .934 r
.46572 .32381 .4669 .32398 .46894 .32328 .46776 .3231 Mtetra
.488 .893 .934 r
.46776 .3231 .46894 .32328 .47098 .32257 .46981 .32239 Mtetra
.488 .893 .935 r
.46981 .32239 .47098 .32257 .47303 .32186 .47185 .32168 Mtetra
.489 .893 .935 r
.47185 .32168 .47303 .32186 .47508 .32115 .4739 .32097 Mtetra
.49 .893 .936 r
.4739 .32097 .47508 .32115 .47712 .32044 .47595 .32026 Mtetra
.47595 .32026 .47712 .32044 .47917 .31973 .47801 .31955 Mtetra
.47801 .31955 .47917 .31973 .48123 .31902 .48006 .31883 Mtetra
.491 .894 .936 r
.48006 .31883 .48123 .31902 .48328 .31831 .48211 .31812 Mtetra
.48211 .31812 .48328 .31831 .48533 .31759 .48417 .3174 Mtetra
.48417 .3174 .48533 .31759 .48739 .31688 .48623 .31669 Mtetra
.48623 .31669 .48739 .31688 .48945 .31616 .48829 .31597 Mtetra
.491 .894 .937 r
.48829 .31597 .48945 .31616 .49151 .31545 .49035 .31526 Mtetra
.492 .894 .937 r
.49035 .31526 .49151 .31545 .49357 .31473 .49241 .31454 Mtetra
.49241 .31454 .49357 .31473 .49563 .31401 .49448 .31382 Mtetra
.49448 .31382 .49563 .31401 .49769 .3133 .49654 .3131 Mtetra
.49654 .3131 .49769 .3133 .49976 .31258 .49861 .31238 Mtetra
.49861 .31238 .49976 .31258 .50183 .31186 .50068 .31166 Mtetra
.50068 .31166 .50183 .31186 .5039 .31114 .50275 .31094 Mtetra
.50275 .31094 .5039 .31114 .50597 .31042 .50482 .31022 Mtetra
.50482 .31022 .50597 .31042 .50804 .3097 .50689 .3095 Mtetra
.50689 .3095 .50804 .3097 .51011 .30898 .50897 .30878 Mtetra
.50897 .30878 .51011 .30898 .51219 .30825 .51105 .30805 Mtetra
.51105 .30805 .51219 .30825 .51426 .30753 .51312 .30733 Mtetra
.51312 .30733 .51426 .30753 .51634 .30681 .5152 .30661 Mtetra
.5152 .30661 .51634 .30681 .51842 .30608 .51728 .30588 Mtetra
.51728 .30588 .51842 .30608 .5205 .30536 .51937 .30516 Mtetra
.51937 .30516 .5205 .30536 .52259 .30463 .52145 .30443 Mtetra
.52145 .30443 .52259 .30463 .52467 .30391 .52354 .3037 Mtetra
.52354 .3037 .52467 .30391 .52676 .30318 .52563 .30298 Mtetra
.52563 .30298 .52676 .30318 .52884 .30246 .52772 .30225 Mtetra
.52772 .30225 .52884 .30246 .53093 .30173 .52981 .30152 Mtetra
.52981 .30152 .53093 .30173 .53302 .301 .5319 .30079 Mtetra
.5319 .30079 .53302 .301 .53512 .30027 .53399 .30006 Mtetra
.53399 .30006 .53512 .30027 .53721 .29955 .53609 .29934 Mtetra
.53609 .29934 .53721 .29955 .5393 .29882 .53819 .2986 Mtetra
.53819 .2986 .5393 .29882 .5414 .29809 .54029 .29787 Mtetra
.54029 .29787 .5414 .29809 .5435 .29736 .54239 .29714 Mtetra
.54239 .29714 .5435 .29736 .5456 .29662 .54449 .29641 Mtetra
.54449 .29641 .5456 .29662 .5477 .29589 .54659 .29568 Mtetra
.54659 .29568 .5477 .29589 .54981 .29516 .5487 .29495 Mtetra
.5487 .29495 .54981 .29516 .55191 .29443 .5508 .29421 Mtetra
.5508 .29421 .55191 .29443 .55402 .29369 .55291 .29348 Mtetra
.55291 .29348 .55402 .29369 .55613 .29296 .55502 .29274 Mtetra
.55502 .29274 .55613 .29296 .55824 .29222 .55713 .29201 Mtetra
.492 .894 .936 r
.55713 .29201 .55824 .29222 .56035 .29149 .55925 .29127 Mtetra
.55925 .29127 .56035 .29149 .56246 .29075 .56136 .29053 Mtetra
.56136 .29053 .56246 .29075 .56458 .29001 .56348 .28979 Mtetra
.56348 .28979 .56458 .29001 .56669 .28927 .5656 .28906 Mtetra
.491 .894 .936 r
.5656 .28906 .56669 .28927 .56881 .28853 .56772 .28832 Mtetra
.56772 .28832 .56881 .28853 .57093 .28779 .56984 .28758 Mtetra
.491 .894 .935 r
.56984 .28758 .57093 .28779 .57305 .28705 .57196 .28683 Mtetra
.57196 .28683 .57305 .28705 .57517 .28631 .57409 .28609 Mtetra
.49 .894 .935 r
.57409 .28609 .57517 .28631 .5773 .28557 .57621 .28535 Mtetra
.49 .894 .934 r
.57621 .28535 .5773 .28557 .57942 .28482 .57834 .28461 Mtetra
.489 .894 .934 r
.57834 .28461 .57942 .28482 .58155 .28408 .58047 .28386 Mtetra
.489 .893 .933 r
.58047 .28386 .58155 .28408 .58368 .28333 .5826 .28312 Mtetra
.488 .893 .933 r
.5826 .28312 .58368 .28333 .58581 .28259 .58473 .28237 Mtetra
.487 .893 .932 r
.58473 .28237 .58581 .28259 .58794 .28184 .58687 .28163 Mtetra
.58687 .28163 .58794 .28184 .59008 .28109 .58901 .28088 Mtetra
.486 .893 .932 r
.58901 .28088 .59008 .28109 .59221 .28035 .59114 .28013 Mtetra
.486 .892 .931 r
.59114 .28013 .59221 .28035 .59435 .2796 .59328 .27939 Mtetra
.485 .892 .931 r
.59328 .27939 .59435 .2796 .59649 .27885 .59542 .27864 Mtetra
.59542 .27864 .59649 .27885 .59863 .27811 .59757 .27789 Mtetra
.59757 .27789 .59863 .27811 .60077 .27736 .59971 .27715 Mtetra
.486 .892 .931 r
.59971 .27715 .60077 .27736 .60292 .27662 .60186 .2764 Mtetra
.486 .893 .931 r
.60186 .2764 .60292 .27662 .60506 .27587 .604 .27565 Mtetra
.487 .893 .932 r
.604 .27565 .60506 .27587 .60721 .27512 .60615 .2749 Mtetra
.60615 .2749 .60721 .27512 .60936 .27436 .6083 .27414 Mtetra
.488 .893 .931 r
.6083 .27414 .60936 .27436 .61151 .27361 .61046 .27339 Mtetra
.488 .894 .931 r
.61046 .27339 .61151 .27361 .61366 .27285 .61261 .27263 Mtetra
.488 .894 .93 r
.61261 .27263 .61366 .27285 .61582 .27208 .61477 .27187 Mtetra
.488 .894 .929 r
.61477 .27187 .61582 .27208 .61797 .27131 .61692 .2711 Mtetra
.486 .894 .927 r
.61692 .2711 .61797 .27131 .62013 .27052 .61908 .27033 Mtetra
.478 .891 .922 r
.61908 .27033 .62013 .27052 .62229 .26972 .62124 .26957 Mtetra
.475 .892 .911 r
.62124 .26957 .62229 .26972 .62444 .26892 .6234 .26878 Mtetra
.495 .902 .91 r
.6234 .26878 .62444 .26892 .62661 .26814 .62557 .26793 Mtetra
.562 .929 .93 r
.62557 .26793 .62661 .26814 .62877 .26741 .62772 .26698 Mtetra
.624 .931 .967 r
.62772 .26698 .62877 .26741 .63094 .26669 .62988 .26602 Mtetra
.652 .903 .982 r
.62988 .26602 .63094 .26669 .6331 .26595 .63205 .26509 Mtetra
.635 .862 .985 r
.63205 .26509 .6331 .26595 .63527 .26517 .63422 .26429 Mtetra
.625 .854 .986 r
.63422 .26429 .63527 .26517 .63744 .26438 .63639 .26353 Mtetra
.605 .851 .99 r
.63639 .26353 .63744 .26438 .63961 .26361 .63856 .26283 Mtetra
.552 .841 .998 r
.63856 .26283 .63961 .26361 .64179 .26289 .64075 .26225 Mtetra
.585 .885 .991 r
.64075 .26225 .64179 .26289 .64397 .26216 .64292 .26151 Mtetra
.713 .927 .962 r
.64292 .26151 .64397 .26216 .64614 .26141 .64509 .26034 Mtetra
.879 .872 .826 r
.64509 .26034 .64614 .26141 .64832 .2606 .64721 .25801 Mtetra
.827 .691 .714 r
.64721 .25801 .64832 .2606 .6505 .25978 .64929 .25495 Mtetra
.748 .56 .642 r
.64929 .25495 .6505 .25978 .65268 .25899 .65136 .25146 Mtetra
.586 .41 .61 r
.65136 .25146 .65268 .25899 .65486 .25827 .65352 .25012 Mtetra
.536 .369 .603 r
.65352 .25012 .65486 .25827 .65705 .25756 .65571 .24967 Mtetra
.52 .362 .606 r
.65571 .24967 .65705 .25756 .65924 .25685 .65792 .24951 Mtetra
.553 .39 .615 r
.65792 .24951 .65924 .25685 .66143 .25612 .66011 .24883 Mtetra
.553 .391 .616 r
.66011 .24883 .66143 .25612 .66363 .25538 .66231 .24815 Mtetra
.554 .393 .617 r
.66231 .24815 .66363 .25538 .66582 .25464 .6645 .24745 Mtetra
.556 .395 .618 r
.6645 .24745 .66582 .25464 .66801 .25389 .66669 .24673 Mtetra
.557 .396 .618 r
.66669 .24673 .66801 .25389 .67021 .25313 .66889 .24599 Mtetra
.558 .397 .618 r
.66889 .24599 .67021 .25313 .67241 .25237 .67108 .24524 Mtetra
.559 .397 .619 r
.67108 .24524 .67241 .25237 .67461 .25161 .67328 .24447 Mtetra
.559 .398 .619 r
.67328 .24447 .67461 .25161 .67681 .25084 .67548 .2437 Mtetra
.56 .398 .619 r
.67548 .2437 .67681 .25084 .67901 .25006 .67767 .2429 Mtetra
.561 .398 .618 r
.67767 .2429 .67901 .25006 .68122 .24928 .67987 .24209 Mtetra
.562 .399 .618 r
.67987 .24209 .68122 .24928 .68342 .24849 .68207 .24126 Mtetra
.563 .399 .617 r
.68207 .24126 .68342 .24849 .68563 .24769 .68427 .2404 Mtetra
.565 .4 .616 r
.68427 .2404 .68563 .24769 .68783 .24687 .68647 .23949 Mtetra
.566 .399 .614 r
.68647 .23949 .68783 .24687 .69004 .24604 .68867 .23855 Mtetra
.568 .399 .612 r
.68867 .23855 .69004 .24604 .69225 .24519 .69087 .23755 Mtetra
.6 .419 .608 r
.69087 .23755 .69225 .24519 .69446 .24429 .69303 .23589 Mtetra
.573 .393 .599 r
.69303 .23589 .69446 .24429 .69667 .24338 .69522 .23464 Mtetra
.519 .353 .595 r
.69522 .23464 .69667 .24338 .69888 .24248 .69747 .23448 Mtetra
.358 .252 .594 r
.69747 .23448 .69888 .24248 .70109 .24164 .69986 .23687 Mtetra
.351 .312 .675 r
.69986 .23687 .70109 .24164 .70331 .24081 .70222 .23837 Mtetra
.354 .459 .828 r
.70222 .23837 .70331 .24081 .70553 .23996 .70453 .23905 Mtetra
.573 .752 .962 r
.00274 .48203 .0041 .48307 .00582 .48244 .00441 .48166 Mtetra
.739 .837 .925 r
.00441 .48166 .00582 .48244 .00759 .48145 .00619 .48066 Mtetra
.793 .832 .882 r
.00619 .48066 .00759 .48145 .00939 .48028 .00802 .4793 Mtetra
.698 .794 .925 r
.00802 .4793 .00939 .48028 .01113 .47951 .00977 .47848 Mtetra
.678 .783 .929 r
.00977 .47848 .01113 .47951 .01286 .47885 .01151 .47776 Mtetra
.656 .767 .931 r
.01151 .47776 .01286 .47885 .01457 .47827 .01323 .47712 Mtetra
.634 .75 .932 r
.01323 .47712 .01457 .47827 .01628 .47776 .01494 .47657 Mtetra
.603 .735 .937 r
.01494 .47657 .01628 .47776 .01797 .47734 .01663 .47613 Mtetra
.567 .718 .943 r
.01663 .47613 .01797 .47734 .01964 .47703 .01831 .4758 Mtetra
.477 .68 .955 r
.01831 .4758 .01964 .47703 .02128 .47696 .01996 .47571 Mtetra
.472 .676 .954 r
.01996 .47571 .02128 .47696 .02293 .47688 .0216 .47564 Mtetra
.5 .688 .952 r
.0216 .47564 .02293 .47688 .02458 .47673 .02325 .47549 Mtetra
.523 .699 .95 r
.02325 .47549 .02458 .47673 .02623 .47665 .02492 .47529 Mtetra
.596 .703 .918 r
.02492 .47529 .02623 .47665 .02792 .47626 .02662 .47489 Mtetra
.666 .723 .891 r
.02662 .47489 .02792 .47626 .0297 .47534 .02836 .47418 Mtetra
.803 .774 .827 r
.02836 .47418 .0297 .47534 .0318 .47228 .03025 .47252 Mtetra
.896 .953 .831 r
.03025 .47252 .0318 .47228 .03436 .46612 .03222 .47031 Mtetra
0 0 0 r
.03222 .47031 .03436 .46612 .06629 .2623 .03425 .46769 Mtetra
.495 .254 .478 r
.03425 .46769 .06629 .2623 .06823 .2596 .03597 .46717 Mtetra
.496 .254 .478 r
.03597 .46717 .06823 .2596 .0698 .2594 .03765 .46691 Mtetra
.494 .253 .477 r
.03765 .46691 .0698 .2594 .07135 .25934 .03945 .46589 Mtetra
.474 .235 .471 r
.03945 .46589 .07135 .25934 .07348 .25529 .04237 .45721 Mtetra
0 0 0 r
.04237 .45721 .07348 .25529 .07549 .25214 .07386 .25367 Mtetra
.977 .919 .653 r
.07386 .25367 .07549 .25214 .07736 .24989 .07608 .24903 Mtetra
.831 .808 .828 r
.07608 .24903 .07736 .24989 .07911 .24841 .07787 .2473 Mtetra
.716 .765 .891 r
.07787 .2473 .07911 .24841 .08079 .24748 .07954 .24642 Mtetra
.58 .739 .951 r
.07954 .24642 .08079 .24748 .08238 .24715 .08114 .24606 Mtetra
.373 .647 .963 r
.08114 .24606 .08238 .24715 .08372 .24857 .08267 .24616 Mtetra
.254 .357 .776 r
.08267 .24616 .08372 .24857 .08459 .25335 .0841 .24695 Mtetra
.233 .152 .554 r
.0841 .24695 .08459 .25335 .057 .45765 .08533 .24923 Mtetra
0 0 .005 r
.08533 .24923 .057 .45765 .05806 .46185 .05826 .44996 Mtetra
0 0 .207 r
.05826 .44996 .05806 .46185 .05952 .46327 .05851 .45981 Mtetra
0 0 .501 r
.05851 .45981 .05952 .46327 .06111 .46373 .05981 .46239 Mtetra
.426 .639 .945 r
.05981 .46239 .06111 .46373 .06283 .46335 .06147 .46244 Mtetra
.69 .814 .941 r
.06147 .46244 .06283 .46335 .06461 .46256 .06325 .46165 Mtetra
.752 .819 .905 r
.06325 .46165 .06461 .46256 .06641 .46162 .06507 .46054 Mtetra
.609 .76 .951 r
.06507 .46054 .06641 .46162 .06811 .46136 .06681 .46005 Mtetra
.585 .711 .93 r
.06681 .46005 .06811 .46136 .06982 .46107 .06853 .45967 Mtetra
.648 .716 .898 r
.06853 .45967 .06982 .46107 .0716 .46031 .07029 .45905 Mtetra
.799 .764 .822 r
.07029 .45905 .0716 .46031 .07368 .45736 .0722 .45737 Mtetra
.912 .915 .807 r
.0722 .45737 .07368 .45736 .0763 .45048 .07422 .45485 Mtetra
0 0 0 r
.07422 .45485 .0763 .45048 .10599 .2453 .07634 .45162 Mtetra
.494 .253 .477 r
.07634 .45162 .10599 .2453 .10796 .24232 .07815 .45058 Mtetra
.496 .255 .478 r
.07815 .45058 .10796 .24232 .10958 .24194 .07984 .45048 Mtetra
.494 .253 .477 r
.07984 .45048 .10958 .24194 .11116 .24187 .08164 .44959 Mtetra
.466 .228 .469 r
.08164 .44959 .11116 .24187 .1131 .23918 .08495 .43757 Mtetra
0 0 0 r
.08495 .43757 .1131 .23918 .11504 .23642 .1135 .2376 Mtetra
.973 .923 .672 r
.1135 .2376 .11504 .23642 .11689 .23438 .11564 .23339 Mtetra
.8 .796 .848 r
.11564 .23339 .11689 .23438 .11859 .23342 .11741 .23194 Mtetra
.619 .678 .884 r
.11741 .23194 .11859 .23342 .12022 .23299 .11905 .23146 Mtetra
.517 .629 .9 r
.11905 .23146 .12022 .23299 .12183 .23276 .12064 .23134 Mtetra
.588 .678 .903 r
.12064 .23134 .12183 .23276 .12346 .23235 .12227 .23099 Mtetra
.634 .704 .896 r
.12227 .23099 .12346 .23235 .12511 .23181 .12392 .23045 Mtetra
.643 .708 .894 r
.12392 .23045 .12511 .23181 .12677 .23122 .12557 .22988 Mtetra
.652 .713 .893 r
.12557 .22988 .12677 .23122 .12843 .23058 .12723 .22927 Mtetra
.66 .721 .894 r
.12723 .22927 .12843 .23058 .1301 .2299 .1289 .22862 Mtetra
.669 .729 .895 r
.1289 .22862 .1301 .2299 .13178 .22919 .13058 .22794 Mtetra
.706 .744 .881 r
.13058 .22794 .13178 .22919 .1335 .22818 .13227 .22707 Mtetra
.71 .769 .899 r
.13227 .22707 .1335 .22818 .13521 .22723 .13397 .22621 Mtetra
.664 .776 .933 r
.13397 .22621 .13521 .22723 .13686 .22672 .13564 .22556 Mtetra
.501 .694 .955 r
.13564 .22556 .13686 .22672 .13831 .22782 .13725 .22542 Mtetra
.36 .425 .793 r
.13725 .22542 .13831 .22782 .13933 .23236 .13878 .22594 Mtetra
.329 .225 .581 r
.13878 .22594 .13933 .23236 .11527 .43647 .14016 .22764 Mtetra
.457 .226 .475 r
.14016 .22764 .11527 .43647 .11641 .441 .13996 .24193 Mtetra
0 0 .038 r
.13996 .24193 .11641 .441 .11795 .44239 .11705 .4379 Mtetra
0 0 .481 r
.11705 .4379 .11795 .44239 .1196 .4429 .11836 .44113 Mtetra
0 .305 .798 r
.11836 .44113 .1196 .4429 .12128 .44319 .11995 .44215 Mtetra
.459 .718 .98 r
.11995 .44215 .12128 .44319 .12301 .44306 .12168 .44203 Mtetra
.742 .805 .902 r
.12168 .44203 .12301 .44306 .12484 .44211 .12353 .44095 Mtetra
.895 .763 .708 r
.12353 .44095 .12484 .44211 .12702 .43835 .12573 .43704 Mtetra
.948 .689 .51 r
.12573 .43704 .12702 .43835 .15381 .23197 .15274 .22968 Mtetra
.913 .69 .586 r
.15274 .22968 .15381 .23197 .15693 .21954 .15574 .21821 Mtetra
.846 .749 .757 r
.15574 .21821 .15693 .21954 .15883 .21706 .15764 .21577 Mtetra
.661 .728 .899 r
.15764 .21577 .15883 .21706 .16052 .21638 .15933 .21512 Mtetra
.513 .679 .94 r
.15933 .21512 .16052 .21638 .16215 .2162 .16096 .21496 Mtetra
.633 .728 .917 r
.16096 .21496 .16215 .2162 .16384 .21554 .16263 .21443 Mtetra
.714 .773 .899 r
.16263 .21443 .16384 .21554 .16557 .21453 .16435 .21354 Mtetra
.676 .788 .933 r
.16435 .21354 .16557 .21453 .16726 .2139 .16605 .21284 Mtetra
.401 .671 .97 r
.16605 .21284 .16726 .2139 .16878 .2147 .16766 .21287 Mtetra
.102 .345 .814 r
.16766 .21287 .16878 .2147 .16997 .21837 .16917 .21376 Mtetra
.27 .229 .626 r
.16917 .21376 .16997 .21837 .1479 .42227 .17061 .21531 Mtetra
.495 .259 .486 r
.17061 .21531 .1479 .42227 .14902 .42757 .17211 .21633 Mtetra
.499 .262 .487 r
.17211 .21633 .14902 .42757 .15079 .4273 .17379 .21584 Mtetra
.501 .264 .487 r
.17379 .21584 .15079 .4273 .15268 .42595 .17554 .21476 Mtetra
.5 .263 .487 r
.17554 .21476 .15268 .42595 .15456 .42473 .17728 .21382 Mtetra
.17728 .21382 .15456 .42473 .15638 .42406 .17899 .21313 Mtetra
.17899 .21313 .15638 .42406 .1582 .42339 .18069 .21244 Mtetra
.18069 .21244 .1582 .42339 .16001 .42275 .1824 .21177 Mtetra
.1824 .21177 .16001 .42275 .16182 .42215 .18411 .2111 Mtetra
.499 .263 .487 r
.18411 .2111 .16182 .42215 .16364 .42155 .18582 .21044 Mtetra
.501 .264 .487 r
.18582 .21044 .16364 .42155 .16549 .42061 .18758 .20933 Mtetra
.18758 .20933 .16549 .42061 .16736 .41952 .18935 .20812 Mtetra
.499 .262 .486 r
.18935 .20812 .16736 .41952 .16915 .41917 .19102 .20783 Mtetra
.486 .251 .483 r
.19102 .20783 .16915 .41917 .17074 .42066 .19216 .21236 Mtetra
0 0 .078 r
.19216 .21236 .17074 .42066 .17228 .42266 .17141 .41763 Mtetra
0 0 .373 r
.17141 .41763 .17228 .42266 .17391 .42386 .17269 .42204 Mtetra
0 .291 .789 r
.17269 .42204 .17391 .42386 .17564 .42409 .17433 .42315 Mtetra
.58 .788 .978 r
.17433 .42315 .17564 .42409 .17746 .42354 .17614 .4227 Mtetra
.699 .839 .95 r
.17614 .4227 .17746 .42354 .17931 .42276 .178 .42183 Mtetra
.698 .821 .941 r
.178 .42183 .17931 .42276 .18116 .422 .17986 .42097 Mtetra
.647 .791 .951 r
.17986 .42097 .18116 .422 .183 .42135 .18169 .42032 Mtetra
.647 .79 .951 r
.18169 .42032 .183 .42135 .18483 .42071 .18353 .41967 Mtetra
.646 .788 .95 r
.18353 .41967 .18483 .42071 .18667 .42007 .18537 .41902 Mtetra
.644 .786 .95 r
.18537 .41902 .18667 .42007 .18851 .41944 .18721 .41838 Mtetra
.636 .782 .952 r
.18721 .41838 .18851 .41944 .19034 .41884 .18905 .41777 Mtetra
.616 .774 .956 r
.18905 .41777 .19034 .41884 .19217 .41833 .19088 .41723 Mtetra
.594 .763 .96 r
.19088 .41723 .19217 .41833 .194 .41789 .19271 .41677 Mtetra
.596 .758 .956 r
.19271 .41677 .194 .41789 .19582 .41745 .19454 .4163 Mtetra
.614 .759 .948 r
.19454 .4163 .19582 .41745 .19765 .41695 .19637 .41577 Mtetra
.636 .762 .939 r
.19637 .41577 .19765 .41695 .19949 .41635 .19821 .41517 Mtetra
.644 .763 .935 r
.19821 .41517 .19949 .41635 .20134 .41572 .20006 .41453 Mtetra
.646 .762 .934 r
.20006 .41453 .20134 .41572 .20319 .41508 .20191 .41389 Mtetra
.645 .761 .934 r
.20191 .41389 .20319 .41508 .20504 .41445 .20377 .41325 Mtetra
.647 .761 .932 r
.20377 .41325 .20504 .41445 .20689 .41381 .20562 .4126 Mtetra
.647 .76 .932 r
.20562 .4126 .20689 .41381 .20875 .41316 .20747 .41195 Mtetra
.647 .759 .931 r
.20747 .41195 .20875 .41316 .2106 .41252 .20933 .4113 Mtetra
.653 .76 .928 r
.20933 .4113 .2106 .41252 .21246 .41186 .21119 .41063 Mtetra
.667 .762 .921 r
.21119 .41063 .21246 .41186 .21433 .41114 .21306 .40989 Mtetra
.685 .764 .912 r
.21306 .40989 .21433 .41114 .2162 .41034 .21494 .40907 Mtetra
.686 .759 .907 r
.21494 .40907 .2162 .41034 .21808 .40954 .21682 .40823 Mtetra
.661 .748 .914 r
.21682 .40823 .21808 .40954 .21994 .4089 .21868 .40752 Mtetra
.617 .72 .919 r
.21868 .40752 .21994 .4089 .22178 .4085 .22054 .40699 Mtetra
.651 .71 .891 r
.22054 .40699 .22178 .4085 .22365 .40778 .2224 .40631 Mtetra
.74 .742 .854 r
.2224 .40631 .22365 .40778 .22562 .40599 .22432 .40508 Mtetra
.866 .828 .809 r
.22432 .40508 .22562 .40599 .22785 .40136 .22634 .40281 Mtetra
.807 .955 .619 r
.22634 .40281 .22785 .40136 .24756 .20589 .22842 .39985 Mtetra
.489 .248 .476 r
.22842 .39985 .24756 .20589 .25099 .18689 .23051 .39684 Mtetra
.494 .253 .477 r
.23051 .39684 .25099 .18689 .2528 .18549 .23241 .39576 Mtetra
.496 .254 .478 r
.23241 .39576 .2528 .18549 .25452 .18523 .23425 .39544 Mtetra
.23425 .39544 .25452 .18523 .25621 .18527 .23608 .39524 Mtetra
.495 .254 .478 r
.23608 .39524 .25621 .18527 .25796 .18463 .23795 .39461 Mtetra
.23795 .39461 .25796 .18463 .25971 .18399 .23982 .39399 Mtetra
.23982 .39399 .25971 .18399 .26147 .18336 .2417 .39336 Mtetra
.2417 .39336 .26147 .18336 .26322 .1827 .24357 .39273 Mtetra
.24357 .39273 .26322 .1827 .26498 .18204 .24545 .39209 Mtetra
.496 .254 .478 r
.24545 .39209 .26498 .18204 .26673 .18153 .2473 .3917 Mtetra
.497 .255 .478 r
.2473 .3917 .26673 .18153 .26844 .18142 .24912 .39183 Mtetra
.495 .253 .477 r
.24912 .39183 .26844 .18142 .2702 .18073 .25101 .3911 Mtetra
.489 .248 .476 r
.25101 .3911 .2702 .18073 .27208 .17867 .25313 .38765 Mtetra
0 0 .12 r
.25313 .38765 .27208 .17867 .27407 .17537 .27246 .17951 Mtetra
.816 .822 .344 r
.27246 .17951 .27407 .17537 .27599 .17285 .27474 .17261 Mtetra
.934 .888 .762 r
.27474 .17261 .27599 .17285 .27784 .1711 .2767 .16969 Mtetra
.716 .733 .864 r
.2767 .16969 .27784 .1711 .27962 .17025 .27849 .1687 Mtetra
.626 .68 .881 r
.27849 .1687 .27962 .17025 .28138 .16965 .28024 .16816 Mtetra
.578 .67 .902 r
.28024 .16816 .28138 .16965 .28313 .16917 .28198 .16781 Mtetra
.616 .709 .912 r
.28198 .16781 .28313 .16917 .28489 .16865 .28374 .16731 Mtetra
.616 .714 .916 r
.28374 .16731 .28489 .16865 .28665 .16812 .2855 .16682 Mtetra
.636 .728 .915 r
.2855 .16682 .28665 .16812 .28841 .1675 .28726 .16625 Mtetra
.685 .752 .902 r
.28726 .16625 .28841 .1675 .2902 .16666 .28904 .16545 Mtetra
.696 .764 .904 r
.28904 .16545 .2902 .16666 .29199 .16578 .29083 .16461 Mtetra
.702 .772 .907 r
.29083 .16461 .29199 .16578 .29378 .16487 .29262 .16375 Mtetra
.711 .783 .909 r
.29262 .16375 .29378 .16487 .29558 .16384 .29441 .16285 Mtetra
.673 .8 .943 r
.29441 .16285 .29558 .16384 .29736 .16312 .29619 .16212 Mtetra
.575 .767 .97 r
.29619 .16212 .29736 .16312 .29909 .16308 .29795 .16172 Mtetra
.339 .578 .93 r
.29795 .16172 .29909 .16308 .30066 .16526 .29966 .16198 Mtetra
.284 .31 .712 r
.29966 .16198 .30066 .16526 .30171 .17439 .30131 .1631 Mtetra
.301 .162 .519 r
.30131 .1631 .30171 .17439 .28832 .37913 .30277 .1667 Mtetra
0 0 .162 r
.30277 .1667 .28832 .37913 .28998 .38183 .28919 .37455 Mtetra
0 0 .43 r
.28919 .37455 .28998 .38183 .29177 .38288 .29064 .38011 Mtetra
0 .163 .686 r
.29064 .38011 .29177 .38288 .29361 .38316 .29237 .38194 Mtetra
.476 .697 .965 r
.29237 .38194 .29361 .38316 .29549 .38303 .29425 .38182 Mtetra
.672 .773 .926 r
.29425 .38182 .29549 .38303 .29741 .38234 .29618 .38104 Mtetra
.759 .778 .869 r
.29618 .38104 .29741 .38234 .29939 .38088 .29815 .37972 Mtetra
.811 .807 .847 r
.29815 .37972 .29939 .38088 .30152 .37723 .30014 .37801 Mtetra
.849 .99 .725 r
.30014 .37801 .30152 .37723 .304 .36848 .30219 .37544 Mtetra
0 0 .151 r
.30219 .37544 .304 .36848 .32015 .16042 .3044 .37073 Mtetra
0 0 .154 r
.3044 .37073 .32015 .16042 .32218 .1563 .32059 .16159 Mtetra
0 0 0 r
.32059 .16159 .32218 .1563 .32408 .15399 .32285 .1542 Mtetra
.951 .939 .74 r
.32285 .1542 .32408 .15399 .32594 .15248 .32481 .15112 Mtetra
.707 .743 .88 r
.32481 .15112 .32594 .15248 .32774 .15172 .32662 .15018 Mtetra
.598 .675 .894 r
.32662 .15018 .32774 .15172 .32952 .15125 .3284 .14975 Mtetra
.535 .655 .912 r
.3284 .14975 .32952 .15125 .3313 .15087 .33017 .14955 Mtetra
.692 .746 .893 r
.33017 .14955 .3313 .15087 .33313 .14985 .33198 .1487 Mtetra
.677 .774 .923 r
.33198 .1487 .33313 .14985 .33494 .14906 .33379 .14794 Mtetra
.615 .761 .949 r
.33379 .14794 .33494 .14906 .33671 .14878 .33559 .14743 Mtetra
.42 .625 .938 r
.33559 .14743 .33671 .14878 .33835 .15076 .33734 .14751 Mtetra
.36 .362 .726 r
.33734 .14751 .33835 .15076 .33965 .1583 .33906 .14832 Mtetra
.356 .212 .545 r
.33906 .14832 .33965 .1583 .32874 .36426 .34067 .15084 Mtetra
0 0 .189 r
.34067 .15084 .32874 .36426 .33046 .36723 .32972 .35816 Mtetra
0 0 .407 r
.32972 .35816 .33046 .36723 .33229 .36837 .33119 .36522 Mtetra
0 .117 .647 r
.33119 .36522 .33229 .36837 .33418 .36865 .33296 .36742 Mtetra
.564 .735 .956 r
.33296 .36742 .33418 .36865 .33612 .36804 .33488 .36704 Mtetra
.711 .825 .936 r
.33488 .36704 .33612 .36804 .33808 .36712 .33685 .36606 Mtetra
.762 .825 .902 r
.33685 .36606 .33808 .36712 .34005 .36606 .33883 .3648 Mtetra
.583 .737 .949 r
.33883 .3648 .34005 .36606 .34198 .36584 .34077 .36436 Mtetra
.612 .71 .914 r
.34077 .36436 .34198 .36584 .34391 .36538 .34271 .36383 Mtetra
.674 .722 .885 r
.34271 .36383 .34391 .36538 .34589 .36433 .34468 .36299 Mtetra
.842 .786 .798 r
.34468 .36299 .34589 .36433 .34803 .3603 .34672 .36076 Mtetra
.936 .967 .729 r
.34672 .36076 .34803 .3603 .35063 .34786 .34881 .35758 Mtetra
.183 0 .288 r
.34881 .35758 .35063 .34786 .3637 .14257 .35098 .35311 Mtetra
.49 .249 .476 r
.35098 .35311 .3637 .14257 .36563 .14 .35306 .34998 Mtetra
.494 .253 .477 r
.35306 .34998 .36563 .14 .36746 .13917 .35503 .349 Mtetra
.499 .257 .478 r
.35503 .349 .36746 .13917 .36922 .13981 .35688 .3503 Mtetra
.503 .26 .479 r
.35688 .3503 .36922 .13981 .37046 .15049 .35865 .35324 Mtetra
.501 .258 .478 r
.35865 .35324 .37046 .15049 .36182 .3539 .36048 .35514 Mtetra
.572 .084 .058 r
.36048 .35514 .36182 .3539 .36357 .35732 .36236 .35615 Mtetra
.276 .607 .954 r
.36236 .35615 .36357 .35732 .36547 .35795 .36428 .35644 Mtetra
.591 .699 .917 r
.36428 .35644 .36547 .35795 .36743 .35748 .36624 .35599 Mtetra
.759 .759 .852 r
.36624 .35599 .36743 .35748 .36944 .35592 .36824 .3546 Mtetra
.938 .764 .641 r
.36824 .3546 .36944 .35592 .37167 .35008 .37047 .34876 Mtetra
.969 .689 .446 r
.37047 .34876 .37167 .35008 .38379 .13645 .38268 .13511 Mtetra
.944 .75 .611 r
.38268 .13511 .38379 .13645 .38591 .12974 .3848 .12843 Mtetra
.802 .778 .83 r
.3848 .12843 .38591 .12974 .3878 .12811 .38669 .12679 Mtetra
.645 .736 .916 r
.38669 .12679 .3878 .12811 .38963 .12747 .38852 .12615 Mtetra
.527 .688 .94 r
.38852 .12615 .38963 .12747 .39145 .12726 .39034 .12594 Mtetra
.727 .761 .88 r
.39034 .12594 .39145 .12726 .39331 .12621 .3922 .12488 Mtetra
.697 .752 .894 r
.3922 .12488 .39331 .12621 .39516 .12533 .39406 .12399 Mtetra
.521 .681 .938 r
.39406 .12399 .39516 .12533 .39698 .12515 .39588 .12379 Mtetra
.835 .402 0 r
.39588 .12379 .39698 .12515 .39863 .12908 .39753 .12766 Mtetra
.97 .683 .426 r
.39753 .12766 .39863 .12908 .39147 .3421 .39029 .34063 Mtetra
.904 .505 .097 r
.39029 .34063 .39147 .3421 .39319 .34782 .392 .34646 Mtetra
.142 .484 .9 r
.392 .34646 .39319 .34782 .39513 .34832 .39393 .34712 Mtetra
.656 .779 .939 r
.39393 .34712 .39513 .34832 .39713 .34751 .39593 .34638 Mtetra
.811 .825 .861 r
.39593 .34638 .39713 .34751 .39915 .34596 .39796 .3447 Mtetra
.899 .796 .738 r
.39796 .3447 .39915 .34596 .40119 .34427 .40006 .34141 Mtetra
.899 .688 .609 r
.40006 .34141 .40119 .34427 .40324 .34199 .4023 .33426 Mtetra
.966 .681 .443 r
.4023 .33426 .40324 .34199 .40535 .33819 .4123 .12417 Mtetra
.51 .271 .488 r
.4123 .12417 .40535 .33819 .41499 .1322 .41432 .11908 Mtetra
.589 .374 .556 r
.41432 .11908 .41499 .1322 .41727 .12014 .41625 .11654 Mtetra
.688 .55 .692 r
.41625 .11654 .41727 .12014 .41924 .11643 .41815 .11485 Mtetra
.695 .714 .864 r
.41815 .11485 .41924 .11643 .42113 .11504 .42002 .11392 Mtetra
.62 .768 .95 r
.42002 .11392 .42113 .11504 .42298 .11448 .42188 .11336 Mtetra
.578 .752 .96 r
.42188 .11336 .42298 .11448 .42483 .11422 .42374 .11295 Mtetra
.721 .772 .893 r
.42374 .11295 .42483 .11422 .4267 .1134 .42561 .11193 Mtetra
.717 .738 .868 r
.42561 .11193 .4267 .1134 .42858 .11245 .42749 .1109 Mtetra
.633 .694 .889 r
.42749 .1109 .42858 .11245 .43045 .11173 .42936 .11029 Mtetra
0 .301 .794 r
.42936 .11029 .43045 .11173 .4323 .11165 .43117 .11143 Mtetra
.883 .454 .153 r
.43117 .11143 .4323 .11165 .43412 .11239 .43288 .116 Mtetra
.968 .675 .42 r
.43288 .116 .43412 .11239 .4359 .11471 .42829 .32592 Mtetra
.506 .263 .479 r
.42829 .32592 .4359 .11471 .43163 .32124 .43014 .33067 Mtetra
.549 .241 .399 r
.43014 .33067 .43163 .32124 .43334 .33105 .43209 .33223 Mtetra
.47 0 0 r
.43209 .33223 .43334 .33105 .43526 .33373 .43407 .33279 Mtetra
.47 .761 .994 r
.43407 .33279 .43526 .33373 .43725 .33404 .43608 .33255 Mtetra
.639 .728 .913 r
.43608 .33255 .43725 .33404 .43927 .3334 .43811 .33188 Mtetra
.677 .737 .895 r
.43811 .33188 .43927 .3334 .44131 .33241 .44014 .33101 Mtetra
.661 .75 .916 r
.44014 .33101 .44131 .33241 .44333 .33158 .44216 .33023 Mtetra
.647 .754 .928 r
.44216 .33023 .44333 .33158 .44536 .33087 .44419 .32953 Mtetra
.646 .755 .929 r
.44419 .32953 .44536 .33087 .44739 .33015 .44622 .32882 Mtetra
.646 .756 .93 r
.44622 .32882 .44739 .33015 .44942 .32945 .44825 .32811 Mtetra
.645 .757 .931 r
.44825 .32811 .44942 .32945 .45145 .32874 .45029 .32741 Mtetra
.645 .758 .931 r
.45029 .32741 .45145 .32874 .45349 .32804 .45232 .32671 Mtetra
.45232 .32671 .45349 .32804 .45552 .32733 .45436 .326 Mtetra
.645 .758 .932 r
.45436 .326 .45552 .32733 .45756 .32663 .45639 .3253 Mtetra
.45639 .3253 .45756 .32663 .45959 .32593 .45843 .3246 Mtetra
.645 .759 .932 r
.45843 .3246 .45959 .32593 .46163 .32522 .46047 .32389 Mtetra
.46047 .32389 .46163 .32522 .46368 .32451 .46251 .32318 Mtetra
.46251 .32318 .46368 .32451 .46572 .32381 .46456 .32248 Mtetra
.46456 .32248 .46572 .32381 .46776 .3231 .4666 .32177 Mtetra
.4666 .32177 .46776 .3231 .46981 .32239 .46865 .32106 Mtetra
.46865 .32106 .46981 .32239 .47185 .32168 .4707 .32035 Mtetra
.646 .759 .932 r
.4707 .32035 .47185 .32168 .4739 .32097 .47275 .31963 Mtetra
.646 .759 .931 r
.47275 .31963 .4739 .32097 .47595 .32026 .4748 .31892 Mtetra
.4748 .31892 .47595 .32026 .47801 .31955 .47685 .31821 Mtetra
.47685 .31821 .47801 .31955 .48006 .31883 .4789 .31749 Mtetra
.4789 .31749 .48006 .31883 .48211 .31812 .48096 .31678 Mtetra
.48096 .31678 .48211 .31812 .48417 .3174 .48302 .31606 Mtetra
.48302 .31606 .48417 .3174 .48623 .31669 .48508 .31535 Mtetra
.48508 .31535 .48623 .31669 .48829 .31597 .48714 .31463 Mtetra
.48714 .31463 .48829 .31597 .49035 .31526 .4892 .31391 Mtetra
.4892 .31391 .49035 .31526 .49241 .31454 .49126 .31319 Mtetra
.49126 .31319 .49241 .31454 .49448 .31382 .49333 .31247 Mtetra
.49333 .31247 .49448 .31382 .49654 .3131 .4954 .31175 Mtetra
.4954 .31175 .49654 .3131 .49861 .31238 .49746 .31103 Mtetra
.49746 .31103 .49861 .31238 .50068 .31166 .49953 .31031 Mtetra
.49953 .31031 .50068 .31166 .50275 .31094 .50161 .30959 Mtetra
.50161 .30959 .50275 .31094 .50482 .31022 .50368 .30887 Mtetra
.50368 .30887 .50482 .31022 .50689 .3095 .50575 .30814 Mtetra
.50575 .30814 .50689 .3095 .50897 .30878 .50783 .30742 Mtetra
.50783 .30742 .50897 .30878 .51105 .30805 .50991 .3067 Mtetra
.50991 .3067 .51105 .30805 .51312 .30733 .51199 .30597 Mtetra
.51199 .30597 .51312 .30733 .5152 .30661 .51407 .30525 Mtetra
.51407 .30525 .5152 .30661 .51728 .30588 .51615 .30452 Mtetra
.51615 .30452 .51728 .30588 .51937 .30516 .51823 .3038 Mtetra
.51823 .3038 .51937 .30516 .52145 .30443 .52032 .30307 Mtetra
.52032 .30307 .52145 .30443 .52354 .3037 .52241 .30234 Mtetra
.52241 .30234 .52354 .3037 .52563 .30298 .5245 .30161 Mtetra
.5245 .30161 .52563 .30298 .52772 .30225 .52659 .30089 Mtetra
.52659 .30089 .52772 .30225 .52981 .30152 .52868 .30016 Mtetra
.52868 .30016 .52981 .30152 .5319 .30079 .53077 .29943 Mtetra
.53077 .29943 .5319 .30079 .53399 .30006 .53287 .2987 Mtetra
.53287 .2987 .53399 .30006 .53609 .29934 .53496 .29797 Mtetra
.53496 .29797 .53609 .29934 .53819 .2986 .53706 .29724 Mtetra
.53706 .29724 .53819 .2986 .54029 .29787 .53916 .2965 Mtetra
.53916 .2965 .54029 .29787 .54239 .29714 .54126 .29577 Mtetra
.54126 .29577 .54239 .29714 .54449 .29641 .54337 .29504 Mtetra
.54337 .29504 .54449 .29641 .54659 .29568 .54547 .29431 Mtetra
.54547 .29431 .54659 .29568 .5487 .29495 .54758 .29357 Mtetra
.54758 .29357 .5487 .29495 .5508 .29421 .54969 .29284 Mtetra
.54969 .29284 .5508 .29421 .55291 .29348 .55179 .2921 Mtetra
.55179 .2921 .55291 .29348 .55502 .29274 .55391 .29137 Mtetra
.55391 .29137 .55502 .29274 .55713 .29201 .55602 .29063 Mtetra
.55602 .29063 .55713 .29201 .55925 .29127 .55813 .28989 Mtetra
.55813 .28989 .55925 .29127 .56136 .29053 .56025 .28915 Mtetra
.56025 .28915 .56136 .29053 .56348 .28979 .56237 .28841 Mtetra
.56237 .28841 .56348 .28979 .5656 .28906 .56449 .28767 Mtetra
.56449 .28767 .5656 .28906 .56772 .28832 .56661 .28693 Mtetra
.56661 .28693 .56772 .28832 .56984 .28758 .56873 .28619 Mtetra
.56873 .28619 .56984 .28758 .57196 .28683 .57085 .28545 Mtetra
.647 .759 .931 r
.57085 .28545 .57196 .28683 .57409 .28609 .57298 .28471 Mtetra
.57298 .28471 .57409 .28609 .57621 .28535 .57511 .28396 Mtetra
.647 .76 .931 r
.57511 .28396 .57621 .28535 .57834 .28461 .57724 .28322 Mtetra
.57724 .28322 .57834 .28461 .58047 .28386 .57937 .28248 Mtetra
.57937 .28248 .58047 .28386 .5826 .28312 .5815 .28173 Mtetra
.647 .76 .932 r
.5815 .28173 .5826 .28312 .58473 .28237 .58363 .28098 Mtetra
.58363 .28098 .58473 .28237 .58687 .28163 .58577 .28024 Mtetra
.58577 .28024 .58687 .28163 .58901 .28088 .58791 .27949 Mtetra
.646 .76 .932 r
.58791 .27949 .58901 .28088 .59114 .28013 .59004 .27874 Mtetra
.59004 .27874 .59114 .28013 .59328 .27939 .59218 .278 Mtetra
.59218 .278 .59328 .27939 .59542 .27864 .59433 .27725 Mtetra
.59433 .27725 .59542 .27864 .59757 .27789 .59647 .2765 Mtetra
.59647 .2765 .59757 .27789 .59971 .27715 .59862 .27575 Mtetra
.59862 .27575 .59971 .27715 .60186 .2764 .60076 .275 Mtetra
.647 .76 .932 r
.60076 .275 .60186 .2764 .604 .27565 .60291 .27425 Mtetra
.647 .76 .931 r
.60291 .27425 .604 .27565 .60615 .2749 .60506 .2735 Mtetra
.60506 .2735 .60615 .2749 .6083 .27414 .60721 .27274 Mtetra
.60721 .27274 .6083 .27414 .61046 .27339 .60937 .27199 Mtetra
.648 .76 .931 r
.60937 .27199 .61046 .27339 .61261 .27263 .61152 .27123 Mtetra
.648 .761 .931 r
.61152 .27123 .61261 .27263 .61477 .27187 .61368 .27047 Mtetra
.649 .761 .931 r
.61368 .27047 .61477 .27187 .61692 .2711 .61584 .2697 Mtetra
.649 .762 .932 r
.61584 .2697 .61692 .2711 .61908 .27033 .618 .26894 Mtetra
.648 .762 .933 r
.618 .26894 .61908 .27033 .62124 .26957 .62016 .26818 Mtetra
.652 .765 .932 r
.62016 .26818 .62124 .26957 .6234 .26878 .62232 .2674 Mtetra
.662 .77 .93 r
.62232 .2674 .6234 .26878 .62557 .26793 .62449 .26657 Mtetra
.681 .78 .925 r
.62449 .26657 .62557 .26793 .62772 .26698 .62665 .26564 Mtetra
.684 .786 .928 r
.62665 .26564 .62772 .26698 .62988 .26602 .62881 .26471 Mtetra
.676 .789 .934 r
.62881 .26471 .62988 .26602 .63205 .26509 .63097 .26381 Mtetra
.651 .784 .945 r
.63097 .26381 .63205 .26509 .63422 .26429 .63315 .26302 Mtetra
.643 .785 .95 r
.63315 .26302 .63422 .26429 .63639 .26353 .63532 .26227 Mtetra
.623 .779 .956 r
.63532 .26227 .63639 .26353 .63856 .26283 .6375 .2616 Mtetra
.554 .755 .971 r
.6375 .2616 .63856 .26283 .64075 .26225 .63969 .26118 Mtetra
.636 .819 .971 r
.63969 .26118 .64075 .26225 .64292 .26151 .64187 .26042 Mtetra
.797 .864 .899 r
.64187 .26042 .64292 .26151 .64509 .26034 .64401 .25885 Mtetra
.94 .799 .677 r
.64401 .25885 .64509 .26034 .64721 .25801 .64605 .25444 Mtetra
.947 .688 .511 r
.64605 .25444 .64721 .25801 .64929 .25495 .64774 .24143 Mtetra
.971 .663 .361 r
.64774 .24143 .64929 .25495 .65136 .25146 .64146 .03352 Mtetra
.502 .264 .487 r
.64146 .03352 .65136 .25146 .65352 .25012 .64344 .03177 Mtetra
.499 .262 .487 r
.64344 .03177 .65352 .25012 .65571 .24967 .64548 .03131 Mtetra
.498 .261 .486 r
.64548 .03131 .65571 .24967 .65792 .24951 .64755 .03144 Mtetra
.499 .263 .487 r
.64755 .03144 .65792 .24951 .66011 .24883 .64958 .03073 Mtetra
.64958 .03073 .66011 .24883 .66231 .24815 .65162 .03005 Mtetra
.65162 .03005 .66231 .24815 .6645 .24745 .65366 .02936 Mtetra
.65366 .02936 .6645 .24745 .66669 .24673 .65569 .02862 Mtetra
.65569 .02862 .66669 .24673 .66889 .24599 .65773 .02787 Mtetra
.65773 .02787 .66889 .24599 .67108 .24524 .65977 .0271 Mtetra
.65977 .0271 .67108 .24524 .67328 .24447 .66181 .02632 Mtetra
.5 .263 .487 r
.66181 .02632 .67328 .24447 .67548 .2437 .66385 .02551 Mtetra
.66385 .02551 .67548 .2437 .67767 .2429 .66589 .02469 Mtetra
.66589 .02469 .67767 .2429 .67987 .24209 .66793 .02385 Mtetra
.66793 .02385 .67987 .24209 .68207 .24126 .66997 .02298 Mtetra
.66997 .02298 .68207 .24126 .68427 .2404 .67201 .02208 Mtetra
.67201 .02208 .68427 .2404 .68647 .23949 .67405 .02113 Mtetra
.67405 .02113 .68647 .23949 .68867 .23855 .67609 .02015 Mtetra
.67609 .02015 .68867 .23855 .69087 .23755 .67813 .01914 Mtetra
.502 .264 .487 r
.67813 .01914 .69087 .23755 .69303 .23589 .68012 .01733 Mtetra
.5 .263 .487 r
.68012 .01733 .69303 .23589 .69522 .23464 .68216 .01623 Mtetra
.497 .261 .487 r
.68216 .01623 .69522 .23464 .69747 .23448 .68427 .01643 Mtetra
0 0 .36 r
.68427 .01643 .69747 .23448 .69986 .23687 .69815 .22364 Mtetra
0 0 .458 r
.69815 .22364 .69986 .23687 .70222 .23837 .70106 .23497 Mtetra
.035 .167 .672 r
.70106 .23497 .70222 .23837 .70453 .23905 .70349 .23768 Mtetra
.442 .547 .867 r
.00151 .48011 .00274 .48203 .00441 .48166 .0031 .48026 Mtetra
.673 .718 .883 r
.0031 .48026 .00441 .48166 .00619 .48066 .00484 .47953 Mtetra
.759 .775 .866 r
.00484 .47953 .00619 .48066 .00802 .4793 .00665 .47831 Mtetra
.689 .792 .928 r
.00665 .47831 .00802 .4793 .00977 .47848 .00839 .47753 Mtetra
.689 .799 .933 r
.00839 .47753 .00977 .47848 .01151 .47776 .01014 .47675 Mtetra
.68 .789 .932 r
.01014 .47675 .01151 .47776 .01323 .47712 .01188 .47602 Mtetra
.63 .759 .94 r
.01188 .47602 .01323 .47712 .01494 .47657 .01359 .47548 Mtetra
.611 .756 .947 r
.01359 .47548 .01494 .47657 .01663 .47613 .01529 .475 Mtetra
.605 .747 .945 r
.01529 .475 .01663 .47613 .01831 .4758 .01698 .47454 Mtetra
.627 .73 .921 r
.01698 .47454 .01831 .4758 .01996 .47571 .0187 .47402 Mtetra
.622 .66 .866 r
.0187 .47402 .01996 .47571 .0216 .47564 .02041 .4735 Mtetra
.609 .601 .818 r
.02041 .4735 .0216 .47564 .02325 .47549 .02211 .47301 Mtetra
.586 .557 .789 r
.02211 .47301 .02325 .47549 .02492 .47529 .02381 .47261 Mtetra
.581 .539 .772 r
.02381 .47261 .02492 .47529 .02662 .47489 .0255 .47222 Mtetra
.584 .542 .774 r
.0255 .47222 .02662 .47489 .02836 .47418 .0272 .47182 Mtetra
.605 .578 .797 r
.0272 .47182 .02836 .47418 .03025 .47252 .02892 .47132 Mtetra
.628 .742 .929 r
.02892 .47132 .03025 .47252 .03222 .47031 .03064 .47079 Mtetra
.232 .739 .691 r
.03064 .47079 .03222 .47031 .03425 .46769 .03236 .47023 Mtetra
.406 0 .147 r
.03236 .47023 .03425 .46769 .03597 .46717 .03402 .47016 Mtetra
.357 0 .154 r
.03402 .47016 .03597 .46717 .03765 .46691 .03572 .46978 Mtetra
.153 0 .022 r
.03572 .46978 .03765 .46691 .03945 .46589 .03753 .46866 Mtetra
.921 .933 .567 r
.03753 .46866 .03945 .46589 .04237 .45721 .03992 .46367 Mtetra
.948 .697 .525 r
.03992 .46367 .04237 .45721 .07386 .25367 .07213 .25584 Mtetra
.993 .857 .596 r
.07213 .25584 .07386 .25367 .07608 .24903 .07481 .24811 Mtetra
.83 .797 .821 r
.07481 .24811 .07608 .24903 .07787 .2473 .07661 .24634 Mtetra
.684 .787 .928 r
.07661 .24634 .07787 .2473 .07954 .24642 .07826 .24563 Mtetra
.528 .78 .99 r
.07826 .24563 .07954 .24642 .08114 .24606 .07984 .24533 Mtetra
.74 .841 .926 r
.07984 .24533 .08114 .24606 .08267 .24616 .08153 .24438 Mtetra
.669 .653 .826 r
.08153 .24438 .08267 .24616 .0841 .24695 .08318 .24361 Mtetra
.533 .458 .716 r
.08318 .24361 .0841 .24695 .08533 .24923 .08475 .24349 Mtetra
0 0 .478 r
.08475 .24349 .08533 .24923 .05826 .44996 .08583 .24681 Mtetra
0 0 0 r
.08583 .24681 .05826 .44996 .05851 .45981 .05793 .45343 Mtetra
0 0 .1 r
.05793 .45343 .05851 .45981 .05981 .46239 .05862 .46022 Mtetra
.244 .401 .822 r
.05862 .46022 .05981 .46239 .06147 .46244 .06018 .46094 Mtetra
.629 .694 .891 r
.06018 .46094 .06147 .46244 .06325 .46165 .06193 .4604 Mtetra
.724 .758 .879 r
.06193 .4604 .06325 .46165 .06507 .46054 .06374 .45938 Mtetra
.67 .764 .92 r
.06374 .45938 .06507 .46054 .06681 .46005 .06551 .45867 Mtetra
.647 .718 .9 r
.06551 .45867 .06681 .46005 .06853 .45967 .06727 .45805 Mtetra
.646 .681 .869 r
.06727 .45805 .06853 .45967 .07029 .45905 .06903 .45741 Mtetra
.647 .68 .867 r
.06903 .45741 .07029 .45905 .0722 .45737 .07079 .45676 Mtetra
.632 .862 .985 r
.07079 .45676 .0722 .45737 .07422 .45485 .07256 .45612 Mtetra
.037 0 0 r
.07256 .45612 .07422 .45485 .07634 .45162 .07432 .45548 Mtetra
.425 .063 .244 r
.07432 .45548 .07634 .45162 .07815 .45058 .07603 .4553 Mtetra
.419 .077 .277 r
.07603 .4553 .07815 .45058 .07984 .45048 .07775 .45496 Mtetra
.314 0 .214 r
.07775 .45496 .07984 .45048 .08164 .44959 .07957 .45395 Mtetra
0 0 0 r
.07957 .45395 .08164 .44959 .08495 .43757 .08183 .44969 Mtetra
.957 .705 .513 r
.08183 .44969 .08495 .43757 .1135 .2376 .1114 .24294 Mtetra
.948 .867 .451 r
.1114 .24294 .1135 .2376 .11564 .23339 .11429 .2332 Mtetra
.895 .9 .823 r
.11429 .2332 .11564 .23339 .11741 .23194 .11615 .23104 Mtetra
.689 .806 .937 r
.11615 .23104 .11741 .23194 .11905 .23146 .11783 .2303 Mtetra
.55 .712 .947 r
.11783 .2303 .11905 .23146 .12064 .23134 .11944 .23003 Mtetra
.608 .704 .912 r
.11944 .23003 .12064 .23134 .12227 .23099 .12107 .2296 Mtetra
.635 .7 .893 r
.12107 .2296 .12227 .23099 .12392 .23045 .12273 .22906 Mtetra
.633 .699 .893 r
.12273 .22906 .12392 .23045 .12557 .22988 .12438 .22853 Mtetra
.644 .709 .894 r
.12438 .22853 .12557 .22988 .12723 .22927 .12604 .22795 Mtetra
.655 .718 .895 r
.12604 .22795 .12723 .22927 .1289 .22862 .1277 .22733 Mtetra
.664 .725 .895 r
.1277 .22733 .1289 .22862 .13058 .22794 .12937 .22667 Mtetra
.68 .733 .891 r
.12937 .22667 .13058 .22794 .13227 .22707 .13105 .22593 Mtetra
.691 .759 .904 r
.13105 .22593 .13227 .22707 .13397 .22621 .13274 .22516 Mtetra
.692 .776 .916 r
.13274 .22516 .13397 .22621 .13564 .22556 .13443 .22439 Mtetra
.741 .764 .871 r
.13443 .22439 .13564 .22556 .13725 .22542 .13616 .22332 Mtetra
.68 .627 .79 r
.13616 .22332 .13725 .22542 .13878 .22594 .13787 .22238 Mtetra
.562 .467 .704 r
.13787 .22238 .13878 .22594 .14016 .22764 .1395 .22204 Mtetra
.169 .125 .561 r
.1395 .22204 .14016 .22764 .13996 .24193 .1408 .22444 Mtetra
.966 .707 .491 r
.1408 .22444 .13996 .24193 .11705 .4379 .11657 .43018 Mtetra
.715 .546 0 r
.11657 .43018 .11705 .4379 .11836 .44113 .11713 .43936 Mtetra
0 .041 .593 r
.11713 .43936 .11836 .44113 .11995 .44215 .11864 .44098 Mtetra
.527 .719 .961 r
.11864 .44098 .11995 .44215 .12168 .44203 .12039 .44074 Mtetra
.762 .763 .853 r
.12039 .44074 .12168 .44203 .12353 .44095 .12227 .43942 Mtetra
.878 .735 .699 r
.12227 .43942 .12353 .44095 .12573 .43704 .12447 .43547 Mtetra
.948 .689 .51 r
.12447 .43547 .12573 .43704 .15274 .22968 .15131 .23022 Mtetra
.967 .759 .569 r
.15131 .23022 .15274 .22968 .15574 .21821 .15446 .21764 Mtetra
.898 .838 .777 r
.15446 .21764 .15574 .21821 .15764 .21577 .15638 .21505 Mtetra
.711 .848 .947 r
.15638 .21505 .15764 .21577 .15933 .21512 .15809 .2142 Mtetra
.566 .771 .975 r
.15809 .2142 .15933 .21512 .16096 .21496 .15974 .21384 Mtetra
.612 .744 .939 r
.15974 .21384 .16096 .21496 .16263 .21443 .16141 .21337 Mtetra
.663 .772 .93 r
.16141 .21337 .16263 .21443 .16435 .21354 .1631 .21272 Mtetra
.654 .818 .962 r
.1631 .21272 .16435 .21354 .16605 .21284 .16479 .21208 Mtetra
.645 .83 .972 r
.16479 .21208 .16605 .21284 .16766 .21287 .16648 .21147 Mtetra
.648 .706 .889 r
.16648 .21147 .16766 .21287 .16917 .21376 .16817 .21086 Mtetra
.609 .531 .742 r
.16817 .21086 .16917 .21376 .17061 .21531 .16986 .21025 Mtetra
.575 .43 .646 r
.16986 .21025 .17061 .21531 .17211 .21633 .17155 .20961 Mtetra
.561 .392 .61 r
.17155 .20961 .17211 .21633 .17379 .21584 .17326 .20893 Mtetra
.56 .389 .606 r
.17326 .20893 .17379 .21584 .17554 .21476 .17496 .20824 Mtetra
.562 .396 .613 r
.17496 .20824 .17554 .21476 .17728 .21382 .17666 .20756 Mtetra
.564 .4 .618 r
.17666 .20756 .17728 .21382 .17899 .21313 .17836 .20689 Mtetra
.564 .401 .618 r
.17836 .20689 .17899 .21313 .18069 .21244 .18007 .20622 Mtetra
.564 .401 .619 r
.18007 .20622 .18069 .21244 .1824 .21177 .18177 .20555 Mtetra
.564 .402 .619 r
.18177 .20555 .1824 .21177 .18411 .2111 .18348 .20487 Mtetra
.564 .401 .619 r
.18348 .20487 .18411 .2111 .18582 .21044 .18518 .2042 Mtetra
.58 .413 .619 r
.18518 .2042 .18582 .21044 .18758 .20933 .18692 .2033 Mtetra
.586 .42 .623 r
.18692 .2033 .18758 .20933 .18935 .20812 .18866 .20234 Mtetra
.551 .399 .628 r
.18866 .20234 .18935 .20812 .19102 .20783 .19034 .20189 Mtetra
.341 .244 .598 r
.19034 .20189 .19102 .20783 .19216 .21236 .19181 .20341 Mtetra
.93 .701 .217 r
.19181 .20341 .19216 .21236 .17141 .41763 .19163 .22005 Mtetra
0 0 .064 r
.19163 .22005 .17141 .41763 .17269 .42204 .17157 .41927 Mtetra
0 .027 .596 r
.17157 .41927 .17269 .42204 .17433 .42315 .1731 .42141 Mtetra
.579 .645 .88 r
.1731 .42141 .17433 .42315 .17614 .4227 .1749 .42105 Mtetra
.697 .703 .852 r
.1749 .42105 .17614 .4227 .178 .42183 .17677 .42009 Mtetra
.693 .689 .842 r
.17677 .42009 .178 .42183 .17986 .42097 .17864 .41912 Mtetra
.64 .657 .851 r
.17864 .41912 .17986 .42097 .18169 .42032 .18048 .41847 Mtetra
.641 .657 .85 r
.18048 .41847 .18169 .42032 .18353 .41967 .18232 .41781 Mtetra
.638 .655 .85 r
.18232 .41781 .18353 .41967 .18537 .41902 .18416 .41716 Mtetra
.635 .654 .851 r
.18416 .41716 .18537 .41902 .18721 .41838 .186 .41652 Mtetra
.634 .654 .852 r
.186 .41652 .18721 .41838 .18905 .41777 .18784 .4159 Mtetra
.633 .651 .851 r
.18784 .4159 .18905 .41777 .19088 .41723 .18968 .41528 Mtetra
.63 .64 .842 r
.18968 .41528 .19088 .41723 .19271 .41677 .19152 .41466 Mtetra
.626 .622 .826 r
.19152 .41466 .19271 .41677 .19454 .4163 .19336 .41404 Mtetra
.623 .605 .811 r
.19336 .41404 .19454 .4163 .19637 .41577 .19521 .41342 Mtetra
.622 .595 .802 r
.19521 .41342 .19637 .41577 .19821 .41517 .19705 .4128 Mtetra
.622 .594 .801 r
.19705 .4128 .19821 .41517 .20006 .41453 .1989 .41216 Mtetra
.623 .595 .801 r
.1989 .41216 .20006 .41453 .20191 .41389 .20075 .41153 Mtetra
.624 .596 .801 r
.20075 .41153 .20191 .41389 .20377 .41325 .2026 .41088 Mtetra
.625 .596 .8 r
.2026 .41088 .20377 .41325 .20562 .4126 .20446 .41023 Mtetra
.627 .597 .799 r
.20446 .41023 .20562 .4126 .20747 .41195 .20632 .40956 Mtetra
.629 .596 .797 r
.20632 .40956 .20747 .41195 .20933 .4113 .20818 .40887 Mtetra
.627 .592 .794 r
.20818 .40887 .20933 .4113 .21119 .41063 .21004 .40819 Mtetra
.623 .589 .795 r
.21004 .40819 .21119 .41063 .21306 .40989 .2119 .40755 Mtetra
.618 .595 .805 r
.2119 .40755 .21306 .40989 .21494 .40907 .21375 .40694 Mtetra
.622 .619 .827 r
.21375 .40694 .21494 .40907 .21682 .40823 .21561 .40634 Mtetra
.63 .65 .852 r
.21561 .40634 .21682 .40823 .21868 .40752 .21747 .40573 Mtetra
.637 .667 .862 r
.21747 .40573 .21868 .40752 .22054 .40699 .21933 .40509 Mtetra
.638 .653 .848 r
.21933 .40509 .22054 .40699 .2224 .40631 .2212 .40443 Mtetra
.642 .658 .85 r
.2212 .40443 .2224 .40631 .22432 .40508 .22307 .40376 Mtetra
.658 .744 .913 r
.22307 .40376 .22432 .40508 .22634 .40281 .22494 .40305 Mtetra
.389 .849 .82 r
.22494 .40305 .22634 .40281 .22842 .39985 .22681 .40234 Mtetra
.261 0 .054 r
.22681 .40234 .22842 .39985 .23051 .39684 .22869 .40167 Mtetra
.387 .048 .264 r
.22869 .40167 .23051 .39684 .23241 .39576 .23056 .40103 Mtetra
.399 .068 .284 r
.23056 .40103 .23241 .39576 .23425 .39544 .23243 .40041 Mtetra
.392 .056 .271 r
.23243 .40041 .23425 .39544 .23608 .39524 .2343 .39979 Mtetra
.378 .034 .25 r
.2343 .39979 .23608 .39524 .23795 .39461 .23618 .39914 Mtetra
.377 .033 .248 r
.23618 .39914 .23795 .39461 .23982 .39399 .23806 .39849 Mtetra
.377 .031 .247 r
.23806 .39849 .23982 .39399 .2417 .39336 .23993 .39784 Mtetra
.377 .031 .246 r
.23993 .39784 .2417 .39336 .24357 .39273 .24181 .39719 Mtetra
.375 .029 .245 r
.24181 .39719 .24357 .39273 .24545 .39209 .2437 .39654 Mtetra
.393 .045 .252 r
.2437 .39654 .24545 .39209 .2473 .3917 .24557 .39602 Mtetra
.427 .074 .262 r
.24557 .39602 .2473 .3917 .24912 .39183 .24741 .39579 Mtetra
.349 0 .209 r
.24741 .39579 .24912 .39183 .25101 .3911 .24931 .39507 Mtetra
.081 0 .084 r
.24931 .39507 .25101 .3911 .25313 .38765 .25132 .39295 Mtetra
.808 .801 .309 r
.25132 .39295 .25313 .38765 .27246 .17951 .25387 .38438 Mtetra
0 0 .1 r
.25387 .38438 .27246 .17951 .27474 .17261 .27341 .17349 Mtetra
.979 .915 .647 r
.27341 .17349 .27474 .17261 .2767 .16969 .27549 .16901 Mtetra
.761 .875 .93 r
.27549 .16901 .2767 .16969 .27849 .1687 .27729 .16789 Mtetra
.587 .813 .986 r
.27729 .16789 .27849 .1687 .28024 .16816 .27904 .16742 Mtetra
.49 .79 .998 r
.27904 .16742 .28024 .16816 .28198 .16781 .28078 .16714 Mtetra
.658 .861 .977 r
.28078 .16714 .28198 .16781 .28374 .16731 .28255 .16642 Mtetra
.667 .818 .956 r
.28255 .16642 .28374 .16731 .2855 .16682 .28433 .16571 Mtetra
.666 .774 .93 r
.28433 .16571 .2855 .16682 .28726 .16625 .2861 .16502 Mtetra
.657 .749 .917 r
.2861 .16502 .28726 .16625 .28904 .16545 .28787 .16436 Mtetra
.657 .774 .935 r
.28787 .16436 .28904 .16545 .29083 .16461 .28965 .16369 Mtetra
.66 .811 .956 r
.28965 .16369 .29083 .16461 .29262 .16375 .29143 .16301 Mtetra
.669 .851 .969 r
.29143 .16301 .29262 .16375 .29441 .16285 .29321 .16227 Mtetra
.657 .882 .981 r
.29321 .16227 .29441 .16285 .29619 .16212 .29499 .16153 Mtetra
.675 .884 .975 r
.29499 .16153 .29619 .16212 .29795 .16172 .29678 .16074 Mtetra
.749 .818 .906 r
.29678 .16074 .29795 .16172 .29966 .16198 .29859 .15965 Mtetra
.629 .59 .791 r
.29859 .15965 .29966 .16198 .30131 .1631 .30037 .15898 Mtetra
.467 .387 .683 r
.30037 .15898 .30131 .1631 .30277 .1667 .30208 .15933 Mtetra
0 0 .402 r
.30208 .15933 .30277 .1667 .28919 .37455 .30338 .16516 Mtetra
0 0 .148 r
.30338 .16516 .28919 .37455 .29064 .38011 .28963 .3758 Mtetra
0 0 .421 r
.28963 .3758 .29064 .38011 .29237 .38194 .29119 .37993 Mtetra
.489 .571 .865 r
.29119 .37993 .29237 .38194 .29425 .38182 .29306 .37993 Mtetra
.651 .664 .85 r
.29306 .37993 .29425 .38182 .29618 .38104 .29498 .37918 Mtetra
.697 .687 .836 r
.29498 .37918 .29618 .38104 .29815 .37972 .29693 .37814 Mtetra
.544 .664 .915 r
.29693 .37814 .29815 .37972 .30014 .37801 .29882 .37789 Mtetra
.513 .903 .94 r
.29882 .37789 .30014 .37801 .30219 .37544 .30075 .37718 Mtetra
0 0 0 r
.30075 .37718 .30219 .37544 .3044 .37073 .30275 .37549 Mtetra
.689 .746 .243 r
.30275 .37549 .3044 .37073 .32059 .16159 .3051 .36855 Mtetra
0 0 .136 r
.3051 .36855 .32059 .16159 .32285 .1542 .32149 .15608 Mtetra
.958 .905 .535 r
.32149 .15608 .32285 .1542 .32481 .15112 .32362 .15047 Mtetra
.796 .889 .912 r
.32362 .15047 .32481 .15112 .32662 .15018 .32547 .14915 Mtetra
.645 .786 .949 r
.32547 .14915 .32662 .15018 .3284 .14975 .32726 .14852 Mtetra
.551 .712 .946 r
.32726 .14852 .3284 .14975 .33017 .14955 .32904 .14822 Mtetra
.668 .739 .903 r
.32904 .14822 .33017 .14955 .33198 .1487 .33084 .14749 Mtetra
.666 .759 .92 r
.33084 .14749 .33198 .1487 .33379 .14794 .33265 .14678 Mtetra
.665 .768 .927 r
.33265 .14678 .33379 .14794 .33559 .14743 .33446 .14608 Mtetra
.739 .756 .866 r
.33446 .14608 .33559 .14743 .33734 .14751 .33629 .14494 Mtetra
.635 .575 .77 r
.33629 .14494 .33734 .14751 .33906 .14832 .3381 .14418 Mtetra
.518 .421 .684 r
.3381 .14418 .33906 .14832 .34067 .15084 .33987 .14415 Mtetra
0 0 .482 r
.33987 .14415 .34067 .15084 .32972 .35816 .34136 .14868 Mtetra
0 0 .172 r
.34136 .14868 .32972 .35816 .33119 .36522 .3302 .36006 Mtetra
0 0 .367 r
.3302 .36006 .33119 .36522 .33296 .36742 .33178 .36536 Mtetra
.467 .556 .863 r
.33178 .36536 .33296 .36742 .33488 .36704 .33368 .36545 Mtetra
.659 .712 .887 r
.33368 .36545 .33488 .36704 .33685 .36606 .33564 .3647 Mtetra
.74 .77 .877 r
.33564 .3647 .33685 .36606 .33883 .3648 .33762 .3635 Mtetra
.659 .759 .924 r
.33762 .3635 .33883 .3648 .34077 .36436 .33957 .36276 Mtetra
.659 .711 .886 r
.33957 .36276 .34077 .36436 .34271 .36383 .34153 .36201 Mtetra
.658 .679 .858 r
.34153 .36201 .34271 .36383 .34468 .36299 .34349 .36122 Mtetra
.668 .689 .861 r
.34349 .36122 .34468 .36299 .34672 .36076 .34545 .36038 Mtetra
.631 .921 .977 r
.34545 .36038 .34672 .36076 .34881 .35758 .34742 .35953 Mtetra
.159 0 0 r
.34742 .35953 .34881 .35758 .35098 .35311 .34939 .3587 Mtetra
.392 .067 .29 r
.34939 .3587 .35098 .35311 .35306 .34998 .35135 .35793 Mtetra
.429 .127 .35 r
.35135 .35793 .35306 .34998 .35503 .349 .35331 .35721 Mtetra
.435 .135 .355 r
.35331 .35721 .35503 .349 .35688 .3503 .35527 .35655 Mtetra
.424 .105 .318 r
.35527 .35655 .35688 .3503 .35865 .35324 .35723 .356 Mtetra
.329 0 .118 r
.35723 .356 .35865 .35324 .36048 .35514 .35919 .35549 Mtetra
0 0 0 r
.35919 .35549 .36048 .35514 .36236 .35615 .36115 .35498 Mtetra
.43 .688 .972 r
.36115 .35498 .36236 .35615 .36428 .35644 .36308 .35494 Mtetra
.584 .699 .921 r
.36308 .35494 .36428 .35644 .36624 .35599 .36504 .35452 Mtetra
.74 .757 .866 r
.36504 .35452 .36624 .35599 .36824 .3546 .36704 .35327 Mtetra
.938 .765 .641 r
.36704 .35327 .36824 .3546 .37047 .34876 .36926 .34744 Mtetra
.969 .689 .446 r
.36926 .34744 .37047 .34876 .38268 .13511 .38156 .13378 Mtetra
.944 .751 .611 r
.38156 .13378 .38268 .13511 .3848 .12843 .38369 .12712 Mtetra
.803 .779 .831 r
.38369 .12712 .3848 .12843 .38669 .12679 .38557 .12548 Mtetra
.646 .738 .916 r
.38557 .12548 .38669 .12679 .38852 .12615 .38741 .12484 Mtetra
.529 .689 .94 r
.38741 .12484 .38852 .12615 .39034 .12594 .38923 .12461 Mtetra
.726 .761 .88 r
.38923 .12461 .39034 .12594 .3922 .12488 .39109 .12356 Mtetra
.698 .754 .895 r
.39109 .12356 .3922 .12488 .39406 .12399 .39295 .12267 Mtetra
.53 .689 .94 r
.39295 .12267 .39406 .12399 .39588 .12379 .39477 .12244 Mtetra
.806 .364 0 r
.39477 .12244 .39588 .12379 .39753 .12766 .39644 .12596 Mtetra
.971 .683 .425 r
.39644 .12596 .39753 .12766 .39029 .34063 .38914 .3382 Mtetra
.879 .513 .03 r
.38914 .3382 .39029 .34063 .392 .34646 .39083 .34465 Mtetra
.124 .391 .845 r
.39083 .34465 .392 .34646 .39393 .34712 .39275 .34561 Mtetra
.611 .71 .915 r
.39275 .34561 .39393 .34712 .39593 .34638 .39474 .34507 Mtetra
.8 .796 .848 r
.39474 .34507 .39593 .34638 .39796 .3447 .39677 .3434 Mtetra
.935 .776 .66 r
.39677 .3434 .39796 .3447 .40006 .34141 .39894 .33828 Mtetra
.97 .687 .438 r
.39894 .33828 .40006 .34141 .4023 .33426 .40928 .12494 Mtetra
.517 .277 .489 r
.40928 .12494 .4023 .33426 .4123 .12417 .41143 .11676 Mtetra
.622 .43 .601 r
.41143 .11676 .4123 .12417 .41432 .11908 .41334 .11476 Mtetra
.593 .465 .675 r
.41334 .11476 .41432 .11908 .41625 .11654 .4152 .11399 Mtetra
.567 .542 .787 r
.4152 .11399 .41625 .11654 .41815 .11485 .41705 .11366 Mtetra
.632 .759 .939 r
.41705 .11366 .41815 .11485 .42002 .11392 .41891 .11307 Mtetra
.649 .835 .972 r
.41891 .11307 .42002 .11392 .42188 .11336 .42077 .11237 Mtetra
.649 .805 .958 r
.42077 .11237 .42188 .11336 .42374 .11295 .42264 .11169 Mtetra
.725 .777 .894 r
.42264 .11169 .42374 .11295 .42561 .11193 .42452 .11066 Mtetra
.694 .765 .906 r
.42452 .11066 .42561 .11193 .42749 .1109 .42639 .10979 Mtetra
.517 .73 .97 r
.42639 .10979 .42749 .1109 .42936 .11029 .42825 .10954 Mtetra
.797 .313 0 r
.42825 .10954 .42936 .11029 .43117 .11143 .43 .11252 Mtetra
.97 .678 .417 r
.43 .11252 .43117 .11143 .43288 .116 .42514 .32418 Mtetra
.512 .267 .48 r
.42514 .32418 .43288 .116 .42829 .32592 .4269 .33157 Mtetra
.531 .192 .337 r
.4269 .33157 .42829 .32592 .43014 .33067 .42887 .33248 Mtetra
.211 0 0 r
.42887 .33248 .43014 .33067 .43209 .33223 .43089 .33185 Mtetra
.707 .947 .957 r
.43089 .33185 .43209 .33223 .43407 .33279 .43292 .33072 Mtetra
.663 .656 .833 r
.43292 .33072 .43407 .33279 .43608 .33255 .43495 .32983 Mtetra
.62 .575 .782 r
.43495 .32983 .43608 .33255 .43811 .33188 .43697 .32911 Mtetra
.62 .571 .778 r
.43697 .32911 .43811 .33188 .44014 .33101 .439 .32839 Mtetra
.622 .584 .791 r
.439 .32839 .44014 .33101 .44216 .33023 .44102 .32768 Mtetra
.622 .59 .797 r
.44102 .32768 .44216 .33023 .44419 .32953 .44305 .32698 Mtetra
.622 .591 .798 r
.44305 .32698 .44419 .32953 .44622 .32882 .44508 .32629 Mtetra
.622 .592 .799 r
.44508 .32629 .44622 .32882 .44825 .32811 .44711 .32559 Mtetra
.622 .593 .8 r
.44711 .32559 .44825 .32811 .45029 .32741 .44915 .32489 Mtetra
.622 .594 .8 r
.44915 .32489 .45029 .32741 .45232 .32671 .45118 .32419 Mtetra
.623 .594 .801 r
.45118 .32419 .45232 .32671 .45436 .326 .45322 .32349 Mtetra
.623 .595 .801 r
.45322 .32349 .45436 .326 .45639 .3253 .45525 .32279 Mtetra
.45525 .32279 .45639 .3253 .45843 .3246 .45729 .32209 Mtetra
.623 .596 .801 r
.45729 .32209 .45843 .3246 .46047 .32389 .45933 .32138 Mtetra
.624 .596 .802 r
.45933 .32138 .46047 .32389 .46251 .32318 .46137 .32068 Mtetra
.46137 .32068 .46251 .32318 .46456 .32248 .46342 .31997 Mtetra
.46342 .31997 .46456 .32248 .4666 .32177 .46546 .31926 Mtetra
.624 .597 .802 r
.46546 .31926 .4666 .32177 .46865 .32106 .46751 .31855 Mtetra
.46751 .31855 .46865 .32106 .4707 .32035 .46956 .31784 Mtetra
.46956 .31784 .4707 .32035 .47275 .31963 .47161 .31713 Mtetra
.47161 .31713 .47275 .31963 .4748 .31892 .47366 .31642 Mtetra
.47366 .31642 .4748 .31892 .47685 .31821 .47571 .3157 Mtetra
.47571 .3157 .47685 .31821 .4789 .31749 .47777 .31499 Mtetra
.625 .597 .802 r
.47777 .31499 .4789 .31749 .48096 .31678 .47982 .31427 Mtetra
.47982 .31427 .48096 .31678 .48302 .31606 .48188 .31355 Mtetra
.48188 .31355 .48302 .31606 .48508 .31535 .48394 .31283 Mtetra
.48394 .31283 .48508 .31535 .48714 .31463 .486 .31212 Mtetra
.486 .31212 .48714 .31463 .4892 .31391 .48806 .3114 Mtetra
.48806 .3114 .4892 .31391 .49126 .31319 .49013 .31068 Mtetra
.49013 .31068 .49126 .31319 .49333 .31247 .49219 .30996 Mtetra
.49219 .30996 .49333 .31247 .4954 .31175 .49426 .30924 Mtetra
.49426 .30924 .4954 .31175 .49746 .31103 .49633 .30851 Mtetra
.49633 .30851 .49746 .31103 .49953 .31031 .4984 .30779 Mtetra
.4984 .30779 .49953 .31031 .50161 .30959 .50047 .30707 Mtetra
.50047 .30707 .50161 .30959 .50368 .30887 .50254 .30635 Mtetra
.50254 .30635 .50368 .30887 .50575 .30814 .50462 .30562 Mtetra
.50462 .30562 .50575 .30814 .50783 .30742 .50669 .3049 Mtetra
.50669 .3049 .50783 .30742 .50991 .3067 .50877 .30417 Mtetra
.50877 .30417 .50991 .3067 .51199 .30597 .51085 .30345 Mtetra
.51085 .30345 .51199 .30597 .51407 .30525 .51293 .30272 Mtetra
.51293 .30272 .51407 .30525 .51615 .30452 .51502 .30199 Mtetra
.51502 .30199 .51615 .30452 .51823 .3038 .5171 .30127 Mtetra
.5171 .30127 .51823 .3038 .52032 .30307 .51919 .30054 Mtetra
.51919 .30054 .52032 .30307 .52241 .30234 .52127 .29981 Mtetra
.52127 .29981 .52241 .30234 .5245 .30161 .52336 .29908 Mtetra
.52336 .29908 .5245 .30161 .52659 .30089 .52545 .29835 Mtetra
.52545 .29835 .52659 .30089 .52868 .30016 .52755 .29762 Mtetra
.52755 .29762 .52868 .30016 .53077 .29943 .52964 .29689 Mtetra
.52964 .29689 .53077 .29943 .53287 .2987 .53173 .29616 Mtetra
.53173 .29616 .53287 .2987 .53496 .29797 .53383 .29543 Mtetra
.53383 .29543 .53496 .29797 .53706 .29724 .53593 .2947 Mtetra
.53593 .2947 .53706 .29724 .53916 .2965 .53803 .29396 Mtetra
.53803 .29396 .53916 .2965 .54126 .29577 .54013 .29323 Mtetra
.54013 .29323 .54126 .29577 .54337 .29504 .54224 .29249 Mtetra
.54224 .29249 .54337 .29504 .54547 .29431 .54434 .29176 Mtetra
.54434 .29176 .54547 .29431 .54758 .29357 .54645 .29102 Mtetra
.54645 .29102 .54758 .29357 .54969 .29284 .54856 .29029 Mtetra
.54856 .29029 .54969 .29284 .55179 .2921 .55067 .28955 Mtetra
.55067 .28955 .55179 .2921 .55391 .29137 .55278 .28881 Mtetra
.55278 .28881 .55391 .29137 .55602 .29063 .55489 .28808 Mtetra
.55489 .28808 .55602 .29063 .55813 .28989 .557 .28734 Mtetra
.557 .28734 .55813 .28989 .56025 .28915 .55912 .2866 Mtetra
.55912 .2866 .56025 .28915 .56237 .28841 .56124 .28586 Mtetra
.56124 .28586 .56237 .28841 .56449 .28767 .56336 .28512 Mtetra
.56336 .28512 .56449 .28767 .56661 .28693 .56548 .28438 Mtetra
.56548 .28438 .56661 .28693 .56873 .28619 .5676 .28363 Mtetra
.5676 .28363 .56873 .28619 .57085 .28545 .56973 .28289 Mtetra
.56973 .28289 .57085 .28545 .57298 .28471 .57185 .28214 Mtetra
.57185 .28214 .57298 .28471 .57511 .28396 .57398 .2814 Mtetra
.57398 .2814 .57511 .28396 .57724 .28322 .57611 .28065 Mtetra
.57611 .28065 .57724 .28322 .57937 .28248 .57824 .27991 Mtetra
.57824 .27991 .57937 .28248 .5815 .28173 .58037 .27916 Mtetra
.58037 .27916 .5815 .28173 .58363 .28098 .58251 .27841 Mtetra
.58251 .27841 .58363 .28098 .58577 .28024 .58464 .27766 Mtetra
.58464 .27766 .58577 .28024 .58791 .27949 .58678 .27692 Mtetra
.58678 .27692 .58791 .27949 .59004 .27874 .58892 .27617 Mtetra
.58892 .27617 .59004 .27874 .59218 .278 .59106 .27542 Mtetra
.59106 .27542 .59218 .278 .59433 .27725 .5932 .27467 Mtetra
.5932 .27467 .59433 .27725 .59647 .2765 .59535 .27392 Mtetra
.625 .597 .801 r
.59535 .27392 .59647 .2765 .59862 .27575 .59749 .27317 Mtetra
.59749 .27317 .59862 .27575 .60076 .275 .59964 .27242 Mtetra
.59964 .27242 .60076 .275 .60291 .27425 .60179 .27166 Mtetra
.60179 .27166 .60291 .27425 .60506 .2735 .60394 .27091 Mtetra
.60394 .27091 .60506 .2735 .60721 .27274 .60609 .27015 Mtetra
.60609 .27015 .60721 .27274 .60937 .27199 .60825 .2694 Mtetra
.626 .597 .801 r
.60825 .2694 .60937 .27199 .61152 .27123 .6104 .26864 Mtetra
.6104 .26864 .61152 .27123 .61368 .27047 .61256 .26787 Mtetra
.61256 .26787 .61368 .27047 .61584 .2697 .61472 .26711 Mtetra
.627 .597 .801 r
.61472 .26711 .61584 .2697 .618 .26894 .61688 .26634 Mtetra
.61688 .26634 .618 .26894 .62016 .26818 .61904 .26557 Mtetra
.627 .596 .799 r
.61904 .26557 .62016 .26818 .62232 .2674 .6212 .26479 Mtetra
.627 .597 .8 r
.6212 .26479 .62232 .2674 .62449 .26657 .62337 .26401 Mtetra
.629 .603 .805 r
.62337 .26401 .62449 .26657 .62665 .26564 .62553 .26323 Mtetra
.632 .618 .818 r
.62553 .26323 .62665 .26564 .62881 .26471 .6277 .26246 Mtetra
.635 .636 .834 r
.6277 .26246 .62881 .26471 .63097 .26381 .62987 .26169 Mtetra
.635 .651 .849 r
.62987 .26169 .63097 .26381 .63315 .26302 .63204 .26094 Mtetra
.636 .656 .853 r
.63204 .26094 .63315 .26302 .63532 .26227 .63422 .26019 Mtetra
.619 .648 .857 r
.63422 .26019 .63532 .26227 .6375 .2616 .6364 .25954 Mtetra
.548 .615 .871 r
.6364 .25954 .6375 .2616 .63969 .26118 .63859 .25926 Mtetra
.641 .681 .872 r
.63859 .25926 .63969 .26118 .64187 .26042 .64077 .2585 Mtetra
.797 .742 .801 r
.64077 .2585 .64187 .26042 .64401 .25885 .64291 .25651 Mtetra
.95 .729 .569 r
.64291 .25651 .64401 .25885 .64605 .25444 .64481 .24853 Mtetra
.975 .67 .347 r
.64481 .24853 .64605 .25444 .64774 .24143 .6384 .0319 Mtetra
.509 .27 .487 r
.6384 .0319 .64774 .24143 .64146 .03352 .64025 .02675 Mtetra
.592 .417 .614 r
.64025 .02675 .64146 .03352 .64344 .03177 .64225 .02544 Mtetra
.555 .399 .624 r
.64225 .02544 .64344 .03177 .64548 .03131 .64428 .02481 Mtetra
.535 .383 .621 r
.64428 .02481 .64548 .03131 .64755 .03144 .64632 .02447 Mtetra
.559 .392 .612 r
.64632 .02447 .64755 .03144 .64958 .03073 .64835 .02371 Mtetra
.558 .391 .611 r
.64835 .02371 .64958 .03073 .65162 .03005 .65038 .02296 Mtetra
.557 .39 .61 r
.65038 .02296 .65162 .03005 .65366 .02936 .65241 .02221 Mtetra
.558 .389 .609 r
.65241 .02221 .65366 .02936 .65569 .02862 .65444 .02144 Mtetra
.558 .389 .608 r
.65444 .02144 .65569 .02862 .65773 .02787 .65648 .02067 Mtetra
.65648 .02067 .65773 .02787 .65977 .0271 .65851 .01988 Mtetra
.65851 .01988 .65977 .0271 .66181 .02632 .66055 .0191 Mtetra
.559 .389 .608 r
.66055 .0191 .66181 .02632 .66385 .02551 .66258 .0183 Mtetra
.66258 .0183 .66385 .02551 .66589 .02469 .66462 .0175 Mtetra
.56 .39 .608 r
.66462 .0175 .66589 .02469 .66793 .02385 .66666 .01668 Mtetra
.56 .391 .609 r
.66666 .01668 .66793 .02385 .66997 .02298 .6687 .01586 Mtetra
.562 .392 .609 r
.6687 .01586 .66997 .02298 .67201 .02208 .67074 .01503 Mtetra
.564 .394 .611 r
.67074 .01503 .67201 .02208 .67405 .02113 .67278 .01416 Mtetra
.565 .396 .612 r
.67278 .01416 .67405 .02113 .67609 .02015 .67482 .0133 Mtetra
.567 .399 .614 r
.67482 .0133 .67609 .02015 .67813 .01914 .67687 .01241 Mtetra
.592 .418 .615 r
.67687 .01241 .67813 .01914 .68012 .01733 .67889 .0111 Mtetra
.576 .415 .626 r
.67889 .0111 .68012 .01733 .68216 .01623 .68093 .01017 Mtetra
.528 .386 .631 r
.68093 .01017 .68216 .01623 .68427 .01643 .68301 .00996 Mtetra
.165 .135 .576 r
.68301 .00996 .68427 .01643 .69815 .22364 .68533 .01387 Mtetra
0 0 .344 r
.68533 .01387 .69815 .22364 .70106 .23497 .69977 .22914 Mtetra
0 0 .497 r
.69977 .22914 .70106 .23497 .70349 .23768 .7024 .23539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-200)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-100)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(100)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(200)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[45]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001GR000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3oool=0?ooo`H00000103oool4000000D0oooo
1000002=0?ooo`00o`3oool=0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`2:0?ooo`00
o`3oool>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0RP3oool00?l0oooo3`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo08X0oooo003o0?oooa00oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`2:0?ooo`00
o`3ooolA0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0RP3oool00?l0oooo3@3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0RP3oool00?l0oooo3@3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0RP3oool00?l0oooo3P3oool4000000D0oooo100000050?ooo`@00000403oool60000
00@0oooo100000050?ooo`@00000IP3oool00?l0oooo=03oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0H`3oool00?l0oooo=@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo06<0oooo003o0?oo
ocH0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`1S0?ooo`00o`3oool[0?ooo`H000001P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo06<0oooo003o0?ooocP0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1S
0?ooo`00o`3ooold0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1S0?ooo`00o`3ooold
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1S0?ooo`00o`3ooolT0?ooo`8000003`3o
ool4000000D0oooo100000050?ooo`@00000IP3oool00?l0oooo8P3oool5000008X0oooo003o0?oo
oal0oooo0`0000030?ooo`800000RP3oool00?l0oooo7@3oool2000000H0oooo00<000000?ooo`00
0000R@3oool00?l0oooo6P3oool3000000P0oooo00@000000?ooo`3oool00000R03oool00?l0oooo
5`3oool3000000H0oooo0P2GJid01027HZ40:R:C0?ooo`0000020?ooo`030000003oool0oooo08H0
oooo003o0?oooaD0oooo0`0000070?ooo`07091UW02AIYd0Uf^M08MRX@0Z8Y<0oooo000000030?oo
o`030000003oool0oooo08D0oooo003o0?oooa80oooo0`0000030?ooo`040000003oool0oooo0?oo
o`<0SfBK00@0T6FL095VW@2GJid0Od=l0P0Z8Y<00`000000oooo0?ooo`020?ooo`030000003oool0
oooo08@0oooo003o0?oooa00oooo0P0000080?ooo`<0Sf>K0P2?I9/01`2@II`0TFJM0813O020@g`0
Od9l02XRT`000000103oool00`000000oooo0?ooo`240?ooo`00o`3oool=0?ooo`<000001`3oool4
08iSV`80Sf>K0P2?I9/307m3O0050813O01o@W`0:R:C0000001/`oh0103oool00`000000oooo0?oo
o`230?ooo`00o`3oool;0?ooo`800000203oool00`2?I9`0SVBL08iSW00308iSV`0308mSV`1o@g`0
Od=l00@0Od=l00D0P4=l07m2O00Z8Y<0M1<j000000040?ooo`800000Q03oool00<H0oooo1`000003
0?ooo`@000001@3oool4000002X0oooo0`0000070?ooo`060895O02GJYd0R6:N08mTW02>I9`0SV>L
0P2>Hi/807m3O0060813O01o@W`0:R:C07i1NP000000001O0P3oool00`000000oooo000000240?oo
o`00b@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo02D0oooo0P0000020?ooo`030000003oool0oooo
00D0oooo00D0PTEl09MZW@28HYh0SfBL08iTW00;07m3O0070813O01o@W`0:R:C07i1NP000000n:I>
0?RWBP040?ooo`030000003oool0oooo0840oooo00390?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
8P3oool3000000d0oooo0P20@g`00`1o@W`0Od=l07m3O00:07m3O0080813O01o@W`0:R:C07i1NP00
0000n:I>0?RWBP24ZNd30?ooo`030000003oool0oooo0840oooo00390?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool07`3oool300000100oooo00<0PTEl0813O01o@W`0301o@g`02020@g`0Od9l02XRT`1n
@GX000000?RVCP3hYdX0Pj[^103oool00`000000oooo0?ooo`200?ooo`00b@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo01d0oooo0P00000C0?ooo`030895O020@g`0Od9l00`0Od=l00H0P4=l07m2O00Z
8Y<0OT5j0000003hYTh20?RWBP0308:[k`3oool0oooo0080oooo00<000000?ooo`3oool0O`3oool0
0<T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0J0?ooo`<000005@3oool00`22AG`0P4=l07m2O00<
07m3O0060813O01o@W`0:R:C07i1NP000000n:I>0P3hYdX00`2mD`00PJ__0?ooo`020?ooo`030000
003oool0oooo07l0oooo00390?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0603oool2000000030?oo
o`000000oooo01@0oooo00@0Xn?l0895O020@g`0Od9l301o@g`01P20@g`0Od9l02XRT`1n@GX00000
0?RVCP<0n:M:00<0_e@00?ooo`3oool00P3oool00`000000oooo0?ooo`1n0?ooo`00a`3oool30000
00D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool05@3oool3000000@0oooo00<000000?ooo`3oool02P3oool00`1K03P0Wca:07JHi@02
0?ooo`070:?Uo01D14D0G`U30609@P22AG`0P4=l07m2O00<07m3O0060813O01o@W`0:R:C07i1NP00
0000n:I>103hYdX50?ooo`030000003oool0oooo07d0oooo00390?ooo`030000003oool0oooo00@0
oooo100000050?ooo`@000005P3oool200000140oooo00<0Yn3k05H1?`1103L00P2O?4X02P3VO1/0
R0000:/h;@1a6TX0E0A505l9@`1o@GX0PTEl0813O01o@W`<07m3O0060813O01o@W`0:R:C07i1NP00
0000n:I>1@3hYdX01@1nZ_00oooo0?ooo`3oool0000007l0oooo003`0?ooo`<000004@3oool0101P
2T<0G`U305h8@P1F0Cl207i1NP040?RXF03hZEL0n:UG0?VYE@<0OT5j00@0Od5j0895O020@g`0Od9l
301o@g`01P20@g`0Od9l02XRT`1n@GX000000?RVCPD0n:M:00<0OJW_0?ooo`3oool00P3oool00`00
0000oooo0?ooo`1l0?ooo`00kP3oool200000140oooo00D0Xn7l064;A01Q2d@0H0Y305l9@`0407i1
NP0507m1NP3hZ5P0n:UG0?VYE@27Ag/00P1n@GX0101o@GX0PTEl0813O01o@W`<07m3O0060813O01o
@W`0:R:C07i1NP000000n:I>1P3hYdX01P1mZ>l0oooo000000000000oooo000007d0oooo003[0?oo
o`<00000403oool20:?Qo0<0H@]41`1n@GX01@1o@GX0n:QH0?RYE`3iZED0QdMk0080OT5j00@0Od5j
0895O020@g`0Od9l301o@g`01P20@g`0Od9l02XRT`1n@GX000000?RVCPH0n:M:00<0_E8007jXk`3o
ool00P3oool00`000000oooo0?ooo`1k0?ooo`00j03oool3000000<0oooo00<000000?ooo`3oool0
2`3oool00`2ThO`0H@]4064;A002064;A0T0OT5j00D0Od5j0?RXF03hZEL0nJUE08M7N`0207i1NP04
07m1NP22AG`0P4=l07m2O0`0Od=l00H0P4=l07m3O00005`0001H0000003hYTh70?RWBP030;a@003o
ool0oooo0080oooo00<000000?ooo`3oool0NP3oool00>H0oooo0P00000A0?ooo`80YN3k101Q2d@;
07i1NP0507m1NP3hZ5P0n:UG0?VYE@27Ag/00P1n@GX0101o@GX0PTEl0813O01o@W`<07m3O080P4=l
00@0Od9l0000F0000000n:I>203hYdX00`1mZ>l0oooo0?ooo`020?ooo`030000003oool0oooo07T0
oooo003S0?ooo`<000004@3oool00`2Ugo/0H@a5064<A@02064;A0h0OT5j00D0Od5j0?RXF03hZEL0
nJUE08M7N`0207i1NP0407m1NP22AG`0P4=l07m2O0d0Od=l00H0P4=l07m2O00005P000000?RVCP26
AW/80?RWBP@0oooo00<000000?ooo`3oool0N@3oool00>40oooo0P00000B0?ooo`03068=A@1R34D0
H@a50080H@a5401n@GX01@1o@GX0n:QH0?RYE`3iZED0QdMk0080OT5j00@0Od5j0895O020@g`0Od9l
3@1o@g`01`20@g`0Od9l02XRT`000000n:I>08I6N`3hYdT01`3hYdX00`1nXNT0oooo0?ooo`020?oo
o`030000003oool0oooo07P0oooo003N0?ooo`<000004@3oool01@2Tgo/0HPe6068=AP1R3DD0HPa5
01<0OT5j00D0Od5j0?RXF03hZEL0nJUE08M7N`0207i1NP0407m1NP22AG`0P4=l07m2O0d0Od=l00L0
P4=l07m2O00Z8Y<000000812NP26AW/0n:M900P0n:M:0P2@0000100VY>X0Rk3_0?ooo`00001i0?oo
o`00g03oool2000000<0oooo00<000000?ooo`3oool02`3oool00`2Tgo/0HPe6068=AP02068=AQH0
OT5j00D0Od5j0?RXF03hZEL0nJUE08M7N`0207i1NP0407m1NP22AG`0P4=l07m2O0d0Od=l00H0P4=l
07m2O00Z8Y<000000812NP26AW/90?RWBP030?RWB`3hYd`0SZ?S0080Qj;V00<000000?ooo`3oool0
M`3oool00=T0oooo0`0000060?ooo`030000003oool0oooo00P0oooo00<0Y=ok068=AP1R3DH00P1R
3DHH07i1NP0507m1NP3hZ5P0n:UG0?VYE@27Ag/00P1n@GX0101o@GX0PTEl0813O01o@W`=07m3O006
0813O01o@W`0:R:C07m1NP000000QTIk2@3hYdX0103hYd/0n:M<0:bgh@2>YnH20?ooo`030000003o
ool0oooo07H0oooo003G0?ooo`8000004@3oool00`2Tgo/0HPe6068=AP02068=AQ/0OT5j00D0Od5j
0?RXF03hZEL0nJUE08M7N`0207i1NP0407m1NP22AG`0P4=l07m2O0d0Od=l00H0P4=l07m2O00Z8Y<0
Od5j00000026AW/90?RWBP030?RWB`3hYd`0RT]m0080Y[gZ0`00001g0?ooo`00e03oool300000100
oooo0P2Tgo/2068=AP0307i1NP1R3DH0OT5j01`0OT5j00D0Od5j0?RXF03hZEL0nJUE08M7N`0207i1
NP0407m1NP22AG`0P4=l07m2O0d0Od=l00H0P4=l07m2O00Z8Y<0OT5j0000003hYTh90?RWBP080?RW
B`3hYd`0RT]m0:O5k`2I__80Y<G`0?ooo`00001g0?ooo`00d@3oool300000140oooo00<0Y=ok068=
AP1R3DH00`1R3DHO07i1NP0507m1NP3hZ5P0n:UG0?VYE@27Ag/00P1n@GX0101o@GX0PTEl0813O01o
@W`=07m3O0060813O01o@W`0:R:C07i1NP000000n:I>2@3hYdX02@3hYd/0n:M<08Y;O@35fNP0XL_f
08ZjmP1m[_<0oooo0000001f0?ooo`00c`3oool2000000<0oooo00<000000?ooo`3oool02`3oool2
0:COn`@0HPe68P1n@GX01@1o@GX0n:QH0?RYE`3iZED0QdMk0080OT5j00D0Od5j0895O020@g`0Od=l
07m2O00<07m3O0060813O01o@W`0:R:C07i1NP000000n:I>2@3hYdX01P3hYd/0n:M<08Y;O@3lcY<0
^KKF09R[i080RiGH00<0oooo0000003oool0M03oool00<`0oooo0`00000A0?ooo`030:COn`1R3DH0
HPe60080HPe69@1n@GX01@1o@GX0n:QH0?RYE`3iZED0QdMk0080OT5j00D0Od5j0895O03hZE`0Od=l
07m2O00<07m3O0060813O01o@W`0:R:C07i1NP000000n:I>2@3hYdX01`3hYd/0n:M<08Y;O@3lcY<0
XWbZ0:1dX02lT:P00P3oool00`000000oooo0?ooo`1c0?ooo`00bP3oool200000140oooo0P2Tgo/4
068=ARL0OT5j00D0Od5j0?RXF03hZEL0nJUE08M7N`0207i1NP0507m1NP22AG`0n:UL07m3O01o@W`0
301o@g`01P20@g`0Od9l02XRT`1n@GX000000?RVCPT0n:M:00@0n:M;0?RWC02:Bgd0m<:I0P25BH40
1@26BX40QT^10?ooo`3oool0000007@0oooo002G0?ooo`@00000;03oool300000140oooo00<0Y=ok
068=AP1R3DH00P1R3DHZ07i1NP0507m1NP3hZ5P0n:UG0?VYE@27Ag/00P1n@GX01@1o@GX0PTEl0?RY
G01o@g`0Od9l00`0Od=l00H0P4=l07m2O00Z8Y<0OT5j0000003hYTh90?RWBP080?RWB`3hYd`0RT]m
0?VZDP2:CX40QDV108I:P@26Bh420?ooo`030000003oool0oooo0780oooo002F0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool09`3oool200000140oooo00<0Y=ok068=AP1R3DH00P1R
3DH]07i1NP0507m1NP3hZ5P0n:UG0?VYE@27Ag/00P1n@GX01@1o@GX0PTEl0?RYG01o@g`0Od9l00`0
Od=l00H0P4=l07m2O00Z8Y<0OT5j0000003hYTh90?RWBP050?RWB`3hYd`0RT]m0?VZDP2:CX400P25
BH401@26BX40QT^10?ooo`3oool0000007<0oooo002F0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0903oool300000080oooo00<000000?ooo`3oool02`3oool20:COn`<0HPe6<01n
@GX01@1o@GX0n:QH0?RYE`3iZED0QdMk0080OT5j00D0Od5j0895O03hZE`0Od=l07m2O00<07m3O006
0813O01o@W`0:R:C07i1NP000000n:I>2@3hYdX01@3hYd/0n:M<08Y;O@3iZU80RTj10080QDV100<0
QTZ108I;P@3oool00P3oool00`000000oooo0?ooo`1`0?ooo`00UP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030:?Oo01R3DD0HPe60080HPe6<P1n@GX0
1@1o@GX0n:QH0?RYE`3iZED0QdMk0080OT5j00D0Od5j0?V[F03hZE`0Od=l07m2O00<07m3O0070813
O01o@W`0001L0000F0000000n:I>08I6N`090?RWBP040?RWC02:Bgd0nJYB08Y>P@80QDV100@0QTZ1
08I;P@3oool0oooo0P00001b0?ooo`00UP3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01l0oooo0`00000@0?ooo`80X]ol0`1R3DDe07i1NP0507m1NP3hZ5P0n:UG0?VYE@27Ag/00P1n
@GX01@1o@GX0nJ]H0?RYG020@g`0Od9l00`0Od=l00P0P4=l07m3O00005`0001H0000003hYTh0QTIk
0?RWB@P0n:M:00@0n:M<08Y;O@3iZU80RTj10P25BH400`26BX40QT^10?ooo`030?ooo`030000003o
ool0oooo0140oooo1`0000030?ooo`@000001@3oool4000004L0oooo002F0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0703oool300000100oooo0P2RhO`0101R34@0HPe5068=A@1R
3DDg07i1NP0507m1NP20@WX0PT=j0?VYE@27Ag/00P1n@GX01@1o@GX0nJ]H0?RYG020@g`0Od9l00`0
Od=l0P20@g`01P1o@W`0001H0000003hYTh0QTIk0?RWB@P0n:M:00@0n:M;08Y;O@3iZU80nJYB0P25
BH400`26BX40QT^10?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`140?ooo`00UP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo0P00
00060?ooo`80Q;[h2@3oool00`2Sh_`0H@]3064;A002068<A3X0OT5j00D0Od5j0812NP22@gX0nJUE
08M7N`0207i1NP0507m1NP3iZeP0n:UL0813O01o@W`03@1o@g`01`20@g`0Od9l0000F0000000P49j
08I6N`3hYdT0203hYdX0103hYd/0RT]m0?VZDP3iZU8208E9P@0408I:P@26Bh4006Nh001W^0<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo04@0oooo002F0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool05`3oool300000080oooo00P000000?ooo`3oool0
oooo0:K>m@2ia^@0]kcN0<a@008006O@0P21^_T20?ooo`050:?Uo02TiO/0H0]4060:@`1Q2d<0?@1n
@GX01@1o@GX0P49j0893NP3iZED0QdMk0080OT5j00D0Od5j0?V[F03hZE`0P4=l07m2O00=07m3O007
0813O01o@W`0001H00000020@WX0QTIk0?RWB@080?RWBP040?RWB`3hYd`0nJYB0?VZDP80QDV100@0
QTZ108I;P@3gYED0n:M<0P3XQd/20?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`140?ooo`00U`3oool4000001P0oooo0P0000070?ooo`80XL;`00@0W/Cc0:joiP2^_nH0
n:eZ0`3g[6/01P3h[FT003R/08l_B@1W54d0F`M4060;A3l0OT5j00D0Od5j0812NP22@gX0nJUE08M7
N`0207i1NP0507m1NP3iZeP0n:UL0813O01o@W`03@1o@g`01`20@g`0Od9l0000F0000000P49j08I6
N`3hYdT0203hYdX0103hYd/0n:M<0?VZDP3iZU8208E9P@0708I:P@26Bh40mjEE0?RVD03hYd`0j8M;
0:^bg@020?ooo`030000003oool0oooo00D0oooo1P0000060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0A03oool00;00oooo0`0000070?ooo`0409m^V@2GMj`0/8ba0;NSa080UgF[00<0];CH0?R]JP3g
[6/00P3g[6/00`3h[FT0mja[08l_B@1207i1NP0507m1NP20@WX0PT=j0?RYE`27Ag/00P1n@GX01@1o
@GX0nJ]H0?RYG020@g`0Od9l00d0Od=l00H0P4=l07m2O00005P000000812NP26AW/90?RWBP040?RW
B`3hYd`0nJYB0?VZDP80QDV100X0QTZ108I;P@3gYED0n:I@0?RWC03XQd/0/KoT0;;2i@3oool00000
4`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo04@0oooo002^0?ooo`8000002P3oool02024AWd0UUn>
09IOSP2cOYX0WVbH09MeZ`2/Qjh0n:eZ0`3g[6/00`3h[FT0mja[0812NP1207i1NP0507m1NP20@WX0
PT=j0?RYE`27Ag/00P1n@GX01@1o@GX0nJ]H0?RYG020@g`0Od9l00d0Od=l00H0P4=l07m2O00Z8Y<0
00000812NP26AW/90?RWBP040?RWB`3hYd`0RT]m0?VZDP80QDV100P0QTZ108I;P@3gYED0mjEE0?RW
C029C800/=Cc0:oDl`80oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
04@0oooo002[0?ooo`<000001@3oool208N`l0D0oooo00P0Q4Im0895O02FGhh0/gjJ09i/V02?EXP0
^XFL0?R]JP<0mja[00<0n:eY0?N/J`20@WX0@`1n@GX01020@WX0n:QH0?RYE`27Ag/307i1NP040?V[
F03hZE`0P4=l07m2O0d0Od=l00H0P4=l07m2O00Z8Y<000000812NP26AW/90?RWBP080?RWB`3hYd`0
RT]m0?VZDP2:CX40QDV108I:P@26Bh420?NUE@050?RWC029C800[[OO0:feg`2KO:l00P3oool00`00
0000oooo0?ooo`0=0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`140?ooo`00Z@3oool2000000<0oooo00L000000?oo
o`3oool0Qk3`0;W2h@2b`>@0QJk`00@0oooo0P24AWd01`22AG`0UUn>0;=nVP22AGd0SeJ80;Z5W03h
[FX00`3g[6/00`3h[FT0mja[0812NP1307i1NP0507m1NP3hZ5P0n:UG08M7N`1o@WX00P1n@GX0103i
ZeP0n:UL0813O01o@W`=07m3O0060813O01o@W`0:R:C07m1NP000000QTIk2@3hYdX03`3hYd/0n:M<
08Y;O@3iZU80RTj108E9P@26BX40QT^108U<O`3gYED0n:M<08U<P02SS[h0Vg^_09]l[`020?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool4000000D0oooo100000170?ooo`00
YP3oool3000000L0oooo00H0cLOD0:FljP26/?00^L;Q0;6oi03GJ0030?ooo`80Q4Im00L0PTEl09IO
SP24Agd0PTEm08mFR03c_I@0n:eZ00<0mja[00<0n:eY0?N/J`20@WX0@`1n@GX01@1o@GX0n:QH0?RY
E`27Ag/0Od9j0080OT5j00@0nJ]H0?RYG020@g`0Od9l3@1o@g`01P20@g`0Od9l02XRT`1o@GX00000
08I6N`T0n:M:00/0n:M;0?RWC02:Bgd0nJYB08Y>P@25BH40QTZ10?VYD`29C7l0mjEE0?RWC00208U<
P080QD^200@0QT^20000003oool00000J`3oool00:<0oooo0`00000:0?ooo`070?6oW03=a]@0Y<_d
08:gm`2``NH0n:i]0>J2@P020;M4<080Q4Im00L0PTEl09IOSP24Agd0PTEm08mFR03h[fh0n:eZ00<0
mja[00<0n:eY0?N/J`20@WX0@`1n@GX01@1o@GX0n:QH0?RYE`27Ag/0Od9j0080OT5j00@0nJ]H0?RY
G020@g`0Od9l3@1o@g`01P20@g`0Od9l02XRT`1o@GX000000?RVCPT0n:M:00/0n:M;0?RWC02:Bgd0
nJYB08Y>P@25BH40n:QG0?VYD`3gYU/0mjEE0?RWC00208U<P00308AQXP25Bh80QT^200<0oooo00<0
00000?ooo`3oool0J03oool00:40oooo0P00000<0?ooo`0:0?70W03a_i`0blWI0;j^b@2KYMd0Y;?S
0?R^K@3g[Vd0mZa_0?N]KP80Q4Im00L0PTEl08I8O@24Agd0PTEm08mFR03h[fh0n:eZ00<0mja[00<0
n:eY0?N/J`20@WX0@`1n@GX01@1o@GX0n:QH0?RYE`27Ag/0Od9j0080OT5j00@0nJ]H0?RYG020@g`0
Od9l3@1o@g`01P20@g`0Od9l02XRT`1o@GX000000?RVCPX0n:M:00X0n:M<08Y;O@3iZU80RTj108E9
P@3hZ5L0nJUC0?NVF`3gYED0n:M<0P29C8000`24HJ80QD^208I;PP030?ooo`030000003oool0oooo
06P0oooo002N0?ooo`<000003P3oool20?6oW0080?;3WP2NKi`0UWJ]0:b:/@3h[Vd0mji]0?J/K`3g
[Fh208A6O@070895O026B7d0Q4Mm0895O@2?EXP0n:m^0?R]JP030?N/J`030?R]J@3g[6/0P49j04<0
OT5j00D0Od5j0?RXF03hZEL0QdMk07m2NP0207i1NP040?V[F03hZE`0P4=l07m2O0d0Od=l00H0P4=l
07m2O00Z8Y<0OT5j0000003hYTh:0?RWBP0:0?RWC02:Bgd0nJYB08Y>P@25BH40n:QG0?VYD`26Bh40
mjEE0?RWC080RDb000D0Q66R08E;PP26Bh803`0009O1m0020?ooo`030000003oool0oooo06L0oooo
002L0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`0404405`3PRFL0M9[X07BJj080oooo
00X0n;1b0?W<V@3R[Yh0Q4Im09IQT02nS:40n:i]0?N^K@3f[6l0mje^0P24AWd01`22AG`0QTQm08A7
O@22AGd0SeJ80?R_KP3h[FX00`3g[6/00`3h[FT0mja[0812NP1307i1NP0507m1NP3hZ5P0n:UG08M7
N`1o@WX00P1n@GX0103iZeP0PTEl0813O01o@W`=07m3O0070813O01o@W`0:R:C07i1NP000000n:I>
08I6N`090?RWBP040?RWC02:Bgd0nJYB08Y>P@80QDV100@0QTZ108I;P@3gYED0n:M<0P29C8001P24
HJ80QD^208I;PP1l=fh0XEAa09b3^080oooo00<000000?ooo`3oool0IP3oool009T0oooo0`000006
0?ooo`030000003oool0oooo00@0oooo00<0OT1j0812NP3JIPL00`3oool02P3h/780n;1a08A6O@24
AWd0PTEm08I8OP3h[Vd0mji]0?J/K`3g[Fh208A6O@070895O026B7d0Q4Mm0895O@2;C7h0n:m^0?R]
JP030?N/J`030?R]J@3g[6/0P49j04<0OT5j00D0Od5j0?RXF03hZEL0QdMk07m2NP0207i1NP0507m1
NP22AG`0P4=l07m3O01o@W`0301o@g`02020@g`0Od9l0000G01n@GX000000?RVCP26AW/0n:M9203h
YdX0103hYd`0RT]m0?VZDP3iZU8208E9P@0408I:P@26Bh40mjEE0?RWC080RDb000H0Q66R08E;PP26
Bh80O3M^0:5DL@2LPkP20?ooo`030000003oool0oooo06H0oooo002G0?ooo`8000003`3oool01@1m
?gT0OT1j0812NP3g[Vl0n:m_0080oooo00X0n;1b0?R`L@24AWd0Q4Im0895O@26B7h0n:i]0?N^K@3f
[6l0mje^0P24AWd01`22AG`0QTQm08A7O@22AGd0Rdan0?R_KP3h[FX00`3g[6/00`3h[FT0mja[0812
NP1307i1NP0507m1NP3hZ5P0n:UG08M7N`1o@WX00P1n@GX01@1o@GX0PTEl0?RYG01o@g`0Od9l00`0
Od=l00P0P4=l07m2O00005`0OT5j0000003hYTh0QTIk0?RWB@P0n:M:00@0n:M;08Y;O@3iZU80nJYB
0P25BH401026BX40QT^10?NUE@3hYU0208U<P00708AQXP25Bh80QT^207`gKP2QE740QgRk08YRW@02
0?ooo`030000003oool0oooo06D0oooo002D0?ooo`<000001P3oool00`2m`Md0XY?50000N`080?oo
o`0507doN@1n@7X0P49j0?N^K`3h[fl00P26XnL02P3h/780n;1a08A6O@24AWd0PTEm08I8OP3h[Vd0
mji]0?J/K`3g[Fh208A6O@070895O026B7d0Q4Mm0895O@2;C7h0n:m^0?R]JP030?N/J`030?R]J@3g
[6/0P49j04<0OT5j00D0Od5j0?RXF03hZEL0QdMk07m2NP0207i1NP0507m1NP22AG`0n:UL07m3O01o
@W`0301o@g`02020@g`0Od9l0000G00005P000000?RVCP26AW/0n:M9203hYdX0103hYd/0RT]m0?VZ
DP3iZU8208E9P@0408I:P@26Bh40mjEE0?RVD080RDb000L0Q66R08E;PP26Bh80O3M^0:5DL@0>7I/0
RV:M00<0oooo00<000000?ooo`3oool0I03oool00940oooo100000050?ooo`0608fflP2[_NL0Z/;[
09g2lP1LG;T0001k1`3oool02P0002h0OCmi07i0NP20@WX0mji_0?R_K`3PMPL0JIo`0?R`LP3h/742
08A6O@060895O@26B7h0n:i]0?N^K@3f[6l0mje^0P24AWd01`22AG`0QTQm08A7O@22AGd0Rdan0?R_
KP3h[FX00`3g[6/00`3h[FT0mja[0812NP1307i1NP0507m1NP3hZ5P0n:UG08M7N`1o@WX00P1n@GX0
1@1o@GX0PTEl0?RYG01o@g`0Od9l00`0Od=l0P20@g`01P1o@W`0001H0000003hYTh0QTIk0?RWB@P0
n:M:00@0n:M;08Y;O@3iZU80nJYB0P25BH403@26BX40QT^10?NUE@25BGl0n:M<08U<P024HJ80QD^2
08I;PP0606T0QDZ100hMV`2:HYd00P3oool2000006H0oooo002?0?ooo`800000103oool02`000000
oooo0?ooo`3oool0];kQ09V/i028YnT0^L7Q0;3;k@1LG;T0001k00L0oooo00X0000^07doN@1n@7X0
P49j0?N^K`3h[fl0mji_0?N^L03h/780n;1a0P24AWd01P22AGd0QTQn0?R^K@3g[Vd0mZa_0?N]KP80
Q4Im00L0PTEl08I8O@24Agd0PTEm08]<OP3h[fh0n:eZ00<0mja[00<0n:eY0?N/J`20@WX0@`1n@GX0
1@1o@GX0n:QH0?RYE`3iZED0Od9j0080OT5j00D0Od5j0895O03hZE`0Od=l07m2O00=07m3O0070813
O01o@W`0001H00000020@WX0QTIk0?RWB@080?RWBP040?RWB`3hYd`0nJYB0?VZDP80QDV100X0QTZ1
08I;P@3gYED0QDUo0?RWC029C800Q66R08E;PP26Bh801P1Y0P25BX400`0>7I/0oooo0?ooo`020?oo
o`030000003oool0oooo06<0oooo002<0?ooo`<000002P3oool01`3Cj>D0ZJ_I0:Nhi@2X^nH0a/KJ
0;Fhf`0007/01`3oool02P0002h0OCmi07i0NP20@WX0mji_0?R_K`3g[Vl0mji`0?R`LP3h/74208A6
O@060895O@26B7h0n:i]0?N^K@3f[6l0mje^0P24AWd01`22AG`0QTQm08A7O@22AGd0Rdan0?R_KP3h
[FX00`3g[6/00`3h[FT0mja[0812NP1307i1NP0507m1NP3hZ5P0n:UG0?VYE@1o@WX00P1n@GX01@1o
@GX0PTEl0?RYG01o@g`0Od9l00d0Od=l00L0P4=l07m2O00005P000000812NP26AW/0n:M900P0n:M:
0100n:M;0?RWC03iZU80nJYB08Y>P@25BH40QTZ108I;P@24B7l0mjEE0?RWC029C800Q66R08E;PP26
Bh801P1Y0P25BX400`0>7I/0oooo0?ooo`020?ooo`030000003oool0oooo06<0oooo00170?ooo`L0
00000`3oool4000000D0oooo1000000/0?ooo`800000303oool020000280YLWc08jfl@2V^^L0[;oX
0;72i`33eNL0001k1P3oool02`0002l0000^07doN@1n@7X0P49j0?N^K`3h[fl0mji_0?N^L03h/780
n;1a0080Q4Im00H0PTEm08I8OP3h[Vd0mji]0?J/K`3g[Fh208A6O@070895O026B7d0Q4Mm0895O@2;
C7h0n:m^0?R]JP030?N/J`030?R]J@3g[6/0P49j04<0OT5j00D0Od5j0?RXF03hZEL0nJUE07m2NP02
07i1NP0507m1NP22AG`0n:UL07m3O01o@W`03@1o@g`01`20@g`0Od9l0000F0000000P49j08I6N`3h
YdT0203hYdX03@3hYd/0n:M<0?VZDP3iZU80RTj108E9P@26BX40QT^108A8O`3gYED0n:M<08U<P024
HJ800P25Bh801026Bh80QDZ108E:P@0>7I/50?ooo`030000003oool0oooo0680oooo001:0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool09P3oool3000000h0oooo00<0000R0:R[f@2JX]X00P2]`NT00`2g
c>X0UZ_U0000N`060?ooo`0;0000;`0002h0OCmi07i0NP20@WX0mji_0?R_K`3g[Vl0mji`0?R`LP3h
/7400P24AWd01P22AGd0QTQn0?R^K@3g[Vd0mZa_0?N]KP80Q4Im00L0PTEl08I8O@24Agd0PTEm08]<
OP3h[fh0n:eZ00<0mja[00<0n:eY0?N/J`20@WX0@`1n@GX01@1o@GX0P49j0?RYE`3iZED0Od9j0080
OT5j00D0Od5j0895O03hZE`0Od=l07m2O00=07m3O0060813O01o@W`0001H00000020@WX0QTIk2@3h
YdX03@3hYd/0n:M<0?VZDP3iZU80RTj108E9P@26BX40QT^108U<O`3gYED0n:M<08U<P024HJ800P25
Bh801026Bh80QDZ108E:P@0>7I/60?ooo`030000003oool0oooo0640oooo001:0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0903oool200000080oooo00P000000?ooo`3oool0oooo0:SQn`2/h_T0_m7W
07MS[PH0oooo00T0000U0:K;l`2?]o80Yk[W0:Rlj02``nP0`]CX085]/`0007/01P3oool02`0002l0
000^07doN@1n@7X0P49j0?N^K`3h[fl0mji_0?N^L03h/780n;1a0080Q4Im00H0PTEm08I8OP3h[Vd0
mji]0?J/K`3g[Fh208A6O@070895O026B7d0Q4Mm0895O@2;C7h0n:m^0?R]JP030?N/J`030?R]J@3g
[6/0P49j04<0OT5j00D0Od5j0812NP22@gX0nJUE08M7N`0207i1NP0507m1NP22AG`0n:UL07m3O01o
@W`03@1o@g`01P20@g`0Od9l0000F0000000P49j08I6N`T0n:M:00d0n:M;0?RWC02:Bgd0nJYB08Y>
P@25BH40QTZ10?VYD`29C7l0mjEE0?RWC029C800Q66R0080QD^200@0QT^208E:P@25BX403QfK1P3o
ool00`000000oooo0?ooo`1Q0?ooo`00BP3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0240oooo0`00
00060?ooo`060:S6k`2Xco@0]/SX0;?5j01nUn40B4nf1P3oool0100002D0];kQ09ZRf`2CYn<20:gA
l`030:?9m021KK<0001k00D0oooo00`0000/0000;`0002h0OCmi07i0NP20@WX0mji_0?R_K`3g[Vl0
mji`0?R`LP3h/74208A6O@060895O@26B7h0n:i]0?N^K@3f[6l0mje^0P24AWd01`22AG`0QTQm08A7
O@22AGd0Rdan0?R_KP3h[FX00`3g[6/00`3h[FT0mja[0812NP1307i1NP0507m1NP20@WX0PT=j0?VY
E@27Ag/00P1n@GX01@1o@GX0PTEl0?RYG01o@g`0Od9l00d0Od=l00H0P4=l07m2O00005P000000812
NP26AW/:0?RWBP0?0?RWC02:Bgd0nJYB08Y>P@25BH40QTZ10?VYD`29C7l0mjEE0?RWC029C800ODJ2
08AQXP25Bh80QT^20080QDZ100<03QfK07RUk`3oool01@3oool00`000000oooo0?ooo`1P0?ooo`00
?P3oool6000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0O0?ooo`8000001@3oool02P2Fd?`0
OL[o0:[Am02Za^h0[l3V0;6gg@2`[mL0UfZM091UW@3:SP060?ooo`0300009@3Din@0Yk_W0080[L3X
00@0`LKN0:BLc@004:00001k1@3oool0300002`0000_0000;P1m?gT0OT1j0812NP3g[Vl0n:m_0?N^
K`3g[W00n;1b0?R`L@80Q4Im00H0PTEm08I8OP3h[Vd0mji]0?J/K`3g[Fh208A6O@070895O026B7d0
Q4Mm0895O@2;C7h0n:m^0?R]JP030?N/J`030?R]J@3g[6/0P49j04<0OT5j00D0Od5j0812NP22@gX0
nJUE08M7N`0207i1NP0507m1NP22AG`0n:UL07m3O01o@W`03@1o@g`01P20@g`0Od9l0000F0000000
P49j08I6N`X0n:M:00X0n:M<08Y;O@3iZU80RTj108E9P@3hZ5L0nJUC0?NVF`3gYED0n:M<0P29C800
0`24HJ80QD^208I;PP0208E:P@0300hMV`32E`00oooo00H0oooo00<000000?ooo`3oool0G`3oool0
04X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0L0?ooo`<000001`3oool02P2g^md0X:kQ09jWg02N
Ym`0YKSV0:S;lP2PU/X0UfZM091UW@3:SP060?ooo`0900009@2I[ND0RJSY0:Nkj02Xh?X0`MGY0:BL
c@0007<0001k00D0oooo00`0000/0000;`0002h0OCmi07i0NP20@WX0mji_0?R_K`3g[Vl0mji`0?R`
LP3h/74208A6O@060895O@26B7h0n:i]0?N^K@3f[6l0mje^0P24AWd01`22AG`0QTQm08A7O@22AGd0
Rdan0?R_KP3h[FX00`3g[6/00`3h[FT0mja[0812NP1307i1NP0507m1NP20@WX0PT=j0?VYE@27Ag/0
0P1n@GX01@1o@GX0PTEl0?RYG01o@g`0Od9l00d0Od=l00H0P4=l07m2O00005P000000812NP26AW/:
0?RWBP0:0?RWC02:Bgd0nJYB08Y>P@25BH40n:QG0?VYD`3gYU/0mjEE0?RWC080RDb000<0Q66R08E;
PP26Bh800P25BX400`0>7I/0n:M;07ZVk`060?ooo`030000003oool0oooo05l0oooo001:0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool06@3oool3000000T0oooo00/0kn?30=OIf@2]Z]D0Z<kc0:S4kP2c
aNL0YZWI03]6/`2GJYd0P4=l0<Z>00050?ooo`0:00008P0002D0ZJcI0:O2k@2ca^T0]:gB0:V]fP1D
Fkd0001c0000N`@0oooo00d0j=i^0000;00002l0000^07doN@1n@7X0P49j0?N^K`3h[fl0mji_0?N^
L03h/780n;1a0080Q4Im00H0PTEm08I8OP3h[Vd0mji]0?J/K`3g[Fh208A6O@070895O026B7d0Q4Mm
0895O@2;C7h0n:m^0?R]JP030?N/J`030?R]J@3g[6/0P49j04<0OT5j00D0Od5j0812NP22@gX0nJUE
08M7N`0207i1NP0507m1NP3iZeP0n:UL07m3O01o@W`03@1o@g`01@20@g`0Od9l02XRT`1o@GX00000
0080QTIk2@3hYdX02P3hYd`0RT]m0?VZDP2:CX40QDV10?RXE`3iZE<0mjIK0?NUE@3hYU0208U<P003
08AQXP25Bh80QT^20080QDZ100@03QfK08YRW@3hYd/0NjO_103oool300000600oooo00180?ooo`<0
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`0G0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`090:?Qo03FnZl0[]?c
0;30iP2U^nT0/KOM09M[WP2@IYh0001L0080P4=l00<0bXh00?ooo`3oool00P3oool02`1_cOh0000R
00009@2R^^X0/KoT0;:igP2JNk00TVVP085NX@0007<0001k00@0oooo00d0000_0000;00002l0000^
07doN@1n@7X0P49j0?N^K`3h[fl0mji_0?N^L03h/780n;1a0080Q4Im00H0PTEm08I8OP3h[Vd0mji]
0?J/K`3g[Fh208A6O@070895O026B7d0Q4Mm0895O@2;C7h0n:m^0?R]JP030?N/J`030?R]J@3g[6/0
P49j04<0OT5j00D0Od5j0812NP22@gX0nJUE08M7N`0207i1NP0507m1NP3iZeP0n:UL07m3O01o@W`0
3@1o@g`01@20@g`0Od9l02XRT`1o@GX000000080QTIk2@3hYdX02P3hYd`0RT]m0?VZDP3iZU80QDV1
0?RXE`3iZE<0QT^10?NUE@3hYU0208U<P00308AQXP25Bh80QT^20080QDZ100D03QfK08YRW@3hYd/0
`5D008^[j`060?ooo`030000003oool0oooo05d0oooo001:0?ooo`030000003oool0oooo00@0oooo
100000050?ooo`@000005`3oool3000000X0oooo00`0Y=kk0:?No01b6DT0000N0:Fhi`2OZ=d0X;3S
0:S9l@2QU/T0Uf^N091VWP0005`20813O00@0<Z>003oool0oooo0?ooo`1?03h0000X00008P0002D0
Z/oc0:SGn02SW<h0VW^`099YX021GZ40001c0000N`@0oooo00X0000Y0000;00002l0000^07doN@1n
@7X0P49j0?N^K`3h[fl0mji_0P3h/7804P3h/740Q4Im08A6O@22AGd0QTQn0?R^K@3g[Vd0mZa_0?N]
KP24AWd0mjia0895O026B7d0Q4Mm0895O@2;C7h0n:m^0?R]JP<0mja[00<0n:eY0?N/J`20@WX0@`1n
@GX01@1o@GX0P49j0893NP3iZED0QdMk0080OT5j00D0Od5j0?V[F03hZE`0P4=l07m2O00=07m3O005
0813O01o@W`0:R:C07m1NP0000000P26AW/00`3hYdT0n:M:0?RWBP060?RWBP0:0?RWC02:Bgd0nJYB
0?VZDP25BH40n:QG0?VYD`26Bh40mjEE08E9O`80RDb000<0Q66R08E;PP26Bh800P25BX401@1kG:<0
301]0?RWB`3hYd/0[48000H0oooo00<000000?ooo`3oool0G@3oool007<0oooo0P00000;0?ooo`06
0:CLn`1O1ch0GPLo078IB@1S3TL0000I0P2XeoP01P2bbN/0YZcL0000J02GJih0P4Am0000G080P4=l
0100bXh00?ooo`3oool0C`0n070IB`000240000R00009@30a]l0/koS0000Q01`AXl0PDEm0814O@00
07<0001k0`3oool02`0002l0000Y0000;00002l0000^07doN@1o@GX0P49j0?N^K`3h[fl0mji_0080
n;1b0180n;1a08A6O@24AWd0PTEm08I8OP3h[Vd0mji]0?J/K`3g[Fh0Q4Im0?N^L@22AG`0QTQm0?N^
L022AGd0Rdan0?R_KP3h[FX30?N/J`030?R]J@3g[6/0P49j04<0OT5j00D0Od5j0812NP22@gX0nJUE
08M7N`0207i1NP0507m1NP3iZeP0n:UL0813O01o@W`03@1o@g`02020@g`0Od9l02XRT`1o@GX00000
0?RVCP26AW/0n:M9203hYdX0103hYd/0RT]m0?VZDP3iZU8208E9P@0408I:P@26Bh40mjEE08E9O`80
RDb000<0Q66R08E;PP26Bh800P25BX400`1kG:<03QfK0?RWB`020?RWB`L0oooo00<000000?ooo`3o
ool0G03oool00700oooo0`00000;0?ooo`0=0<7NkP1d64<0G`Ln05h6?P1N1cl0Od5j07i0NP0001T0
ZlG]0:NWeP2HKJ00TFVR07IFX0020814O@060000G020@g`0P4=l0<Z>003oool0K]3m0P1o@W/02`00
0240000R00009@2/h?T0`=;X07]Z]01`AXl0PDEm0814O@0007<0001k00<0oooo0P0002T02@0002`0
000_0000;P1n@7X0Od5j0812NP3g[Vl0n:m_0?N^K`020?R`LP0B0?R`L@24AWd0mZic0895O@26B7h0
n:i]0?N^K@3f[6l0mje^08A6O@3g[W40PTEl0?R_K`3g[W00PTEm08]<OP3h[fh0n:eZ0`3g[6/00`3h
[FT0mja[0812NP1307i1NP0507m1NP20@WX0PT=j0?VYE@27Ag/00P1n@GX01@1o@GX0nJ]H0?RYG020
@g`0Od9l00d0Od=l00P0P4=l07m2O00005`0Od5j0000003hYTh0QTIk0?RWB@P0n:M:01<0n:M;08Y;
O@3iZU80nJYB08Y>P@25BH40QTZ108I;P@24B7l0QDUo0?RWC029C800Q66R08E;PP26Bh80OSif08E:
P@1kG:<03QfK00<0n:M;00<0n:Q;0?ooo`3oool00P3oool0103ndhh0oooo0?ooo`00001M0?ooo`00
KP3oool3000000`0oooo00<0>@0Y06T;>`1N1Sd00`1n@GX00`1o@GX0OT1j00006@02095XW`0309=Y
W`2AJJ80MUJP0080P4Am00H0001L0813O020@g`0bXh00580@@1H1TD207m2N`0;00008@000280000U
0:VagP23XNH0CS6>0716S`21AGd0P4Am0000L`0007/00`3oool20000:@090000;00002l0OCmi07i0
NP1o@GX0P49j0?N^K`3h[fl0mji_0080n;1b01P0n;1a08A6O@3f[W<0PTEm08I8OP3h[Vd0mji]0853
NP3g[Fh0Q4Im0?N^L@3g[W00n:m_0?N^L022AGd0Rdan0?R`KP3h[FX0mja[0853NP24AG/0n:eY0?N/
J`20@WY307i1NP0507m1NP20@WX0PT=j0?RYE`27Ag/00P1n@GX01@1o@GX0nJ]H0?RYG020@g`0Od9l
00d0Od=l00P0P4=l07m2O00005`0Od5j0000003hYTh0QTIk0?RWB@P0n:M:00h0n:M;08Y;O@3iZU80
nJYB08Y>P@25BH40QTZ108I;P@24B7l0QDUo0?RWC029C800Q66R08E;PP80QT^20P25BX401@0>7I/0
n:M;0?RWB`3hYd/0n:Q;00@0oooo00@01@1[0?ooo`3oool00000G@3oool006/0oooo0`0000030?oo
o`030000003oool0oooo00T0oooo00<0OT1j07i1NP1n@GX00`1n@GX0201o@GX0OT1j00006@2@IYd0
TFRO09=YW`20A7d0OT=l0P20A7d01P0005`0P4=l0813O03:SP00L1]=07i1N`80Od9k00h0000Q0000
8P0002D0Vg:T07iQYP1><Hh0L4J?0855O@20A7d0001c0000N`2lmO00N]_k0000;@80000Y00T0000/
0000;`1m?gT0OT1j07m1NP20@WX0mji_0?R_K`3g[Vl00P3h/7805`3h/740Q4Im0?J^L`22AGd0QTQn
0?R^K@22A7/0PD=j0?N]KP24AWd0mjia0?N^L03h[fl0mji`0895O@2;C7h0n;1^0?R]JP3g[6/0PD=j
08A5N`23A7/0P49j04@0OT5j00D0Od5j0812NP22@gX0n:UG08M7N`0207i1NP0507m1NP3iZeP0n:UL
0813O01o@W`03@1o@g`02020@g`0Od9l0000G00005P000000?RVCP26AW/0n:M9203hYdX03@3hYd/0
RT]m0?VZDP3iZU80RTj108E9P@26BX40QT^108A8O`3gYED0n:M<08U<P024HJ800P25Bh801026Bh80
QDZ108E:P@0>7I/30?RWB`030?RXB`3oool0oooo0080oooo00D0nJY?0?S5U03oool0oooo0000001L
0?ooo`00J@3oool200000100oooo00<0W^3m02@0;@1n@7X01@1n@GX0101o@GX0OT1j00006@2@IYd3
0814O@0407i3O020A7d0P4Am0000G080P4=l00<0bXh007m2N`1n@G/00P1o@W/03P000240000R0000
9P2KLZ@0OV6V04haSP1`AXl0PDEm0814O@0007<0mjmb05/:B@1i9E@0000]0P0002T02@0002`0000^
07doN@1n@7X0Od5j0812NP3g[Vl0n:m_0?N^K`020?R`LP0G0?R`L@24AWd0mZic0?J^L`26B7h0n:i]
0894N`21@gX0mje^08A6O@3g[W40mji`0?R_K`3g[W00PTEm08]<OP3h/6h0n:eZ0?N/J`21@gX0Q4Ek
08=4N`20@WX0A01n@GX01@1o@GX0P49j0893NP3hZEL0QdMk0080OT5j00D0Od5j0?V[F03hZE`0P4=l
07m2O00=07m3O0080813O01o@W`0001L0000F0000000P49j08I6N`3hYdT80?RWBP0=0?RWB`3hYd`0
nJYB0?VZDP2:CX40QDV108I:P@26Bh40Q4Qo0?NUE@3hYd`0RDb008AQXP0208E;PP0408I;PP25BX40
QDZ100hMV`<0n:M;00<0n:Q;0?ooo`3oool00`3oool01@3haI@0n<FC0?ooo`3oool0000005/0oooo
001V0?ooo`<00000403oool01@2ShO`0H0U207<LC00T02d0OT1j00D0OT5j00<0Od5j07i0NP0001T0
1020A7d0101n@g`0P4Am0814O@0005`20813O0030<Z>001o@W/0OT5k0080Od9k00h0000Q00008P00
0280PTEn0814OP1><Hh0L4J?0855O@20A7d0001c0?N_LP1i9E@0K1]B0000;@80000Y00@0000/0000
;P1m?gT0OT1j0P20@WX20?R_K`050?N^K`3h/780n;1a0?R`LP24AWd00P3f[W<04`26B7h0n:i]0894
N`21@gX0mje^08A6O@3g[W40mji`0?R_K`3g[W00PTEm08]<OP3h/6h0n:eZ0?N/J`21@gX0Q4Ek08=4
N`20@WX0A@1n@GX01020@WX0n:QH0?RYE`27Ag/307i1NP040?V[F03hZE`0P4=l07m2O0d0Od=l0P20
@g`01P1o@W`0001H00000020@WX0QTIk0?RWB@T0n:M:00`0n:M<0?VZDP3iZU80RTj108E9P@26BX40
QT^108U<O`3gYED0n:M<08U<P01mAX8208E;PP0408I;PP25BX40QDZ100hMV`<0n:M;00<0n:Q;07BS
k`3oool00`3oool01@3iZU00n<FC0?W5TP3oool0000005/0oooo001S0?ooo`<00000403oool0202R
go`0H0U105l9@@1P2D80J15507i1NP1l?gX0OT1j1@1n@GX00`1o@GX0OT1j00006@040814O@0407i3
O020A7d0P4Am0000G080P4=l00<0bXh007m2N`1n@G/00P1o@W/02`000240000R00008P22AGh0P4An
04haSP1`AXl0PDEm0814O@0007<0mjmb0080P4=l00L0000]0000:@0002T0000/0000;P1m?gT0OT1j
0080P49j0P3h[fl06P3g[Vl0n;1b0?R`L@3g[g80Q4Im0895O@3f[W<0n:i/0?R^K@22A7/0PD=j0?R_
L024AWd0PTEl0?N^L03h[fl0mji`0895O@2;C7h0n;1^0?R]JP3g[6/0PD=j08A5N`23A7/0P49jA@1n
@GX01@1o@GX0n:QH0?RYE`27Ag/0Od9j0080OT5j00D0nJ]H0?RYG020@g`0Od=l07m2O00=07m3O007
0813O01o@W`0001H00000020@WX0QTIk0?RWB@090?RWBP0<0?RWC03iZU80nJYB08Y>P@25BH40QTZ1
0?VYD`29C7l0mjEE0?RWC029C800ODJ20P25Bh801026Bh80QDZ108E:P@0>7I/30?RWB`030?RXB`34
FP00oooo00<0oooo00H0nJY@0?W5TP3iaI80nLJB0?ooo`00001J0?ooo`00H@3oool200000080oooo
00<000000?ooo`3oool02`3oool01@2lgo40KQ4o0609@01Q2D40G`U10080OT5j00@0Od5j07i1NP1l
?gX0OT1j1@1n@GX00`1o@GX0OT1j00006@040814O@0407i3O020A7d0P4Am0000G080P4=l00<0bXh0
07m2N`1n@G/00P1o@W/02`000240000U0855OP22AGh0P4An04haSP1`AXl0PDEm0814O@0007<0mjmb
0080P4=l00L0000]0000:@0002T0000H0000;P1m?gT0OT1j0080P49j0P3h[fl01`3g[Vl0n;1b0?R`
L@3g[g80Q4Im0895O@3f[W<00P3h[Vd04@22A7/0PD=j0?R_L024AWd0PTEl0?N^L024Agd0mji`0895
O@3h[fh0n;1^0?R]JP3g[6/0PD=j08A5N`23A7/0P49j04D0OT5j00D0Od5j0?RXF03hZEL0QdMk07m2
NP0207i1NP050?V[F03hZE`0n:UL07m3O01o@W`03@1o@g`01`20@g`0Od9l0000F0000000P49j08I6
N`3hYdT02@3hYdX03`3hYd`0nJYB0?VZDP2:CX40QDV108I:P@3iZE<0RDao0?NUE@3hYd`0RDb007e6
PP24HJ80QD^208I;PP0208E:P@0700hMV`3hYd/0n:M;0?RWB`3hZ4/0n:Q<07BSk`030?ooo`040?VZ
D03iZTl0nLFB0?W6TP80oooo00<000000?ooo`3oool0E`3oool005h0oooo0`0000050?ooo`030000
003oool0oooo00X0oooo00<0KQ4o07@IAP1n@GX0101n@GX0101o@GX0OT5j07`oNP1n@7X507i1NP03
07m1NP1n@7X0P4Am00@0P4Am00@0OT=l0814O@20A7d0001L0P20@g`00`3:SP00Od9k07i1N`0207m2
N`0;00008@0002D0PDEn0895OP20A7h0CS6>0716S`21AGd0P4Am0000L`3g[g800P20@g`01`0002d0
000Y0000:@0001P0000^07doN@1n@7X00P20@WX20?R_K`0J0?N^K`3h/780n;1a0?N_LP24AWd0PTEm
0?J^L`3h[Vd0mji]0894N`21@gX0n:m`08A6O@22AG`0mji`08A7O@3g[W00PTEm0?R_KP3h/6h0n:eZ
0?N/J`21@gX0Q4Ek08=4N`20@WY507i1NP0507m1NP3hZ5P0n:UG08M7N`1o@WX00P1n@GX01@3iZeP0
n:UL0?RYG01o@g`0Od9l00d0Od=l00L0P4=l07m2O00005P000000812NP26AW/0n:M900T0n:M:00l0
n:M<0?VZDP3iZU80RTj108E9P@3hZ5L0nJUC0?NVF`3gYED0n:I@08U<P01mAX80Q66R08E;PP26Bh80
0P25BX401@0>7I/0RV:M0?RWB`3hYd/0n:Q;0080n:Q<00@0M:?_0?ooo`3oool0nJY@0P3iZTl0103i
aY80oooo0?ooo`00001I0?ooo`00G03oool2000000H0oooo00<0T6JN09I[W`1G?YT0303oool207m1
NPD0OT5j00@0Od5j07i1NP1l?gX0OT1j1@1n@GX00`1o@GX0OT1j0814O@040814O@0407i3O020A7d0
P4Am0000G080P4=l00<0000Y07m2N`1n@G/00P1o@W/02`000240000U0855OP22AGh0P4An04haSP1`
AXl0PDEm0814O@0007/0mjmb0080P4=l00T0000]0000:@0002T0000H0000;P1m?gT0OT1j0812NP3d
ZW800P3h[fl06P3g[Vl0n;1b0?R`L@3g[g80Q4Im0895O@3f[W<0n:i]0?N^K@22A7/0PD=j0?R_L024
AWd0PTEl08I8O@24Agd0mji`0895O@3h[fh0n:m_0?R]JP3g[6/0PD=j08A5N`23A7/0P49jA@1n@GX0
1@1o@GX0n:QH0?RYE`27Ag/0Od9j0080OT5j00D0nJ]H0?RYG03hZE`0Od=l07m2O00=07m3O0060813
O01o@W`0001H00000020@WX0QTIk2P3hYdX03`3hYd`0RT]m0?VZDP2:CX40QDV10?RXE`3iZE<0mjIK
0?NUE@3hYU00RDb007e6PP24HJ80QD^208I;PP0208E:P@0507]LX`2:HYd0n:M;0?RWB`3hZ4/00P3h
Z4`0101dXnl0oooo0?ooo`3iZU030?VZC`040?W6TP3oool0oooo000005P0oooo001I0?ooo`<00000
1P3oool2091VWP0309AYWP2FJil0EcjI00X0oooo00@0W^?m0000401o@GX0Od5j1@1n@GX0101o@GX0
OT5j07doN@1n@7X507i1NP0307m1NP1m?gT0P4Am00@0P4Am00T0OT=l0814O@20A7d0001L0813O01n
@W`0001V07m2N`1n@G/00P1o@W/02`3igW`0000U0855OP22AGh0P4An04haSP1`AXl0PDEm0814O@00
07/0mjmb0080P4=l00T0000]0000:@3hhX80000H0000;P1m?gT0OT1j0812NP3dZW800P3h[fl06P3g
[Vl0n;1b0?R`L@3g[g80Q4Im0895O@3f[W<0n:i]0?N^K@3f[6l0PD=j0?R_L024AWd0PTEl08I8O@24
Agd0mji`0895O@3h[fh0n:m_0?R]JP3g[6/0PD=j08A5N`23A7/0P49jA@1n@GX01@1o@GX0n:QH0?RY
E`27Ag/0Od9j0080OT5j00D0nJ]H0?RYG03hZE`0Od=l07m2O00=07m3O0060813O01o@W`0001H0000
0020@WX0QTIk2P3hYdX03`3hYd`0RT]m0?VZDP2:CX40QDV10?RXE`3iZE<0mjIK0?NUE@3hYU00RDb0
07e6PP24HJ80QD^208I;PP0208E:P@0307]LX`0<06d0n:M;0080n:M;0`3hZ4`00`1dXnl0oooo0?VZ
D0030?VZC`80nLJB0P3oool00`000000oooo0?ooo`1E0?ooo`00E`3oool3000000H0oooo00L0SfFL
091VWP2@IYh0T6JN09AYWP2FJil0O41k00L0oooo00D0X]kl06<<A01]5TT0H@m;0000400207m1NPD0
OT5j00@0Od5j07i1NP1m?gT0OT1j1@1n@GX00`1o@GX0000N0814O@040814O@0907i3O020A7d0P4Am
0000G020@g`0OT9l0000:01o@W/0OT5k0080Od9k00/0000R00009@21AGh0PTEn0814OP1><Hh0L4J?
0855O@20A7d0001k0?N_LP020813O0090000;@0002T0nN:20000;`0002h0OCmi07i0NP20@WX0m:Yb
0080n:m_0100mji_0?R`LP3h/740mjmb08A6O@22AGd0mZic0?R^K@3g[Vd0mZa_0853NP3h[g00Q4Im
0895O026B7d0Q4Mm0P3g[W00203h[fh0n:m_0?R]JP3g[6/0PD=j08A5N`23A7/0P49jA@1n@GX01@1o
@GX0n:QH0?RYE`27Ag/0Od9j0080OT5j00D0nJ]H0?RYG03hZE`0Od=l07m2O00=07m3O0050813O01o
@W`0001H00000020@WX00P26AW/90?RWBP0:0?RWC02:Bgd0nJYB0?VZDP25BH40n:QG0?VYD`3gYU/0
mjEE08E9O`80RDb000<0Q66R08E;PP26Bh800P25BX400`1kG:<03QfK0?RWB`020?RWB`<0n:Q<00<0
a5X00?ooo`3iZU00103iZTl20?W6TP030?ooo`000000oooo05H0oooo001D0?ooo`<000000`3oool0
1`000000oooo0:GDn02Ue?P0VhNm08mTW02?II`0102@IYh00`20@g`0O41k0?ooo`030?ooo`0809gN
o@2Og_d0HP]2068;@P1]5TT0MAm?07`oNP1m@7X207m1NPD0OT5j00<0Od5j07i1NP1n@7X01@1n@GX0
0`1o@GX0OT1j00006@050814O@0F07i3O020A7d0P4Am0000G020@g`0000U0000901o@W/0OT5k07m2
N`1n@GX0000R00009@21AGh0PTEn0814OP1><Hh0L4J?0855O@20A7d0001k0000:@80P4=l00T0000]
0000:@3ihX80000_0000;P1m?gT0OT1j0812NP3g[Vl00P3h[fl00`3g[Vl0n;1b0?R`L@0208A6O@0;
0895O@3f[W<0n:i]0?N^K@3f[6l0PD=j0?R_L024AWd0PTEl08I8O@24Agd00P3g[W00203h[fh0n:m_
0?R]JP3g[6/0PD=j08A5N`23A7/0P49jA@1n@GX01@1o@GX0P49j0?RYE`27Ag/0Od9j0080OT5j00D0
nJ]H0?RYG03hZE`0Od=l07m2O00=07m3O0050813O01o@W`0001H00000020@WX00P26AW/90?RWBP0:
0?RWC02:Bgd0nJYB0?VZDP25BH40n:QG0?VYD`3gYU/0Q4Qo08E9O`80RDb000<0Q66R08E;PP26Bh80
0P25BX400`1kG:<03QfK0?RWB`020?RWB`060?RXB`3hZ4`0n:Q<0?RXC01dXnl0nJY@103iZTl30?W6
TP030?ooo`000000oooo05D0oooo001B0?ooo`8000001@3oool0202ffO80W;k`0:W5kP2L__00IZ_h
09^7_@2?I9`0SfFL0`1o@g`20813O00607a0N`3oool0oooo04h0;`1c64@0HP]10P1R2d8207m1NP03
07m2NP1l?gX0OD1j0080Od5j1@1n@GX00`1o@GX0OT5j07i0NP0507i1NP0307m1NP1n@7X0000I00D0
P4Am01H0OT=l0814O@1n@W`0001L0813O03:SP00000T07m2N`190Tl0Od9k00008@000280000U0855
OP22AGh0P4An04haSP1`AXl0PDEm0814O@0007/0000Y0P20@g`02@0002d0000Y0?WRPP0002l0000^
07doN@1n@7X0P49j0?N^K`020?R_K`030?N^K`3h/780n;1a0080Q4Im00/0PTEm0?J^L`3h[Vd0mji]
0?J/K`21@gX0n:m`08A6O@22AG`0QTQm08A7O@020?N^L0080?R_KP3h[fl0n:eZ0?N/J`21@gX0Q4Ek
08=4N`20@WY507i1NP0507m1NP20@WX0PT=j08M7N`1o@WX00P1n@GX01@3iZeP0n:UL0?RYG01o@g`0
Od9l00d0Od=l00D0P4=l07m2O00005P000000812NP0208I6N`030?RWB@3hYdX0n:M:00H0n:M:00X0
n:M;08Y;O@3iZU80nJYB08Y>P@3hZ5L0nJUC08I;P@24B7l0QDUo0P29C8001`24HJ80QD^208I;PP26
Bh80QDZ100P0K00>7I/00`3hYd/00`3hZ4/0n:Q<0?RXC0020?RXC00306TbN@3iZTl0nJY?00<0nJY?
0P3iaY800`3oool000000?ooo`1E0?ooo`003P3oool6000000@0oooo100000050?ooo`@00000:P3o
ool3000000H0oooo00L0iMK60=Ro`@2Y^^H0ZK[U08RWj@2^Y]00ACZP00D0Od=l0P20@g`01@1l@7/0
oooo04h0;`1c5T40H`Y000D0Od5j00<0Od9j07`oNP1m@7X00P1o@GX507i1NP0307m1NP1n@GX0OT1j
00D0OT5j00<0Od5j07i0NP0001T01@20A7d00`1n@g`0P4Am07i2O0020813O0030<Z>000002@0Od9k
0080Od9k00`0000Q00008P0002D0PDEn0895OP20A7h0CS6>0716S`21AGd0P4Am0000N`0002T20813
O0090000;@0002l0000/0000;`0002h0OCmi07i0NP20@WX0mji_0080n:m_00<0mji_0?R`LP3h/740
0P24AWd02`22AGd0mZic0?R^K@3g[Vd0mZa_0853NP3h[g00Q4Im0895O026B7d0Q4Mm0080mji`00P0
n:m^0?R_K`3h[FX0mja[0853NP24AG/0PdAk0812NTD0OT5j00D0Od5j0812NP22@gX0QdMk07m2NP02
07i1NP050?V[F03hZE`0n:UL07m3O01o@W`03@1o@g`01@20@g`0Od9l0000F0000000P49j0080QTIk
00<0n:M90?RWBP3hYdX01P3hYdX03@3hYd/0RT]m0?VZDP3iZU80RTj10?RXE`3iZE<0QT^108A8O`25
BGl0n:M<08U<P024HJ800P25Bh801026Bh80QDZ10?V[E00>7I/30?RWB`030?RXB`3hZ4`0n:Q<0080
n:Q<00<01@1[0?VZC`3iZTl0103iZTl0103iaY80000000000000000;0?ooo`@00000AP3oool000h0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo02@0oooo0`0000090?ooo`070?O2T@3D^;d0
e;Rm0;:nh`2/_^L0[ZK@04DjX00507m3O080P4=l00@0O41k0?ooo`1o@GX0Od9j1P1o@GX00`1o@WX0
O3mj07e0NP0207m1NPD0OT5j00<0Od5j07`oNP1n@7X01@1n@GX00`1o@GX0OT1j00006@050814O@03
07i3O020A7d0OT9l0080P4=l00<0bXh007m2N`1o@W/00P1o@W/030000240000R00009P21AGh0PTEn
0814OP1><Hh0L4J?0855O@0002l0001k0000:@80P4=l00/0000]0000:@0002`0000_0000;P1m?gT0
OT1j0812NP3g[Vl0n:m_0?N^K`020?R`LP0>0?R`L@24AWd0Q4Im0895O@26B7h0n:i]0?N^K@3f[6l0
PD=j0?R_L024AWd0PTEl08I8O@24Agd20?N^L0030?R_KP3h[fl0PdAj0080mja[00<0n:eY08=4N`20
@WX0A@1n@GX01@1o@GX0P49j0893NP27Ag/0Od9j0080OT5j00D0nJ]H0?RYG03hZE`0Od=l07m2O00=
07m3O0050813O01o@W`0001H00000020@WX00P26AW/00`3hYdT0n:M:0?RWBP060?RWBP0=0?RWB`2:
Bgd0nJYB0?VZDP2:CX40n:QG0?VYD`26Bh40Q4Qo08E9O`3hYd`0RDb008AQXP0208E;PP0408I;PP25
BX40QDZ100hMV`<0n:M;00<0n:Q;0?RXC03hZ4`00P3hZ4`00`3k]e<0nJY?0?VZC`050?VZC`040?W6
TP3oool0oooo000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`130?ooo`00
3`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0280oooo0P0000020?ooo`030000003oool0oooo0080
oooo00<0:an?0?ooo`3oool00P3oool01`3g`Y40lk^C0=cKe@3:f^D0];oR09Fgk`15>Z001@1o@g`2
0813O00407a0N`1n@7X0Od5j07m2NPH0Od5j00<0Od9j07`oNP1m@7X00P1o@GX407i1NP0407m1NP1n
@GX0O3mj07i0NPD0OT5j00<0Od5j07i0NP0001T01020A7d0101n@g`0000S0814O@0005`20813O003
0<Z>001o@W/0Od9k0080Od9k00`0000Q00008P0002H0PDEn0895OP20A7h0CS6>0855O@20A7d0000_
0000N`0002T20813O00;0000;`0002T0000/0000;`000000OCmi07m1NP20@WX0mji_0?R_K`3g[Vl0
0P3h/7803P3h/740Q4Im08A6O@22AGd0QTQn0?R^K@3g[Vd0mZa_0853NP3h[g00Q4Im0895O026B7d0
Q4Mm0P3g[W000`3h[fh0n:m_08=4NP020?N/J`030?R]J@23A7/0P49j04D0OT5j00D0Od5j0812NP22
@gX0QdMk07m2NP0207i1NP050?V[F03hZE`0n:UL07m3O01o@W`03@1o@g`01@20@g`0Od9l0000F01o
@GX000000080QTIk00<0n:M90?RWBP3hYdX01P3hYdX03@3hYd/0RT]m0?VZDP3iZU80RTj108E9P@26
BX40QT^108A8O`3gYED0n:M<08U<P00106T00P25Bh801026Bh80QDZ108E:P@0>7I/30?RWB`030?RX
B`3hZ4`0n:Q<00<0n:Q<1`3iZTl0103iaY80nLJC0?ooo`0000090?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0@`3oool00100oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0O0?ooo`<0
00001P3oool0102aa^X0_L?N08mg]00[7hl40?ooo`070?O2T@3c^i<0/>ch08W@o`2T_>/0]l;S04Dj
X00507m3O080P4=l00@0O41k07i0NP1o@GX0Od9j1P1o@GX0101o@WX0O3mj07i1NP1o@GX507i1NP04
07m1NP1n@GX0O3mj07i0NPD0OT5j00<0Od5j07i0NP0001T01020A7d0101n@g`0P4Am0814O@0005`2
0813O0030<Z>001o@W/0OT5k0080Od9k00`0000Q00008P0002H0PDEn0895OP20A7h0CS6>0855O@20
A7d0001c0000N`0002T20813O00;0;g;CP0002T0000/0000;`000000OT1j07m1NP20@WX0mji_0?R_
K`3g[Vl00P3h/7803P3h/740Q4Im0?J^L`22AGd0QTQn0?R^K@3g[Vd0mZa_0853NP3h[g00Q4Im0895
O026B7d0Q4Mm0P3g[W000`3h[fh0n:m_08=4NP020?N/J`030?R]J@3g[6/0P49j04D0OT5j00D0Od5j
0812NP22@gX0QdMk07m2NP0207i1NP050?V[F03hZE`0n:UL07m3O01o@W`03@1o@g`01@20@g`0Od9l
0000G01o@GX000000080QTIk00<0n:M90?RWBP3hYdX01`3hYdX0302:Bgd0nJYB0?VZDP2:CX40QDV1
08I:P@26Bh40Q4Qo0?NUE@3hYd`0RDb007e6PP80QD^200@0QT^208E:P@25BX403QfK0`3hYd/00`3h
Z4/0n:Q<0?RXC0030?RXC0P0nJY?0P3iaY<00`3oool000000?ooo`070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0@`3oool000D0oooo1P0000060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool07@3oool2000000L0oooo00H0ZKWU0:jki02ea>H0ZLK^05a/b`0[7hl40?ooo`070?O2T@3c
^i<0aJFi09fLdP1kU^80ZZ_G04DjX00507m3O080P4=l00@0O41k07i0NP1o@GX0Od9j1P1o@GX0101o
@WX0O3mj07m1NP1o@GX507i1NP0407m1NP1n@GX0O3mj07i0NPD0OT5j00<0Od5j07i0NP20A7d01020
A7d0101n@g`0P4Am0814O@0005`20813O0030<Z>001o@W/0OT5k0080Od9k00`0000Q00008P000280
PDEn0895OP20A7h0000[0855O@20A7d0001c0000N`1:0dh20813O00;0;g;CP0002T0000/0000;`1m
?gT0OT1j07m1NP20@WX0mji_0?R_K`3g[Vl00P3h/7803P3h/740Q4Im0?J^L`22AGd0QTQn0?R^K@3g
[Vd0mZa_0853NP3h[g00Q4Im0895O026B7d0Q4Mm0P3g[W000`3h[fh0n:m_08=4NP020?N/J`030?R]
J@3g[6/0P49j04D0OT5j00D0Od5j0812NP22@gX0QdMk07m2NP0207i1NP050?V[F03hZE`0n:UL07m3
O01o@W`03@1o@g`01@20@g`0Od9l0000G01o@GX000000080QTIk00<0n:M90?RWBP3hYdX01`3hYdX0
302:Bgd0nJYB0?VZDP2:CX40QDV108I:P@3iZE<0RDao0?NUE@3hYd`0RDb007e6PP80QD^200@0QT^2
08E:P@25BX403QfK0`3hYd/00`3hZ4/0n:Q<0?RXC0030?RXC0030?VZD03iZTl0nJY?00D0nJY?0`3i
aY<00`3oool000000?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@`3o
ool00180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`0J0?ooo`<000001P3oool02@2K]>T0X[?T0:Be
i02X^>@0Zk[U0;[0gP2l`n00U[W`02/OS`030?ooo`050?O2T@3Y/9H0lk^C0=>JV@2ULYX00P2YPZX0
0`15>Z00Od=l07m3O00307m3O080P4=l00@0O41k07i0NP1o@GX0Od9j1P1o@GX0101o@WX0O3mj07m1
NP1o@GX507i1NP0407m1NP1n@GX0O3mj07i0NPD0OT5j00<0Od5j07i0NP20A7d01020A7d0101n@g`0
P4Am0814O@0005`20813O0030<Z>001o@W/0OT5k0080Od9k01T0000Q0?SNNP000280PDEn0895OP20
A7h0000[0855O@20A7d0001c0000N`21@g`0P4=l0000;@2mbdh0000Y0000;00002l0OCmi07i0NP1o
@GX0P49j0?N^K`3h[fl0mji_0080n;1b00h0n;1a08A6O@3f[W<0PTEm08I8OP3h[Vd0mji]0?J/K`21
@gX0Q4Im0?N^L@22AG`0QTQm08A7O@80mji`00<0n:m^0?R_K`23A7X00P3g[6/00`3h[FT0mja[0812
NP1507i1NP0507m1NP20@WX0PT=j08M7N`1o@WX00P1n@GX01@3iZeP0n:UL0?RYG01o@g`0Od9l00d0
Od=l00D0P4=l07m2O00005`0001H0000000208I6N`030?RWB@3hYdX0n:M:00L0n:M:00`0n:M<0?VZ
DP3iZU80RTj108E9P@26BX40nJUC08U<O`3gYED0n:I@08U<P01mAX8208E;PP0508I;PP25BX40QDZ1
07]LX`2:HYd00P3hYd/00`3hZ4/0n:Q<0?RXC0030?RXC0030?VZD03iZTl0nJY?00H0nJY?0P3iaY<0
0`3oool000000?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@`3oool0
00h0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo01P0oooo0`0000060?ooo`0;0>GVdP2N
[N80Q:7V09J]i`2U]nD0Z;ST0:fmi@2__nH0[[oV0;g3gP0[7hl00P2H^Nl02@3oool0l[220?>kT`3e
]840diZI0:EbVP21AGd0/7ZH04DjX00507m3O0060813O01o@g`0O41k07i0NP1o@GX0Od9j1P1o@GX0
101o@WX0000@07m1NP1o@GX507i1NP0407m1NP1n@GX0c_BN07i0NPD0OT5j00<0Od5j07doN@20A7d0
1020A7d0101n@g`0P4Am0814O@0005`20813O0030<Z>001o@W/0OT5k0080Od9k00<0000Q00009@21
AGh00P21AGh050000340000[0855O@20A7d0001c0?N_LP21@g`0P4=l0000;@2mbdh0000Y0000;000
02h0OCmi07i0NP1o@GX0P49j0?N^K`3h[fl0mji_0P3h/7804`3h/740Q4Im0?J^L`3f[W<0QTQn0?R^
K@3g[Vd0mZa_0853NP24AWd0mjia0895O026B7d0mji`0895O@3g[W00n:m^0?R_K`23A7X00P3g[6/0
0`3h[FT0mja[0812NP1507i1NP0507m1NP20@WX0PT=j08M7N`1o@WX00P1n@GX01@3iZeP0n:UL0?RY
G01o@g`0Od9l00d0Od=l00P0P4=l07m2O00005`0001e00000026>fT0QTIk0?RWB@T0n:M:00l0n:M<
0?VZDP3iZU80RTj108E9P@26BX40nJUC08U<O`3gYED0n:I@08U<P01mAX80Q66R08E;PP26Bh800P25
BX400`1kG:<0301]0?RWB`020?RWB`D0n:Q<00<0nJY@0?VZC`3iZTl01`3iZTl0103iaY<0oooo0?oo
o`0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@`3oool000h0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo01D0oooo0`0000030?ooo`030000003oool0oooo00<0
oooo00h0l]ec0;NhfP2JWmP0X;KX0::hj02T^nX0Zl3Y0:k1i`2_`NL0`LGM02/OS`3b[h40e5d00?oo
o`80l[2200H0mKB10=>JV@2ULYX0PDEm0;1jV015>Z0507m3O0060813O01l@7/0O41k07i0NP1o@GX0
Od9j1@1o@GX00`1o@WX0OT5j07e0NP0207m1NPD0OT5j00@0Od5j07i1NP1m?gT0OT1j1@1n@GX00`1o
@GX0OCmi0814O@040814O@0407i3O020A7d0P4Am0000G080P4=l00<0bXh007m2N`1n@G/00P1o@W/0
2`3igW`0000U0855OP22AGh0PDEn0000<@0002/0PDEm0814O@0007<0mjmb0080P4=l00`0000]0000
:@0002T0000/0000;P1m?gT0OT1j07m1NP20@WX0mji_0?R_K`3g[Vl20?R`LP0C0?R`L@24AWd0mZic
0?J^L`26B7h0n:i]0?N^K@3f[6l0mje^08A6O@3g[W40mji`0?R_K`3g[W00PTEm0?N^L03h[fh0n:m_
08=4NP020?N/J`030?R]J@3g[6/0P49j04D0OT5j00D0Od5j0812NP22@gX0QdMk07m2NP0207i1NP05
0?V[F03hZE`0n:UL07m3O01o@W`03@1o@g`02020@g`0Od9l0000G00007D0000008HkJ@26AW/0n:M9
2@3hYdX03`3hYd`0nJYB0?VZDP2:CX40QDV108I:P@3iZE<0RDao0?NUE@3hYU00RDb007e6PP24HJ80
QD^208I;PP0208E:P@0307]LX`0<06d0n:M;0080n:M;1@3hZ4`00`3iZU00nJY?0?VZC`080?VZC`04
0?S5T`3iaY80oooo000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`130?oo
o`003`3oool4000000D0oooo100000050?ooo`@000005P3oool2000000X0oooo00L0Y]Oi0775o`2W
e_P0U]Sn09Rcj`2Q^>T0Y;cZ0080XmCi00L0Y/C^09_2l`2^aN/0:an?0?:_P@3DG@00TKK_0080l[22
00L0mKB10=>JV@23AWh0PDEm0;1jV01n@W`0P4=l00<0Od=l0P20@g`00`1l@7/0k[<g07i0NP0707m1
NP0307m2NP1l?gX0OD1j0080Od5j1@1n@GX00`1o@GX0OT5j07i0NP0607i1NP0307m1NP0001h0P4Am
00@0P4Am00@0OT=l0814O@20A7d0001L0P20@g`00`0002T0Od9k07i1N`0207m2N`0;0?WNO00002D0
PDEn0895OP21AGh0000a0<R70021AGd0P4Am0000L`3g[g800P20@g`0300002d0000Y0000:@0002`0
000^07doN@1n@7X0Od5j0812NP3g[Vl0n:m_0?N^K`80n;1b01<0n;1a08A6O@3f[W<0mZic08I8OP3h
[Vd0PTAk0853NP3g[Fh0Q4Im0?N^L@3g[W00n:m_0?N^L022AGd0mji`0?R`KP25Agd0PdAj0080mja[
00<0n:eY0?N/J`20@WX0A@1n@GX01@1o@GX0P49j0893NP27Ag/0Od9j0080OT5j00D0nJ]H0?RYG03h
ZE`0Od=l07m2O00=07m3O00809U[V`2BI9T0Q5ZH05]0V0000000QS]Y08I6N`3hYdT90?RWBP0?0?RW
C03iZU80nJYB08Y>P@25BH40n:QG0?VYD`3gYU/0mjEE08E9O`29C800ODJ208AQXP25Bh80QT^20080
QDZ100<0NebS00`0K@3hYd/00P3hYd/00`3hZ4L0n:Q<0?RXC0020?RXC0030?VZD03iZTl0nJY?00P0
nJY?00@0n<FC0?W6TP3oool000001P3oool4000004H0oooo000h0?ooo`<00000303oool03@1c6TT0
McYh09RKe@2IXMX0Xl_d0:C2k`2ZaNd0XJ7E09bQf02JY]h0WXZm0;bfd`0[7hl00P3b[h40203KJ0<0
l[220?:`PP3e]840QdUn08=6OP21AGd0bhnD1@1o@g`20813O00407a0N`3^/cL0Od5j07m2NPH0Od5j
00<0Od9j07`oNP1m@7X00P1o@GX507i1NP0307m1NP1n@GX0OT1j00D0OT5j00<0Od5j07i0NP0001T0
1@20A7d0101n@g`0P4Am0814O@0005`20813O00@0000:@1o@W/0OT5k07m2N`1n@GX0nMil00009@21
AGh0PTEn0855OP000340L4J?0855O@20A7d0001c0?N_LP80P4=l00`0000]0000:@3hhX80000H0000
;P1m?gT0OT1j07m1NP20@WX0mji_0?R_K`3g[Vl20?R`LP0C0?R`L@24AWd0mZic0?J^L`26B7h0n:i]
0894N`21@gX0mje^08A6O@3g[W40mji`0?R_K`3g[W00PTEm08]<OP3h/6h0QDMm08=4NP020?N/J`03
0?R]J@3g[6/0P49j04D0OT5j00D0Od5j0812NP22@gX0QdMk07m2NP0207i1NP050?V[F03hZE`0n:UL
07m3O01o@W`02P1o@g`2091VW@09095VW02IJi/0TVBI08AJV01K@9P0000008HkJ@26AW/0n:M900T0
n:M:00l0n:M<0?VZDP3iZU80RTj108E9P@3hZ5L0nJUC0?NVF`24B7l0QDUo08U<P01mAX80Q66R08E;
PP26Bh800P25BX400`1kG:<03QfK0?RWB`020?RWB`030?RXB`3hZ4`0n:Q<0080n:Q<00<0nJY@0?VZ
C`3iZTl02@3iZTl0103iaY8000000?ooo`00001?0?ooo`00=@3oool3000000l0oooo00`0OT1j0?Bd
P`2T]nH0X[OW0:g0j02`^n80YjSG08ePV02>HYX0U6nV0;:8Z@3PeL`40?:_P@80l[2200D0mKB108M9
OP23AWh0PDEm04DjX00507m3O080P4=l00@0O41k0>jc=`1o@GX0Od9j1P1o@GX00`1o@WX0O3mj07e0
NP0207m1NPD0OT5j00<0Od5j07i1NP1n@7X01@1n@GX00`1o@GX0OT1j00006@050814O@0F07i3O020
A7d0P4Am0000G020@g`0OT9l0000:@1o@W/0OT5k07m2N`1n@GX0000R00009@21AGh0PTEn0814OP1>
<Hh0L4J?0855O@20A7d0001c0?N_LP80P4=l00`0000]0000:@3hhX80000H0000;P1m?gT0OT1j07m1
NP20@WX0mji_0?R_K`3g[Vl20?R`LP0C0?R`L@24AWd0mZic0?J^L`26B7h0n:i]0894N`21@gX0mje^
08A6O@3g[W40mji`0?R_K`3g[W00PTEm08]<OP3h/6h0QDMm08=4NP020?N/J`030?R]J@3g[6/0P49j
04D0OT5j00D0Od5j0812NP22@gX0QdMk07m2NP0207i1NP050?V[F03b/880n:UL07m3O01o@W`0201o
@g`03@2?IIh0SfJN091VW@2@IYd0TFJL09U[V`2BI9T0Q5ZH0:6GbP000000_/cU08I6N`3hYdT02@3h
YdX03`3hYd`0nJYB0?VZDP3iZU80RTj10?RXE`3iZE<0mjIK08A8O`25BGl0RDb007e6PP24HJ80QD^2
08I;PP0208E:P@0300P0K00>7I/0n:M;0080n:M;00<0n:Q;0?RXC03hZ4`00P3hZ4`00`1Y<WT0nJY?
0?VZC`090?VZC`050?W6TP3iai80n/NB0?ooo`000000CP3oool003<0oooo0P0000030?ooo`060000
003oool0oooo08O7o@2mend0ZjOC203oool207i0NP0;0?BdP`2O]NL0YkkZ0:;Qo02QfO/0V86h08eP
V02>HYX0PTEm0;R1V@3`^YL0103b[h420?:`PP050?:`P`27BGh0PdIn0855O@15>Z001@1o@g`20813
O00407a0N`1n@7X0Od5j07m2NPH0Od5j00<0Od9j07`oNP1m@7X00P1o@GX507i1NP0307m1NP1l?gX0
OT1j00D0OT5j00<0Od5j07i0NP0001T01@20A7d05P1n@g`0P4Am0814O@0005`0P4=l07i2O00002T0
Od9k00009`1o@W/0OT5j00008P0002D0PDEn0895OP20A7h0CS6>0716S`21AGd0P4Am0000L`3g[g82
0813O0070000;@0002T0n>:20000600002h0OCmi07i0NP020812NP80n:m_00D0mji_0?R`LP3h/740
n;1b08A6O@020?J^L`0?08I8OP3h[Vd0PTAk0853NP3g[Fh0Q4Im0?N^L@3g[W00n:m_0?N^L022AGd0
Rdan0?R`KP25Agd0PdAj0080mja[00<0n:eY0?N/J`20@WX0A@1n@GX01@1o@GX0P49j0893NP27Ag/0
Od9j0080OT5j00D0nJ]H0?:`PP3hZE`0Od=l07m2O00507m3O0@0SfFN00L0SfJN091VW@2@IYd0TFJL
0:>IbP2SUlT0XiK80080000000<0^_Cb06GId02i@2002@3hYdX03P3hYd`0RT]m0?VZDP3iZU80RTj1
0?RXE`3iZE<0mjIK08A8O`25BGl0RDb007e6PP24HJ80QD^20P26Bh800`25BX40nJ]D00hMV`030?RW
B`030?RXB`3hZ4`0n:Q<0080n:Q<00<0JC9i0?VZC`3iZTl02P3iZTl0103iai80n/NB0?ooo`00001>
0?ooo`00<03oool3000000L0oooo00@0e<cB0=C>d`2f^M/001:Q203oool207i0NP0;0?BdP`2Y_nT0
//GX0;B^d`2GZ>80BSBE08ePV02<GYL0PTEm0;R1V@3g]7d0103b[h420?:`PP050?:`P`27BGh0PdIn
0855O@15>Z001@1o@g`20813O00407a0N`1n@7X0Od5j07m2NPH0Od5j00@0Od9j07`oNP1n@GX0Od5j
1@1n@GX0101o@GX0OT5j07`oNP1n@7X507i1NP0307m1NP1n@7X0000I00D0P4Am01H0OT=l0814O@20
A7d0001L0813O01n@W`0001V07m2N`190Tl0Od9k00008@000280000U0855OP22AGh0P4An04haSP1`
AXl0PDEm0814O@0007<0mjmb0P20@g`01`0002d0000Y0?SRPP0001P0000^07doN@1n@7X00P20@WX2
0?R_K`0F0?N^K`3h/780n;1a0?N_LP24AWd0PTEm0?J^L`26B7h0n:i]0894N`21@gX0mje^08A6O@3g
[W40mji`0?R_K`3g[W00PTEm08]<OP3h/6h0QDMm08=4NP80mja[00<0n:eY0?N/J`20@WX0A@1n@GX0
1@1o@GX0P49j0893NP27Ag/0Od9j0080OT5j00D0nJ]H0?:`PP3hZE`0Od=l07m2O00207m3O00408eT
W@2>IIh0SVFN08iUWP<0SfFN00@0SfJN091VW@2QV<`0XIS;0`0000000`1ni^H0nJUG000000020?V[
DPT0n:M:00X0n:M<08Y;O@3iZU80nJYB08Y>P@3hZ5L0nJUC0?NVF`24B7l0QDUo0P29C8001`24HJ80
QD^208E;PP26Bh80QDZ10?V[E00>7I/00`3hYd/00`3hZ4/0n:Q<0?RXC0020?RXC00300D0J`3iZTl0
nJY?00/0nJY?00@0n/NB0?W8T`3oool00000C@3oool002h0oooo0P00000:0?ooo`040?kKV03Uo</0
`MS[08Md]`L0oooo00X0000307i0NP1n@7X0m;B30:jmi@2LQ;T0VW:T09E[X01:=9D0P4=m0P22AGd0
0`2hPIT0mkAm0?:_P@020?:_P@<0l[2200D0l[2308M9OP23AWh0PDEm04DjX00507m3O080P4=l00@0
O41k07i0NP1o@GX0Od9j1P1o@GX0101o@WX0O3mj07i1NP1o@GX507i1NP0407m1NP1n@GX0O3mj07i0
NPD0OT5j00<0Od5j07i0NP0001T01@20A7d01P1n@g`0P4Am07i2O03aZc@0P4=l07i2O0@0Od9k00`0
000Q00008P0002H0PDEn0895OP20A7h0CS6>0716S`21AGd0P4Am0000L`3g[g820813O0070000;@00
02T0nN:20000600002h0OCmi07i0NP020812NP80n:m_01H0mji_0?R`LP3h/740mjmb08A6O@22AGd0
mZic0?R`L@3h[Vd0PTAk0853NP3g[Fh0Q4Im0?N^L@3g[W00n:m_0?N^L022AGd0Rdan0?R`KP25Agd0
PdAj0P3g[6/00`3h[FT0mja[0812NP1507i1NP0507m1NP20@WX0PT=j08M7N`1o@WX00P1n@GX01P3c
^Y40l[220?RYG02FJ9`0REjJ08ELV`80SFBM0`2>IIh0102?IIh0X9S<0:2Hc02PV<`300000006087W
k@21i^h0mjIN0?NVGP3iZEL000000P3iZe800`2aE000n:M:0?RWBP060?RWBP0=0?RWB`2:Bgd0nJYB
0?VZDP2:CX40n:QG0?VYD`3gYU/0Q4Qo08E9O`3hYd`0RDb00040J@0208E;PP0408I;PP25BX40nJ]D
00hMV`<0n:M;00<0n:Q;0?RXC03hZ4`00P3hZ4`00`3k]e<0nJY?0?VZC`0;0?VZC`050?[7TP3ib9<0
oooo0?ooo`000000C03oool002`0oooo0P00000;0?ooo`80KLWn00<0[LG/09BVhP0n:8h01P3oool0
2`1`6D/0000307i0NP1n@7X0m;B30:[=lP2WZmX0VW:T09E[X01:=9D0P4=m0080PTEm00<0l;ZG0?Nd
O@3b[h400P3b[h420?:`PP060?FdP@3b/8<0QdUn08=6OP3]ZX@0ACZP1@1o@g`20813O00407a0N`1n
@7X0Od5j07m2NPH0Od5j00@0Od9j07`oNP1o@GX0Od5j1@1n@GX0101o@GX0OT5j07`oNP1n@7X507i1
NP0307m1NP1n@7X0Od=m00D0P4Am00H0OT=l0814O@1n@W`0lJ/d0813O00002D407m2N`0<00008@00
0280000V0855OP22AGh0P4An04haSP1`AXl0PDEm0814O@0002`0mjmb0P20@g`02@0002d0000Y0?WR
PP0001P0000^07doN@1n@7X0P49j0?BZLP020?R_K`0K0?N^K`3h/780n;1a0?N_LP24AWd0PTEm0?J^
L`3h/740n:i]0894N`21@gX0mje^08A6O@3g[W40mji`0?R_K`3g[W00PTEm08]<OP3h/6h0QDMm08=4
NP3g[6/0Q4Ek0?R]J@3g[6/0P49j04D0OT5j00D0Od5j0812NP22@gX0TdQ^07m2NP0207i1NP060?>j
T@3b/880_hnT09IXW029GYX0QEbK0P2=I9d208iUWP80WiS<0`0000001@1oiNl0n:UI0?VZE`3iZe@0
nJ]B0080mjIN00<0nJUG0?V[D`0000000P3iZe800`2kD@00n:M:0?RWBP050?RWBP0=0?RWB`2:Bgd0
nJYB0?VZDP2:CX40n:QG0?VYD`26Bh40Q4Qo08E9O`3hYd`0RDb007e6PP0208E;PP0408I;PP25BX40
QDZ100hMV`<0n:M;00<0n:Q;0?RXC03hZ4`00P3hZ4`00`3k]e<0nJY?0?VZC`0<0?VZC`040?W8T`3g
`8l0oooo000004`0oooo000/0?ooo`8000002P3oool01P0_03/0l[:60:FUeP2oe>X0ZJGB03hXSPH0
oooo00/0OT5j00000`1n@7X0OT1j0:Rki`2i`=l0SWbl0814O@21A7d0BSBE0813O@020895O@030?6`
Q03g]7d0lZn10080lZn10P3b/8801P3e]840l[2308M9OP21AGd0kJZ404DjX0D0Od=l00H0P4=l07m3
O01l@7/0OT1j07m1NP1o@WX607m1NP0407m2NP1l?gX0Od5j07m1NPD0OT5j00@0Od5j07i1NP3>m9h0
OT1j1@1n@GX00`1o@GX0OT1j0814O@040814O@0707i3O00002<0P4Am07i2O00002L0P4=l0<Z>0004
07m2N`0<00008@000280000V0855OP22AGh0P4An04haSP1`AXl0PDEm0814O@0007/0mjmb0P20@g`0
2@0002l0000Y0?WRPP0001P0000007doN@1n@7X0P49j0?BZLP020?R_K`0K0?N^K`3h/780n;1a0?N_
LP24AWd0PTEm0?J^L`3h/740n:i]0894N`21@gX0mje^08A6O@3g[W40mji`0?R_K`3g[W00PTEm08]<
OP3h/6h0QDMm08=4NP21@gX0Q4Ek08=4N`3g[6/0P49j04D0OT5j00H0Od5j0812NP22@gX0TdQ^07m2
NP1n@GX20?>jT@060?:`PP2oSj@0UVRL08UNVP25G9/0SFBM0P2NUl`02`2OUl`000000000001niNl0
ONC_0?VZF03iZeH0n:UI0?VZE`3iZe@0nJ]B0080mjIN00@0nJUG0?V[D`3iZe8000000P3iZe880?RW
BP0<08Y;O@3iZU80nJYB08Y>P@3hZ5L0nJUC08I;P@24B7l0mjEE0?RWC029C800ODJ20P25Bh801026
Bh80QDZ108E:P@1kG:<30?RWB`030?RXB`3hZ4`0n:Q<0080n:Q<00<0nkMC0?VZC`3iZTl03@3iZTl0
103g`8l0o/j=0?ooo`00001;0?ooo`00;03oool00`000000oooo000000080?ooo`070:COn`1g9eT0
l[:60:k9kP2f`>80W[3U03hXSP050?ooo`80OT5j00X0000007i0NP1n@7X0[MKf07Ven02>O;`0P4Am
0854O@1:=9D0P4=m0P22AGd00`3a/8@0mkAm0?:_P@020?:_P@80l[2200H0mKB10?:`P`3a[X<0PDEm
0>fZQ015>Z0507m3O0040813O01o@g`0O41k07i0NPL0Od5j00<0Od9j07i1NP1m@7X00P1o@GX507i1
NP0407m1NP1n@GX0c_BN07i0NPD0OT5j00<0Od5j07doN@20A7d01020A7d0101n@g`0lJ`e0814O@1n
@W`20813O0030<Z>001o@W/0OT5k0080Od9k00`0000Q0?SNNP0002H0PDEn0895OP20A7h0CS6>0716
S`21AGd0P4Am0000N`3g[g820813O0090<;>DP0002l0nN:2000060000000OCmi07i0NP20@WX0m:Yb
0080n:m_01X0mji_0?R`LP3h/740mjmb08A6O@22AGd0mZic0?R`L@3h[Vd0PTAk0853NP3g[Fh0Q4Im
0?N^L@3g[W00n:m_0?N^L022AGd0Rdan0?R`KP25Agd0PdAj0853NP24AG/0PdAk0812NTH0OT5j00h0
Od5j0812NP22@gX0TdQ^07m2NP1n@GX0c;g=0?3<[@3C/;H0_hnT09IXW02MU</0WIG;09jFc0<00000
00h0PDAm0814O@21A7d0PDEm0?VZF03iZeH0n:UI0?VZE`3iZe@0nJ]B0?J^L`3gYUh0nJUG0?V[D`80
nJ]B00<000000?V[DP2jC@001`3hYdX0302:Bgd0nJYB0?VZDP2:CX40n:QG0?VYD`26Bh40Q4Qo0?NU
E@3hYU00RDb007e6PP80QD^200D0QT^208E:P@25BX40NebS08YRW@030?RWB`D0n:Q<3`3iZTl00`3g
`8l0o/j=00000002000004X0oooo000/0?ooo`@000001P3oool0201/4T80OT5j07i0NP3b/XH0XkGU
0<7Ej@28MKP0?RR>1@3oool207i1NP0:0000001n@7X0McYh0;o3g@2T]>@0000c0814O@21A7d0BSBE
0813O@80PTEm00<0lK240?NdO@3b[h400P3b[h420?:`PP070?FdP@3b[h<0PdIn0855O@3b[h80OT9l
0813O00407m3O0040813O01l@7/0O41k07i0NPL0Od5j00<0Od9j07i1NP1m@7X00P1o@GX507i1NP04
07m1NP1n@GX0c_BN07i0NPD0OT5j00<0Od5j07doN@20A7d01020A7d0101n@g`0lJ`e0814O@1n@W`2
0813O0030<Z>001o@W/0OT5k0080Od9k00`0000Q0?SNNP0002H0PDEn0895OP20A7h0CS6>0716S`21
AGd0000_0000N`3g[g820813O0090<;>DP0002T0nN:20000;`000000OCmi07i0NP20@WX0m:Yb0080
n:m_01X0mji_0?R`LP3h/740mjmb08A6O@22AGd0mZic0?R`L@3h[Vd0PTAk0853NP3g[Fh0Q4Im0?N^
L@3g[W00n:m_0?N^L022AGd0Rdan0?R`KP25Agd0PdAj0853NP24AG/0PdAk0812NTH0OT5j00/0Od5j
0812NP2RYmX0XZOJ08bMgP2RdOP0SL7h0;K]mP2V[M`0Y:CE0:6Lc`030000000A07[SkP21A7d0PDAm
0854O@20A7d0PDAm0855O@3iZUP0nJ]F0?RYF@3iZUL0nJ]D0?V[DP3f[W<0mjIN0?VYE`3iZe<00P3i
Ze8010000000nJ]B0?V[DP2jC0060?RWBP0508Y;O@3iZU80nJYB08Y>P@3hZ5L00P3iZE<01@29C7l0
mjEE0?RVD029C800ODJ20080QD^200D0QT^208E:P@25BX40NebS00`0K@030?RWB`D0n:Q<3`3iZTl0
1@3iZU00o/j=0?ooo`3oool0000004X0oooo000[0?ooo`8000000`3oool00`000000oooo0?ooo`02
0?ooo`0906`B@P1_5dL0OT5j07i0NP3b/XH0]lWX0:O:lP12;8l0?RR>00D0oooo0P1n@GX02P000000
OT1j0?BdP`2/a^d0Zik:0000<`20A7d0PDAm04XdU@20@gd20895O@030?6`Q03b[h40lZn10080lZn1
0P3b/8801`3e]840QdUn08=6OP21AGd0lZn207m3O020@g`00`1o@g`20813O00407a0N`3^/cL0Od5j
07m2NPH0Od5j00<0Od9j07`oNP1m@7X00P1o@GX507i1NP0307m1NP1n@GX0OT1j00H0OT5j00<0Od5j
07doN@20A7d01020A7d0101n@g`0000W0814O@0005`20813O0030<Z>001o@W/0OT5k0080Od9k00`0
000Q0?SNNP000280PDEn0895OP20A7h0CS6>0855O@20A7d0000_0000N`21@g`20813O0090000;`00
02T0nN:20000;`000000OCmi07m1NP20@WX0m:Yb0080n:m_0P3h/780603h/740mjmb08A6O@22AGd0
mZic0?R`L@3h[Vd0PTAk0853NP3g[Fh0Q4Im0?N^L@3g[W00n:m_0?N^L022AGd0Rdan0?R`KP25Agd0
PdAj0853NP24AG/0PdAk0812NTD0OT5j00T0XI[>0:6Nd@2RX]D0Y/Sa0:C8l`2JfOd0XZcN0::]g`2S
[]l00`0000000`1og?`0PDAm0854O@040854O@0=0814O@21A7d0PDEm0?VZF03iZeH0l:n60?VZE`3i
Ze@0nJ]B0?J^L`3gYUh0nJUG0?V[D`030?V[DP040000003iZe80nJ]D0;]<00D0n:M:00`0RT]m0?VZ
DP3iZU80RTj108E9P@26BX40nJUC08U<O`3gYED0n:I@08U<P01mAX8208E;PP0508I;PP25BX40QDZ1
07]LX`0<06d00`3hYd/00`3hZ4L0n:Q<0?RXC0020?RXC0030?VZD03iZTl0nJY?00`0nJY?00H0nJY@
0?VZC`3hbIT0o]JB0?ooo`0000190?ooo`00:`3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`1o@GX00P1n@GX01P1n@7X0l[:60;o2g02ZYM40@Rb?0000NP@0oooo00<0000007i1
NP1n@GX00P1n@7X02`3d]8<0/lGX0007Q00003<0P4Am0854O@1:=9D0P4=m0895O@3_[HD0lK2400@0
lZn10P3b/8801@3b/8<0QdUn08=6OP21AGd0000800D0Od=l0P20@g`0101l@7/0k[<g07m1NP1o@WX6
07m1NP0307m2NP1l?gX0OD1j0080Od5j1@1n@GX00`1o@GX0OT5j07i0NP0607i1NP0307m1NP1m?gT0
P4Am00@0P4Am00@0OT=l0814O@20A7d0001L0P20@g`00`3:SP00Od9k07i1N`0207m2N`0<0?WNO000
02D0PDEn0855OP22AGh0P4An04haSP21AGd0P4Am0000;`0007/0PD=l0P20@g`02@2mbdh0000Y0?WR
PP0002l0;P1907i0NP1o@GX0P49j0?BZLP020?R_K`80n;1b01P0n;1a0?N_LP3f[W<0PTEm0?J^L`3h
[V`0n:i]0894N`21@gX0n:m`08A6O@22AG`0mji`0?R_K`3g[W00PTEm08]<OP3h/6h0QDMm08=4NP21
@gX0Q4Ek08=4N`20@WY307i1NP040:2Hc@2PV<`0[/O/0:k7k080Y^Ok00<0Y:cL0:>Ue`0000000P00
00040855O@H0PDAm00d0P4Am0854O@21AGd0nJYH0?V[EP3`[hH0nJYG0?V[E03iZe80mZic0?NVGP3i
ZEL0nJ]C00@0nJ]B00<000000?V[E02kC0001@3hYdX03`2:Bgd0nJYB0?VZDP2:CX40QDV108I:P@3i
ZE<0RDao0?NUE@3hYU00RDb007e6PP24HJ80QD^208I;PP0208E:P@0307]LX`0<06d0n:M;0080n:M;
00<0n:Q70?RXC03hZ4`00P3hZ4`00`3iZU00nJY?0?VZC`0<0?VZC`040?VZD03iZTl0mlVJ0?kFTP80
oooo00<000000?ooo`3oool0AP3oool001l0oooo1`0000050?ooo`030000003oool0oooo00@0oooo
00`000000?ooo`3oool0Od5j0000001n@GX0OT1j0?:bQP2gbNP0Jjcg048/S`0k9Xd40?ooo`030000
001n@GX0OT5j0080OT1j00/0m;B30;k1g02f`>80000c0814O@21A7d0P4=m0854O@22AGd0kjf50?6`
Q0040?:_P@80l[2200D0l[2308M9OP23AWh0PDEm04DjX00507m3O080P4=l00@0O41k07i0NP1o@GX0
Od9j1P1o@GX00`1o@WX0O3mj07e0NP0207m1NPD0OT5j00<0Od5j07i1NP1n@7X01P1n@GX00`1o@GX0
000I0814O@040814O@0407i3O020A7d0P4Am0000G080P4=l00<0bXh007m2N`1n@G/00P1o@W/0303i
gW`0000U0855OP21AGh0PTEn0814OP0002/0PDEm0814O@0002l0001k0853O080P4=l00T0_L]>0000
:@0002`0000_07doN@1n@7X0Od5j0812NP3dZW800P3h[fl20?R`LP050?R`L@3g[g80mZic0895O@3f
[W<00P3h[Vd04@22A7/0PD=j0?R_L024AWd0PTEl0?N^L024Agd0mji`0895O@3h[fh0n;1^08E7O@23
A7X0PD=j08A5N`23A7/0P49j0400OT5j0`2PV<d01@2U`nh0Y/?^07WTj@20A7d0PDAm00<0000000<0
Z]_h0855O@21AGd01021AGd60854O@0=0814O@21A7d0YgFK0?VZF03iZeH0l:n60=:JW03iZe@0nJ]B
0?J^L`3gYUh0nJUG0?V[D`050?V[DP030000003iZe@0_4d000@0n:M:00l0RT]m0?VZDP3iZU80RTj1
08E9P@26BX40nJUC08U<O`24B7l0QDUo08U<P01mAX80Q66R08E;PP26Bh800P25BX400`0806`03QfK
0?RWB`020?RWB`030?RXA`3hZ4`0n:Q<0080n:Q<00<0nJY@0?VZC`3iZTl0303iZTl0103iZU00nJY?
0?VZC`3neY820?ooo`030000003oool0oooo04H0oooo000R0?ooo`030000003oool0oooo00H0oooo
0P0000060?ooo`80000000T0Od5j0000001n@GX0OT1j0<33g02/`NT0R7:d048/S`0k9Xd0103oool0
0`000000OT5j00000`0207i0NP070?BdP`2X_NP0_l7K0000<`20A7d0PDAm0813O@020895O@030>n]
Q@3g]7d0lZn10080lZn10`3b/8801@3b/8<0QdUn08=6OP3]ZX@0ACZP00D0Od=l0P20@g`0101l@7/0
OT1j07m1NP1o@WX607m1NP0407m2NP1l?gX0OT5j07m1NPH0OT5j00<0Od5j07`oNP1n@7X01@1n@GX0
0`1o@GX0OT1j00006@050814O@0407i3O020A7d0P4Am0000G080P4=l00L0bXh007m2N`1n@G/0Od9k
07i1NP3igW`0000U0080PDEn01<0PTEn0814OP0002/0PDEm0814O@0002l0001k0853O020@g`0000]
0;g;CP0002T0000/0000;`1m?gT0OT1j07m1NP20@WX0m:Yb0080n:m_0P3h/780603h/740mjmb0?J^
L`22AGd0mZic0?R^K@3g[Vd0PTAk0853NP3h[g00Q4Im0895O026B7d0Q4Mm0?N^L022AGd0n:m^0?R`
KP25Agd0PdAj0853NP24AG/0PdAk0812NSd0OT5j0`2OV<d20:G2kP0307cTk@3i[Ed0PDEm00<00000
1021A7d60855O@<0PDAm00L0SF2I08aPV@2<H9T0RUnJ08aRW@2WMI/0nJYH0080l:n600L0dYZL0?:i
TP3iZe80mZic0?NVGP3iZEL0nJ]C00D0nJ]B00@000000?V[E03iZEL0_Dh00`3hYdX03`2KD740nJYB
0?VZDP2:CX40QDV10?RXE`3iZE<0mjIK08A8O`25BGl0RDb007e6PP24HJ80QD^208I;PP0208E:P@03
00P0K00>7I/0n:M;0080n:M;00<0n:Q;0?RXC03hZ4`00P3hZ4`00`1Y<WT0nJY?0?VZC`0<0?VZC`04
0?VZD03iZTl0nJY?0?VZC`<0oooo00<000000?ooo`3oool0A@3oool00280oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`090000001o@GX0000007i1NP3b/XH0Z/?/09g4l`28
L[@0@Rb?00D0oooo00<0000007i1NP0000<00P1n@7X01`1iZO80YkcX0:Rlj020A7d0PDAm04XdU@20
@gd00P22AGd00`3a/8@0mkAm0?:_P@020?:_P@80l[2200H0mKB10?:`P`27BGh0PdIn0>fZQ015>Z05
07m3O080P4=l00@0O41k07i0NP1o@GX0Od9j1P1o@GX0101o@WX0O3mj07i1NP1o@GX507i1NP0407m1
NP1n@GX0O3mj07i0NPD0OT5j00<0Od5j07i0NP0001T01@20A7d0101n@g`0P4Am0814O@0005`20813
O0070000:@1o@W/0OT5k07m2N`1n@GX0nMil00009@030855OP0B0000<@0002/0PDEm0814O@0002l0
mjmb0853O020@g`0000]0;g;CP0002T0000/0000;P1m?gT0OT1j07m1NP20@WX0m:Yb0P3h[fl20?R`
LP030?R`L@3g[g80mZic0080mZic00T0n:i]0?N^K@3f[6l0PD=j0?R_L024AWd0PTEl08I8O@24Agd0
0P3g[W00203h[fh0n:m_08E7O@23A7X0PD=j08A5N`23A7/0P49j>P1n@GX309nHc@80YL;^0P1li>h0
103iZel000000000000000020814O@D0PDAm1P21AGd308iQV@0@08ePV@2<H9T0S62I08YOVP2<HYd0
YgFK0?2hT`3_c[00l:n60=:JW03b^I80o/f;0?J^L`3gYUh0cYJJ0?V[D`D0nJ]B00D0nJ]D0000003i
ZEL0nJUG0;i?00020?RWBP0309]@L@3iZU80nJYB0080RTj100T0n:QG0?VYD`3gYU/0Q4Qo08E9O`29
C800ODJ208AQXP25Bh800P26Bh800`25BX40201/00hMV`030?RWB`030?RXB`3hZ4`0n:Q<0080n:Q<
00<0JC9i0?VZC`3iZTl0303iZTl01@3iZU00nJY?0?VZC`3iZTl0SUJ900<0oooo00<000000?ooo`3o
ool0A03oool00280oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`090000
001o@GX0000007i0NP3b/XH0]l3Q0;32i`1G=hl0cXH000D0oooo00<0000007i1NP0000000P1n@7X0
1`2P^^/0NJcc0:Nmj@20A7d0PDAm04XdU@20@gd00P22AGd00`3a/8@0mkAm0?:_P@020?:_P@80l[22
00H0mKB10?:`P`27BGh0PDEm0>fZQ015>Z0507m3O080P4=l00@0O41k07i0NP1o@GX0Od9j1P1o@GX0
101o@WX0O3mj07i1NP1o@GX507i1NP0407m1NP1n@GX0O3mj07i0NPD0OT5j00<0Od5j07i0NP0001T0
1@20A7d05P1n@g`0P4Am0814O@0005`0P4=l07i2O00002T0Od9k0<W=D01o@W/0OT5j00008P0002D0
PDEn0895OP21AGh0000a0000:`21AGd0P4Am0000L`3g[g820813O00:0000;@2mbdh0n>:20000;000
02h0OCmi07i0NP1o@GX0P49j0?BZLP80n:m_0P3h/7800`3h/740mjmb0?J^L`020?J^L`090?R^K@3g
[Vd0mZa_0853NP3h[g00Q4Im0895O026B7d0Q4Mm0080mji`00P0n:m^0?R_K`25Agd0PdAj0853NP24
AG/0PdAk0812NSL0OT5j102OV<d20:G2kP0307cTkP20A7d0P4Am0080000000<0nJaN0?V]G@21AGd0
0P20A7d50854O@@0PDEm00<0Sf:J08iRVP2>HYT00P2>HIT01@2=H9T0S62I08aPV@2:GiX0S6:M0080
`k?:00H0klj`0=:`]`3BVY`0nlRA0?k=R`3f[W<20<jFVP030?2gTP3iZe80nJ]B00<0nJ]B0P3iZe@0
0`000000nJUG0;i?00020?RWBP0=09]@L@3iZU80nJYB0?VZDP2:CX40n:QG0?VYD`3gYU/0Q4Qo08E9
O`29C800ODJ208AQXP0208E;PP0408I;PP25BX40nJ]D00hMV`<0n:M;00<0n:Q;0?RXC03hZ4`00P3h
Z4`00`1Y<WT0nJY?0?VZC`0<0?VZC`050?VZD03iZTl0nJY?0?VZC`2>EXT00`3oool00`000000oooo
0?ooo`140?ooo`005P3oool6000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`0:0000001o@GX0OT5j07i0NP3b/XH0Xk_[0;o2g01G=hl0?RR>0>b:?P@0oooo0P1n@GX0
2P000000OT1j07LjN03;`m<0X;c/09jlk@20A7d0PDAm04XdU@20@gd20895O@030?6`Q03g]7d0lZn1
0080lZn10P3b/8801P3e]840lZn30?6^P`21AGd0kJZ404DjX0D0Od=l00@0P4=l07m3O01l@7/0OT1j
201o@GX0101o@WX0OD1j07m1NP1o@GX507i1NP0407m1NP1n@GX0c_BN07i0NPD0OT5j00<0Od5j07i0
NP1o@gd01@20A7d05P1n@g`0P4Am0814O@0005`0P4=l07i2O00002T0Od9k0<W=D01o@W/0OT5j0000
8P0002H0PDEn0895OP21AGh0000a0000:`21AGd0P4Am0000L`3g[g820813O00:0000;@2mbdh0n>:2
0000;00002h0OCmi07i0NP1o@GX0P49j0?BZLP80n:m_0P3h/7800`3h/740mjmb0?J^L`020?J^L`09
0?R^K@3g[Vd0mZa_0853NP3h[g00Q4Im0895O026B7d0Q4Mm0080mji`00P0n:m^0?R_K`25Agd0PdAj
0853NP24AG/0PdAk0812NSD0OT5j0P2OV<d30:G2kP0307cTkP000500P4Am00<0000000D0PDEm0?V[
G`3i[5h0nJeM0855O@020814O@D0PDAm00L0PDEm08mSV`2?Hi/0Sf>J08mRVP2>HYX0SV:I0080SV6I
0100SF2I0:2Md@2OWM80WIcC08ZCeP2Nd?T0[>gh0=[Tg@2Y]n@0Rkgg0<WChP3jaXl0l<^/0<^T/P3>
UYX0l;NB1@3iZe820?V[E0060000003iZEL0nJ]A0;i@003hYdX0Ve1a0`3iZU802@2:CX40n:QG0?VY
D`3gYU/0Q4Qo08E9O`29C800ODJ20040J@0208E;PP0408I;PP25BX40nJ]D00hMV`<0n:M;00<0n:Q;
0?RXC03hZ4`00P3hZ4`00`0506/0nJY?0?VZC`0<0?VZC`050?VZD03iZTl0nJY?0?VZC`2>EXT00P3o
ool3000004D0oooo000R0?ooo`030000003oool0oooo00D0oooo0P0000080?ooo`0;07m1NP1n@GX0
OT5j07i0NP3b/XH0a/;F0:Blj`1G=hl0?RR>0>b:?P1n[o<00`3oool207i1NP0:0000001n@7X0m;B3
0>VkX`3Ae=/0V<3c0814O@21A7d0BSBE0813O@80PTEm00<0lK240?NdO@3b[h400P3b[h420?:`PP06
0?FdP@3b[h<0lJj30855O@3b[h80ACZP1@1o@g`01020@g`0Od=l07a0N`1n@7X707m1NP0307m2NP1n
@GX0OD1j0080Od5j1@1n@GX0101o@GX0OT5j0<kdWP1n@7X507i1NP0307m1NP1n@7X0Od=m00D0P4Am
01H0OT=l0814O@20A7d0001L0813O01n@W`0000Y07m2N`190Tl0Od9k00008@000280000V0855OP22
AGh0PDEn0000<@0002/0PDEm0814O@0007<0mjmb0P20@g`02P0002d0_L]>0?SRPP0001P0000^07do
N@1n@7X0Od5j0812NP3g[Vl20?R_K`80n;1b00<0n;1a08A6O@3f[W<00P3f[W<02@3h[Vd0mji]0?J/
K`21@gX0n:m`0?N^L@22AG`0QTQm08A7O@020?N^L0080?R_KP3h[fl0QDMm08=4NP21@gX0Q4Ek08=4
N`20@WXa07i1NP@0WiS=00D0YL;^07cTkP1li>h0PDEm0854O@03000000080854O@20A7d0P4Am0855
O@3iZel0nJaN0?V]G@21AGd20814O@<0PDAm0P2>Hi/308mSV`0508mSVP2?HYX0SV:J08iRV@2RWM00
0P2QWM002P2QWM40Y<Sb09_Oo@2T`>h0W/Kd0:74l@2G`O@0IjWg096nm@2<ao/20?3;[0040<^T/P3>
UYX0l;NB0?_9T@@0nJ]B0P3iZe@01P3iZEL000000?V[D@3iZU<0_U0009]@L@<0nJYB00T0RTj10?RX
E`3iZE<0mjIK08A8O`25BGl0RDb007e6PP0106T00P25Bh801026Bh80QDZ10?V[E00306/30?RWB`03
0?RXB`3hZ4`0n:Q<0080n:Q<00<0nkMC0?VZC`3iZTl0303iZTl01@3iZU00nJY?0?VZC`3iZTl0SUJ9
00@0oooo00<000000?ooo`3oool0@`3oool00280oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`0>07m1NP1n@GX0OT5j07i0NP3b/XH0j;ZU0<K2eP1G=hl0?RR>0?2^Q@3/R3X0
OZoc0?ooo`00000207i1NP80OT1j00P0m;B30>VkX`3/_jH000000814O@21A7d0BSBE0813O@80PTEm
00<0lK240?:_P@3b[h400P3b[h420?:`PP070?FdP@3b[h<0PdIn0855O@3b[h80OT9l0813O00407m3
O0040813O01o@g`0O41k07i0NPL0Od5j00<0Od9j07i1NP1m@7X00P1o@GX507i1NP0407m1NP1n@GX0
c_BN07i0NPD0OT5j00<0Od5j07doN@20A7d01@20A7d01`1n@g`0P4Am07i2O03aZc@0P4=l07i2O000
02T00`1o@W/030000240000R00009P21AGh0PTEn0855OP000340000[0855O@20A7d0001c0?N_LP80
P4=l00X0000]0000:@3hhX80000H0000;P1m?gT0OT1j07m1NP20@WX0mji_0P3h[fl20?R`LP030?R`
L@24AWd0mZic0080mZic00P0n:i]0?N^K@3f[6l0PD=j0?R_L03g[W40PTEl08I8O@<0mji`00P0n:m^
0?R_K`25Agd0PdAj0853NP24AG/0PdAk0812NRl0OT5j0`2OV<d20:G2kP0307gTk`21AGd0PDEm00<0
000000@0Od=m0000D020A7d0PDAm0P20A7d01@21AGd0nJ]O0?:eR`3i[Ed0PDEm0080P4Am00<0PDAm
08eRV`2=HY/00P2>Hi/308mSV`0408mSVP2QV/d0XI[=0::Md080Y/Oa0P2Og_`0402V/>00YK?R0:k1
j02`d?40YlC^0:B/g@2P/nH0NJoe09c9m`2cdNl0d/cD0:Nag`33/LP0oM2B0?_9T@3jai030?V[DP80
nJ]D0P3iZEL010000000nJYC08]>P@2KD7430?VZDP0908Y>P@3hZ5L0nJUC0?NVF`24B7l0QDUo0?RW
C025Bh<0ODJ20080QD^200@0QT^208E:P@3iZe@00`1[103hYd/40?RXC0030?^gD`3iZTl0nJY?0100
nJY?00<0SUJ90?ooo`3oool00`3oool00`000000oooo0?ooo`120?ooo`00803oool3000000L0oooo
00<000000?ooo`3oool01`3oool0101o@GX0000007i1NP1n@7X30>RjY@0705LgS`0007X0l:j50?2^
Q@3[QcT0OZoc0000000207i1NP80OT1j00/0m;B30?75Y03/_jH0000c0814O@21A7d0BSBE0813O@22
AGd0kjf50?6`Q0040?:_P@80l[2200L0l[2308M9OP23AWh0PDEm0?:_PP1o@g`0P4=l00@0Od=l00D0
P4=l07a0N`1l@7/0Od5j07m2NP0607m1NP0307m2NP1n@GX0OD1j0080Od5j1@1n@GX0101o@GX0OT5j
0<kdWP1n@7X507i1NP0307m1NP1m?gT0P4Am00D0P4Am00L0OT=l0814O@1n@W`0lJ/d0813O01n@W`0
000Y00<0Od9k00`0000Q00008P0002H0PDEn0895OP21AGh0000a0000:`21AGd0P4Am0000L`3g[g82
0813O00:0000;@0002T0n>:20000600002h0OCmi07i0NP1o@GX0P49j0?N^K`80n:m_0P3h/7803@3h
/740Q4Im0?J^L`3f[W<0QTQn0?R^K@3g[Vd0mZa_0853NP3h[g00mjia0?N^L03h[fl00`3g[W00203h
[fh0n:m_0?N^L023A7X0PD=j08A5N`23A7/0P49j;01n@GX309nHc@80YL;^00<0ONC_0854O@21A7d0
0`0000020855O@050854O@1o@gd0001@0814O@21A7d00P20A7d01`2gP9T0nJ]O0?:eR`3i[Ed0_XbP
09EVV@27FiL00`2=HY/208iSV`80Sf>K00d0Wi;609nCa`2QU/X0[/K/0:GLn`2VZ]T0YZ_K0:J`g`2X
^^H0Z[cV0:kTn@2Vho/0nJaI0080XkWY0P2mc>H01P2Q`Nl0X[c[0:Bkj@1ZY_@0TK[c0<ONjP80n/N@
00<0n/J@0?V[DP3iZe800P3iZe@20?VYE`040?V[D@000000Rdj10:Ho00<0nJYB00T0RTj10?RXE`3i
ZE<0mjIK08A8O`25BGl0n:I@08E;P`1mAX800P25Bh801@26Bh80QDZ108E:P@1kG:<0301]00<0n:M;
103hZ4`00`3k]e<0nJY?0?VZC`0=0?VZC`040?VZD03iZTl0nJY?08iFR@H0oooo00<000000?ooo`3o
ool0@@3oool00280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`050000
001o@GX0000007i1NP1n@7X00`3X^ZD00`12;8l0>bJ=0?2^Q@020?2^Q@040>b8>@000000OT5j0000
0`80OT1j00/0m;B30?2`Q`26BX00000c0814O@21A7d0P4=m0854O@22AGd0kjf50?6`Q0040?:_P@80
l[2200L0l[2308M9OP23AWh0PDEm07XnN`1o@g`0P4=l00<0Od=l0P20@g`0101l@7/0k[<g07m1NP1o
@WX607m1NP0307m2NP1l?gX0OD1j0080Od5j1@1n@GX00`1o@GX0OT5j07i0NP0607i1NP0307m1NP1m
?gT0P4Am00D0P4Am00L0000S0814O@1n@W`0000W0813O01n@W`0001V00<0Od9k00`0000Q0?SNNP00
02H0PDEn0895OP21AGh0000a0716S`21AGd0P4Am0000L`3g[g820813O00<0000;`0002T0n>:20000
60000000OCmi07i0NP1o@GX0P49j0?N^K`3h[fl0mji_0P3h/7801`3h/740Q4Im0?J^L`3f[W<0QTQn
0?R^K@22A7/00P21@gX0103h[g00mjia0?N^L03h[fl30?N^L0080?R`KP3h[fl0mji`08=4NP21@gX0
Q4Ek08=4N`20@WXY07i1NP<0WiS=0P2U`^h207gTk`040854O@0000000000000000D0PDEm00h0PDAm
07m3O@000500P4Am09I[WP2EJId0PUbL095WWP3iZel0l[F;0?V]G@2nS:00UFJI08MKU`<0SF:K00@0
SV>K09jBa`2NT/L0Wi;60P2Y`>X0502UkOT0V>oc09kQo@2W/Ml0ZK?O0;SMl`3iZe`0n:i/0?>SJ03i
ZU`0nJaI0?V[F@3i[5T0R4^00?VZG02I_O40Z;WU08^elP2ha^D0N:gd0P3;d=d0103jai00n/J@0?V[
DP3iZe820?V[E080nJUG00@0nJ]A0000002;CX40nJUG0`3iZU802@2:CX40n:QG0?VYD`3gYU/0Q4Qo
0?NUE@3hYU00RDb007e6PP0208E;PP0508I;PP25BX40QDZ107]LX`0<06d00`3hYd/01@3hZ4L0n:Q<
0?RXC03hZ4`0nkMC00l0nJY?00D0nJY@0?VZC`3iZTl0SUJ907ZVk`050?ooo`030000003oool0oooo
0440oooo000Z0?ooo`8000001`3oool01P000000Od5j0000001n@GX0l[:60>n_R080j;ZU00<0@Rb?
0?2^Q@3`[XD00`3`[XD00`000000OT5j00000`0207i0NP0;0?2_Q`3`/8L0QTZ00000<`20A7d0PDAm
0813O@21A7d0PTEm0>n]Q@3g]7d00`3b[h430?:`PP050?:`P`27BGh0PdIn0>fZQ00000P01@1o@g`2
0813O00407a0N`3^/cL0Od5j07m2NPH0Od5j00<0Od9j07`oNP1m@7X00P1o@GX507i1NP0307m1NP1n
@GX0OT1j00H0OT5j00<0Od5j07doN@20A7d01020A7d02@1n@g`0lJ`e0814O@1n@W`0000W0813O01n
@W`0Od9k07i1N`0207m2N`0<00008@3hgWX0000V0855OP22AGh0PDEn0000:@1`AXl0PDEm0814O@00
07<0mjmb0P20@g`03032cU80000Y0?WRPP0001P0000007doN@1n@7X0Od5j0812NP3g[Vl0n:m_0?N^
K`80n;1b00L0n;1a08A6O@3f[W<0mZic08I8OP3h[Vd0PTAk0080PD=j00@0n:m`0?N^L@3g[W00n:m_
0`3g[W00203h/6h0n:m_0?N^L023A7X0PD=j08A5N`23A7/0P49j9P1n@GX309nHc@80YL;^00<0ONC_
0854O@21A7d00`0000030854O@D0PDEm00P0PDAm07m3O@000500PebM09I[WP2EJId0PUbL095WWP80
l[F;00P0djb`0;j<X02EIYT0Qe^G08eRV`2MTLL0WY7709jBa`80Y[k[00<0Q>Kc08GVm022AWl01@22
AWl20?V[G00?0?R^K03cXfP0nJYL0?V/F@3iZeT0nJaI08Q;P03iZU`0nZaF07b[l@2^`nT0_<[T07j^
l`2M_o00c=3M00<0n/J@00<0nJ]B0?V[E03iZe@00P3iZEL0103iZe40nJYC0000003iZEL30?VZDP09
08Y>P@3hZ5L0nJUC0?NVF`24B7l0mjEE0?RVD029C800ODJ20080QD^200D0QT^208E:P@25BX40NebS
00`0K@030?RWB`030?RXA`3hZ4`0n:Q<0080n:Q<3`3iZTl01@3iZU00nJY?0?VZC`2>EXT0_e@000H0
oooo00<000000?ooo`3oool0@03oool002T0oooo0P0000080?ooo`050000001o@GX0OT5j07i0NP3b
/XH00P3_[hP00`3X^ZD0@Rb?0?2^Q@040?2^Q@0<0000001n@GX0000007i1NP1n@7X0l:n70?2`Q`26
BX00P4Am0854O@1h?G/0P4=m0P22AGd00`3a/8@0mkAm0?:_P@020?:_P@80l[2200H0mKB10?:`P`27
BGh0PdIn0>fZQ015>Z0507m3O080P4=l00@0O41k07i0NP1o@GX0Od9j1P1o@GX0101o@WX0O3mj07i1
NP1o@GX607i1NP0307m1NP1n@GX0OT1j00H0OT5j00<0Od5j07doN@20A7d01020A7d02@1n@g`0000W
0814O@1n@W`0000W0813O00002D0Od9k07i1N`0207m2N`0<0?WNO03hgWX0000V0855OP22AGh0P4An
04haSP1`AXl0PDEm0814O@0002`0mjmb0P20@g`03032cU80000Y0?WRPP0001P0000007doN@1n@7X0
Od5j0812NP3g[Vl0n:m_0?N^K`80n;1b00L0n;1a08A6O@3f[W<0mZic08I8OP3h[Vd0PTAk0080PD=j
00@0n:m`0?N^L@3g[W00n:m_0`3g[W00203h/6h0n:m_0?N^L023A7X0PD=j08A5N`23A7/0P49j8`1n
@GX409nHc@80YL;^00<0ONC_0854O@21A7d00P0000060854O@D0PDEm0100PDAm07m3O@000580PebM
09I[WP2EJId0PUbL0:NXe`3@^<80h]O<0=>//02nS:00WI3509b>a@2LSlH0WI760P2U_N/00`25i_D0
PTIo0896O`070896O`80nJ]L00P0n:i/0?>SJ03iZU`0nJaI0?V[F@3i[5T0R4^00?VZG080nZaF00H0
Nj[a0:jhh@2k`n00Pk3b09nok`3;cM`20?[6T0090?_6S03iZe@0nJ]D0=BHUP3iZEL0nJ]A0?VZD`2;
CX40000000<0nJYB00T0RTj10?RXE`3iZE<0mjmb08U<O`3gYED0n:I@08U<P01mAX800P25Bh801@26
Bh80QDZ108E:P@1kG:<0301]00<0n:M;00<0n:Q70?RXC03hZ4`00P3hZ4`?0?VZC`060?VZD03iZTl0
nJY?0?VZDP3gYeh0NJK_1P3oool00`000000oooo0?ooo`0o0?ooo`00:@3oool00`000000oooo0?oo
o`070?ooo`80Od5j00<0OT5j07i0NP3b/XH00`3_[hP00`3>QP00l:j50?2^Q@030?2^Q@80OT5j00X0
000007i0NP1g>WP0l:n70?2`Q`26BX00P4Am0854O@1:=9D0P4=m0P22AGd00`3a/8@0mkAm0?:_P@02
0?:_P@80l[2200H0mKB10?:_P`27BGh0PDEm0>fZQ015>Z0507m3O080P4=l00@0O41k07i0NP1o@GX0
Od9j1P1o@GX0101o@WX0O3mj07i1NP1o@GX607i1NP0307m1NP1l?gX0OT1j00H0OT5j00<0Od5j0000
6@20A7d01020A7d02@1n@g`0000W0814O@1n@W`0000W0813O03:SP00Od9k07i1N`0207m2N`0<0?WN
O03hgWX0000R0855OP22AGh0P4An04haSP1`AXl0PDEm0814O@0002l0mjmb0P20@g`01`32cU80000Y
0?WRPP0001P0000007doN@1n@7X00P20@WX20?R_K`050?N^K`3h/780n;1a0?R`L@24AWd00P3f[W<0
0`26B7h0n:i]0894N`020853NP040?R_L03g[W40mji`0?R_K`<0mji`00P0n;1^0?R_K`3g[W00PdAj
0853NP24AG/0PdAk0812NR40OT5j0P2OV<d20:G2kP80ONC_0P21A7d3000000P0PDAm1021AGd209IX
VP03075=U`1B?Y/0PebM0080[:_F00H0SiSH0:OBmP2?`OP0`^ka0:^`g02XY=820::kjP80QNGe3022
AWl20?V[G0080?R^K03cXfP0nJYL0?V/F@3iZeT0nJaI08Q;P03iZU`20?Z/EP80S:c[0P36e>D20::i
j@030<g9eP3jai00nlJ<0080nJ]D00L0e9RF0?VYE`3iZe40nJYC08]>P@3iZEL000000080nJYB00T0
RTj10?RXE`3iZE<0mjmb08U<O`24B7l0QDUo08U<P01mAX800P25Bh801@26Bh80QDZ108E:P@0806`0
301]00<0n:M;00<0n:Q70?RXC03hZ4`00P3hZ4`00`3iZU00nJY?0?VZC`0<0?VZC`070?VZD03iZTl0
nJY?0?VZC`2>EXT0n:M;07VUk`050?ooo`030000003oool0oooo03l0oooo000Y0?ooo`030000003o
ool0oooo00L0oooo00D0Od5j07i1NP1n@GX0OT1j0?:bQP020>n_R00305LgS`0n:8h0l:j500@0l:j5
0P1n@GX02P3kfJ00OT1j0?BdP`3`[hL0l;2708I:P020A7d0PDAm04XdU@20@gd20895O@030?6`Q03g
]7d0lZn10080lZn10P3b/8801P3e]840lZn30?6^P`21AGd0kJZ404DjX0D0Od=l0P20@g`00`1l@7/0
OT1j07m1NP0707m1NP0407m2NP1l?gX0OT5j07m1NPD0OT5j00@0Od5j07i1NP1l?gX0OT1j1@1n@GX0
0`1o@GX0OT1j00006@050814O@0407i3O00002L0P4Am07i2O080P4=l00L0bXh007m2N`1n@G/0Od9k
07i1NP3igW`0000U0080PDEn00P0PTEn0814OP1><Hh0L4J?0855O@0002/0000_0?N_LP80P4=l00L0
`/iB0000:@3ihX80000H0000001m?gT0OT1j0080P49j0P3h[fl01@3g[Vl0n;1b0?R`L@3h/780Q4Im
0080mZic00<0QTQn0?R^K@22A7/00P21@gX0103h[g00mjia0?N^L03h[fl30?N^L0080?R`KP3h[fl0
mji`08=4NP21@gX0Q4Ek08=4N`20@WXM07i1NP@0WiS=0P2U`^h00`1mi>l0PDAm0854O@03000000/0
PDAm0P21AGd0402?I9`0SfBK099VV`2FJ9X0LDfG058nV`0GB/D0Sl7g09oWo02>f?l0YK;R0:>bh`2P
^>X0V[K/08?KoP2;f?l?0896O`0:0;1jV03iZe`0n:i/0?>SJ03iZU`0nJaI0?V[F@3i[5T0R4^00?VZ
G080nZaF0P3iZeP20?RYG00507N/l`2V^^L0IJ;c0=K>dP3kaH/00P3iZe@01`3DV9H0nJUG0?V[D@3i
ZU<0Rdj10=JIU00000000P3iZU80302:CX40n:QG0?VYD`3g[g80RDao08A8O`25BGl0RDb007e6PP24
HJ80QD^208I;PP80QDZ100<0201/00hMV`3hYd/00P3hYd/00`3hZ4/0n:Q<0?RXC0020?RXC0030?VZ
D03iZTl0nJY?00`0nJY?00L0nJY@0?VZC`3iZTl0nJY?08iFR@3hYd/0`EH000@0oooo00<000000?oo
o`000000@03oool002T0oooo0P0000080?ooo`0507m1NP000000OT5j07i0NP3b/XH00P3_[hP00`1G
=hl0?RR>0?2^Q@030?2^Q@030000001n@GX0OT5j0080OT1j00P0m;B30?2_Q`3`/8L0QTZ00814O@21
A7d0BSBE0813O@80PTEm00<0lK240?NdO@3b[h400P3b[h420?:`PP060?FdP@3b[h<0lJj30855O@3b
[h80ACZP1@1o@g`01020@g`0Od=l07a0N`1n@7X807m1NP0407m2NP1m@7X0OT5j07m1NPD0OT5j00@0
Od5j07i1NP3>m9h0OT1j1@1n@GX00`1o@GX0OT1j00006@050814O@0407i3O00002L0P4Am07i2O080
P4=l00L0bXh007m2N`1n@G/0Od9k07i1NP3igW`0000U0080PDEn00D0PTEn0814OP1><Hh0L4J?0855
O@020000;`0<0?N_LP20@g`0P4=l0<;>DP0002T0nN:2000060000000OCmi07i0NP20@WX0m:Yb0P3h
[fl02P3g[Vl0n;1b0?R`L@3g[g80Q4Im0895O@3f[W<0n;1a0?R^K@22A7/20853NP040?R_L03g[W40
mji`0?R_K`<0mji`00P0n;1^0?R_K`3g[W00PdAj0853NP24AG/0PdAk0812NQ/0OT5j0`2OV<d20:G2
kP0307gTk`21A7d0PDAm00<000003P21A7d308mTW00;08mTV`2BIY/0UVRJ075=U`1B?Y/0CU:f09jU
f`2U/N40YK_X0:Fjj02Ng?d04`22AWl02P2`NYP0nJ]L0?R^K03cXfP0nJYL0?6dS03iZeT0nJaI08Q;
P03iZU`20?Z/EP80nJ]H0P3hZE`06`3i[5D0EYO`0:RojP2Z`n`0nLF@0?7:Z@3?YZh0e9RF0>jcT03m
cHh0nJYC08]>P@3FVI@0k[:@0000003iZU80RTj10?RXE`3iZE<0mjmb08U<O`24B7l0QDUo08U<P01m
AX80Q66R08E;PP0208I;PP0308E:P@0806`03QfK00<0n:M;00<0n:Q;0?RXC03hZ4`00P3hZ4`00`1Y
<WT0nJY?0?VZC`0<0?VZC`050?VZD03iZTl0nJY?0?VZC`2>EXT00P3hYd/00`1kY^h0oooo0?ooo`04
0?ooo`030000003oool0oooo03d0oooo000Y0?ooo`030000003oool0oooo00H0oooo00D0000007m1
NP000000OT5j07i0NP030>n_R00305LgS`000040l:j500<0l:j500<0000007i1NP1n@GX00P1n@7X0
203d]8<0l:n70?2_Q`000000P4Am0854O@1:=9D0P4=m0P22AGd00`3a/8@000090?:_P@020?:_P@80
l[2200H0l[230?:_P`3a[X<0PDEm0?:_PP15>Z0507m3O0040813O01o@g`0O41k07i0NPL0Od5j00<0
Od9j07i1NP1m@7X00P1o@GX507i1NP0407m1NP1n@GX0c_BN07i0NPD0OT5j00<0Od5j07i0NP1o@gd0
1@20A7d0101n@g`0000W0814O@0005`20813O0070<Z>001o@W/0000W07m2N`1n@GX0nMil00009@02
0855OP050895OP20A7h0CS6>0855O@20A7d00P0002l0303g[g80P4=l0813O00002l0000Y0?WRPP00
01P0000007doN@1o@GX0P49j0?BZLP80n:m_0P3h/780203h/740mjmb08A6O@22AGd0mZic0?R`L@3h
[Vd0PTAk0P21@gX0103h[g00mjia0?N^L03h[fl30?N^L0080?R`KP3h[fl0mji`08=4NP21@gX0Q4Ek
08=4N`20@WXH07i1NP<0WiS=0P2U`^h00`1mi>l0PDAm0854O@03000000d0PDAm0P2>I9`508mTW009
08mTV`2BIY/0UVRJ09n@a@2LSlD0VI390:noiP2]_^H0XMkl0140PTIo0P2<GiP0301oEiT0SV:K0;1j
V03iZe`0n:i/0?>SJ03iZU`0lKB<0?V[F@3i[5T0R4^00?VZG080nZaF0P3iZeP20?RYG00;0?V/E@3i
ZeL0DIC_0:_6k@2[_^P0f<c>0<nV[P32ZL40nLNC0?g=SP3iZU<00P3FVI@03P3^/Y00nJYB0000002:
CX40n:QG0?VYD`3g[g80RDao08A8O`25BGl0RDb007e6PP24HJ80QD^20P26Bh800`25BX40nJ]D00hM
V`030?RWB`030?RXB`3hZ4`0n:Q<0080n:Q<00<0JC9i0?VZC`3iZTl0303iZTl01@3iZU00nJY?0?VZ
C`3iZTl0SUJ900<0n:M;00<0NjO_0?ooo`3oool00`3oool00`000000oooo0?ooo`0m0?ooo`00:@3o
ool00`000000oooo0?ooo`060?ooo`050000001o@GX0000007i1NP3b/XH00`3_[hP00`1G=hl0001j
0?2^Q@030?2^Q@030000001o@GX000030080OT1j00/0m;B30?2`Q`3`[hL000000814O@21A7d0BSBE
0813O@22AGd0kjf50?6`Q0040?:_P@80l[2200L0l[2308M9OP23AWh0PDEm0?:_PP1n@W`0P4=l00@0
Od=l00@0P4=l07m3O01l@7/0OT1j1`1o@GX00`1o@WX0OT5j07e0NP0207m1NPD0OT5j00@0Od5j07i1
NP3>m9h0OT1j1@1n@GX00`1o@GX0OT1j07m3O@050814O@0407i3O020A7d0P4Am0000G080P4=l00L0
000Y07m2N`39cE00Od9k07i1NP3igW`0000U0080PDEn00P0PTEn0814OP1><Hh0PDEm0814O@0002l0
001k0?N_LP80P4=l00T0_L]>0000:@3ihX80000H02h0B@1n@7X0Od5j0812NP3dZW800P3h[fl20?R`
LP080?R`L@3g[g80mZic0895O@3f[W<0n;1a0?R^K@22A7/20853NP040?R_L03g[W40mji`0?R_K`<0
mji`00P0n;1^0?R_K`3g[W00PdAj0853NP24AG/0PdAk0812NQD0OT5j0`2OV<d20:G2kP80ONC_00@0
PDAm00000000000000003P21A7d408iTW0@0SfBL0`2OT/L01@2PT/H0YkgY0:Znj02LkOL0T>[f00l0
PTIo0P2>HIP0402>H9P0SEnH08aOV02<GiP0OeNI08iRV`2`NYP0kk>>0?R^K03GW9D0nJYL0?6dS03j
`h`0nJaI08Q;P03iZU`20?Z/EP80nJ]H0P3hZE`06P3i[5D0nJ]G08U=P@2bb>/0e=oO0;KPm@2M__00
[ZcE0<O7f@3kb940l/bY0=6W[P3FVI@0k[:@0?VZDP000000RTj10?RXE`3iZE<0mjmb0=^NT`24B7l0
QDUo08U<P01mAX800@1Y0P25Bh801026Bh80QDZ10?V[E00306/30?RWB`030?RXB`3hZ4`0n:Q<0080
n:Q<00<0JC9i0?VZC`3iZTl0303iZTl01@3iZU00nJY?0?VZC`3iZTl0SUJ900<0n:M;00<0`UL00?oo
o`3oool0103oool00`000000oooo0?ooo`0l0?ooo`00:@3oool3000000H0oooo00D0000007m1NP3k
j9/0OT1j0?:bQP030>n_R003048/S`3`[XD0l:j500<0l:j500<0000007i1NP0000<00P1n@7X02`3`
[hL0l;270?2_Q`0003<0P4Am0854O@20@gd0PDAm0895O@3_[HD0lK2400@0lZn10P3b/8801`3b/8<0
QdUn08=6OP3]ZX@0l[2207m3O020@g`0101o@g`01@20@g`0Od=l07a0N`1o@GX0Od9j00H0Od5j00<0
Od9j07i1NP1m@7X00P1o@GX507i1NP0407m1NP1n@GX0c_BN07i0NPD0OT5j00<0Od5j07doN@1o@gd0
1@20A7d0101n@g`0P4Am0814O@0005`20813O0070000:@1o@W/0bLe@07m2N`1n@GX0000R00009P02
0855OP0C0895OP20A7h0000[0855O@20A7d0000_0000N`3g[g80P4=l0000;@2mbdh0n>:20?WRPP00
01P0OCmi07i0NP1o@GX0P49j0?BZLP020?R_K`80n;1b00P0n;1a0?N_LP3f[W<0PTEm0?J^L`3h/740
n:i]0894N`80PD=j00@0n:m`0?N^L@3g[W00n:m_0`3g[W00203h/6h0n:m_0?N^L023A7X0PD=j08A5
N`23A7/0P49j4P1n@GX309nHc@80YL;^0P1mi>l01021A7d0000000000000000>0854O@L0SVBL0P2?
I9`209jBa`0409nBa`2V_NX0Y[gZ08OVmQ40PTIo0P2?HIT0102?HIP0SV6H08iPV02=GiP208aOV004
07mGV@2>HY/0aJ_00>o8Z`80e:b`0P3a]8`0103j`h`0nJaI08Q;P03iZU`20?Z/EP80nJ]H0P3hZE`0
6P3i[5D0nJ]G08U=P@3hZE/0nJ]G0?V/E03iZeH0Vkoa0=SIf03bc:T0f<k?0=6W[P33Z/40nLNC0?_9
T03iZU8000000?RXE`3iZE<0mjmb0=^NT`24B7l0QDUo08U<P01mAX800@1Y0P25Bh801026Bh80QDZ1
0?V[E00306/40?RWB`@0n:Q<00<01@1[0?VZC`3iZTl0303iZTl01@3iZU00nJY?0?VZC`3iZTl0SUJ9
00@0n:M;00<0a5<00?ooo`3oool0103oool00`000000oooo0?ooo`0k0?ooo`00:03oool2000000P0
oooo0P1o@GX00`1n@GX0OT1j0?:bQP030>n_R003048/S`3`[XD0l:j500<0l:j50100000007i1NP00
0000OT5j07i0NP3`[hL0l;2708I:P00003<0P4Am0854O@20@gd0PDAm0895O@3_[HD000060`3b[h43
0?:`PP070?:`P`27BGh0PdIn0>fZQ01j?W/0Od=l0813O00407m3O0050813O01l@7/0k[<g07m1NP1o
@WX01P1o@GX00`1o@WX0OT5j07e0NP0207m1NPD0OT5j00@0Od5j07i1NP3>m9h0OT1j1@1n@GX00`1o
@GX0OCmi07m3O@050814O@0=07i3O020A7d0P4Am0000G020@g`0OT9l0000:@1o@W/0bLe@07m2N`1n
@GX0000R00009P020855OP0C0895OP20A7h0000[0855O@20A7d0000_0000N`3g[g80P4=l0000;@2m
bdh0n>:20?WRPP0002l0OCmi07i0NP1o@GX0P49j0?BZLP020?R_K`80n;1b00P0n;1a0?N_LP3f[W<0
PTEm0?J^L`3h/740n:i]0894N`80PD=j00@0n:m`0?N^L@3g[W00n:m_0`3g[W00203h/6h0n:m_0?N^
L023A7X0PD=j08A5N`23A7/0P49j3`1n@GX409nHc@040:G2kP1mi>l0PDAm0854O@<000003`21A7d8
08iTW0@0WY;70P2U_N/00`27i_H0PTIo0896O`0>0896O`80SV:I00/0SV6I08mQV@2?HIT0Sf6H08iQ
V02>H9P0SEnH08aOV02NU<T0VY;;08b<c@020<kIh@0:0=kKd`3D[;00c;;00?g9R03j`h`0nJaI0=JI
T`3iZU`0nLJC0?Z/EP80nJ]H0P3hZE`04P3i[5D0nJ]G08U=P@3hZE/0nJ]G0?V/E03iZeH0F9[a0:W<
lP3=fN80WKg^0;2`f034bn00oLj>0?_9T03BZ:d0fI^A00000080mjmb00H0fijC08A8O`25BGl0RDb0
08E;P`3fZ3d208E;PP0508I;PP25BX40nJ]D00<0J`3hYdX00`3hYd/40?RXC0030?^gD`3iZTl0nJY?
00d0nJY?00@0nJY@0?VZC`3iZTl0SUJ91@3hYd/60?ooo`030000003oool0oooo03/0oooo000X0?oo
o`030000003oool0oooo00L0oooo00D0Od5j07i1NP1n@GX0OT1j0?:bQP030>n_R00300000@3`[XD0
l:j500<0l:j50P1n@GX03P000000OT5j07LjN03`[hL0l;2708I:P020A7d0PDAm07PmN`20@gd0PDAm
0895O@3a/8@0mkAm0`3b[h420?:`PP080?FdP@3b[h<0QdUn08=6OP3]ZX@0000807m3O020@g`307m3
O080P4=l00@0O41k0>jc=`1o@GX0Od9j1P1o@GX00`1o@WX0O3mj07e0NP0207m1NPD0OT5j00<0Od5j
07i1NP1n@7X01P1n@GX00`1o@GX0OCmi0814O@050814O@0=07i3O020A7d0P4Am0000G020@g`0OT9l
0000:@1o@W/0B@9?07m2N`000240000R00009P030855OP0B0000<@0002/0PDEm0814O@0002l0mjmb
0853O020@g`0000]0;g;CP3hhX80nN:20000;P1m?gT0OT1j07m1NP20@WX0m:Yb0P3h[fl20?R`LP03
0?R`L@3g[g80mZic0080mZic00<0n;1a0?R^K@22A7/00P21@gX0103h[g00mjia0?N^L03h[fl30?N^
L0080?R`KP3h[fl0mji`08=4NP21@gX0Q4Ek08=4N`20@WX<07i1NP@0WiS=0P2U`^h00`1mi>l0PDAm
0854O@02000000h0PDAm2@2>I9`309jBa`80YKg[0P26i_H@0896O`D0SV:I00D0SV6I08mQV@2?HIT0
Sf6H08iQV00209nEb@0@09jDb@2Ta?00W/?b08KEo`2Gf_h0X/7_09W2m02H_o80LZgf0=KRg`3`aZH0
cZ>/0=JIT`3_/Xd0nLJC0?_4RP80nJ]H0100f9ZA0?RYG03i[5D0nJ]G08U=P@3hZE/0nJ]G0?V/E03i
ZeH0RDf107jNi`2/_NH0_lSQ07R/l`2C`oL0bM3O0P3Jcld20<>Y_`080000003I/K00fijC08A8O`25
BGl0RDb008E;P`3fZ3d208E;PP0508I;PP25BX40nJ]D00<0J`0<06d00`3hYd/01@3hZ4L0n:Q<0?RX
C03hZ4`0nkMC00l0nJY?00@0nJY@0?VZC`3iZTl0nJYB1@3hYd/00`3hYd`0oooo0?ooo`020?ooo`03
0000@P3oool0000000X0oooo1`0000030?ooo`@000001@3oool4000001/0oooo000;0?ooo`@00000
1P3oool2000000H0oooo100000070?ooo`030000003oool0oooo00L0oooo00D0Od5j0000001n@GX0
OT1j0?:bQP030>n_R0030<j6003`[XD0l:j500<0l:j50P1n@GX02P3kfJ00OT1j0?BdP`3`[hL0l;27
08I:P020A7d0PDAm04XdU@20@gd20895O@030?6`Q03g]7d0lZn10080lZn10P3b/8801P3e]840lZn3
08M9OP23AWh0kJZ404DjX0D0Od=l0P20@g`0101l@7/0OT1j07m1NP1o@WX607m1NP0407m2NP1l?gX0
OT5j07m1NPH0OT5j00<0Od5j07i1NP1n@7X01P1n@GX00`1o@GX0OCmi0814O@050814O@0F07i3O020
A7d0P4Am00009020@g`0OT9l0000:@1o@W/0B@9?07m2N`000240n=ij00009P21AGh0PTEn0855OP00
0340000[0855O@20A7d0000_0?N_LP80P4=l00X0000]0;g;CP3hhX80nN:20000;P1m?gT0OT1j07m1
NP20@WX0m:Yb0P3h[fl20?R`LP030?R`L@3g[g80mZic0080mZic00<0n;1a0?R^K@22A7/00P21@gX0
103h[g00mjia0?N^L03h[fl30?N^L0080?R`KP3h[fl0mji`08=4NP21@gX0Q4Ek08=4N`20@WX:07i1
NP80WiS=0P2U`^h207gTk`030814O@21A7d00000008000003@21A7d908iTW0<0WY;70P2U_N/208KV
mQ40PTIo1`2>HYT04@2>HIT0Sf6I09j=`P2OT<@0Wi;60:2Db02Va>l0Wm[l0:Jei02U]N@0Y;GU0:^m
iP2^eoD0XLSd06n]m`2Q`o40cm7K0080eLK<0P38[Kh0803iaY<0nlB:0?W2S@3iZeP0f9ZA0?RYG03i
[5D0nJ]G08U=P@3hZE/0nJ]G0?V/E03iZeH0RDf108VZj`2heo00OlKn0;o^lP27YNP0ZkcV0<cHhP3J
cld0/ZoE0<>Y_`000000fK6`0<>Z`@24B7l0QDUo0:1@J`25Bh<0ODJ20P25Bh801@26Bh80QDZ10?V[
E00306/0301]00<0n:M;00D0n:Q70?RXC03hZ4`0n:Q<0?^gD`0?0?VZC`050?VZD03iZTl0nJY?0?VZ
DP3gYeh0103hYd/01`3hYd`0oooo0?ooo`3oool09`9[0000@P2<ZNT00P00000<0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0603oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01`3oool0101o@GX0000007i1NP1n@7X30>n_R00305LgS`0n:8h0l:j500<0l:j5
00<0000007i1NP1n@GX00P1n@7X0203d]8<0l:n70?2`Q`26BX00P4Am0854O@1:=9D0P4=m0P22AGd0
0`3a/8@0mkAm0?:_P@020?:_P@80l[2200H0mKB10?:_P`3a[X<0PDEm0>fZQ015>Z0507m3O080P4=l
00<0O41k07i0NP1o@GX01`1o@GX0101o@WX0O3mj07i1NP1o@GX607i1NP0307m1NP1n@GX0OT1j00H0
OT5j00<0Od5j07doN@20A7d01@20A7d01`1n@g`0P4Am07i2O03aZc@0P4=l07i2O00002T00`1o@W/0
30000240n=ij00009P21AGh0PTEn0855OP000340000[0855O@20A7d0000_0?N_LP80P4=l00X0000]
0;g;CP3hhX80000/0000;P1m?gT0OT1j07m1NP20@WX0m:Yb0P3h[fl20?R`LP030?R`L@3g[g80mZic
0080mZic00<0n;1a0?R^K@22A7/00P21@gX0103h[g00mjia0?N^L03h[fl30?N^L0040?R`KP3h[fl0
mji`08=4NP80Q4Ek00<0PdAk0812NP1n@GX01P1n@GX309nHc@80YL;^00<0ONC_0?R^K023AWh00`00
000=0854O@T0SVBL102NT/L20:Fmj`0308KVmP22AWl0PTIo00l0PTIo0`2>HYX608iRV@@0WHc10240
[KkV0:g1j02ZhoX0YkCR0:J^g@2/]=l0Y[SU0:?Ln`23B840n:YP0?V/G03j[EX0PK7d0:W3k02ga>@0
V[W]0:n_f03=cMX0nlR>0?_4RP3i`Xd0nJ]H0=RJT@3hZE`0nJaE0?V[E`29CH40fi^@0?V[E`3i[5@0
nJ]F08U=P@3hZ5`00P3iZeH02@3hZE/0O<So0?V[DP3iZeD0Rdn209^kkP2lf^l0V/Ce000000020;o9
hP0408E9O`2PD6/0QD^307e6PP80QD^200D0QT^208E:P@25BX40NebS00`0K@030?RWB`050?RXA`3h
Z4`0n:Q<0?RXC03k]e<03`3iZTl01@3iZU00nJY?0?VZC`3iZU80SUJ900@0n:M;00H0n:M<0?ooo`3o
ool0oooo01l9NP0004820::ah`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`0H0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0103oool2000000L0oooo00D0000007m1NP000000OT5j07i0NP030>n_R00305LgS`0n
:8h0l:j500<0l:j500<0000007i1NP1n@GX00P1n@7X0203d]8<0l:n70?2_Q`26BX00P4Am0854O@1:
=9D0P4=m0P22AGd00`3a/8@0mkAm0?:_P@020?:_P@80l[2200H0mKB10?:_P`3a[X<0PDEm0?:_PP15
>Z0507m3O080P4=l00<0O41k07i0NP1o@GX01`1o@GX0101o@WX0OD1j07i1NP1o@GX607i1NP0307m1
NP1l?gX0OT1j00H0OT5j00<0Od5j07doN@20A7d01@20A7d01`0002<0P4Am07i2O00002L0P4=l07i2
O00002T00`1o@W/030000240n=ij00009P21AGh0PTEn0855OP000340000[0855O@20A7d0000_0?N_
LP80P4=l00X0000K0;g;CP3hhX80000H0000001m?gT0OT1j07m1NP20@WX0m:Yb0P3h[fl20?R`LP03
0?R`L@3g[g80mZic0080mZic00<0n;1a0?R^K@22A7/00P21@gX0103h[g00mjia0?N^L03h[fl30?N^
L0050?R`KP3h[fl0PdAj0853NP2<?FH00P23A7/01020@WX0OT5j07i1NP1n@GX409nHc@80YL;^00<0
O>C_0895O@3fZfl00`0000000`21AGd0P4Am0854O@0;0854O@P0SVBL102NT/L20:Fmj`0308KVmP22
AWl0PTIo00l0PTIo1P2>HYX408iRV@80WHc200D0WHc10:Fii`2V^^L0Tn[g08gWn00208=8P00N0?RZ
HP2^d_<0[];c08M;P@24BH40PdR10?RZH03i[5`0nZeJ0?V/G025X>D0/l3S0;g@j01d[?@0UL?f0:6l
k03k`XP0nL:=0?V[F03HVY40n:UL0?W5T03iZeL0RDf10=^KT03^/8`0nJaD0?V[EP29CH40n:QL0P3i
ZeH03`3hZE/0nJYF0?V[DP3iZeD0Rdn207ZMj02U^NL0`<OP07R[l`000000a<oR08E9O`2PD6/0QD^3
07e6PP0208E;PP0508I;PP25BX40QDZ107]LX`0<06d00`3hYd/01@3hZ4L0n:Q<0?RXC03hZ4`0nkMC
00l0nJY?00D0nJY@0?VZC`3iZTl0nJY?08iFR@040?RWB`0:0?RWC03oool0oooo0000@028DXX00012
0:^mi`2^`^P0[=Ge000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0H0?ooo`002P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`050000001o@GX0nnRK07i1NP3b/XH00`3_[hP00`1G=hl000010?2^Q@03
0?2^Q@030000001o@GX000030080OT1j00`0m;B30?2`Q`3`[hL000000814O@21A7d0BSBE0813O@22
AGd0kjf50?6`Q03g]7d30?:_P@80l[2200H0l[230?:_P`3a[X<0PDEm0?:_PP15>Z0507m3O0040813
O01o@g`0O41k07i0NPL0Od5j00D0Od9j07i1NP1m@7X0OT5j07m1NP0507i1NP0407m1NP1n@GX0O3mj
07i0NPH0OT5j00<0Od5j00006@20A7d01020A7d0201n@g`0lJ`e0814O@1n@W`0000W0813O01n@W`0
000Y0`1o@W/0303igW`0n=ij00009P21AGh0PTEn0855OP000340000[0855O@20A7d0000_0?N_LP80
P4=l00X0`/iB0;g;CP3hhX80000H0000001m?gT0OT1j07m1NP20@WX0m:Yb0P3h[fl20?R`LP030?R`
L@3g[g80mZic0080mZic00<0n;1a0?R^K@22A7/00P21@gX0103h[g00mjia0?N^L03h[fl30?N^L006
0?R`KP3h[fl0PdAj0853NP2<?FH0Y4UJ0P20@WX309nGc00409nHc02U`^h0YL;^07_TkP80P4Am0`00
00001@3h[f/0n:i/08=6OP21AGd0P4Am00X0PDAm202>I9`209jBa`80YKg[0P26i_H@0896O`X0SV:J
102MS<820:Fii`030:Jii`2>i_X0PdR000@0PdR001L0n:YR0?R[H@3i[5d0Qd^108A9P@23B840n:YP
0?V/G03j[EX0nJaL08M<P@3gZ6<0nZeI0?V/F`1k[?<0fLg>0=c?c03`aZD0d:B[0=RJT@3_/H`0nLF@
0?V[E`020=^KT0050>j`S03i[5@0nJ]F08U=P@3hZ5`00P3iZeH03`3QX8`0nJYF0?V[DP3iZeD0Rdn2
0?VYF01i_od0]MC`0<7^l@25YNT000000<_FhP2PD6/0QD^307e6PP0208E;PP0508I;PP25BX40QDZ1
00P0K00<06d00`3hYd/01@3hZ4L0n:Q<0?RXC03hZ4`0nkMC00l0nJY?00D0nJY@0?VZC`3iZTl0nJY?
08iFR@040?RWB`0;0?RWC03oool09P9[0000@028DXX08P]k0;?Cl02WeOP0X[WY0?ooo`0000002P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo01P0oooo00000`3oool0000000000004000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool207m1NP0307i1NP1n@7X0l[:600<0kjn800<000000?2^Q@3`[XD00`3`
[XD040000000Od5j00000`1n@GX0OT1j0?2_Q`3`/8L0l:n700000020A7d0PDAm04XdU@20@gd0PTEm
0>n]Q@3a/8@40?:_P@80l[2200H0l[230?:_P`3a[X<0PDEm0?:_PP1n@W`507m3O0040813O01o@g`0
O41k07i0NPL0Od5j00D0Od9j07i1NP1m@7X0OT5j07m1NP0507i1NP0407m1NP1n@GX0c_BN07i0NPH0
OT5j00<0Od5j00006@20A7d01020A7d02@1n@g`0000W0814O@1n@W`0000W0813O01n@W`0000Y07i1
N`0207m2N`0<0?WNO03hgWX0000V0855OP22AGh0PDEn0000<@0002/0PDEm0814O@0007<0mjmb0P20
@g`02P32cU80_L]>0?SRPP0001P0000007doN@1n@7X0Od5j0812NP3dZW820?R_K`80n;1b00<0n;1a
0?N_LP3f[W<00P3f[W<00`3h/740n:i]0894N`020853NP040?R_L03g[W40mji`0?R_K`<0mji`00<0
n;1^0?R_K`23A7X00P2<?FH01`2TBEX0WY;709nEbP2OUl`0YL7]0:G1kP1mi>l00P20A7d300000008
0814O@22AGd0mZ]_0?R_J`3h[V`0PdIn0855O@20A7d70854O@P0SVBL0`2NT/L20:Fmj`0308KVmP22
AWl0PTIo00l0PTIo2@2>HYX509f<`P80YKWW00<0S^Gj08=8P023B8001P23B800403hZV80n:]Q0?V/
G@27Bh40Q4V108=8P@3hZV00nJaL0?Z]FP3i[5`0Qdb10?NXH`3j[ET0nJaK06fEj02]_ND20=GMg@80
/JWA00X0nLF@0?g:S03aajD0dJFZ0=^KT03^/8`0nJaD0?V[EP29CH40n:QL0P3iZeH02`3QX8`0nJYF
0?V[DP3iZeD0Rdn20?VYF03j[5P01@1Z0040J@3gZD4000000080QTb300D0QD^307e6PP25Bh80QD^2
08I;PP0208E:P@0300P0K00>7I/0n:M;0080n:M;00<0n:Q70?RXC03hZ4`00P3hZ4`?0?VZC`050?VZ
D03iZTl0nJY?0?VZC`2>EXT0103hYd/0203hYd`0000l028;N`0R2gX0R5::01l9NP35enL0[j_C0P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0603oool000X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@000001P3oool00`000000oooo0?oo
o`070?ooo`80Od5j00<0OT5j07i0NP3b/XH00`3_[hP00`12;8l0l:j50?2^Q@030?2^Q@0@0000001n
@GX0000007i1NP1n@7X0l:n70?2`Q`3`[hL0000c0814O@21A7d0P4=m0854O@22AGd0kjf50>B:3`<0
lZn10`3b/8801`3b/8<0QdUn08=6OP3]ZX@0l[2207i2O020@g`0101o@g`01@20@g`0Od=l07a0N`1n
@7X0Od9j00H0Od5j00<0Od9j07i1NP1m@7X00P1o@GX507i1NP0407m1NP1n@GX0c_BN07i0NPD0OT5j
00<0Od5j07i0NP1o@gd01@20A7d05`1n@g`0000W0814O@1n@W`0000W0813O01n@W`0001V07i1N`1o
@W/0OT5j0?WNO03hgWX0000V0855OP22AGh0PDEn0000<@0002/0PDEm0814O@0007<0mjmb0080P4=l
00X0`/iB0;g;CP3hhX80000H0000001m?gT0OT1j07m1NP20@WX0m:Yb0P3h[fl20?R`LP030?R`L@3g
[g80mZic0080mZic00<0n;1a0?R^K@22A7/00P21@gX0103h[g00mjia0?N^L03h[fl30?N^L0060?R`
KP3h[fl0Qc5F03H0002dl_@0ZJOE0P2]_>D00`1niO00TNcd0854O@03000000@0P4Am00L0PTEm0?J[
K`3h[f/0n:i/08=6OP21AGd0P4Am0080PDAm102>Hi`508iTW0@0WY;70P2U_N/00`26i_H0PTIo0896
O`0?0896O`X0SV:J0`2MS<820:Fii`80S^Gj2`23B8003@2mPY<0l[230?V/G@27Bh40Q4V108=8P@2Z
LY<0nJaL0?Z]FP3i[5`0Qdb10?NXH`3j[ET00P3i[5/03`1fXNd0^Moc0;Ofl02R^n/0WkGX0=SIf03j
aXh0lLNU0=6UZP3KVi00k[2<0?g;S03iZeH0hYn90?RXG0020?V[EP0?0>6PS03][X`0nJ]B0?V[E@2;
Ch80nJUH0?Z/F00506X0n:U=07i6P`1lAH80000008I<P`25Bh<0ODJ20080QD^200D0QT^208E:P@25
BX40201/00hMV`030?RWB`030?RXB`3hZ4`0n:Q<0080n:Q<00<0JC9i0?VZC`3iZTl0303iZTl01@3i
ZU00nJY?0?VZC`3iZTl0SUJ900@0n:M;00P0n:M<02H1JP0R2g/0R5::028;NP0O2GX0YmCh08^4aP<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo01P0oooo000:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`80
0000203oool01@1o@GX0OT5j07i1NP1n@7X0l[:600<0kjn800<000010?2^Q@3`[XD00`3`[XD207i1
NP0>0?_IX01n@GX0McYh0?2_Q`3`/8L0QTZ00000<`20A7d0PDAm0813O@21A7d0PTEm0>n]Q@0000H3
0?:_P@80l[2200P0mKB10?:_P`27BGh0PdIn0>fZQ01j?W/0Od=l0813O0@0Od=l00D0P4=l07m3O01l
@7/0Od5j07m2NP0607m1NP0307m2NP1n@GX0OD1j0080Od5j1@1n@GX0101o@GX0OT5j0<kdWP1n@7X5
07i1NP0307m1NP1n@7X0Od=m00D0P4Am00d0OT=l00009`20A7d0OT9l00009`20@g`0OT9l07m2N`1n
@G/0Od9k07i1NP3igW`0000U0080PDEn00P0PTEn0855OP000340000[0855O@20A7d0001c0?N_LP80
P4=l00X0`/iB0;g;CP3ihX80000H0000001m?gT0OT1j07m1NP20@WX0m:Yb0P3h[fl20?R`LP030?R`
L@3g[g80mZic0080mZic00D0n;1a0?R^K@22A7/0PD=j08E6N`020?N^L@030?N^L03h[fl0mji`0080
mji`00@0n;1^0?R_K`3g[W00mji`0P20A7d00`3g[Vl0n:m^00000002000000L0P4Am00H0fYV=0?J[
K`3h[V`0n:i/0855O@20A7d208aRV`0308eRV`2=Hi`0SV>L0080SV>L0P2>I9`409jBa`80YKg[00<0
Q^Gf0896O`22AWl03`22AWl:08iRVP<0WHc20P2U^NL208kUnPh0PdR000D0_H:C0?:`P`3i[5d0Qd^1
08IGT`020:YbT`060?2aR@3j[EX0nJaL08M<P@3gZ6<0nZeI0P3i[5/20?NXHP0=0?Z/F@3j[E`0FYkc
0:Voj@3Je=80f/W90=6UZP36YkX0nLFA0?g;S03iZeH0e:NY0?RXG0020?V[EP0?0>6PS03][X`0nJ]B
0?V[E@2;Ch80nJUH0?Z/F00506X0n:U=07i6P`1lAH80QTb300000025Bh<0ODJ20080QD^200D0QT^2
08E:P@25BX40nJ]D00<0J`030?RWB`030?RXB`3hZ4`0n:Q<0080n:Q<00<0JC9i0?VZC`3iZTl0303i
ZTl01@3iZU00nJY?0?VZC`3iZTl0SUJ900D0n:M;00P09P5Z028;N`28DXX08P]j01l9NP2EQKl0=cbZ
07mSZ0<0oooo00<000000?ooo`3oool0103oool3000000D0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0603oool000X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool01@1o@GX0000007i1NP1n@7X0l[:600<0kjn800<000010?2^Q@3`[XD00`3`
[XD207i1NP0>0?_IX01n@7X0m;B30?2_Q`3`/8L0QTZ00814O@21A7d0N3ek0813O@21A7d0PTEm0?6`
Q00000H30?:_P@80l[2200P0mKB10?:_P`27BGh0PdIn0>fZQ01j?W/0Od=l0813O0@0Od=l00D0P4=l
07m3O01l@7/0Od5j07m2NP0607m1NP0307m2NP1n@GX0OD1j0080Od5j1@1n@GX0101o@GX0OT5j0<kd
WP1n@7X507i1NP0307m1NP1m?gT0Od=m00D0P4Am00d0OT=l00009`20A7d0OT9l00009`20@g`0000U
07m2N`39cE00Od9k07i1NP3igW`0000U0080PDEn00P0PTEn0855OP000340000[0855O@20A7d0000/
0?N_LP80P4=l00X0`/iB0000:@3ihX80000H0000001m?gT0OT1j07m1NP20@WX0m:Yb0P3h[fl20?R`
LP030?R`L@3g[g80mZic0080mZic00H0n:i/0?R^K@22A7/0PD=j0?R_L03g[W460?N^L0040?R`KP3h
[fl0mji`0?N^L080P4Am0P0000000`3g[Vl0PTEm0854O@060814O@0;09U/WP3JVHd0n:m[0?R^K02/
Nih0SV6H08=HU`28GIX0S6:K08eRV`2=Hi`00`2>Hi`309jBa`80YKg[00<0Q^Gf0896O`22AWl03`22
AWl908iRVPD0WHc20P2U^NL00`2>iOX0PdR008=8P00;08=8P080S5fE00l0OeBF08mRV02mPY<0l[23
0?V/G@27Bh40QUNC08=FT`2ZLY<0l;690?Z]FP3i[5`0Qdb10?NXH`3j[ET00P3i[5/00`3SWhL0mjQR
0?Z/F@020?Z]G080^=kc00D0^OO_0:Bnj`3=am@0WkGX0?;8Y0020=BWZ@0>0>n^Q`3`aZL0nJ]F0>6P
S03][X`0nJ]B0?V[E@2;Ch80dYVI0?k=R03j[5P0n:U=07i6P`1lAH8208I<P`050000001mAX800@1Y
08E;PP2ZL9400P25BX400`3iZe@00`1[0?RWB`030?RWB`@0n:Q<00<0JC9i0?VZC`3iZTl0303iZTl0
1@3iZU00nJY?0?VZC`3iZTl0nJYB00D0n:M;00P0n:M<08QBRP0R2g/08P]j01l9NP2@P;h0Pf:U0?BV
>P<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`@000001@3oool40000
01/0oooo000;0?ooo`@000003P3oool5000000D0oooo00<000000?ooo`3oool01P3oool01@000000
Od5j0000001n@GX0OT1j00@0kjn800<0?RR>0?2^Q@3`[XD00P3`[XD00`000000OT5j07i1NP0207i0
NP0<0?BdP`3`[hL0l:n708I:P020A7d0PDAm07PmN`20@gd0PDAm0895O@3a/8@0mkAm0`3b[h420?:`
PP080?FdP@3b[h<0lJj308=6OP3]ZX@0NSik07m3O020@g`407m3O0050813O01l@7/0k[<g07m1NP1o
@WX01P1o@GX00`1o@WX0OT5j07e0NP0207m1NPD0OT5j00@0Od5j07i1NP3>m9h0OT1j1@1n@GX00`1o
@GX0OCmi07m3O@050814O@0=07i3O00002L0P4Am07i2O00002L0P4=l0<Z>001o@W/0bLe@07m2N`1n
@GX0nMil00009P020855OP080895OP21AGh0000a0716S`21AGd0P4Am0000;`3g[g820813O00:0<;>
DP0002T0nN:2000060000000OCmi07i0NP1o@GX0P49j0?BZLP80n:m_0P3h/7800`3h/740mjmb0?J^
L`020?J^L`80n:i]00L0PTAk0853NP3V/9/0aiRV0?N^L03h[fl0i[:N0080mji`00@0n:m^0?R`KP3g
[W00mji`0`0000030?N^K`040895O@20A7d0P4Am0814O@80SF6J00d0SF:K085IVP2IK9h0fYV=0?R_
J`3h[V`0c9jY08iQV023F9L0R5fJ08aRV`2=HY/0SF>L00<0WY;70P2U_N/208GUmP0308M;O`24B7l0
PTIo00d0PTIo2P2>HYX409f<`P80YKWW00<0S^Gj08=8P023B8002`23B80208iOUP0B08eNUP2<GID0
S5fE07mDUP2?HYP0_H:C0?:`P`3i[5d0b8nH08IGT`23EY<0ZW:C0?2aR@3mahD0nJaL08M<P@3gZ6<0
nZeI0P3i[5/00`3SWhL0mjQR0?Z/F@050?Z]G00D05VNl`2O`O00ZKoZ0=[Ed`3LblP0e:NY0<RX^P3`
aZL0fZj[0<NY^`3][X`0oLb>0?V[E@2;Ch80dYVI0?k=R03j[5P0PDR307i6P`1lAH8208I<P`050000
001mAX800@1Y07A:T02EHY@00P25BX400`3iZe@00`1[0?RWBP030?RWB`@0n:Q<00<0JC9i0?VZC`3i
ZTl0303iZTl20?VZD080nJY?00<0nJYB0?RWB`3hYd/00`3hYd/02@3hYd`0R5::028;N`0R2gX07`Uj
03<kZ`23HZD0m:Hj0?ooo`02000000030?ooo`000000oooo03D0oooo000W0?ooo`030000003oool0
oooo00H0oooo00D0000007m1NP3kj9/0OT5j0?:bQP030>n_R00305LgS`0n:8h0l:j500<0l:j500<0
000007m1NP1n@GX00P1n@7X0203d]8<0l:n70?2_Q`26BX00P4Am0854O@1:=9D0P4=m0P22AGd00`3a
/8@0mkAm0?:_P@020?:_P@80l[2200P0mKB10?:_P`3a[X<0PDEm0>fZQ00000P0Od=l0813O0<0Od=l
0P20@g`00`1l@7/0000@07m1NP0707m1NP0407m2NP1l?gX0OT5j07m1NPH0OT5j00<0Od5j07i1NP1n
@7X01P1n@GX00`1o@GX0OCmi07m3O@050814O@0407i3O00002L0P4Am07i2O080P4=l00L0bXh007m2
N`39cE00Od9k07i1NP3igW`0000V0080PDEn00P0PTEn0855OP000340L4J?0855O@0002/0000_0?N_
LP80P4=l00X0`/iB0000:@3ihX80000H0000001m?gT0OT1j07m1NP20@WX0m:Yb0P3h[fl20?R`LP03
0?R`L@3g[g80mZic0080mZic00@0hH<70>=l?`21@gX0klJX0P38Zkd01P3g[W00i[ZX0>JbWP3;WJL0
mji`0?R`KP<000000P20A7d20?N^K`060>^eVP3g[Vl0SV6H08AIU`2:GiT0SF:J0P2=HIX01@2=HY/0
PEVJ09U/WP3Q^:h0jkRL0080c9jY00<0SV6H08=HU`28GIX00P2MTLL00`2MT/L0Y;g[0:Fmj`0208CU
m@0508=7O`3cYg40nJmY08M;O`24B7l02`22AWl308iQVPL0SV:J102MS<820:Fii`0308kUnP23B800
PdR000`0PdR0102>GiH01`2=GYH0S5fE08aMU@1oE9H0Sf:H0;f2T`3b/8<00P3K[:L02@26Ei<0PeJC
0:YbT`3`/HT0oLN50?V/G03VXH@0mjQS0?Z]F@020?V/F`030>>OQ`3gZ680nZaI00H0nZeL00`0LYk/
0;SOm02jnN`0Yl;]0;J^dP37c=d0hm_>0<3MkP2h]=D0nLFC0?g<SP3abJP20=:IV@060?k=R03j[5P0
PDR307i6P`1lAH80QTb30P2FH900100000000@1Y07A:T02EHY@208E:P@030?V[E00306/0n:M:00<0
n:M;00D0n:Q70?RXC03hZ4`0n:Q<00D0J`0>0?VZC`80nJY@0P3iZTl00`3iZU80mjMN0?RWB`030?RW
B`080?RWC028DXX08P]k028;NP0O2GX0O:S_03<kZ`3dYSX40?ooo`030000003oool0oooo03@0oooo
000V0?ooo`<000001`3oool207m1NP030?_XV`1n@7X0l[:600<0kjn800<0EcN?00000@3`[XD00`3`
[XD00`000000Od5j00000`0207i0NP080?BdP`3`/8L0l:n708I:P020A7d0PDAm04XdU@20@gd20895
O@030?6`Q03g]7d0lZn10080lZn10P3b/8801P3e]840lZn30?6^P`21AGd0lZn204DjX0D0Od=l0P20
@g`00`1l@7/0OT1j07m1NP0707m1NP0407m2NP1l?gX0OT5j07m1NPH0OT5j00<0Od5j07i1NP1n@7X0
1P1n@GX00`1o@GX0OCmi0814O@050814O@0407i3O00002L0P4Am07i2O080P4=l00L0000Y07m2N`39
cE00Od9k07i1NP000280000V0080PDEn00D0PTEn0855OP0002T0L4J?0855O@020000;`0=0?N_LP20
@g`0P4=l0<;>DP0002T0nN:2000060000000OCmi07i0NP1o@GX0P49j0?BZLP020?R_K`80n;1b00<0
n;1a0?N_LP3f[W<00P3f[W<02@3h/740W;GZ0<c;f@3Vbk`0c]3J0<R[_@3V^ZP0hlg20=2h`P030000
00080?R_K`3Z/YL0mji`09M[WP2CIi/0mji_0?R_KP3[]IX20:UhW@0308AIU`2:GiT0SF:J0080SF6J
00<0SF:K085IVP2EW=P00P3Ud/@01@3K`/00c9jY0:2Db02LSlD0W9360080Y;g[0P23iOD30896OP05
08=7O`3cYg40nJmY08M;O`24B7l02022AWl408iQV@80SV6J102>HYX309f<`P80YKWW0P2=iOX>08=8
P080SUnG1@2>GiH05`2=GYH0S5fE08aMU@1oE9H0Sf:H0<RV]`3a`j00j=G20=^/Y`26Ei<0VXW00;nN
]`3j`h/0oLN50?V/G03BXjL0mjQS0?W2R`3j`XP0nJaK0>>OQ`3gZ680nZaI00L0nZeL00T0001U0000
HP000680JJ_g0:K9lP2hc>X0LJcf09Rll@3<gnL00P3abJP03P3>Yk00dYVI0?k=R03j[5P0PDR307i6
P`1lAH800P1Y08=CS`2FH900ND^>0000001dBY00UF:D0P25BX400`3iZe@00`1[00`0K@030?RWB`05
0?RXA`3hZ4`0n:Q<0?RXC03k]e<03`3iZTl01@3iZU00nJY?0?VZC`3iZU80SUJ900@0n:M;00P0n:M<
08QBRP0R2g/08P]j01l9NP2b`ND0<c^[0?BV>PD0oooo00<000000?ooo`3oool0<`3oool002H0oooo
00<000000?ooo`3oool01`3oool207m1NP0307i1NP1n@7X0l[:600<0kjn800<0EcN?0000003`[XD0
0`3`[XD04@3lfJ00Od5j00000`1n@GX0OT1j0?2_Q`3`/8L0l:n700000020A7d0PDAm04XdU@20@gd0
PTEm0>n]Q@3a/8@0mkAm00<0lZn10P3b/8801P3b/8<0lZn30?6^P`21AGd0lZn204DjX0D0Od=l0P20
@g`00`1l@7/0OT1j07m1NP0707m1NP0407m2NP1m@7X0OT5j07m1NPH0OT5j00<0Od5j07i1NP1n@7X0
1P1n@GX00`1o@GX0OCmi0814O@050814O@0407i3O00002L0P4Am0000G080P4=l00L0000Y07m2N`39
cE00Od9k07i1NP000280000V0080PDEn00D0PTEn0814OP1><Hh0PDEm0814O@020000;`090?N_LP20
@g`0P4=l0000;`3hhX80nN:20000600^04T0OCmi0080Od5j00<0P49j0?BZLP3h[fl00`3h/7800`3h
/740mjmb0?J^L`020?J^L`060?R`L@0TNnH0YlO`0:KSn`1dg[/0WkKX0`0000002@2j]mH0klV/0?CA
ZP3^aZX0j[:G0<>DYP2GJih0TfNK0?N^K`020>^eVP050<ZKY`2YN9d0Q5VG08YOV@2=HYX00P2PW=00
2P2QWm<0TKof09G7n02Rio/0SMco0:Vch02WWll0Wk[/0:>kj`21iO@70896OP0508=7O`3cYg40nJmY
08M;O`24B7l01@22AWl408eQV@<0SV6I0P2>HIX00`2>HYX0WHc209f<`P0209f<`P80YKWW00<0SNGj
08=8P023B8003023B80408eOU`0308iOU`2>GiH0SUnF00<0SUnF00D0SEjF09f=`P2MSL80V8[308j5
aP020=OFf0070>SE`P2h]=H0YYW808b1`P3Hcm00Y<3]0?;3W`020=:SY`070?6_P`3i`X/0n/:80?V/
F`3SWhL0mjQR0?Z/F@070?Z]G00=0000I@000680001R0000I@1g[_D0[LS]0;[<j01d[oL0U/[i0<KH
i`3Dbm00cZN`0;G6i`020?Z/F00:0858P`1nAX<0O4F20080J@23Dhl0UV2@07U;SP000000M4Z@09ER
U080QDZ100<0nJ]D00<0J`0<06d00`3hYd/01@3hZ4L0n:Q<0?RXC03hZ4`0nkMC00l0nJY?00D0nJY@
0?VZC`3iZTl0nJYB08iFR@040?RWB`080?RWC028DXX08P]k028;NP28DXX0mjY203<kZ`3dYSX60?oo
o`030000003oool0oooo0380oooo000V0?ooo`030000003oool0oooo00L0oooo00D0Od5j07i1NP1n
@GX0OT1j0?:bQP030>n_R003048/S`3`[XD0l:j500<0l:j50140000007i1NP000000OT5j07i0NP3`
[hL0l;270?2_Q`000000P4Am0854O@1:=9D0P4=m0895O@3_[HD0lK2400002@030?:_P@80l[2200H0
l[230?:_P`3a[X<0kJZ40?:`PP15>Z0507m3O0040813O01o@g`0O41k07i0NPL0Od5j00D0Od9j07i1
NP1m@7X0OT5j07m1NP0607i1NP0307m1NP1l?gX0OT1j00H0OT5j00<0Od5j07doN@20A7d01@20A7d0
3@1n@g`0P4Am0814O@0005`0P4=l07i2O00002T0Od9k04T2C`1o@W/0000Q0?SNNP0002H00P21AGh0
1@22AGh0P4An04haSP21AGd0P4Am0080000_00X0mjmb0813O020@g`0_L]>0?SRPP3ihX80000H02h0
B@1]85T0Kb9J0P20@WX20?R_K`040?33Y03h/780n;1a0?R`L@@0mZic00<0n;1a0?N_LP3f[W<00`00
0000402B`_L0^L3O09Fkl@28^OH0^MS`08Ron@3Vb[X0cjni0<>DYP2GJih0TfNK0>:fZ@3Vc[h0fKbm
0<ZKY`2YN9d209b?a@0:09nDb@2]aN/0Z<K_0:7Jo02Ugo/0XZcN0:Fij02S^NT0WKO[08KIo`X0PTIn
00L0PTIo0?>WL@3i[fT0n:iZ08A8O`2?GiD0QUVF0080S5nH00<0S62I08eQV@2=HIT00P2=HIT308iQ
V@@0WHc20P2U^NL00`2=iOX0PdR008=8P00<08=8P0L0SEnG00<0SUnG08iOUP2>GiH00P2>GiH02P2L
R;d0WHVn09f=`P2U`Nd0WKk`08[Fo`2Hf?d0YLSb0:K2k@2K`?8208?8oP80XMOk00/0eM_L0=W5a@3B
XjL0bjRf0?g6QP3j`XP0nJaK0>>OQ`3gZ680nZaI0?Z]G@060?Z]G0050000I@000680001R0000I@00
06<00P2_b>`01@2mcNL0T;_c09jgjP2Z_^P0iNOB00<0nZaH00l0PDR307i6P`0106P00P1Y08=CS`2F
H900ND^>00`=R@000000WXBg0:V9]025BX40nJ]D00<0J`0<06d00`3hYd/01@3hZ4L0n:Q<0?RXC03h
Z4`0nkMC00l0nJY?00D0nJY@0?VZC`3iZTl0nJY?08iFR@040?RWB`090?RWC028DXX08P]k028;NP28
DXX0A05B03<kZ`29EH`0PJS^00D0oooo00<000000?ooo`3oool0<P3oool002H0oooo00<000000?oo
o`3oool01`3oool01@1o@GX0000007i1NP1n@7X0l[:600<0kjn800<000010?2^Q@3`[XD00`3`[XD2
07i1NP0>0?_IX01n@GX0OT1j0?2_Q`3`/8L0l:n700000020A7d0PDAm0813O@21A7d0PTEm0>n]Q@3T
RPl30?:_P@<0l[2200H0l[2308M9OP23AWh0kJZ40?:`PP1n@W`507m3O0040813O01o@g`0O41k07i0
NPL0Od5j00D0Od9j07i1NP1m@7X0OT5j07m1NP0507i1NP0407m1NP1n@GX0c_BN07i0NPH0OT5j00<0
Od5j07doN@20A7d01@20A7d03@1n@g`0P4Am0814O@0002@0P4=l07i2O00002T0Od9k04T2C`1o@W/0
000Q0?SNNP0002H00P21AGh01@22AGh0P4An0000:`21AGd0P4Am0080000_00/0mjmb0813O00002d0
_L]>0?SRPP3ihX80000H06@ABP1]85T0Kb9J0812NP020;mJC@80l<>T00@0l<>S0?73X@3h/780iZfH
0`3f[W<300000080mZib01/0mjma03B2j@2[`>T0a]SW09:ckP2J[^D0`lWO0=K>dP3?[kT0Y9W:092;
b`2FTlh0_M;Y0=cUf`2^l_D0ZJGC0:6Ca`2MT<D0YkkZ0:_1j@2AkO40mji`0:K0k02S/n<0ZkCO0:WM
n@21AWh03022AWh01`22AWl0ljMa0?V_J@3h[VX0/gnK08mOU@21E9@00P2<GiP00`2<H9T0SF6I08eQ
V@0208eQV@@0WHc20P2U^NL00`2=iOX0Q4R008=8P00<08=8P0X0SEnG00<0SUnG08iOUP2LQk`00P2L
Qk`02P2LR;d0[;cU0:[QnP2X^ND0Yk?R0:fdgP2]^n@0/]?a0;;Jm02Ve_T20:fegP0=09Jol`2Rc?H0
Y<?_0::kj`2cZm00Vkc`0=_QfP3a`j00dJ:W0>>OQ`3/ZhT0m<2G0?Z]G@060?Z]G00;0000I@000680
001R0000Q`0f7XL0N:oe0:k=l02gd>d0T[K_09V^iP2_b>`0103j[5P03`21B8<0OTJ30040J00006L0
Pe>?09IPT01iBhh0>CRT08Ic]P000000^;cL08E:P@3iZe@00`1[00`0K@030?RWB`050?RXA`3hZ4`0
n:Q<0?RXC03k]e<03`3iZTl01@3iZU00nJY?0?VZC`3iZTl0SUJ900@0n:M;00X0n:M<08QBRP0R2g/0
000008QBRP0O2GX0<c^[08UES01oHjP0O:C]1@3oool00`000000oooo0?ooo`0a0?ooo`009P3oool2
000000P0oooo00@0Od5j0000001n@GX0OT1j103_[hP00`000040l:j50?2^Q@030?2^Q@80OT5j00h0
nmVP07i0NP3d]8<0l:n70?2`Q`3`[hL0000c0814O@21A7d0P4=m0854O@22AGd0lK2400001P<0lZn1
0P3b/880203e]840lZn308M9OP23AWh0kJZ40?:`PP1n@W`0P4=l101o@g`01@20@g`0Od=l07a0N`1n
@7X0Od9j00H0Od5j00D0Od9j07i1NP1m@7X0OT5j07m1NP0507i1NP0407m1NP1n@GX0c_BN07i0NPH0
OT5j00<0Od5j00006@20A7d01@20A7d01`1n@g`0P4Am0814O@3aZc@0P4=l07i2O00002T00`1o@W/0
0`3igW`0n=ij00009P020855OP050895OP20A7h0000[0855O@20A7d00P0002l02P3g[g80P4=l0000
;@2mbdh0n>:20?WRPP0X0000I15:06lRFP1/6U420897O`0709Fbj`32`]X0l<>S0?34Y03a`j40mjmb
0>J]V003000000030?R`L@3f[W<0mZic0080mZib01/0mjma0?J^LP3g[W80mjma0?N^LP1h^o/0Y][j
09gdiP2__^D0Yj?B0:Ffi@2J^>d0R>Kf0855OP2/`>T0V[7W0:Bdi02?ioT0PdMn0896OP21AWh0mji`
0?R_KP3g[Vl0PdMo0896O`21AWh01`22AWh01P2=GiL0S5jG08aNU`21EiL0PeZI09MYV`80nJmY00@0
n:iZ0;=oV`2?GiD0PEBD0P2<GiP00`2<H9T0SF6I09b<`P0309b<`P80YKWW00D0SNGj0?V^I`3h[VP0
QDZ108A8P00:08=8P0/0SEnG1@2LQk`05@2U]N@0Y[GT09[YnP25BX80Q4Z208E:PP2R/^@0/=7a0?Z^
GP3j[El0nJeP0?Z^H@2Nd?T000000;S]m@2O_Nh0Yk[W0:BljP1YZOH0U<Oi09g=n0020=W4a@040<FQ
]03d`9L0m<2G0?Z]G@H0nZeL00/0001U0000HP0006D0002703HNQ`1BA:<0UKW`0:S<lP2S/n@0PjK[
0>cTa`040?Z/F00;0858P`0106T00@1X0000I`23Dhl0UV2@07U;SP0i>:@0;Uc>08VOhP0000000P3i
Ze@00`0806`0301]0?RWB`020?RWB`050?RXA`3hZ4`0n:Q<0?RXC03k]e<03`3iZTl01@3iZU00nJY?
0?VZC`3iZTl0SUJ900D0n:M;00`0R5::028;N`28DXX08P]j01l9NP0c>j/0REF<02LAOP3:HP003fKK
04Vlm@2>/>d30?ooo`030000003oool0oooo0300oooo000V0?ooo`030000003oool0oooo00H0oooo
00D0000007m1NP3kj9/0OT5j07i0NP040>n_R0030000003`[XD0l:j50080l:j500<0000007i1NP1n
@GX00P1n@7X0303d]8<0l:n70?2_Q`26BX00P4Am0854O@1h?G/0P4=m0854O@22AGd0lK2400001P<0
lZn10P3b/880203e]840lZn308M9OP23AWh0kJZ407XnN`1o@g`0P4=l101o@g`01@20@g`0Od=l07a0
N`1o@GX0Od9j00H0Od5j00<0Od9j07i1NP1m@7X00P1o@GX507i1NP0407m1NP1n@GX0c_BN07i0NPH0
OT5j00<0Od5j07m3O@20A7d01@20A7d01`0002<0P4Am07i2O00002L0P4=l07i2O00002T00`1o@W/0
0`3igW`0n=ij00009P030855OP0@0000<@0002/0PDEm0814O@0002l0000`0?N_LP20@g`0000K0;g;
CP3hhX80nN:202P00025BH00m[1h08a?P@80PTMo00<0000h09Rdj`3<b=H00P3a`j42000000060<JF
Y03f[W<0n;1a0?R`L@3V[YP0mZic103f[W801P3g[W80mjma0?N^LP3g[W80mjia0?N_L@80mjia0P3g
[g003`3g[W40PDEn0855OP3g[W40n:m_0?N^L023Agh0PTIn0856OP3g[W00n:m^0?N^K`23Agl0PTIo
0856OP040896OP0408iQV02>H9P0SV2H08eOU`80S5jG00X0PENG08=JV@2GJI/0g;:]0>fhVP3@XJH0
/gnK08mOU@21E9@0S5nH0P2LRl401@2LS<40W8c20:Bii`2U^NL0S>Gj0080PdR000D0n:eZ0?V^I`3h
[VP0QDZ108A8P00708=8P00308eNUP2=GYL0SEnG00T0SEnG0P2KQk`209b7_00:0:Fdi02U]N@0TnCl
09?To03i[F40nJeR08E:PP24BX80QDZ20?NYI`80nZiN00@0nZeO0?V]H03j[V40nZiP0`3j[Ul02`2?
YnH0[kSP0;[6h`28^?D0X<[e0:?2k`2R^>P0/JG<0<W1dP3j[ET0nZeM00H0nZeL00/0001U0000HP00
06D0001U07M^^`2BRlP0XjKH09ZjkP2O/>@0]/WY0?Z]E0040?Z/F00;0858P`0106T02PV50000I`23
Dhl0WH:e0:62/P21L;L0^/M90?V[D`0000000P3iZe@00`0806`0301]0?RWB`020?RWB`050?RXA`3h
Z4`0n:Q<0?RXC03k]e<03`3iZTl01@3iZU00nJY?0?VZC`3iZTl0nJYB00D0n:M;00`0R5::028;N`28
DXX08P]j01l9NP0c>j/0Pf:U0?BV>P3hYd/0n:M>0?RWD03]Sdd205bfo0030::WfP000000oooo0340
oooo000V0?ooo`030000003oool0oooo00H0oooo0P1o@GX00`3kj9/0OT5j0?:bQP030>n_R00305Lg
S`0n:8h0l:j500<0l:j500<0000007m1NP1n@GX00P1n@7X0303d]8<0l:n70?2_Q`26BX00P4Am0854
O@1h?G/0P4=m0854O@22AGd0lK240?NdO@<0lZn10P3b/880203e]840lZn30?6^P`23AWh0kJZ407Xn
N`1o@g`0P4=l101o@g`01@20@g`0Od=l07a0N`1o@GX0Od9j00H0Od5j00<0Od9j07i1NP1m@7X00P1o
@GX507i1NP0407m1NP1n@GX0c_BN07i0NPD0OT5j00<0Od5j07i0NP1o@gd01P20A7d01`3a[3D0P4Am
07i2O00002L0P4=l07i2O00002T00P1o@W/04@1n@GX0nMil0?SNNP0002H0PDEn0895OP21AGh0000a
0000:`21AGd0P4Am0000;`0006P0mjmb0813O032cU80_L]>0080Zk3L00P0lmVe08E9P03f/7P0S4n1
0897O`23B7l0000h001Ne@<0000000L0i/Rh0<NW^@36UZ@0ikNT0?R`L@3g[g80iZjH0080mZib00<0
mjma0?J^LP3g[W80103g[W840?N^L@80mjm`00h0mjia0855OP21AGh0mjia0?R_K`3g[W00PdMn0896
OP21AWh0mji`0?R_KP3g[Vl0PdMo0856OP<0PTIn0P2>H9P0102>HIP0SV2H08iPV02=GiL208aNU`0=
085GU`23FYT0[J7<0>CAa@3O`kd0d:6V0;=oV`2KRKl0VHNo09Z9`02KRl40Y;SW0:Bii`0208_UnP@0
PdR000D0n:eZ0?V^I`3h[VP0QDZ108A8P00408=8P080S5jF0P2=GYH00`2=GYL0SEnG08eOU`0508eO
U`@0VhNl0P2U]>@209?To00908A:P@3hZfD0nJeQ0?V]H@3i[F80QDZ208A:PP25BX80mjUW0080nZiN
00@0nZeO0?V]H03j[V40nZiP0`3j[Ul02`3j[V40_]O/0;kGk02fmO80W;k`0:Bij01YX_80U;7[0831
o03laHT0nZeM00H0nZeL00@0001U0000HP0006D0001U0P2=[^`01@33dND0R;?b08kKo`27Zn`0nZeD
00@0nZaH00l0PDR30040J@0:2HD0:aJ3010[Z@2MP[D0^;OI0?7[`P2jadT0nJ]C0?V[E0000000nJ]D
00P0K00F7YT00`3hYd/01P3hZ4/0n:Q<0?RXC03hZ4`0nkMC06TbN@h0nJY?00D0nJY@0?VZC`3iZTl0
nJY?0?VZDP050?RWB`080?RWC028DXX0@`9C028;NP0O2GX0X/?`08=RY@3dYSX20?RWB`80n:M@00D0
n:IF0?RWCP2^_ND0[[gU0000000a0?ooo`009@3oool00`000000oooo000000070?ooo`80Od5j00<0
OT5j07i0NP3b/XH00`3_[hP00`1G=hl000010?2^Q@030?2^Q@030000001o@GX000030080OT1j00`0
m;B30?2`Q`3`[hL0QTZ00814O@21A7d0N3ek0813O@21A7d0PTEm0?6`Q03g]7d30?:_P@80l[2200P0
mKB10?:_P`3a[X<0PDEm0>fZQ01j?W/0Od=l0813O0@0Od=l00<0P4=l07m3O01l@7/0201o@GX00`1o
@WX0OT5j07e0NP0207m1NPD0OT5j00@0Od5j07i1NP3>m9h0OT1j1@1n@GX00`1o@GX0OCmi07m3O@05
0814O@0R07i3O00002L0P4Am07i2O00002L0P4=l07i2O00002T0OT5k07m2N`1n@GX0nMil0?SNNP00
02H0PDEn0895OP21AGh0000a0000:`21AGd0P4Am0000;`0006P0mjmb0813O02X`^`0Z;KR0:bhhP3c
fKD0[Khn08E9P03f/7P0PdMo0897O`<0000000P0<fkK09nej03@d=T0c/cG0<NW^@2k[lh0l<JV0?C<
Y@80iZjH00P0bIRS0?J^LP3g[g40mZib0?N^LP3g[g40ik2J0?N^LPD0mjia00@0mjm`0?N^L@3g[W40
PDEn0P3g[W420?N^L0040896OP21AWh0mji`0?N^L080mji_00<0SUjF085EU029G9L00P2=H9P208iP
V00408iQV02>H9P0SV2H08eOU`<0WYG:00H0T8k=0;;Bl@2bd_40f>SQ0;2_e`2[Wl/20::fi`030:Bh
i`2:i?X0R^Gi00L0PdR000T0n:eZ0?V^I`3h[VP0QDZ10;j6V01mD900PUFC08]LU@2<GIH00P2<GYH2
08eNUP0308eNU`2=GiL0SEnG0080SEnG102KQk`20:Fdi00309;So024BX40Q4Z100<0Q4Z100P0n:]U
0?V]H@3i[F40nJeR0<Z>U021DI00_Gn?0?NYI`80nZiN00@0nZeO0?V]H03j[V40nZiP0`3j[Ul30?Z^
H@08028<N`2@]o40Z[kX08:_lP2ia^@0m/FI0?c5R@3j[Ed60?Z]G080001U00T0;a^700h?RP0c78H0
OK_j0;?9j`2i_]d0k>C70<G;C@3j[E@0103j[5P0200506X0002400X9Q@0[5X<0AcnU07^QjP2De?h0
M]kd0P3iZe<20?V[E0030000000806`05QjI00@0n:M;103hZ4`00`1Y<WT0nJY?0?VZC`0<0?VZC`05
0?VZD03iZTl0nJY?0?VZC`3iZU801@3hYd/0203hYd`0R5::028;N`0R2gX07`Uj0;kDj`0c>j/0m:Hj
0P3hYd/0203hYdh0n:M@0?RVEP3hYdd0[l7W0:[CmP3oool00000<03oool002D0oooo0P0000080?oo
o`80Od5j00<0OT5j07i0NP3b/XH00`3_[hP00`1G=hl000010?2^Q@030?2^Q@0=0?cIX01o@GX00000
07i1NP1n@7X0l:n70?2`Q`3`[hL0QTZ00814O@21A7d0BSBE0813O@020895O@030?6`Q03g]7d0lZn1
0080lZn10P3b/880203b/8<0lZn30?6^P`21AGd0lZn20000201o@g`0P4=l101o@g`00`20@g`0O41k
0>jc=`0807m1NP0407m2NP1n@GX0OT5j07m1NPH0OT5j00@0Od5j07i1NP3>m9h0OT1j1@1n@GX00`1o
@GX0OCmi07m3O@050814O@0O07i3O00002L0P4Am07i2O00002L0P4=l07i2O00002T0bLe@07m2N`1n
@GX0nMil0?SNNP0002H0PDEn0895OP21AGh0000a0000:`21AGd0P4Am0000;`0006P0MhkL0:Rfh`33
dnH0UKcb09K0m03_fk`0m:ei08E9P0030000000808=8O`0003P0000b0000=P11RN`0[>7i093_e02=
`OP20;k4gP0=0>o4YP3VbKT0bJVi0<VHX`3U]J@0i[2J0<jMY03g[W80i;FT0>N`VP3g[W80mjia0?N_
L@020?N^L@80mjm`00H0mjia08MKV027FiP0mjia0?R_K`3[/iL209e_W@08099TV@3g[W00n:m^0>bd
U`2/NI/0SUjF085EU029G9L208ePV080SV2H00H0SV6H09nAa@2OU<P0WiG909nEbP2T`nl209cKo@06
0::bi02Q]>H0WKGY09fej@2J/nT0P]Wn2023B8001P2;G9D0PdR009EVV03h[FX0nJiW0?R^J080_XJH
00@0OE2@089ET`2;G9D0S5fF0P2<GYH208eNUP0308eNU`2=GiL0VhNl00<0VhNl0P2U]>@0102Bi?`0
Q4Z108A:P@2:Ehl208UGT00408QGT01nD900T5nE091OU@80nJeQ00D0nJeR0<Z>U021DI00Oe6@0?NY
I`020?Z^GP040?Z]G`3i[F00nZiQ0?Z^H0<0nZiO0`3j[V40200R37/0B3^O07f/l@2Y`n`0d<C?0?Rn
R`3laHT0nZeM1P3j[E`20000I@0602lKQ`0>3hX0<ab605aYa`1cZO<0W/Kd0P3j[5P00`3j[E@0nZaH
0?Z/F0020?Z/F00700D0JP0008@0AcnT06eT]`27PlP0^kkL0<SBF0030?V[D`<0nJ]D00<00000028?
O`3hYd/00`3hYd/40?RXC00306TbN@3iZTl0nJY?00`0nJY?0P3iZU020?VZC`030?VZDP3gYeh0n:M;
00<0n:M;00P0n:M<08QBRP0R2g/08P]j01l9NP3L[jT0<c^[0?BV>P80n:M;00P0n:M>0?RWD03hYUH0
n:M=0:Jok02I^>d0oooo00000300oooo000U0?ooo`030000003oool0oooo00L0oooo00D0Od5j0000
001n@GX0OT1j0?:bQP030>n_R0800000103`[XD04@000000OT5j0000001n@GX0OT1j0?2_Q`3`/8L0
l:n700000020A7d0PDAm04XdU@20@gd0PTEm0>n]Q@3a/8@0mkAm00<0lZn10P3b/880203b/8<0lZn3
0?6^P`21AGd0lZn20000201o@g`0P4=l0`1o@g`20813O00307a0N`1n@7X0Od5j00L0Od5j00@0Od9j
07e0NP1n@GX0Od5j1P1n@GX00`1o@GX0OT5j07i0NP0607i1NP0307m1NP1m?gT0Od=m00D0P4Am00d0
OT=l00009`20A7d0OT9l00009`20@g`0OT9l0000:@39cE00Od9k07i1NP3igW`0000V0080PDEn00d0
PTEn0855OP000340000[0855O@20A7d0000_03XXT0007JD0VmGl0:Neh`2W[M`0blOG00<000000180
m[1h08=7O`22Agl0PdQo0000>0000380000f0855OP22AGh0mZie0?N_M00_L=h0c<[G09fdj03@c]P0
bJVi0;^^c03Ub[`20=6d_@80i;FT01P0ik2J0<jMY03g[W40ik6J0<nMX`3g[W40i;BT0?N_L03g[W40
VffL08MKV03g[W40n:m_0>^cU`3<VjD0WFnM099TV@3g[W00n:m^0>bdU`3=W:@0SUjF085EU029G9L2
08ePV00308iPV02MS<40WHg20080[L;Y0P2Sf_/01P2U[Md0YK7Q0:FgiP2U]nH0WmSl0:3In`P0PdR0
00l0S5fD08aLU02;G9@0RebE081DU021EYH0n:eZ0?V^I`3^^IT0eJ>S0;j6V01mD900PUFC08]LU@2<
GIH00P2<GYH00`2=GYH0VhJl09^6_00209^7_080YKCT00<0T^Cl08A:P@2:Ehl0102:Ehl208UGT004
08QGT01nD900NTjA091OU@80nJeQ00/0nJeR0<Z>U021DI00Oe6@0?NYI`3h`Hh0nZiN0?Z]G`3i[F00
nZiQ0?Z^H0030?Z^G`<0nZiQ00P0001l0928a`2IX]X0QJoa0:6ij@3IfMP0nZeJ0?Z]G@H0nZeL00P0
001U034MR00_6hL0001e07AZ^P2>Q/H0^kgK0<K<CP80nZaH00<0nZeD0?Z/F03j[5P00P3j[5P01`05
06X0002404LoY01@J<`0ZKWT0<KLj@2Te?T00`3iZe<30?V[E0030000000R3gl0Y2X000<0n:M;00D0
n:Q70?RXC03hZ4`0n:Q<06TbN@0>0?VZC`80nJY@0P3iZTl00`3iZU80mjMN0?RWB`030?RWB`080?RW
C028DXX08P]k028;NP0O2GX0TE^=03<kZ`29EH`20?RWB`060?RWCP3hYe00n:IF0?RWC@2[S[L0Uh>l
0P3oool00`000000oooo0?ooo`0]0?ooo`006@3oool4000000P0oooo00<000000?ooo`3oool01`3o
ool0101o@GX0000007i1NP1n@7X40>n_R0030000003`[XD0l:j500<0l:j50P1n@GX03`3kfJ00OT5j
07i0NP3`[hL0l;270?2_Q`000000P4Am0854O@1:=9D0P4=m0895O@3_[HD0lK2400002@030?:_P@80
l[2200H0l[230?:_P`3a[X<0kJZ40?:`PP15>Z0507m3O080P4=l00<0O41k07i0NP1o@GX01`1o@GX0
101o@WX0OD1j07i1NP1o@GX607i1NP0307m1NP1n@GX0OT1j00H0OT5j00<0Od5j07doN@1o@gd01@20
A7d03@1n@g`0000W0814O@1n@W`0000W0813O01n@W`0000Y0<W=D01o@W/0OT5j0?WNO00002H00P21
AGh02P22AGh0PDEn0000<@0002/0PDEm0814O@0002l0>RR@0:N^g@36bmh30000000?08_Tn`3d[GT0
QDV008a?P@23Agl0PTMo08=8O`0003P0000b0000=P21AGh0PTEn0?J^M@3g[g@0mJie0080ZN7j00d0
[oO]09RbjP2nb>80_/SR0=GOg`3A];d0_:k<0>G:_03B]Kd0cYfT0>BdY03Ub[`0dkJm0080i;BT00D0
jk:G0<^KY@2KKI`0Qe^H0>6bYP020>^cU`040<bKY@2MKid0TVBI0=naY`80k;BG00D0cIbT08iNUP21
EI@0REbG09b<`@0209f<`@090:Nki`2[_>H0Xngi09O/mP2Xa^l0Y;7R0:^bg@2/f?L0]=Ca00P0PdR0
0140SEfE08eNU@2=GI@0S5fD08aLU02;G9@0RebE081DU021EYH0n:eZ0=J[[@3^^IT0eJ>S0;j6V01m
D900PUFC08]LU@0509^6_080YKCT00<0T^Cl08YGS`2:Ehl01`2:Ehl208UGT00408QGT01nD900NTjA
091OU@80nJeQ00/0nJeR0<Z>U021DI00Oe6@0?2^Q@3h`Hh0n/270?Z]G`3i[F00nZiQ0?Z^H0030?Z^
G`<0nZiQ00P0001R09Baj`2g`n<0^<cY07B[m01f]oX0nlF80?Z]G@H0nZeL00P0001U034MR00_6hL0
B4:W05A_d@2Xe_P0Mkkm077Pi@80nZaH00<0nZeD0?Z/F03j[5P00P3j[5P01`0506X0:A>006iU]`28
P/L0[/ka0?C9XP3lbXl00`3iZe<40?V[E0030000001?AJH0n:M;0080n:M;00D0n:Q70?RXC03hZ4`0
n:Q<06TbN@0>0?VZC`80nJY@0P3iZTl00`3iZU80SUJ90?RWB`030?RWB`080?RWC028DXX08P]k028;
NP28DXX0A05B03<kZ`29EH`20?RWB`070?RWCP3hYe00TU^<0?RWC@2CGHh0U6FI099SV0020?ooo`03
0000003oool0oooo02`0oooo000H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`050000001o@GX0nnRK07i1NP1n@7X0103_[hP00`000040
l:j50?2^Q@020?2^Q@060?[GY01n@GX0OT5j0?_IX01n@7X0m;B30`3`[hL020000000P4Am0854O@20
@gd0PDAm0895O@3_[HD000060`3b[h430?:`PP80lZn300@0lJj30>fZQ03b/880ACZP1@1o@g`01020
@g`0Od=l07a0N`1n@7X707m1NP0507m2NP1n@GX0OD1j07i1NP1o@GX01P1n@GX00`1o@GX0OT5j07i0
NP0607i1NP0307m1NP1m?gT0Od=m00D0P4Am00d0OT=l00009`20A7d0OT9l00009`20@g`0OT9l07m2
N`39cE00Od9k07i1NP3igW`0]/=30080PDEn00L0PTEn0855OP000340000[0855O@20A7d0000_00<0
000000<0^[[I0<W7f03_g;h00P3d[GT02`3e[WP0S4n108=7O`22Agl0m:ih0000>0000380000f0855
OP22AGh0mZie0080mJie0P3f[W@20?F]M@0601:Lf@3g[g80VKK/09fjk@1^/OT0`NC`0P2UZ]X08@3U
b[`0e^3N0=>f_@2l[L/0i/Vj0=Vi^@3;VjD0VffL08MKV02_W/L0il^k0=Zj^P3<VjD0WFnM09F<a`2]
WLH0i/bl0=^l^P3=W:@0XHo209b:`02LRl40YKWW0:Fji`2U^^P0R^Kh08=8P024B800mje_0?R_K@3g
[Fl0`8BC06e0R@0708=8P00;08aMU@2=GID0SEfE08eNU@2=GI@0S5fD08aLU02;G9@0RebE081DU021
EYH00P3FZjd00`3RaK/0eJ>S0;j6V00209R2^P80VXFl00P0VhJl0:Bdi02T]>@0TN?l08A:P@2<FHl0
ReR?08]GS`P0RUN?0P29Ei004@28Ei00OU2@07Y>T@2@GiD0bZ:_0?V]H@3LZJ40bXjD085AT01oDI00
`I^a0?S1SP3j`8L0n;f80?V]H03j[V40nZiP00<0nZiO0`3j[V4020000680RL3i08W0n@2n`mh0/KkS
0?RnR`3kaHP0nZeM1`3j[E`01`0a7HP06CFa071X^P2HZN80/]Kc0?G8W@3lah/00P3j[5P00`3j[E@0
nZaI0?Z/F0030?Z/F00602TCP021YN/0[kSP0;C=k03g`Y80o<Z?0`3iZe<40?V[E0030000G`000000
/jcA0080n:M;00D0n:Q70?RXC03hZ4`0n:Q<06TbN@0?0?VZC`050?VZD03iZTl0nJY?0?VZDP2>EXT0
103hYd/04@3hYd`0R5::028;N`000000R5::04@1DP0c>j/0REF<02LAOP3hYd/0n:M>0?RWD02BFh`0
n:M=09=MSP2DIIT0TV>H0080oooo00<000000?ooo`3oool0;03oool001P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`<000001`3oool207m1NP030?_XV`1n@GX0OT1j00@0
kjn800<000010?2^Q@3`[XD00P3`[XD00`000000OT5j07i1NP0207i0NP0<0?BdP`3`[hL0l:n70?2_
Q`0003<0P4Am0854O@20@gd0PDAm0895O@3a/8@000060`3b[h420?:`PP070?FdP@3b[h<0QdUn08=6
OP3]ZX@0l[2207i2O00507m3O0040813O01o@g`0O41k07i0NPL0Od5j00D0Od9j07i1NP1m@7X0OT5j
07m1NP0607i1NP0307m1NP3>m9h0OT1j00H0OT5j00<0Od5j07doN@20A7d01@20A7d03@1n@g`0000W
0814O@1n@W`0000W0813O01n@W`0001[0<W=D01o@W/0OT5j0?;M^P0002l00P21AGh01@22AGh0PDEn
0000<@0002/0PDEm008000000P0006@0101/Y_@0W[k_0;[3h@30g>h20?B]N@090?F^N02<Ch40PdMo
0897O`3d[WP0000h0000<P0003H0PDEn0080mZie00@0jK2F0?J^M03f[W@0mZid0P3e[GD07`3f[W@0
mjmb0?R`LP3g[g<0RDb00896O`22AWh0W;[]09OJoP2Um^`0YZ_J0;g7hP2L^Nd0gMkF0:bVd@2AR<H0
UXk80;k?i`3NhmP0/_7e0:fWdP2BR<D0X/3^0;7amP2@jOL0//KY0:VJa`2S]ND0Y;SW0:Fhi`2=i_T0
1023B8001P24B800mje_0?N]K`3g[Fl0`8BC06e0R@80PdR000@0REVC08YKU02;Fi@0S5bE0P2<GID2
08eMU@0I08eNU@2=GI@0S5fD08aLU02;G9@0W8g30966a02AR<L0Z9O50;3>k`3RaK/0/:380:B>_P2J
Q;X0V8:j0:Bch`2T/n@0TN?l097So@24BX40Seb@08iKT02<FHl0ReR?08]GS`0808YGS`80REN@0140
R5N@07i@T01jCY40XHfo0<ZR[`3Xc[`0g:VQ0<Z>U02<Nk`0VXBk0<6K/@3ka8P0n/270?RmR03i[F00
nZiQ0?Z^H0030?Z^G`<0nZiQ00P0001R03XTR`1dZ_<0//3U0;;2iP3LblP0mM9S0?Z]G@L0nZeL00L0
<Af801Te/@2=[>/0//;V0;CEl@3h`8h0o<N;0080nZaH00<0nZeD0?Z/F@3j[5P00`3j[5P01P0Y4h00
0B:V056Un02_c>l0dlgC0380>0<0nJ]C1@3iZe@01@000000dlkE0:Vli`3hYd/0n:Q700<0n:Q<00<0
Y/mP0?VZC`3iZTl03@3iZTl01@3iZU00nJY?0?VZC`3iZTl0SUJ900D0n:M;01@0R5::028;N`000000
R5::01l9NP0c>j/0REF<02LAOP3hYd/0n:M>0?RWD02BFh`0n:M=09=MSP2DIIT0TV>H0?ooo`000000
oooo000002d0oooo000H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`80Od5j00<0nnRK07i1NP3b/XH0103_[hP00`000000l:j50?2^Q@02
0?2^Q@030000001o@GX0OT5j0080OT1j00`0m;B30?2_Q`3`[hL0QTZ00814O@21A7d0N3ek0813O@21
A7d0PTEm0?6`Q00000H30?:_P@80l[2200P0mKB10?:_P`27BGh0PdIn0>fZQ03b/880OT9l0813O0@0
Od=l00D0P4=l07m3O01l@7/0OT1j07m2NP0607m1NP0507m2NP1n@GX0OD1j07i1NP1o@GX01@1n@GX0
101o@GX0OT5j0<kdWP1n@7X607i1NP0307m1NP1m?gT0P4Am00D0P4Am00d0OT=l00009`20A7d0OT9l
00009`20@g`0000Y0000J`39cE00/ZoF0<o>f03FoKP0000_0080PDEn00<0PTEn0855OP0000000P00
00002020A7d0000/0000I01LD:/0L7S;06JUm029Y>H0mZmh0P3d[GT0403e[WP0S4n108=7O`22Agl0
m:ih0000>0000380PDEn0:akWP3f[WD0mjmd0>V`UP3AWJ00mZid0?N_M03e[GD20?J^M0080?N_LP3h
/780mjmc08U<P022AWl0PTIn0?J]M03g[g820?J]L`0C0?J^L`3g[g80PK_i09^`iP2U]><0YnCk0?J]
L`22Agl0MkKi09^_iP2Vho/0mZeb08A8P023Agl0MkOj09^_i@2=d?h0mZea08YGSP0508=8P080mje_
00X0l;B>0<24T`30Q9<0KD2907i@T027Ei80REVC08YKU02;Fi@0S5bE0P2<GID208eMU@0308eNU@2=
GI@0WHg20080WHg201@0W8c20:C0k@2D^_40R]Oo0:Fmj`2a`>D0][CG09b`iP2R/^<0TN?l08oRo@24
BX40QDZ1095NTP2AGI40Seb@08iKT02<FHl0ReR?08]GS`P0RUN?01<0REN@09Z5^`2JQK/0VXFl09>1
_@2QSKl0Zl_a0=7^j031cnD0^Zo?08ak_02JQ;/0Y[gZ0>?KcP3j`8L0n;f80?V]H03j[V40nZiP00<0
nZiO0`3j[V4020000680>RB;00H_/@1QX?<0[<K]0:3@n@3edV<0mmAX1`3j[E`01`000780B4>X09Z[
h`26`_/0X[[[0=?Hg03ee6L00P3j[5P00`3j[E@0nZaI0?Z/F0030?Z/F00602TCP01<?j40EF;405VK
l@1^[?L0n/F=0`3iZe<50?V[E00504nVn0000000@Yoe0?RWB`3hZ4L00`3hZ4`00`2Vcf00nJY?0?VZ
C`0=0?VZC`050?VZD03iZTl0nJY?0?VZC`2>EXT01@3hYd/02028DXX08P]k00000028DXX07`Uj03<k
Z`29EH`0m:Hj0P3hYd/01`3hYe00TU^<0?RVEP3hZEX0U6FI099SV02;W=l00`3oool00`000000oooo
0?ooo`0Z0?ooo`00603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01`3oool207m1NP0307i1NP1n@7X0l[:600<0kjn800<0EcN?00000@3`[XD00`3`
[XD04@000000Od5j00000`1n@GX0OT1j0?BdP`3`/8L0l:n708I:P020A7d0PDAm07PmN`20@gd0PDAm
0895O@3a/8@0000600<0lZn10P3b/880203e]840lZn30?6^P`23AWh0kJZ407XnN`1o@g`0P4=l101o
@g`01@20@g`0Od=l07a0N`1o@GX0Od9j00H0Od5j00D0Od9j07i1NP1m@7X0OT5j07m1NP0507i1NP04
07m1NP1n@GX0c_BN07i0NPH0OT5j00<0Od5j07doN@20A7d01@20A7d03P1n@g`0000W0814O@1n@W`0
000W0813O00002P0001^07fBg@2/aNd0Wmkm0856OP0002l0PDEn0`0000002`000340000[0855O@00
02/0000_0000J@1fR=P0XJCH0<36gP3HolD0mZmh0080m:ei00X0m[1h08a?P@23Agl0PTMo0?B^N000
0380000f0693U`2/Nih0mZie0P3Y/9H01@3AWJ00mZid0?N_M03e[GD0mZid0080mjmb00@0n;1b0?N_
L`22AWl0PTIn0P3f[G@0103g[g80mZec0?J]L`3f[W<20?J]L`040?J^LP3g[g40mZec0?J]L`80PTMo
0`3f[G800`24B800PdMo0?J]L@030?J]L@0608YGSP1bA8/0PU:@08QITP23B800VVVG0P3g[Fl02P3`
]8h0f:6L0<24T`1]@8T0OU2@08MGTP29FI<0RU^D08]KU02<G9D208aMU@0<08eMU@2LQk`0W8Rm09f:
_`2MS<40Y/3/0:G0k@2Of?`0YKSV0:BhiP2T]>@0Y;GU0P2FdO`20?R]J`030?V^J@0004H0Q4Z10080
W6ND00H0TEfA08mLT02>Fi00S5V?08]HS`2;Ehl608YGS`<0VhFk0180VXFk0:>nk02S_^d0TMOn09_K
o@2R_nh0ZKoZ09O0m02<a?X0N<?n06c1oP2Sd?L0YL?_0=oAbP3g_X/0nJeP0?Z^H@3j[V030?Z^G`<0
nZiQ00P0001R000AU02AR/P0Uj3K0>gPa03faiX0mM9S0?ODJ0L0nZeL00L0001W0;G3i02e`n@0_M3X
07ONmP1g]OT0mMAW0080nZaH00<0nZeD0?Z/F@3j[5P00`3j[5P01P1mAh@0RX330<72f`3Uf/X0nlF=
0?[5S@<0nJ]C1P3iZe@0101<U?0000000=?Bf03hZ4L30?RXC0030:K?H03iZTl0nJY?00d0nJY?00D0
nJY@0?VZC`3iZTl0nJY?0?VZDP050?RWB`0808QBRP0R2g/0R5::028;NP0O2GX0nJ]D08=RY@3dYSX2
0?RWB`050?RWD02BFh`0n:IF0?RWCP2AFhh00P2@Fhh30?ooo`030000003oool0oooo02X0oooo000H
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`07
0?ooo`80Od5j00<0OT5j07i0NP3b/XH00`3_[hP00`1G=hl000010?2^Q@030?2^Q@0A0?cIX01o@GX0
000007i1NP1n@7X0l:n70?2`Q`3`[hL0QTZ00814O@21A7d0N3ek0813O@21A7d0PTEm0?6`Q03g]7d0
0`3b[h420?:`PP080?FdP@3b[h<0lJj308=6OP3]ZX@0NSik07m3O020@g`407m3O0030813O01o@g`0
O41k00P0Od5j00<0Od9j07i1NP1m@7X00P1o@GX507i1NP0407m1NP1n@GX0c_BN07i0NPH0OT5j00<0
Od5j0<k=C`20A7d01@20A7d02`1n@g`0000W0814O@1n@W`0P4=l07i2O0000680EUBc0;2_e`3?cmT0
l]jk00<0000000X0PDEn0895OP21AGh0000a0000:`21AGd0P4Am0000J00d98l0IGkG0P2Lfod02@3g
hh40mZmh0?B]N@3d[GT0m[1h08a?P@23Agl0PTMo0?B^N0020000>00<0693U`2/Nih0ikJQ0>W=^03Y
/9H0dIfP0>RdWP3Z[i80dIbO0?J^M03W]9h0n;1b0P3g[g<00`2:Fi@0OU6B0?J]M0020?N_LP040?J]
L`3f[W<0mjmb0?J]L`80mZib00@0mjma0?J]L`22Agl0PTMo0P3f[G80103^/Y00mZeb08=7O`2AH9D3
0?J]L@0C0;UoU02:Ehh0LTB;089BT028FI80NDjB089FU@3g[Fl0n:m]0?2dSP3HXI`0`8BC06e0R@1n
D900QeNB08UIT`2:Fi@0Re^D08aLU@0409^6_080[;[T00D0ZnGj0:S=l`2V]>80ZJoL0:Rbg`020:?C
n@030?R]K03g[F`0n:iZ0080n:e[00/0nJiY0000AP24BX40WFZF09aWU02AGI40Seb@08iKT02<FHl0
ReR?08]GS`0308YGS`@0VhFk0P2U_^/04P2Mf_`0YKk/0:Fok02U]><0Z;KS0;3Im@000000V=kn09fk
k@2T^>L0W[W/07jam02U`nl0Y[_Y0?_5R`3h^h<0nZiQ0?Z^H0<0nZiO0`3j[V4020000680001f0;Fk
gP2e^mh0g<_90?_4R03edV<0mmAX1`3j[E`01`0006L0P/;l0;G=k02na=h0[kkU0?NoSP3ee6L00P3j
[5P00`3j[E@0nZaI0?Z/F0030?Z/F00607e7Q026YNT0]lcZ0;7=kP3ka8X0n/F=0P3jaY000`3iZe<0
nJ]D0?V[E0050?V[E00304bCl0000000YL?_00<0n:Q<00<0Y/mP0?VZC`3iZTl03@3iZTl01@3iZU00
nJY?0?VZC`3iZTl0nJYB00D0n:M;00P0n:M<028;N`28DXX08P]j01l9NP3iZe@09a5n0?BV>P80n:M;
00P0n:M>0?RWD03hYUH0n:M=09=MSP2@FXh0T5^>08:YkP<0oooo00<000000?ooo`3oool0:@3oool0
01P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`800000203oool01@1o
@GX0000007i1NP1n@7X0l[:600<0kjn800<0000000000@3`[XD00`3`[XD04@000000OT5j0?_IX01n
@GX0OT1j0?2_Q`3`/8L0l:n708I:P020A7d0PDAm04XdU@20@gd0PDAm0>n]Q@3a/8@0mkAm00<0lZn1
0P3b/880203b/8<0lZn30?6^P`21AGd0lZn207XnN`1o@g`0P4=l101o@g`00`20@g`0Od=l07a0N`08
07m1NP0307m2NP1n@GX0OD1j0080Od5j1@1n@GX0101o@GX0OT5j0<kdWP1n@7X607i1NP0307m1NP1o
@gd0P4Am00D0P4Am00P0OT=l00009`20A7d0000T08EMW02:H9`0001R07b@g0<0000000l0PDIn0000
;`21AGh0PDEn0895OP21AGh0000a0000:`21AGd0000_0000J01eQmL0X:CH0<36gP3Dol@00P3f[gP2
0?B]N@080?J`N02<Ch40PdMo0897O`3d[WP0000h02PGQP1R@iL20<Nfb@040>W=^03D]KX0a;[A0>W;
]`80dk>i0P3W]9h03@3gc9l0mjmc0<ZCW@2:Fi@0OU6B0?J]M03T/Il0mjmb0?J]L`3f[W<0mjmb0?J]
L`3DWYd00P3g[g401P3f[G<0VVVH089ET`3f[G80mjm`0>jbT080WffH00`0TF2E0?J]L@3h[fl0mZea
0=JNW02:Ehh0LTB;089BT028FI80NDjB089FU@3g[Fl20?2dSP060=RQW030Q9<0KD2907i@T027Ei80
REVC0`2JQK`02`2KQ[`0Y;GT0:Fei02Ai_/0S^Gk0?R^K@3g[Fd0n:i[09g:m`3h[F`0nJmZ0080nJmY
00<0n:e/0?N]K03h[VX00P3h[F/02`3i[VT0001608eNUP2MJYH0W6ND095MT@2?G900SU^@08aIS`2;
F8l0ReN?00@0VhFk00<0Y;k/0:Fnj`2Mf_`00P2U_N/20:FbhP050:?Bn02SdoT0nZmS0?Z^I03h[FH0
0P3h[6L02@2D]^h0[koV0:O0k01jZ_40XKWY09[4m@3h^h<0nZiQ0?Z^H0030?Z^G`<0nZiQ00P0001R
03LRRP1l_o`0^<cY06VbnP3Rg]40mM9S0?ODJ0P0nZeL00D0<1Z506jWm02_`>H0[l;X0?_6R`030?Z/
F0030?Z]E03j[5T0nZaH00@0nZaH00D00P1Z05:IlP2/aN`0ZlS^0?[6S`020?[6T0030?V[D`3iZe@0
nJ]D00H0nJ]D00<000000=?Be`2U`nl00P3hZ4`00`2Vcf00nJY?0?VZC`0=0?VZC`060?VZD03iZTl0
nJY?0?VZC`3iZU80mjMN103hYd/0203hYd`0R5::04<2D`0R2gX07`Uj0?V[E00c>j/0m:Hj0P3hYd/0
2@3hYdh0n:M@0?RVEP3hYdd0Tef>091JSP2@Fhh0n:M9082Zk`030?ooo`030000003oool0oooo02P0
oooo000H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`050000001o@GX0nnRK07i1NP1n@7X0103_[hP2000000@0l:j50P1n@GX03`3kfJ00
OT5j07i0NP3`[hL0l;270?2_Q`000000P4Am0854O@1:=9D0P4=m0895O@3_[HD0lK240?NdO@030?:_
P@80l[2200P0l[230?:_P`3a[X<0kJZ40?:_PP1j?W/0Od=l0813O0@0Od=l00<0P4=l07m3O01l@7/0
201o@GX0101o@WX0OT5j07i1NP1o@GX607i1NP0407m1NP1n@GX0c_BN07i0NPD0OT5j00<0Od5j01@0
5@1o@gd01P20A7d01@1n@g`0000W0814O@0002L0QEfL00<0000000D0IL3n08Z/k022AWh0PDIn0000
;`020855OP0;0895OP21AGh0000a0855O@20A7d0000a034QS@007ZH0MJkf09_Lo@3_gKl00P3f[gP2
0?B]N@0A0?J`N02<Ch40PdMo0897O`3d[WP0000i02PGQP1DL]<0WMSl04jMm021i?@0RlWm0:[4k02d
f?<0f>KO0=>c^@30//d00P3gc9l0103g[g<0dj^_08YKU01nDI820>BaW`0P0>^`TP3CWIh0mZic0?N_
LP3f[G<0e9jM0>FaWP3g[g40mZec09YYV022EI<0mZeb0?N_L03^/Y00dYbO09m]V02AH9D0mZea0?R_
K`3f[G40eYjL08YGSP1bA8/0PU:@08QITP1iCY80PUJE0=n^Y03ZckX0hl2d0=RQW030Q9<209J6`003
09V8`02IQkh0VHFm0080XkGU00/0Rn?k08WSnP26Bh40Qdb208Q<PP3h[Vd0mje]0?R^J`3h[V`0n:e/
0?V_JP020?V_J@030?R]K03g[F`0n:iZ0080n:e[00P0nJiY0?V_J02=GYH0WFZF09aWU02AGI40Seb@
08iKT080W8Jk0P2KQK/20:Bok00309_Ko@2T_^`0Y;k/0080Y;;R00P0X]3h0:?@n03h[FL0nJiU0?Z_
HP3j[f<0nZiT0?R]IP80n:aW00T0nZiS0;;4i`2ba>L0Z;gY0?3S`@3jbI<0n;^30?Z^H@3j[V000`3j
[Ul30?Z^H@080000H`0g8XX0CTFW066UmP2Rd_T0KKOl0?RmQ`3ge6P80?Z]G006030JQ@1<@J<0G9ca
0:W5k@2Mc_T0n/:90P3j[5P00`3j[E@0nZaI0?Z/F0040?Z/F0050080JP007j@0CIKa0=_Ie@2Xc_@0
0P3jaY000`3iZe<0nJ]D0?V[E0060?V[E00304bCk`000000YL?_0080n:Q<00<0Y/mP0?VZC`3iZTl0
3@3iZTl01P3iZU00nJY?0?VZC`3iZTl0nJYB0?NWGP@0n:M;00P0n:M<08QBRP130U<08P]j01l9NP3i
Ze@0<c^[08UES080n:M;00T0n:M>0?RWD02@FH`0n:M=09=MSP2@FXh0T5^>0?RWB@2oE0000`3oool0
0`000000oooo0?ooo`0X0?ooo`006@3oool4000000L0oooo00<000000?ooo`3oool01P3oool207m1
NP030?_XV`1n@GX0OT1j00@0kjn800<000010?2^Q@3`[XD00P3`[XD01P3jej@0OT5j07i1NP3kfJ00
OT5j0?BdP`<0l:n700T000000814O@21A7d0BSBE0813O@22AGd0kjf50?6`Q03g]7d00`3b[h420?:`
PP80lZn300H0lJj30>fZQ03b/880000807m3O020@g`407m3O0030813O01l@7/0000@00P0Od5j00@0
Od9j07e0NP1n@GX0Od5j1P1n@GX0101o@GX0OT5j0<kdWP1n@7X407i1NP0406@;@01]4T<0P4Am07m3
O@H0P4Am00<0000S0814O@0000000P000000202_Xl/0VY?<09^FcP2i_]d0lMfj0<kWj021AWh0000_
0P21AGh02`22AGh0PDEn0000:`24FiX0U6JK04H_TP0a8Hd0Wj?H0:n^e`3_gKl0ljej0080mZmh0P3d
[GT04`3f/7P0S4n108=7O`22Agl0m:ih02/HQP0X5hH0BDFZ0;G5iP2[dO@0YLke09g<n02DbOX0TLgl
09?7n@19XoL0P;cj0;cRlP32g>`00P3CZjl0202:Fi@0OU6B0;2OaP3Xb[P0eKBh0=>MWP3U/Ih0jjnB
0P3DWYd01P3U/Ih0k[6>0=2KW`2JJIP0PUFC0>6_XP80k[:@00D0dYbO09m]V02AH9D0hJjR0>ncSP02
0=JNW00A08YGSP1bA8/0PU:@09b>a02<QLH0U8c90:jLa02geo00hl2d0;F[c`2ST/@0VHO009J6`02I
_O40V[O/07OLn01ce_`00P3i[f/02P3g[Fh0QT^108M<PP28C880n:i]0?N]K@3h[V/0n:i/0?R]K03i
[fX20?V_J@030?R]K03g[F`0n:iZ0080n:e[01/0nJiY0?V_J02=GYH0WFZF09aWU02OR;`0WXRk09f7
^`2LQ[/0Y/;]0:G1k@2IgOh0X/Ca0:?0kP2S/n@0Xk;S09oAn@2Pd?T0nKUm0?VhNP3i[FH0n:eW0?V^
I@3j[f80nZmS0?Z^I03h[FH00P3h[6L02@3j[V<0S;;_0;>mhP28/>l0gl_50?[9T`3h^h<0nZiQ0?Z^
H0030?Z^G`<0nZiQ00P0001S07Q^^`2?R<L0_l?M0>gRa@3jc9P0n;f70?ODJ0P0nZeL00H0MFRg08b3
a02EW=P0j=o90?W>W@3j`XT20?Z/F0030?Z]E03j[5T0nZaH00@0nZaH00P0LF>b04TlX01YYO@0XlWd
07Z_m03>d=`0n/J@0?[;U@P0nJ]D00H02PN304bCk`000000YL?_0?RXC02Vcf0?0?VZC`80nJY@0P3i
ZTl00`3iZU80mjMN0?RWB`030?RWB`0D0?RWC028DXX08P]k028;NP0O2GX0nJ]D03<kZ`29EH`0Of>X
0?RWB`3hYdh0n:M@099KS03hYdd0Tef>091JSP2@Fhh0n:M90?RWBP1mZO030?ooo`030000003oool0
oooo02L0oooo000T0?ooo`030000003oool0oooo00H0oooo0P1o@GX00`3kj9/0OT5j0?:bQP040>n_
R00300000@3`[XD0l:j50080l:j500<0000007m1NP1n@GX00P1n@7X03@3d]8<0l:n70?2_Q`3`[hL0
00000814O@21A7d0P4=m0854O@22AGd0kjf500001P0000T00P3b[h430?:`PP80lZn300H0lJj30>fZ
Q03b/880000807m3O020@g`307m3O080P4=l00<0O41k07i0NP1o@GX01`1o@GX0101o@WX0OD1j07i1
NP1o@GX607i1NP0307m1NP1n@GX0OT1j0080OT5j00L0H0Po0607?`1T2d00KA9305T0=@20A7d0Od=m
00D0P4Am0`0000001`27GY/0BcJF08JEfP2Rc?H0/<_^06GGk@21AGh00P22AWh03`21AWh0000_0855
OP21AGh0PTEn0855OP0002T0Q5^J09AVV`16;i8000NH07B]mP38i>`0Vm_m0?>]NP020?J_N080m:ei
02X0m[1h08a?P@23Agl0PTMo0000>00[68H0012L08^im@2ej_L0/]Cb0:_<l@2Wc?<0Y<Sb09g7m@2J
`O<0V<?e05fYn02<b?`0[=?d0=_>c02^]Mh0ZJ?A09>?c02jdnd0T/Gh0=WTg@32/l`0ZkgV0>O9^03F
];P0e9jM0>FaWP3K]k@0d9^O09YYV022EI<0[Y_40>S:]`3M^K@0dYbO09m]V02]V/<20>W;]`0B0>2k
/`3FWY`0Y9?309V9`@2JRl<0Vhg40:;7lP2:__P0N]cj09cLo@2Db_X0TLKi09?2m`28eol0V<Oh09W4
m@2R^NT0jlRa0`3i[f/20?N]KP0808M<PP28C880n:i]0?N]K@3h[V/0n:i/0?R]K03i[fX20?V_J@03
0?R]K03g[F`0n:iZ0080n:e[01/0nJiY0?V_J02=GYH0ZI2k0:N>^`2OR;`0Z/;[0:W2k02Ogod0XmOj
0:34lP2L__00W;W]09;=o03i[VD0n:eW0?R/J03i[VD0nKUm0?VhNP3i[FH0n:eW0?V^I@3j[f80nZmS
0?Z^I03h[FH00P3h[6L02@3j[V<0001O082/l@2g`n<0i/fn0>O?_P3g_8T0n[ao0?Z^H0030?Z^G`<0
nZiQ00P0001S0000M@2?[NX0_LkW0>CDaP3j_X80n;f70?ODJ0P0nZeL00X0MFRg0;:igP2<ZNP0g=7>
0?W>W@3j`XT0n/B<0?Z/F03j[E@0nZaI1@3j[5P0201aHk80R7k20;k7hP24]?@0X<3_0<[8f03f`YD0
n/^E203iZe@01P0:1h<02P1^04RAk`000000dm;G0:K?H0l0nJY?0P3iZU020?VZC`030?VZDP2>EXT0
n:M;00<0n:M;0180n:M<08QBRP0R2g/08P]j08QBRP140E80<c^[08UES00W4Gh0n:M;0?RWCP3hYe00
TU^<0?RWC@2CGHh0T5Z>091KSP3hYdT20?RWBP0507fXk`00000000000?ooo`000000:03oool002<0
oooo0P0000080?ooo`80Od5j00<0OT5j07i0NP3b/XH0103_[hP00`000040l:j50?2^Q@020?2^Q@03
0000001o@GX0OT5j0080OT1j00`0m;B30?2_Q`3`[hL0l:n700000020A7d0PDAm0813O@21A7d0PTEm
0?6`Q00000H30?:_P@80l[2200L0mKB10?:_P`27BGh0lJj30>fZQ03b/880ACZP00D0Od=l00@0P4=l
07m3O01l@7/0OT1j1`1o@GX01@1o@WX0OT5j07e0NP1n@GX0Od5j00H0OT5j00H0Od5j07i1NP1S34<0
IQ580608?`1P1cl30814O@030854O@20A7d0Od=m00<0P4Am0P0000001`1n@g`0001M08EMV`27GY/0
BcJF04=6[`2MWmD00P3cf[D01@21AGh0PTIn0896OP21AWh0000_0080PDEn00/0PTEn0855OP0002l0
Q5^J09AVV`2GUm80UiWC09VPf@3_gKl0`/iC0?>]NP020?J_N080m:ei01P0m[1h08a?P@23Agl0PTMo
03HSS00[68H0C4FY0;S1h@2dcNd0/LW/0:k9k@2]`^X0[lCY0:Nnj@2U_>T0X[g/0::bh`2L^>`0X;_/
09^lk`2B^o<0S/;h08W;o@2I`O<209c1lP0U08O1nP2OgO`0PlSn0:fli@32/l/0/lo^0=oMe02^XL/0
ShS809F<a`2^Vl@0^]3[0;Fae@2`XlX0TXW709F;aP2jdN/0h^?C0;c0g@2dZLd0Y9?30:C2k`2Ta>l0
W>3m0:?Bn02Vb?40YlS`0:C8lP2Ta?00WL?c09nol02L_o40RKKc096dk`2/^nD0]<7T0>k6Z@020?V_
J`030?N]KP3CW9`0Qdb20080n:i]00D0mje]0?R^J`3h[V`0n:e/0?V_JP020?V_J@030?R]K03g[F`0
n:iZ0080n:e[01/0nJiY0?V_J000?l40VHNo0;[5h`2ihO<0ZmGf0:g8kP2[b>l0ZLG]0:G2kP2Q_>`0
n]bW0?V_I03i[VD0n:eW0=NOV`3i[VD0nKUm0?VhNP3i[FH0n:eW0?V^I@3j[f80nZmS0?Z^I03h[FH0
0P3h[6L02@3j[V<0001O0000N01_Yo<0^L[W0>3:``3ka8T0n[ao0?Z^H0030?Z^G`@0nZiQ00L0=1j8
00<`/`2ddNl0]=7_0;3AlP3kaXd0mmAX00P0nZeL00X00P1X07bno02gcN/0//OZ0>7Bb@3ja8/0n/B<
0?S1SP3j[E@0nZaI1P3j[5P01P27aO`0]]G`0;_;i`1l[O<0WKO[0<SCh`T0nJ]D00@02PN300X0KP00
6Il000000P3=bmP?0?VZC`80nJY@0P3iZTl00`3iZU80SUJ90?RWB`040?RWB`0A08QBRP0R2g/00000
08QBRP140E80<c^[08UES00W4Gh0n:M;0?RWCP3hYe00TU^<0?RWC@2CGHh0T5Z>091KSP3hYdT00P3h
YdX01@2nD`00oooo0?ooo`3oool0000002P0oooo000S0?ooo`030000003oool0oooo00L0oooo0P1o
@GX00`1n@GX0OT1j0?:bQP040>n_R0030000003`[XD0l:j50080l:j500H0o=VP07m1NP0000<0OT5j
07i0NP3d]8<30?2_Q`080814O@21A7d0N3ek0813O@21A7d0PTEm0?6`Q00000H30?:_P@80l[2200L0
mKB10?:_P`27BGh0PdIn0>fZQ03b/880OT9l00D0Od=l00@0P4=l07m3O01l@7/0OT1j1`1o@GX01@1o
@WX0OT5j07e0NP1n@GX0Od5j00H0OT5j00<0Od5j0<kdWP1V4DP01P20A7d00`21A7d0P4Am07m3O@03
000000080814O@2FJ9/0LdfF0000G@25GI/0ZJCA0:jQbP2^^^<20=;Vi@0600005`21AGh0PTIn0896
OP21AWh0000_0`21AGh02P000340;1b;000LYP2XY=80/JK=09^ol@2T^NP0W=;k08M;P03c[GX20?J_
N080m:ei00H0m[1h08a?P@23Agl0PTMo03HSS0006:420;[Ck00?0<KNjP2baNP0/<7V0:k0i`2]_NH0
YjOE0:JVeP2UYmL0[[KO0;;7j@2Y_>H0Y:;D0::Re02QZ=/0[;SR0080Z<7[0P2RYMP0802Z^^D0Z;kY
08bjm02:a_`0XjkO0;6hgP2R^NP0Xk_Z08bdl@2Afol0YkCR0;>lg`2T^^T0Y;cZ093CoP2U^NL0/[[O
0:K0k02LaO@0V<gj0:S6k`2[`^/0ZL?/0:_3j`2[/]h0Z[SS0:jli02Z_^P0Z;_W0:BljP2S^^X0XK_/
0P2:/_003P3^aZT0^<CT0>k6ZP3i[f/0mje^0=>LW03h[V`0jk:F0?R^K@3g[Fd0n:i[0?R^K03h[F`0
nJmZ0P3i[fT00`3h[F`0mje/0?R^JP020?R]J`0K0?V^J@3i[fP0nJmX000g^@2ncnL0Wl3`0;k8h`2`
a^/0[;GO0:^liP2T^NL0Z;KS0:ffg`3Ya[80nJiU0?R]I`3GWi/0nJiU0?ViO@3i^7X0nJeV0?R]I`3i
[VD0nZmR0?Z_H`3j[V@0n:eV0080n:aW00X0nZiS0?V^H`0i9H`013Fh06bWm02ab>/0Y]?g0?ZlO`3j
_X<0n[j20P3j[Ul40?Z^H@0707M/^@1<A:L0UJ?N0:_6k@3Fa//0Y;_Z0?ODJ0080?Z]G00:00lBSP0W
4Gl0FIod0;7:k02`c^l0n/B;0?[4S03h`Hh0nMQa0?Z/F@L0nZaH00H0P;;d0;36j`2haN@0Ljkf0?K?
Y03ja8d90?V[E00506iM[P15>9`0EYK_0000001jeod03`3iZTl20?VZD080nJY?00<0nJYB08iFR@3h
Yd/0103hYd/02028DXX08P]k00000028DXX0A05B03<kZ`29EH`09a5n0P3hYd/01`3hYe00TU^<0?RV
EP3iZU<0TE^>091KSP3hYdT00`3hYdX01@1lZ>l0oooo0?ooo`3oool0000002L0oooo000S0?ooo`03
0000003oool0oooo00L0oooo00D0Od5j0000001n@GX0OT1j0?:bQP030>n_R00305LgS`000040l:j5
00<0l:j50140o=VP07m1NP000000OT5j07i0NP3`[hL0l;270?2_Q`26BX00P4Am0854O@1h?G/0P4=m
0854O@22AGd0lK2400001P030?:_P@80l[2200P0mKB10?:_P`3a[X<0PdIn0>fZQ03b/880OT9l0813
O0@0Od=l00D0P4=l07m3O01l@7/0OT1j07m2NP0607m1NP0507m2NP1n@GX0OD1j07i1NP1o@GX01P1n
@GX00`1SfM40Z;kY0854O@060814O@<000000P20A7d02@2?Hi/0TFFK09IXV`1cCIH0Ac:E08RDf@2S
c?D0/<[]06[Il0020897O`0C00005`21AGh0PTIn0896OP21AWh0000X0855OP2IJ9P0SEjE0758T@0/
78/001bV08>hm`25dOl0XjcM0<O9f`3e[gT0Qd^00?>]NP020?J_N080m:ei00l0m[1h08a?P@23Agl0
PTMo03HSS01BBZ/0IW[C0:feg`2g`N40]l;S0;;2iP2YYM<0Z:CB0:VXeP2Y/]h00P2cfo@05P23Ah00
mJeg0:J/f`2][mT0/][e0;_Ek@23B800T[C^0:F]g@2//=/0/M_f0?B/MP24BH00SkKa0:>^g`2eeO40
m:ae08A9P@23B840S[Wc0:B`h02fe_020?J]L`0H0?N_LP2F`?@0/Lo_0;Ofl@2__nD0[[CM0;Fhf`2d
`nD0ZZ[G0:VXeP2a/mX0/KOM0;S:i`2^^^<0ZZ_G0;>ae`2/]n40YkSU0:Bhi`2>/^l0]lCT0>k7Z`2h
a><0k[:?0P3CW9`0203KZJ<0jk:F0?R^K@3g[Fd0n:i[0?R^K03h[F`0nJmZ0P3i[fT00`3h[F`0mje/
0?R^JP020?R]J`040?V^J@3i[fP0nJmX0?R]J`80Z=?f00@0[_WV0:jdg@2^]=d0_/KP0P2H/^T00`3Y
a[80jlN`0?2fT0020=NOV`0:0=:SY`3i^Gd0nKQj0?V]IP3h[FL0nJiU0?_1Q03j^W`0nZiT0?R]IP80
n:aW00X0nZiS0?V^H`0J8Y`0CTNY096Qg`3`i/80nl^D0?ZlO`3j_X<0n[j20P3j[Ul40?Z^H@0707M/
^@2g`^<0U[3Y07N^m@2K`o@0M;Sk0?ZoQ@080?Z]G00:00lBSP0W4Gl0B3jR05nRm02Zd?@0f]GC0?[4
S03h`Hh0nMQa0?Z/F@P0nZaH00D0[[kU07^/l`39amP0m/nT0?[4S@090?V[E00506iM[P23M[`0_koJ
0?C@ZP0000003`3iZTl20?VZD0<0nJY?00<0nJYB0?RWB`3hYd/00`3hYd/02028DXX08P]k00000028
DXX0mjY20?V[E023HZD0m:Hj0P3hYd/01`3hYe00TU^<0?RVEP3hYdh0TE^>091JSP2@Fhh0103hYdX0
101lYnl0oooo0?ooo`00000W0?ooo`008`3oool00`000000oooo0?ooo`060?ooo`050?_AV`1o@GX0
nnRK07i1NP1n@7X0103_[hP00`00000000010?2^Q@030?2^Q@0A0000001o@GX0nmVP07i1NP1n@7X0
l:n70?2`Q`3`[hL0QTZ00814O@21A7d0N3ek0813O@21A7d0PTEm0?6`Q00000H00`3b[h420?:`PP08
0?FdP@3b[h<0lJj308=6OP3]ZX@0NSik07m3O020@g`407m3O0030813O01o@g`0O41k00P0Od5j00D0
Od9j07i1NP1m@7X0OT5j07m1NP0307i1NP80Xj[L0P2m_MX00`20A7d0PDAm0814O@020814O@<00000
00h0PDAm0814O@20A7d0UV^N09]^W@2?Hi/0TFFK09IXV`1cCIH0Ac:E03m3[P2LWmH0lmZd08M;P080
PTMo01<0P4En0855OP22AWh0PTIn0856OP21AGh0WfjJ09UXV02=GYD0LDRA0000D@2NY]/0[k?K09Zh
k@2R/nD0VmKl0?F_N@27Bh00ljej0080mZmh0P3d[GT01P3f/7P0S4n108=7O`22Agl0m:ih07]ja`80
a/?G00L0^^?c0897O`23Agl0W[GX0:Z^fP2ldn/0lJUj0080PdR000D0PdN00?F]M`3aZGT0lJUi08A8
P00308=8P00;0?F]M@3f[g@0m:af0?B/MP24BH00PdR00?F]M03_/8/0m:ae08A9P@23B8400P3e[G@3
0?J]L`030?N_LP3e[7@0mJad0080Q4V100@0?;S]0?N_L@2km_00V/3c0P2ldNX00`26Bh80Qdb208M<
PP020;;9j`0B0;[dl@2VZ]X0/;;J096^jP2B]Nh0^LCS0;RngP3Vb;T0djnd0=>LW03KZJ<0jk:F0=JQ
WP3KZjD0jk>H0=JQW`3h[F`0fJZW0P3i[fT00`3h[F`0mje/0?R^JP020?R]J`030?V^J@3i[fP0nJmX
0080n:e[0P3i[fP0503h[FX0n:e[0?V^J03i[fL0TJo[0;bog@3[bK80i/fm0=Vf]@3GWi/0dZ>W0?^k
N@3i^7X0nJeV0?R]I`3i[VD0nl640?ZjO03j[V@0n:eV0P3h[6L02P3j[V<0nJiS000BW`2g_=d0UZoX
0>;?a@3j^W/0n[ao0?ZnP`3j_X820?Z^G`D0nZiQ00L0UL_j0;S>jP2c_n<0nLfI0?ZoQ03j_hD0n/68
00L0nZeL00X0nZeM07AU]02:PL@0U9gJ08Ffm@2Ua?00Y<;_0?JoT@3if740nZaI203j[5P0101`Y_80
[L3W0=_@cP3LdLh20?[6T0T0nJ]D00D0PioU0;?9jP3Dd]H000000?W9U@0?0?VZC`050?VZD03iZTl0
nJY?0?VZC`3iZU801@3hYd/0203hYd`08P]k08QBRP0R2gX07`Uj0?V[E023HZD0m:Hj0P3hYd/0203h
Ydh0TU^<0?RVEP3hYdd0nJYE091JSP2@Fhh0n:M90`3hYdX01@2lD@00oooo0?ooo`3oool0000002H0
oooo000S0?ooo`8000001`3oool207m1NP030?_XV`1n@GX0OT1j00@0kjn800<0000000000@3`[XD0
0P3`[XD04P3jej@0OT5j07i1NP3kfJ00OT5j07i0NP3`[hL0l;270?2_Q`26BX00P4Am0854O@1h?G/0
P4=m0854O@3_[HD0lK240?NdO@<0lZn10P3b/880203b/8<0lZn30?6^P`21AGd0lZn207XnN`1o@g`0
P4=l101o@g`00`20@g`0Od=l07a0N`0807m1NP0>07m2NP1n@GX0OD1j07i1NP1o@GX0OT5j09nFb`2O
W]<0ZKoY09fhj`2V]N@0Y][j0814O@21A7d3000000@0P4Am00T0OT=m0000A02FJih0VfjM08mSV`2A
II/0WiC809jAaP2LT<L00P2]^>801P2YiOX0Qd^00897O`22Agl0P4En0855OP80PTIn00/0P4En07]C
U`2EJ9/0VFRH08eNU@1aB940=3JU08>fmP2Ghod0lmbg0?>iS@020?F_N@80ljej0P3f[gP20?B]N@0:
0?J`N02<Ch40PdMo0897O`3d[WP0RJk^0;C]m`1Aao00PdMo0897O`80PdMo00<0mJig0?6`Q@3aZGX0
0P23B8001023Ah00mJeg0?6YN@3aZGT408=8P0050?F]M@3f[g@0m:af0?B/MP23B8000P3e[G@0103_
/8/0Q4V108=8P@2BH9@20?F]M0<0mZec00@0mjmb0?F/M024BH40Q4V10P3f[G<20?J]LP040?J]L@3g
[W00Qdb208I;PP80Qdb20180mZea0?N]L03g[Vl0mje`0:k9k@2fm?<0V[O/09nbi@2m`Md0eLgA0:bX
d`2jX/40hLJm0=Zj^@2oZlH0fj^U0>79`03K_;X20=VZY`80nJmY00H0n:e/0?N]K03h[VX0n:e[0=RR
W@3i[VT20?V_J080n:e[0P3i[fP00`3h[FX0n:e[0?V^J0020?V_I`0?08NVj@33bMl0fm?A0;6bf@2i
XL00hLFk0>_D_P3`^ID0eZ2M0?R]I`3i[VD0nl640?ZjO03j[V@0n:eV0080n:aW00L0nZiS0?V^H`3i
[FD0SLCj0;k>iP3Wckd0j<nm0080n[j30P3j_X800`3j[Ul0nZiQ0?Z^H@040?Z^H@0407j^l`2d`><0
]/CU0?ZmP@<0n/681P3j[E`20?Z]G@80_MC/00H0_=3Y08Bcl`3?a=00X;SY0?[2R@3j[5T90?Z/F003
05RJl@2]aN`0f];@0080n/J@00<0n/N@0?V[E03iZe@01`3iZe@01@2X`nd0e];D0:O4kP000000nLVF
00h0nJY?00D0nJY@0?VZC`3iZTl0nJY?0?VZDP050?RWB`080?RWC00R2g/0R5::028;NP0O2GX0nJ]D
03<kZ`29EH`20?RWB`080?RWCP3hYe00T5V<0?RWC@2CGHh0T5Z>091KSP3hYdT40?RWBP0507bWk`3o
ool0oooo0?ooo`0000002P3oool6000000@0oooo100000050?ooo`@00000103oool00280oooo0P00
00080?ooo`80Od5j00<0nnRK07i1NP1n@7X0103_[hP00`00004000000?2^Q@020?2^Q@060?[GY01n
@GX0OT5j0?_IX01n@GX0m;B30`3`[hL02@000000P4Am0854O@1:=9D0P4=m0854O@3_[HD0lK240?Nd
O@030?:_P@80l[220P3b[h<01P3a[X<0kJZ40?:`PP1j?W/0Od=l0813O0@0Od=l00<0P4=l07m3O01l
@7/0201o@GX02`1o@WX0OT5j07i1NP2OV<`0X9S<0:2Gb`2Z`n/0Yl;]08GXk`21AGd0PDAm00<00000
1@20A7d02021A7d0UVNJ06i9U00005d0UV^N0;:[d@2QWm80XI_>0P2S_^d01@1li?00N^?^0?:]OP3d
[g`0Qd^00080PTMo00l0P4En0855OP22AWh0TF6E0000;`1kDiL0UFRK09UXV02=GYD0WIK<09>Bc`2F
Wm/0e<kC0;>lh@3c^Hd00P3e[gT0103c[GX0m:ii0?J_N03f[gP20?B]N@060?J`N02<Ch40PdMo0897
O`3d[WP0mJmg0P3_Z7`00`23Agl0PTMo08=7O`020?F^M`040?6`Q@3aZGX0PdR008=7P080mJeg00H0
lJUi0:A_UP26EY00MdfB08=8P02QKYP20?J_M00;0?B/MP2GIIL0Q5JC0?F]M03g[g<0kk2;0=:KW02J
J9H0TV2D0?F]M03g[g800`3f[G<0103g[g80mJad0:5]UP2@GY<20?J]L`070>b`T@3f[G40mZea0?N^
L03f[G40QT^208M<PP020?J]L@040?N]L03g[Vl0mje`08I<PP80R4f201D0QTb208Q=PP28CH<0M;Wk
09J_j02kg?40[^7h0;>kg`3QbL00//?W0=^l^P2nZlH0j<Rf0?V_J@3^]I80e9jL0?N]K03h[VX0n:e[
0=RRW@3i[VT00P3i[fP20?R]J`80nJmX00<0n:eZ0?R]J`3i[VP00P3i[fL03`3h[FX0Tl_k0?V^J019
`O00Q:c_0>_D_P2`an/0f[Vh0=JPW@3AY:P0n;^60?_1Q03j^W`0nZiT0?R]IP020?R/I`090?Z^H`3i
[V<0nJeU08Q>Q01d[OD0^lcW0;[;i`3Vd;l0n[j30080n[j200<0nZiO0?Z^H@3j[V401@3j[V400`1/
Y_@0iM320;O9j0030?[1R0030?[1Q`3j`HH0nZeL00<0nZeL0P3j[Ed02025aod0//SZ08Nfm01bZO@0
Ukoc07gLo03j`XT0nZaI2@3j[5P0100B3HH0[<G/0:c5k02/a^d20?[7T0030?[6S`3iZe@0nJ]D00H0
nJ]D00H0CYC`0:O4kP2W`nh0nLVF0000003ibIH=0?VZC`060?VZD03iZTl0nJY?0?VZC`3iZU80mjMN
103hYd/0203hYd`0R5::04<2D`0R2gX07`Uj0?V[E00c>j/0REF<0P3hYd/0203hYdh0n:M@091IS03h
Ydd0Tef>091JSP2@Fhh0n:M91@3hYdX0101mYnl0oooo00000000000:0?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`010?ooo`008`3oool00`000000oooo0?ooo`060?ooo`80Od5j00<0nnRK
07i1NP3b/XH0103_[hP00`000040l:j50?2^Q@020?2^Q@030000001o@GX0OT5j0080OT1j00d0m;B3
0?2_Q`3`[hL0l:n700000020A7d0PDAm04XdU@20@gd0PTEm0>n]Q@3a/8@0mkAm00<0lZn10P3b/882
0?:_P`060?6^P`3]ZX@0l[2207XnN`1o@g`0P4=l101o@g`00`20@g`0Od=l07a0N`0807m1NP<0WiS=
0P2U`^h207WSk0070855O@00000000000000001o@gd0P4Am0854O@040814O@0@08iRVP2AI9/0UVNJ
06i9U00005d0RYOJ0:b[eP2bd>l0RmKo06oOhP2V_>T0m:mm08Q<P03b[Gh0m:ml08M;P080PTMo00l0
P4En0896OP2MK9T0TF6E03/US01kDiL0UFRK0;BWc02SW<d0XlKb09VolP2Je?`0Ll_o0??0VP3c^Hd0
0P3e[gT02@3c[GX0m:ii0?J_N02>DH40m:ei0?F^N03f/7P0S4n108=7O`020?B^N00S0?F_M`3_Z7`0
PdMo0897O`23Agl0Xg6I0?F^M`3f[gH0lK2508eNU@25Ei@0UVFF0?F]M`3f[gD0lJUi0:A_UP26EY00
MdfB08MKU`2QKYP0hjjM0?J_M03d[7H0UfFG08AFT`3e[G@0hJbN0>n`R`3BVi`0VVRF099PU03e[G@0
mjmb0?J]L`3GWi/00P3g[g801`3e[7@0XFfF091NT`3f[G<0mjma0>b`T@3GWi/00P3g[W020?J]L@03
08M<PP3f[G40mje`00<0mje`00/0QTb208Q=PP28CH80QTb208Q=PP28CH<0Qdb20?N]K`3h[fd0nJm/
001Kd`020;G7j0080;:mh@2``nP0QkCc0:kBl`3F/kD0e9jL0=VXY03/]9H20=RRW@030=RXYP3i[fP0
nJmX0080n:e[0P3i[fP00`3h[FX0n:e[0?V^J0020?V_I`80n:eZ00<0nJiX0?Z`I03i[fH00P2od^T0
4`3Ge=H0/[OM0;^U``3Pb<40n[]m0?ZjO03j[V@0l[V@0=fSUP3h[6L0nZiS0?V^H`3i[FD0R4j40000
H@1`ZoH0^/_W0;W;i`3Vd<000P3j_X800`3k`XH0nkQe0?Z^H@060?Z^H@80]/SX00H0hm350?[1R03j
`HP0n/670?[1QP3j`8D30?Z]G0<0nZeM00@0QkKd0;73i`2k`n00n<nP0P3j`XT00`3j[5T0nZaH0?Z/
F0070?Z/F008018=QP0706`0ZlK]0=[Bd@2[a^d0n/N?0?[6S`3jaXh70?V[E0060?V/E01?U?00Y/?^
0:K3kP3ibIH000003@3iZTl01P3iZU00nJY?0?VZC`3iZTl0nJYB0?NWGP@0n:M;0180n:M<08QBRP13
0U<08P]j01l9NP3iZe@0<c^[08UES00W4Gh0n:M;0?RWCP3hYe00TU^<0?RWC@2CGHh0T5Z>091KSP3h
YdT50?RWBP050;aA003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0040
oooo000R0?ooo`030000003oool0oooo00L0oooo0P1o@GX00`1n@GX0OT1j0?:bQP040>n_R0030000
0@3`[XD0l:j50080l:j500H0000007m1NP1n@GX0OT5j07i0NP3d]8<30?2_Q`0900000020A7d0PDAm
0813O@21A7d0PTEm0>n]Q@0000H000090080lZn10`3b/8820?:_P`060?6^P`3]ZX@0l[220000201o
@g`0P4=l101o@g`00`20@g`0Od=l0000400507m1NP030::Vf@2QXmL0X9oC0080X/?`00<0MN;Y073O
iP3c/7l00`0000020855O@030854O@1o@gd0P4Am0080P4Am01<0SF6J08aQVP2=HIX0SV:J095TV`2F
IiX0KTVD04<`U016O^<0XjgO0:B[g02h^]/0lmVd0?:]OP3d[gd0R4b00?:]OP3d[g`0Qd^00080PTMo
00H0PDEn09U/W@2MK9T0TF6E03/US0000iH20:gFm@0C0:K/n@2Oc?L0WlCb0:o1i`3c`9X0m;Z>0?>i
S@3e[gT0e9ZG0?>]NP3d[WT0mZmh08iAP@3d[GT0mJih0?J`N023Agl0WF^H0?B^N0020?F_M`0P0>nX
O02NJiL0O52B07YAU02SLIT0mJig0?J_MP3a/8D0ciVM08EGU02FIIH0mJeg0?J_M@3aZGT0Y6nF08IF
T01gCI80Qe^G0:5^V03S[Yd0kk2;0=6KW@2GIIL0Q5JC0?F]M03Q[9h0kk2;0=:KW02JJ9H0TV2D0=n/
W`3//9420=NOV`0;0>:]W@3g[g80e9fK0:5]UP2@GY<0mZec0?N_L@3//940einK0=n[W`3g[W000P3f
[G401@3g[W00mZea0=NPW03g[G00jk6C0080mje`00l0R4f20?N]L026C880R4f20?N]K`27C880mje_
0?R_K@3i[f`0mZe`005Dd033d^H0Yloe09_1l`2ka>400P3GdM<20;bU`P040>78`03M_KT0f::M0=RX
YP80nJmX00L0eYjK0?R]J`3i[fP0nJmX0?2fT@3h[F/0nJiX0080nJmW0P3h[FX04`3i[VP0n[1T0?V_
IP25^OL0^<SV09:bk023/_<0ZKkY0:?:m03Uc;h0n[Yj0?Z^I03b^I00gJ>F0?R/I`3j[V<0nJiS0?V]
I@28CX@00P0006401`1/ZoH0^L_X0>OB`03j_X80nKb30?_2QP3k^7D01`3j[V40201ZY_@0]LWY06VV
m03SdLD0n/680?[1Q`3j`HH0n/250`3j[E`40?Z]G@0608:`lP2a_^@0glo80?[0QP3j`XT0n/B=2@3j
[5P01P0B3HH01`1/04nHl@2Zb_40g=WD0?[6S`80n/J>1`3iZe@20?V/E00504jDl03DdML0Y/?^0000
003ibIL0303iZTl01P3iZU00nJY?0?VZC`3iZTl0nJYB0?NWGP@0n:M;0180n:M<08QBRP130U<08P]j
01l9NP140E80<c^[08UES00W4Gh0n:M;0?RWCP3hYe00TU^<0?RWC@2CGHh0T5Z>091KSP3hYdT60?RW
BP0507fVkP3oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0040oooo000R
0?ooo`030000003oool0000000L0oooo00D0Od5j0000001n@GX0OT1j0?:bQP040>n_R0030000003`
[XD0l:j50080l:j500H0o=VP07m1NP0000<0OT5j07i0NP3d]8<30?2_Q`0800000020A7d0PDAm0813
O@21A7d0PTEm0?6`Q00000H30?:_P@80l[2200T0mKB10?:_P`3b[h<0lJj30>fZQ03b/880000807m3
O020@g`01@1o@g`0101l@7/0OT1j07m1NP1o@GX20:BXf@070::Wf@2Rb?<0WLKd08GGo`3gfJd0lZn1
0?2]P@02000000030?6]P@3b[h00PDEm0080PDEm0140PDAm0814O@21A7d0VFbL08iRVP2=HIX0S66J
08eQVP2>HYX0TFBK09IWVP2NTLH0V93909VHd@2Y_>L0W[KY0:GDn0020?:]OP050?B_O@28C800lZen
0?B_O027Bh000P22Agl04P26GI/0VFbM09e/V@2AHID0>bF<038gYP2K^Nd0Zlcb0:K;l`2Ma?<0Q;Wg
09nlk@2O_^l0lkV=0?6jU03e[gT0e9ZG0?>]NP80mZmh00l0eIbJ0?B]N@3e[WP0m[1h08ULU`26FIH0
m:ih0>F_V`3e[gL0kjQl09i[U`1lD980NU6D0:=aV@3e[WL00P3a/8D0403?VId0QEND09IUUP3e[GL0
lK250=6JW02TKiH0QUJ@07M=TP27FiL0XFjH0>>^W@3K];40dI^M09MUU`24EY<20>6/WP0>0=^d/@3B
Vi`0VVRF0:bD_P3O[9l0ilNf0=Rd]@3GWi/0hZfM0>naR`3DWI/0XFfF091NT`3MZJ020>b`T@0:0=NO
V`3OZil0jk2B0=NOV`3f[G40mji`0?J]L@3GX9`0mji_0>^aT`80mje`00D0n:i_0?N]L03g[G00R4f2
0>baTP020?N]K`0D0?R_K@3i[f`0mZe`08M=P`28CH<0R4j308M=P`2Rc_L0W_CS0;CJl`2;]?80/L;V
0=KLg02f_^00_jW40>oE^03]dKL0kkFB0=JNV`3h[F/20?V_J0030?2fT@3GWiX0nJiX0080nJmW0P3h
[FX02@3i[VP0nkeo0?V_IP3i[fL0XLcf09kei02SfOX0Q;Cd0;6ni0020>S=^`080?Z^I03b^I00gJ>F
0?R/I`3j[V<0nJiS0?V]I@28CX@20000H@0903TeX@2hd>`0^=3/0;KCk`3h^hH0nl:60?^hM@3k^7L0
nkUg00D0nZiQ00P00@1W06VVm02ebNT0hm750?[1R03j`HL0n/660?[0Q@<0nZeL1@3j[Ed01P2baNP0
I:7b0>3Ab@3j`XT0n/B=0?[4SPP0nZaH00H04Pf606mL[@12=Y`0IZGd0:G?mP2SboD20?[6SP030?[5
S@3iZe@0nJ]D00@0nJ]D0`3i[5@01@2V`nh0e=7G0?W9UP000000nLVG00/0nJY?0P3iZU020?VZC`03
0?VZDP2>EXT0n:M;00@0n:M;0140R5::04<2D`0000007`Uj04@1DP0c>j/0REF<02LAOP3hYd/0n:M=
0?RWD02BFh`0n:IF09=MSP2@FXh0T5^>0?RWB@070?RWBP0407bRj`3oool0oooo000000/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`010?ooo`008P3oool2000000L0oooo00H0nm6K07m1NP3kj9/0OT5j
07i0NP3b/XH30>n_R00305LgS`000040l:j500<0l:j500L0o=VP07m1NP3kfJ00OT5j07i0NP3`[hL0
l;270080l:n700P0P4Am0854O@1h?G/0P4=m0854O@22AGd0lK2400001P<0lZn10P3b/8802@3e]840
lZn308M9OP3a[X<0kJZ40?:`PP1n@W`0Od=l0813O00307m3O00<099VV`2DIYX0I4:D0006V02b/mX0
/K3G0:G:l`2bd_00WMgm0::[g@2PXmL0`;gH0`000000103`[H40lk1o0?6]P@25BGl30855O@0?0854
O@22FY/0Uf^M09U/W02>HYX0SF6J08aQVP2=HIX0SF:J09fBa`2OT/H0Y[gZ0:Vnj@2Jk?P0QDUo0080
PTIo0P3b[Gh01@3d[gd0R4b00?:]OP3d[g`0Qd^00080PTMo02T0QUfK09U/W@2MK9T0YIW90:6GbP2e
b^X0]Lc[0;CCl02Xa>h0Y/7]09fnl01^ZoH0eLcA09o1l03X_ZX0bj2]0=BJU`3W[YH0i[n_0?J_N03E
W9X0m:ei0?J`N038U9l0REbG08IIUP3d[WP0iJnK0?6_Q03<UYh0WV^G07a@TP1jDI@0Xg6I0>F_V`3Z
a:l0fK6`0<nIW@25Ei@0UVFF0>B^V`020=Zb/0070:A_UP26EY00VHJn08V1a02bW<40jLJa0>?KcP02
0:jJ``0I09J5_P2]U;d0i=c=0=^d/@2`WL@0T8C209J7`P3WakH0^lcW0=Rd]@31Z/80ilFc0=ff/@3D
WI/0XFfF09B4_`2YTK`0i/Nh0=Vf]@3GWi/0gj^O0>^`TP3GWi/0gZZO0>^`TP020=NPW0050=jZX03[
/I<0mje`0?N]L03h[Vl00P3g[G007@3h[Vh0k;6B0=VQV`3g[Fl0n:m]0?V_K03f[G00mje_08Q=P`28
CX<0Qdf30?N]KP3h[V`0nJm[0?N]K`2E/^/0^/;P09^lk`27]?<0[=3c0;;8jP3H];@0eYjK0=FTY@3U
aKL0nJmX0?2fT@3GWiX0nJiX0080nJmW0P3h[FX0103i[VP0nkeo0?V_IP3i[fL20?R]JP0I0?N/J`3i
[VP0Q:oa0;[5hP3/c[L0jljg0?:iT03MXiH0dj:S0?Z^H`3i[V<0nJeU08Q>Q00006400@1k03TeX@14
I/l0KJoh0>7=a02/b>h0nZiQ0?^hM@3k^7L0nkUg0?^hM`050?Z^H@06028=O@1UY_D0]LWY0;G;jP3j
`HL0n/660P3j`8D20?Z]G0H0nZeM00H0/LOZ0;76jP3OdLX0n/B=0?[4SP3ja8d80?Z/F00706mL[@23
Mkd0_<KR08:fmP2RaO80XL?a0?[6S@020?[5S@D0nJ]D0`3i[5@01P1>U?00Y/?^0=CBe`3ibIL00000
0?W9U`X0nJY?0P3iZU020?VZC`030?VZDP2>EXT0n:M;00@0n:M;00P0R5::028;N`000000R5::04@1
DP3iZeH0REF<02LAOP80n:M;00L0n:M@099KS03hYUH0nJYC095KSP2@Fhh0n:M;00L0n:M:00D0b600
07D0002hDDT0KK[m0000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00@3oool000@0oooo1000
00060?ooo`8000001P3oool4000000P0oooo00<000000?ooo`3oool01P3oool207m1NP030?_XV`1n
@GX0OT1j00@0kjn800<0000000000@3`[XD00`3`[XD04@000000Od5j0?_IX01n@GX0OT1j0?2_Q`3`
/8L0l:n708I:P020A7d0PDAm07PmN`20@gd0PDAm0895O@3a/8@0000600<0lZn10P3b/8801`3e]840
lZn30?6^P`23AWh0kJZ40?:`PP1n@W`00P1o@g`208iSV`0:08eRV`2BIY/0U6JJ06A2U012<iT004[9
0:?Xn`2@gOh0YJgM0:Bjj@<0000000L0lZn108I9O`3`[H40l:f10?>`O`3b[h00P4Am0080PDEm0100
PDAm07i3O@22FY/0Uf^M09U/W02>HYX0XIoB09nLd@2NV<d0X[o]0:Bnk01li?00N>;]0?B`O@3c[gd0
QDUo0P22AWl20?:]OP050?B_O@28C800lZen0?B_O027Bh000P22Agl04026GI/0ZIW60;:Oa@2^a^`0
[/O/0:cNn@2abN`0[/;Y0:boj02Y_nX0Y[3O09ndi`1gZo<0X<Kc0;S;j03@_lX20<N^`@080>Jo[`3A
Zk40eIbJ0>N_V03E[K00b9BO08ULU`26FIH20>F_V`0N0=N_/03<UYh0WV^G09Z:`@29Q<P0W9;90;NP
`P3TfL/0fK6`0:nOb02;PlD0/Y_00>[5[`2ocnH0f[:`0:fI`P2IQK`0VHJn08fel@2Ma?<0/>Kh0;Nn
g`2d[=00[Y[309>]j02jko@0V>Wj0;[7i02f[Ll0ZKGQ0P2Df_h03P2Y^^H0/k;H0;[9i@2K^nh0/NGh
0;R^c`2BPkl0U8Bo0;W;i`3KgmT0/k;H0<2Y`P3Ua[P0fKFe0P2oY/00503TaKP0fKJe0=NPW03NZZ00
jk6C0=RPV`3MZJ00k;6B0=VQV`3g[G00gJVP0>baTP3IXI/0mje_0?R_K@3i[f`0mZe`0?N]K`28CH<0
mje_0P3g[Fh03@3h[V`0nJm[0?N]K`3g[Fh0YLge0;?fl02Ma?<0Vk7W0<7Ai`3Gd=80/[7G0;ZQ_`3^
d[P00P3`]Y40103GWiX0e:>T0?V_I`3i[fL20?R]JP040?V^J03k_Gl0nJmV0?V_I`80n:eZ00<0mja[
0?V^J03i[fH00P30cN@05030bn<0g[Zc0;jR_@3CXZ<0hlFj0?V^H`3/^j00R4j40000H@007:@0JEjc
0:o8k01j[oD0YKcZ09[5m@1Xf^X0nkQe0?^hM`3k^GL0nkQg1@3j[V401P0R3Gd002R^066UmP3Ue/L0
/m?`0?[1QP80n/2500<0n/260?Z]G03j[Ed01@3j[Ed00`1RXO<0/LOZ0;77jP020?[4SP030?[4S@3j
[5P0nZaH00L0nZaH0P2ke>`01032e^P0XL;a0:72l@3@dMX30?[5S@@0nJ]D0`3i[5@01P3iZeL0CYC`
0:K3kP2V`nh0nLVG000000X0nJY?0P3iZU020?VZC`80nJYB1@3hYd/02028DXX08P]k00000028DXX0
A05B0?V[EP29EH`0m:Hj0P3hYd/01`3hYe00TU^<0?RVEP3hYdh0TE^>091JSP2@Fhh0203hYdX01@3U
Ocl0^55908V^kP3oool0000000H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0040oooo
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo0P1o
@GX00`3kj9/0OT5j07i0NP040>n_R003000000000040l:j50080l:j500H0n]NT07i1NP1n@GX0nmVP
07i1NP1n@7X30?2_Q`0908I:P020A7d0PDAm07PmN`20@gd0PDAm0895O@3a/8@0000600<0lZn10P3b
/8802@3b/8<0lZn30?6^P`23AWh0kJZ407XnN`1o@g`0VVjN09M[W@0208iSV`0708eRV`2BIY/0U6JJ
06A2U02LUlh0WYkD0:6Wf`030000000G0?:_P@24B7h0ljn00?:_P@26BGl0l:f10?6]P@3c/7l0lZn0
0814O@21AGd0X72L08eNUP1U@I40PUZK0:j[e02`ZM40XIoC0:?8l`2Na_@0P]Ko0=_Fd`3ffk000P3d
/7d00`3b[Wh0ljmm08E9O`020896O`80lZen00D0m:mm08Q<P03b[Gh0m:ml08M;P0020897O`0?0?:]
O@2ia><0U;O_0;c]m02]]n40]KWL0<;9g`2a`^L0ZJKC0:RWe02_]ml0[kWQ0:o7j`2QZmh0XZcN0080
Mjgd00H0[mcg0=WCd`2_[]H0aZg10>S1[@3QdlX20:ND``0709Z<``2gW[l0hmK:0=N_/02ZU/80WXVn
09^8_P0208bgl`0G0;?Wm`2Gg_h0]kgO0:BljP29/o80UMgn08_?oP2X]n<0]:[?09nbi@2W]N<0Y^Sk
08gXm`2R^n/0YJoO0:RagP2CdOd0RmKo08A:P@24BH40m:ef0?B`OP1?^oT00P2cl_@06P2H^^l0]M;_
0;GBk`3d[7H0mJee0?B`OP2S/>40]=7_0:K3kP2S^>P0ZK3M096/j02I^>h0[n?h0:S8l02b[mD0^KoN
0=_KeP3I][D0_jK00>C5^@3J]kD0_jJo0=fYX03TaKT0fkNe0P3MZJ004@3//I80fJ6K0?N]K`3i/6`0
nJm/0?J]L03g[Fl0n:i]0>faT03KXYT0mje^0?R^K03i[f/0mje_0?N]KP3h[V`0nJmZ0080mje^00T0
mja^0?V_JP28[Nh0]LWY07Z^m03Xc[`0fKFd0;^Q_P3DXj@00P3i[fL01P3IX9T0n:eZ0?V^J03k_Gl0
nJmV0?V_I`80n:eZ00<0mja[0?V^J03k_Gh00P2<[N`03037fnP0aNK^0;Zhe`3SaKX0/;WP0>oB]P3/
^j00`9nf09]k[P1TJ/<095W?09ODo@80Wkg^0P3j[V40103k^7D0nkQg0?^iM`3k^7L50?Z^H@0601`J
T@13?:<0CfO<0:_>lP1m]OL0ZLO_0P3j`8D00`3j`8H0nZeL0?Z]G@060?Z]G@0406:Ql`2aan/0gm7;
0?[4SP80n/B=2@3j[5P01P2bbN/0_<gW0;;9k02P`_00cm7J0:31l080n/F=103iZe@30?V/E0070?V[
E`2=E8P0CYC`0=CBe`2V`nh000000?W9UP090?VZC`80nJY@0P3iZTl20?VZDPD0n:M;00P0R5::028;
N`000000R5::0?NZ@P3iZe@0Pf:U0?BV>P80n:M;00P0TEZ<099KS03hYUH0TU^<0?VZE@2@FXh0T5^>
0?RWB@L0n:M:00D0n:M;0?RWD`2:[^h0RZo^000000060?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`80Od5j00<0nnRK07i1NP3b/XH0
103_[hP200000@<0l:j500H0n]NT07m1NP1n@GX0nmVP07i1NP3d]8<30?2_Q`0908I:P020A7d0PDAm
07PmN`20@gd0PDAm0>n]Q@3a/8@0mkAm00<0lZn10P3b/8820?:_P`070?6^P`3]ZX@0lZn20000G`0D
07@0VVjN09M[W@0208iSV`0408eRV`2OVLh0WiK;09nEb@<000000200lk200?>`P@3c/840lZn10>n[
PP3c[h00lZn108I9O`3`[H40lJf10?>`O`3b[h00PDEm09]^WP2PL9`0SEjF06E1T@0]?:l0SYWJ0;3G
m02JjOX0XJoR09nXg@2j_=/0m]^`0=OOgP3d/7d0m;^?0?:^OP3c[gd0QDUo0896O`<0lZen00D0m:mm
0?:]OP3b[Gd0m:ml08M;P0020897O`0>0?:]O@3c[W`0m:ml0?:]O@3c[G`0W=Wm08M;P@34h^d0X[CU
0:f`fP2be?40mJmj08U=P@3b[G`20;G9j@0=0;cRlP2PZMd0Yk;P08V^kP2Q`O00V=on0;>hg@2^X/`0
YiC309Baj`31k_40WNci0;Nlg@020:Jah080Z>Sj00H0UnSk0:J`g`2V/=l0XMWk0;OEk`3d[GT209^d
j@030;CBk`2BdOd0Q4V100@0Q4V100D0I/?n0?J^MP3g/7@0Q4Z108A9P@020?B]MP030?B`OP3]YG`0
QDZ200<0m:ef0P3d[7H01`3e[GD0m;1n0>nVNP1mCHd0Seb@09Rll@2Sbo@00P3d[7@01@3e[G@0kjn9
09O?n`2Gco/0[OGa0080V[7X0P3Lg=H05`2e/MD0i<Fi0=cLeP3K]kD0`JW10>C6^P3K^;D0fJ6K0=^X
X@3i/6`0nJm/0=VNV03g[Fl0fjJO0>faT03KXYT0mje^0?R^K03i[f/0mje_0?N]KP3h[V`0nJmZ0080
mje^00D0mja^0?V_JP3i[fX0Pj__096ak@020;gOl@0:0;^Q_P3TaKL0kM>i0?2fT03J][@0dj:T0?Rh
O`3k_Gl0nJmV0?V_I`80n:eZ00<0mja[0?V^J03k_Gh00`3i[fH04P3j]G80nJmV0;cDj`2le>/0i]O7
0=;1b@30WkH0Vg^^0:>ci02Q^>T0V/Wh0:6jjP3KcL`0Y;g[0?^gM03k^7D0nkQg0?^iM`80nkQg103j
[V401`000Y<0]/3Q0;K0h@2jd>X0Z<G^0=kAc02Xa>h00P3j`8H00`3ja8`0nZeM0?Z]G@050?Z]G@04
0?V/H02aan/0/LO[0=oAb`<0n/B=203j[5P01020/oD0/LS[0;c<iP1o/O@20:31l0<0n/F=0`3iZe@3
0?V/E0080?V[E@2=E8P0CYC`0:K3kP1>U?00nLVF0000003ibIH80?VZC`80nJY@0`3iZTl00`3iZU80
n:M;0?RWB`030?RWB`080?RWC00R2g/0000008QBRP3gZT80nJ]D02LAOP29EH`20?RWB`080?RWCP2B
Fh`0T5V<0?RWC@3iZUD0T5Z>091KSP3hYdT70?RWBP030?RWB`3hYe<0]LCU0080RK;`00<000000?oo
o`3oool0103oool4000000D0oooo100000050?ooo`@00000103oool000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo0P0000080?ooo`80
Od5j00<0OT5j07i0NP3b/XH0103_[hP00`00004000000?2^Q@020?2^Q@030000001o@GX0OT5j0080
OT1j00d0m;B30?2_Q`3`[hL0l:n700000020A7d0PDAm07PmN`20@gd0PDAm0>n]Q@3a/8@0mkAm00<0
lZn10P3b/8820?:_P`0:0?6^P`3]ZX@0l[220000G`0D07@0VVjN09M[W@2>Hi/0XjSI0:6SeP<00000
103c/8020?>`P@0@0?:_P@3_Zh80ljn00?:_P@26BGl0l:f10?6]P@3c/7l0lZn001P4N02KKYh0X72L
08eNUP1U@I40>RRA09Z[h`80V/?e00<0U;_b06S<o03c[Wh00P3b[Wh0403d/7d0m;^?0?:^OP3c[gd0
QDUo0896O`3b[Gh0j:jD0?:]OP3d[gd0lZen0?:]O@3d[g`0Qd^00897O`3b[Gd20?>^O0070?B_O03b
[Gd0ljel0?B_N`27Bh40PdQo0?>]O0020?>^N`0:0?F_NP3b[G`0ljek0?F_NP28C840PdR009Zaj02Y
dOD0m:ij0?F_N@80ljek00T0Sk3/09SDo@24BH40PdR10?>]NP3d[WT0H;om08U=PP24BH400P3c[GT0
103f[gL0RTj208A9P@24BH420?B]N@030?J`MP2:CX80PDn=00@0Q4V100`0Y6nF0?J^MP3f[WH0mk1d
09ARU02DHI<0m:ef0?J_M03d/7h0VFJD089BT02BH9<20?B]MP070?B/MP3e[GD0mJee0?B`OP2UKY<0
ODf=08mLT0020?B/M@040?B/M03e[G@0mJed0>n_R@80mJec0140mjib0?F/M027C8<0R4f30?R`K`2J
/NP0Ulok09Wch@2h^]/0]/CT096gl@2cdo40]k_L0>[5/03bdJl0l;:<0=N`/@020=^VW`090>faT03K
XYT0mje^0?R^K03i[f/0mje_0?N]KP3h[V`0nJmZ0080mje^00X0mja^0?V_JP3i[fX0nJmZ0?N/KP3f
[6h0n:i[08R_k`2cbNX0_M;Y0P3J][@02P2lXkl0hlJk0?^kNP3i[fH0nJmW0?:fS@3h[FX0mja[0?V^
J03k_Gh30?V_IP0B0?ZeLP3i[fH0O;Kh0<;IjP24^oP0_m7W0:c7kP2NcoT0Wm_l09oLo02Ia?D0Ljgf
0:K2kP2U`nl0i<o30?^hMP3k^7L0nkUg0P3k^7L20?^iM`<0nZiQ00T0U/_j0;cGk@2=cOd0Q;Ge0:O4
kP23]?@0gM3<0?VnR03ja8`01`3j[Ed01@3i[600n:YT0;77j`3OdL/0/LO[00<0n/B=203j[5P01P20
/_@0/LS[0;c<iP1o/O@0Wl7`0<o@fP<0n/F=0P3iZe@40?V/E0080?V[E`3iZeT0CYC`0:K3kP3Dd]L0
nLVF0000003ibIH70?VZC`80nJY@0`3iZTl00`3iZU80n:M;0?RWB`030?RWB`0B0?RWC00R2g/0R5::
028;NP0O2GX0nJ]D03<kZ`29EH`0Of>X0?RWB`3hYdh0n:M@091IS03hYdd0Tef>091JSP2@Fhh0n:M9
1`3hYdX01P3hYd/0n:M>0;?5j02B^O40VJCL00000200oooo00030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0
oooo0P1o@GX00`1n@GX0OT1j0?:bQP040>n_R00300000@3`[XD0l:j50080l:j500H0o=VP07m1NP1n
@GX0OT5j07i0NP3d]8<30?2_Q`0900000020A7d0PDAm04XdU@20@gd0PDAm0>n]Q@0000H0mkAm0080
lZn10`3b/8820?:_P`070?6^P`3]ZX@0l[220000G`008:T0V:KO0;Bcf003000000030::mk@3ec:@0
lk2000@0lk200P3c/8403`3b[h40kj^20?>_P03b[h40QTUo0?2]P@3a[H40lk1o0?:_P00H17P0VfjN
0:1`W02WX<l0YIk>0;3;kP020;3Gm0030:G0k@3baj80l[>90080c9ZS0P3d/7d08@3d^hl0lZin0?>_
O@22AWl0]WjH0?:]OP3X[Y@0lZen0?B_O@3b[Gh0lZem0?B_O022Agl0/7ZH0?:]O@3W[YH0ljil0?B_
O03b[Gd0ljel0?B_N`23B7l0[WNG0?>]O03W[ID0ljik0?F_NP3b[G`0ljek0?F_NP28C840PdR00?>]
N`020?B^NP070?F_N@3c[G/0m:ij0?F_N@28CH40Q4V108=8P@020?B^N@060?J_N024BH40Wf^D0?>]
N@3e[WP0mZmg0P24BH401P2KIi@0m:ei0?B]N@3f/7H0ZG6C085?S@80RUVB03h0MT^@08QJU@2TKiH0
hj^J0?J^MP3g/7@0U6:D09AQT`3d[GH0mZmd0?B`OP3EW9T0PU:@099PT`3d[GH0mZmd0?B/MP3e[GD0
mZic0?B`OP3IWiL0ODf=08mLT03d[7D0mjib0?B/M03e[G@0mjib0>n_R@3MXIH0mJec0?N^LP3e[7@0
mZec08Q=P`3h/6l0lk2108M=P`28CX<0mjia09Zfj`2m`ml0TKWb08bflP2cdo40^<_X0>S:^03G/;40
_Z>n0=^VW`3]/I00fj:I0=VVX@3h[V`0nJm[0?N]K`3g[Fh0n:i/0?V_JP3a/h`0mje^0?N/KP<0nJmZ
0180mja^0?J/KP3h[V/0nJmY08>hm`30eNT0^/_W0;Jef02lXkl0[KoW0>_D_@3i[fH0nJmW0?:fS@3h
[FX0mja[0?V^J03k_Gh30?V_IP060?ZeLP3i[fH0nZmU09W0l`2oc^D0Vl7b0P2ac>d02P2`cNl0V<Gf
09S5mP1j/_L0KJ[e0:;1k`3Scl<0nkQf0?^hM`3k^GL20?^hM`<0nkUg0`3j[V40202=^_@0]/[Y0;78
j`23/o@0Yl;]0:K2k@3f_8`0n/B<1`3j[Ed00`3i[600n:YT06>Rl`020;77j`<0n/B=2@3j[5P00`20
/_@0/LS[0;c;iP0209o0l0050<o@fP3jaHd0n/F=0?[5SP3iZe@0103i[5@0103iZeL0S5B808iFR01>
U?020:K3kP030000003ibIH0nJY?00L0nJY?00H0nJY@0?VZC`3iZTl0nJY?0?VZDP3gYeh40?RWB`0B
0?RWC00R2g/0R5::028;NP0O2GX0nJ]D03<kZ`29EH`09a5n0?RWB`3hYdh0n:M@099KS03hYdd0Tef>
091JSP2@Fhh0n:M91`3hYdX01P3hYd/0n:M>0;C<k02ZWl/0U7be00000200oooo00030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02`3oool4000000L0oooo00<000000?ooo`3oool0
1P3oool01P3kdI/0Od5j0?_XV`1n@GX0OT1j0?:bQP@0kjn800<000000?2^Q@3`[XD00P3`[XD01@3l
fJ00Od5j00000`1n@GX0OT1j00@0l:n700T000000814O@21A7d0P4=m0854O@22AGd0kjf50?6`Q000
00T00P3b[h400`3P_;80l[220?:`PP020?:_P`040?6^P`3]ZX@0l[220000G`<0000000H0Zlgb09g5
m02J__40[;kV0>;4^@3T`kH40?>`P080lk2100/0lZn10>n[PP3c[h00lZn10?2]P@3_/Hd0lkV?0?6]
P@3b[h00002=09NJe0020;c<iP0B0:OQn`2^bnl0[<_`0:2nkP2Z^nH0[[gU0>NdW`3@/[`0c9ZS0=6]
]@3b^I40m;^?0?>_O@2ePih0PUJE08MJUP3b[Gh0j:jD0P3d[gd0<@3b[Gh0lZem0?B_O026FYH0Qe^G
0?:]O@3W[YH0ljil0?B_O03b[Gd0ljel0?B_N`27FYD0QeVE0?>]O03W[ID0ljik0?F_NP3b[G`0ljek
0?F_NP23B800ZG>F0?>]N`3V[IH0m:ij0?F_N@3c[G/0m:ij0?F_N@24BH40PdR10:A^U@3V[9L0m:ii
0?J_N02:FY<0Wf^D0?>]N@3e[WP0mZmg0=:IV@22Di40VfND0?B]N@3e[WL0m[1f0:UaT`21Chd00P2:
FI807P1fBi00R5ZE0:A_UP3SZiX0mZif0?N`M02DHY@0U66C0?B]MP3f[g@0m;1n0=FLV@22DY00TV2C
0?B]MP3f[g@0m:af0?F]M@3f[W<0m;1n0=VOU`1mCHd0Seb@0?B/M@3g[W80m:ad0?F]M03g[W80kjn9
0=fQUP80mjib01h0mJad0?J]L`28CH<0n;1_0?>`P@3e[7<0R4j30?N^L@3e[7<0Zloc0;cdl@2E^o80
WkCW0<CBi@3Icll0]K7E0;jS_P3SaKX0g;Vd0<6W_`3YaK40lM:b0?2cS03IWiL0mje^0=NTX@3i[fX0
lK><0?N]KP3g[6h30?V_JP030?N/KP3f[6h0n:i[0080nJmY00d0UkK]0;[2h02O`_40NkCg0>_D_@2]
bNh0j/^f0?V_I`3b]Xd0n:eZ0?N/J`3i[VP0nken00<0nJmV00T0n[Eb0?ZfM03j]W<0nJmV09g1lP32
c^@0`/gS0<G>h@2fbnX00P2Wao001@2=^_D0M:ge06^Wm02Q`Nl0XL7`0080nkUg0P3k^7L30?^iM`@0
nZiQ00L0S;Sc0;G8j02aa^X0Pk7b0:JnjP3E`lP09P0g00L0nZeM00H0nJaP0?RZI03i[600Hj;c0;77
j`3OdL/30?[4S@T0nZaH0P2aan/01`2lbnH0Wl3`0<o@fP2O`?00n/F=0?[5SP3iZe@0103i[5@0203i
ZeL0n:YL0?V[F@3iZe<0Y/?^0=CBe`2V`nh000000P3ibIH60?VZC`060?VZD03iZTl0nJY?0?VZC`3i
ZU80mjMN1@3hYd/04@28DXX0@`9C028;NP0O2GX0nJ]D03<kZ`29EH`09a5n0?RWB`3hYdh0n:M@099K
S03hYdd0Tef>091JSP2@Fhh0n:M900L0n:M:00H0n:M;0?RWCP2HXm`09EC;07Md``00000P0?ooo`00
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`060?ooo`80Od5j00<0nnRK07i1NP1n@7X01@3_[hP00`000040l:j5
0?2^Q@020?2^Q@070?cIX01o@GX0nmVP07i1NP1n@7X0l:n70?2`Q`020?2_Q`0600000020A7d0PDAm
0813O@21A7d0PTEm0P3a/8@01P2gR`00lZn10>2l/P3U`kD0kM>i0?:`PP80lZn300h0lJj30>fZQ000
0000000003lcV`2e^=`0_lgU0:_8k`30d>H0ZLG^08BfmP2aa>P0hl>g0>;4^@<0lk2001l0lk210?:_
P@3b[h40kj^20?>_P03b[h40l:f10>naS@3c^Hl0lJf10?:_P03`[840U/7e0;cPl@2;e?l0`/ON0:o5
jP2^`^T0X;CV08nil`2`b^d0a/WL0=2b_03<VZ<0flK50?BkS`3`]Y40ljmm0;F3WP22EYD0QeZF0080
j:jD0180m:mm0=RNU`3b[Gh0m:ml0;j;X026FYH0Qe^G0?:]O@3W[YH0m:ml0=VNU`3b[Gd0m:mk0<>?
WP27FYD0QeVE0?>]O03W[ID20?F_NP0O0?:]O03c[G/0mJmj08QIU025Ei<0ljek0>J]UP3d[WX0mJmi
0?>]N`3d[WX0mJmi08UJT`24EI80Y6jE0>J/U`3d[WT0mZmh08YJT`2OJi@0ljei0?F^N03f[gL0dYVI
089CT@2KIi@0m:ei0?F^M`3f/7H0ZG6C085?S@0208YITP0907I;T028FYD0Y6nF0>>[VP3g/7@0eIbI
09ARU02DHI<0hJZK0080m;1n00L0eIbI089BT02BH9<0gjVL0>j_S03JX9P0mJee0080m;1n02@0fInG
07e=S@2?G900m:ae0>j`R`3LXIH0mJed0?N^LP3_[hT0gJ6F0>2XV`3g[W80mJad0?J]L`3g[g00n;1_
0?>`P@3LX9@0R4j30?N^L@3e[7<0mZeb08Q>Q03e[780Qdj408Q>Q03h/6h0IL7n092fl02adO40]=;`
0;Vlf`2c`N@0l<na0>S:^@3H/K020=NTX@040?V_JP3a/h`0mje^0?N/KP<0nJmZ00<0l[>90?J/KP3h
[V/00`3i[fT00`2_n>d0000006G=n`020;S1h@070>c<]03i[fL0l[J=0=jRU@3g[6/0nJiX0?^mOP03
0?V_IP030?ZeLP3j]W@0n[Ic0080nJmV00@0Wl7a0<?=hP36c^00^<_X0P2fb^T01`2A_?@0R[Sd07:/
m@1ZYo@0hlo30:71l03k^GL00P3k^7L40?^iM`@0nZiQ00L0S;Oc0;C8j@2[`n/0W;oa0=Soc026gOh0
n/6800H0nZeM00L0nJaP0?RZI03i[600nZeM06>Rl`2aan/0gm7;00<0n/B=203j[5P01020/O@0/LOZ
0;c;iP1o/?@209o0l080n/F>00<0nLB@0?oGQP3i[5@00P3i[5@02@3iZeL0n:YL0?V[F@3iZeD0CYC`
0:K3kP3Dd]L0nLVF000000020?W9UPD0nJY?00H0nJY@0?VZC`3iZTl0nJY?0?VZDP3gYeh50?RWB`08
08QBRP130U<08P]j01l9NP140E80<c^[08UES00W4Gh20?RWB`070?RWD02BFh`0n:IF09=MSP2@FXh0
T5^>0?RWB`080?RWBP060?RWCP3oool0oooo00dOWP1kGJ@000007`3oool000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo0P0000070?oo
o`80Od5j00<0nnRK07i1NP1n@7X0103_[hP00`00000000010?2^Q@020?2^Q@080?[GY0000000Od5j
0?_IX01n@GX0OT1j0?2_Q`3`/8L20?2_Q`0?0814O@21A7d0N3ek0813O@21A7d0PTEm0?6`Q03b/8@0
DD:R08JhmP2mc^H0kM>i0;ORm@3b/880lZn300<000000`3b/880202VfOX0`<[R0:33l@2jb>@0Yl;/
08Ngm01n/oH0[l?Y0P3Ra;X20?>`P00=0?>`P@3b[h40g9nC0>n[PP3c[h00lZn10?2]P@3_/Hd0lkV?
0?6]P@3b[h00l:b10?6`Q`020:6lk00I0<KHi`30f>/0ZjoK0;Jhf`2iaN<0Wkk^0:J^g@2Q]>H0Xkk/
07F[m03La/<0ikRT0<^NZ@2ePih0PUJE08MJUP39ZKX0i;^/0<nV[P3HWYL0jZjB0=:W[@2nRj00QUZF
08MKU`020>N^UP070=6X[P3IWYL0jJjB0?B_N`3DZJ`0QeZE08MIU@020>N]U@0H0?F_NP3JWiH0lZel
0?F_NP38TYd0R5VD08EGT`3c[G/0iZfF0?F_N@3JWiH0ljek0?F_N@3=UI/0REZC08AETP2TKYD0iZbG
0?J_N03?UiX0RUZC09m[U03c[GT0mZmg0P3BVIT01`22Di40VfND0?B]N@3f/7H0e9^H0:UaT`21Chd0
0P2:FI801`1fBi00R5ZE0;6G^`3SZiX0fk:^0=FLV@2DHY@00P2[SkP04P3Y`jl0g;:^0=FLV@22DY00
ZXjh0>O4/P3I/K40fZ2H0>:ZVP3X`k00m;1n0=VOU`1mCHd0Seb@0=fWW@3^/8/0f[>a0>6YV`80kjn9
0240gJ6F0>2XV`3g[W80fj6G0?J]L`3g[g00n;1_0?>`P@3LX9@0R4j30?N^L@3e[7<0mZeb08Q>Q03e
[780mZeb08Q>Q03h/6h0lk6201UTf@2T]ND0`m3T09:mm02fbnX0Sk?_0;c3h03H/K00_9nk0>O3/P3i
[fX0lK><0=^PUP3g[6h00`3i[fX00`3b/hT0gZ6C0?R^J`060?V_J@0908B`lP31b^40Ok7d0>g>/`3M
][40gZ:E0=:PXP3h]gh0nken00<0nJmV00<0n[Eb0?ZfM03j]W<00`3i[fH0302P`O00a<gQ0<O>g`2j
b^L0]/WX0;[:iP2@^o<0RKOd076[m@2P`O00hlo30:31l080nkQg1@3k^GL40?Z^H@060;?2iP2=]O40
]/7R0?ZoQ03j_H00n/681P3j[Ed0203i[600n:YT0?V/H03j[Ed0nZeL0;77jP3OdL/0/LOZ0`3ja8d8
0?Z/F009082am02aanX0^l_V07n`l`2O_nl0cloJ0?[5S`3ia900omN600<0nJaD00/0nJ]G0?RZG03i
ZeT0nJ]E0?V[E01?U?00Y/?^0=CBeP3ibIH000000?W9UP050?VZC`060?VZD03iZTl0nJY?0?VZC`3i
ZU80SUJ91@3hYd/02028DXX0@`9C0000000O2GX0A05B0?V[EP29EH`09a5n0P3hYd/01`3hYe00TU^<
0?RVEP2CGHh0TE^>091JSP3hYd/0203hYdX01P3hYdh0oooo0?ooo`3oool0NefT000001l0oooo0004
0?ooo`@000003P3oool5000000D0oooo0P0000080?ooo`80Od5j00<0nnRK07i1NP1n@7X0103_[hP0
0`00000000010?2^Q@020?2^Q@060?[GY01n@GX0OT5j0?_IX01n@GX0OT1j103`[hL03020A7d0PDAm
07PmN`20@gd0PDAm0895O@3a/8@0lJn40552XP1YJ;h0blOF0=k6`P<0000000<0lJj30=nRTP3]ZX@0
103b/8802P2I5000`<SQ0:72l02h`>00Z[oY08Vel`21/_@0[l;X0;32i`3Sa;P20?>`P@0/0?:_P@3L
Wi<0ljn00?:_P@3FW9P0l:f10>naS@3c^Hl0lJf10?:_P03`[840lK270?>iS`3a[H40lZn00>jYPP3c
[gl0YMOi08I:P01Db?@0Z;KS0;[:iP2Z`N/0[;WS08^UiP3HalT0e[Zn0:^Pc02NU<T0XIS;0=;?eP3H
b/`0cjJ^0=2`^@3W^jT0g/[50;j;X026FYH0X9G90<FW^`3JcLd0dJR^0<j^^P3W_:T20=BY[00708MJ
U@27FID0`Z>j0>Jm[03BZJh0fYnF0>V]T`020=JZ[00[08QIU025Ei<0iZfF0>J]UP3CZZh0fYnF0>R]
U03X_ZX0ejb/08UJT`24EI80Y6jE0>J/U`3f[gP0ciNJ08YJT`2OJi@0iJbG0>W1Z`3I[Z`0dYVI089C
T@2KIi@0i:bH0?J`MP3DViP0ZG6C085?S@2:FI80VX>i09^5^`29O;l0/INk0;o=i03Uf<T0^:c=08ij
^@2FPKX0Zhnh0<77g`2hZL/0[iJm08mk^@020;o5g`090>3Kd@31YK`0`JFl0>S3/03N]:d0]9^o099n
^P2XS;P0ilFc0080f[>a00P0a:Vo0>O5]03K/k40gJ6F0>2XV`3^/8/0fj6G0=fWW@80n;1_0100lk21
0=bPU03g[W40mjia0?F/L`3f[G80mji`0?F/LP3f[G80R4j40?R`KP3c/H80ljYd0?F/LP3g[Vl0n;1]
0P2Tbo@0202`mnh0]JoC0;>ig@2<[nd0lM6`0=Vb/03KX9H0eZ>Q0`3i[fX00`3b/hT0gZ6C0?R^J`07
0?V_J@0507jbm@34dN@0`mKW0=_Dd@2i]MH00P3RaKX01`3k_Gh0nJmV0?V_IP3i[fH0n[Eb0?ZfM03j
]W<0103i[fH03@2P`O00a<gQ0<C=h@2jb^H0]lWX0:O4kP2@^_<0R;Od06VVm02Q`O00JJKd0:71l03k
^7L01@3k^GL40?Z^H@0708Vbl02c_^80f/_:0>?>`P3j_H00n/680?[1R@050?Z]G@060?V/H03hZV@0
nJaP0?Z]G@3j[E`0I:;c0P2aanX30?[4S@T0nZaH00<0PK7d0;77jP2kb^H00P2O_nl00`3>c]X0mKnC
0?oGQP030?V/E0070?V[E`3hZU`0nJ]I0?V[E@3iZe@0nJ]C04nEl0020:K3kP030000003ibIH0nJY?
00@0nJY?0P3iZU020?VZC`80nJYB1@3hYd/02028DXX0@`9C00000028DXX0A05B0?V[EP29EH`09a5n
0P3hYd/0203hYe00TU^<0?RVEP3hYdh0TE^>091JSP3hYe<0n:M91`3hYdX01P3hYd/0n:MC0?ooo`3o
ool03AnN000001l0oooo000P0?ooo`030000003oool0oooo00L0oooo0P1o@GX00`3kj9/0OT5j0?:b
QP040>n_R08000010`3`[XD01@3jej@0Od5j07i1NP3kfJ00OT5j00@0l:n700P0QTZ00814O@21A7d0
N3ek0813O@21A7d0kjf50?6`Q080lJn40`0000001P3W`Jl0lZn30?:_P`3a[X<0gj:B0?:_PP@0l[22
0140lZn20:2_hP32`m/0Z;gY0;k9h`2VZ]T0Sjg[08NclP2a`^L0/l?V0>72^@3R/ZD0aYZZ0=bOT`3c
[h00bj6]0=JLV0020>naS@090?>iS`3b[h00lZn00?2/P@3a/8L0lkV?0?6]P@3b[h00kZV20080ljmo
02/0hjB?0?>_O`3c[gl0ljmo0>jZPP2E/n`0_=C/08gAoP2_[MH0YkCR0:6hj02;dol0Y;3P0:>bh`2O
/N@0Z<K_0<WVk02c]MX0[jG>0:>Gb@2Wb_80RkWe0<;Wl02Q/nD0]K3D0=3=eP3Pc<D0/JK=0:JGa`2N
TLH0c/oJ0:G8lP3BZJh0c:bj0>RmZ@3Qc/D0eZZ/08b3a02LSL@0_Inj0=cAc@3CZZh0bJ^k0080j;jZ
00T0ejb/08UJT`24EI80^I^j0>W0Z`3I[Z`0ciNJ08YJT`2fVKX00P3Y`J/0;P3I[Z`0dYVI09R7_`2b
U[X0jL6/0=Z_[03DViP0WH>g09Qn]P2FO[H0VX>i0:Zki@2</_00U]cn0:Znj02l`ml0^:c=09n_h`2B
Z>D0WNOk097/lP2nb>80WZWN09>Xi02Ni_`0S]co0:g7k@2O/nL0_/7L0<?Mk033cN80]9^o08j^k02L
_Nl0/NGh0:cBm02k_=X0]lcZ0=gLe03K/k40a:Rn0>K5]03J/k40`JFm0=fWW@3/`jX20?>`P@0H0=bP
U03MYY/0mjia0?F/L`3f[G80mji`0?F/LP3f[G80mji_0?R`KP3c/H80ljYd0?F/LP3g[Vl0n;1]0?>Z
M03eZg80mji_0?R_K@1n/?@0`]?W0<ODi03KdLl0_J6l0P3Va;@20?V_JP030?:cR@3NXI<0n:i[00P0
nJmY00L0R[kh0;cAjP2mcnL0Q[?c0:fmiP2Vc?@0jLjj00<0nJmV00<0n[Eb0?ZfM03j]W<0103i[fH0
2P0008<0XL7`0<C=h@38cMh0^/[V0;O9j02Wa>h0T;[c08Rfm01YY_@20:71l0030?^hM`3k^GL0nkUg
00<0nkUg00<0nkUh0?Z^H@3j[V400P3j[V40101fZO80]lKV0;O8i`3j`8P20?[1R@030?[2RP3j[Ed0
nZeM0080nZeM00@0nJaP0?RZI03i[600nZeM0P3j[E`00`1TX_<0/LOZ0=oAb`030?[4S@T0nZaH0P2a
a^X01@2jbND0Wkg]0<Nod`2O]NP0omN600<0nJaD00`0nJ]G0?RZG03iZeT0nJ]E0?V[E03iZe<04`1d
0:K3kP2Va>h0e=;G0000003ibIH40?VZC`80nJY@0P3iZTl20?VZDPD0n:M;00P0R5::04<2D`000000
R5::04@1DP3iZeH0Pf:U08UES080n:M;00P0TEZ<099KS02@FH`0TU^<095KSP2@FXh0T5^>0?RWB@L0
n:M:00H0n:M;0?RWD`3oool0oooo00dOWP00000O0?ooo`00803oool00`000000oooo0?ooo`070?oo
o`80Od5j00<0OT5j07i0NP3b/XH0103_[hP00`00004000000?2^Q@020?2^Q@050000001o@GX0OT5j
07i1NP1@03H0103`[hL01`26BX00P4Am0854O@1h?G/0P4=m0854O@3_[HD00`000000203`[XD0S[[d
0<S8fP3X`Zl0iL:c0>6`X`35V:T0gj:B1@3b/8820?:_PP80lJj300`0lZn20:^ghP2mbn@0YmGh0:75
lP2b^Mh0^/;P0<c<f@36VZX0eK2c0>:eZ03B_lL20=Fa]080lkV?00P0lZn00=NLUP3`[840lK270?>i
S`3a[H40lZn00>jYPP80ljmo00D0hjB?0?>_O`3c[gl0ljmo0>jZPP020?>_O`0O0>>TS`3c[gh0R]3o
0?>_OP26BX40W[?W0:Rbg`2_eO@0ljmn08I;P@23B800W;GY0:kCm02ggo@0X[?U0:Rbg`2T]><0WN;m
08_Fo`2Wh_/0Y[?R0:BgiP2:d_l0/=Gc0:Ngi02S]ND0YL?_0<GVkP2h^]/0/jK<0:RGa@020:C6l@0C
0;kVlP2U]nH0]ZoB0<_;fP3Rd<D0]JS<0:^H``2JR/40bLkM0:?5l@3Td/H0]jg?08ao`@2IRL00alkO
0>CDaP2h[/l0[i_308]n_`020<C=h@0@0;WVm@2gZ/`0[YNn0:B_h02U/>00Y>Ok09WUo03bZgX0W;?X
0:F]g@2bcNh0T/gl08MESP28EXl0QD^20:QaU080ljah0180mjme0>2RTP3c[7P0mJif0?N_M03bZWT0
VF6>09^jkP2Vc?@0]_7e0:C6l@2Z/ml0^lOS08nkm02N^>/0YLKa0:_@m02?__H20=gKe@0P0;Vgf03/
`jX0llfY0>[7/P3F[Jh0g:2D0=fVV`3_/8X0gZ:D0?J]LP3g[W00mJab0?J]LP3KYId0n;1^0?>aPP3c
ZW@0mJab0?N^K`3h/6d0ljYd0?F[LP3g[Vl0n:m]0?V`K@2A`OL0_L_U0;W:j02g/]@0/KoU0:c>lP3/
bK420?:cR@030=jQT`3EXJ00nJmY00P0nJmY00D0V[oa0;W9i`2L`?40OKOh0;77j`020>W=^P80nJmV
00<0n[Eb0?ZfM03j]W<0103i[fH02`0?03H0XL7`0<C<h@2Q`O00b<gN0;[:iP2gbNP0Yl?^092jl`1a
Z_D0JJKd0080XL7`00<0hlo30?^iM`3k^GL00P3k^GL00`3k^GP0nZiQ0?Z^H@030?Z^H@0306^Vm02g
b>P0]/SX0080n/6900<0n/::0?Z]G@3j[Ed00P3j[Ed0103i[600n:YT0?V/H03j[Ed30?Z]G00306BR
l`2aanX0/LOZ00<0n/B=203j[5P01`20/?<0/<K[0;O7iP1bYo80UKW`08W>oP3jaI000`3i[5@03@3i
ZeL0n:YL0?V[F@3iZeD0nJ]D0?V[D`0C07@0ASNL0:K3kP3Ed]H0nLVF0000003ibIH00`3iZTl20?VZ
D080nJY?0P3iZU850?RWB`0808QBRP0R2g/0000008QBRP000000nJ]D02LAOP29EH`20?RWB`080?RW
CP2BFh`0T5V<0?RWC@3iZUD0T5Z>091KSP3hYdT70?RWBP060?RWB`2CGHh0oooo0?ooo`0=7ih00000
7`3oool00200oooo0P0000070?ooo`060?_AV`1o@GX0nnRK07i1NP1n@7X0l[:6103_[hP00`000040
000I0?2^Q@020?2^Q@040?cIX01o@GX02@000500=PD0l:n700@000000814O@21A7d0N3ek0`000000
303a/8@0lJn40?6_Q03`[XD0l:j408^lm`36a]X0glO00=3>f035V:T0f[:`0>?3^0@0l[220P3b[h82
0?6^P`0=0?:_PP3a[h80gZ6B0?:`PP3c/880UmGm07KRb@2Yc?80VjKM0;;2iP3?g^@0d[o70;>]dP02
0>K>_`030>>eYP37VjX0eibF0080lK2700@0lkV?0?:_P03b[h00kZV20P3c[gl01@3SY8l0ljmo0?>_
O`3c[gl0kZZ20080ljmo00/0hjB?0?>_OP3c[gh0ljmn08I:P@23Ah00l:b00?2[P03c[gh0QT^108=8
P0030?6/O`0^0?B_O@27c_l0lJao0?B_O@28C840Q4V108C>o`3W[9<0lZem09fci`2W/Ml0[M7c0?B_
O028CH80Q4V109^dj@2/d?<0^>Ge0:6gj02W/=h0Yk;Q09cOo@2;d_l0XnOk0:Fah@2V]N<0Rm3n0;;C
l@2U]nH0XkKV0:>hj02Oe_/0X]Oj0:Bhi`2Y/Mh0XkKV0:>gi`2OeO/0XK[[0:Bhj02W[md0WK7V08cH
o`2>d_h0K42;08E;PP80lZ]j00`0mJih0?J_MP3bZgX0PTR208MESP28EXl0LDF=0:QaU03c[7P0mZif
0?N_M@3PXY820?F^MP0L0?N_M03bZWT0VF6>0?6YN@3f[W@0mjmc0?>[M`1ec?l0mZid0?N_L`2Q_Nd0
/<O[0;kZl`2R^^X0W;S[0:bfh@2>]_40]m?_08Bkn02kc>L0eZf^0;jO^@3MYY/0g;B`0=jRU03MYY/0
kk2;0=jRU@80fjFM01H0n;1^0?>aPP3cZW@0mJab0?N^K`3h/6d0ljYd0?F[LP3g[Vl0n:m]0?V`K@0I
HML0Y;GU0<??i02Db_X0R;Sd0;S1h@3^bZh0jlfg0=^b[`3NXI<0eJ6P2P3i[fT02`2K__00^/WU0:?1
k`2:]o@0/LOZ0;;7jP3XbkT0nJmV0?ZeLP3j]W@0n[Ic00@0nJmV00H03`0f0?V_IP2Q`O00a<cP0<S=
gP34c>020;O9j0060:O3kP28]_@0LJ[e06ZVm02Q`O00hlo3103k^GL00`3k^GP0n[Uh0?Z^H@040?Z^
H@0306^Vm02fb>P0hm3500<0n/::0`3j[Ed0103i[600n:YT0?V/H03j[Ed40?Z]G00306BRl`3OdL/0
/LO[00<0n/B=203j[5P01`21/?<0[l;X0;[1h03ddZ`0n/F>0?[5T03jaY400P3i[5@03@3iZeL0n:YL
0?V[F@3iZeD0nJ]D0?V[D`0C07@0ASNL04ZBk`2Ua_00Xlce0?W9UP0000000`3iZTl20?VZD080nJY?
0P3iZU850?RWB`0B0?RWC00R2g/0000008QBRP3gZT80nJ]D03<kZ`29EH`09a5n0?RWB`3hYdh0TU^<
091IS03hYdd0nJYE091JSP2@Fhh0n:M91`3hYdX01P3hYd/0n:M>0?ooo`3oool03AnN000001l0oooo
000P0?ooo`030000003oool0oooo00H0oooo0P1o@GX00`3kj9/0OT5j07i0NP050>n_R00300000000
01T0l:j50080l:j500<0o=VP00T0001/43h01P3`[hL4000000040813O@21A7d0kjf50?6`Q080lJn4
00X0l:j50?2^Q03b/8@0WL7b09_No@1TdZ/0W;7V0;>ohP3XbkT0iL>d0`3b/8804P3b[h80lJj30?6^
P`3a[X<0lZn20?6_PP3NXI80l[220?>`PP3b/880lJj20=nRT@3b[h80lk210?:`P@3a[X80MJ_d0;C;
j`80g/[500T0cKC20=>_/`3C[k<0lkV?0>ndT03b[h00hZ>?0>jYPP3c[gl00P3SY8l30?>_O`040>jZ
PP3c[gl0ljmo0>>TS`<0ljmn02@0PdN00<:7U@3`[800l:^00?>_OP23B800_XBF0?6/O`3Y[I40lJao
0?B_O@3`Zgl0lJao0?B_O@24BH40^7jF0?6/OP3W[9<0lZem0?B_O03a[7h0lZem0?B_O028CH80/gZE
0?:/O@3VZi@0ljel0?B_N`24boh0lZel0?F_NP29CX80[gJD0?:/O03c[W/20?F_NP0;0:c>lP23b_h0
mJmi08Y>P`2/Li<0WK;W0:[<lP3e[gP0RDj3081@SP2]Li800P2XbO401P3f[gP0lZ]k0?:[N`1/@8/0
/7NC0?:[NP80mJih02<0mZmf0?:[NP22B880QeF>08QFS`1aAHd0Z76D0?>/N03f[WH0mjme0>2RTP3S
ZIH0mJif0?N_M03bZWT0VF6>0?6YN@3f[W@0mjmc0?>[M`3SZ9H0mZid0?N_L`3cZgL0R4j40?R`L@3g
[g80K/So0;gYl`29/O00X;?V08NclP2Xbo80/l?U0;jO^@020=oHd@0@0<>U^`3U`kD0iL>e0=be/032
Y;/0fjFM0?R`KP3c/H80gj6B0?F/LP3g[Vl0n;1]0?>ZM03eZg80mji_0?R_K@<0nK1]00X0n:m]095F
QP3`YWL0Sk?_0<?;h03LdLh0fk:_0;fO^P3U`kD0n[Qh2P3i[fT02P2M]nX0^koM0:Jnj`2>]o80j<^i
0;;2iP3i[fH0n[Eb0?ZfM03j]W<40?V_IP0700l0=P3i[fH0nJmV0:71l034c>00b<gN0;[:iP020;O9
j003092jl`28]_@0LJ[e00<0X<7`0`3k^GL00`3k^GP0n[Uh0?ZiN@040?Z^H@0406^Vm02fb>P0JjOd
0>?@a@80n/::00L0n/:90?Z]G@3j[Ed0nJaP0?RZI03i[600nZeM00D0nZeL00<0/LO[06BRl`3OdL/0
0`3ja8d70?Z/F0070?Z/F@2^_>@0[[cT0=_?cP3jaHh0n/F@0?[6T@020?V/E00=0?V[E`3hZU`0nJ]I
0?V[E@3iZe@0nJ]C0?V[EP16=i`0CUVn06NPl@2Qao<0a/WL000000020?W9UP030?VZC`3iZU00nJY@
00<0nJY?00<0nJYB0?RWB`3hYd/00`3hYd/02`3hYd`08P]k0000000R2gX0mjY20?V[E00c>j/0REF<
02LAOP3hYd/0n:M>0080TU^<00D0n:M=09=MSP2@FXh0T5^>0?RWB@070?RWBP060?RWB`3hYdh0oooo
0?ooo`0=7ih000007`3oool00200oooo00<000000?ooo`3oool01P3oool207m1NP030?_XV`1n@GX0
OT1j00D0kjn800P0000100006@3`[XD0l:j50:F^gP2U]nH0c<?B0?_NX`<0l:n700T0l;270?2_Q`00
000000000814O@21A7d0P4=m0854O@3>UIT00P3a/8@0103a[h@0l:j50?2^Q@3`[X@20?:`Q0080?6`
Q03a[h@0l:j407Ram`32a]d0iL>d0>C1]03V`[820?:_PP<0lJj30180lJn20=jQTP3NXI80l[220?>`
PP3b/880lJj20=nRT@3b[h80lk210?:`P@3a[X80i:F>07^Tk@33c>80d];I09jci`2cZm020>G>`006
0>BeY@3:WJT0hZ>?0?>_O`3S]ZL0cj>[0`3c[gl00`3RY900kZZ20?>_O`020>>TS`<0ljmn00<0RUbE
0<:7U@3`[8000P3c[gh07`28FYD0RE^E0?6/O`3Y[I40lJao0?B_O@3`Zgl0lJao0?B_O@2;G9D0R5ZD
0?6/OP3W[9<0lZem0?B_O03a[7h0lZem0?B_O02=GI@0QeRC0?:/O@3VZi@0ljel0?B_N`3a[7d0lZel
0?F_NP2>GI<0QUJB0?:/O03c[W/00P3e[gX03P3b[7`0ljek0?F_N@2AGi<0[7>C0?:[O03d[WX0mJmh
08U>P`20D8h0[G>B0?6[N`3d[WT0mZmh0P3bZg/0801/@8/0QeNB0?:[NP3SZIH0mJih0?J_MP3bZgX0
PTR208MESP28EXl0LDF=0:QaU03c[7P0mZif0?N_M@3PXY80hjVF0?F^MP3g[g@0lZYi09UQSP3aZGT0
mZid0?N_L`3cZgL0hjRF0?J^M03g[g<0lj]g0?J^L`3h/740mjmb0P3`Z7T0603f[W@0ijJ<0?>ZM`28
Ch@0PK;d09^_i@2IboT0]mod0;fhe@2h`^40gMWB0;fieP32Y;/0l/n]0?;>[03c/H80gj6B0=VSW@3g
[Vl0n;1]0?>ZM03eZg80mji_0?R_K@<0nK1]00@0n:m]095FQP3`YWL002fa0P34e>L0102kb^H0/;kT
08^dl@3^dkP;0?V_J@80^_Ka00L0L]?l0;Noh02g_n00j/bg0?ZeL`3j]W@0n[Ic00@0nJmV01003`0f
0?V_IP3i[fH0S5F:0:71l034c>00b<gN0;[:iP2gbNP0^/[V092jl`28]_@0LJ[e0:31l03Scl<0X<7`
0P3k^GL0103k^GP0n[Uh0?ZiN@3j^WX40?Z^H@0<06^Wm02eb>P0]LSX0>?@a@3j`XX0n/:90?[1R03k
_X40nJaP0>VYR`3i[600nZeM1@3j[E`00`1TX_<0/LO[0=oAb`030?[4S@L0nZaH01T0nZaI0?NYI02^
`nX0g=7=0:g5j`3jaI00n/JA0?[6T03i[5@0nJ]G0?RZG03iZeT0nJ]E0?V[E03iZe<0nJ]F06aL[`3i
ZUP0nJ]D0:>ij03=bML0nLVF0000003ibIH0nLVE0080nJY@0`3iZTl00`3iZU80mjMN0?RWB`040?RW
B`0A028;N`28DXX08P]j0?NZ@P3iZe@0<c^[08UES00W4Gh0n:M;0?RWCP3hYe00TU^<0?RWC@2CGHh0
T5Z>091KSP3hYd/0203hYdX01@3hYdh0oooo0?ooo`3oool0000001l0oooo000P0?ooo`030000003o
ool0oooo00H0oooo0P1o@GX00`3kj9/0OT5j07i0NP040>n_R0080000000001X0?VKB0;W2h@2Q/N@0
Vl;c0:Fgi@2_co430?2_Q`<0000000/0l:n70814O@20A7d0N3ek038LQP2SMj80cYFI0?6`Q03b/8@0
lJn40?2^Q@020?2^Q080l[2400l0lK240?6_Q03`[X@0l:j408>fm@24]oH0`[oH0>O4/@3[c[L0gjnU
0<ZLZ03a[X<0lZn20?6_PP3<WjX00P3b/8802P3c/880lJj20?6^PP3OXY40lZn20?>`P@3b/840lJj2
0>BUSP3b[h420?>`P@040?6^PP1f[?@0/l[[0=k:a@80ckG100/0e:nc0>>fY`3S]ZL0cj>[0=F`/`3S
]ZL0d:>[0>:TT03c[gl0i;JW0=2SZP030?>_OP080;^8WP2:G9D0`XNE0>b^S@3V^:H0_XVN08QJU@29
FiD20>V]T@0K0?B_O@3NXI80l:]o0?B_O@36TIh0RebE08QJU03a[7h0ijbC0?B_O03MXI<0lJan0?:]
O@3d[g`0SEfD08MHT`3b[7d0iZ^D0?>]O03d[g/0lJam0?:]O03e[gX0SUfC08IFTP3b[7`0ljik0080
mJmj00h0lZal0?>]N`3e[gT0TEnC0:acT`3bZg`0m:ij0?F_N029CX<0P52>0:ecTP3aZg/0m:ii0?J_
N080lZ]k00h0K42;08MGTP3bZgX0hjVF0?F^N03f[gH0lZ]j0898PP27EHh0R5J?0755S@2XLI@0hJRI
0?N_M@80h::B0140hjVF0?N_M03QXY00lZYi09UQSP3PYiP0mjmc0>BUSP3cZgL0hjRF0?J^M03SY8l0
lj]g0?J^L`3h/740mjmb0?2XN@020?J^M00;0>NVS03cZWL0R4n408mDQ@3cZgH0RDn40?R`L00WOnP0
V[W^0;c2g`2=]o<00P2ed^l02P2jc^T0fJj]0;fM^03IXid0nK1]0?>aP@3QXY00mJ]b0=RRW@3h[fd3
0?V`K@040?R_K@2AEXH0l:Ig0?N^KP80Xk?T00D0`/kS07jem`2`bnh0QkOe0;K0h@0:0?V_J@090?V_
JP1XDJ@0J56T08B_l@2obN40Ojoc0>_<]`3j]W@0n[Ic00@0nJmV00H03`0f0?V_IP3i[fH0S5F:0000
I`2Q`O020<C<h00?0;[:iP2gbNP0Yl?^092il`28]_@0JZKd0:31l01ZY_@0hlo30?^iM`3k^GP0n[Uh
0?ZiN@3j^WX0n[]m00<0nZiQ00`0nZiP06^Wm02ebNT0hm350?[2RP3j`XT0n/680?^nP@3i[600jJV;
0?V/H03j[Ed60?Z]G00306>Rl`2aan/0/LO[00<0n/B=1P3j[5P06@3j[5T0mjUT05VJl@2]a^`0[LG/
0?[6T03jaY40n/J@0?[7S`3iZeL0jjb=0?V[F@3iZeD0nJ]D0?V[D`3iZeH0n:UL0?VZF03iZe@0CYC_
0:G1k@2V`^h0nLVF0000003ibID00P3iZU030?VZC`030?VZDP3gYeh0n:M;00@0n:M;00P0000004<2
D`0R2gX07`Uj04@1DP0c>j/0REF<02LAOP80n:M;00L0n:M@099KS03hYUH0Tef>095KSP2@Fhh0n:M;
00P0n:M:00H0n:M>0?ooo`3oool0oooo07]MY000000N0?ooo`00803oool00`000000oooo0?ooo`06
0?ooo`80Od5j00<0nnRK07i1NP3[kY40103_[hP020000000000J0000P01]Xo40[]kh0:BVf02>X^80
i]K60`0000040?2_Q`0<00005`21A7d0DSB@038LQP2SMj80gKF_0>S6/`3a[h@0hJnQ0?2^Q@3`[X@0
lJn40P3b/8@01P3a/8@0lJn40?2^Q03`[X@0lJn409Bgl080c]CN00D0Vo;90<J]`@3:W:P0f[6^0>6b
Y@020<bOZP040=R`/03b/880lk220?6^PP80gj:A00H0lZn20?>`P@3b/840lJj20>BUSP3b[h420?>`
P@80lJj200`0`lcR08ZelP3Cd]P0X[SX0;N_d@3Gb<`0e/;60;ZfeP3Fc=00el?60=2SZ`3C[[<20>Bf
Y`0E0=2SZP3A[;80ljmn0=6TZ@2kR9h0RUbE0<RT/`3/[Xd0i[RV0=:UZP28FYD0RE^E0<JR]03Y[I40
dJF[0=jQTP3YZhl0m:mm0=R]Z`2;G9D0R5ZD0080ijbC00L0m:ml0=fQT`3WZi40m:ml0<^DW02=GI@0
QeRC0080iZ^D00P0m:mk0=jQT`3a[7d0mJmj0<nGV`2>GI<0QUJB0?:/O080mJmj00l0gZ6B0?:/O03c
[G/0mJmi095OT`2/Li<0lZ]l0?B^NP3e[gP0eY^F081@SP2]Li80lJ]k0?B^N@3LWi800P3bZg/02`1/
@8/0QeNB0>>YUP3SZIH0mZmf0=fOTP3bZgX0PTR208MESP28EXl0LDF=0080[Xjf00/0j<6^0=V_[@3P
XY80hjVF0=jaZ@3QXY00lZYi0:R9/`3PYiP0j<:^0=^`[0020>>XUP030?N_L`3SY8l0lj]g0080n;1a
01P0mjmb0?2XN@3PYYH0mZid0>NVS03cZWL0mZic08mDQ@3cZgH0RDn40?R`L03h[g405goV0:g<l032
ko40SkSb09nciP34d><0^M;/0;R]cP3Y`Jd0lLj]0>c;/`3J[jd20=RRW@080?R_K@3i/6d0nK1]0?V`
K@3h[fd0TEJ60?2VM`3g[Vh20?V`K080nK1]00@0S[;^0;_1g`2oaMh0k<Zb2@3i[fT01P3i[fX0J56T
06QAY01WDJD0O[3d0<7;hP80jlfg00<0n[Eb0?V_IP3i[fH00P3i[fH05`3j^gl0nJmV0?V_IP2<EHX0
001W08QBR@2Q`O00a<cP0<S=gP2jb^H0]lSX0:O3kP2@^O<0RKKc06ZVm02P`O00XL7`0?^iM`3k^GP0
n[Uh0?ZiN@3j^WX0n[]m00<0nZiQ0P3j[V002P1[Yo@0]LWY0>?Aa@3j`XT0n/680?^nP@3f_Hh0jJV;
0?V/H03j[Ed70?Z]G00306>Rl`2aan/0gm7;00<0n/B=1@3j[5P05@3j[5T0mjUT0?NYI01IVo80[<G/
0=_Bd03jaY40n/J@0?[7S`3iZeL0jjb=0?V[F@3iZeD0nJ]D0?V[D`3iZeH0n:UL0?VZF03iZe@0nJ]C
04fBk`020:K3kP040?W9UP000000nJY@0?VZD0<0nJY?00<0nJYB0?NWGP3hYd/0103hYd/02028DXX0
@`9C0000000O2GX0A05B0?V[EP29EH`09a5n0P3hYd/01`3hYe00TU^<0?RVEP2CGHh0TE^>091JSP3h
Ye<0203hYdX01P3hYdh0oooo0?ooo`3oool03AnN000001h0oooo000O0?ooo`800000203oool207m1
NP0307i1NP1n@7X0kjn800@0kjn800D000010000<`13?ZD0];CH0:R_g@03000000L0l:n700/0000G
099UV`1B=90003:h092Qg`3Xa[<0a]KV0>S6/P3Q[j40aYRW0?2^Q0030?:`Q0050?6`Q03`[X@0l:j4
0?2^Q03a[h@00P3b/8<20?6_P`0;0?2]Q030/L/0`;7;0=g7``3B^l<0c9nZ0>;3^@3c/880l[220?6^
PP3OXY400P3b[h801@3c/840lJj20?6^PP3TYHh0lZn10080lk210P3a[X820?:_P@0M0?6^P@3b[h40
N[Oi0;>oh`2`a^/0P;Wi0:?;m035gn`0Xk7R0;N^d03FbLh0el?60=2SZP3A[;80gLC00=6TZ@2kR9h0
QeVE0:6>`@3V^:H0g/K10=:UZP28FYD0Whg00<JR]03Ia/L0dJF[0<^U/P3T]ZP00P3H[J/07P2;G9D0
R5ZD0<6M]03U^ZT0dZJ/0=fQT`3WZi40m:ml0=Z^Z`2=GI@0QeRC0;fJ]03VZi@0djR/0=jQT`3VZY80
mJmj0<nGV`2>GI<0QUJB0>F[U@3V_:/0mJmj0=jQTP3UZI<0mJmi0=BKV@2AGi<0[7>C0>FZU080mJmh
00H0eY^F081@SP2]Li80iJZD0?J_N03LWi820?:[N`0j06a0R`27Ei80/Y:f0>>YUP3L[jT0gInB0898
PP2DNK80V7fc09Qm]029M;H0Uh2h0<75g@3Rf<`0^Zk=0<>S^03Ve<D0g[6Y0;JI^`2@NKH0UGbe0>S2
[P3RfLd0fk2/0<FU^@3X`Jh0fk2/0>>TS`3OYYT0llZT0?N_LP3ZYhL0l:Qi0>2VUP3f[W@0ijJ<0?>Z
M`3f[W<0SeB50?>[MP3g[W80n;1`0?R_L@3g[g80RDn50?N^LP3h/700SE>508iCQP3g[W40TJo[0;c;
iP3bcZ`0aMCU0=Z_[@2nW[P0f::M0?R_K@<0nK1]00@0n:m]095FQP3`YWL0mji^0P3i/6`30?V`K@04
08Ndl`34bml0k<Zb0>c:/PP0nJmY00H0nJmZ06QAY01XDJ@0Ie6U0000H`20/_@20<7<h`030>_=]`3i
[fH0nJmV0080nJmV00L0n[]o0?V_IP3i[fH0S5F:0000I`28DXT0XL7`0080a<cP00T0b<gN0;[:iP2f
b>P0Yl;]096ilP1bZo@0JZKd0:71l02Q`Nl00P3j^GP0103j^GT0n[Yj0?ZkO@3j_7l20?Z^H@<0nZiP
00T0]/WY0>?Aa@2fbNT0nl660?^nP@3f_Hh0jJV;0?V/H03e^hd01`3j[E`0103j[Ed0/LO[06:Rl`3O
dL/30?[4S@@0nZaH00@0nZaI0?NYI03gZF@0nJ]M0P2/aN`03@2/a^`0n/J@0?[7S`3iZeL0jjb=0?V[
F@3iZeD0nJ]D0?V[D`3iZeH0n:UL0?VZF03iZe@00P3iZe<20:K3kP040=CAeP000000n/RD0?VZD0<0
nJY?00<0nJYB0?NWGP3hYd/0103hYd/02028DXX0@`9C0000000O2GX0A05B0?V[EP29EH`09a5n0P3h
Yd/0203hYe00TU^<0?RVEP3iZU<0TE^>091JSP3hYe<0n:M91`3hYdX01P3hYd/0n:MC0?ooo`3oool0
3AnN000001h0oooo000O0?ooo`030000003oool0oooo00H0oooo00@0nm6K07m1NP1W02D09`051P3_
[hP00`0000001P1f00000002000000030?cRXP3`/8H0m[N400H0l:n700/0QTZ000005`2BII/0DSB@
02l[VP0ERnL0JM;i0;gJkP2deo80b<kO0<JHY`020>G4]@030>K2/P3a/8@0lK2400<0l:j400<0lJn4
0?:`P`3b/8<00P3a[h<02P3`[H@0l:j40<7Xl@1leOl0X]ol0;:nh`1n[o<0iLFg0>:bX`38VZP20=J^
/080lk2100@0lJj20>BUSP3TYHh0lZn10P3c/8420?6^PP80lZn100T0lJj10?:_P@3a]Xh0W;K[0<7D
j02gd^h0X:gP0:RagP2N/^H00P2Qh_`0302Ne?/0]ZW<0=K6bP2__^D0];;F0:nOa`2?PL00//GX0=?V
i02ZkOT0/9o70:6>`080/<?X00d0cNOY0:Nag`2dYLT0c[o<0>CBa@32l?00[:;=09f8_03Aa<d0flS7
0=:V[039Y;<0i;NX0080fZj[03l0Sgfk09b5^P2mV[@0g<_80=>X[037Xk<0i;RY0=^_Z`3?Ui/0SUfC
08IFTP2hU[@0i[b[0=BY[036X[@0iJVC0?F_N@3DViT0TEnC08EDT02eT[<0j;fX0=Z/Z03FViH0P52>
0;>B]03UZY@0fjjX0=bOTP3bZg/0Ug^c09Ak]@2IPk/0/Y:f0>KCa03L[jT0/IFj09ao/`2GN[40V7fc
0:>/g@2U[Md0TjOS0:7Vo02Hk_<0//W[0:6ci@34fnX0a/gP0;n^b@2<[>/0W[_]0;KUmP2FfOh0_kWD
0;_:iP2D`OH0ZM[i0;fedP3]`:D0llZT0>c5[@3GZZT00P3PYYH02P3g[g80ijJ<0?>ZM`3f[W<0SeB5
0?>[MP3g[W80n;1`0?R_L@3g[g820?N^LP0<0?R`L02=DhD0SU>60?N^L@3h/6l0T/3f0<KEi@2Ga?H0
^Jo@0;jN^02d_^80l=2a0`3i/6d0103h[fd0TEJ60?2VM`3g[Vh20?V`K0<0nK1]00D0Re>908Rfm034
bn00k<^b0>c;/`070?V_J@0:0?V_JP1XDJ@0J56T06MAY@0006<08a6107jcmP31cN<0k=2g0>c@^0<0
nJmV00/0n[]o0?V_IP3i[fH0S5F:0000I`28DXT0L5NV0:71l034c>40XL7`0<C=h@020;K7j0060:O1
k02;]_80M:_d06^Vm02Q`>l0hlo30P3j^GT00`3j^WX0n[]m0?ZlO`020?Z^H@<0nZiP00X0nZiQ0;K9
j@1ZYoD0i=740?ZmP@3f_Hh0jJV;0<^HX@3e^hd0n/661P3j[E`0103j[Ed0401b0;77j`2aan/30?[4
S@@0nZaH00D0nZaI0?NYI03gZF@0nJ]M0?Z/E`020:c6k@0<0=_Bd03jahl0jjb=0>^/S@37UJ80l[bE
0?V[E03iZe<0nJ]F0?RYG03iZUP0nJ]D0`3iZe<01@2W`nd0Yl?^0?W8U0000000nJY@00<0nJY?00<0
nJYB0?J_MP3hYd/0103hYd/01P28DXX0@`9C00000028DXX0A05B0?V[EP80REF<0P3hYd/0202AFX`0
TU^<091IS02BFh`0TE^>091JSP2@Fhh0n:M91`3hYdX01P3hYd/0Tef>0?ooo`3oool03AnN000001h0
oooo000O0?ooo`030000003oool0oooo00H0oooo00<0Od5j0>Gce03_[hP01P3_[hP3000000050;6]
e02MXmX0h_KG0?cRXP3`/8H01`3`[hL0400001800005099UV`2DIYX0Xj7C0;7=kP2_f?D0V/[h09je
j025^_L0VKK/0:k7k02^d_<0i/6_0>O0[P3a[h@20?2^Q080lJn40P3b/8<0103a[h<0l:f40?2]Q03`
[X@20?:`P`0<0?2]Q0000840`<KN08F[k@3BcmL0c;2n0;JYc@3Q`kT0ilbj0>>bX`38VZP0i:F>0P3b
[h40103c/840lJj20?6^PP3a[X820?:_P@080?6^P@3b[h40lkJ90?>`P@3b[X40QDZ108=8P02Bco`2
0?>_P0040?:_P03b[X00ljn00?:_P080D/?f00<0XZkP0:7Ro03c[gl00P3b[Wl03`2F[^L0XN7l0:3F
n`24BH40lJf00?>_OP2V]N@0Wmgl08E:P@24BH40m:mm09:]j@2fi?H0_>Gc0:Vdh@020<bncP070<gX
j@36lNl0[j?<0:jhh02AZnP0dN3S0:^ghP020<Vmc`100>KEa@39l^d0/ZG:09Z3^@3=`]00gLg80;NW
b@36X[@0i;RY0=baZ`2fY/P0SgZh09Z1]`2eT[<0i<o20=Z/Z02_U[d0SW^j0;>B]03Y_ZP0iM320;^Z
b02LOk<0Ug^c09Ak]@2Q`>l0Rjo^0;[Tm032a]d0/IFj0::Zg@2SZm`0Xj_M09OMoP3bZgX0SU>50?J_
MP3e[gL0RDn408I=Q01kBh/0lZ]j0:O:lP1ha_l0^Nge0:ZbgP2S^>P0^lGS09fkkP2UbO80/=?b09>g
l02k`Mh0^mC/0>c5[@3GZZT0_ife0>2VUP3g[g80ijJ<0>2VU`3g[g40iJF=0?>[MP80n;1`00P0n:ma
0?N_LP3LXiP0mjib0?R`L02=DhD0SU>60?N^L@80n;1_00D0Wkg^0;c3g`2<^O@0PKOg0;C>k@020>g8
[P80nK1]00@0n:m]095FQP3`YWL0mji^0P3i/6`30?V`K@0608]CR@00::/0RKOd0<C;h034c>00k<^c
1P3i[fT02P3i[fX0J56T06QAY03k/eX0nk9M02<AP@00>kl0N[Ch0<7Ej@2leN`30?V_IP0D0?ZkO`3i
[fH0nJmV08aERP2:DhT0R5:9071GYP1WE:T0XL7`0<C=h@37cMh0^<SW0;C6j02V_n/0U;O_092el01i
Zo<0XL3_0>??``2R`>h20?ZjNP040?ZkO@3j_7l0n[f10?Z^H@<0nZiP00/0nZiQ06ZWm@2fbNP0]l_Y
0>OC`P3W`Jl0`Inf0<^HX@3e^hd0n/660?[0Q@050?Z]G0050?Z]G@0@0780HZ7c0;77j`3OdL/00`3j
a8d30?Z/F00C0?Z/F@3gZF@0mjUT0?V[G@3j[5L0FIcb0:g6k03Ne<l0n<BB0>c9/P34X[L0aiFR0?:l
U@3jai00n/N?0?V[EP3^[HL0nJYH0?V[E0030?V[D`0506R=hP2W]N<0[l?Y0<Gnc00000000`3iZTl0
0`3iZU80mZmf0?RWB`040?RWB`0B08QBRP130U<0000008QBRP140E80nJ]F08=RY@29EH`09a5n0?RW
B`3hYdh0TU^<091IS03hYdd0nJYE091JSP2@Fhh0n:M91`3hYdX01P3hYd/0Tef>0?ooo`3oool03AnN
000001h0oooo000O0?ooo`030000003oool0oooo0080oooo00H0X;[[09^Id@2KVM40U8W50<g6d`3]
hL@40>n_R0<0000000P0kjn80000<00007`0CY?_0<;Rk`2@fOl0l:n60?2`QPL0l:n701<000040000
J@0lG<T0Xm7h0:c]n02Y^>@0Y[?Q0:Joj`2Y`>X0Z=oj0?6_Q@1N^_d0^l3M08Vbl@3V`K00hZjO0<NH
YP3`[X@0fZn/00<0l[2300@0lJn30?2]Q03`[H@0l:j40P3b/8<0203`[H@0l:j40?2^Q038gNP0TmSn
0:OMnP2a_N<0O:kc0P3Ob<800`3=/Kh0eJf_0=F][`020?>`P@<0lJj200P0lZn10?6^P@3a[X40lZn1
0?>fR@3c/840lZj108=8P080lJf10P3c[h001@3b[h00lZj00?>_P03b[h00Q4V10080lJf10P3c[gl2
0?:^O`80ljmo00<0Q4V10?6]P03a[H000P3c[gh00`25BX40Q4V10?6]O`020?B_O@050?>_O@3c[gh0
m:mm05bjo025Bh800P3a[7h30?B_O00407i>S@1oYnd0Y;?S09cIo080m:ml01l0m:mk08nYi`2chOL0
_n_b0:fkh`2R/N<0i]K50<SVk03aZgd0SgZh0:^dg`2?Z>H0/^7g0<;4g02W/n40S;3^0:C0kP2Lg?d0
`/CK0;^Zb02Q[=l0YZkM0:_Qn@2Iio/0X<3_0:F[g02O/>@0TLkm09C9nP26C8<0QEB?0080lZ]j02L0
m:eh0?J_MP3e[gL0RDn408I=Q01kBh/0lZ]j0>:WU03e[WL0mZme08[>oP3d[GL0mjme0::hj02`aNT0
`>Ca086/l02E^>l0`/CL0=g;a`2gYlP0_ife0>K0[`3L/J`0a:>g0>O1/03L/Z`0iJF=0=fUV@3[`JP0
n;1`0?R_L@3g[g80g:>H0?N^LP3h/700SE>508iCQP3g[W400`3h/6l01@19a[H0n;1_0734o`2D]>d0
_/?M0080k/R]00D0nK1]0?R_K@3^ZX40l:Ig0=NOW0020?V`K0<0nK1]00D0Re>9069:W`000640RKOd
0<C<h0020>c;/`D0nJmY00/0nJmZ06QAY01XDJ@0nk=J0?^bG@0k<9X0Qh3508BMh`26_?P0/l[[0>W=
^P020?V_IP0J0?ZkO`3i[fH0nJmV08aERP2:DhT0R5:9071GYP1WE:T0nk1K0:71l034cN40a/gO0;G7
i`2``NL0YK_Y09Rek02F]^h0Ojga0::okP2S_nd0hlk30?ZjNP3j^gd0n[ao0?ZmP@3j[V430?Z^H00<
0?Z^H@0;06l0J:Sf0;S>j`2he>h0aKkD0<6O]P3D_lH0oLR70?[1QP3j`8D0n[n4103j[E`0103j[Ed0
401b00d0L@1RXO<20;77j`<0n/B=0P3j[5P04`3j[5T0lJb00?NYI03iZed0nZaG0?Z/F01HW?80[LW^
0:k>l@3:amL0a::g0<Nkc`3jbYD0n/N@0?[7S`3iZeH0kZf70?VZF03iZe@01`3iZe<01P000000n<^K
0?[9U@3iZTl0nJYB0?J_MPD0n:M;0180n:M<04<2D`000000R5::04@1DP3iZeH09a5n08UES00W4Gh0
n:M;0?RWCP2BFh`0T5V<0?RWC@3iZUD0T5Z>091KSP3hYdT70?RWBP060?RWB`3hYdh0oooo0?ooo`0=
7ih000007P3oool001h0oooo0`0000002P2`c>h0XL;`09c1lP2A]o40NZkd07n`l`25/_<0[o3f06CF
k`3_[hP3000000@0kjn800L0000`03hkY02`[MD0imS50=Sod`3`[hH0l;2600@0l:n700H0l;270?2_
Q`3`[hL0kJb80000J@2e_n420:k<k`0<09k1l@2?eOl0lK250?6_Q@3a/8D0lJn50>j]QP000HX0a<CJ
08V/k03AcMH0bJ^k0P3J[j`01@3YbkH0l[230?:`P`3a[h<0l:f40080l:j400<0l[230?2]Q03`[H@0
0P3`[X@20?:`P`0?0?2]Q01a[oL0_lKO08>YkP3Cd=H0cK6n0;JXc03P`[X0ilbk0>BbX`3;W:L0lJj2
0?:_P@3S/j@0cj6X0080lZn100H0lkJ90?:^P@2dOi/0PU>B08UJU03a[H420?>_P0050?:_P03b[X00
ljn00?:_P023E9400P3a[H420?>_O`80lZio0P3c[gl00`24E900lJf00?6]P0020?>_OP0308ADT023
E940lJeo0080m:mm00L0ljmm0?>_OP3d[gd0ljmm08ECS`21DHl0lJan00<0m:ml00@0OTj=0?6/OP3a
[7h0l:Yo0P3d[g`20?B_N`050?B_O03d[g/0m:mk05Ren`27Dh`00P3aZgd0303b[7`0mJmj0?B_N`3_
ZGh0QlWm0:_<l@2ji_@0GM?20:J]g02abnd0U<_k0>jXOP80l:Um00P0ljej0?J_N03e[gT0mJmi08I<
P`23BX<0QTb308EDS`80lZ]j01D0m:eh0?J_MP3e[gL0RDn408I=Q01kBh/0lZ]j0>:WU03e[WL0mZme
0?J_MP3d[GL0mjme0?J_M@3d[7L0mjmd0?J_M@1U_?d0Zl[`0<C[l022[O000P31f>/01`2igO80^l7O
0;_1g`3Qeld0`;OA0<>R]`3[`JP00P3h[g401`3g[g80g:>H0?R`L03h/700SE>508iCQP3g[W401P3h
/6l02@00=[D0al_M08nhlP3_b:`0l<RY0?R_K@3L/:X0l:Ig0=NOW0020?V`K0<0nK1]00@0Re>9069:
W`00064002RZ0P34c>000`3/bk<0nJmY0?V_J@030?V_J@0>0?V_JP1XDJ@0001O0?^cFP3k/Ud004K7
09n_h`34dnD0ZlW_0;;7jP2<^O@0//OZ0?RdN03j^gl20?V_IP0408aERP2:DhT0R5:9071GYP80nk1K
0140QTj70:32l033c>40`lcQ0;74j02/_NH0YKSW09nWg02L[>80MjWb0:C0k@2U_^`0hL[20?ZkO@3j
_7l0n[f10?ZmPP030?Z^H00;0?Z^H@0;06l0MV:^07>an02ednl0/<_]08Jcl`3Kem<0V/Ce0?_1Q@3j
`8D00P3j_h@30?Z]G0070?Z]G@0@07803@1a08eERP1QXO<0gm7;0;77j`020?[4S@0E0?[4S03j[5P0
nZaI0?6/P03gZF@0nJ]M0?Z/E`3j[5P0nZaI06JUm02_co40^LGS08NclP39d^40UKkc0<gQi`3jahl0
nJ]F0>j]Q`3iZUP0nJ]D00P0nJ]C00D000000?[9U@3iZTl0nJYB0?J_MP050?RWB`0B0?RWC0130U<0
000008QBRP3gZT80nJ]D03<kZ`29EH`09a5n0?RWB`3hYdh0TU^<091IS03hYdd0nJYE091JSP2@Fhh0
n:M;203hYdX01@3hYdh0oooo0?ooo`3oool0000001h0oooo000O0?ooo`0:00000032a]d0//_/0:g8
k@2T_nd0VKO]09RPfP3?`Ld0j]2k0=ONK@8000001P3_[hP01P000000101d0000N@2Q`o40S]Wo0>>h
Z`80l;261`3`[hL01@3][8P0001f0;;Al02ogNl0/n;g0080hL>k01D0jKfX0?6`Q@3a/8D0lJn50>j]
QP3_[HD0W`h00<[Mi`2Bg?h0UMKn0;NZc@2d`><0ilBb0>S3[`3a[h<0i:nM0<ZIY03`[X@0lJn30?:`
P`3U[i/00`3`[X@0103b/8<0l:f40?2]Q03`[X@209;GoP050?2^P`1l[O<0O:gc0>O<^`2gbnT00P3?
/[d02`3DZjh0hk>T0>>cY03?XJP0e:^_0?6fSP3c]XT0lZj10;AoV`22Di80REZD0080ljn000H0lZn0
0?:^P03b[X00lZn00;f7V`23E9420?6]P@040?>_O`3b[Wl0lZio0?:^O`80ljmo00P0Q5B@0?6]P03a
[H00ljmn0<J>VP24E900PeBA0?6]O`80m:mm00L0ljmm0?>_OP3d[gd0ljmm08ECS`21DHl0lJan00<0
m:ml00@0OTj=0?6/OP3a[7h0l:Yo0P3d[g`20?B_N`050?B_O03d[g/0m:mk0?B_N`27Dh`00P3aZgd0
103b[7`0mJmj0?B_N`3_ZGh20?F_NP0606XkQP3`ZWd0l:Ym0?>]N`3e[gT0kZQn0P3`ZGd0203c[GX0
mZmh0?F_N@3e[gT0QTb308=:P`26C8<0QEB?0P3bZgX02@3d[GP0mZmf0?F_M`29Ch@0QTf407];R`3b
ZgX0hZND0?F^M`020?J_MP0L0?B]M`3g[gD0mZme0?B/M`3g[g@0mZme0>:VU03e[WH0mk1c08aAQ@2<
DXD0m:af0?N_L`0kWo@0^]3[0;SHl02B^?40^/7O0;WDkP3/b:h0fZbY0;nL]@3LXiP0n;1_0?R_L03g
[W40SU>60?N^L@L0n;1_00H0nK1^092jl`39c=`0l<RY0>g;/P3L/:X20=NOW080nK1/0`3i/6d0202;
DhT0001Q0000H@000640RKOd0<C<h029]o@0a<cP103i[fT0103i[fX0J56T0000G`3k/eX208A>R004
09kDn`2kbnH0^l_V0:?2k`80/L?W01L0hL:i0?ZkO`3i[fH0nJmV08aERP2:DhT0R5:9071GYP3k/5/0
001Y03@TS`0006L0W<7b0<;>i02oc>@0Zk_U0:>okP2W`N`0RN?k08O2nP1nZo00Z;SU0>?:_`020?Zl
O`030?ZmP@3j_H80nZiP0080nZiP00/0nZiQ00/0K`3j[UL02`1_08bim02dbNT0/<W/086dmP3Nd/d0
Y/G_0?[0Q0030?ZoQ080nZeL01P0nZeM0100LP0=0740SEF:08aERP2aan/0HJ7c0=oAb`3ja8d0n/B<
0?[4R`3j[5T0lJb00?NYI03iZed0nZaG0?Z/F03j[5T0nJaJ0;O7iP2?]?00MZke0:>ij@22/o@20?[7
S`040?S4T@3^[HL0bIFP0?2jU@P0nJ]C00D0n/VE0000003jbI<0nJYB0?J_MP060?RWB`0:028;N`00
0000R5::0?NZ@P3iZe@0<c^[08UES00W4Gh0n:M;0?RWC@80TU^<00D0n:IF0?VZE@2@FXh0T5^>0?RW
B`080?RWBP050?RWCP3oool0oooo0?ooo`0000007P3oool00180oooo1`0000050?ooo`080000002m
e^`0_MK/0<GLj`2Z`^/0X[_[09bgj`2;Z>P3000000P0kjn800P000010000N@2KY]h0/kSM0<C8gP3S
^:/0kLN]0?2`QPL0l:n700H0kJb803lgX02e]mX0/LS[0:VojP2j_]d20>VmZ0050>RnZP3a[hD0lJn5
0>j]QP3_[HD00P3`[XD02P3_[HH0cI6D06nbn@33b]l0NkKh0<O<gP3YaK00cJfj0<ZIY03`[X@20?:`
P`050>F_V`3;VJ<0l:j40?2^Q03b/8<00P3`[H@00`3`[X@0lJn30?6_P`020?2^P`0M0?:`PP34bml0
a<_O0=?@eP3?/[d0]jO90=W5a@3F_<40cj6X0=B[[`3c]XT0lk210<fMY02dOi/0PU>B08UJU03>YJl0
ljn00?:_P03b[X00ljn00?:_P02mQi/0PeBA0?6]P@3c[gl0iKFT0=>TY`3b[Wl00P3c[gl02033S9X0
Q5B@0?6]P03c[gh0ikNS0=JVYP24E900PeBA0P3d[gd0203c[gd0ljmn0?>_OP3c[gd0cI>H08ECS`21
DHl0lJan0P3d[g`0103AUYH0OTj=0?6/OP3a[7h30?B_O080m:mk00D0m:ml0?B_N`3d[g/0m:mk08MC
S0020?6[O@040?:/O03e[gX0m:mk0>nYOP80mJmj00H0JS^60?2ZO@3`ZWd0ljek0?F_N@3^Z7h20?2Y
O@080?>]NP3f[gP0mJmi0?F_N@26C8<0PdZ308I<P`25E8l20?:[NP060?J_MP3e[gL0mJmg08U?Q026
CH@0Nd^;0P3RYi@0103f[gD0mZmf0?J_MP3g[gD20?J_M@0C0?B/M`3g[g@0mZme0>:VU03e[WH0mk1c
08aAQ@2<DXD0m:af0?N_L`3f[g@0Z;OT0;3=kP33l_00S/3h0<3<h`3Mc<P0^Zc;0;nL]@020?;<Z003
0=Z/Z03g[W40fj:I00P0n;1_00P0nK1^000n_03;dMh0T;kf0<_FhP2l[/`0_Ybe0>K0/080nK1/0`3i
/6d02@2;DhT0001Q0000H@000640001P08Vhm034c>00RKSe0>c;/P030?V_J@040?V_JP0002X0001O
0?^cFP80Q4j800`0PTb809^olP2K_o80X<3_08Val02^^^80Z<C^09SUo03i[fH0nKZ008aERP2:DhT2
08QBR@0=0?^`F`27D8P0=2B?0000I`1KLM00^]7/0:;4l@2^`NP0o<mY0?V^I029DXT0nZmH0000GP02
0;6mh`030>K=_P3j_7l0n[f10080n[f20P3j[V001@3j[V402`1_0?Z^E`0;06l0001f0080]LWY00@0
/LS[0:O4k`22]?D0g]7<0`3j_h@20?Z]G0060?Z]G@0@07803@1a08UITP2<EHX0ReB:0P2aan/20?[4
S00D0?[4R`3k`HD0lJb00?NYI03iZed0nZaG0?Z/F03j[5T0nJaJ099IR@3iZed0nZaF06>Ql`2X_>P0
Z/;[0?_4RP3ha940kZf70<VEX03`^YD90?V[D`050?[9U0000000nJYB0?J_MP39U9h01@3hYd/0200R
2g/0R5::028;NP3gZT80nJ]D099LSP29EH`09a5n0P3hYd/01`3hYe00TU^<0?RVEP2CGHh0TE^>091J
SP3hYd/0203hYdX01P3hYdh0oooo0?ooo`3oool03AnN000001d0oooo000E0?ooo`030000003oool0
oooo00H0oooo00D000000?ooo`2aaNT0/<CY0:Rlj00300000080jM:n2@3_[hP01`000040>cRS05nQ
l`2UeoT0_[cH0>JlZ`3]ajd0203`[hL0203][8P06h?X0;?7j@3:d]l0Vl3b09nnk`33a]`0j;jZ0P3X
_JT0203a[hD0kZf60>n]Q@3M[:@0l:j50>n]QP3=TI@0k:V70P1d^_`0103:f^D0`^7^0<f]^P3:VJ@2
0>K3]080iJnK00D0biVS0?2^Q03a[h<0l[230?2]Q0020?2^Q0040?6_P`3`[X<0l:j30?2^P`<0l[22
03@0l:f3056jnP2hgO<0^=gc0:[TnP2iZ//0gl:k0;2lh`3W]9l0ekFh0;AoV`22Di80REZD0<jU[`3T
]:@0dZ>W0=BZ[P3V]J40dj>U0;f7V`23E940QeRB0<ZR/03U]J@0djBW0?:^O`3c[gl0eJBU0<><VP24
E900lJf00?>_OP3W]j<0eZJV08ADT023E940a9fa0?B_O@3DYJL0ljmn0?B_O@3c[gd0cI>H08ECS`21
DHl0m:ml0>RiY03d[g`0dIJF07i>S@3a[7h0jjb<0P3d[g`20?B_N`80m:ml0P3d[g/01@3JW980Qe><
0?6[O@3aZgd0mJmj0080m:mk00@0kjUn0?F_NP3OX8l0JS^60P3`ZWd00`3c[G/0hZ:>0>jXOP020?2Y
O@0I0?>]NP3e[gT0mJmi0?F_N@26C8<0PdZ308I<P`25E8l0lZ]j0>BXT`3f[gH0mJmg08U?Q026CH@0
001B07];R`2/R[40hZND0=b^Z03f[gH0iZR@0?N_M@3f[gD0iZR@0?N_M0020?J_M@0C0>:VU03g/7<0
mk1c08aAQ@2<DXD0m:af0?N_L`3f[g@0mJie0?N`LP3h/780mk1b0:>jj@2m`]h0QKCd09:fl02gd^h0
_=K]0=g<a`020;nK]0030>VoZ`3h/6l0n;1_00D0n;1_00X0nK1^0000FP2FaOL0U/Gg0<3Bj02l[/`0
/kcP0>k@]02^cO00nK1/0`3i/6d02P2;DhT0001Q0000H@000640001P0000G@28^?D0a<cP0>c;/P3]
c;820?V_J@040?V_JP0002X0001O0?^cFP80Q4j800H0PTb80000I0009ZT0^<GT09^kk`2/_nP30?V_
IP030?VjP02=EHX0RU>90080R5:900/0001Y08M@R00d98l0LEbZ08=f_02Z^nH0Zk3L0<o8e02X^>D0
nJiT0?Z_FP020000GP0506NNl02gaND0J:3a0>K>_P3j_H400`3j_H801`3j[V00nZiQ00/0K`3j[UL0
2`1_0000MP2;E8T00P2fbNT00`22/oD0YlC^0:O4kP040?ZoQ0080?Z]G03j[Ed0401b00d0L@0A07<0
S5F:08]DRP1QXO<20;77j`0<0?[4S03ja8/0nl650?6/P03gZF@0nJ]M0?Z/E`3j[5P0nZaI0?V/FP2B
FHT0nJ]M0P3j[5H02@1AUO00ZlG/0:c8kP3]b[00aZ>e0<VEX03`^YD0n/RB0?[7TP070?V[D`05028<
O0000000nLRC0?J_MP39U9h01@3hYd/0200R2g/0R5::028;NP3gZT80A05B099LSP29EH`09a5n0P3h
Yd/01`3hYe00TU^<0?RVEP2CGHh0TE^>091JSP3hYe<0203hYdX01P3hYd/0n:MC0?ooo`3oool03AnN
000001d0oooo000E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000P0000001@2]
]]l0Pjka092[j02dcnh0j;^W00T0kjn800P0000`051]d@31d^L0`M;W08Zjm@2jf_00ikj[0>VlY`L0
l:n701h0kJb80>j]Q`3_[XL0ZlC/0<;7gP2F_?80Vkka09^ml03X_JT0ikf[0>F]V@3=VZ40kjf50=f/
Y03W[iP0dIfP0<fAU00001h07@j201DYYP22c_l0W=;k08S5o02N]^T0[LS^0:SJn@3Rb/40cJfi0<^I
X`3I[JX20?:`P`040?2]Q03>Vj40lJn30?6_P`<0l:j30P3b/8830?2]P`0>0?6_PP3a[X<0lJj30?:_
PP2ma^40OJS_0=W?d03G]KP0/9k609b=``2ST<40fLW90=W0`@3?h^H20=[7a`0S0=g0_02OS/80SX71
0:6=_`3HbL/0f/;20=>TY`3BZJl0ikJR0=FTY@33S9X0Q5B@0<NO/03W]j<0h<Fm0=JVYP24E900WHRm
0<BM/@3LaL<0e:FW0<nW/03W]j<0ejNU0<fCV025Dhl0PE6?0<6J/03X^J@0f:RU0=6FUP1nCXd0_YRa
0>NiYP3FYjL00P3=Y[800`3V^JH0eZNW0?B_N`020?B_N`070=ZLTP27Dh`0lJ]m0>RZT03e[gX0ejVX
0>f/R0020?F_NP0;0=nPS`1Z>hH0l:Ym0>JYT@3e[gT0hZ:>0>jXOP3`ZGd0iJRA0?J_N03L[:D00P3e
[gT208I<P`050899P`25E8l0/8fa0>VnZ03N[jD00P2dUKH02@2FMjh0TgJ_09Il]02/R[40i=K80=b^
Z036Xk@0jKnY0=b^Z0020<JR]0040>RnZP3L[ZP0hZJD0>:VU080mk1c01@0mZie08aBQ@3d[7H0mjmc
0?J_M03e[WD0mk1b0?R`LP3g/780S5:60;3;k@34l?00PK_i09Zml02nbn@0^<OU0;^/bP2oVk@0l<f]
0>k6ZPH0n;1_00X0nK1^0000FP0005/006KI0;[9iP2R`_00RKSd0;>lh02=/nl05P150`3i/6d0102;
DhT0001Q0000H@0006420000H00:02@CP`27]oD0Q[Sf0>g</P3]cK<0nKIh0?V_JP0002X0001O089=
R080Q4j800D0PTb80000I00006<0V;S^0;_0gP020>_;]080nJmV01@0nKZ008eERP2:DhT0R5:90?Z`
GP27DHT0Qe280000IP2MZ=h0^K_K0;[9iP2@__D0nJiT0?^aF`3i[V@0nZmJ0000GP0506`0R5:906fT
lP80^<OV00<0i/jn0?ZmPP3j_H800P3j_H802P3j[V402`1_0?Z^E`0007/02`1_08]DR@2=^O<0]/WX
0;;7jP22/o@20:O4kP<0n[n400T0n[n50?Z]G@0@078000:50000@02=EHX0ReB:00d0L@1QXO<00P2a
b>/02`3k`XH0nl650?6/P03;UYh0nJ]M0?[7T@3j[5P0nZaI0?V/FP2BFHT0nJ]M0080nZaF00P0SEJ;
0:g>lP1SX_<0bmOS0:NdhP35]/`0am3Q0?[8TP80n/NB1P3iZe<01@3iZe80nlN>0000003AZK00bIBN
00D0n:M;00P0R5::04<2D`000000mjY204@1DP3iZeH0REF<02LAOP80n:M;00P0n:M@099KS02@FH`0
Tef>095KSP2@FXh0TEZ=0?RWB@L0n:M:00H0n:M;0?RWD`3oool0oooo00dOWP00000M0?ooo`005@3o
ool00`000000oooo0?ooo`060?ooo`8000000P3oool01`1l/_H0ZKCQ0;^if038aMP0h<6h0>RkY`3X
^Z@0203_[hP0200?0WX0EW3A09;>o02Wa>h0Z<7[0:jmi@3W_Z/0jKbW1P3`[hL20>f/R0080>j]Q`3_
[XL0kZf70:Vdh@34`mT0V[__09bmk`2K_o420>30^0050<fY]@3M[:@0gJbT0=Vd]03AWJ000P2SSkl0
3P2DQl<0SXk>0;39k02Xco@0VlOf09K7n01T^od0Z]Og06k0oP3=[KT0]j_<0>G3]03/c[D0ik2J0P3>
Vj401@3I[:P0lJn30?2^P`3`[X<0lZn30080l[220`3`[H<30?6^P`0?0?:_PP3a[X80amcX08oCoP32
dnH0Z;?P09^dj@2<eOl0YkOU0:Jji`2/]Ml0[/G[0=CPh02i]MD0/j;70080SkSb01`0cN;W0:;Qo02]
]n00f<O90:g4j`3Bh>80]J?608io_P2OR[d0[<K]0:;Qo02gYlT0Y97109f8_@3DbLl0ZLG^0;b/bP2_
^^80e<O=0>75_02hYLH0Yi2m09b5^P3DbLl0h/Rm0;ZYb02XT[h0SGZj0P3AbM80303NbL@0_[;>0<fV
/P3NbL@0eZNW0<bU/@3X^J@0fZVU0=ZLTP27Dh`0^9:a0>NjY`80ejVX00X0bZBb0>RjY@3JZZD0gj2?
06XkQP2cS[00iZVA0=^/YP3RXXh0kZQn0P2aS:l04`3X_:H0g:bU0?F_N@26C8<0U7J^09Qj/02HNk80
RG>d09Qn]P34am`0im700<6]aP2dUKH0UWN^0:Nag`2;Zn/0X;c]09OJoP2ifO400P2nb>80303Se<P0
`[G>0<JR]03Se<P0g:jX0<BO]03]_Z<0m<RP0?N_M03f[WD0iJN@0?N_L`80mZmd00@0mJie0?N`LP3h
/780mk1b0P2<DXH02P3e[G@0n;1a046Al02R^NT0_<7N09:ek`2dcnh0PkSg0;S@k03^aZT50?R`K`05
0?V`KP0005X0001K0000F`2R`_000P2jb>D00`1o/oH0L/?n0?V`K@030?V`K@0408]CR@000640001Q
0000H@80001P00X091>303LkZ@22_?T0`=CY0;[>j@3YcKP0nJmZ0000:P0005l0PTf80P24CXP06`22
C8P0001T0000H`0106L0Rk?a0<;9g`3/c;<0k<jf0?RdN03i^X00SEF:08YCR@0006L0n[1N08MAR@27
D8P0001V03TXT@2Ldo/0^KoN0>39`P3T`kH0nk5K0?V^I00006D0001N08UBR@0208QBR@0306nWl`2i
b>H0i/nn00@0n[f200/0nZiQ00/0K`0<0700001k00/0K`2;E8T0S5B908fhl`2fbNP0//OZ08:cm002
0:O3kP80n[n401H0n[n50?Z]G@0@078000:50000@02=EHX0ReB:00d0L@2<EHT0HJ7c0>3BbP2aanX0
k<F]0<FP/`3;UYh0l[V@0?[7T@3ka8/0nZaI0?V/FP2BFHT0nJ]M0P3j[5H208eFR`050:fihP2nb^<0
MJ_d09?3m`3;bmT0103jai860?V[D`040181M`3?c]P000000;f^b`D0n:M;00P0R5::04<2D`000000
7`Uj04@1DP3iZeH0REF<02LAOP80n:M;00P0TEZ<099KS02@FH`0TU^<095KSP2@FXh0TEZ=0?RWB@L0
n:M:00H0n:M;09=MSP3oool0oooo00dOWP00000M0?ooo`005@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0080oooo00H0Z;OT0<Vnd03X^jL0jKZT0>RjY03X^jL80>n_R00509nUfP37
bM`0V<?e09nkk@30aMh00P3Y_:L00`3X_JT0l:n70?2_Q`030?2_Q`80kJb800d0kZf70>n^Q`3^[HL0
kZf70;?Hl`2kmnl0V;K/0:NiiP38d>00ZmGf0:ZWe02lYl@0_/7L0080]Z_>01H0ZYK10:joi`2_`NL0
]]kd0;?;k02_aNX0//?W0:?4l@2P`o40Sl7h08g1n@26`OX0GZgj0:_8kP2VfOX0[mWf0=2_^03>Vj40
fJbX0>B`WP3@WZ<0l:j30`3b/8830?2]P`<0lJj30`3a[X820?:_PP80lJj200X0lZn20:6`h`2ad?00
Ulgk0?6^P@3a[X80lZn109nai@2`co00/]Kc0P2X[md02P2>e?l0Z=;f0?:^P@2O/ND0Yk7O0:WAm@2R
^^X0Yk_X0:Rbg`2S]^H209OBo00G0:2kk02O[n80WjoR0:[1j`2Rg_`0/^;g0;RUaP2P/N@0SK?`09oO
o02ca>L0`;oI0:>fiP2;/_00W=om08O@o`2bb^`0WlKc07bem`3NbL@0_:c90<o6d@3Sb;d00P2kYlD0
=@2=N;L0V7ng0<g7e@3Obl@0_Jg90<ZT/P3Sb[h0fZZU0:f?]`2>M;80/hj`0>RkYP3Uc;h0[Y2g08id
/P2GNk80/Hb_0>G=_P3L[:D0/I:f09al[`2DMZh0V7Z`0:R_g@2W/n40V]_m08g=o@2Tao80XJoR0:6Y
g02XgOX0Re650?>/NP2S]>@0ZK7N0;[4hP2J]^/0W;k`0:bgh@2H`?<0[M[g08_7o030//`0_KoK09Ng
kP3]a:T0fZVU0<6L/@3UYi00mjmc0=f_Y`3PY9@0mk1b0080n;1b00`0mk1b08aBQP2<DXH0mJed0?R`
L@2:DXL0=Hk_0<C]l01Yg=@0L[gm0<73f`2G]N`20>o6Z@@0n;1_00<0nK1^0000FP0005/00P0005/0
102R_^d0^/3N0:2jj`3VbKX40?V`K@0408]CR@000640001Q0000H@80001P00X0ACNL08J1aP2K_>l0
SkKa0;>mhP2/a^d0nJmZ0000:P0005l0PTf80P24CXP06`22C8P0001T0000H`0o;iL0=3FT0<??h`1m
]?L0jLbh0>;2^00002P0SEF:08YCR@0006L0n[1N08MAR@27D8P0001V03TXT@0c<9l0S[C`0;k4g`3Z
ckX0nZmT0?VlPP0006D01@1/08UBR@0208QBR@0408UBR01`ZO@0^/WV0;[9iP<0n[f200<0nKn800/0
K`0<07000P0;06l02@2;E8T0S5B908]CR@2=^?<0]/WX0;;7jP22/o@0g]3;0:O3kP020?ZoQ@0=0?Jk
RP011hP0KDRE00d0L@2=EHX0ReB:00d0L@2<EHT0HJ7c0;;:k01QX_@0/m3_0<c3d@020<fia`060?[7
T@3ka8/0nl630?V/FP2BFHT0nJ]M0P3j[5H208eFR`0606c=o@3iZed0nJaI07B[m02T^NL0Y[[X0`3j
ai860?V[D`060181M`0Q37/0RKKc0000002jbnL0^]ca0`3hYd/04P28DXX0@`9C00000028DXX0A05B
0?V[EP23HZD0REF<02LAOP3hYd/0TEZ<099KS02@FH`0TU^<095KSP2@FXh0T5^>0?RWB@L0n:M:00H0
n:M;09=MSP3oool0oooo00dOWP00000M0?ooo`005@3oool00`000000oooo0?ooo`080?ooo`800000
0`3oool00`2V_^X0d<C?0:K0k0020>RkY`030>RlZ03_[hP0kjn800H0kjn800P0[/S]03JHlP31b=l0
V;oc0<;7g`3X_JT0`<OO0>RnZP@0l:n700<0kJb80>j]Q`3^[HL00`3^[HL20>n^QP0G0>j]Q`3_[HL0
kjj60>n]Q`1Z]_/0V]Om0:khk02ma^40ZKGQ0;6gg@2me>/0[[CM0;Zhf02la>00/kcO0;:ig`2b_>40
]kSJ0:[0jP2R_nd0U[oc09K1m@1W/o/00P2Je?`0302R^^X0^jk=0=k8``3F^Kd0d9jS0=R[ZP3Ta;H0
l[220>N`VP3@W:00l:f30?6_PP80lJj300D0lZn20?6^PP3a[X80lJj20?:_PP030?6^PP060?:_PP3a
[X80lJj20?:_P@3a[X40lJj20P3b[h40103b[X40QEB@0?2/PP3`[8820?:_P00I0?:^P@3b[h00lZn0
08M=P`21D8d0X[3R0;3<kP3c[gl0lZmo0?:^O`3c[gl0T/Sj089@S01oCX`0l:^10?>_OP2@b_/0O>KJ
0;KNm02Q/>80YjgK0;;?k`3c[gh0ljin03njk`020;K5iP0[0;WFkP2P]^P0XZgO08b/j`2Pfo`0[^Oi
0<?1f@2U[Md0XZoQ09cLo@28cOh0[LK]0:FljP2<[>/0an3[0<C3f@2]SkL0SWBb0:VfhP3<iNT0a/KJ
0;bVa02>M;80Z;GR09>Sh02Xi?X0b<SJ0;6B]P2SYmT0Y:OI0:_On@2TgO/0TeR60?:[O02UZm/0/LKZ
0:W2k026CHD0QTf408]AQ@3c[7X0mZmg0?F_N0020?J_M`0409K9n@32g^d0`]k]0:>ci080^L;Q00H0
Rkkh09Jkl@3PbL80h<W20;bYaP3W_Z/20=f_Y`030<BO/P3[_ZH0n;1b0080mk1b0P2<DXH02P3e[G@0
n;1a08YBQ`0005H0001G08YAQ`29DHL0UkO^0<[:fP2F^o420>o6Z@<0n;1_00<0nK1^0000FP0005/0
0`0005/0102L^>`0a<CJ0>o7Z@3^ajX30?V`K@0408]CR@000640001Q0000H@<0001P00@0XK3R0:[=
lP2G_o<0Yl3[0P3i[fX00`0002X0001O089=R00208A>R00I089<R00006@0001S03l_U`0d=J@0AFkG
082jn@2hc^/0/;cR0000:02=EHX0RU>90000I`3j/5h0Qe6908M@R00006H0>BRA03<`W`0lH/h0]M3]
072^m`2Tj?/0nKb20000I@0208UBR@80R5:900D0RE:802hLR01aZ_D0ilno0;[:i`020?ZmPP090?Vo
R00;06l0MT^A08YCR@0;06l0ReB908aDR@2;DhT0301_0080]/WX00`0//OZ0:O3kP23/o@0Yl?]0?Zo
QP3f^hX00@N80100LP0=0740SEF:08]DRP0=074208aER@0<06fZmP2cd_00c=OR08fel@2Z]N40d]?J
0?[7T@3ka8/0nl630?V/FP2BFHT0nJ]M0P3j[5H0102DFh/0SEJ;08eFR`3iZed20?V/F@0305BGl03I
dM40ZL?/0080n/NB1P3iZe<20181M`0501P5N@000000_/cU0:c5k02mbN@00P3hYd/04P28DXX0@`9C
00000028DXX0A05B0?V[EP0W4Gh0REF<02LAOP3hYd/0n:M>099KS02@FH`0n:M=0?VZE@2@FXh0T5^>
0?RWB`P0n:M:00D0n:M>0?ooo`3oool0oooo0000000M0?ooo`005@3oool00`000000oooo0?ooo`0:
0?ooo`070000003oool0oooo0?ooo`2V`Nd0clGA0:G1k@030>RlZ0L0kjn800X0k:^90:c6k031b>00
`LSP09Jnl`1m]OL0`<OP0>RnZP3X_ZT0jKfW0P3`[hL00`3][8P0kZf70>n^Q`030>j]Q`030>n^QP3^
[HL0kZf700<0kjf700@0kjf60?2^QP3_[HH0kjj60P3`[XH00`3_[HH0W/cg0;OBkP020>n]QP040:ji
h@2l^]L0^KcK0;BnhP80/[cR01D0ZKkX0:?1kP2N`?40T/7g08o1n01Q/_/0NmOn08C;oP2U_NX0i<Bf
0:_7kP3Zb[D0dJnh0=2LX03HZJP0iK2M0=>PXP3a[X<0lZn20?6^PP3CXJ<00P3b[h860?6^PP80lJj1
00D0lJj20?:_P@3b[h40lZj108EDT0020?2/PP80lZn000D0lZj10?:_P03b[h00Qdf3085@S@020?2/
P@030?>_O`3b[gl0lZio0080ljmo00<0PU2<07m>S03`Zh400`3c[gh00`1gAXT0kj^00>n[P0020?>_
OP060?>^OP3c[gd0ljmm0?>^OP26C8<0T<Gj0P3d[gd09`3d[g`0ljim0?B_O02<ao/0M^?J06_Hm02O
[n<0[l_^0:c7k@3d[W`0m:mk09V/i02PY]X0Ym?g08I<Q02:D8D0m:mk0:6VfP2Xd_H0WLOe08U@Q@3[
Y840W:kT09g5m01H0000Qdj408I=Q022BH@0TeR60?:[O03f[gP0m:ii08U?Q@26CHD0QTf408]AQ@3c
[7X0mZmg0?F_N0030?J_M`0N0?F_M`3f[gL0mZmf0?F_M`3d[GP0RJW[0:k9kP37kNh0^/[V0;bYaP2n
_m/0hm?70<:cc034Wk80l/ZW0?C;Y@3a`j40mjmc0?J^M02<DXH0mJed0?R`L@2:DXL0001F0000E`2:
DHL0RE670000E`2F_?80Ukgb0`3_aZT20?R`K`030?V`KP0005X0001K00@0001K00@0Tk[a09:kl`3^
b:d0k/R]0P3i/6d0102;DhT0001Q0000H@0006430000H0090000GP2M^^d0_L;M0>c8/03^bJh0nJmZ
0000:P0005l0PTf80080Q4j801T0PTb80000I00006<0001T075O[P2g_=h0XL;`082bm03ckKh0Wn7m
08eERP2<EHX0001W08QBR@27DHT0Qe280000IP0006L0KeZZ07ic_02]^^<0n[Qg0?Z_I03i_880001U
0080RE:90P28DXT04@29DXP0;Qb802hZVP2jbnL0KJ[f0>SB`03g^HH0nKn800/0K`0<0700RU>900/0
K`2;E8T0S5B908]CR@0<06l02`1_0080]/SX00D0Pk;d0:O3k@2W`^d0n/260?JkRP020100LP0400d0
L@2=EHX0ReB:00d0L@80S5F900l0SEF908fTi02ianD0_=G/07J_mP2U_>T0elc?0?_2Q@3k`H<0nJaJ
0<fFW03iZed0nLJC0?Z/EP2DFh/00P2=EX/0103iZed0nJaI0?V/FP2@FH/20:[4k@040=WAdP3jai80
n/NB0?[7TP@0nJ]C00H0;3>V0181M`0H1GT0N:cc0000001fZ_<30?RWB`0B0?RWC0130U<0000008QB
RP140E80nJ]F03<kZ`29EH`09a5n0?RWB`3hYdh0TU^<091IS03hYdd0nJYE091JSP2@Fhh0n:M;203h
YdX01@3hYdh0oooo0?ooo`3oool0000001d0oooo000C0?ooo`<000003@3oool01`000000oooo0?oo
o`3oool0YL;]0<o6dP2U`^h0103X_:P50>n_R080k:^900@0=Y;`0<37g`2/a>`0OKGg0P30an001`3X
_ZT0jKfW0>RmZ03T[9P0biRQ0>j]Q`3_[XL00P3^[HL20>n^QP040>j]Q`3_[HL0kjf70>n]Q`@0kjf6
00H0kjj60?2^QP3_[HH0kjf60>n^QP3`[XD20>n]QP0I0?2^Q@2Y[]/0aKkC0<34g@2`[MD0_<;O0;Jj
g02a_>80_<3M0:Vli`2V_n/0Wl;a09[3m02>`_P0S<;i04J/n02]fOL0Z=Oh0=6_^02kZlT0gLK30=Ni
^`3CX:80ejVY0>B`W`020=>QX`050=JXZ@3b[h80dZ6S0?6^PP3b[h800P3a[X80203b[h40i;6P0?6^
PP3a[X80lZn10?:^P@33RYP0QEB@0P3`[8800`3b[h00lZj10?:^P@020?:_P00707m>S021D8d0l:b1
0?2/P@3c[gl0lZmo0?:^O`020?>_O`03089@S01oCX`0l:^100<0ljmn00<0MdJ90>n[P03_Zh000P3c
[gh01P3c[Wh0ljmm0?>_O@3c[Wh0QTb30>fXP@80m:mm00X0m:ml0?>^O@3d[g`0m:ml0?>^O@27CH@0
SE:50?B_O03d[g/0m:il0`3d[g/06P3c[W`0QTb408Y@Q@3d[g/0mJmj0?B^N`28CX@0RE250>^TP@3e
[gT0m:ij08U?Q@27CX@0QTf40899Q02CF8H0lZ]l0?J_N03d[WT0RDn508I=Q@26CH@0Re650?>/NP3f
[gL0mJmh0`3f[gL06`3e[gL0mZmg0?J_MP3e[gL0m:eh0?N`M029DHL0RU6708Q@Q`1EVO40W[k_0;g2
gP1n/_D0^];[08Rmn02ndnT0lL>Q0=ZZY@3f[W@0gJ6E0?N`LP3h/740RU:70000EP0005L0RU6708UA
Q`020000E`0409RmlP3;c=X0klJY0>o6Z@80n;1_00<0nK1^0000FP0005/01@0005/01P2B^o<0b<cM
0>g8[@3^b:d0nK1]08]CR@<0001Q0`0006002@0005l0001S09:gl035bMd0k<R_0?V_JP0002X0001O
089=R00208A>R00:089<R00006@0001S0000I00906X0`=?Y09kDnP2g_n00nJmW0000:080S5F:00d0
001W08QBR@27DHT0Qe280000IP0006L0V:?L0<76gP2K`?80a=3S0?RgO@3i_880001U0080RE:90P28
DXT05@29DXP0;Qb802hZVP0iG</0^M?]0;GCk`3K`/40nK^008YDRP0007<0RU>900/0K`2;E8T0S5B9
08]CR@0<06l02`1_08fhl`2fb>P0/LKZ08:bl`020:K2k@070?k;Q`0@0780401b00d0L@2=EHX0ReB:
00d0L@0208aER@0908eER@2<EHT0ReB900h0LP0D07@0ZkkW06NUm03QdlT0n<2;0080aj2a00@0nJ]M
0?W6T`3g`iD0U5^;0P2=EX/01@3iZed0nJaI0?V/FP3i[5T0EYSa0080Z/C]103jai830?V[D`07028<
O00B0GL090il08iHS01/Y?8000000=;>e@030?RWB`0804<2D`000000R5::0000003iZeH0<c^[08UE
S00W4Gh20?RWB`80TU^<00D0n:IF0?VZE@2@FXh0T5^>0?RWB`080?RWBP050?RWCP3oool0oooo0?oo
o`0000007@3oool001D0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`3oool20:G2
kP030<o7dP3X_:P0j;bX0080j;bX103_[hP20>b[R@0H0>f]R@3_[XP0[<?[0<36g`1n]OL0`LOO09Nn
l`3Y_JH0j;fX0<ZV]03;V:40kZf70>:/W03>W:<0kZf70=f]Y@3_[XH0kZf70>n]Q`3_[XH0kjf70>n]
QP3`[XH0hZfN0P3_[XH0103`[XH0kjf60>n]QP3_[XH30>n]QP0C0?2^Q@3_[HH0kjf60>n]Q@2ScOH0
^<o[002=]P2od^T0/KSO09[Io@2i_=`0/;oU0:o0iP2T_nd0Wko_09S1m02?_OH0Q/3j08o3n@020:G<
m00@0<oOi02n[/X0_Zk:0=c6``3G^K`0dj6S0=JXZ@3T/Il0dZ6S0=FXZP3T/J00dj6S0?6^PP3b[h40
i;6P0=>RX`80lZn100@0lZj10<>:V025E900l:b20P3b[h002@3b[X40lZn00>NcW`3b[h00Odj<085@
S@3`[840ljmo0?:_O`020?:^O`050?>_O`3AUID0PU2<07m>S03`Zh400P3c[gh01@3HVY80MdJ90>n[
P03_Zh00ljmn0080ljin00D0ljmm0?>^OP3c[Wh0QTb30>fXP@020?B_O@80ljim0P3d[g`01P3c[Wd0
Qdf408eBQ@3d[g`0m:mk0?B^O0<0m:mk0140ljil08I<Q02:D8D0m:mk0?F_NP3d[W/0R4j408U@Q@3[
Y840mJmi0?B^NP29ChD0Qdj408I=Q022BH@0TeR60?:[O0020?B^N@0508U?Q@26CHD0QTf408]AQ@3f
[gL00P3e[gP20?J_M`80mJmg00l0mZmg0?J_MP3e[gL0m:eh0?N`M029DHL0RU6708Q@Q`1eAhd0HJWh
0;?;k01jiM`0L;Ok09bgj`37a]T00P3Pbl<02@2nV;00gJ6E0?R`L@3g/780RU:70000EP0005L0RU67
08UAQ`030000E`0709RmlP3;c=X0blcJ0>o6Z@3h/6l0nK1^0000FP060000F`06000h]@2A^o<0b<_L
0<S<g@3]bk40Re>90`0006430000H0090000G`16=YX0<CJW0<K=g`27^?H0`LON0000:P0005l0PTf8
0080Q4j800H0PTb80000I00006<0001T040_U@006:820;k4g`0A0>_=]`0002P0S5F:08aERP0006L0
R5:908MAR@27D8P0001V0000I`0j:90000280<3<h`1j/OH0i<Bh0?ZgM`0006D00P29DXT208QBR@0H
08UBR00506`0JE>V07U]^@1l]OL0[;_U0:>okP3i^h00RUB:0000L`2:DhT02`1_08]DR@2<E8T0Re>9
00`0K`0;06l0301_08bhl`2eb>P0/<GZ08B^l03Gc<h0W[_]0P0@0780100=0740SEF:08]DRP0=0742
08aER@0?08eER@2<EHT0ReB901<0M00B07<000JF0:o8k02`cNl0kLFZ0<k4d037X;40l;JA0?W6T`3g
`iD0U5^;0080SEJ;00P0nJ]M0?V/F@3i[5X0nJaI0?RYH@1GVO40ZlG]0=WBdP<0n/NB0`3iZe<00`0R
37`04P5g02@>O00208iHS0030000003EdMH0eM7F0080n:M;00P0@`9C00000028DXX0mjY20?V[E02B
G8h0REF<02LAOP80n:M;0P2BFh`01@3hYUH0nJYE095KSP2@FXh0n:M;00P0n:M:00H0n:M>0?ooo`3o
ool0oooo00dOWP00000L0?ooo`009@3oool200000080oooo00<037WR0:G3kP2U`nl00`3X_:P01@3X
_:L0kjn80>n_R03_[hP0k:^90080kJf900L0kjj80?2`R02Z]^40a<?J08Ffm@2J__40`lON0080clGA
00@0biRQ0=j]Y03P`[X0dK2i0P3M[JD02@3R[9d0cifS0>n]Q`3R[9d0cifS0>n]QP3`[XH0hZfN0<nM
X`020?2^QP030>n]QP3_[XH0l:j500<0kjf600D0l:j50>n]QP3_[HD0kjf50?6`Q0020>n]QP0H0>n]
Q@3a[hD0Z:kL0<Fnd`32a=`0]KkQ0;:hg@2d^mh0ZKcW0:Nlj02N_>d0VkGZ09N`j02O]nT0Wkc]07bc
mP2Ce?h0MKgm0:6hj@2lZLH0flC20=Ni_03CgN00f/?30P3H^k`05P3DYjX0i;6P0>BaX03CXZ<0djJZ
0>JcW`3EXZ80`hZH08EDT03:Wj`0iK>Q0=BSY03b[X40dZJ[0>NcW`3FY:80Odj<085@S@3`[840ljmo
0?:_O`3b[Wl20?>_O`090=NUXP22D8`0Odj<0?>_OP3W]Z40ljmn0=RJTP1gAXT0kj^00080ljmn00H0
ljin0?>_O@3W]Z40fZNQ0?>^OP26C8<20?B_O@040?B_O03c[Wd0ljim0?B_O080ljim00<0Qdf408eB
Q@3d[g/00P3d[W`20?B_N`80ljil00<0QTb408Y@Q@3d[g/00P3d[W/00`28CX@0RE250>^TP@020?B^
NP0608U?Q@27CX@0QTf40899Q03XZHd0mZmh0P3d[WT01P29ChD0QTf408]AQ@3VZ8l0jKbW0=f]Y0<0
mZmg0P3e[gL06P3f[gH0mJmg0?F_M`3d[GP0mk1d08UAQ`2:DHL0R52707E7S@29DHL0RE26028DQ`0W
68P06H7W0=3Cf`2Nao@0h<_30;^Wa@3T^:P0lLf]0?N`LP2:DXL0001F0000E`2:DHL0RE670`0005L0
1`0005X0Ukgb0<_<f`3Y`:X0k/V]0000;@0005X01P0005/01P1=?9h0<CZ[08jkm@34amd0nNR]08]C
R@<0001Q0`0006002@0005l0ASJJ034fY`0kKm/0Y^kh06o1oP0002H0001O089=R00208A>R00:089<
R00006@0001S0000I010;iD0<3:S08:cm02hd>d0Lk;h0:KZnP80S5F:00d0001W08QBR@27DHT0Qe28
0000IP0006T0>RR@02l^W`1g/OL0_<OR0;??k`3j]gL0001U0080RE:90P28DXT0600206/01@1/09>Q
g@2nc^L0Z/_a07>bn03g^H@0nK^008YDRP0;06l0RU>900/0K`0706h0S5B908]CR@0<06l02`1_00`0
K`0]9ID0RKOd0;;7j@2^`^P0m[b<0?VnQ`80401b00@03@1a08eERP2;E8X03@1a0P2<EHT03`2=EHT0
S5F908]DR@0C07@052>O071Q/@1AWO@0Ymgj0<7NkP3>a=00ZK3L0<k>fP3iaY<0ml>E09AKR`0208eF
R`040?V[G@3i[5T0nJaJ0?V/F@80n:UQ00<0ZlG]0=WBdP2[aNd00P3jai830?V[D`04028<O00B0GL0
90il028<O080SUR<00`000000:K2kP3hYd/0n:M;04<2D`0000008P]j0?NZ@P140E80TUb>08UES00W
4Gh20?RWB`080?RWD02BFh`0T5V<09=MSP2AFhh0T5Z>0?RWD`3hYdT70?RWBP060?RWB`3hYe<0oooo
0?ooo`0=7ih00000703oool002L0oooo00L000000?ooo`3oool0oooo0:G3k`3?am80YL?_0080j;bW
00D0jKbW0>VkY03_[XP0k:^90>f]R@020>n^R0030?2`R03`[hP0kjn80080jjZ900`0Wkk_0<37h02J
_O00ZkKR0>32^P2dc^`0dK2i0<2`bP3O`[/0dK6i0<nMX`3L[:H20=6a^@090=^/YP3R[Ih0hZfN0<nM
X`3KZjH0l:j60>n]QP3_[XH0l:j50080kjf60P3`[XD0503_[HH0kjf50>n]Q@3a/8@0iJjJ0>n]QP3_
[HD0lJn50?6`Q02cdo40/o_N09gLo@2a^Ml0^kWG0;Rkg02]_>D0Z[_V09jgjP2@^O80mlfO0P3b/8<0
4`14[?L0VjcR09>/i`28e?l0V]3k09cPo@2a^n40[/3W0=7Gg@2`]=`0_JW60=[4a03H^k`0_:K30=[1
`@3M_KP0eJ:R0<>:V022DHh00P3Ia/H0303J_[d0dZJ[0=:VZ`3W/il0eZBR07m>S021D8d0aYb/0>Fd
XP3EY:@0dJF[0>NdX080ejFR01@0PU2<07m>S033V:`0ikJQ0=RVXP3HVY80MdJ90<6G[@3V]Z<0ejJT
0?>^OP3c[gd0ikJQ0=ZWX@26C8<000180;bC[03d[gd0f:NT0?>^O@80m:ml0P3c[Wd01027CH@0m:ml
0>JgY03IYj@30?B_N`80ljil00<0QTb40?B_N`3e[gX00P3d[W/04028CX@0kjf40?F_N@3NZj80m:ij
08U?Q@26CH@0PTV40;:;[@3XZHd0gjfQ0?B^N@29ChD0TG6/08Q^[P2FNK020>VlY`0E0=f]Y038X;00
mZmg0=f/Y03e[gL0mZmg0?J_MP3e[gL0h:BC0?N`M@3g/7@0RE6708YAQ`28D8L0MDN=08UAQ`29D8H0
8QB702LHR00/6hT0XlWc0080_<_V00T0TjkY0;Fae@2_d?40n;1b08YBQ`0005H0001G08YAQ`29DHL0
0`0005L01`1EAJ80<Sj_09Fnl`37amX0`MCX0000;@0005X01P0005/01P1=?9h0<CZ[03]fh02Xl_@0
L<Ko08]CR@<0001Q10000600200006<0LV6_0;Jef03Tc;l0nJm[00009P0005l0PTf80P24CXP02P22
C8P0001T0000H`0C0gT0@2nE071L[02V^NL0hO[D0?V_J00002H208aERP0=0000I`28DXT0Qe6908M@
R00006H0001Y03XXT01]F:T0MhgL06bgo03h]gd0n[Mg0000I@0208UBR@80R5:901P00P1[02lLR00/
:9T0SKWc0;C8j@2banX0fl2n0?VkP02:E8X02`1_08YCR@0;06l01`1^08aDR@2;DhT0301_00/0K`0<
06l0;BFE03mIa@2_aNX0R;?b0:g4j`3maX<20100LP0400d0L@2=EHX0ReB:00d0L@80S5F900X0XWBO
09e_W@2EJ9`0ID^O01@SW`1`HK40/koS0:G3kP2Q`O00Tk_b0P2A`oP00`3:_Lh0ml>E09AKR`0208eF
R`040?V[G@3i[5T0nJaJ0?V/F@80n:UQ00<0Ei[a0:_5k@3Id]800P3jai820?[7T@050?V[D`0R37`0
4P5g02@>O00R37`00P2>F8`0301=Tnl000000=?Ae`3hYd/08P]k08QBRP000000mjY204@1DP3iZeH0
REF<02LAOP80n:M;00P0n:M@099KS02@FH`0Tef>095KSP2@FXh0TEZ=0?RWB@L0n:M:00H0n:M;09=M
SP3oool0oooo00dOWP00000L0?ooo`00:03oool01`000000oooo0?ooo`3oool0YL?_0<o7dP2U`nl0
0P3Y_:L02@3Y^j@0i:^G0<^GX@3][HT0gjfS0>n_R03`/8P0l:n80>J/U@020>^ZR@0P0>f]R02^_N@0
BHo]09:nm02Q/><0YK_X09K1m@28`?T0e=SK0:?In`2[[m/0gl6j0;W9iP3A/KT0_:S40=k1^P3B/KT0
cifS0=^[YP3R[Id0d9fS0=^[YP3S[Id0dIjR0>n]QP3JZjH0l:j50>n]QP3_[HD0l:n50?6`Q03U[YX2
0>n]Q@030?6_Q@3a/8@0kjf50080kjf500H0lJn40:N^g033_M@0_l?N0:njhP2Y[m`20=bn^`030>Rm
Z@3b/8<0l[230080l[22103b/8<00`2@ZnP0];WL0:Bdi0020:WPnP0O0:WDm`2b^n00TJkZ0=WGeP2m
]]80X8^m08mm^`2_aNX0dMoR0;>ig@2nZ/D0fLC50=no^02hX/<0XX^k09j5^03Ha/P0[L?Z0=3Pi02n
ZLD0elC70=o0^@3GYJ80XhRh09b1]03F`lL0hL:i0=RVXP2VS;X0SWRf0=C6c0020=k3_P0?0<jS[03W
]Z40ikJQ0=ZWX@2YSKP0VWjc0;bC[03V]j<0f:NT0<fR[@3X]j40fjRR0?>^O@27CH@0^8n/0080i[NT
00/0fJNT0<^P[@3d[g/0g:VR0?>^O026C8@0]8b/0?B_N`3MZZ80m:ik08Q>Q0020;::[00J0>RiY03N
Zj80RDn509AcZ`2ALJ`0RFj^0;:;[@3Y^j@0gjfQ0;BA/P2LNJ/0UG>Z08Q^[P2FNK00aLGJ0>GA`P35
]<T0b:2`0>GA``3M[:@0ain`0>RlY`3L[:D0`Y^`0>2TT`3g/7@208UAQ`0>08YAQ`28D8L0MDN=08UA
Q`29D8H08QB702LHR0000580001E046Dl@2U`nl0V;oc0;_7i03[_:@208YBQ`040000EP0005L0RU67
08UAQ`<0001G00L0EDFR07QX]@1ZW>h0L/_o0:2nkP3h/700001J00D0001K00@0001N0000G`1dI;80
^;OH0P3X`:`0102;DhT0001Q0000H@0006440000H00804PfV@009iX0b<oO09C<n`3]bk40000V0000
G`22CHP208A>R00:089<R00006@0001S01<3N@0m:i80VjGL0<;6g@36dN80iL:c00009P80S5F:00d0
001W08QBR@27DHT0Qe280>fH9@0006T0=R>=09RQf`2a/=L0`<KN0>?3]`3j]gL0001U0080RE:901T0
R5:90080J`0206/002:^06UBY@20SmP0S;Sd0:jih@3[i<T0000D08YDRP0;06l0RU>900/0K`0706h0
S5B908]CR@0<06l02`1_02TWV@1UCZ80MFNf0:V^f`2Y[MX0Z[cW00<0401b01D03@1a08eERP2;E8X0
3@1a0180L`2LLJ40XWBO09e_W@2EJ9`0ID^O02];`02J_o80/^Gh0:N^g02SZM/0XZSK08NLh02Q]^L0
UMWn0?V/F`2DFh/00P2=EX/0103iZed0nJaI0?V/FP3i[5T20?RYH@0408EAR`1GV_80ZlG]0:_5k@@0
n/NA00@08Pal0181M`1gG:H02anN0P2>F8`02`2>Eh`0CI?_0000002U`nh0000004<2D`000000mjY2
04@1DP3iZeH0REF<00809a5n00T0n:M;095JS02BFh`0T5V<099KS02AFhh0T5Z>095JS@3hYdT01`3h
YdX01P3hYd/0Tef>0?ooo`3oool03AnN000001`0oooo000Y0?ooo`040000003oool0oooo0?ooo`80
YL?_00`0clOB0>VkY03X^jH0h[nd0<VT/`3][HT0gjfS0?2`R03`[hP0kjn80>J/U@3[ZXT20>f]R080
kJb900L0kJf809fol@2bcNh0D<?e0:>fiP2OZml0Z[;N0080T=co00T0O>C^0:b/e`2k`Ml0emKH0<3L
kP2mZ<@0g/6k0=>b^@2nZ<@00P3O`KX01P3C/[P0fZ^V0=Z[YP3S[Id0dIjR0>n]Q@80lK2400D0iJjJ
0<jJX03a[hD0lJn50?6`Q0030>n]Q@070?6_Q03a/8@0/M7a0?6`Q027eOl0YK7P0;Zdd`020>RmZ@80
l[230P3b/8850?:`P`03093:o03b/8<0l[2300<0l[2300/0R5260000:P28d?l0/Lg^09[;n02R_>`0
Z:kL09b^i02B/^d0Ymoj0;WLlP020:J^g@0L08_AoP2Uc_H0Yl7/0;Bjg@2]`>P0dmcO0<2id`2gWl00
XhRh0;2khP2HZ^<0/>Oh0<>me02VS;X0Sk7]0:_1j@3>hNH0^;kO0;nZa@3Da<X0dMkR0;bU`P2YSKP0
VWjc0=;5cP3OaKl0c>7X0;W1h080hlFj01l0_:?008ic/02HN[40cl7=0>37_`2oZ<<0bj2]0>RhX`3L
ZJ80[Hfd08ib[`2dS:`0j;VS0>G8^`2^S[@0SW:^09Mh[`2bRZ`0i/Vk0=j[XP2bT;<0VgV/095a[029
KZh0b<3B0:Nbh03;i>T0`ZW109aiZ`2VZMT0YJkN0080Um_n00/0Zmoi07Nen@2bgoL0/]og0;gMl030
a]l0U/7e0>C@a030[LL0i[NT0?;:Z00208UAQ`0;08YAQ`28D8L0MDN=08UAQ`29D8H08QB702LHR000
05@0FDRS0351/P2P`_000P2na=h01`3`a:@0RU:708YBQ`0005H0001G08YAQ`29DHL00`0005L01`00
05X0YJgM0<S8f@3Wb;P0j[nX00008P0005X01@0005/01`0005h0BCRJ0012/@3;c]`0Vlgi0?[RZP2;
DhT00`0006440000H00804PfV@0^=JL0RkOd0;cBjP3hiK40[>kh0000G`22CHP208A>R00:089<R000
06@0001T01<3N@0m:i80;32S08Bdm030aMh0^M7/0:SYnP80S5F:00d0001W08QBR@27DHT0Qe2808QA
R00006T0=R>=02`]W`24bOh0_/GP0?;V_P0001`0001U0080RE:90`0206/0100606`0U9oK0;k=i@2/
aN`209oBnP0@0000502:E8X02`1_02HBP@0;06l01`1^08aDR@2;DhT0301_00/0K`0Y9iT0SYKF0;7>
k`2D_o@0G<Kj00d0L@<0401b01003@1a08eERP2;E8X04@1c0180L`2<IJ00XWBO09e_W@2EJ9`0ID^O
09bEc02OX]H0Z:oM0:Nhi@2Ff_h0V=_n0P2=EXX00`3iZeh0nJaK09AKR`0208eFR`040?V[G@3i[5T0
nJaJ0?V/F@80n:UQ00D0QE6;01/6N01FV_80fM;B0:_6k@030?[7T@04028<O00B0GL08@ak01P5N@80
SUR<00X0SUN<00L0M0000000CI?_0100M`130U<000000?NZ@P140E80nJ]F0P29EH`02P0W4Gh0n:M;
095JS02BFh`0T5V<099KS02AFhh0T5Z>091KSP3hYd/80?RWBP0509=MSP3oool0oooo0?ooo`000000
703oool002X0oooo01L000000?ooo`3oool0oooo00Eeg`2V`nl0Y/G_0>:o]03@aLl0bJBc0=n]X`3W
_:T0k<>Z0>VlYP3_[hP0iZbE0>^ZR@3][HP0kZj80>f/R@3][HP0kZj80>f/R0020>j]R0040>j^R03]
[8P0kZf80>j]R080kJb80140kZf80>n^Q`3][8P0kZf709Zfj`30g>d0Z<C^0:j^e`2l`]h0f=OG0=>b
^02oZlD0gl6k0=Bc^03AWZ80fJZV0>_8/@020>F^VP040<jJX03GZ:H0lJn50?6`Q0<0kjf500<0lJn4
0?6`Q03a/8@00`3a/8@0102B/N`0al;F0>Jo[`3U`;430?:`PPT0l[2300D0kjf40?:`P`28D8H0000`
07U1P00308I<P`0509_8m`3b[h40lZn10?6^P@1oChh00P3_[8802P3b[h40Rm?o0:o8k02Ia_H0Qdj4
08M=Q01N_od0Vj[Q0:?GnP2Sc?H208I=Q00:0:6_hP2^bNh0/m_d09C_k@2W[=/0X:gP08o=o@1@c<80
]nGf0:6_hP80ZLgb0140Y/Ka09k3lP2>[>X0ZKcX0<kNi036`MH0_:?009jSf@2Z]N40cn;V0:_TnP2o
Z<<0c[o<0>?6^P3@eml0[Hfd08ib[`020<g0cP0O0<oRi@2oY/40SW:^0:Rbg`2BX=h0Zn;j0<2W`@2b
T;<0XJCG0::TeP2Fe_d0X]Wk08Q@Q@0Y/]D0XjGG0:_>lP040000m:ij08Q?QP2T]nH0/lKY0;g[l`2H
bOT0X[o]0:_2j`1laol0UmWn0;[Il030[LL0^;;D0?cUV00208UAQ`0D08YAQ`28D8L0MDN=08UAQ`29
D8H08QB70000DP0005@0FDRS07Q[^02mb><0VKK/0;[9i@2;^?@0/O?d08YBQ`0005H0001G08YAQ`29
DHL20000E`080000FP1C@Il006?;0:;=mP38aML0nmnT00008P0005X40000F`80001N00H0BCRJ02dh
Z`0iMn40PKcj07K5o`2;DhT30000H@@0001P00P0001T075O[`2e]=P0i<bo0?V_J`0001X0001O089=
R080Q4j800X0PTb80000I00006@04`=i03d[TP1]FZ/0LI7S0::lk03i[fP0001X0P2<EHX03@0006L0
R5:908MAR@27D8P0R5680000J@0f8hd0JUJX07B>gP1a/?P0K;Sl00D0K00006D00P29DXT30080J`0F
02TFQ000<;D0S]?n0;>kh030a]h0SUN;08eGR`2:E8X02`1_02HBP@0;06l01`1^099YW`2JKYl0QEnN
01`b[01OBj<0[jkG0>3Qe00206h04@1c00d0L@<0401b00d03@1a08eERP2IKIh0R66N01/^Z02<IJ00
[ig50:>A``2RT<40Whk10:nni02Oj?/0V>cg00D0SEJ:00<0nJ]N0?V/F`2DFh/00P2=EX/0103iZed0
nJaI0?V/FP3i[5T20?RYH@0608EAR`0K1WP0Dc^G0:[6kP3Id]80Z/K^0P3jai40100R37`04P5g0181
M`0H1GT208iHS00F08iGS00c6800CI?_0000002U`nh0@`9C0000003gZT80A05B0?V[EP0W4Gh0REF<
02LAOP3hYd/0n:M>099KS02@FH`0n:M=0?VZE@2@FXh0T5^>0?RWB`P0n:M:00D0n:M>0?ooo`3oool0
oooo0000000L0?ooo`00:`3oool2000000<0oooo00H0Z<_b0<[?g@2Zbo40[;;M0;g6h@2?_?D20>Vl
YP80iZbE00P0cIVO0>f]R03^[XP0kJb90>f]R03^[XP0kJb80>j]R080kZj800@0kJb80>j]R03_[XL0
kJb80P3^[HP0103_[XL0kZf70>j]Q`3_[XL20>f/Q`0@0>j]Q`2GeOd0kZb704bcn@2>^O<0]]?_0:W9
l@2a^=l0iKn`0;K4i03Q`[T0cj^d0<jJX03GZ:H0lK240?6_Q080kjf50P3a[h@60?6`Q00508Vel`36
aMT0iL6b0>G1/`3b/8802P3b/8<02@3_[H@0l[2308Q@QP000300QTb309eZU`22E980VFNF0?2]P`02
0?:_P@070?6^P@1oChh0kjb20>n/PP3c/800lk1o08Q>Q00208M>Q080Qdf41@26CH@02027CH@0Qdj4
08Q>Q027CX@0Pd^406/mR02GHY40kj^10`3c[gh01@3b[Wl0U<Cg0:g6k03[YX<0SeB60080ljmm00<0
O[kk09o7m029D8D00P3d[gd01@3c[Wd0NNGN07SMn02L[>80XZGH0080U=Kn0P3d[g`00`2QYMP0Yloe
09k5l`020?B_N`0<09j]hP2RY=L0Ylcc0?B_NP3e[gX0ljik08Q@Q@28ChD0RE260?F_NP3e[gT0m:ij
0P28ChH02`29D8H0Qdn505I0W01W[OT0Y/cd0;??kP2L_o40UK7Z05>Gl01iiM`0V:gU0080RE6700h0
RU6708Q@Q`1eAhd0RE6708U@QP0R58L0001D05I6X`0V@[P0R[gg0:cHm`2bcNh0VZ_S0000EP80RU:7
00@0001F0000E`2:DHL0RE670P0005L0200005X0Dd6O02lm/00lOnH0Ql7j07_;o`2;DhP0001J1000
05/0200005h0ACFI02<f[@1aHK40/k;G0?7a`02<E8T0Re>90`0006430000H0090000H`15<YH0Xl;_
0<W?g`2FcO/0kLZ`00006P0005l0PTf80080Q4j800X0PTb80000I00006@0?RfD02PaYP2JYml0_lkU
0;oFj`3YbKH0001X0P2<EHX03`0006L0R5:908MAR@27D8P0R5680000J@0W;J80Uj3K0:n]eP2gbNP0
0P1[00D0K00606`0RE:902@AP@020080J`0G00D0K00Y5X@0MVZi07V;f@1j]_P0SKoh08iGR`2=Eh/0
RUB:00/0K`0V4X402`1_00L0KP2BJIl0VVjO08EOWP1MGKT0SI?E0;;6j@2UiO/00P1^0140L`0=0740
0`0@07803@0=0740TFRO09U]WP28HIh0GUZf09:Bd02[Wl/0[lW]06CIg@1Peml0SEJ;08aER`0F0GD0
102=EXX01@2bOi`0nJ]N0?V/F`2DFh/0SEJ;0080YWFL00h0kkB?0?V/FP3i[5T0eYVC0?RYH@0Q2WX0
6@Eh05<kU`1:U_40ZLK_0:S8l02VcO@0n/NA01l:N`804P5g01T060Ei08iHS02>F8`0SUN<03<HP00T
3W`0CI?_0000002U`nh0dm;G000000140E80nJ]F02LAOP29EH`09a5n0?RWB`3hYdd0TU^<091IS03h
YUH0nJYE091JSP2@Fhh0n:M;00P0n:M:00D0n:M>0?ooo`3oool0oooo0000000L0?ooo`00;@3oool0
10000000oooo0?ooo`3oool20;:oi00L0<O>g`2:`OT0`/GL09^jkP3X^jH0h[nc0<^U/P3=VIl0gZ^Q
0>B[V03AW9l0kJf80>j^R03][8P0kZf80=j[X@3^[XP0kJb80>j]R03_[XL0kJb80>j]R03_[XL0iJbH
0=>NW`3^[HL0kjj70>f/Q`80kZf70P3^[8L01@3^[HL0l;260:RjiP35cn80Q[_h0080^lKS00X0_l?M
0<n[]02jX/40i;ja0>[7/@3U[YX0cY^P0>n]Q@3FYZH0lJn41`3a/8@20<G6f`030<G7f`3U`[@0l[23
00T0l[2300d0kjf40?:`P`28ChH0000`08]LU@2MJYL0PUBB09UWUP3`[H<0lZn10?6^P@37SIL0Odn>
0080kjb200<0lk1o08M>Q028CX@00P27CX@208M=Q0D0QTf400P0Qdf408M>Q028CX@0Qdj408=;Q01[
?HP0Uf:A0>n[P@<0ljmn00H0lZio08I=Q03[YX<0jjJ308mDQP3c[gd20?:^OP0308Q>Q@29D8D0m:mm
0080ljim0P3d[g`20?>^O@0308M>Q@29D8D0m:ml0080ljil00<0R4n508U@Q@3d[g/00P3c[W`208Q?
Q@070?B_NP3c[W/0ljik08Q@Q@28ChD0RE260?F_NP020?B^NP80R4n600/0RE2608M?Q@1F@9`0LV>b
09NhkP2T`>h0XKk^09RYhP2X^^H0Sjk[0:oamP0208UAQ`0>08YAQ`28D8L0MDN=08UAQ`29D8H0001B
0000E01FAZ<0LV^k0;g9h`2R`>l0UKG]08_5n`0005H208YBQ`0>0000EP0005L0RU6708UAQ`0005L0
001J04loW`0V?K<0XZcM0;JceP2ocND0000Q08]CR00005X30000F`80001N00L0ACFI02<f[@1HU>d0
/O?d07[Go@2<E8T0Re>900<0001Q0`0006002@0006<0AC:F02/cY`2=^?<0_]7Y0?SQ/02ak?P0001O
089=R00208A>R00:089<R00006@0201a03h]U01XF:d0Wk_/09>ekP2d^mh0[/?Y0000J080S5F:00l0
001W08QBR@27DHT0Qe280000L`0i9i00IUBY07:PkP1fd?l0oMbN0080J`0506`01P1/08UBR@0T4H40
0P0206/01@0W58<0;42c096HeP2[Z=@0]LKW0080SUN;00@0SEN;08YDRP0;06l09Q:10P0;06l02P2B
JIl0VVjO08EOWP2KV=00V:7K0;Vog`2>F8`00P1^0140L`0=07430100LP0=02HSU`2AJ9l0VFfN08QQ
WP1NF[H0FX;O09fOe@3i[F405@5e0140M02=EX/0S5F;01H1M@0208eFRP0G09]_W`2:Hil0UVbP0?V[
GP3i[5/0U5^;0<NDX@2AIYd0YWFL0>ndS`3k`hP0nJaI0=JIT`3hZF408@Yj01T5N01C>iL0IeN]05JK
lP2Sc_L0Wlgg0?g@T00O2W/00P0B0GL0400H1GT0SUR<08iHS02>Eh`0<aR002@>O00R37`0YL?_0000
003Cd]L0000004@1DP3iZeH0<c^[08UES00W4Gh20?RWB`80TU^<00D0n:IF0?VZE@2AFhh0T5Z>0?RW
B`080?RWBP060?RWCP3oool0oooo0?ooo`0=7ih000006`3oool002h0oooo00<000000?ooo`3oool0
103oool0302R^n/0:i3^0<k4d@3BaLd0bjFb0;jV`@3Q_[D0dJfd0=6LW`3NZj40i:bH0=:MW`80gZ^Q
00T0iJbH0=:MW`3^[HP0kjj70>f/R03^[HP0kjj70>F/V03CWYl00P3_[XL0103][8L0kZf70>n^Q`3^
[8L20>j]Q`0:0?2`QP3`[hH0k:Z80>bZR01m^oX0Ym3f0:chjP2/d?<0]k_L08Z`k`80h/>i00<0d:^d
0=JVYP3FYZH02@3a/8@01027]oD0a<OL0>G2]03U`[@90?:`P`080>n]Q00002@0R4n60000<02;G9D0
WFZG089DTP2IIiH20?:_P@080?6^P@37SIL0Odn>0>n/PP3b[h40l/6L08M>Q028CX@208M>Q080Qdf4
1@26CH@02027CH@0Qdj408Q>Q027CX@0Pd^406/mR02GHY40kj^10P3c[gh20?:^O`0308I=Q03[YX<0
jjJ30080ljmm0P3b[Wh01@28CXD0m:mm0?B_O@3JYZ00ljim0080m:ml0P3c[Wd00`27CXD0RE250?B_
O0020?>^O00308Q?Q@29D8D0m:mk0080ljil00T0R4n508U@Q@3e[gX0hJ^L0?>^N`28D8D0R4n50?F_
NP3e[gT00P3d[WX03028ChH0RE2608M?Q@0004l0ET2L0:fkh`30d^P0Yl3[0:6`hP2M[N<0RNcT09b[
h@<0RE6700h0RU6708Q@Q`1eAhd0RE6708U@QP0005@0EdJS02E2^@2=`?P0[MWg0:J]g@3gk;80001I
0000EP80RU:700/0001F0000E`2:DHL0RE670000F`0005X0CcnO02Hm/`1RXO<0Q][n09n]hP0208]C
R00=0000FP0005/0001K0000F`0005h0ACBH028e[@2Q[^40a<kS0>K<_@3X_ZX0S5B908]CR@030000
H@80001P00X04`Im044_U@15<YH0KUf^0;:_eP3^k/P0Qe690000H00005l0PTf80P24CXP02P22C8P0
001T00P0L@0006H0Y/Wb0<7Hj`2I`_@0XJgO0000I`0006P208aERP0F0000I`28DXT0Qe6908M@R000
07<00@1Y09RQfP31a]h0i<>e0?V_IP0206/01@1/00H0K00Z5X@091610080J`0506`0;T6d06i[_P1d
c?l0nNZI08eGR`80SUN;0100SEN;08YDRP0;06l09Q:100/0K`1NBZ<0:S^`09NId`2_co00W[g^0:?I
nP2;_?H0SUR<0080KP0A07<03@1a0`0@0780500V8iL0TFRO0:ZKb02YUl@0VHc50:jfg`2VjOX0nJeQ
01D1M@0A07@0SEJ;08aER`0F0GD05P9f08USW`2KKil0RV>O09I/X03Z[Y40nJaK0P37U:404`2AIYd0
YWFL0>ndS`3k`hP0nJaI0=JIT`3hZF408@Yj05<iU00D=;40VIcF0;ODk`1aZoD0U[W`0<SQj`25DH`0
8Pal0181M`0H1GT00P2>F8`03@2>Eh`0<aR002@>O00R37`09A>30000002U`^h0000004@1DP3iZeH0
nJYH08UES00W4Gh00P3hYd/2099KS0050?RVEP3iZUD0TE^>091JSP3hYe<0203hYdX01P3hYdh0oooo
0?ooo`3oool03AnN000001/0oooo000_0?ooo`030000003oool0oooo00@0oooo00@0[L?Z0=7Dg03A
e=`0Wk;V0P31`]/03@3Idm<0`Z_30>6o]@3Q_kD0dZjd0<>]a03Q_kH0djjd0=:MW`3MZj40iJbH0=>M
W`3^[HP00P3U[9P0303CWYl0g:VR0>n^Q`3][8L0kZf70>n^Q`3^[8L0kZf70?2_QP3`/8H0l:n60>bZ
R0@0kZb700T0kZf6000^[P35b=`0SK;_0=K:cP3@Zk@0^Z;00>:n/`3WaK<0203a/8@01@3b/8@0Q[Oe
0<C8g@34b=d0i<>e00P0l[230180nl>908Q@QP28ChH0000`08]LU@2MJYL0PUBB09UWUP3;WZT0i[:N
0=JSXP37SIL0Odn>0<:FZP3[]YX0l/6L0>fYQ028CX@208M>Q080Qdf41@26CH@02P27CH@0Qdj408Q>
Q027CX@0Pd^406/mR02GHY40ljmn0>ReW`3c[gh20?:^O`0508I=Q03[YX<0_i>Y0?>_O@3MYih00P3b
[Wh01`2jSZP0m:mm0?B_O@3JYZ00m:ml0>ReW`3d[g`00P3c[Wd00`27CXD0m:ml0?B_O0020?>^O003
08U@Q@3d[g/0m:mk0080ljil00X0R4n50;67Z03Y]j00hJ^L08Q@Q@28ChD0[hBW0?F_NP3e[gT0m:ij
0P2DKjD02P2LMZL0V76U071HY`1[I;T0X/Sc0:F[f`2TZMX0WZKK0;>mh@2P]^P408UAQ`0>08YAQ`28
D8L0MDN=08UAQ`29D8H0001D05M6X`2[_>H0`=KZ08fjm02G]N`0S/Gj0000F@0005H208YBQ`0;0000
EP0005L0RU6708UAQ`0005/0CSjN01XBR02S[=d0_lgU0:79m@2hmO400P2;DhP03@0005X0001K0000
F`0005h0AcFH04DdV01YGK80M;Wk09gEn`2i_=/0nMbY08aDR@2;DhT00`000640300006004@Al01<6
O@11;iD093:Y09[4m02ck_L0O]Go08MAR@000600001O089=R080Q4j800X0PTb80000I@080740?R^A
02P^XP2J^Nd0/<CX0:cLn00006L0001X0P2<EHX05P0006L0R5:908MAR@0007@0001c03HRS000<kX0
Qlcn0<36g`2id>`00P1[00D0K00606`0:QJ402@AP@0206/0GdbU02i1]02@UmH0a<SL0;C6i`2=Eh/2
08iGR`0708eGR`2;E8X02`1_02HBP@0U9IT0GTZS06]V_0020:?0kP070;>lh02O/nH0dn;R08iHS002
06h04@1c00d0L@020100LP0Z02HSUP1LAj40=eS708Ngm@2Xb_80KMc^0?V]H`3i[6@0nJeQ01D1M@0A
07@0SEJ;08aER`0F0GD07A^A08USW`2KKil0RV>O09I/X030XKX0k<>Y0=fg/037U:40TFJM0;bN^P3n
bH@0nl>80?V/F@3FVI<0n:UQ024:NP1C>I@0DTZZ08_Fo`2Sao80XL7_0:ZkiP3h`Hh0QE6<028<O00B
0GL090il0P2>F8`03@2>Eh`0<aR0024<O00R8IH0ECbG04B?kP000000d<_E04@1DP3iZe@0TUb>08UE
S00W4Gh00P3hYd/2099KS006091IS03iZUD0TE^>091JSP2AFXd0n:M91`3hYdX01P3hYd/0n:MC0?oo
o`3oool03AnN000001/0oooo000`0?ooo`800000203oool06@2Qf?/0<:c]0?ooo`2F_?80_=K/09G5
n02Qb?@0^LgY0934n@3C[[@0`jc40;BjgP3C[k@0difO0=fZX@3Q_kH0djnd0=>NW`3LZJ80iJbH0=>N
WP3^[HL0iJbH0=:MW`3^[HL00P3`/8H01@3`[hH0k:Z80>j/Q`3_[XH0kZb70080kZf600T0l:j60?6`
Q@2Re_X0lK2503f^m029/?00j<Rf0;_9i@3V`[401`3a/8@01P3b/8@0l[6408JhmP34b=d0Q[Sf0>C3
]@H0l[2300h0l;><0?_3R@28D8H0R4n60000<02;G9D0WFZG08eMU02TR[P0flC20=jm]`3FXj80WhFh
08if/`80eKRm00<0Qdf40>fYQ028CX@00P27CX@208M=Q0D0QTf401D0Qdf408M>Q028CX@0Qdj408=;
Q01[?HP0Uf:A0<:FZ@3X]Il0g:NN0?:^O`26CH@0QDb409em/02oTjT0j;FO0>?2]P3b[Wh0Sg6]09Qh
[@3W]J400P3JYZ007P3<WjT0j;FO0=jXWP3c[Wd0Qdj50;J;Z03d[g`0gZVM0?>^O028ChD0UgF[0>Rg
X03PZYd0ljil08i_Z`2FM:/0/HNX0>VgX03QZi`0]92a08i^ZP2_Q:L0jKRP0>:/V`2gT:h0W7JW09A_
Y@2LMZL0V76U0:FZfP80YJ_K00<0YLC_0:G2kP29DHL01P29DHL03P2:DHL0R52707E7S@29DHL0001E
05I6X`0S@KT0WLki0:kEm02WZ=L0mn^b08]BR00005T0001F0P2:DXL02`0005H0001G08YAQ`29DHL0
001K04hnWP1]HkH0OHOC08gYmP2M[N80001L0080Re>800d0001J0000F`0005/0001N04LeV00P=:d0
X[CU0;kHk@20]oP0R;Od07g1o@2<E8T0Re>900<0001Q00`0001P0144O00C1Wd0832Y06QJ[`2b/=H0
nK1]08aER@27DHT0001P0000G`22CHP208A>R00:089<R00006D0201a03h[T@1[F:X0X:WM0>7ie`00
06H0001W0000J080S5F:01@0001W08QBR@27DHT0001d0000J@0f8X`0Mfjl072=g`1]^O`0ReB:0080
J`0506`01P1/02XFQ00T4H401@1/05m<Y@1/J[h0KYSY0:>Yf`80SEN;0P2>Eh/02P2=Eh/0ReB:00/0
K`0V4X409BFI04MXd02je^h0X<Od08Bfm@2;^OD308iHS0030080KP0A07<03@1a0080401b02/09R>F
08R;c`2SX=<0aLKK0000003j[Ud0nJeS0?V/I03i[F405@5e0140M02AIid0V6^L08AMW00M6i40RF>O
0:JD``2XU<40XY;40<g>fP3]k/X0nZeI0:f`fP2CQL80el[=0:jhh@3No/40e:FX0=JIT`2USkh0X8Zl
0925a02[a^d0YlK_08Zhm02N]^T0a;cB0?S1SP25DH`08Pal0181M`0T3W`0SUR<0080VVVI00`0<aR0
01dNU@0R8IH0ECbG06MFZ`1@TNd0000008c:o@3iZe80TUb>08UES00W4Gh20?RWB`080?RWD02BFh`0
T5V<09=MSP2AFhh0T5Z>095JS@3hYdT70?RWBP060?RWB`2CGHh0oooo0?ooo`0=7ih000006`3oool0
0380oooo00<000000?ooo`3oool01`3oool20>f/R@0305FAk02__N@0alkP0080X[CV00d0O;?g08k2
n@2WfoX0fMGE0;Bjg@32[<<0]lcZ0=>_]032Zl<0hKng0=B_]03CWYh0g:VR0080e;2d00T0fZRS0>Jm
[@3`[hH0l:n60>bZR03^[8L0kjj60>j/Q`3^[HH00P3`[XH30?6`Q@060?6_Q@3a/8D0a/OK0<K7f`37
bM/0i/6a1P3a/8@0203b/8@0l[6407m7P`26^?H0a<SN0>C3]@34b=h0i<>e103b/8<04`3`/h`0nl>9
08Q@QP28ChH0000`03<l[02VR[L0VX:h0;?5j02F^>l0f=cJ0<6id`2OQKP0SWJc0:b^f@3;m:40ZG6C
0>fYQ028CX@00P27CX@208M=Q0D0QTf400l0Qdf408M>Q028CX@0Pd^40000DP1[?HP0WX6b0<:FZ@3X
]Il0g:NN0:f;/P2JN:`0Sg6]08aa[`3D`<L00P3S`[H03@2nX[d0Sg6]09Qh[@3A_/P0h<:j0<6W_`3<
WjT0hl>g0<2T_@2]Rk40Sg2/0;J;Z03Ua;H00P31YKd05`2?Kj/0UgF[0<jmbP3VaKH0a:Rm0;:>/@2F
M:/0cL3?0>K7]`36Zkl0]92a08i^ZP3;`=00ilRg0<JZ_@2gT:h0W7JW09A_Y@2WZ=L0Y/cc0:G;l`2U
aO00h<k600T0RE6700<0RU6708Q@Q`29DHL00P2LMJH02@1FAZ<0Z;CQ0;RjfP2G_o@0X[_Z04K7c02;
DXP0001I0000EP0208YBQ`0;0000EP0005T0PV:T09UbY@2KLjD03@J106J4g02ocND0XLWe0;WdlP00
05`00P2;DhP03@0005X0001K0000GP19=YT0AcFH06UM/P2X`^`0XkGU0:F]g@2V^>H0ReB908aDR@2;
DhT00`0006420144O00:044_U00P<:T0E8_X0;?^mP1jeOh0S5F908MAR@000600201[089=R080Q4j8
00X0001d0000I@0k:9008RfT09ZRfP2ib>H0/^[h0000IP0006L0001X0P2<EHX04@0006L0R5:908QB
R@0007@0=2:<03U>_@2FW=L0alWL0;S8iP2;E8X00P1[00D0K00606`0:QJ402@AP@1MBj@0@VWC0080
]LGW00<0[>Kj08eGR`2=Eh/00P2>Eh/02P2=Eh/00P1/00/0K`0<0700Gd^S06aW^`2`_^@0Z;GR0:6c
i@3i[V@308iHS00>0080KP0A07<03@1a0100LP0Y=:P0FdJP03YIa`2<]O40Yn;k0000003j[Ud0n:]W
091IS03i[F4201D1M@0]095WW@2HJi`0Q5fL051D]`2@QL<0[LK/0;35j@1Vf]L0REB;0>V]T@3lc8l0
nJaN08]ES029;U00SUR<08iGS02l/m40_:G20:K2k@2Y`n`0WNCl0:;>m`2N_^l0U[W`06jQl03=g^D0
Rkkh08EAS00R37`04P5g02@>O00R37`0SF2I09YYV@1G?IL07AjE065D[@1mM/40UXo90;g0g0000000
nJYK0?V[DP3iZeH0REF<00809a5n00T0n:M;095JS02BFh`0T5V<099KS02AFhh0T5Z>095JS@3hYd/0
203hYdX01@2CGHh0oooo0?ooo`3oool0000001/0oooo000c0?ooo`030000003oool0oooo00H0oooo
00H0kJb90>j^R@3_[hP0kjn80>n^R@2=DH<20;C;j`080<7Zl@2/]=h0X;c/0;c6h@2P]>L0Y/3/0:79
m02<`OT20=SFe@0?0;Fjg@3Q`;L0]/cZ0=B`]02oYl40i[f]0>[2[03Y[Y<0dibL0>j/Q`3_[XH0dijN
0>j]QP3HYZ@0l:j600<0lK2500D0lJn50?6`Q@3_[XL0SK_e0<O8f`030>K1/@@0lK2400L0l[240?:a
Q01oAh<0S56508FhmP34b=h0QKSf0080i<>e0`3b/8<04`3`/h`0nl>908Q@QP28ChH0000`08A<Q02L
]^/0^]S_0;;7jP2Qa_<0YK?S09f^h`2<cOd0L/Oo07C;o`22DHh0ZG6C0>fYQ028CX@00P27CX@208M=
Q0@0QTf400<0Qdf408M>Q028CX@00`2HNZl0902BM[00WX6b0=K1a@3Hg]`0b<3B0:f;/P2JN:`0XjGG
09NUg`2`hoP0_N_c0<[2d`2RY=H0WZ7G0:oQn02Ge_d0/ncg0:^bgP2=Z>L0[/ka0<_4d`2]Rk40Sg2/
0:Z`g03Cg^00cLOD0<6U_@2PX=@0ZJoL0=;Oh@3@bmD0YZWI0:>Yf`2=Y^H0X=Wk0;SIl@80YJoN00d0
S:CU09kHo02ffO80XjcM0:>Wf02SX]@0[M;c06OKcP2PZMd0Y9oA0;nke`3kiJH0e?_P00P0RE6700h0
RU6708Q@Q`29J:L0VWBW09aeYP1XHKL0S<[l0;6eg02:DXP0Re:808]CR02;DXP0001I0000EP80RU:7
00/0001J0000F@22HZ@0VG:U09]cY@1WGK<0HGOB0:BVe`0001/0001I0000G00208]CR00=0000FP00
05/0001N04TfV@0P=:d0[mCc07^Xl029^?D0Rkkg09JTg`2;E8T0S5B908]CR@030000H@804@Al00/0
Cf[>09jZg`32cN<0i[j]0>c6[P2<EHT0Qe690000H00806/0PTf808A>R0020000M0090000I@12G<H0
/kSM09ZVgP3SdLH0nJmZ0000IP0006L0001X0080S5F:01@0001W08QBR@28DXT0001Y03@RS01_Kl<0
KZ7`0::[g@2=EXX0ReB:0080J`0506`01P1/02XFQ00O99X0GD^T06]Y_P2QZM`0n[Ac08aFR`80SEN;
0P2>Eh/02P2=Eh/00P1/00/0K`0<0700SiCD0;k;i02bcNh0R;Kd0:bdgP3i[V@408iHS00l0140L`0@
0780401b02TdZ027RLh0XYoB0<34g@3Hj^40nZiO0?Z^G@3hZfL0T5V<095JS00E0GD0FdFO095WW@2H
Ji`0Q5fL09F<b0000000nJeO0?V/H00G0gH0;RNF0>V]T@3lc8l0oLZ:08]ES00O2GX0SUR<08iGS01`
[OH0Ym;f0<7Fj@2Yanl0YlC^0:C2kP2N]nX0WJ_P0;_6h`2T[Md0nJaK08EAS00R37`0:A5m02@>O00R
37`0SF2I09YYV@1G?IL07AjE065D[@1VM/h0W=Sl06Vjo@3iZeT000000?V[DP3iZeH0REF<0P0W4Gh0
2@3hYd/0TEZ<099KS02@FH`0TU^<095KSP2@FXh0TEZ=0?RWB`080?RWBP0509=MSP3oool0oooo0?oo
o`0000006`3oool003@0oooo00<000000?ooo`3oool01@3oool01@3][8T0kZj90>n_R03_[hP0kjj9
0080k:b900@0ijbD0>f/R@3][8T0kZf80P3[ZXT04@2bb^/0Jl_n0:>hj02[/mh0[kSP08flm@26aod0
YL7^0;Bff`2h`n80k<F]0;WDk@3@ZK40dibL0=ZWX@3U[IP0e;2d0080f:JT103a/8D01@3a[hD0lK25
0>n^Q`2>DhD0S[_e0080alSK00<0i/6a0?6`Q03a/8@00P3a/8@02P3b/8@0l[6407m7P`2<DHD0RE25
050^R034b=h0QKSf0<C8gP3T`kD20?:`P`0C0?2cS03k`hT0R52608Q?QP39R@00Q4b408U@Q@2M/ND0
][WK0;G@k@000000000^08=:Q029ChD0000f089ASP2YLI<0kJV408Q>Q00208M>Q080Qdf41026CH@5
09Qj[`0>0:>Xf@2MY]`0V]_m05[B`@0C0000Wj[O0::Te`2LeO`0YLkf0?6]P029ChD0Qdj508Q?Q@25
_OT20?>_OP0D0?:^O`3c[gh0ljmn0?:]O`28D8H0Wj[O0:73l@2Vc?@0ljmm0?:]OP28ChH0X<;`08Bk
n03d[g`0ljim0?B_O02C`_H0V>gf09GWn`2S[Mh20;73i`0=06OG^03d[g/0XZcN0:ZliP2^_nL0I][A
08U@QP29DHH0Re:70?B_NP23/o@0ljik08YAQ`0808UAQ`0?08YAQ`29DHL0001D08UXY`2JM:L0^KSH
0:6Yg02e`^@0Y<3^0;[al`2;DXP0Re>808]BR00005T0001F0080RU:700/0001J054oWP22HZ@0VG:U
0;Rfe`2SZM/0X/3^08kFo`2;DhP0001I0000G00208]CR00=0000FP0005h0BcRI04TfV@1YGK40][KI
0:BWf02_^N40X[SX0;7^m`2;E8T0S5B908]CR@020000H@070185O@0A17`0@RnD06IH[P1PTn/0V]Om
0;Rkg00208aER@0508MAR@000600201[089=R024CXP00P0007@02@0i9Xl082bT0:;7l`31f>/0i;nb
0;JlgP0006H0001W0000J00208aERP0F08YCR@28DXT0001c06=BZ00kD;h0UYcG0;S8iP2aj_P0SEJ:
08]DRP0206/01@1/00H0K00Z5X@07bBJ045Ze02eaNH0TK[b0:gVn@2<EX/02`1`08eGR`80SUN;00X0
SEN;0080K00;06l0301`02DSUP2A^_80[L7X0:KCm`3i[V<0nJiT102>F8`01`0A07<0401b02/eZ@1W
HKP0K8cQ0777o`29_OL00P3j[Ul0503j[Ud0n:]W0?V]H`2AFX`05@5e05]5W`0cD/<0U8[60<73g03e
kih0d?WU0?V]G`3i[60060=g02hWUP3gaIL0o<b?0?g:RP2;EH`07`Uj0P2NJYD05@0T3G/0PkCd0;K:
j@33c>80Z<3[0:Fmj`2>[^/0T[C_07fXk`3j[5T0nJaK08EAS00R37`0:A5m024<N`0T5HH0SF2I09YY
V@1G?IL073J`07Uc`0020;g0g0050>oWa@3iZeT0TE^=0000003iZeH00P29EH`02P0W4Gh0n:M;0?RW
CP2BFh`0T5V<0?RWC@2AFhh0T5Z>091KSP3hYd/80?RWBP0509=MSP3oool0oooo0?ooo`0000006`3o
ool003D0oooo0P0000050?ooo`0<0>f/R@3_[hP0kjn80>n_R03_[XT0k:b90>j]R@3W[9@0kJb90>j]
R03W[9@0jjZ90P3][8T02@3YZ8X0kJb90>f/R@3_[hP0kJb809nnkP2abN`0^?Ga07Zln`020<38h@07
0=C7c@2c/mP0h;ng0>2o]`3D/;@0_jG00=RVY0040?6`Q@030?6_Q@3a/8D0l:n60080SU>500<0S[_e
0<O8f`2>_?D00P3V`K420?6`Q00;0?:`Q03b/H@0OdN308aAQ@29D8D0QDb408Q?Q@25^?H0a<SN0>C3
]@3T`kH00P3`/h`01@3b/8<0R52608Q?QP0002/0Q4b40080RE2500/0000d08I=Q028ChD0000^08=:
Q029ChD0000f089ASP2YLI<0kJV408Q>Q00208M>Q00308M=Q026CH@0V7V_0080V7V_0`2HNZl20:BX
f@0309kHo02Of?`0R4n50080R4n500@0Qdj508U@Q@2<DXH0ljmo0P3a[H001@29ChD0Qdj508Q?Q@2;
DXH0ljmn0080lZio00D0ljmn0?:]O`3b[Gl0R52608Q?QP020?>_O@80lZen00<0R4n608YAQP3d[gd0
0P3c[Wd0203d[g`0lZem0?:]O@29D8H0RU660?B_O03d[g/0ljil0`3d[g/01P3c[G`0RE6608U@QP29
DHH0Re:70?B_NP80ljik00<0RU6708UAQ`29DHL01@29DHL0402FL:D0W7BU09I_X`2<Ij<0Hejg082J
h`2TfOX0Z=gj09RYh`0C3HH0RU:808]BR02;DhP0Re:80000F@0005H208YBQ`0;0000FP1A?ih06cRc
07Jam`2Jgod0YZOG0?CY^P0002X0Re>80000F@0005`00P2;DhP03@0005l0001N04/hV@0N=:d0Y<of
072Sl02;h_`0S5B90000I@0006<0ReB908aDR@2;DhT00P0006406@0B1Gd04@Al05A]c`2O[n80_]K/
08Rjm`2ag_L0O[gk08aER@27DHT01P1Z00P0J`22CHP0001f0000M00006D0AEg60;C0h`2H_?40QKCd
0;33j02[foP0001V0000I`0006P00P2<EHX05P2:DhT0<1b80000L`1SDZP0Kfo20:6hj@3;bmX0nJmW
08eFRP2;E8X00P1[00D0K00606`01P1]05i;Y02YZ=D0gm390>?4^03j]7<0S5J;00/0L02=Eh/208iG
R`0:08eGR`0206`02`1_03<n[`1RC:80MHOG0::Wf@3ikJ80nJiS0?V^I0@0SUR<00L04@1c05a7X@0T
8YH0QhS=0<34g@2b`^H0nZiP0080nZiO01T0nZiM0?R[I`3i[F<0nJaT01H1M@1KAIl0IUje08:_l@1I
_?`0n/240?V/H03i[El0nJaP000CV01YHKH0OWg70?c<S`3mbXX0ReF<01l9NP2<GID0WVZE02@=N`0N
27T0QK?c0080`LWQ02<0Y;WX09jVg02X[]`0nZaH0?Z/F@3i[5/0QE6<028<O018<I808b2D02@EQP2=
H9T0VVVI05LmU`1GCJ/0CFS>06_Kk@24[o40nJ]G0?V[F@2CG8d0nJ]B0000000W4Gh0REF<02LAOP3h
Yd/0n:M=099KS02@FH`0n:IF0?VZE@2@FXh0T5^>0?RWB`080?RWBP050?RWCP3oool0oooo0?ooo`00
00006`3oool003L0oooo00<000000?ooo`3oool00P3oool04P3MZZ00ik^W0>n_R03_[hP0kjj90>b/
R@3^[HT0ijbD0>f/R@3^[HP0ijbD0>^ZR@3][8T0kZf80>VXRP3][8T0kZf80>n_R080kJb80P3`[hL0
303_[hL0jjZ90:>fiP2o`]`0R;We0:?In`24aOd0]KKJ0;nU`02f`N<0jLB`0>Jo[`80lK2500<0lJn5
0?6`Q@3`[hH00P2>DhD03`27CH@0S[ce08flm@37b=/0i/6a0>>m/@3b/8@0lK240?:aQ01oAh<0RE25
08Q>Q@25C8@0R4n50000;0020<?8g@0D0<C9gP3P_[H0l_Fd0?:`P`28D8H0R4n60000:`24C8@0RE25
08Q?Q@0003@0QTf408Q?Q@0002h0PdZ408U?Q@000300PU6>0:UaT`3]ZH@208M>Q00308M=Q02HNJl0
V7V_00<0V7V_0P2TZ=T00`2Of?/0R4n508Q?Q@0508Q?Q@0408M>Q@29D8D0S5:60?:^O`80lJf000<0
RDn508M>Q@28ChD00P3c[gh20?:^O`050?>_OP3OZ9X0lZeo08Q@QP28ChH00P3c[gd20?:]OP0308Q?
QP2:DHH0m:ml0080ljim00H0m:ml0?:]O@3b[Gd0RE2608YAQP3d[g`20?>^O080m:mk0P3c[G`01@29
DHH0RE2608UAQP2;DXL0mJmj0080ljik00<0RU6708UAQ`29DHL00P29DHL409I`Y@0?09adY@2FKj<0
S6NS0::Yg02RZmd0XJcO0:6ij@1Id]l04`f608YBR02;DXP0Re>808]BR00005T0001F0080RU:700L0
Vg:S00P3O`2U/N00]kWJ09VolP2R^NT0J=W^0080Re>800X0001I0000G02;DhP0Re>80000G`1:=iT0
BcRI06UM/@2d[m@0l]aa0P2<E8T03P0006D0001S08]DR@2<E8T0Re>90000H@0A1Gd04PEm04@`U01d
Nl`0ZJoK0:BWf02UYMH0[KOQ0P2<EHT04027DHT01P1Z00P0J`22CHP0001f0000M00j9Xh0L7C70:;R
o029^OH0YKWX0>GTd029DhX0001V0000I`0006P208aERP0?08YCR@0`78P0001c0040JP32aM`0Wkk_
0>_;/`3eg[D0SEJ:08]DRP0206/01@1/00H0K00706d07QnF0080a=7T00D0j<^i0?^jMP2<EX/02`1`
08eGR`0208iGR`0:08eGR`3bUc`0:AF302@UVP2>S/l0]<?U0:gSn@3j^GT0nJiS0?V^I0@0SUR<00L0
4@1c05a7X@1WHKP0JhcQ0:>bh`3g_hl0nZiP0080nZiO01d0nZiM0?R[I`3i[F<0nJaT01H1M@0^9I@0
WYS=0;>kg`3k_Gh0n/240?^mOP3i[El0nJaP0000KP1YHKH0ck[609fIc`3mbXX0ReF<01l9NP2<GID0
WVZE07E<T`0P89H06`Ii0;;5j01o/?@0Pjg`09NhkP020?Z/F00F0?Z/F@3i[5/0QE6<028<O018<I80
8b2D02@EQP2?Okh0Xhfm0:R?^`2U/N40[K?M0;cHkP3iZe@0nJ]G0?V[F@2CG8d0nJ]B0000000W4Gh0
CCBC02HOTP80n:M;0P2BFh`01@3hYUH0nJYE095KSP2@FXh0n:M;00P0n:M:00H0n:M>0?ooo`3oool0
oooo00dOWP00000J0?ooo`00>03oool010000000oooo0?ooo`3oool20>NkY`0B0>ZmY`3_[XT0dY^L
0>b/R@3W[9@0e9jM0>f/R@3^[HP0ijbD0>^ZR@3][8T0kZf80>VXRP3][8T0kZf80>n_R03][8P0kjj8
0P3`[hL03@3_[hL0jjZ900J2h02bd>l0__O_09O<nP2T^NP0/;_R07VjnP2jcNT0i[n_0;_6hP3U_Jh0
0P3a[hD01`3a/8D0l:n608iCQ@3[ZHP0Qdf40000900001/00P37bM/07`3R_K80j<Rf0?6`Q03b/H@0
RU2508U@Q@26CH@0QDb408Q?Q@0002`07A24086gm`2nan40]]G`087Xg03b/8<0R52608Q?QP0002/0
R4n508U@Q@28ChD0000d08I=Q028ChD0000^08=:Q029ChD0000f089ASP2YLI<00P2INZl309Qi[`80
XjOI00D0Y:OI09oHo023Bh@0Re6608U@Q@0708Q?Q@0408M>Q@29D8D0ljmo0?:^O`80lJf000<0RDn5
08M>Q@2nTJL00P3c[gh01`3b[Wl0ljmn0>RcW03OZ9X0lZeo08Q@QP2:DHH00P3c[gd20?:]OP0408Q?
QP3d[gd0m:ml0?>^O@80m:ml0P3b[Gd01029D8H0m:ml0?B_N`3NZ9d30?B_N`80ljel00D0RE6608U@
QP29DHH0m:mj0?F_NP020?>^N`80RE671`2FL:D03@2U[=`0YJ_K0:?<m@2Sb_@0Vm?l0?WR[P2:DXP0
Re>801<=QP2:DXP0Re:808]CR02;DXP00P0005T02@27IJ@0VW:T09]bX`1UFk80G7KD09G]m02//M`0
Re>80000F@0208]CR00:0000F@0005`0Re>808]CR00005l0BSNI01`c[@2RaO80_^kc08SJo`80S5B9
00h0001U0000H`2;E8T0S5B908]CR@0006404@Em04DbU@1IL<l0X:WM0;O@k@2S`>h0P]So0000G`80
S5F90100Qe6900H0JP0806/0001h0000MP1RDjX0BUo609^Wg`2ne^`0UKC]0:K=m025col0RE>:0000
IP0006L0001X0P2<EHX05P2:DhT0<1b80000L`1UDJH0;V;C08Nhm@2ld>T0/NKh08eFRP2;E8X00P1[
00D0K00606`01`1]05m:XP1m/oH0]lg[0?7Q_@2YhOX0S5J;00/0L02=Eh/208iGR`0:08eGR`2<EX/0
2S>d06UU^`2R]>D0nN6/0?RmR@3j^GT0n[Ym0?V^I0@0SUR<00L04@1c0619X029RLd0^/7O0;oAi`3g
_hl0n[j40080nZiO01d0nZiM0?^gL@3i[F<0nJaT01H1M@0^9I@0F[Ol04N`n03k_Gh0n/240?^mOP3i
[El0nJaP0?V]GP1]W^h0/KoT0:kLm`3i[5h0ReF<01l9NP2<GID0WVZE07E<T`0P89H0CcJD02@k/P2^
_>@0^KkM000000020?Z/F00;0?Z/F@3i[5/08Pal01l:N`18<I808b2D05eA[01QMM00U>?m07g<o`2T
b?80103iZe@01`3iZeT0Teb=0?V[DP3iZeH0000004ddT`0V7i800P3hYd/2099KS006091IS03iZUD0
TE^>091JSP3hYe<0n:M91`3hYdX01P3hYd/0n:MC0?ooo`3oool03AnN000001X0oooo000i0?ooo`0<
0000003oool0oooo0?ooo`3Z_JL0hkja0<fT[`3BVi`0gJRO0>N/U03BZk40gJRO0P3W[9@02@3EWY`0
kJb90>V]T@3GWi/0kJb90>j]R03_[hP0kJb80>n^R0020?2_Q`030>n_Q`3[ZXT0kjj70080l:n700T0
kjn703N5jP2T/^80_[oJ092jl`2j^m/0V:gV0>Jn[P3U_Jh00P3a/8D05P3`[hH0SU>50>^YR027CH@0
000T00008`00?L00`LOO08:jn02kenh0lK2407m7P`2:D8D0RE2508I=Q025C8@0R4n50000;00R:Il0
TXo=05o5o02e`N<20?:`P`0K08Q@QP0002X0000[08Q?Q@29D8D0R4n50000=026CH@0R4n50000;P23
BX@0RDn50000<`0h<Yh0XhBb0:20/02INZl0V7V_0:BWf@2SYmT0W]Sl08E<Q@27ChD0000k08=;Q02;
DHH0RE2500L0R4n500L0RE250<:CYP3c[gl0gjNJ0?6]P029ChD0Qdj50080VgZ]02H0ik>N0=bVW@3>
WZH0ljmn0>RcW03OZ9X0R52608Q?QP2hRjH0ljmm0>2XV`3b[Gh0R4n60;J9YP3d[gd0gJNM0?>^O@3d
[g`0hJVJ0?:]O@29D8H0/XFV0?B_O03W]J00gZRM0<^LYP3X]Ih0m:mk0?>]O029DHH0RE2608UAQP2a
QJH0m:mj0>B/V@3c[W/0W7BT09=/X`D0UW2U0P2U[=`06@2ScoL0Xlkg09kGo02QZ=/0Y:CE0;Bkg`2m
m_00RU:808]CR00C3HH0RU:808]BR02;DhP0Re:80000F@1D@Ih0QfFT09YbY02h]=H0XjOI0;>oh`2T
_^`0^n[d08]CR00005T00P2;DhP02P0005T0001L085NX02HKj80KU6P000PY@1XG;40/joD0?;LL000
06@208aDR@0>0000I@0006<0ReB908aDR@2;DhT0101d0145O@15<YD0Lg[;0;:^e03`i<40S5F:08MA
R@0005l208aER@0=08MAR@0606X0201[0000N00007H0HU>Z06mda`2;^_H0Y[WW0;k1g02T]>@0ReB:
08UCRP020000J@0I08UBR@1Q@9@0S5F:08YCR@0`78P00@1Y06EAYP1cK;`0WJSN08]DRP0106/0SEJ:
08]DRP0206/01@1/00L0K@0K7iP0GdZR0:NYf03Md/d0nJmV0?^gLP2<EX/02`1`08eGR`0208iGR`0:
08eGR`2<EX/0HTbR08f>c`2m`]h0`m7U0?boO03j^GT0n[Ym0?V^I0@0SUR<00L04@1c0619X00XCl@0
^/SU0>?=`P2abnd0n[j40080nZiO01d0nZiM0?^gL@3i[F<0nJaT00DRY01IA9h0eL360?^nO`3k_Gh0
n/240?^mOP3i[El0nJaP0?V]GP3i[5h0jOC>00003`3i[5h0_XNI01X5N02<GID0WVZE07E<T`0P89H0
CcJD06]ab01`Y_80VlSf000000030?Z/F00;0?V/F`0R37`07`Yk04PaTP1LD:`0NG:o09:Bd02md^X0
W[;V09Bjl@1gfO/00`3iZe@01`2BG8d0Teb=0?VZF`3iZeH0nJYH0000000[>jl00P3hYd/2099KS006
091IS03iZUD0TE^>091JSP2AFXd0n:M91`3hYdX00`3hYd/0Tef>0?ooo`020?ooo`030000003oool0
oooo01P0oooo000j0?ooo`8000000P3oool20=G3b@0?0;jQ^`3Q_;80dZ^a0=:[/@31Y;`0hKbb0=>/
/@3EWY`0gJRO0>V]T@3GWi/0gJRN0>n_R03GWi/0kJb800<0l:n700<0kjn70>^ZR@3_[XL00P3`[hL0
?P3_[hL0kjj70>j]R03_[hL0kjj707^`m@37a=L0X/;_0=3Pi03Yck`0SE:50?2_QP2>DhD0jjV808M=
Q00002@0<3JW07ig`02e`n@0elO;0>>l[`3hk:d0OdN308aAQ@29D8D0QTf408E<Q028ChD0000/000a
/`2P/^@0aLOK0>6m/`3Wb;L0o>6808Q@QP000300000[08Q?Q@29D8D0R4n50000=026CH@0R4n50000
;P23BX@0RDn501@GT@0BB/H0/;WP0:f`f`2TZ=T0Wm[l0000A@2;DhP0RU:808E<Q@27ChD0000k08=;
Q02;DHH0RE251P28ChD08027CXD0SG2]0<:CYP3X/i`0gjNJ0:f9[`2IMJT0TW2X08a^[02KNZd0e;k5
0>2o]`33YK`0j;>L0>>o/`3OZ9X0[8R_09MdZP2hRjH0i<6c0<:T^P2]RJl0SVjY0;J9YP3R`[P0gJNM
0<bMYP3X]9h0i<:d0;2;[P2?KJP0UG6X0P3W]J002P3NZ9d0bibV0>ReWP3SZiT0]Xj/09]cY@2>JZD0
RFRW0;65YP3Y]il20<V[^`0409adY02CK:<0UW2U09I`Y@80YJcL00<0Xlog09oHo02Of?/00P2TZ]/0
3`2T_^`0UkS_02Rbc03c[GX0Re:808YBR02;DhP04`f608YBR02;DXP0Re>808YBR00005T0E46N01Lh
]0020:KEn0060:STn`2DY^80S5B908aDR@2;DhP0001I0P2;DhP02P0005l0001N085NX02HKj80KU6P
069F[P1LVo40_Nkc08GJoP0006@208aDR@0>0000I@0006<0ReB908aDR@2;DhT0101d04@aU@1KLM00
X<?a0;cZm025f?l0S5F:08MAR@0406T208aER@0=08MAR@0606X0001i0000N01RDjX0Cf7609^Ug@2o
eN/0T/7f0?SVRP2=EXX0ReB:08UCRP020000J@0I02hJQP1Q@9@0VFbM079@V`0`78P0GDfV04]hg02I
__80j>[@0;CYm`0106/0SEJ:08]DRP0206/01@1/03M3/P1UIKd0AfkE0;gGk@2?d_h0/kkR0?^gLP2<
EX/02`1`08eGR`0208iGR`0:08eGR`2<EX/0HTbR06iT]P1j]?L0]Lg/0:ONnP3j^GT0n[Ym0?V^I0D0
SUR<0100H4VP06eQ]01/aOh0X:gP0?ZkO@3j_X@0n[n40?ZnP`3j[Ud0nkMa0?V]H`3i[6@0nJeQ07Yl
b@2TWm00_LSS0P3j`8@04`3k_Gh0nJeO0?V/H03i[Eh0nJaN0?V/G`3i[5d0nJaN0;j7V@0J1GP0S5fE
09iZU@1eC9<0D4VZ07ee_`2GTL`0//CW0?7M^`3maX<00`3j[5P02@3i[5/021BC01l:N`18<I80G52/
09;CoP2Ya^h0Z;[V0:Nag`050?V[E0090?V[E`2CG8d0nJYK0?V[EP2BG8h0d5L00000001RL</0Xj[L
0080TU^<00H0T5V<0?VZE@2AFhh0T5Z>095JS@3hYd/80?RWBP0509=MSP3oool0oooo0?ooo`000000
6P3oool003`0oooo010000000?ooo`3oool0YKCS0:6ei`35fNP0X]?i0;J/c`31Y;`0`;oI0=>//@31
Y;/0hKbb0=B]/@33Y[`0h[fb0P3E[K401P3LYil0ikbY0>c2Z03_[hL0g:6F0>^ZR@<0l:n701l0kjn7
0>n^Q`3^[HP0kjn70>n^Q`3^[HL0l:n70>n^Q`3Yck`0QTb308eBQ@3`[hH0h:BD0>^YR027CH@0000T
07U1P02T]>@0b<OI0:?:m03S_:l0lnbl07m7P`2<DHD0RE2508I=Q025C8@0R4n50000;00005T0;CR[
0080`<GN01d0^]C]09Wak@28D8H0000`0000:`28ChD0RE2508Q?Q@0003@0QTf408Q?Q@0002h0PdZ4
08U?Q@0D5i4072nY08GIo`2B[n/0oN:?0?:_P`0004D0Re>808YBR025C8D0Qdn50000=023Bh@0Re66
08U@Q@0308Q?Q@1C09MfZ`2GMJ/0UgF[091a[02=L:d0ekk20>>n/P3JfmP0_j6j09UeZ@2BL:P0VioG
0:fcg@2`h?L0a<?I0<>U_02]/]d0c/CA0<6S^P2/R:l0ZjoK09>MfP3Ffm`0d<OB0:f9[`2>KZT0ZJgJ
0=;Lg`37bM/0a:Nl0<njaP3T`[@0a:Jj08m]Z02ELJP0c;[80>?4^035Z;`0bibV0>K3]037YkX0]Xj/
09]cY@2>JZD0RFRW0<bncP2V]><0bmkW0<V[^`2SW/l0Y:7B0:FVeP2VcO@0Xm?i0:JVeP2UZm/0Y[o[
0:Foj`1Wfn40RU:808]CR03d[gT0mJmi0?>]NP2;DXP0RU:808]CR00005@0RU:808]BR02;DhP0UfjQ
08eVX@1D@Ih0Jf6f0;Ngf@2T[Mh0XkSX0?CT^P2hl?@0S5B908]CR00005T00P2;DhP02P0005l0CCVI
085NX02HKj80]k;D0:2Qe@2`_N<0]n?e08aDR@0006@208aDR@0>0000I@0006<03@9k09Q^X@2IKZ00
101d05Uad02a[M@0WJ?I08IAR@2=EHX0S5F:08MAR@0406T208aER@0<08MAR@0606X0001i00P0LP1R
DjX0KgC80:Z`g02VZ]X0`<3J0:bdg`2=EXX0ReB:0`0006T06@0^6XH0HD2D09M[WP1bD9/01AJG05e=
YP2ZZ=@0j>_@00004@0A07000@1[091SV@2FIiT01@1/00L0K@0g@k80S9;D0:N`gP2I`o@0[;oX0:GC
n02>Eh/0S5J;00/0L02=Eh/00P2>Eh/02P2=Eh/0S5J;069<XP1^I;H0W[3T0<K8g03j[V<0n[Ui0?Zj
O@3g^hH508iHS00U0:HN002k`=h0UkK]0<7?i@3j^gd0n[j40?ZoQ03j_X<0nkj10?^gL@3i[F<0nJaT
0?V]H@3i[F80I[cm0;[@jP2hb^P0nkj00?^mOP3i[El0nJaP0?V]GP3i[5h0nJaO0?V/G@3i[5h0_XNI
01X5N02<GID0WVZE0:F<^P1@BJX0BVgC07c8o`2ZaNd0dLO@0?g6P`030?Z/F00:0?Z/F@0859<0BS:B
02/n/P2cc^h0TK3/08>dm@2E^_40nl:70?[5S@@0nJ]D00@0nJ]G0?V[F@3iZU/0nJ]B0P3iZeH02`00
0000RZc/0;SJl@37e^D0TU^<091IS02CGHh0TE^>091JSP2AFXd0n:M;00P0n:M:00D0Tef>0?ooo`3o
ool0oooo0000000J0?ooo`00?@3oool00`000000oooo0?ooo`030?ooo`0B07RYlP2Qe?T0_o3b0:c3
j`2P]^P0aM_Z0:cGmP2j]MD0_LGP0=cDc`3E[K40`JFl0>g4Z@3/`ZP0dJN]0=bQUP3KYYh0ik^Y0P3`
[hL20>n^Q`0h0>j]R03_[hL0kjj70>j]Q`3`[hL0kjj708aBQ@26C8<0kjj70?2_QP3PY9@0jjV808M=
Q01i@H00QTf300l5OP2Fa_P0`lGL0>W6/P2ne^/0OdN308aAQ@29D8D0QTf408E<Q028ChD0000V0000
F@0G2h40Shc<0;KWmP3]nKd0Qdn508Q?QP000300000[08Q?Q@29D8D0R4n50000=026CH@0000^08=:
Q029ChD0000f000GW@2I[nL0];OK0;SBk@2Ml_00lZn30000A@2;DhP0RU:808E<Q@27ChD208=;Q004
08U@Q@2HMj`0V7J/09QfZ`80UgJ[0P2GMJ/04P2SY=H0UjCN09[Ho@1RelL0X:WM0::Re02RXM<0WM7j
08U@QP2:DHH0lZj00>jZPP20_OX0V>ob09WOo@2PZMd0Y<[c09SAo080lZio01H0X:[M0::Qe02Sb?<0
00000?>^OP3a[Gl0[<_`07fin@2GkO@0Xj7C09nMdP2BV]P0[]_g0;?bm@2Y[m`0SZKV0:_9l03DcM<0
Y9k?0:>Nd02TX]<0ZLod0P2Lfod02P2VZMT0Y:GG09k7m0000000lZam08YBQ`2TZm`0Z[SS093ZmP3c
[G`308YBR00C08]CR03d[gT0ljej0?>]NP2;DXP0RU:808]CR00005P0RU:80:9hY02LLj<0UfjQ08eV
X@1SF[80P;Kg08K=oP2;DhT0001J08]DR@0208aDR@0>08]CR00005h0Re>808]CR00005l0CCVI01Da
[P2Td_P0Lj_d07C>o`2@Xn40m=ec08aDR@0006@208aDR@0>0000I@0006<03@9k07YGW@2IKZ00KU2N
05EYb`2O`o80PmSo08IAR@2=EHX0S5F:08MAR@0406T208aER@0908MAR@0007@0001i069CZ`1CI<H0
X/Sc0;O>j`1hf?`0RE>:0080SEJ:01d0ReB:0000J@0006T0001Y02hJQP1Q@9@0Uf^N079@V`1KBJ@0
?G?M09RolP1hdoh0SEJ:0140L00106/0T6>I09IWV@1F@Yh0=T:a06=S_@1kY>d0Xkk/0:NdhP2d^]h0
n>bK08iGR`2<EX/02`1`08eGR`0208iGR`0:08eGR`2<EX/03P1a09^ik@33d>@0j/fh0>_>^03j^GT0
n[Ym0?NkQPH0SUR<02@0N;Ch0;_:i@1d[?D0i/no0?ZnQ03j_h@0n[j30?^nP@3k]g40nJeS0?V/I03i
[F40nJeR0?V/H`1/Z?D0]lWW0>KA`@3k_Gh0d:6V0?V/H03i[Eh0f:RV0?V/G`3i[5d0nJaN0;j7V@1D
>9<02RV[0:F<^`2US;X0[<7Y0:_Hm`2Mb?H0000006^dn`3j[5T30?Z/F00;0?Z/F@3i[5/0Ng6m05a@
Z`2Rd?P0Y:gN0:72l03ibiP0nl:70?[5S@3jaHh00`3iZe@0103iZeL0nJ]I0?VZF`3iZe820?V[EP0;
07>lo@000000`loS0<;>h`2BFh`0T5V<099KS02AFhh0T5Z>095JS@3hYd/0203hYdX01@2CGHh0oooo
0?ooo`3oool0000001X0oooo000n0?ooo`030000003oool0oooo00L0oooo00H0XFVA0>RXR`0GSnL0
S<Ok09_:n01F[?X20;gJkP070<;Lk03IbL/0_Inj0=^VWP3W^jT0kL:W0>n_Q`020>n^Q`0n0>j]R03_
[XL0kjj70>j]Q`3`[hL0kjj708aBQ@26C8<0kjj70?2_QP3PY9@0jjV808M=Q01NDZ`0Xh:`08U`/@1n
P</0[;;L0=O>d00002L0OdN308aAQ@29D8D0QTf408E<Q028ChD0000/00`5P02L/NH0]KOJ0;[Aj`2O
ln`0R52608Q?QP000300000[08Q?Q@29D8D0R4n50000=026CH@0R4n50000E@2GNK00X7j^07AW]P1c
N//0/]kf0:R]f`3a[X<0lZn30000A@2;DhP0000b08E<Q@27ChD0>BfH0:5n[@2OO:`0V7N/09Qf[02H
MZ/30:>TeP0<09oDnP28D8H0RE260?:^P@3a[H40lZn0099HR029D8H0R4n608U@QP3b[Wl0lZj00P3^
ZX802P29D8H0lZio0?:^O`3SZ9H0lZio0>ZbU`3b[Wl0kjZ108UAQ`2:DHL20?>^OP80lJeo00H0ljin
0?2[P027^OH0RU6708YBQ`3c[Wd20?:]OP0<0?>^O@3XZi40Xj_M0:6lk@1?c<H0ljil0>N/TP3a[7h0
V;ca09O`kP2:j_40m:ik0P3b[7d00`2:DXL0Re:80?B^NP020?>]O0<0RU:800D0Re>80?B_N@3c[GX0
ljej08]BR00208YBR00<0000F024Hj@0VG>U09acX`2GKZ40SFJQ0:2Hc02SWm40^KkN0<;cl00005X0
ReB90P2<E8T02`2;DhP0001N08]CR02HKj40JTjO04diV@1VFk40][KH0:BWf02_^N00^>Ke0080S5B9
0140001T08aDR@2<E8T0001U0000L@0=0W/0NUNM09U^X02SXM<0WIgC0<G6f`2_^n<0QU6908eERP2<
EHX0Qe6900@0J@0208aER@0908MAR@0007@0201c069CZ`2^Z]<0kN?608eGR`2;E8/0RE>:0080SEJ:
01P0ReB:0000J@0006T0001Y02hJQP0D8Id0Uf^N0;2RbP2HU<h0VI_D0:fki02_hOP0SEJ:0140L001
06/0T6>I09IWV@1F@Yh0CeJj08^@dP2jd^`0V<Cf00000026`OX208iGR`0408aFR`0;0700SEN;08iG
R`80X6jH00T0IT>D00h0L@1JA9h0O[Oh0;o<i02ocnH0n[Yk0?ZjO@3g^hH01`2>F8`00`1c[?D0^/[V
0;[:iP020?ZnQ00;0?ZnP`3k_X40nkMa0?V]H`3i[6@0nJeQ0?V]HP3i[6<0nJeP0;S;j02haN@00P3H
_l803@3=Yk80kKfQ0>;?a@3AZJl0lkbC0=^VW`2nQiT0E3RC04e2Y@2</o00Om;o0:;3l02K_>l00P2R
]^L00`3f`Y@0nZaI0?Z/F0020?Z/F00;0?Z/F@3i[5/0Ng6m0;K3i037enD0Ukkb0:Bmj`3AcmL0nl:7
0?[5S@3jaHh00`3iZe@04@3iZeL0nJ]I0?VZF`3iZe80nJ]F0?VZF03iZeH0NZod00000032cN<0TU^<
091IS02BFh`0TE^>091JSP2@Fhh0n:M;00P0n:M:00D0Tef>0?ooo`3oool0oooo0000000J0?ooo`00
?`3oool2000000L0oooo00D0XFVA0>RXR`2<DH@0Qdb30:?@m`020;gIkP0>08S?oP2`fOD0X<We0;>]
dP3W^jT0^/CR0>O1[`3CYj/0kjj70=jVVP3_[hL0kjj70=fVV`3`[hL20>n^Q`0308aBQ@3GXYl0l:n6
0080h:BD02X0jjV80000901NDZ`0VGfc0;:hg@2UYmL0^lkX03`0000002L0OdN308aAQ@29D8D0QTf4
08E<Q028ChD0000Y02LWVP2;Sm80P:_`0:nfg@22BX@0R52608Q?QP000300000[08Q?Q@29D8D0R4n5
0000=026CH@0R4n500H0NP2GNK00X7j^0:^]f02gc>T0Y=3g08U@QP3a[X<0lZn30000;@2;DhP208E<
Q@0408M?Q@0i;IP0TGB^09ml[080Y:GF0P2QeOX03P29D8H0R52608Q@QP28D8H0RE260?:^P@3a[H40
lZn0099HR029D8H0R4n608U@QP3b[Wl0lZj00P3^ZX802P29D8H0lZio0?:^O`3SZ9H0dIfQ0>ZbU`3b
[Wl0kjZ108UAQ`2:DHL20?>^OP030?6]O`3c[Wh0ljin0080l:^000P0RU670?>^O@3c[Wd0lZen0?>^
O@3c[W`0j:^A0?6[O`80RU:700L0m:ml0>N/TP3a[7h0RU:708]BQ`3d[W/0m:mk0080lZam00<0RU:7
0?B^NP3d[gX00P3c[G`308YBR00C0?B_N@3e[gT0ljej08]CR02:DXP0Vg6R09E/X029Hj00Q6>T09Uc
Y@2dZ/l0Xi_=0:W6k`2Ta?00000008aDR@2;DhT0001J08]DR@0208aDR@0;08]CR00005h0QF6P09Q_
X@1ZCYl0H5F^07J[l`2FjoP0RN?k08aER@0006<00P2<E8T04P0006@0S5B908aDR@0006D0001a04Da
U01YN]40YJKG0;OEk`2>d_h0N]3o08aERP26DHT0SEF:08aERP27DHT0101Y07EBVP80VFfN00P0001d
061BZ`1IR^H0Wl3`0;_Wm02=Eh/0ReB;08UCRP80SEJ:01L0ReB:0000J@0006T0001Y02hJQP0D8Id0
Wi[>0;KFl020fod0UKC]095IR`3eZg80SEJ:0140L01A?I`0T6>I09IWV@1F@Yh0CeJj09fWgP2T[Mh0
]kSJ0:N_g@0308iGR`0?08aFR`0;0700SEN;08iGR`2ULi/0X6jH06I3U00>0740FTBN02ECb@2ke^d0
LkCi0;KDl03j^Wd0mk^600P0SUR<0280Ljce0;[:iP3Vd<00n[j40?ZnP`3k_X40nkMa0?V]H`3i[6@0
nJeQ0?V]HP3i[6<0nJeP08BZkP2ohO00_^Kb0:V^f`2/^N<0d>GV0>;?a@2jZLP0elS;0>c=]@2gWl00
TG^h0;Big@2d`N@0[<G/0:NiiP2N]nX0Xk;S09jdi`3j_h<0n/>:0`3j[5P0303j[5T0nJaK0?V[G@1k
__`0//S[0;g<iP1o/O@0d=3H0:70k`3jaHd0n/F>0?[6SP80nJ]D00h0nJ]G0?V[F@3iZU/0nJ]B0?V[
EP3iZUP0nJ]F0?V[E@000000[lK[0<;=hP33c>80ZEee0?VZE@80T5Z>00<0n:M;0?RWBP3hYdX01P3h
YdX01@3hYdh0oooo0?ooo`3oool0000001X0oooo00110?ooo`030000003oool0oooo00@0oooo01@0
XFVA08aAQ027C8<0000F0000M`2Q`_00Z=7e0:G;m02LaoH0U<Gh01F9i`1P^_d0Jl;n07[7o`3CYj/0
`:2h0>:l/@3G[Jd0a:Bi0=fVV`80fk2[00`0S5:50:B4/@3GXYl0hKba0=^`[03[ZHP0V7J[08i_Z`1e
JkX0?iOb08V`l03cm;420?2_Q`0K00009`1oAh<0S56508U@Q@26CH@0QDb408Q?Q@0W9YX0;fCD09fa
iP2kd^/0OM?o089:Q028D8H0R4n60000<00002/0R4n508U@Q@28ChD0000/08I=Q028ChD06QVA03n5
j@1ncol0R[Od0080l[2200d0RE260?6^P`3b[h<0000]08]CR02:DXP0Qdn50000>`0>1X00VZCL0;6`
e`2/g?P0kZ^40080R52600H0RE2608Q@QP28D8H0R5260<FCX@3b[X420?:_P00:08U@QP28ChH0RE26
0<:@XP3Z/YL0ijZ@0>jZPP29D8H0Ug:W0>RaV@80hjRF00T0dIfQ0>ZbU`3XZi00RE6708U@QP2iR:80
ljin0>:XUP3a[Gl00P3c[Wh00`3`Zh00RU670;F5XP020?>^O@090?:]OP3c[Wd0ljil0>R[T@3aZgl0
RU670;62XP3Y]9/0ijbB0080RU:700X0[WnR0?B^N`3d[g/0lZam08YBQ`2[OJ80m:ij0?B_NP3c[G`0
Re>80P2:DXP03@2/Oj<0m:mi0>J]UP3c[GX0W7:R099YX02KLJ80UFbP08USX01PFK<0LK?i09_@nP1P
eNT0102<E8T00`2;DhT0001J08]DR@0208aDR@0809I[W`1VBih0QF6P09Q_X@2PUl/0WiO;0:6Ld02g
_=d208aER@050000H`2<E8T0S5B90000I00006000P2HKIl060000740AC6D0;:cf@2V[mh0Y:[K0:ff
g`2ehOH0S5F:08IAR@2=EHX0S5F:08MAR@0406T0ME:J09Q]W`2IKIh0G4fX061BZ`2/ZM@0j^G;08eF
R`2=Eh/0ReB;08UCRP80SEJ:01D0ReB:0000J@0006T0:AF301<OW01KBjH0[KWR09RmlP2V_>T0Z=Oh
0=ZMT`3eZg80SEJ:0140L01A?I`0@dRb0:^Ha02]a>/0YKcY0:Fjj020dOl01@2>Eh/03`2<EX/02`1`
02/BOP2AIYd0YG>K0:1^V01V@i@02A2>05Y4WP2RY]P0V;?[0:k6k028]oD0[<C[0000600708iHS00K
0:=_U`3fZV`0^/[W0>K@`02jb^L0n[j30?^nP@3k]g40nJeS0?V/I03i[F40nJeR0?V/H`3i[F00oKmi
0?V]HP3i[6<0nJeP0?V]H@3i[680nJeO0:oKm`1ha_l0`[_C0:NYf02][=L0/^Gg0080nZeL00H0X[c/
0:^eh01_Y?40L[;h0?ZoP`3j`hX30?Z/F00;0?Z/F@3i[5/0nJ]M0?JXIP20/_@0/LOZ0;c;iP1o/?@0
cm3J09o0l03?d=X00P3jaXh04P3iZe@0nJ]G0?V[F@3iZU/0nJ]B0?V[EP3iZUP0nJ]F0?V[E@3iZUL0
000008FTj02@FH`0ZEee0?VZE@2AFhh0T5Z>0?RWB`P0n:M:00H0n:M>0?ooo`3oool0oooo00dOWP00
000I0?ooo`00@P3oool00`000000oooo0?ooo`020?ooo`0>09QST@2QJI40WGnb09mn/02JNk00];gQ
0;>hg@2kcNP0//;V0:c0j02`_nD0XKo^0:70k`2;_OL208g4nP0C07[0o@3Me<l0gMC?0;fhe@3R_;00
^<[X0<2ab`2fV[/0T7Jb0>6l/@3Pd<P0fk2/0;JH^02HMZ/0SVn[0:FUeP2YZ=D0^l_V000000020?2_
Q`0400009`1oAh<0S56508U@Q@80QDb40280000/02LVVP1`Jkd0[[GN0;JgfP3^[8L0PTZ408Q@QP28
ChH0000`0000:`28ChD0RE2508Q?Q@26CH@0R4n50000=@0DC/T0^KoO09fdj031cnD0l[2208Q@QP29
D8H0lJj30?:_P`0002d0Re>808YBR02AM[00WH6d0?OGZ`3a/h`0lJj20P3^Zh@00`28D8H0RE2608Q@
QP0208Q@QP0809eiZP35Tj40jk6E0?:_P02_Qj/0Ug6U08YXYP2;JjP20=Rm_`0I0>Bl[P34XkL0SF^V
09MbY`3F_L40hKbb0<NV^03AWJ40j[:G0>R[T02^Qj`0UG2V0;V8XP3X/YX0hZRF0<nMXP3Y/YP0j:^A
0;69Z`2=JJ@0U6jT0>RcV`3SZIH0cibR0?>^O@020>R[T@0P08iXX`2CKJ<0/H:R0>VdV`3W[980]XbY
09=/X`2^Oj80m:ik0>N/T`2hSJT0SVRS0:]mXP3d[WX0ijbD0;^?Z@2KLJ80TFRP08QTX`2DKjD0jKJO
0>S6/`2mTJT0W7:R099YX02KLJ80UFbP08USX02OUl`0XYoA0;Zng@2;E8T408aDR@0=08]CR@0005X0
ReB90:9fXP2LLJ00UV^O06I;WP006j@0YjGD0;7?l02S`^l0Q>Kd0000HP0208aER@0R0000H`2<E8T0
S5B90000I00007@0OeZM09Q]W`1YC9`0D6O;0:C;m02Gj_T0SEJ:08E@R@2=EXX0S5F:08IAR@2=EHX0
S5F:08MAR@0n:Y00ME:J09Q]W`2IKIh0G4fX0528i`2N`?00PmKo08eFR`2=Eh/0ReB;0000K0000780
SEJ:08]DRP80001Y0180:AF305U9Y@1LR>@0XNWk0:g>l@2ab>/0k<^a0=R[Z@3eZg80SEJ:0140L01A
?I`0BE6h08[Ho`2U[=`0_k_E08aFR`0606d408iGR`0?09e/V@2<GiP02`1`02/BOP2AIYd0YG>K0:1^
V01V@i@0ED2L03MRd02Oa?80/nCg09N^i`2[/M`0[;OR00L0SUR<0P2HIiP0603fZV`0T5V<0;[;i`1a
[?H0^/_W0?^nP@3k]g40nJeS0?V/I03i[F40nJeR0?V/H`3i[F00oKmi0?V]HP3i[6<0nJeP0?V]H@3i
[680nJeO0?V]H03i[640nJeO0?Z]F`@0nZeL00L0RJk^0:nih03KblX0nkn40?ZoP`3j`hX0n/><0080
nZaH00/0nZaI0?V/F`3iZed0ljaj0?Z/E`2aanX0P;7d07j`m02O`?00c]3J0?[5SP020?[6SP0C0?_5
RP3iZeL0nJ]I0>bZQ`3iZe80nJ]F0?VZF03iZeH0nJ]E0?VZE`2<Y>D000000<S_k@000000nJYE095K
SP2@FXh0TEZ=0?RWB@070?RWBP030?RWB`2CGHh0oooo0080oooo00<000000?ooo`3oool05`3oool0
04<0oooo00<000000?ooo`3oool00P3oool209eo/P0K0;2bf@2^/=T0^mga0;O7iP2g]=H0/[3F0;Fn
h@2_[mP0/;WP0:nkhP2Z_>H0Z;_W0:6nkP2Q_nl0Ul3d08o0m`1H[?X0I<7n09O;nP2M/NH0Wk;U08>X
k02bhOL0S=Go0<6_b02OYm`0XJGI0080XMWk1@3`[hL0:@0002L0OdN308aAQ@29D8D0001d08Q?Q@2P
OZh0LfRh09;<o02Qm>`0O=Co0>j/Q`22BX@0R52608Q?QP000300000[08Q?Q@29D8D0R4n504m0X02G
N:h0QV^]06iT]P1bYo80V<Kg0;>df@3ekkL0R52608U@QP3a[X<0lZn305a4W02;DhP0NDB40;3?l@05
N^00P<[o0?6cS03UZ9<0kZ^40080R52600L0UW:W09IaY`2ELJL0SVbX08a/Z@3J_Kd0i;^]0080a::g
01H0Ug6U08YXYP2;JjP0[[SQ0=WIe`3BaLh0a:>g08e[YP2/]N00eM[K0<_9f037Y[P0eko20=?Ff`36
Y;L0[XN/09E`YP3C_<@0ZK?O0=?JgP3=c=T0iKj_0P38Y[L05P2=JJ@0U6jT0=2laP3S`;<0b:Rh0>Vc
V@3V`;00bJNg0;B;ZP2CKJ<0/H:R0>VdV`3:Z;L0]XbY09=/X`2^Oj80il>a0<^Z^02hSJT0SVRS0:]m
XP3Wa;820<b[^00809]aXP2AJ:00R6BS09A_Y@37^/h0g=WD0<f]^@2LLZ820:6Gb`040::Ib`2W`nh0
Y<;^08cYm@80ReB9102<E8T03@2;DhT0001L08=OX@2HL:<0W76P09I[W`1VBih0GE>^09nKd03cg[P0
SEF908aER@0006800P2<EHT0=P0006<0S5B909U]W`2HK9h0001d07mJW@2HKIl0X9c@09bJd@3?am80
[k[Q08eFRP25D8T0SEJ:08aERP26DHT0SEF:08aERP27DHT0?RZ@07EBVP2HKIl0/J?:0:2Ic@2]^>40
X[WY0;?Km02=EX/0SEN;08]DR`0006`0001b09Y[V`2LK9X0001Y028=OP1:EK`0Ti[G0<GNj`2SeoX0
WlOd0<;Fj@2lf>h0f:^Y0:ZG`P2OQkT0UWjg099n^P2Z]>00X[;T0:2^h@2^d_<0S5J;00H0K@<0SUN;
00l0UVRK09a]V`2<GiP02`1`02/BOP2AIYd0YG>K0:1^V02QS;h0TH[8092Jf@2U`Nd0W;_^07C0oP1`
`oh01P2>F8`209EWV@0J09MWV@2HIiP0mZY/091IS00K1GL0^/gX06j]m`2jcNP0nkMa0=>QXP3i[6@0
nJeQ0?V]HP3i[6<0nJeP0?foN@3i[F80nJaS0?V]H03i[F40nJaR0?V]G`3i[F00nJaQ0?V]G`3j[E/4
0?Z]G00B0?Z]G@1ZWo00//3T0;?4i`3j_h<0n/>:0?[3S03ja8`0nZaH0?Z/F@3i[5/0nJ]M0?>/NP3j
[5L0nJaJ0;77jP20/O@0O[3d0P2O`?020?[6SP0C0?_5RP3iZeL0nJ]I0>bZQ`3iZe80nJ]F0?VZF03i
ZeH0nJ]E0?VZE`2@Fhh0SeZ>0000003iZU<0nJYE095KSP2@FXh0TEZ=0?RWB`080?RWBP0509=MSP3o
ool0oooo0?ooo`0000006@3oool004@0oooo00L000000?ooo`3oool0oooo0:N^g@2Y[]`0Y^Ck0080
oooo01L0jJV;09;Ao@3;g^L0K]g60;6]e032_MH0^/;P0<_MiP2e/MD0/[gR0:fihP2Z^N@0YK[X09nk
k02=]_40Qk[g08G2n`3lhj@0l:n7096dk`2QZ=`0[/?Y01T000080?2_Q`0?00009`1oAh<0S56508U@
Q@0007@0V7Z_0:1n[P2TY=H0ZJOE0=C=d`2jbnL0kZb7089:Q028D8H0R4n60080000[00d0R4n508U@
Q@0003@0Cd2P09Mh[P2^]]l0YK3Q0:C<m@25_oX0KMcZ08U@QP28D8H0RE260080lZn303X0G4BL08]C
R00003l0000e0<S=g@3a/h`0am7R0>FXT`2bRJ/0VG:V09A_YP2FLZL0UW6W09EaY`2GZN<0TJ[W0;2i
h@2YgOX0dL;<0:F]g@2TZm`0XLkg0:7<mP2Cdoh0Y:gM0:B^gP2Sa_40X/Sc09CKoP2T[=d0Z;gY07nj
n@2Lb_L0_]W]0:F]g02U[=`0RLOl09W6m`2Ae?h0QkOe0:c1j@3@emh0eL[?0<RV]`2MY]`0Z;7O0=7J
h03>cmX0b:Rh0=>oa`3>en40bJNg0;B;ZP2CKJ<0c[[70=3Jh03:Z;L0]XbY0P2U[]d04`3>f^80f]?B
0;R=Z@2>J:<0Y:gM0<_Ji03KeM80c:^h0:>Mc`2QW<l0Wj3E08_2nP2bjOP0T^3n0:FTe02SWLl0X/;_
0:C3k`16a/<01@2;E8T408aDR@0=09I[WP1TBId0PenQ09Q`X`2UXm<0Y9g?0::Hb`2/^^@0X[o^08SV
mP2=EHT0S5F90000HP0208aER@0:0000H`0007L0VFfO09Q/WP1UBI/0LWoA0:FSd`2he>h0T]?n07W?
o`80SEJ:02D0QE2908eFRP2<EHX0QU6907YDVP2HJid0J4ZK03hZT00C::D0Ig790:;<mP2Sj?/0PMOo
09:Wi02;E8/0SEJ;08eGR`2;E8/0001/0000LP1W@i80W6bJ06E4UP18Dk/0HfW30:kAlP2/eOH0Zm?e
09K5m`2EbOT0W/3`0;6/d`2ZUl80V:_S09j]h@22i?D0L=g_00<0SUN;0180S5J;00H0K@2>Eh/0WW2M
09EXV`2FJ9/0W6fK08aOV01VAIH0Adfd095VW@2]VL80Y8no0:W1j`2WgoX0[m[f0:JZfP2i]]H508iH
S0<0U6JJ01d0UFJI09EWV@2GIiT0V6NH0?JZK02@FH`06`Eg06N/n02ld^/0HZ_h0;_OlP3J_[h0dZV^
0>jkW03GYJ@0d:R_0?ZmP@3m_gT0nJeR0?V/H`3i[F00nJeQ0?V/HP3i[El0nJeP0?V/H@3i[El0oLN6
0?^oPP030?Z]G0070?Z]G@3i[600Hiob0;;6j@3Od<T0n/>:0?[3S0020?[4S00P0?Z/F@3i[5/0nJ]M
0?>/NP3j[5L0nJaJ082am02aanX0^l_V07j`m02O`?00cm3J0?[6SP3kaHX0nJ]G0?V[F@3/ZXL0ml>C
0?V[EP3iZUP0nJ]F0?V[E@3iZUL0T5^>08mJSP000000nJYC0?VZE@2AFhh0T5Z>095JS@3hYd/80?RW
BP0509=MSP3oool0oooo0?ooo`0000006@3oool004D0oooo0P0000060?ooo`030>VYR`3^[XT0kjn8
00@0kjn800L0T]3m06?F^@3_[hP0Z<S`0:ffg`2l_=T0Z;[V0080XjWJ00<0o>>T0?2_Q`3`[hL0303`
[hL207m7P`0D08U@Q@26CH@0001d031Zf@2b]M/0V]Sm0:;Oo03a/8D0l:n60>j/Q`22BX@0R52608Q?
QP0002/0Q4b408U@Q@2JMZT0U76Y06mS]02He_d20:[Bm@0;0;6`e`000340000a08U@QP28D8H0RE26
0>^dV03lb8`0G4BL08]CR00003l00P0003D02@29D8H0fkFb02ZFk`2bRJ/0VG:V09A_YP2V[Md0YJkM
0:;>m`020:7Bn@0i0:B/g02T[Mh0Y<C`053=a`2:DHL0TLWk0:FUe@2^_^H0[K[S08?YgP3b[X40lJf1
0?>_P01NeN@0RU670?:^P02TZMX0[K[S08o^j`2:DXL0Re:70:Noj`2c_>00]L_Z0;WOlP2UYMH0YZWH
0:C3k`2;i_T0SMKo0:J^g@2[_NH0O[Sh09S=nP2VZ=P0YZcL09c5m029`oX0VMon0:FXf02V[=`0Xl?`
09g5l`2=eOl0Y:CF0:J/g02S`nl0W/Cc08_Eo`2TYMH0YJOH09Zml02N`O40@/C408eDR@2>EXT0VKW^
0080[^Ki2@2;E8T208aDR@0909I/X@2LLJ00UV^N06A9W@007:H0Z:cI0;OEl023eOl0YZoN00<0S5F9
00<0SEF908aER@0006800P2<EHT02P0006<0001g09U]W`2HK9h0IDVK04aWc@2R[Ml0Y:[K0:fegP2g
go@208eFRP0Q08E@R@2=EXX0S5F:08IAR@1jE9X0V6bN06Q:V`0069d0GU6Z0:f^f@2V/N00X[?T0>SQ
b`2dg?@0ReB;08eFR`2=Eh/0ReB;0000K0000780Id>B09a/VP1UA9H0B5>k0:gFm@2olO80[];c0:K4
k`2S_nd0WkSZ09fdj02:[^d0WJ7H0080SUN;01L0S5J;04PZR@2>Eh/0SUN;09a[V02<EX/01P1]091V
W@2NL9d0UFRK09IXV`2LKI/0S5nH06I5UP1=E;T0V/?d0:7[nP2Y^^H0YkOT0:JchP2R/>80[<ga0939
n`0208iHS00309=UV@2CIIX0TfFJ00<0U6JJ01d0UFJI09EWV@2GIiT0V6NH0?JZK02@FH`06`Eg059;
Z`1U]o`0Y^Kk0:CDn@2Y_nT0^Zg=0=WCd`3Qc<<0^Zg<0=k>b03m_gT0eJ6P0?V/H`3i[F00nJeQ0?V/
HP3i[El0nJeP0?V/H@3i[El0oLN60?^oPP030?Z]G0070?Z]G@3i[600nJaR0;;6j@3OdLT0/LOZ0?[3
S0020?[4S00:0?_3R03i[5/0nJ]M0?>/NP3j[5L0nJaJ0?V/F`20/O@0/LOZ0;_:iP80Wl3`01@0X<3_
0?_5RP3daYd0ejJS0>bZQ`3g`i<0nJ]F0?VZF03iZeH0nJ]E0?VZE`2@Fhh0SeZ>0>ZXR@000000nJYE
095KSP2@FXh0TEZ=0?RWB`P0n:M:00D0Tef>0?ooo`3oool0oooo0000000I0?ooo`00A`3oool00`00
0000oooo0?ooo`030?ooo`030>VYR`3_[hP0kjn800T0kjn800D0[;gV0;o0f`2:/O00WoGT08CCo`0=
0?2_Q`0900008@1UE:X0YXB_0:1n[P2JN:`0O6B/06ekd02e/mL0Z:KD0080lK2500l0l:n60>j/Q`22
BX@0R52608Q?QP0007L0UGN^0:=o[@2JMZT0U76Y0:JVe@2WZ]T0Y:gN09fnk`0200000P0003406@29
D8H0R5260?6^P`3[]9P0o<R<08YBR02;DhP0000a0000J027ChH000110000I031/ld0[ZWB0:JRdP2a
do40[m?c08O[jP2VYM@0YZSH0:O1k015a;X0000l08YAQ`2:DXL0102:DHL04`29DHL0RU:70?6]P@3a
[H40ljn008YBQ`2:DHL0lZj00?6^P03c[gl0T5N808YBQ`2;DXL0lZio0?>_O`2AF8T0RU:703^oe03b
[Wl00P3`Zh405P3b[Wh0ljmn09=JR@2;DhP0VkW]0:^hh`2Mk?P0lJao0?>^OP3[[8d0Z[OS09k[nP2;
DhP0ljim0>V/T02Pj?/0BLGY08]CR03c[W`0m:ml09Zhk@2Si?`308]CR00408eDR@2>EXT0lJam08aD
R@P0ReB90`2EK:4209I/X@0809aaX02FJih0I4VM05]C[`2PXMH0YJSI0:nfgP2mh?4308aER@0708eE
R@2<EHT0001R0000G`2IKIl0V6bN0000M@020:JRd@060:W6kP2W`^d0Tmkn06S>o02=EXX0001S0P2=
EXX03025D8T0SEJ:08aERP26DHT0NUBJ09Q/WP1XBY/0FTbX06BEj`2Tb?80SN3m08]DR`80SEN;01<0
ReB;0000K`2=Eh/0ReB;0000K0000780Id>B09a/VP1UA9H0V9O@0;?Dl@2gdnh0Z<K_0::ij@2P/><0
WZSM09ZUg@2UYmP0[]3b0080SUN;01<0S5J;04PZR@2>Eh/0Xg6J09a[V028FiL01P1]091VW@2NL9d0
UFRK09IXV`2LKI/0WXJi09N2^`2BQ<40ZkOR0:Rfh`2W]N<0W]Kk0080SUR<1@2CIIT209=UVP<0U6JJ
01h0UFJI09EWV@2GIiT0V6NH0::6]@2PQ;D0VH6g0961_P2baNP0ZLS`0;;?k`2J`_@0W<;c09O3mP1n
^OT0Wl7`097?o@2Ie?`0g;nm0=2V[@3^^i/0fJNR0=6W[P3i[El0f:JT0?V/H@3i[El0oLN60?^oPP3k
_X420?Z]G0040?Z]G@3i[600nJaR06:Ql`80/LOZ0`3ja8`0803k`hP0nJaK0?V[G@3c[7X0nZaG0?V/
FP3i[5/0nJ]M08:`l`2ba^T0^lGR0:70k`2Q`Nl0n/:90?C6W@3GYZ<0`ifb0?O3T`3iZeH0nJYH0?V[
EP3iZeD0nJYG091KSP2?FXh0jZR90?VZD`000000TE^>091JSP2AFXd0n:M;203hYdX01@2CGHh0oooo
0?ooo`3oool0000001T0oooo00180?ooo`030000003oool0oooo0080oooo00<0dInT0>6k/@3_[hP0
2P3_[hP01@2[^nH0_kcG0>Bn/03X^jH0jK^V00`0l:n700P0000W06EDZP2IO;40X7j^0::^h02RZM/0
Ylkd09CCo@<0lK2500l0l:n60>j/Q`22BX@0R5260000:P0007L0UGN^0:=o[@2ZZ]H0YJ?C0:cEmP2U
e_T0RU6708UAQ`0003H00P0003406@29D8H0YWbV0?6^P`3[]9P0o<R<08]CR02:DXP0000a0000J02E
LZT0WGNX06UL/@0XJm/0QlKl0?>`PP2<E8T0Hd^P08aDR@2P^^/0<KRn08=<Q`23C8H0000l08YAQ`2:
DXL0102:DHL03029DHL0Re>70>ZaU@3a[H40ljn008YBQ`2;DXL0lZj00?6^P03c[gl0T5N808YBQ`80
lZio00<0ljmo095HR@2:DXL00P3b[Wl01@3`Zh40lZio0?:^OP3c[gh0TeZ90080Re>800H0ljin0?6/
O`3a[7l0ljim0>^/S@3_ZH4208]CR0030?>^O@3Y[900l:]o0080Re>800@0ljil0?B_O03`Zgh0l:]n
0`2;DhP0103d[W/0m:mj0?6/O@2<E8T508]DR@H0UFbQ0P2FK:401P2SU/L0XYC60:6CaP2_`>L0[/7X
06c@o0D0S5F900/0SEF908aER@000680001h09U]W`2HK9h0FTn/07BYl`2Bho`0O<So0<k4d@0308eF
RP0?0000H`2=EXX0SEJ:08E@R@1mEi/0V6bM06A7VP1jE9X0V6bN0:jJ``2HSLL0VYK?0;>ff`0000L0
ReB;0080SEN;0140ReB;0000K`2JJiX0VfZI0000K00U4H00HfK00:>Fb02jd^`0_m[]0:gamP2W_n/0
YK_Y09jbiP2F[^P0Sk;^08aFS00200H0K@80SUN;0180S5J;04PZR@2OL9`0Xg6J09a[V028FiL0E4:O
091VW@2NL9d0YHjl09n8^`2QRKX0X8Rj0:^dg`2X/n40T^Wh08iHS02LK9X809=UV@80TfFJ0`2DIYX0
9`2EIYT0UFNI09n5]`2OQKL0XHFf0;6hgP2b^n40]NGf0;:nh`2d^]h0/k?H0:^nj02Y]^80Xkk/0:?0
k@29__P0V]7k09k<m`2Z_^P0^Z_:0=OBe03Tc/80_[7=0>jlW@3Sc/<0c:B`0?RoS03mahH0nkn20?^n
P@3k_X00nZeL0?Z]G@3i[600nJaR0?V]GP1RXO<0/LOZ0;77j`020?[4S00P0?_3R03i[5/0nJ]M0?>/
NP3j[5L0nJaJ0?V/F`3iZed0RJOY0;Blh034d><0QK;b0:C1kP3?dM/0hLW10;VVa`33WK80ml>C0=ZW
XP3iZUP0nJ]F0?V[E@3iZUL0T5^>08mJSP3ZZ8T0nJYC0>BaX@000000T5Z>095JS@3hYd/80?RWBP05
09=MSP3oool0oooo0?ooo`0000006@3oool004T0oooo00L000000?ooo`3oool0oooo0>6k/@3Wa[@0
ilFc00/0kjn800D0Y[WW0:>kjP3Y^jH0j;bW0>RmZ@0<0?2_Q`0600L4P@2U_>T0/N3g09[=nP2Ye_L0
lOJj103a/8D03`3`[hH0kZb700009`28D8H0000`0000M`099JH0Q]7o07SKnP3mgh`0RE670000<@2:
DHL0RE670000=P020000<@0I08U@QP000740jkBH0>^dV02:DXP0Re>808YBR00003`0001X09EbZ@2M
MjP0^/?P0>Ska03b/880lk2208]CR@1SBj00S5B908E?Q`1oBHH0Pdb708=<QP0003X0RU6708YBQ`04
08YAQ`0<08UAQ`2;DhL0j[6E0?6]P@3c[h00RU:708]BQ`3b[X00lJj00?>_O`2@EhP0RU:70P3b[Wl0
0`3c[gl0TER90;V7X0020?:^O`060?2[P@3b[Wl0lZin0?>_OP2CFXT0Re>80P3c[Wh01@3a[7l0ljin
0>VbV@3[[8d0kjV10080Re>800<0ljml0>V/T03`Zgl00P2;DhP20?B_O080l:]n0P2;DhP01P2`P:40
m:ik0?B_NP3a[7d0ReB908]CR@80U6^Q1`2EK:401P2QU/P0XYG80::Eb02V`>`0YKo/05gEfPP0S5F9
00/0UFZN09IYW@28Gi`0001h09U]W`2`W/D0W8o509^Db`2__^@0Y;;R09KEo@0308eFRP0R0000H`2=
EXX0SEJ:08E@R@1mEi/0V6bM06A7VP0059`0XYO90;79k02W_>T0S^Ck08iGR`2=Eh/0ReB;0000J02=
Eh/0ReB;0000K`2JJiX0VfZI0510X00U4H00GVS508OWm@1e^o`0[=3c0:S7l02RZmh0X:GI09nNd`2N
W=40YZOG08aFS0801P1]0P2>Eh/04P2<EX/0B2Z9095VW02SLIX0W6^H08QKU`1D@Yl0DEBg0:ZD_`2U
S[`0Y[CS0:NdhP20hoH0KaM708eGS00;0700SUR<09m_V`P0TfFI0P2CIIX209AVVP80WXFh02D0WhFh
09n5]`2X/Mh0Un[i08kVn@3g[6X0nJiU0:[@m01hh/D0`=CY0:faf`2b/MH0_<?O0:b`f`2a^Ml0/[;H
0:;0kP2M_^l0R<;j09K6n021__/0U/[i0;[]m02[bo00^jc;0=O;cP3mahH0nkn20?^nP@3k_X00nkj1
0?Z]G@3i[600nJaR0?V]GP3j[E/0HJ7c0080/LO[00T0n/B<0?_3R03i[5/0ejBR0?>/NP3f`I80nl:6
0?V/F`3iZed00P3i[5X05P3iZe/0nJaJ07nbm02/^nD0/L3U09bhk03<gNH0d=oS0>?<`@35W[40lL6N
0>B`W`3iZUL0T5^>09Uk/02ZQZh0lL>Q0>BaX@000000VGZ_0:N4[P3hYd/80?RWBP060?RWCP3oool0
oooo0?ooo`0=7ih00000603oool004X0oooo0P0000020?ooo`040>O5/`3V_Zd0ikf[0>RmZ0T0kjn8
00@0000O09k1l@3?b]D0W<Gd0`3X_ZX:0?2_Q`0507A^_P2o`md0ZLG^0:S0j`2A^O801@3a/8D20>j/
Q`0400009`28D8H0000o00TUY@80]KCH0280_LoX08]BQ`29DHL0000a08YAQ`29DHL0000f0000<@27
ChH0RE260000L@2lXkl0l>o50000A@2;DhP0RU:800h7P@0006P03d;00;2[dP3Dd]L0/=;a0?:`PP3c
/880Re>906=;X02<E8T0QDn707m9QP23C8L0Pdb60000>P2:DHL0RU:70`2:DHL05P29DHL0RU:70<>@
X@3Z/ID0ljn008YBQ`2:DHL0_XbP0?:^P03c[gl0T5N808YBQ`2lRJ00lZio0?>_O`2AF8T0U6fS0;V7
X03b[Wl0iJVC0?2[P@3b[Wl20?>_OP0808]CR02eQ:00ljin0?>^OP3a[7l0ljin0>VbV@3[[8d208]C
R0030;61X03X/Y/0jJb@0080Re>800d0[gnP0>RcV`3d[g`0l:]n091WWP2;I9l0UFjS0;20X@3d[W/0
jJf@0;f@YP2LL:00SFFO0080U6^Q0`2EK:420:6Eb0030:6Fb02U`>d0YL3]0080GMKJ1`2<EHT209AY
WP0709AZW`2EJYh0UFZN09IYW@28Gi`0F4j/07n5d0020;?;k003073Oi@2=EXX0SEJ:00@0SEJ:0280
001S085JV`2HK9d0HDBI07eGV`2HK9d0I4NJ09JBc@2HVmD0000008eGR`2:E8/0SUN;08eGR`2;E8/0
001`09][VP2IJIT0001_09Y[VP2KJYT0D42P051H_02BUmD0[]Cd0:g<l02Ya^h0Xk_Z09R_i`2IZn@0
RlKk07O0o@2>F8`0S5J<0P0606d03`1?;XX0V6VJ0692U@18:XT0TFJL0:=aVP2LJiP0R5^G05A2W`18
Dk/0K];l09VWh02>F8`0SEN<01@0L`0209MWV00300/0L02?Hi/0WfnK00P0TfFI0`2NQ;P209j5^080
Y[3O00d0SNCk06T>?P2CI9P0VVZI0?N/JP3i[VD0nJeU0?R]IP3i[V@0nZiR0?Z^H`3j[V80ZM3d0080
00000200Z;oZ0;>mh@2lan<0Y<Ga0:;7l`2MaoH0S<7i07:dnP1?XoL0h=kC09?9nP3k_h80nkj10?^n
P03k_X40nken0?V/H03i[680nJeN0?Z]F`3i[5h0/LO[066Ql`2ab>/0nl>80??2W03GY:80ljaj0?K1
TP3k`XH0nJaK0?V[G@80nJaJ01H0nJ]K0?V/FP3i[5P0^=3/08>mnP1j/?D0YL7^0<O@h@2d`nD0_:[7
0<K;gP3^f;`0`jk609=g/@2INk00ZXJ^0<;6g@32[LD0]IBe0000002o_mT0n:M;203hYdX00`3hYd/0
n:MC0?ooo`020?ooo`030000003oool0oooo01H0oooo001<0?ooo`050000003oool0oooo0?ooo`3X
_JT00P3X_JP80>n_R0050?ooo`0B2h<0V/Sg09S9n035cN000`3X_ZX90?2_Q`040000:@2ad_40Z]Kg
0:?6lP80j;nZ103a/8D20>j/Q`0<08M?Q@28D8H0000o00TUY@13S>d0M:cd0:VbgP2;DXL0RE670000
<@2:DHL0RE670P0003H06029D8H0W7NY0000L@3`klD0RU:80000A@2;DhP0RU:800h7P@025iT0MWc<
0;JlgP3Ma/80l[220?C:X`3c/880Re>908]CR02<E8T0QDn707m9QP23C8L0Pdb608Q@Q`@0RU6703D0
UG2U08i[YP2LMZP0`i2Q0>ZaU@3c[h00ZX>Z09I_Y02nS:00j[6F0<NS]02/Q:T0UFjT0;b9X03Y/IL0
b:Bd0:j5Z@2>J:<0^HNP0>RaV@3UZI<0d9^O0>VaU`3U_:d0/HNX08iXXP2CK:80j;6J0>FYU03?Vj00
ljin0>VbV@3[[8d0]8VX09=[XP2aPJ00j;:K0>V/T02fRjP0Tf^Q0:moX03X/i/0jZb?0;^>YP2KL:00
RfBO08UTX@2`P:40j;>L0<j[]@2mT:H0W72P08eUW`0209A[X@<0XIG80P2U`>d00`1LeMT0S5F908aE
R@0508aER@<0TfRN0P2CJIh02`2DJIh0U6ZO09EZWP2EJYh0UVVM08QOW02IS<@0VI380=36d02=EX/0
001R00H0SEJ:0280PTj9085JV`2HK9d0HDBI000EW@2TVL/0/9k60:;1k`2gf_80U=7l08eGR`2:E8/0
SUN;08eGR`2;E8/0001`09][VP2IJIT0001_09Y[VP2KJYT0D42P09FXh`2_co40Zlca0:G1kP2U_^`0
X:3E0<6hd@3Wf<L0Q52;00X0KP2>F8`0S5J<0P0606d0501?;XX0V6VJ0692U@18:XT0TFJL0:NA_P2Q
Rk`0WHJj09F1^`2^/=T0YjoM0;OOm02>F8`0SEN<01@0L`2GIiT0UfNH00/0L02?Hi/0WfnK102CIIT5
09f4^00N0:F`g`2V/=l0Rn;l095RU`2:GIL0SeV=09i^V`2QKiX0TfBH09YZV@3g[6X0nJiU0?V]I@3h
[FH0nJiT0?c3Q03j[V<0nZiR028<O00I1WT070Qj01d9NP2H^>h0_LSS0;k:h`2^an`0[<S^0:?6lP2<
_OL0N[Ch0P2K`_<05@2L`O80nkj10?^nP03k_X40nken0?V/H03i[680nJeN0?Z]F`3i[5h0nJaO0;77
jP2banX0h];80??2W03GY:80aYf_0?K1TP3k`XH0nJaK0?V[G@020?V/FP0G0?V[F`3i[5X0nJaH0?V[
F@3iZe/0nJ]I08:Vj`2[_>H0_<CP08Jem02Zanl0bm7N0:B_g`2S[n00SZKU09;IoP3<e>00XJWL0::V
f02DWMT0000006;GaP3AHP00203hYdX01@2CGHh0oooo0?ooo`3oool0000001P0oooo001=0?ooo`04
0000003oool0oooo0?ooo`80j;fX0P3X_:P60>n_R0060?ooo`1nM;h0`L;K082hn030an00Ul3c0P3X
_ZX00`3X_JX0l:n70?2_Q`060?2_Q`0:04DkX@0M<JX0G9O^0<79h@2La?@0jKjY0>VoZ`3Y`:X0k;jT
0?2_QP80kZb703<0R52609]eZ00006T0:UoB0;c>j02EbOX0[?Cb08]BQ`29DHL0000a08YAQ`29DHL0
000a02DMS`1G@Yh0W7NY06iHZ03/m<P0RU:80000A@2;DhP0RU:800h7P@025iT0W<_g0;g?j02@d?d0
/[[O0?C:X`3c/880Re>908]CR02<E8T0QDn707m9QP23C8L0Pdb608YAQ`2:DXL0WWNW09MaYP2FL:D0
UG2U08i[YP2LMZP0fKbm0>Bk[036X[@0ZX>Z09I_Y03G^kh00P3Fal/04`2/Q:T0UFjT0=Fj_`3T_:d0
elS<0:j5Z@2>J:<0dk[10:Z`g03DemX0clWD0=Bj`03U_:d0b:Bd08iXXP2CK:80d;S20>>m/@39Y[D0
0P3Y/YT06P3:Y[@0]8VX09=[XP2aPJ00j;:K0<^W]02fRjP0Tf^Q0:moX03V`:l0cJRd0;^>YP2KL:00
RfBO08UTX@39]/L0YJ[J0=kEc`2mT:H0W72P09nCa`2QU<P0XIG80:G0k@1LeMT0G=CI1`2<EHT209AX
W@80TfRM0P2CJ9h209=YWP0;09AYWP2DJYl0X9330:2@``2RTL<0Whk20:Jji`2/]N00VnGl08eFR`00
0680102=EXX0902NKi`0UfVK05a0V021FY/0V6bM0654V@1FBZP0XJkQ0:F`h02W[md0[;;M08iGR`2=
Eh/0RUB;0000I`2KJiT0VFRH0000L02KJiX0VFVI04doX01ZJ/00/9[10;O@k02`j?P0Z/cb0:O3kP2I
/^T0VZkU09bUg02aco004P1a08A@R`0:06h0SUR<08aFS0801P1]01@0Cbj:09QYVP1R@YD000nC09b=
``2/U/00ZL?/09nhj`1_f?P0NmWm00`0L02?F8`0SUR<08eGS00D07<0UfNI09MWV01A?Yd0Sf>K09m_
V`80WXRk02L0WXFh09f4^02MQ;P0WHBh0:F_g`2:h_`0RN;l08mIS@2OKYT0Tf>G095RU`2:GIL0Rf2J
09AXW02QKiX0TfBH09YZV@3g[6X0nJiU0?V]I@3h[FH0nJiT0?c3Q03j[V<0nZiR08iJS`0I1WT070Qj
01d9NP0T3G`0`<_R09Vll031bn80algO0;G9j@2C_?<0S;Wd07Z`m@2K`?400P2L_o404`3k_X00nkj1
0?^mOP3i[600nJaR0?V]GP3j[E/0nJaN0?V/G`1^WNd0/lGX0;K7i`2e_^40^J?30<o1c@3f`I80nl:6
0?V/F`3iZed00P3i[5X04`3iZe/0nJaJ0?c8RP3iZeT0nJ]K0?V[F@3iZeP0H=Fo0?V[F02R[]l0YZSG
0;;7jP2AFhh0iZF<0?V[DP2X_nX0[lCY01T0003iZe<00P3iZe800`000000dF800;Y>00070?RWBP05
09=MSP3oool0oooo0?ooo`000000603oool004h0oooo00@000000?ooo`3oool0oooo0`3X_:P60>n_
R080oooo00@0/]?a02jSl01k]_P0U[od0P30an000`3X_JX0ikfZ0?2_Q`060?2_Q`0404DkX@1iKKT0
`<;K09;2m`80`LWQ05T0`<[R0>W0ZP3/_Z@0l:n60>j/Q`22BX@0D3^I09]eZ01iGZL0I7?=0:6Zg@29
DHL0RU:708]BQ`29DHL0000a08YAQ`29DHL0000a02DMS`0TE/`0VZOO0=7Eg02cdo40RU:80000A@2;
DhP0RU:80000?`1OE:h0]k_M09W1m02]aN`0l^:m09oVo03c/880Re>908]CR02<E8T0QDn707m9QP23
C8L0Pdb604HdV02QNJL0WWNW09MaYP2FL:D0Y:gM09JWhP2AZ>D0Z=cj0<OXk@2U[]h0UjCN08nShP2X
f?T0anK]0:F]g02UZm/0Sj;Q0:SGn02Ih_d0YZcL0:FZfP29a?/0Ul?f08SGo`2LYM`0[K?M0=GCe`3H
b/`0YZ?C09fPeP2X[M/0d]KL0=7=eP39Y[D0dKW20=;Bf@3:Y[@0]8VX09=[XP3<]<80e=CI0<^W]02f
RjP0YJ7B096Ad0020=gAc@0;0:BHb@2QU/T0XIW<08g1n@2RdOP0Sn;m0:V/fP2WXm80X[g/0:Bok01I
dmP01`2<EHT309AYW@<0U6RM0P2CJ9d209=XWP0309=YWP2PT/H0Wi340080X93300<0YK_Y06WKj01[
g>L0102=EX/02`000680SEJ:0:9cWP2FJYd0UFVM09i_W02GJI/0G42H000CW02SU/L0[IS10080[[_S
01`0XKKX09KAo02>Eh/0SUN;09iZUP2:E8/0001b09][V@2IJ9P0001`09][VP2IJIT0CCnP05F@j`1Q
^_d0WM7j0:WBmP2Q_^h0W[W/09fVf`3Vf<L0QE6;08]FS00B0740001e00D0K02>F8`0UfNH0P0606d0
?@1?;XX0V6VJ0692U@1A@9l0HZ?d0:Bhi`2W]n@0Z:kL08mIS02?F8`0301`01@0L`2GIiP0GcjC01@0
L`2GIiT0UfNH054nW@1BD;40ZI:m0:J>_02NR;/0X;?V0:F`h026h_X0^GnD0?:XM02;EX`0401c08aP
V@2OKYT0Tf>G095RU`2:GIL0Rf2J09AXW02QKiX0TfBH09YZV@38WJ/0nJiU0=NTX@3h[FH0nJiT0?c3
Q03j[V<0nZiR08iJS`0I1WT070Qj01d9NP0T3G`0V[g`0<;<hP2J_O40]/SX0;?6j02X`N`0UkS_092g
l@1n[o<00P2L__004`3Md<`0nkj10?^mOP3i[600nJaR0?V]GP3f_Xh0nJaN0?V/G`3i[640NKgl0?V]
G03i[5h0Y;?S0:6nkP3OdLX0nl:60=VUX03iZed00P3i[5X02@3iZe/0nJaJ0?c8RP3iZeT0nJ]K0?V[
F@3iZeP0nJ]J0?V[F0020?V[FP08091KSP2AFhh0iZF<0?V[DP3iZeH0nJYI0?V[E`3iZe<20?V[DP03
0000003iZe80^Th000L0n:M:00D0Tef>0?ooo`3oool0oooo0000000H0?ooo`00C`3oool200000080
oooo103X_:P40>n_R0<0oooo00P0?iWc0<38h02/aN`0UKkc0;o7h03W_JX0_lKP0>JkZPP0l:n706T0
/=Kd0<;:h@2;__L0UL7e0<7;hP32c>80k;bR0>:[VP2cS:d0NEbU01U@bP2_[]H0Y:?D0:6NdP2haN@0
RE6708YBQ`2;DXL0RE670000<@2:DHL0RE670000KP0U7Hl0IEbc0:Rag`2d/mP0l[2408YBR00004D0
Re>808YBR00003@0001E09WCo02ga^D0]lGU0=fj]@3c/880S5B908]CR@2;DhP0S5B908E?Q`1oBHH0
Pdb70000?016=9P0XGVW0;:bf02V[]d0X]7h0:CBn02Ig_h0XjcM0:>/gP2S`Nh0X/;_05oFf`29DXP0
XjOI0:bhhP2OkoH0S5>808aDR02TZ=T0[;SR0:C^n02Wj_X0S5B80?2]P@2M^>/0X>_j0:OXnP2<E8T0
lJf009^ikP2]gOP0[Moh0:>XfP2V^NL0Sk_d08_Vn02IfOd0YZOH09fFc02I`_@0E=3A09SLoP2WZMP0
Y;[Y09W1l`21j>@0E]7C0:V[f02WW/d0ZK_V09S^m@2<E8T0W;O[0:Rch@2^h?P0TUV:08eER@2<E8T0
1P2<EHT509AYW@<0U6RM0P2CJ9d20:6Ic0040:6Hc02J_O40X[c[05WCgPP0SEJ;00d0001R07mJW02R
Lih0UVZM09EYW@2NKi`0UfVK05a0V01DBJP0IYg_07SSk01/f?D0SEN;00<0SUN;0440YG6H09iZUP1m
DI<0001b09][V@2IJ9P0C3jP0:>Ca02`VL00Vhc30;C@k`2dhoH0Y/[b09bhk02=[^d0TZKS09nXg02V
`N`0QE6;00h0K`0B0740001e00D0K01F=8`0UfNH00H0K@0906h0I5nh09j<`02[T[d0Yk_X0:NiiP27
d?l0T/cl00/0L02?FH`0UfJG00`0L00D07<0UfNH05lnT`0D07<0UfNI09MWV01A?Yd0?V_F09^ol@2Q
i_`0YK_Y0140L`2?FHd0XVnH0;UoU03bZ7@0ReJ<0100L`2<H9T0WfjI09=SU`2AHYL0RUfG08]PVP2D
J9`0XFnJ09=TV0020:B9^00;0>bhV`3QaKd0dJF[0?RlQ`3l`h@0n[]n0?Z^HP2>FXl06@Ii01`8NP0M
2GX00P0T3G`0:02J__40`/cR0<;<hP2da^L0/L?W0:Nlj02J]^/0Q:oa06jUl`2N_Nl0gM3<0?^nP@3k
_Gh0nJaP0=RRWP3i[Eh0m[j>0?^oPP3i[5l0nJaQ0?V/GP3i[E`0nJaN0?V/H02`a>T0/LS[0??2V`3Q
aK`0aif]0>jmWP3MZZ40b9j^0?V/FP3lb8X0nJ]I0?V[F`3iZeT0nJ]H0?V[FP3iZeP20?V[FP08091K
SP2AFhh0iZF<0?V[DP3iZeH0nJYI0?V[E`3iZe<30?V[DP030000003iZe80^T`000H0n:M:00D0Tef>
0?ooo`3oool0oooo0000000H0?ooo`00D@3oool010000000oooo0?ooo`3oool30>RlZ0<0kjn8103o
ool0200oV?80[<C/0;o7h02E_O<0N[?g09Fml`3S^:/0j<2]203`[hL03@2[anh0`/[P0:_6kP2G`oH0
aLoR09S6m`34e>H0aJNk07ULY@1ICJX0IjOe0:b^f@2:DXL00P29DHL0202:DXL0Re:708UAQ`000340
RU670000;`0006h0I5^b0P2FbOT0<`1ieOh0l[2408YBR00004D0Re>808YBR00005d08QJ907eh`P1m
VnD0/kWN08fcl03mi9X0S5B908]CR@2;DhP0S5B908E?Q`1oBHH0Pdb70000?@0004T0W:_Q0;_Ek@2i
j?D0YL3]09VolP2N`?40ImS^08aDR@27D8P0Re>908aDR@29DXP000190000@P29DXP0S5>80?6^P@3`
[H80lZn008iFR@2;DhP0lJf10?2]P@3c[gl0SeJ908]CR03b[X00lJf00?>_O`020?6]P0070?>_OP2@
EhT0S5B908aDR@3b[Wl0ljmm091HRP0208aDR@030?:^OP3d[gd0TER:0080S5B90P3c[Wd0103d[g`0
S5F908aDR@2<E8T30?>^O003099IRP2<EHT0S5F90080S5F90P2EJYh209EYWPD0U6VM00X0U6RM0::I
c02RVL`0XYW<0:?5l@2GgOh0UMcn0::XfP3af[T000001`2=EX/03`2OL9`0QEbI0000L@1oFY`0XW>N
09IZW@2EJId0WVnL0:2;_@2MRKd0U8_60;:dfP2PK9D0RUB;08eGR`0208iGR`0R09EVV@2ULIP0WVZF
07eAT`000780Vf^I09UXV01<?Z00FiG^0:KAmP21i_00ZM3e0:?6l@2Q`>l0VjWP09bRfP27V]l0/kGJ
08aGS025DH/03P1_0180L@0007D01@1/05HdS02GIiP0G3bC055B]01JH/00EgoN0:KXn`2@g_h0_k[F
0?_XVP802`1`05l0501c09MVU`0<0700501c09MWV01O?Y<00PnA09MWV@2WRkP0VX:h08f=cP2V/n80
XjkP0=_He02]bnl06@=f08iQV02iOi@0lZQd08]FS00C07@0S62I09m^V@2CHiL0TF:G08YMU`2OUl`0
YKk[0:_7kP2JR;l0UGnj0;2oi@3Fi^80]/GV0;jZaP3Wg<T0o<>40?ZkOP3j[V80TEb?01T6N@0L27X0
7@Uj05i<Y@0T3G`08P]k09ZnlP31c><0a/cN0;33j02/^>80Y[7P0::_h@2B[nX0MjOa0=c>b`2R_>`0
nken0?:mUP3HXYh0nJeN0?JnSP3k_h80nJaO0?V/H@3i[5h0nJeL0?V/GP3i[600Ji[/0;C4iP3IfmP0
][OJ0;^R`03<`<l0im2o0<2Za03g`940o<R:0=^WW`3iZe/0nJ]I0?V[F03iZeX0nJ]H0>F^V`3iZeX0
T5^>095KSP3VYH`0o<jC0?V[EP3iZUT0nJ]G0?V[D`040?V[DP030000003iZe80^dd000D0n:M:00D0
Tef>0?ooo`3oool0oooo0000000H0?ooo`00DP3oool010000000oooo0?ooo`3oool30>RlZ080kjn8
1P3oool01P2[`n/0_lKP07ZbmP2j^]T0TkC^0;W8iPT0l:n700`006kJ0:_6k@34bMl0X<Cb0:o=l02S
bO<0XKo^09j[h02IW]L0[KkV0??Y_P2/kOP208UAQ`0V08YBQ`2;DXL0RE670000<@2:DHL0000f0000
KP1TFk80];?G0;c=i`2^m?<0l[2408YBR00004D0Re>808YBR00003L0001809bZh031bn80Nk;f07:i
n`3b/8<0S5B908]CR@2;DhP0S5B908E?Q`1oBHH0Pdb7089<QP0004T02Q>B04=afP2]bo00X/Sc0:Z]
f@3lhZ4208aDR@0508M@R02;DhT0S5B908UBR00004T00P29DXP03P2<DhP0lJj10?2]PP3b[h00SUJ9
08]CR03a[H40l:f10?>_O`2?EXT0Re>80?:^P03a[H00ljmo0P3a[H000`3c[gh0T5N908aDR@020?:^
O`030?>_O@2@F8X0S5B90080lZin00L0m:mm095HRP2<E8T0lZin0>R`V03c[Wd0m:ml00<0S5B900P0
]8:N0>R`V@3c[W`0W6nN08mTW02<HY`0U6VN09AZWP80UFZN0P2EJIh209AYW@<0XY[<0P2Ta_401`2F
g_h0Y:oO0:B_g`2S]^H0Vk;X0::_h02Jd_/01P2=EX/209EYW@0409m`W025G9T0001a07mJW080/Io5
02P0XI740:6?`@2U]nD0Z;OT0:Jfi@2Lhod0X6bE08YDR`1cCIH0Xg:K09MXVP2EIYT0YG6H09iZUP1m
DI<0BSfQ09][V@2_Ukh0VH[20;KDl02ecnd0^>;d0:K3kP2Q]nT0WKCX08ZZjP2AY>80Y[o/0>;Ic@2<
Eh`0QE6;00h0K`0007L0001e00D0K01F=8`0UfNH05`lT`1AD[@0RXO:0P2Y^^H00`2adO00U<gk00X0
K`0200/0L00K01@0L`2GIYL0301`01@0L`2GIiP0GcjC050mW@0oJmH0/L3U0:nggP2Pio/04@1c01/4
MP2KJ9H04@1c01T3MP2>HIP0^GnD0?:XM02;EX`0C3RI08aPV@2OKYT0YHVg09f3]P2KP;D0f^[O0080
6PIh01L0JDnQ01h9NP1oaoh0/l[[09k2lP2Nc?L0YlC^0?_2Q@3j^gh0mkZ5095LS`0I1WT070Qj071H
YP1NC:D090el03TdX01ND:T0UKgc0;o@i`2ncNH0WL;b09o9m@03095LS`0X0:Nfh`1kYnl0h/c20?:m
UP3HXYh0b9b[0?JnSP3k_h80nJaO0?V/H@3i[5h0nJeL0?V/GP3i[600nJaN0?V/G@3i[5l0SjOU0:W@
m0000000OJgb0:BahP2P_Nh0hlNl0=^WW`36Vj`0kkfN0=n/W`39WZ`0nJ]H0>F^V`3iZeX0T5^>0:V3
Z`3VYH`0o<jC0?_4RP3iZUT0nJ]G0?V[D`@0nJ]B00<000000?V[DP2kC@001@3hYdX01@2CGHh0oooo
0?ooo`3oool0000001P0oooo001C0?ooo`070000003oool0oooo0?ooo`3X_:P0i[ZX0>RoZP080?oo
o`050:_2j`15VO<0Kl_n09k0l03X_:P02P3`[hL02@0507H0[<W_0<?@i02^a>X0Y[o/0:6gj02C/nd0
X:3D0?7[`@0208YBQ`80RE6702H0RU:708]BQ`0002h0000a08YAQ`0X7Hh0:Aj?07R1c`1aeO/0J:ki
0?:`Q02;DhP0RU:80000A@2;DhP0RU:80000G@0004P021JF09JgkP2d^Md0/<CX0?:`P`2<E8T0Re>9
08]CR02<E8T0QDn707m9QP0003d0PTb60000@@1TDZP0]l7R0:_9l02B]Nl0i>;@0:CAm`80S5B900h0
Qe2808]CR@2<E8T0000o08I?R00_7HT0RE:808aCR03a[X40l:f20?:_P02;DhP0_XVM0?6]P@80ljmo
00D0Re>80;Z7WP3b[X00lJf00?>_O`020?6]P0030?>_OP2<E8T0]hBN0080lZio00<0ljmm08aDR@2e
PYh00P3b[Wh04P3d[gd0S5B90;>1WP3b[Wh0j;2H0?>^O@2AFHX0SfBL08UQW@2FKJ40]8:N0>R`V@3d
[g/0_hnT08mTW02<HY`0U6VN09AZWP80UFZN00@0UFVN0:>Jc02SV/`0Xi[<0P2Ua_400`2Gg_h0YJoO
0:Fgi@020:Fgi@0309OLoP2=EX/0SEJ;00D0SEJ;0P2DJ9d02`2DJId0UFVM09EYW@2OL9`0QEbI05Pm
U`22PLT0YI[:0;S@k02O`?00R=Ko00<0SUN;02@0ZGBH0:1/U@15:X`0LdfF09IYW02GJ9X0UFJI0:Ea
V02NJYH0OE6C04XmX@1fLL00`MKZ0:W?m02Xm?80[/[^0:Jnj`2S^^T0WjSL09fSf@2LWM<0YJKG08MC
S02?FH`0S5N<08EAR`0>06l0001g0000M@0506`0ESB<09MWV01L?9<0@e:l06JUm02J[N@400X0K`80
2`1`00X0501c09MVU`1I>I0000fA09MWV02VR[L0S7fm08b9b`3Ek>@0_KSE0P0A07<04@0K17H0VfRF
0140L`0I0gH0SV6H0;UoU03bZ7@0ReJ<04`hV@1ABj`0Yhbi0:F9]`2N/>@0Y:_L0=[Zg`0J1WP0J4nQ
00807PUj01D0Je2Q08nil`2eb>P0P:kb09o8m01W_?d0n[]n0?NjQ@2AG8l06@Ii01`8NP0V3gd0G4jX
02@=O00i=:00GU2Y075jc@2R`_00/;kT0=?Gf`2f/mH00`2AG8l0:01`V>P0/;_R0;G2h`3M_KT0^J2o
0=?0b03f_Xh0nkn20?V/G`3i[640nJaN0?c5Q`3i[5h0nJaP0?V/GP3i[5d0nJaO0?Z]F@3i[5`0nJ]O
0?V/G01TVNh0/L7V0=WKf@2i^]X0bKk?0>SA_P32Zl80bIj/0>kC^036[l<0]I:c09Ae[P2HMjd0m<:H
0?c>T`3ka8X0gZRL0?V[E`3iZe<50?V[DP030000003iZe80_4h000@0n:M:00<0n:M>0?ooo`3oool0
0P3oool00`000000oooo0?ooo`0E0?ooo`00E03oool200000080oooo00<0i;NX0>RoZP3oool0203o
ool01P2X^nL0`kkF0>?1]@3X_:L0j;bX0>NmZPP0l:n700T01@1f01/[Y@2_b>d0XK?U0:Jkj02R/nD0
U[O^09Vej`0000000P2:DXL208UAQ`0V08YBQ`2;DXL0RE670000<@2:DHL0:1f>000LW`2O[n<0`lcQ
0<;=h`3V`K40Re>808YBR00002d0Re>808YBR00005d0001806IEZ`1cU>@0Y:cM0?O>XP3b/8<0S5B9
08]CR@2;DhP0S5B908E?Q`1oBHH0Pdb6089<QP1LCZT0BWgQ0:GNn`2V[]d0VjON0;o1f`27D8P208aD
R@0j08M@R02;DhT0S5B90000?`0004T0;af908aCR035TIh0lJj10?:_P02^PjH0SFJP0;j9W@3[/980
ljmo0:n3YP2=IZ00^XNN0>V`UP3c[gl0dYbL0?6]P03c[gh0/XJV08mWX02CJj00lZio0?>_O@2eR:H0
SfNO09=YW`3b[Wh0m:mm0;N:YP2?Iil0TfVO0?:^OP3X/9P0m:ml0;b=Y02?I9`0RF6M09I]X@2dPYh0
j;2I0?B_N`2oSj@0SfBL08aRW02DJIh0U6ZN0::DaP2SUlT0Xi[;0:K5l02Kg_d0Vmcm0:J_gP80Y[OU
0P2IgOh608eFR`0309=WW02CJ9`0U6RM00<0U6RM00/0U6VM09EYW@2EJId0Wg2L08ELV@1H?IL0DDRY
09JKe`2V/^40[K;L0;[FkP0208iGR`0U09IWV@2YM9P0X6bE04DZS01cCIH0UVVL09MXVP2EIYT0YG6H
09iZUP1mDI<0Th2k09:Jf02T_N/0]<WY0;CJm02WeOP0ZK;N09b`iP2H[>@0UJGP08o4n@2<Eh`0Qe><
08mIS02<Eh`0QE6;0000N00007L0001e00P0K@1/I;P0WhZm09N4_@2T/^<0Zk7L0;;Al00400X0K`80
2`1`00X0501c09MVU`1I>I0000fA09b5^P2VR[L0ZkCO0;WJl@2Ig?h03`1b0P0A07<0:00K17H0VfRF
0140L`0I0gH0SV6H0;UoU03bZ7@0ReJ<04`hV@13B[@0RmSo0:S2k@2^/M/0nZmU01X5N00J1WP0J4nQ
01h9NP0J1WP07PUj01`7N02C]nl0][kP0>;;`P3lbHl0n[]n0?NjQ@2AG8l08Pal02XBOP0V3gd0G4jX
02@=O00L27X0Pg6g09J9a02maN00Y[_Y09JgkP3i^Gl4095LS`0C07NgnP0N2W`08Pem07fZl02S_^`0
h/o50?^oPP3JY9h0nJaQ0?V/GP3laHL0nJaN0?V/H03i[5h0nJaM0?V/G`3j[ET0nJaL0?V[G`020?V/
G00C0?V[GP3i[5`0SjKU0:S=l`2llo80`LkU0:R`gP3=g^D0dmkP0:>]g`2:X^@0XJkP0<oQi@3lcY<0
nlB:0=jXW03iZeL0m<2G0?[7T0050?V[DP030000003oool0_Dl000@0n:M:00D0Tef>0?ooo`3oool0
oooo0000000G0?ooo`00EP3oool00`000000oooo0?ooo`0;0?ooo`030:BljP2R_nh0XL7_0080ikfZ
203`[hL01`1>?Ih0_[KB0;[3hP2[/]h0YZkN0;2[d`3C`/T0102:DXL208UAQ`0V08YBQ`2;DXL0000a
08YAQ`29DHL0:1f>069I/P2HZn@0V:[R0;NceP2kan<0VO?S08YBR00002d0Re>808YBR00005d0GE6/
021:`P2jbNH0U<Cg0:o_m`3b/8<0S5B908]CR@2;DhP0S5B908E?Q`0003d060Yo0000@00C?;T0VZcT
0;kFk02A]_00PKWh08QBR@27D8P208aDR@0B08M@R02;DhT0S5B90000?`0004T0;af908MVY@35TIh0
iKZY0<ZS/02^PjH0SFJP0=Jg^`3U^ZT0bJ:`0:n3YP2=IZ00dkJm0P3R^Jh0403:Xk40j[2D0>BjZ`3:
Xk40SfNP09=[X03Y/9H0iK^[0<bT/@2?Iil0TfVO0>R`U`3V_:`0cJJa08mWW`2CJIl20>R`V00D0<jV
/@2lSJ@0SfBL08UQW@2FKJ40bJo00>No[03@ZK40_hnT08mTW02NS/80X9330:6@``2^_nL0Vngg09GS
o@2X/=h0[K?M0:Ngi02MgOd708eFR`0509AXW02DIi`0TfNL09=WW02CJ9`0102DJ9d02@2DJId0UFVM
09n;_P2PRkh0X8Zm09j8_@2]^>40YNGk083@o`0208iGR`0V09MXVP2GJ9T0UfNI0:UdV02PK9D0ABZ<
07==UP2FJI`0UfRJ0:6<_P2QRkd0XXZk09j5^@2__><0SnkY08iGS02>F8`0SEN<03dXSP2O/N@0/:kF
0>OGa02=Eh`0SeV=08aGS027Dh`0SeV<08aGS00007D0001h0000M`0506`0FUNe05UR`@2Bg_h0M:kf
09>ck@2c]m/500X0K`802`1`00L0501c09MVU`1I>I00CC^L052Ck`2BZ^H0nNfQ00<03`1b0P0A07<0
400K17H0VfRF058cS@033Xl0SV6H0:N:]P2OPK80W7ja099h/`2Z[m`0Y[3O09S5m`2/and0nlJ;01X5
N00J1WP201h9NP0F01X6N00N2GX070Mh08R`l02ka>00Ojkb0;g8h`3j^gh0mkZ5095LS`0R37`0:Q9n
02H?O@0M2GX090el01`8NP2N/>D0W<ki09C:nP3biKh0nlV@0?ViO`@0TEb?01<0TEf?01h:O00R3Gd0
HYob0;?5i`2eb>T0lknH0>31^@37W:/0mkj=0?c5Q`3i[5h0nJaP0?V/GP3i[5d0nJaO0?NoSP3laHD0
nJ]O0080nJaL01@0nJ]N0?V/G03j[5P0nJaJ0?V/F`3iZed0ljil0?R[HP25]oH0Y[k[0;_3h020/_@0
Wl;a0:33l@3ka8X0gZRL0<:H[03d`9L0n/N@0?[6S`D0nJ]B00<000000;e?002mC`000`3hYdX01@2C
GHh0oooo0?ooo`3oool0000001L0oooo001G0?ooo`030000003oool0oooo00/0oooo00<0067B0<g6
e02Q`Nl00P3W_J/00`3W_Z/0l:n70?2_Q`050?2_Q`060;g=iP3@h^@0V_?X0:FQd@2g]ML0bO;]102:
DXL0200002`0RE6708YBQ`2;DXL0RE6706U>WP2MMJD0HEF^0P2MdOX07P26h?`0RU:808]CR02;DhP0
RU:80000;@2;DhP0000o0000G@1MDJ`0]KWL09ZZh@3Nal80l[2308E>R02<E8T0Re>908]CR02<E8T0
QDn708=<Q`0H2Wl05PUo06ica`2aa>P0Y;WX0;k1f`2R]NH0R5:908M@R080S5B903D0Qe2808]CR@2<
E8T0Qe280000B@002Xl0QfJU0=bl^@3Qf<h0f/W80:j3YP2=IZ00ZjgI0=[DdP3Jb<P0[h>V08eVX02Y
Z]L0e]?F0=;8d03:Xk40e;Jl0=W8b03:Xk40SfNP09=[X03>/;`0g<[80<bT/@2?Iil0TfVO0<fa_P3L
cLT0cJJa08mWW`2CJIl0bJfm0=g=b03>Y[40_8fT0:2Aa02KU</0T9?C0=7Dg02UcoH0[[3I0:NHaP2P
Sl80YK[X06WKi@1/gNH0SeR;0?B_N`0908eFR`0509EYW@2EJI`0UFRL09AXW02DIi`00P2CIi`00`2C
J9`0U6RM09AXW@0409n;_P040:Jgi@2V]n@0Y[KT07_Ql`<0SUN;00/0UVRK09MXV`2GJ9X0UfRI09MW
V@2YM9P0X6bE04DZS0000Y40XY;40;2I`0020:30k`0J0:Jkj@1Hd^@0mZie08iHS02>Eh`0SUR<08eG
S00m:8h0?d6[096[i`2dc>`0SEN<08mIS@2<Eh`0Qe><08mIS02<Eh`0001e0000N00007L070Qj05YG
]@2;Q/T0^<GT0:>^g`2bcnl600X0K`0800/0L00>0740Iefc09f6^P2WS;P0Y;7R0:V_g02`c_0400l0
LP804@1c01406`Af09]XUP1B<hd0C3VJ09V2^02WR[H0[K?M0:J[f`2Ni?`0U>;m01D1M@2?FXd0kjb4
0?_6R`0008D06PIh01h9NP0201X6N00E01h9NP0B07H0CcRG07B]mP2nd>P0^m?/0>?9_P3g^XD0n[n4
028<O00Z4Wh09Pmm01d9NP0T3G`070Qj02<<O02@]O00^L3O0;[3h@3WcK`0nKUo00@0TEb?01<0TEf?
01h:O00R3Gd0SUV>076Ok@2ha^D0f]WF0;Vkf`2kXKh0dl380?c5Q`3LYI`0bIbY0?V/GP3OZId0nJaO
0?NoSP3laHD0gjJJ0080nJaL01@0nJ]N0?V/G03j[5P0nJaJ0?V/F`3iZed0ljil0?V/G02BGY00Rj7S
0;S>jP1jiMD0PKKf0<SAh@2W`nh0_JC00<BoeP3nchh0n/N@0?[6S`D0nJ]B00<000000?ooo`2mC`00
0`3hYdX01@2CGHh0oooo0?ooo`3oool0000001L0oooo001H0?ooo`030000003oool0oooo00/0oooo
0P2P`O020<g7e080ikj[1`3`[hL0103_[hL0kJf808]BQ`29DHL508YBQ`0<0000;029DHL0RU:708UA
Q`0003T0JDjN09eeY@1gFZ@0Y:GF0=77d02``>D0RU:80P2;DhP06P2:DXP0000]08]CR00003d07a:5
000AU`2RbO@0`M7W0;Jjg03`ekP0QDj808aDR@2;DhT0Re>808aDR@25ChL0PTb601P:O`003Y<0Ym3e
0;CKm02Fa?L0PKWh08aER@28DXT0Qe280P2<E8T02@27D8P0Re>908aDR@27D8P0001705Q8Y@23X^P0
L/Oo05oCk`0209;2m`0H08O0nP1be_/0XZcN0:B]g@2Q`Nl0U;oe07oGo`2SY]P0W:KM0:W<lP2?^_@0
T>Oj0:NLb`2MTlT0//o_09ZolP2;k>X0ZZ?@0:2Ld02<_oP0aNc_09CTo@2[[MT0WiK:0P2`cNl02P27
jnX0[JkH0:Rgi02[_^P0V^gg09WMoP2T[]l0Z;7O09bfjP22f?l308eFRP030?:]O@3c[W`0m:mk00D0
SEJ;0P2DJId309EYW@0409EYW02EJ9`0U6RL09AWW080TfNL0P2NRkh209n;_P050:Ffi@2U]nD0O>;c
07_Rl`2>F8`00`2>Eh/09`2HJi`0UfVL09MYV`2GJ9/0UfRJ09MXV@2GIiT0ZGBH0:1/U@15:X`0AC^Q
06^SlP1XaOh0//OZ0:K5k`2ob>80g:NO0?J^M@2JO;40V7^a09eo/P2GNk40RG>d08R3a`2WZMT0SeV=
08eGS02?FHd0S5N<08MCS02LJIL0TF6F0000M@0007P0DT>S05aI]@1IH/40MZke0:6di@0200h0L@H0
2P1_00P03P1a05A?[`1FG;d0TMcn072Ul@2D]nl0[k?K01<0M0@03`1b01<04@1c01<0M01REZh0VfRF
09Ml]028N;/0Ch_Z092Vi03ik:/06@Ag01@1M@0@07@05@5e08mJS@3_[8@0nlJ;0000Q@0N2GX00026
00806PIh01D07PUj0180MP1?>9L0G5>_07^fn02aanX0iMK70;SVQ`3j_h@08Pal02XBOP0L27X07@Uj
02@=O00L27X090el04TaTP1cZ_@0^lWU0>37`03jcV@0102AG8l07P2AGHl07PYl028=O@2>FHh0nJaR
0?Z^G@2AGHl0Pjg`0:Fok02]aN`0h/:h0;jS_P39W:T0ilbk0=nYW@3:WZX0mkn>0?c5Q@3OYYX0nJaL
0>nkVP3QZY`0nJaL0?Z/F03ka8P0nJaK0?V[G@3c[W`0nJaL099NT0<0TUf@00T0NJoe0:c5k02ibnP0
J:Oe08fom`2?aOX0n/N@0?[6S`3jaXh01@3iZe800`000000oooo0;e?00020?RWBP0509=MSP3oool0
oooo0?ooo`0000005`3oool005T0oooo0P00000=0?ooo`030:31l03=am@0ikj[0080ikj[1P3`[hL0
103_[hL0kJf808]BQ`29DHL508YBQ`0<08UAQ`2:DXL0WgNU09UaX`1`Dj40?f_F0:>`h@2efO80R=Co
087?o`0002l0RU:80P2;DhP208YBR00Z08]CR00003d0012F09b^i02me>/0Rkkh0:cPn@1c^o`0QDj8
08aDR@2;DhT0Re>808aDR@25ChL0PTb60000@01KCJP0]/3Q09:fk`2R]NH0Y<of08aER@28DXT0Qe28
08aDR@000440001208]CR@2<E8T0Qe2805Q8Y02EY^80_mS/0:K?m@2Ya^l0YJWJ0:BYfP2T^NP0Y;[X
08kQo@2<EHX0S5B90P2<EHT0702N]>P0[=ki08aER@3a[H40kj^209:bk01JaoT0S5F:0?6]P@3`[840
N]?o08mHRP2fg_@0WkGW0:Vcg`2[g_T0T5R;08eFRP3a[Gl0lZeo0?B_O@2@F8/0SEJ:08aFRP2=EXX0
lZen0?:^OP3d[g`308eFRP060;F2W@3b[Gd0ljil0?B_N`2MKY`0SF6J0P2CJ9d00`2DJ9d0U6VM09AY
W@0309EYW@0:09EYW02EJ9`0U6RL0:6Ba@2PTL@0Who20:>giP2U]^D0YKOU07OPl@D0SUR<02X0SUN;
0:UjW`2IK9d0V6^L09MYW02GJI/0UfRK09MXVP2GJ9T0UfNI0:B>_@2RRk`0WXRl0;77j`2`a>T0U/Kh
0:C5l02<^oD0Y<Ka0;c<iP2aTkP0XH:b09Qk/@2T/>40Xk3Q09Z[h`2E`_H0PM?o08mIS@2=Eh`0SeV=
08aGS00007D0W6VG095QUP0007D0001h0593X`1NQN40RhC60;Zlg02ng>l200h0L@H02P1_00H03P1a
05A?[`26OlD0]l?T0:>]g`2`c>h201<0M0@03`1b00P04@1c01<0M01REZh0Vh6f0:F6/`2WZMP0[:[E
0;SEk`806@Ag0P0D0GD0100E0GD0:BfP0>n/Q03kaX/201h9NP0H0000QP0J1WP06PIh01h9NP0B07H0
03Bk0;[2h02Y`N/0Qk;b0:;7lP2hiXL0n[n4028<O00I1WT070Qj01d9NP0T3G`070Qj02@=O019<I80
FDj[0;C7j01/Yo@0Ym7f102AG8l01P2AGHl07PYl028=O@2>FHh0gJ>G0?Z^G@80TEf?01H0OYoX0;gI
kP39knd0_;kK0:RjiP3;fnD0`];V0=;4c03laXL0o<F50=nVVP38VjP0kk^J0>6ZW039W:X0mKnB0?_4
R03i[5/0nJ]M0?>^O03i[5`0TUj@0`2BGI00202AGI00Njgc0:o7j`2lc>H0O;3e0<cAgP2M`O40n/J?
0P3jaXh40?V[DP060?ooo`000000oooo0;e?003hYdX0Tef>0`3oool00`000000oooo0?ooo`0E0?oo
o`00F`3oool00`000000oooo0?ooo`0;0?ooo`<0X<7`0P3W_Z/50?2_Q`80kJf800<0Re:708UAQ`2:
DXL0102:DXL0301[Cj00Ug:W09mgY@2ILJ<0L5>Q05mD[P2SY=H0XjSJ0:jjhP2[l?L0000_08YBR080
Re>801X0RU:808]CR02:DXP0000j05a@Z`2<^oD0XjOI0:BUeP2/^>80Z^_i08E>R02<E8T0Re>908]C
R02<E8T0OdV60000@01JC:P0CH7S0:CPn`2V[]d0UjGO0;k0f`2<EHT0R5:908M@R080S5B90P2;DhT0
302<E8T0001705Q8Y01YJl80/[;I0:V^f`2X^nL0Yk[W09CQoP2:E8X0RE:908eERP80S5B91@2<EHT0
2P3a[H40kj^20?>_O`2?EhX0S5F:0?6]P@3`[840ljmo08mHRP2=EHX20?6]P00F0?>_OP2@F8/0SEJ:
0?6]O`3b[Gl0m:mm08eFRP2<EXX0SEJ:0;Z5W03b[Gh0lZin0?B_O02LKI`0SF6I08MOW02EJYl0lZem
0?>^O03d[g/0WFjL08eQVP80TfRM00<0U6RM09AYW@2DJId00P2EJId00`2PRkh0X8bn0:2>`0020:S0
j`0409ODo@2Meo`0Y:SI08I@R0L0SUR<00T0SUN;0:9gXP2IK9d0V6^L09MYW02GJI/0UfRK0:69^`2Q
Rkd00P2RSKh00`2Z`NX0Y>;l0:7Qo0020:_1jP0J0:Zmj02V[=/0ZjkJ0;Z`d02X[md0Y<ce0:;<m@2U
Zm`0XjoQ0:RYe`2QY]X0]/_Z08mIS@2=Eh`0SeV=08aGS00007D0W6VG095QUP0007D0D4:R05eI]@2M
W=80]kcM091KSP0@074200h0L@D02P1_00H03P1a05MA[`1FG;d0LZGa09nciP0?078301<0M0@03`1b
00L04`1d0519ZP1CEkT0BVgC097To01hdOl0505e00<06@Ag0P0D0GD01P0G0gH0:BfP0?JoT@3kaX/0
7PUj01X5N0<06PIh01D07PUj01l9NP0H17P0Ul_j0;Noh@3Qbl80j<bi0?VgN`3j_h@08Pal01T6N@0L
27X07@Uj02@=O00L27X090el000>W02@Q<<0^KkN0=k;aP3j_h@0102AG8l01P2AGHl07PYl028=O@2>
FHh0gJ>G0?Z^G@@0TEf?0P2BGHl04@21[?00/[[O0;S;j02Ja_H0X<Kc0>C4]`2nXkd0b9^X0>W>^`3Q
ZY`0bIbZ0?FoTP3ka8P0nJaK0?V[G@3c[W`0nJaL0080TUj@00P0TUf@099NT02BGI00<AZ407j`m02`
an/0_LcV09k0l@80W/3`0`3jaXh30?V[DP80oooo00@000000;e?002lCP00Tef>0`3oool00`000000
oooo0?ooo`0E0?ooo`00G03oool00`000000oooo0?ooo`0;0?ooo`030:32l02P`_40cLOE0080j;j[
103`[hL20>f]R00308]BQ`29DHL0RU:700<0RU:700P0RE6706]?X02GLZL0ZZkJ0:FVe`2TXM80ZL_a
000000<0Re>800`0000_08YBR02;DhP0Re>808YBR01SAIT0Vg6R05]>Z@0YDlP0]M7^0:?4l01<bN82
08aDR@0G08E>R02<E8T0Re>908]CR02<E8T07a2301d>PP0PAKh0_]?Z0:O7l02C]Nh0Y/gd08W<oP2<
EHT0R5:908M@R02<E8T0Qe2804/_SP2<E8T0RE:800l1N@002Xh00P2gd>d02@2IjOX0001;08aERP2=
EXX0RUB:08UBR@2=EHX0S5F:08aDR@0508aER@0:0?6]P@3_Zh80ljmo08aERP2nR9/0lJf10?2/P@3c
[gl0SEF:0;^6V`80lJf001H0ljmn08eFRP2iQ9`0lJeo0?:]O`3d[gd0VffL08eQVP28H9d0UVbO0?:]
OP3d[g`0`XnQ09a]W02=HIT0QenL09EZW`3W[YL0m:mk0<>AX@2MKY`0SF6J0P2CJ9d00`2DJ9d0U6VM
09n;_P0309n;_P060:Rhi02/^^<0U>ce09;To02VZ=P0UZkW2@2>F8`01@2CKJ@0XWNR09U/W@2HJi`0
X8Vk0080X8Rj02<0XHVk0:nmi02Vg_/0Z[?O0:Zdg`2`]mh0]mC_0;O;j@2[/M`0[J[E0:R]f`2W[]`0
YM;g0?J^M@3g/7@0Uk3X0:FWf02cb^/0mZid0?N_L`3OXY<0SeV=08eGS02?FHd0S5N<0000M@2LJIL0
TF6F04LjWP1@@Z80GhOQ0::gj02ng>l0T5^>0100L@0200h0L@@02P1_00L02`1`00h0L@1FGKh0X;CV
0;Rkf`2lf^l03`1b00<04`1d0`0?0780200A07<04`1d0519ZP23NL00][[L01@0302AFhh0505e0`0I
17L201@1M@0403TlZ@17>Yd0g/Bo0>?4^@806PEh0`0J1WP05@0N2GX07`Uj01X6N00O2GX0S;Ca0;c4
h02nb>80mkV40?ZoQ02>FXl06@Ii01`8NP0M2GX090el01`8NP0o>:00Ac2A09JYh`2ob^<0g/_60?Zo
Q005095LS`05095MS`0R3Gd0SUV>0=fSU`3jcIT0102AGHl2099MS`0C09:nm@2BGHl0N^3e09>Xi02f
c>/0dmCI0:Jji`22]?D0W<Of0<B[`@3>`/l0o/b90?_4R03i[5/0nJ]M0?>^O03i[5`0n:]R099NT003
099MT007095MT00]5h<0O[3d0;77j`2mc>D0W/3`0<c@g@040?[6SP80nJ]B0P3oool010000000oooo
0;a>002CGHh30?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo00/0oooo
00<0Wl;a0<g8e@2O`_400P3X_ZX00`3Y_ZT0jkjV0>n_Q`020>f]R00808UAQ`2:DXL0RU:709A^Y02E
KZ@0Vg:T08iXXP1MDjh209oEn`040:KQn`2UY]L0kmk00000?0<0Re>80P2:DXP02@2;DhP0RU:80000
A@1SAIT0Vg6R05]>Z@2RX]@0cLCB0?gQW@0308aDR@0@08E>R02<E8T0000m08]CR02<E8T07a2301d>
PP1/LLH0[K3J0:BXf@31_mP0[;KP0000@P2<EHT0R5:908M@R080S5B90100Bbn>09E/X@1jEih022n`
0:fZe02CVmP0i>3@08eFRP0004/0S5F:08eFRP29DXT0S5F:08eERP2<EHX0S5B90P2<EHT09P2EJil0
S5F90<>=W03a[H40ljmo0;B5X`2>I9d0_XRK0?6]P@3c[gl0]XNS08iTW@2BIid0lJf00?>_OP2hRJ<0
SfFM099WW@3a[Gl0m:mm0;j=XP2KKI`0SF6J08QPW@2FK9l0j:jE0>NlZ@3AYjd0W6fL08eQV@27Gi`0
UFZO0<FW_03W_J/0dZR^09e^W02=HIX0WX^n102ORkh00`2V]nD0O>;c07cRl`0308iGR`0308mHR`2G
Gh`0001K00T0SUR<00<0TffT0:9gXP2fYLP00P2PR;X09@2X]>40SNSg08[Vn02>F8`0ZGJK09nej02[
d?<0VFVI08aNU`2LJiP0mZif0:[8l02MK9T0RefF09YYV03f[WD0mk1d0=RNV028FYD0VVRG0?J^M03g
[g<0gj:C08mIS@2=Eh`0SeV=08aGS00007D0W6VG095QUP17>Yh0GEVe0;Vlg02R]nP0TE^>091KSP0@
07400P0>074400X0K`0704hoW`1HD[00QWk30;Fig@3Mfm@0TE^>00l0LP0301<0M0<03`1b00P0C3ZL
0559ZP1CEkT0GY?[08bZj@2?FXh0TE^>01@1M@<06@Ag0P0D0GD0100I17L0MW7009fHc`3Sa;T201X5
N0<06PIh01D07PUj01l9NP17<iH0BSjQ05M?[P1e[_H0_L[T0;S8i`2BGHl0SUZ?01T6N@0L27X07@Uj
02@=O011;940?cRP04L`T@1EKm00ZM?f06FZm`1Vfml01@2AG8l01P2AGHl09@mm02dZV`3MXiL0n/fI
0?kGO@<0TEf?102BGHl04@2@Fhl09a5o099MS`2BGHl0;1F10:k9k@1l/_H0IZ_g0975n@2Bbo/0nlB8
0=VTW`3;YK80ljil0?V/G03hZf80TUj@00<0TUf@00P0TEf@02dGP`2BGI00/LO[0;g<i@1n/?@0W/3`
0<c@g@<0n/J>0P3iZe830?ooo`030000003oool0/dL000@0oooo00<000000?ooo`3oool0503oool0
05h0oooo00<000000?ooo`3oool02`3oool05`00GLd0Wl?a0<g8e@3>b=D0j[nX0>^nYP3QZid0kJf8
09idX`2@J:00TV^S09=]Y02DKZ@0UFjT09]bY02>J:80K56Q0::Nd@2TZm`0XKSY0>oN`02bk_L0000^
00<0Re>800/0000j0:5gY02NM:80V6jP06a>W@0fG/h0XJ[M0:;:m02P_^h0Qm;o08]CR@0308aDR@0@
08E>R02<E8T0Re>808]CR025ChL07a23000=T`2KY]d0]/o/073Im`2=EHX0S5F:0000@P2<EHT0R5:9
0000@`80S5B903H0Bbn>09E/X@1jEih0F4NR09>nm@2ai_P0L<kn08eFRP0004D0S5F:08eFRP0006`0
S5F:08eERP2<EHX0S5F909ibX@2DJYl0UF^O08]TX033SI`0k:n?0>JiY`3=Xjd0SVBM0;j8V`3[[i00
i[VW0<jT[@2>I9d0TVNM0>Z^TP3V^JP0cZB]08mUW@2BIid0jJjC0>JjZ03?YJd0VffL08eQVP28H9d0
UVbO0<RY^P3W_:T0dJN]09a]W02MRl00VHc40:>IbP3@dMX0h<o70;2Tc02YU/8209f8_@80YKKU00<0
Nn7d08iGR`2>Eh/01@2>Eh/00`3d[gX0mk5g0000F`0;08iHS00X0:aiV`2Q/nD0Wn;l0=>KVP29Fi@0
OE:D08iHS02YMY/0mJig0?J`MP3DW9X0S5jG09a[V03f[WH0mk1e0=FMVP2;GIH0VVVH0?J^M@3g/7@0
f9jH08QJU@2JJ9L0gZNL0?N_L`3OXY<0SeV=08eGS02?FHd0S5N<040dV`2LJIL0Yh^g08mk^@0hCkh0
T=;n07jXkP2AFhh0T5^>0100L@803P1a0`0:06l0201>?Yl0CSnO05Umf`2P]>H0_=[_0=gKe02AFhh0
3`1b0`0C07@200l0LP0904/jW01<>Y`0DUNi09fbiP2f^]`0^MW`08mJSP2AFhh0505e00<06@Ag00H0
505e04TgV@17@:D0IEfd083Wb010^^l201X5N0<06PIh01D07PUj01l9NP17<iH0BSjQ05M?[P1DL]@0
Ijki05_Dc`2BGHl0TEb?01T6N@0L27X07@Uj02@=O011;940@R^?07i]]@2>Pl<0];KJ0?W<V`3nbf`0
1@2AG8l01P2AGHl0@CZR02dZV`3a`Yl0n/fI0?kGO@<0TEf?102BGHl04@2@Fhl09a5o099MS`2BGHl0
;1F107fdmP2`bnd0]Lg/07Nam`2PaO80WlSe0>34_02n[<P0=`0h0?V/G03hZf80TUj@00<0TUf@00T0
TEf@02dGP`2BGI00Ok7d0;78j`2nc>D0O[3d09k0l03<d=d00P3jaXh00`3jaY00nJ]B0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool005l0oooo0P00000<0?ooo`0A
0000;@2Na?<0WLOe09_<n03Y_ZP0h/>h0;^AZ`2NM:<0T6RP099[X`2CKJ@0U6jT0::Pd`2RW<l0XY_=
0:O9lP000000102;DhP03`0002h0Re>808]CR02:DXP0000j09E^Y02NM:80V6jP06a>W@1IC:T0XZSJ
0:>Wf@35`ML0[;KQ08]CR@0308aDR@0908E>R02<E8T0Re>909I]X@2JL:40002505Y<Z02`[=<0hO3I
0080SEF:00@0S5F:0000@P2<EHT000120`2<E8T01P0004H0UFbQ0:ZSd02LVm80WYkC0:^ih`80SEJ:
00@0001=08aERP2=EXX0001/0P2<EHX0:P2:DhT0SfNQ09ibX@2DJYl0UF^O08]TX02JL:40d[2g0=c7
a03=Xjd0SVBM099XWP3?[KP0gLO40<jT[@2>I9d0TVNM0<b[^03Mb<D0cZB]08mUW@2TULD0bJRh0=k9
a03?YJd0X8bo09j=`@2ISLD0YI_;0:O>m02Chod0[j?;0:RE`P2[_NH0YKk/08GFo`2U/=l0ZkCO09bc
j02N/^H0XkCT07SOm0T0SUN;00<0ZWjU0?B_NP3keih0202>F8`0;02CIYX0TfFJ099UVP2CIi`0[7VK
0>:[VP3f/7L0di^J08UKU01mDY@0TFBK0:UfV`3QZY/0m[1f0=BLVP2<GYL0W6^H0>2YV`3g/7D0eIfJ
08]MUP2JJIP0gZRL0?N`M03HWYP0R5ZE09YXU`3NYi`0mjmc0=nRT`2?FHd0SEN<08mIS@2<Eh`0@3BK
07Q[]`2WRkL0Y;WX0:>`h@2bcnl0T5Z>095KSP2@Fhh0401a0P0>074300X0K`0804hnW`1JDk00^;[K
0:6diP2lfNl0SeZ>095KSP0?078301<0M0803`1b00T0BcZL05=:ZP21N<00]LGW0;_2g`3j/6P0SeZ>
095KSP0D0GD00`0I17L01P0F0WH0BCNI04M0Y@1UGK@0iLBf0>oE^0806PEh0`0J1WP05@0N2GX07`Uj
04LcUP1ACk80Ofng0;Noh02ndnX0n;Mm099MS`2AG8l06@Ii01`8NP0M2GX090el044/T@12:hl0E4^[
08_2nP2ncnL0]/OW0?k;K005095LS`06095MS`11>Z80GU^g0:fZe03jcIT0o]Mm0`2AGHl4099MS`0A
091KS`0W4Gl0TUf?099MS`2LMZP0ACNL07Rcn02]eoH0[=;d08NjmP2I`_@0];oR09^dj@3odW`0nJaL
0?R[HP2BGY000`2BGI00202AGI00;AN3099MT02BGI00O[7d0;78k02mcNH0W/3a0P2M`?400`3jaXh0
n/J@0?V[DP040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool00640oooo
00<000000?ooo`3oool02P3oool03@007j<0;XS/0<gDg`2KcoX0_mCZ0<NX^@2NM:<0T6RP09nUf@2R
Z=/0WL[g09C7n@29dol01`2;DhP03`2:DXP0Re>809Q^X02>IIl0001D09E^Y02[Z]H0Y:;C0:>McP2^
a>X0ZLG^06SLe`2<E8T0ReB908]CR@0308aDR@80Re>900L0Q4j709I]X@2JL:40FD^V02U`g`2gioH0
N=?o0080SEF:00@0S5F:0000@P2<EHT0Qe280P2<E8T01`0004H0E4FT09bOe`2ddo00R=[o08O8o@2H
Y]l00P2=EXX09`0004d0S5F:08eFRP0006`0UFZN09Y^WP0004d0SfNQ09ibX@2RVlh0Xic>09VGd02[
e?D0S<Gk08kVn@2]Z=80WY[?0:[@m02;_oP0TnGl0:jWd@2PVLd0ZLkc08bmm`2Ci?d0[J7<0:2Ba@2a
bN`0VKW^097]l02]W/P0Yi?10:Zji@2PjoT0W=cm0:R`g@2X/n00W;CX07SJn`0208eGR`060;V4V`2O
/^D0Zm7d09EMS02>Eh/0SEN;1`2>Eh/01@2GKj@0UVnT09A^Y02GLJH0nmNN00H0SUR<02X0U6JJ09AW
VP2DIiX0U6JJ09=UVP2BIIX0TfNL0:aiV`3RZiX0m[1g0=>KVP29Fi@0OE:D095TV`2YMY/0hJZK0?J`
MP3DW9X0S5jG09a[V03PZI/0mk1e0=FMVP2;GIH0VVVH0=jXW03g/7@0f9jH08QJU@2JJ9L0gZNL0?N_
L`3OXY<0SeV=08eGS02NP[@0VWjd08Uf]`0/B;`0WLkh0:K7l@2S[ml2091JSP03095KSP2@Fhh0401a
00803P1a0P0:06l02@1=?Yl0CSjO05=L_P1ieOh0R:c]0100L`2?FXh0TE^>00l0LP0301<0M00;00l0
LP1;>Y`0BcZL059G^P2OdOT0_<CQ0>k?/`0D0GD0SeZ>095KSP0D0GD00`0I17L01P18=YT0BCNI03ML
b`1kLK`0_L7M0;cQlP806PEh0`0J1WP0500N2GX07`Uj04HnY01mKkT0SJo/08o;o02^^n<0Z<O`099M
S`2AG8l06@Ii01`8NP0V3gd0:11m044/T@16>9`0E4^[059^d01Zg>80HKOl1P2AG8l2095MS`04079V
]`3H_l80i=G80?kGO@<0TEf?102BGHl04@2@Fhl0:Q>004HcU`2FM:T0W7JX089WZ`22Rm<0Yl;]0:C2
kP2M^^`0W[7U0:6^h@3i`hd0om9l0?V/G03hZf80TUj@00<0TUf@00d0TEf@02dGP`2BGI00TUf@03<K
Q01k/OH0/<W]07Z`m@2M`?40W;oa0?[6SP3jaY00l[jH00D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0D0?ooo`00HP3oool00`000000oooo0?ooo`090?ooo`0>0:bbg@1`T^<0V/?d
0:K;l`2XaNh0Yl?]09;1m`2KaoH0V=Sm0::WfP2QYm/0[kOO09ndi`2gk?H708]CR0090:5gX`2NLj80
SVFO05M<Z@2R[=h0]=Ob09kAnP2Qi_`0Z:_I00<0S5B900<0ReB908]CR@2<E8T00P2<E8T02@2FKJ40
VVnQ0000?`2FKJ40VW2Q0:JJbP2OV/h0/k[N0;K/mP0208eERP0=08aERP000480S5F901L7O01D=Y00
VVnO07ECW01DAJ@0[ZoI0:bag02N]NP0g]gD0:_Mn@0208eFRP80S5F:01T0SEJ:0000K00k88D0VVjN
07UEV`0::j`0[jK>0;7@l02Egoh0YK7Q0:Bah@2U^NL0Xk[Y09?PoP2=EX/0W=7j0:VagP2P/^D0[mSf
08eFR`01Sm00X;;T0:SIn@2]e?@0SEN;0080lJf10100ljmn06G6o@2KJIL0O5:E08eGR`39SiL0kj^1
0>bWP`3c[gd0VVZI08eGR`2>Eh/0^HBK0>:YU`3b[Gh0UEf<1P2>Eh/409M_Y00409I_Y02DKZ@0Ug6V
03k1_P<0SUR<102DIYX209AWVP0W09AVVP2CIIX0TVFJ09=WW02/NI/0hZ^J0?J`M`3CViX0RE^D07eB
U02AI9/0ZGJK0>6ZV`3I[jd0e9bJ08aNU`2]SkL0h:VK0=Z`[@3EWIX0RefF0:b=]P3NZ9`0g;6/0=RN
V028FYD0Zhff0>W3[P3N/j/0gj:C0:B7]P2JOk@0X8Be09Yn]02Z^^D0Z[gW0:[;l@2=]O40QjKY0080
T5Z>00<0TE^>091KSP0@07400P0>07402`0:06l02`1`04dnW`1MPMd0XKCU0=cJe02lf>h0401c08mJ
SP2AFhh03`1b00<04`1d00/0BCVL04/jW01GM]H0]/3R09b`iP2HZn@0^=?^01@1M@2?FXh0TE^>01@1
M@0201T4M`07018GTP18=YT0CdBV08n=c@2`]M`0e=OK01T5N00201X5N0<06PIh01@07PUj01LFS`17
<I<0W[7U0<7Dj02U_N/0N[Wj01`8NP2BGHl0TEb?01T6N@0L27X09Pmm02P@O@11;940>e;009N[i02d
_N00cm3J0?NjQ@H0TEb?0P2AGHl00`2:Um/0_=C[00000004095MS`@0TUf?0140T5^?02XCP00S>k<0
UWBY0;ZgeP2c]m`0]Lo]0:k3j@2V^>H0XjGH08bJg02RYmT0Xkg/0?V/G@3i[5`0kJj<099NT003099M
T003095MT00]5h<0TUf@0080WGFU00P0@c:G0:g=l01`[OL0Mjke09^ol@2K__40n/J@0?:nV0H0oooo
00D000000?ooo`3oool0oooo0000000F0?ooo`00H`3oool00`000000oooo0?ooo`090?ooo`0<0;SD
k`2_]Md0/L;V0:^ji02W^NH0YZOG0:>Wf@2T^nT0Y;_Z07WQlP2;DhP0000g1P2;DhP02`0003`0KDfL
0:5gX`2NLj80SVFO06Q;W02QXM@0XjSJ0:ffg`2Q]NL0]N7e00<0S5B900h0ReB908]CR@2<E8T0S5B9
08E>R01TAIL0VVnQ079BWP0ZMN80[Loa08o6nP1Rf=l0R5:908aERP80SEF:0P000480202<EHT05`Ml
05@fT02JKil0ME>L04IF_P2Se?T0XZSK0P2=EX/0302:E8X0SEJ:08eFRP0004d0S5F:08eFRP0006`0
>b2509Y^WP1iEI/0A52j0:2/g`80Y[[W00@0Umkn09KOoP2>Eh/0SEN;1`2=EX/01@3?U9H0kZ^30?>_
O`3c[gl0T6>I0080lJf10P3c[gh0402KJIL0O5:E08AJV@39SiL0kj^10>bWP`3c[gd0VVZI085HV02D
JIh0^HBK0>:YU`3b[Gh0WG:Q091XX02>Ij4209I^X`80UfnS102GKj@308iHS0P0U6JJ0P2DIiX09`2D
IYX0TfFJ099UVP2CIi`0]YVi0>W1[03I[Z`0di^J09^1]@2JP;H0Sg^i0;6C^03VelH0fJn]0;2E^`2C
OKP0[Hng0<;5g@2iZ<P0/IFk09Am]`2/SKH0`LGM0;c_l`2dV[d0UGni0;k9h`2N_Nh0/^Wh0;NL_@2T
QkH0YkSU09cIo02PfO/0X=;i09NgkP2K[N@0g=CA0:Voj@02091JSP03095KSP2@Fhh0401a00803P1a
00H02P1_04`mW`1ME:l0UYKA0;RifP38i7/20100L`0308mJSP2AFhh03`1b00<04`1d00H0BCVL05M<
ZP1@E[X0V[?Y0;bje`0D07D201@1M@0308mJSP2AFhh0505e00806@Ag00L04QNB04PfV@1?D[H0S<Wl
07K?o`0R37/06@Eh00806PEh0P0J1WP201h9NP0C01LFS`17<I<0EDj^096fl02/b>h0S^Wf01`8NP2B
GHl0TEb?028<O00Z4Wh09Pmm01PAR0007j/0R8C808^Yj@2:/_40hm750:C4l006095LS`T0TEf?0P2B
GHl0302MN:T0WgVX09]eY`2@KZP0NW6n08g:o02QiO`0ZJcI0:RZf02W_^X0Xk_Z000000<0TUf@00@0
nJaM0?V/G03][X`0TUj@0`2BGI003@2AGI00@CJM09A`Y`2PN:D0WGFU07aZ/`2I_O40Y<kf09nnk`1j
Z_40b<_L09^jk@37b=/01`3oool010000000oooo0?ooo`00000F0?ooo`00I03oool2000000X0oooo
00H0]NOg00h0002Z/=d0Z[GQ0;6gg@2hj_H20?ooo`80Re>800<0000/08]CR02;DhP00P2;DhP0302K
LJ40UffO06E9W01]CI`0]k?E0:ZYeP2UXM80Z/G]09g4l`1Idm40000_08]DR@@0S5B90P2;DhT0302O
Lj40V6fO06Q:V`1TAIL0VVnQ0:BIb@2MU<X0b/7B0;Big@2=EXX0R5:908aERP80SEF:00X0S5F:08aE
R@28DXT05`Ml035;_@2aY/d0Yio>09^Hd02/^>80[mWf0P2=EX/04P2:E8X0SEJ:08eFRP0004d0SEJ:
08YDRP0006`08SRa09^Gc`2cbn`0Z<?/09SNoP2WcO@0SUN;08aFR`000540SUN;08eGR`@0SEJ;00P0
TfNK08aRV`2IKIh0ciBF0>j[P`3c[gl0_HZO08aPV@80lJf10180ljmn0<RAV`2KJIL0O5:E08AJV@39
SiL0kj^10?>_O@34Sih0VVZI085HV02DJIh0^HBK0>:YU`3d[g`0`I>W091XX02>Ij4209I^X`80UfnS
00D0000008iHS02>F8`0SUR<09=VVP0:09AVVP80U6NJ02H0WhRk09n9_02NRKd0Sh6o0<K>h@2RaO80
]ncf0:nF_@2OQ;H0YZoN09JZi02W^nL0U>Wi0;o6g`2VZ]X0UJOR09KXnP22j>P0`LSP0:6Xg02FY^40
Q=cn09iZU@2K]^/0YZkM0;CAk`2S`o00ZjkI0:Nch@2Te?T0PNGc0:W7k`2/[mT0[KoW0;c2gP2SYML0
RJ;T0:j_f@<0T5Z>00<0TE^>091KSP0@07400P0>07401P1;?9l0C3fO051K_`2Dd?`0N=Km08mJS`80
401c00<0SeZ>095KSP0?07800P0C07@01`0=69D0BCVL05Ife`2P/N@0^mK]0=7/R@0D07D00P0D0GD0
302?FXh0TE^>01@1M@0I17L041FA04LeV01<JLl0];KJ09b]h`2he>l08Pak01T5N0806PEh0P0J1WP0
1`0N2GX05AJ?04DaU@15G/P0ShC40;>df@3@nJ/00P0L27X0302BGHl0TEb?028<O00Z4Wh09Pmm01PA
R00k9H/0V<cj0;_Bk02Y`^`0[kCM099MS`H0TEb?202AGHl209]gZP80W7NY00L0WgVX09]eY`2@KZP0
YYo>0:RYe`2Za>`0000000L0TUf@00@0nJaM0?V/G03][X`0TUj@0`2BGI003@2AGI00@CJM09A`Y`2P
N:D0WGFU0:V_g02bbN/0Y[cY0:>hj02M]^T0WjGJ0<2ec`3b_YP01`3oool010000000oooo0?ooo`00
000F0?ooo`00IP3oool00`000000oooo0?ooo`0?0?ooo`@0Re>800l0UVfR09I]X@2EK:40UFbQ09M]
W`1UBI`0ED^Z05NMl`2Qi_`0T>;m0>WF`@0003@0S5B90000;`2;E8T0102<E8T02P2;E8T0UFfR0:5e
XP2HKIl0J4ZK0000P02PX=@0[/ka07GOl@0n`/`208eFRP0>08QBR@2<EHX0SEF:08eERP2<EHX0S5F9
09U^W`0G1g`0DdFT09_9m`2;g_h0UjOQ0=_/g`2l_=T208eFR`0J0000A`2=EXX0SEJ:0000C@2FJih0
Le2J0000NP1LHKh0L:;`0:J`g`30^mD0Z[;N0000C@2>Eh/0S5J;0000D@2>Eh/0SEN;08eFR`2NL9d0
UFRL09AWV`2CIi/0S6:K08UPW03?U9H20?>_O`030;f:W`2<H9T0lJf10080ljmn0180b96K09]YU`1l
DYD0Q5ZI0<V?U`3_[XP0dZFY0<B?WP2JJYT0PERH09AYWP2oW;@0hKN/0=B`]031TjL0T6RP08iWX@00
000408iHS00409=UVP2CIYX0TfJJ09=VVPT0U6JJ0P2NQKP09`2NQ[P0WhRk0:Nmj@2U_^/0V=Sm0:6l
k02S/n<0W[7U09j_h`20eol0TV:G095QU`2BI9T0/gfH0>6XV03f[gL0finE08EGT`2QKIH0h:NI0?J_
MP3MXI<0OU6B09iZU@3NYYX0mjme0>6STP3e[WL0mjmd0>6TTP3e[WH0UEj>0>:TT@3g[g@0UEj>09Va
j02SX]@0_<3M0=?SM`03091JSP03095KSP2@Fhh0401a00803P1a00H0BcbO05iE[`2h^MX0X[?T0;gG
k@2?FXl20100L`0308mJSP2AFhh03`1b00804`1d00L03ARE05Q=ZP2BTLl0]kSJ0=3]S@0B07@0501e
0080505e00`0SeZ>095KSP0L1WP06@Ag010ET@1mLKX0SXc<08NYj`2[iOX0TUf?028<N`0I1GP201X5
N00901X6N00N2GX07PUj01DFS`1kK;L0FXCQ08c6n`1fcOl07PUj008070Qj00`0TUf?095LS`0R37`0
:Q9n04HfVP0H4HP0NfRb05QbdP2=]?40ZLO_08kUn`2BGHl6095LS`@0TEf?1P2KMjX01P2LMjT0YIk?
0:FNc`2VWLd0Z/oc02@000X0TUf@00<0/hFT0?6iU03][X`00P2NMZD03P2FL:D0WWJU091[Y@1kHJP0
>EG40:_Mn@29`OX0TnSj0:NWeP2VY]H0Y;SW09nfj024ZNd07jWI2@3oool00`000000oooo0000000F
0?ooo`00I`3oool00`000000oooo0?ooo`0>0?ooo`80Re>800@0V72T0:9gX`2FKJ80UVfQ0P2EK:40
2`2GKIl0S6BN0:2JcP2QXM@0Wk_/0;SOl`2;f?l0000d08aDR@0002l0ReB900<0S5B900/0ReB908==
Q`2EKJ80XGFR09Q]W`1XBY/0Vi;909bHc`2<EHX0001008eERP0208eFRP80S5F:00/0SEF:08aERP28
DXT0UVbO09U^W`1C@j80Ti_H0:f^f02X`N/0[m_g087Do`0308eFR`<0SEJ:02d0001=09I[WP1cD9X0
D3jN08fBe02ebn/0[L;Y08;Bo`2>Eh/0001=08iGR`2<EX/0001A08iGR`2=Eh/0SVFM09iaWP2EJ9`0
U6NK09=WV`2<HY/0RF2L0<jX/`3W^:@0dZBX0;f:W`2<H9T0bjJc0>RhX`3DYJL0b96K09]YU`1lDYD0
Q5ZI0<RU]@3W^JD0hL[10<B?WP2LQKX0VX>i0920_P3<`m80hm[=0=B`]00006X00P2>F8`309=UV@<0
TfFJ0`2CIYX509AVVPD0WXFh00T0Y[7O09oZnP2@i_X0mJmi0:2ai02W[=X0]<k]091PUP2AHIH00P2B
HYH07@2BHYL0TF6G099TV@2cOIP0hJRH0?J_M`3KWiD0QENC0:5]UP3PYiT0mZmf0=fQT`1nDI80WVZE
0=jVVP3g[gD0hJ>B0>2WV03g[g@0hJBB0=nWV02EGXh0hZBA0=nVV02EGXh0lJUk0?N_L`3f[g@0Teb>
00<0T5Z>00/0TE^>091KSP0@07403P1a00LGV01OEJl0UIKB08>^l@2Ym^l0?S:K08mJS`020100L`0<
08mJSP2AFhh03`1b01<0M00;5YD0B3RK05fHkP2BcO`0MmCn01@1M@0B07@0501e0P0D0GD0302?FXh0
TE^>01`6N0002X`0AC>G04e[d02he>h0S/[l095LS`2BGHl08Pak01T5N0806PEh01L06PIh01h9NP0D
5Hl0A36E09ZZhP2c]=T0]];^08W/j00N2GX09Pmm01`8NP2BGHl0TEb?028<O013<iP0ASJJ04Q6[01k
J;80/K?J0;CCl01`h=P0nJeV099MS`06095LS`80VWNZ1P2KMjX30:FNc`050:?=mP2BGY00TUf@095L
T00Y4h001P2BGI004P2JLjH0VG>V09MbY`2AKZP0/hFT0?6iU03][X`0^HjZ09ifY@2FL:D0WWJU091[
Y@1kHJP0YIk?0:R[f@2X_^T0YkcX06WKj0l0oooo00<000000?ooo`0000005@3oool006P0oooo00<0
00000?ooo`3oool0303oool208]CR00;0000=`1hEil0XWNS09I]XP2FKJ40Y:GG0::Lc`2SVL/0Z<?]
0:C3k`1>c<L00P3_[hP00`0003h0000d08aDR@0208]DR@0>08aDR@2EJj00W72P08aRW@0003`0UFfR
0;B/d@2ZY=00XYO90:6nkP2jjOD0NN3c0000@02=EHX208eFRP0>05XkTP2<EHX0X7:O08aRV`0004@0
UVbO09U^W`1C@j80A5Jo0:6WfP2=EX/0RUB:08eGR`0004L208eFR`0:04l`S02=EXX0RUB:0000B`2F
Jih0VVfM09JAc02GUm80`KgF0000C`80SUN;02H0001=08iGR`2<EX/0SUN;08eGR`0004l0SVFM09ia
WP2EJ9`0U6NK09=WV`2<HY/0RF2L0:RIaP3Kcld0hLNo0:>Ea`2AQlD0Y9?40=_@cP3SbKh0]k7B09f;
`02JRKl0SXK60:G?mP3:knd0^LKT0;:XcP2LQKX0X[7S09b`i@1Zg>P0E<gZ08]KT`0005X0VffL0:1_
V`<0TfFI0`2CIIX309=VVP80U6JJ102NQKP20:J`g`0;08cSo02:G9D0O5:D0=2BTP3/Yh40mJmi0=fP
T`3_ZWl02P1/091PUP2AHIH00P2BHYH07@2BHYL0TF6G099TV@2cOIP0hJRH0?J_M`3KWiD0QENC0:5]
UP3PYiT0mZmf0=fQT`1nDI80WVZE0=jVVP3g[gD0hJ>B0>2WV03g[g@0hJBB0=nWV02EGXh0hZBA0=nV
V02EGXh0lJUk0?N_L`3f[g@0Teb>00<0T5Z>00/0TE^>091KSP0@074000J?04PjWP1RQMl0Xk?T0;kG
k014=id0?S:K08mJS`020100L`0J08mJSP2AFhh05P5d000:S`17=i/0X;3S0;JgfP2le^d0ONK@01@1
M@0B07@0501e01@1M@0I17L0SeZ>095KSP0L1WP0?RfC07a_^P2d]]X0eOFP01h9N@2AG8l0TUf?028<
N`0I1GP201X5N00G01h9NP1@@J8051F?07]/]`2:Q/T0Y]cj0:jbf`2BGI007PUj02H?O@0L27X0TUf?
095LS`0R37`0@c>H04HfVP1fIK<0Q8770;;6j@3j[V<0nJiT0?V]IP2BGHl00P2AG8l00`2HM:P0VGFY
09UeZ@0209YfZ@0309YgZP2KMjX0VgNZ0080Y9k@00<0Y9k?0:;=mP0R0000102BGY000`2BGI00TEb@
02TCP002099MT080VgFW0180VgBV09YdYP2JLjH0VG>V09MbY`2AKZP0cko;0>o;[P3;Z[P0^HjZ09if
Y@2SVLX0Y9[:0:BIb@2`bN`0ZLO_0000003iZe`B0?ooo`8000005@3oool006T0oooo0P00000<0?oo
o`0:0000<02JL:80HTNL07QGW`2h/m@0YjSG0:C:m02RbO@0Q=Oo0:J[f`D0kjn80P0003@04@2<E8T0
KDbJ0:5eXP2HKZ00UVbP09a`X02<HYd0HdJI04N=k@2OcoP0S^7m0:B[f`3VelH0SEJ:08aERP000400
SEF:0080SEJ:00d0FS^B0:1cX02PLYl0S6:K06A5V01L?980[Yg60::Ca02Y]n<0i=[;0;WVm@2:E8X0
SEN;00<0SEJ;00X0Cc2<09U/W@0004/0CCjP0353]@2ecnd0[LO]0:gFm@29coh0001?0P2>Eh/02000
04d0SUN;08aFR`000540VVbK075=U`2>IId0WW6N0P2RT/@03P2PTL@0XI7409K1m@2:i_L0LMOj0;Rk
f`2Q`>l0U;kc06_Dn@2Pd_T0XlGa08C=o`2;a_/0VLgj0P2N`?00102P_^h0SkSb09fUf`0006d208iH
S00609]ZV02YM9L0Re^C0000G@27G9T0X6nK0`2CIIT309=UVP0309=VVP2NQKP0WXFh0080WXFh0`2U
/=l03P2;h_`0Tf:E095PU02?Gi@0RUbE07aBU03@TY80k:N10?F_N@3MX9<0kjYo00X0K02@H9H0TF6F
0P2BHYH05@2BHYL0TF6G099TV@2cOIP0hJRH0=Z^Z@3KWiD0QENC0:5]UP3PYiT0fjjY0=fQT`1nDI80
WVZE0=jVVP3H[Jd0hJ>B0>2WV03g[g@0hJBB0=nWV0020>:TT@060=nVV03WYhd0lJUk0?N_L`3f[g@0
Teb>0`2@FXh02`2AFhh0T5^>0100L@0l;iP0PWW00;RhfP2nen`0L=fm04@gW@0n<Y/0301h0080401c
0280SeZ>095KSP0F0G@000Z?07md_@2@T<l0[[GN0>OgZ02DGi00505e0180M00D07D0505e01T4M`09
4Hl0Vg^^0:9o[@1mK[L0BHOY08k9o02U[Md07PUi095LS`2BGHl08Pak01T5N00J1GP0@BnD01h9NP1@
@J80Bdfb05V6h`2gd^h0S/Ok0P2BGI004P0N2GX09Pmm03PSS02BGHl0TEb?028<O013<iP0ADB/09R/
i@2of>`0^n3b0;C@kP3Y^J<0_IVb0:Z2Z@2CKZD0U72W09QcZ080VGFY00H0VWJY0:BNc`2TW/l0Y9k@
0:;=mP0S0003099MT0D0TUj@01@0TUf@095LT00Y4h00BcJG0:1jZ02SNjL0VgFW09]dYP2JM:H0VW>V
0:BXf@2TZMX0TJ7O09_Io@2^l?H0gMcE0:BMcP2SV<X0Y<Ka00@00080Tej@00<0TUj@09=NT03iZe`0
4P3oool2000001D0oooo001[0?ooo`030000003oool0oooo00T0oooo00X0001709Y`XP1RAi`0DT^/
08cUnP1cbol0YZcL0:>Ue`2^]Mh0^]ob1@3_[hP04P0003@0S5B908aDR@1]C9X0UVfR09Q^X02FK:00
W72P09Q/WP2MT<H0W9C<0:jni@2R/nD0]=[c089=R02=EXX0001008aERP80SEJ:01H0R5:905XkTP2C
JZ00X7:O08aRV`1TAIP0>e:o067Am02OYm`0l:n608eGR`2=EX/0RUB:08eGR`0004T0SEJ;08YDRP1?
<8`0VFbM06i<V@1=?Z00FV6o0P2Y/Mh00`2P/nD0[MOf0000C`0208iGR`0;0000C@2<EX/0S5J;0000
C`2JK9/0LDfG01`_Z@2]VlD0[9W40:K5k`2Hh?h00P2W^>H04P2V^NH0VN7m0:UeV@28F980Cbf802@>
O@24]_D0/lSZ0;G9j@2T_N/0Xkk/0:>XfP2QZ=/0VjSO0:>WfP2Ub?80001]08iHS080U6FH00D0ZGBG
08]KT`12;I40QebI0:1_V`0309=UV@0309=UVP2MQ;P0WHBh0080WXFh0`2U/=l04@2;h_`0Z7BH09ET
UP2EHiD0Tf:E095PU02?Gi@0RUbE07aBU03@TY80k:N10?F_N@3MX9<0kjYo00X0K02@H9H0TF6F0080
TV:F01d0TV:G09b0]02@NKH0/I2d0>KC``3J[ZT0/IBh09=j]02/Rk<0imC30=^^Z@2bU;P0TgZd0:Z9
/P3Sel/0f:f]0<6P]`3V_jh0f:f]0<:P]P3OYiP0fJj]0>:TT@3OYYP0fZn/0>6VU`3g[g<0h;6W09=L
SP03091JSP0709al/02LO:h0UgR^07eb_01?WO@0Lj[d0:Rbg`0204@gW@0U03hbV`0<07P0401c0100
L`0@0780TE^>0:>0[P1oL[X0D9C`0;cEk@2CcO`0mjib09AOT00D0GD04P1d01@0M@0I17L0E4JT04E=
]@2KNjh0XWn]0:^dg`2^a^/0VLGf01L3M`0N2GT0TEb?099MS`0R37/06@Eh01X5N011;i@0DD:R04U<
/P1jK;L0/k?I0;SAk@03099MT00F02D>O00V3gd0>2><099MS`2AG8l08Pal038fYP1dI;80^<cY0:;H
n`2beO80Ol7l0:GGn@2mVK80ZX:Y09=^Y@2DL:L0XI_>0::KcP2SWLl0X<cg0:7<m`L0TUf@1@2BGY00
1P2BGI00TEb@02`EP@0T?K@0X7ZX0:=kY`80Yj[I00P0X/og0:7?m`2CgOh0YJWJ0:BYfP2U_N/0Xkg/
05_Ch0H0Tej@00<0TUj@09=NT02_PJ<04P3oool2000001D0oooo001/0?ooo`030000003oool0oooo
00P0oooo00X0001709Y`XP2JL:40XZKH0:S3k@2V_n`0Qn7k0?2`R03_[hP0l:n81@3_[hP07`0003@0
VFjP09U^W`1]C9X0UVfR0:NQd02SVld0XiS:0:Fnk02X_^X0G]KG0?2_Q`3b/XD0l:n7089=R02=EXX0
S5F:08eERP2QM:00VFbL08]PVP1J>i80TfZP0:VMbP2SU/L0VXc409N=a`2a]M/0^NGd0?2_QP2=Eh/0
0P2=EX/03P2=Eh/0001908eFR`1[BIP0Cc2<09U/W@1^C9T0?Tjk09c2l`2Oio/0UUn>08A@RP000500
001?0`2>Eh/07P1T@I80001>0000E02JK9/0LDfG03]8]@2W^nP0ZkkX0:Nhi@2X^>D0WMgm04l^RP2=
EX/0WfjJ0:UeV@28F980Cbf802@>O@1>@J80YJ_K0:Z^f`2Y[=X0YJgM0:>]gP2McoT0SeR<08EFTP2=
Eh`0SUR<09e^V`80U6FH00L0ZGBG08]KT`12;I40QebI0:1_V`2NR;/0WXNj00<0WHBh0P2U/=l05`2:
h_`0kZV108mIS@0006<0PUNF0:QdV02EI9H0UF>E09=RU@2AH9@0SenD08YLU@1lDY@0d9:B0>FZT`3e
[gT0gJ2C0>nZO`0:06`0T62F09b0/`2LP;@0WH2d0080W82d02D0T7Vf0:Rhi032kO40a<WM0;6D^02C
N[@0Y[CR0<7/lP35bmh0YJKG09BRgP2U/^80_n_b0;C;j`2n_=P0XK3R0<?Kj`32X;H0h]K;0=V^[@32
X;H0gjJH0=Z_[033X;D0j;n/0>2aY`2TPk00Vg^^09Qi[`2LOK00W7b`09al[P2T/^80X:oS0;79k02I
a_H0n;5a0080A3NM00l0?S:K00`0N00@07<0401c01@0M02NOJl0Xh2^0:B[f`2XZ]P0//OZ08c^i03g
[W80U5n@01@1M@0B07@00P0I17L04`1DAZ@0ADfe06BIk@2Af?h0Y:kN0:Bkj@2BGHl05`=g01h9N@2A
G8l0TUf?028<N`0I1GP0@2fC044_U01A@Z80NV^f08>Xk02]/M`0102BGI004P0U3W`061B;03PSS01R
Bj00XW^X095_Z@1cM/L0Zl[`0:OAmP2UcOD0Vl;c09g=n02L_Nl0W[S[09jVf`2MWmH0S/?i09C7n@/0
TUf@102BGY002P2MMZH0WgNV09YbY@1jHZ/0>f7>09>Sg`2bgOH0ZMoj0:NZf@2VZ]T20:JmjP0305kF
h02CGY00Tej@00L0Tej@00@0VG:T09QaY@2@K:D0[h6S3P3oool4000001L0oooo001]0?ooo`030000
003oool0oooo00L0oooo00X0?bfC076bn@2BiO`0YjkL0>_C_03`[hP0kjn80?2`R03_[hP0l:n81@3_
[hP0200003d0O5NL09U^W`1=A:H0XM3h0;KDl02Oio/0YZoN103`[hL04`3b/XD0l:n708eFRP2=EXX0
R5:909A[X02QM:00VFbL08]PVP0007X0Wi_@0;GBk`2Uao40M]Gm0?6_QP3`[hH0lK260?2_QP2=Eh/0
0P2=EX/0;`2=Eh/0001909IZW@1[BIP0001j09I[W@2PS/00UHW40<>kd`2`/mX0UUn>08A@RP000500
001?08iGR`2<EX/0UfRJ06A1TP000540;c^]09^=a02RS;d0[[WQ0;2jh@2TiO/0QeVD09]YU`2TKiH0
Cbj:0000DP2OKYX0ZGFI08QHTP1?;HP033Rh0;:oi02d^ml0XMKj0>fZQ00m7X80SER<08iSV`2?F8`0
QEJB08eGS00006d0WFjK0080U6FH04X0ZGBG08]KT`12;I4002Va0:J@_P2NR;/0WkGW0:6bi025h_X0
P=oj09ASUP2EI9H0UF>F0>jYP@2?FHd0>bB;089GUP2XM9P0UFBF09ESU@2CHYD0TF2D08mOU02:G9D0
O5:D0;RE/`3X_:L0fJ^X0:nC^@2NPK80VWfa09ao/`2LP;<0W82d0:F[f`2TZm`0TN3n07a>T02AHYL0
lZal0>:WU@2IbOP0mJmi08iIS@2BG8h0hJJF0?J_M`3e[gP0iJRA0?J_MP3e[gL0SeZ>091KSP24ZNd0
XK3R09k>n02gc^/0_[cH0:6`hP33fn/0`j2e0>OE``34/<H0^IVg09]k[P2V]><0Y[GT09[Go@2Kf?d0
Vlgi0::Zg02W_NT0RNcX0?RaL@80A3NM01H0?S:K00`0N00@07<0401c01@0M000G/P0_M[^09cBn`2l
f>h0Zk?O0?R_L@3g[W80U5n@01@1M@0E0GH06@Ag05I6Y016CKD0XkWX0;_Ml@2KaOD0Pkkj0P2BGHl0
300G0gL07PUi095LS`2BGHl08Pak03XXT010;I<0@BnD04Q</P2LZN00^=7/09;_k0@0TUf@01409@il
01PDR`0h8h`0@U_50;Vlf`2f]mX0]]cc0;?OmP2[`n/0Z;gX0:Fkj02R/^<0Wk7T09^`iP2OWm@0aL;G
0>3nb`0<099MT003099NT02KMJL0VgFW0080VgFW00P0WgNV09YbY@1jHZ/0YJ3@0:JWeP2W_n/0Y[k[
067HhPT0Tej@0P2JLZD209YbY00409UbY02HLJD0T6bU0:n1X`X0oooo1000000K0?ooo`00KP3oool2
000000L0oooo00X0JhWN0:F/g035bMd0V[G[08o0m`3`[hP0kjn80?2`R03_[hP0l:n8103_[hP02P00
03h0<An;07aGW02IKYl0HTFI09fUf`2R[^00XK?U0>SE``2ggO<30?2_Q`140?:bQ@3`[hL0LTfG09U/
W@000440U6^P0:5dX02IK9`0Rf2J09N>b02HVM<0Y:oO0:Zag@2beO80lJn60?2_QP3a/8H0l;2608eG
R`2=EX/0SEN;09Q[W00004T0UVZM06]9V01<?Ih0WI770:o7j`27hO/0ImW[0?2^QP2FGhh0Q52:0000
D02>Eh/0W6^I0000C@2GJ9X0I46B0000LP1@E[T0T;ge06C@n03b/840lJj208eGS027FI@0VfVG0:A_
UP1?;XX0001H09m^VP2YMIT0R5RB09In]P2>O;/0UicF0?GJ/P2?FH`0kJZ403dNPP2=F8`0SeR<0:Yf
V@25EY80001K0000GP2MKY/209AUV0080:UdU`2;Fi<0@RfA03TlZP23dol0YkcX0:Jkj02b/]P208mI
S@0;09ASUP2EI9H0UF>F0>jYP@2?FHd0>bB;089GUP2XM9P0UFBF09ESU@2NQ;L00`2MPkL01P2?NkT0
WXJj0<c;f@31jo40^jO609j1/P80Y:WJ02X0T]on09;NoP2@FXd0SeZ=08aHS@1lCY00TF:G0?:/O03R
YiD0mZmh0?F_N@2>FHd0TUb>0>6VUP3f[gL0mJmh0>FXT@3f[gH0mJmg08mJSP2@Fhh0hJJE0?J_MP2D
GXh0mZme0?J_MP2DGXh0QZc^0<CKj`2Oc_P0XkWY0;G=k02Ve?P0YMCh0:fjh`2Y_nX0Y;g/0::`hP2M
l^l0Y:cM0?N`L`3h/G4204@gW@0F01T4M`0<07P0401c01@0M01RDJT0D5>f05n>i`2dbn/0S[gf0?R`
K`3h[g40mjib09AOT00D0GD05@5f05U:YP1FAZ@0Nfji0:_5k@2Q]^L0YK[X09SXn`80TUf?00X05`=g
01h9N@2AG8l0TUf?028<N`0j:900@2fC04aVc01iJ[H0/k?H1P2BGI00400004H061B;04hlW016AJd0
SNCk096ek`2^bNh0[;[T0:Zhh`2Y]^<0Y:?C0:>Re02S]nL0X[OX09Vaj00AXK@:099MT0<0VWFW1@2K
MJL01@2UVl/0YI[:0:FJbP2`bNd0@/6_00P0Tej@1P2JLZD209YbY00309UbY02HLJD0T6bU00L0oooo
1000000O0?ooo`00L03oool00`000000oooo0?ooo`050?ooo`040000S`2X_NP0^L7P0;gMk`80kjn8
00<0l;280>n_R03`[hP0103_[hP0200003T0<An;06Qid@2VX]80^M?]09WNoP2V/N00l;261@3`[hL0
303b/XD0PTf8079=U`2IKIh0H46F09A[X02bXlT0ZI_80:2@``2Y^nL0[K_T08gZm080lK2600<0lJn6
0?2_QP3a/8H00P2=Eh/0D@2:E8X0FSR>09Q[W018>Yd0UVZM09Q[W@2CR<@0U97>0?>aP`3a/8@0lJn5
0?2^QP2FGhh0Q52:0000D00004l0W6^I0000C`2GJ9X0I46B048aUP26QL/0]l7R0;CSmP3b/840lJj2
08eGS027FI@0VfVG0:A_UP1?;XX0001_0:R?^`2XS;P0X8Ff09In]P2W[=X0[J_F0;GIlP2SKiL0kJZ4
03dNPP2=F8`0RenI0:YfV@25EY80Cbf901XRV`2MKY/0U6FH09j6^02OQKL0WH6d09Im]P2[/Md0Z;;P
0::_hP2VbO40001S09i]V@2ULIP0U6>F09ETUP2EHiH0kZV108mIS@0k98/0PUNF0:Z=]`2NQ;L0WhBg
09j4]`2V^^P0YK[X09SIoP2HfOd0W<7b0:>ahP2R/>80R<oo08KDo`05091JS@0`08mJS@2<F8d0O4j@
095RU`3b[7`0hZNE0?J_N03e[gT0SUV=099LSP3QYYH0mZmg0?F_N03UZ940mZmf0?F_M`2?FXh0T5^>
0>6VU@3f[gH0U5j>0?J_M@3f[gH0U5j>0?N`L`3g[g@0mZif09ANSP3g[g@0mZme09EOS`2Y/n00_KcH
0:>hj02Y^N@0U[3Y0:K`m`3g/7<0n;5a04@gW@0I17L04P1d00`0N00D07@0H56Y069AZ@23LkT0]kGG
0P3h/700303h/6l0n:ma0?N^LP2DGi00505e01D1MP1IBZH0ATfe07JQk@2WfOT0XZ_N0:J]g0<0TUf?
00X08Pak01h9N@2AG8l0TUf?028<N`0j:900DT:Q04M;/P2AaoX0L]3n1`2BGI002P0o:i00Beo50:6_
hP32g^d0[[kV0:VYeP2YYmD0ZK_W0:NiiP0h_;H;099MT080VWBW1@2JMJL01P2KMJL0Y9_<0:BKc02T
Vl`0YLSb000000T0Tej@2@2JLZD80?ooo`@000008`3oool00740oooo00<000000?ooo`3oool0103o
ool02@1PDJT0EIgc0;>aeP3W_:T0j;^V0>n_R03`/8P0kjn80?2_R0050>n_R0070006U01EBjX0];gQ
09Vek02W]N<0[loa0?2`QP050?2_Q`0<0?:bQ@3`[hL0LTfG09U]WP1P@IH0<53209o<m`2Pio/0YZkM
0>CEa`3a[hD0lk:40P3a/8H04@3a[hH0l:n60?:aQ@1]BID0VF^L0692U@1J>8h0V6^L04PjW@0QImX0
/<K[0:^liP2ihO@0RN7l0?6`Q03a[hD0l:j60080Q52:00X0001@0000C`2LJiT0?RjE09MXVP2JJYX0
SHK708jBd`3>lnT0^;oO0P3a[X80302=Eh`0QeVD09]YU`2TKiH0Cbj:044^T`2EQ;l0[L7X07oQn@23
hoP0001H08mIS080UVFG01h0kJZ403dNPP0005L0RenI0:YfV@25EY80Cbf901XRV`2CP[h0ZHnj09j6
^02S/>80YJoN09GVo02:ho/0001T0:5]UP000600001S09i]V@2ULIP0U6>F09ETUP2EHiH0kZV108mI
S@0k98/001fW0:F;^@2ha^D209gKo@030:G2kP2V/=l0YK3O0080XLkg2@2@FXd0<02?FXd0S5R=07a>
T02AHYL0lZal0>:WU@3K[:H0mJmi08iIS@2BG8h0hJJF0?J_M`3e[gP0iJRA0?J_MP3e[gL0SeZ>091K
SP3QYYD0fjfX0>FXT@3f[gD0mZmf09ANSP3g/7<0mjmd0?J^MP2DGXh0mjmd0?J_M@2EGhl0DIgd0;;6
j@35gn`0XkCT0?3g]P3g/780mk1c0?RaL@0I17L0L5>P0180M00<07P0501d061AZ@17Dk/0HIga07b`
m080n;1`00`0n;1_0?R_L@3g[W80U5n@01@1M@0E0GH0@bnC0:Jbh@35dN@0Xl?`08S0nP2CGXl3099M
S`0:028<N`0N2GT02a2>099MS`2PNZT0Rff[04MUc@2LZ=l0cm7J0;S?j`L0TUf@00H0NfRb08R1a@2d
[m<0[:kI0:_0j@10`KL2099NT0T0TUf@1P2JM:L309YeY`80Y9_<0P2Tb?8909=NT0<0VW>U1P2JLZD9
0?ooo`<000009`3oool00780oooo00<000000?ooo`3oool00`3oool01@1[P]L0/;oU0<k7d`3>a=40
j;^V0080l;2800<0kjn80?2_R03_[hP0103_[hP01`1GC:/0N:_b08k=o@2Y/Mh0Z;GR0?2_Q`3`/8H0
1@3`[hL02@3b/XD0l:n7079=U`2IKIh0/Io609JFd@2W_^X0XK;T0;?Hl`020?6_Q@0^0?>bQ03a/8H0
lK260?6_QP3`[hH0l[6506e9U@2JKId0HT:E05XhSP2HJi`0IDFF09:Fd`2[]=l0nNV]0?6`Q03c/H<0
lK240?6_Q@3`[XH0UUn>08A@RP0004l0001C09a[V@0n;YD02e??0;KAkP2]bNh0[Mch08;Do`3I[J/0
lJj208eGS02;EH/0QeVD09]YU`2NPkH0Vh6f08al_@2<QlT0^kGD0>bYQ@2=F8`0SeR<0:1_VP80UVFG
0240kJZ403dNPP0005d0RenI0:YfV@25EY80Cbf903@kZ`2A^?80WnGl0:Jlj@2d/]L0kj^209=LS@2?
FHd0001T0:5]UP000600001S09i]V@2ULIP0U6>F09ETUP2EHiH0kZV109en/@2FN[80=cNU0:;3l02Y
bo80Yk;P0:Nag`2ScoL03@2@FXd0802?FXd0S5R=09]m/@2@Mk80/Xj`0>RlZ03K[:H0/Y:f09Ah/@2/
R;00ikbZ0=V[Z@34W[80j;bW0=f^Y@2gU[H0U7Ra0:R5[`3QYYD0fjfX0<FP/`3X_JT0fZbX0>2UUP3/
_J<0mjmd0?J^MP2DGXh0mjmd0?J_M@2EGhl0n;1b1@3g/7800`3g/7<0n;5a079CW`020180M00600`0
N01SE:`0AU>k0:>_h02nd^T0I]Gc0P3h/700303h/6l0n:ma0?N^LP2DGi00505e044`UP13;i<0>W7L
0:?Dn@3Ad=P0]<WZ09=NS`<0TUf?00T08Pak0007R@0;48h0L5NU0:1jZ@2;KJ/0MgW80:6Vf@2LgOd0
202BGI001000B/<0`/kS0:O9lP1Zejl4099NT0H0TUf@202JM:L30:BKc0030:C7lP000000Tej@00L0
Tej@1`2JLjD209YbY@T0oooo1000000Z0?ooo`00L`3oool2000000D0oooo00@0XL7_0<o7d`3V^jX0
k/N/0P3_[hP00`3`[hP0kjn80>n_R0030>n_R00705igd`35bMd0/lOY08bmmP26^_L0l;2608I?Q`05
0?2_Q`090?:bQ@3`[hL0002<0:C=m@2Vj_X0T>?l0:W6kP3P^:h0`mIP0080lJn500h0lk:40?6`QP3a
/8H0lJn60?2_QP3b/HD0KDVE09Y]W@1R@YD0C5Jl09nBa`2gc^/0SLon08OGo`80lK2401h0lk630?6`
Q03a[hD0l:j609IOSP24D8X0001=04=7/@2LJiT0GC^@08^Mg`2UcoH0WlWe0;;7jP2id^`0fJf[0;6J
`02QQ[L0TgZd09Im]@2KPKH0WX>f0:F^gP2U[]d0]MSb09;LoP3/ZHD0SER<08aOV@2PKiX209IUU`0Q
0>fZQ00m7X80001_08]OV@2YS[T0XHJh09Em]P2:N[/0Z;;P0::_h@2Xb?00SeV=0>n[PP2CG8d0SeV=
0000I02QKIH0ES::01`OU`2NKIT0YG6H09ASUP2MPK@0WH2c09j1/`2MO[40UWZb0:^/f02]f?H0[]kh
09m]V03WXhD0TUb>00/0T5Z=1@2LOK407@2@Mk80a/7E0:Rdh@36j^h0/Y:f09Ah/@2V/=l0a>W_0;_=
j032_=@0im2o0<:/a02gU[H0U7Ra0<33g02Q]nP0^>Ke0<FP/`2nan40fZbX0<>N/`3/_J<0kL>X0=NX
YP3RYI<0mjmd0?J_M@2EGhl0jKfX00D0mk1b00<0mk1c0?RaL@0B07@00P0B07@01P0<07P0HeB/081c
^`2l^ML0ilNg0?39Z@80n;1`00`0n;1_0?R_L@3g[W80U5n@0=Ag0011<9H0GD^T08f5aP21WN@0Z;3M
0?N^L02CGXl3099MS`08028<N`001hT0?2ZB055/c`2NZMh0ZJ?@0:O7l00S0009099MT0P0TUj@0P2B
GI0809YdY`<0Y9_<00<0Y<Ob0000002CGY001`2CGY0:09YcY@P0oooo1000000^0?ooo`00M@3oool0
0`000000oooo0?ooo`030?ooo`030:2hjP2D^o8000000080kjn800<0l:n80>n_R03_[hP00`3_[hP0
1`0m:8h0<Xc^0;o6h02Ta?00i[^Z0>g6Z`3`/8L01@3`[hL02@3b/XD0l:n709RJe035bMd0[<O]09jj
k02d_>00^KOH0?_QYP020?6_Q@0>0?>bQ03a/8H0lK260?6_QP3`[hH0l[6506e9U@2JKId0WXk309:>
c02BV]T0Y;GT0:V`g@2`e?<20?6`Q00N0?>aP`3a/8@0lJn50?2^QP2FGhh0Q52:0000D013Ak40WXg1
0;cCj`2^koL0Z]gi0:O?m@2<a_/0Z]?f0;?3iP2aV/00XHJg09F/iP2LZn40XJcO07kOn@2DI9H0U6>F
09=SUP2WLYL0k:V508eHS02<GiT0X6nJ0P2FIIL0603]ZX@0?Aj203`YT02EPkd0Z8nk0;73i`2R/^@0
S=om099KS@2AFhd0PUNF08IIUP3_Zh80Teb=08mIS@0006@0XFfF05HbRP0L7iL0YHZh0:R;]P2MPkH0
WH6d0:J[f`80YZ_J00L0T]on095KSP0006@0101Y09m]V03WXhD0TUb>00P0T5Z=1P2LOK420:FXf00N
09OMoP2<Ehh0VF:?09b^i02Ka_D0m:ij091KSP2AG8h0iJN@0:??m`000000XK7T0:N[fP2ccNd0V/Wh
0:Z`g01m/_H0QlWm0:cLn031/<X0_KgJ0;kDjP3]`jP0ejRV0;nI/@3V_:/0fZfY0=^RV@3Y_JP0klFV
103g/7800`3g/7<0n;5a0180M0030180M00501D0M02Zb>l0cLgJ09o>n037a]T00P3h/700303h/6l0
n:ma0?N^LP2DGi00n;1_044`UP1LM]@0XJ_N0;gAj@3h[fh0hk2Q09=NS`<0TUf?00D08Pak03DRS@1g
J;@0Ph;:0;>aeP0<099MT0H0TUj@202JM:L30:BJc0<0Y<Ob202CGY0909YcY@P0oooo1000000b0?oo
o`00MP3oool00`000000oooo0?ooo`020?ooo`050552XP3K`l40jK^T0>BfYP3`[hP01P3_[hP01P0m
:8h0GTjX08>dm@2N^N`0^l3N0;_HkPH0l:n700P0l[:50?2_Q`3`[hL0ZL_a0;k8hP1n]OL0RKGb0;KF
l0<0lJn50`3a/8H0203a[hH0l:n60?:aQ@3`[hH0XI730;c6h@2b`nL0VM[m0P3b/8@30?6`Q00N0?>a
P`3a/8@0lJn50?2^QP2FGhh0001@0000OP1<EK/0Y:_L0<GGi`2^co40ZlG/0:Nlj02T^^P0X[KW09bd
j@2E]>d0Vj?K0;Nad`3fg[40001C0:1^V02DI9L0U6>F09=SUP2WLYL0k:V50000F02<GiT0X6nJ0P2F
IIL08@3]ZX@0W86d08Qi^`0iNN<0X[k]0:Rnj@2d/]H0d<oI099KS@2AFhd0PUNF08IIUP3_Zh80Teb=
08mIS@0006h0XFfF05HbRP0c>:L0TWfi0;36jP2Q]NL0PmCo08CIo`2@Fhh00`1X08]FS@2AFhh00`1X
00@0J@2OKIP0ij>5099LSP04091JS@H0W7fa0P2UYmP00`2Ig?h0T5^>091KSP02091KSP0M08aGSP2I
HXl0iZR?0?F_N@3d[WX0T5^>095LSP3UYi00mZmh0?F_N@3e[gP0mZmg0?F_N03f[gL0K]oF08@_F02T
/N80/L7V0<3NkP2E^o80`l?J0=o8`P2jY<80_iVa0>?BaP3J[JT0`Ibb0>VmZ03_aJH0103g/7800`3g
/7<0n;5a0180M0030180M00506UHZ`1=D[L0AhCW097`f`1Uc?`00P3h/700503h/6l0n:ma0?N^LP2D
Gi00n;1_04MhgP2j^=L0YJcL0<S8fP3h[fh0hk2Q0:InZ02JLjH0UW2V09aeYP2FL:H0N6Ja04f6i`2E
aOP0Lm7n302BGI02099NT0D0VgFW0`2JM:L30:BJc080Y<Ob2@2CGY0909YcY@P0oooo1000000f0?oo
o`00M`3oool02@000000oooo0?ooo`3oool0PHO@0<S6e`2W`^`0blkL0>g5Z`070>n_R00305VTm`2c
e_80_/;M0080ikj/00<0j;fY0?2_Q`3`[hL00`3`[hL02@3b/XD0l:n70?2_Q`0]5h<03F[L0:?4l02l
a^80_LKQ0>NnZ`020?6_Q@<0lK2600X0lJn60?2_QP3b/HD0l:n605A2W`0dM^40^lOS09g3l`2lan<0
n>>_0`3a/8@03P3c/H<0lK240?6_Q@3`[XH0UUn>0000C`13<iT0@77J0:gWn@2hfO40/<K[0:c0j02U
YmL0Y:KG0P2RZ=/0<P2QZ=`0W:GL0:>Ue`2=Eh`0XW2J0:1^V02DI9L0U6>F09=SUP2WLYL0k:V5034E
O@2<GiT0X6nJ0:N<^@2OQ[P0X8Jh09b1]02Z[m/0Zk3L09gFn`2Bb?X0kJZ409INSP2BFhd0TE^=0000
F`26FIH0kj^209=LS@2?FHd0001^09ITUP2NPK<0QgFh08bOh@2Q`_00YZ_J0:O5kP2<Ehd0T5^>00<0
J02;EXd0TE^>00<0J00M79<0WffH0>NSQ@2BG8h0T5Z=1@2LOK430:FWf00309WKoP2@Fhh0T5^>00D0
T5^>00l0S5N>09URS`3VZ8l0mJmi0?B^NP2@Fhh0TEb>0>FWT03f[gP0mJmi0?F_N03f[gL0mJmh0?J_
M`3e[gP00P3f[gL00`3e[gL0Tej?0?N`M@020?N`M@0708NWjP32e^T0W/Se0<2_b02k]mD0jKfX0>o5
YP040?N`LP030?N`L`3h/G404P1d00<04P1d00D0TEf@0:R_g039b=T0eLgB0?35YP020?R`L0040?R`
K`3h[g40mjib09AOT080n;1_00h0Wlgh0<_:f@2I_?00kLN/0>>`X@2jTjl0VW>V09I`YP2LMJH0UW2V
0::Jc@2UW/l0]L3S07OScP/0TUf@202KMJL30:BKc0030:C7lP000000Tej@00P0Tej@202JLjD80?oo
o`@00000>P3oool007P0oooo00P000000?ooo`3oool0oooo09jjk030^mD0i[ZY0;g1g@T0kjn800D0
a/7D0:FljP3X_:L0j;fY0>RnZP070?2_Q`0802dGP`1GAZ80L9k]09VolP2na^00_LKQ0>>l[`3a/8D3
0?6`QP0:0?6_QP3`[hH0l[650?2_QP1D@Yl0Z:KE092ck`2e_^40R[Kc0;;Bl@<0lK2400h0lk630?6`
Q03a[hD0l:j609IOSP18>9/0RHO;0<CBi02kd^/0[KgU0:^eh02V[=/0YZ_J0:FZfP80SeV=0300UFBF
0:ihU`3[Z8L0SEN<08iQV02PKYP0U6BG09ASUP2CHiH0Yg:G0>bYQ@0a5Gd0<SBT0:R>^P2WS;T0Yk_X
09;DoP2Leo`0X[WY095KS@0003l0YW:H0>fZQ02FGXh0TU^=095KS@0c88/0QUVF0>n[PP2CG8d0001S
03PTS02FOKL0/[GK0:V/f@2/g_T0001N095KSP0306P0S5N=091KSP0306P0ReJ=095KSP0306P07AbC
09m]V02VQ[8209en/@80W7fa0P2UYmP00`2Ifoh0kJR2091KSP09091KSP0?08aGSP2IHXl0iZR?0=f/
X`3d[WX0T5^>0:b6[03UYi00mZmh0?F_N@3e[gP0mZmg0?F_N03f[gL0mJmh0080mZmg00<0mJmg09=N
S`3g/7D00`3g/7D01`0=0740TUf@099MT02D_O<0cL_H0>o5YP3_a:H00`3g/7800`3g/7<0n;5a0180
M0030180M00;095MT000J=X0Y<ge0<k=f03=cMT0klJX0>o6Z@3h/6l0n:ma0?N^LP2DGi000`3h/6l0
2`2H_?40c<_I0<kEgP36Z[h0^Y>_0:BKc02SV/`0Xi_<0:;9m00M000070Mi0080TUj@1`2BGI0409Ye
Y`@0VgFW0`2TVl`00`2Tao80000009=NT00809=NT0T0VW>U203oool3000003h0oooo001i0?ooo`80
00000P3oool0101DX_H0K[7i0>VjY@3X^jL80>n_R00403LQR@2O`O40WLCc0<g?f`80j;jZ1`3`[hL0
1`2``nL0am7Q08jnmP2F]^h0^[[J0;Jnh03a[hH00`3a/8H00`3a[hH0l:n60?:aQ@020?2_QP040:c1
j@2/e_H0YLK`0>C2]0@0lK2404P0lk630?6`Q03a[hD0l:j609IOSP18>9/0DeZl0:k1j02`a>T0Xk[Y
09blk`2WdF<0001H08mIS@2DI9L0UFBG09ETUP2^N9L0jjR70000D`2>HIP0X6jH09ATU`2DHiH0Tf>F
0:MbU`0006@0<AEm02/i[027fOl0ZLO_0:W3k@2Q[=h0d/kF0:_7kP2AFhd0000o0:IbV03]ZX@0UUj>
099KS@2AFhd0<b2;08IIUP3_Zh80X8:c09an/@25LkL0Pgk60<S?g`2c[m@0T5^>0000GP2AFhh00`1X
08aGS@2@Fhh00`1X02DRU@2AFhh00`1X030cX`2@NKD0YXJb0:FXf@2VZ=P0V=cn08iISP2AFhh0301]
0140K`3]Z889091KSP0D09]k[P2AM;00W7fa0>RjY@3Vc;`0/i6c09Af[P2/QZ`0ikZW0=ZZYP35WJl0
ikZW0=ZZY@35WJl0ikZW0=^[Y@3f[gL0ikZW0=^[YP3QYI<40?N`M@0800d0L@2BGI00TUf@01IdhP2N
`O40c/gH0<k<f03_a:H20?N`LP030?N`L`3h/G404P1d00<04P1d00/0TEf@09=NT000IMP0Vkoa0<c<
f@3<c=X0klJY0?R`K`3h[g40mjib09AOT0060?R`K`060:Znj@2V_>T0VkK[04k:_03oool08@]k0P0L
1gT2099NT0<0TUf@102JM:L409YeY`030:BKc@2TVl`0Y9_<0080Y<Sb2@2CGY0909YcY@P0oooo1000
00110?ooo`00N`3oool01`000000oooo0?ooo`3W_:T0j;ZU0>RkY`3X_:L01`3_[hP02@0g8HT0IF_4
09K9n@33bn00V<Cf0<78h03W_JX0l:n70?2`Q`040?2_Q`060?:bQP08MN00_<GQ07J`mP1j^_X0iKna
103a/8H00`3a[hH0l:n60?:aQ@020?2_QP0W01H2MP2N^nd0V;_`08nom`3R^k00hKbc0?>hSP3a/8@0
lk630?6`Q03a[hD0l:j609IOSP00BlL0ZkgV0<O@h@2e]MT0Zj[F0:J[f`2=Eh`0Xg6J09e/V@2DI9L0
UFBG09ETUP2^N9L0jjR70000E@2>HIP0X6jH09ATU`2DHiH0WXBg09n2]02OPK<0TWVd0:^^fP2[/=`0
ZMKg0080SeV=0200T5Z=099LSP2AFhd0001J0:IbV03]ZX@0UUj>099KS@2AFhd0<b2;02`[W02VRKH0
X8:c09an/@2TZ]/0/];`09KHoP2AFhh0T5^>0000GP2AFhh00`1X08aGS@2@Fhh00`1X02DRU@2AFhh0
W7f`030cX`29Z^/0K<Cn08_=oP80TEb?00D0SUV>095KSP0<06d04@1_0>fXPP05091KSP<0W7^^0P2K
Njh0502AM;00W7fa0<Rnd@3:i^/0/i6c09Af[P2V[M`0b>G/0<7?i@33^M40hlg10<6[``35WJl0i<k1
0=^[Y@35W:l0ikZW0=^[YP33Vjl0j[^S0`3g/7D01@0=0740TUf@099MT00@07806WWU0080Wl7`0`3_
a:H00`3g/7<0n;5a0180M0030180M00;095MT02CGY00U5n@001Tf02J_o40c<cJ0>o6Z@3`ajL0n:ma
0=f]Y02DGi001`3h/6l40?ooo`03024;N`0L1gT0>RVA0080TUj@00<0WWRW09YdY`2JM:L0102JM:L3
0:BKc@80Y<Sb00<0000009=NT02CGY001P2CGY0909YcY@P0oooo100000150?ooo`00O03oool01000
0000oooo0?ooo`3oool20>RlY`030>RlZ03_[hP0kjn800D0kjn800P0VYSA0;?4i`21^_T0`<OO09No
l`30a]l0i;Z/0?2`Q`@0l:n700L0l[:60>n_R000I=D0Y;[Y0<>oeP3X_Z/0ikj/00<0lK2600<0lJn6
0?2_QP3b/HD00P3`[hH07P0F0WH0D3jM08W2nP2:`oX0T[_c0>W:]P3c^8h0lK240?>aP`3a/8@0lJn5
0?2^QP2FGhh0SUR<08eHS02i^=P0Y;;R09g7mP2BFhd0SEN<095TV@2MK9T0U6BG09ETU`2EI9H0[WRG
0>^XQ`0h9i40SV6H0:V>^@80WXFh00@0WXBg09f2]P2U[=`0TN;m0P2@FXd02@2?FXd0SeV=08mIS@2@
FXd0TUb>095KS@000640YW:H0>fZQ002095KS@0708mIS@0c88/0:C:W09>ekP2Rho`0Y<?_0;6_e`02
091KSP0>095KSP2@Fhh09A:1095KSP0306P0001Z091KSP0306P0;QV509Aj/`2LOK00YJKG0:RVe02a
d?03095LS`0508iISP2AFhh0301]0140K`3]Z8800P2@Fhh509ak[P<0YJCE01D0WM[l0?B_NP3e[gX0
m:ik09g2lP1j^_/0mJmj0?F_N@2:Y^L0Y<_d0;kalP30d>H0YJkN0<OFi@31d^L0`KSB0>C?`P32[<@0
`i^_0?;7Y03``Z800P3g/7D01P0=0740TUf@099MT00@0780TUf@01Yji@80Wl7`0`3_a:H00`3h/G40
4P1d0180M0020180M006095MT02CGY00U5n@0?N_L`00I=L0V[ob0P3<cMX0103_b:/0gJfT0=ZOU`3U
_:/60?R`K`@0oooo00H08@]k01`7N@0j:I40MEZT0:=lZ02NN:L209YdY`80Xi_<00@0Xi_=0:?8l`2S
b?<00`00202CGY0909YcY@P0oooo100000190?ooo`00O@3oool010000000oooo0?ooo`3oool30>Rl
Z0L0kjn800H0[<G/03nIl`1j]?L0U[kc0;bkf02i_]h50?2_Q`090?:bQP3_[hP0kjn80>n^R03;a]H0
VKkb0<_7e`3W_jd0lK260080lJn600<0l:n60?:aQ@3`[hH00P3`[hH01@2?RLT0`<GN092km02`d?40
N[Sj00@0lK2401P0lJn50?2^QP2FGhh0SUR<08eHS01nChl0SEbC0>^YR02BFhd0SEN<095TV@2MK9T0
U6BG09ETU`2EI9H0[WRG0000HP0h9i40VH>k0;K8j02a`NH0WMWl0:Bii`2f/]D20>^XQ`80T5Z=0140
SeZ=08mIS@2?FHd0T5Z=099LSP2AFhd0>CFQ0:IbV03]ZX@0WX6d09n2/`2KO;00T7Ja0:V]fP2V[mh0
XZgO0:W3k@03091KSP0<095KSP2@Fhh09A:1095KSP0306P0001Z091KSP2SP[40PFnf08^ZjP2;g_h0
Q<oo1@2AG8l01`2>FHh0TE^>00`0K@0A06l0XH6`0:F3[`2LO:h00P2LNjh20:FTe@0809gGo02AG8l0
TEb?091KS`2BGHl0m:mj0?F_NP3d[W/2095LS`030?F_NP3e[gT0m:ij0080mJmi00d0m:ij0?F_N@3d
[WT0mJmi03fo]03d[WT0Kjoh0<G;g`2F^Nl0cM?N0?32XP3Z^j<03@1a0080TUf@00@0401b099MT02B
GI006G[U0P2O`O020>o4YP030?RaL@0B07@04P1d00804P1d00`0TEf@09=NT02DGi00mjmc0?J^M000
H]H0Vkoa09[0lP3?d=X0`:W20<2H[P3U_:/60?R`K`@0oooo00X08@]k03/ZTP0j:I40MEZT0:=lZ02/
[]P0YJGF09g8mP2QbO@02`00202CGY0909YcY@P0oooo1000001=0?ooo`00OP3oool200000080oooo
0`3X_:P60>n_R0070?ooo`0nUo80Zl?/0;c4h01n_O/0Mk;g0>RlY`040?2_Q`0=0?:bQP3_[hP0kjn8
0>n^R00Q37`0U[oc0<_9f03<cM/0il2^0>>l[`2:DhT0l:n60?:aQ@030?2_QP060?2_Q`00?[D0_KkK
0:2kk031`=P0hkb_0`3a/8@0603a[hD0l:j609IOSP2>F8`0SER<07i?S`2=G9<0jjV8099KS@000540
TFBI09e/V@2DI9L0UFBG09ETUP2^N9L0Vgjb091h]025R<h0Tj[V0:Nbh@2R/>40[LK/09G5n080jjR7
0P2@FXd03`2?FXd0SeV=08mIS@2@FXd0TUb>095KS@0i=J40UWjg0:J7]02NPK@0Y;KU0::ah`2Dfoh0
Qm?o09ANSP05091KSP0<095KSP2@Fhh09A:1095KSP0306P0:1B309Ej/P2SP[40XZoQ0:J[fP2Wao00
P>Cd1@2AG8l02@0O7iD0TE^>00`0K@08::X0XH6`0;:_e02UYMH0W=Sl09cIo@05095LS`05091KS`2B
GHl0m:mj0?F_NP3d[W/00P2AG8l00`3e[gX0mJmi0?B^NP020?F_N@0=0?B^NP3e[gT0m:ii0?F_N@3e
[gP0m:ii099MS`0[QN/0dLcD0:C2k`3^`:80j[^S00d0L@02099MT0090100LP2BGI00TUf@00l0LP11
<IL0Wl7`09o0l03_a:H0o=nQ00@04P1d00d0TEf@09=NT02DGi00mjmc0?J^M03WYX`03g;Q0<_Gh`2M
bOH0`:W20;Rhf@3U_:/0k/N[00D0n;1_103oool02@33K000>bZB05Y6X00lAK80V]Cl08WQo02VZMT0
lO31099NT00509=NT0D0VW:U102JLjD90?ooo`<00000D@3oool00800oooo00@000000?ooo`3oool0
oooo0`3X_:P40>n_R080oooo00<0?YKb0<2nf02W^^L00P3X_:L00`3W_JX0l:n70?2_Q`020?2_Q`80
kjn800X0kjj8024<O01??il0SlKj0<K@hP2m`Md0j/Rb0?6`QP3`[hH0l[650`3`[hH01`3`[hL0U5j>
08H00038a]P0Sk_d0<W9fP3hk;000P3a/8@0503a[hD0l:j609IOSP2>F8`0SER<07i?S`2=G9<0jjV8
099KS@0005P0TFBI09e/V@2DI9L0WH:e09f1]02OP[<0Vgjb0:V/f@2[[]T0[]ch0P2AFhh0100005`0
[gVG0>^XQ`3[Z8L2091JS@0?08mJS@2?FHd0SeV=099LSP2AFhd0001P03<QS02G]nh0]<CV0:KVn`2U
`nh0YZSH0<k;e`2=F8d0U5j>00D0T5^>00<0TE^>091KSP0U4X400P2AFhh01P1oK[H096;E087@o`2R
e_X0YJgM0;k7h@H0TEb?00P07anE09Ih/02JNZh0NFVe07O>o`3b^i80m:ml0=jWV`H0TEb?00D0T5^?
099MS`3d[gX0mJmj0?B^N`02095LS`030?F_NP3e[gT0m:ij0080mJmi00d0m:ij0?F_N@3d[WT0mJmi
0?F_N03Q[9h0TUf?095MS`0^Qn`0dL_D0:C2kP3Z^j<03@1a0080TUf@00T0401b099MT02BGI00401c
044aU`0ZO>H0WL;b0<W5eP35dnD0100B07@03`2AGI00Tej@09AOT03g[g<0mZid0>NVS03h/740>Hg^
0:S3k@2lan80Pkkj0;GIl`2kbND0kLJ[0>k6ZP030?R`K`D0oooo00T0>bZB05icd02R[=h0]]Ka0:6j
jP1<b^40U5n@099NT02CGY000P2ILJ@00`2ILZ@0VG:U09UbY@0409YbY@0309YcY@3oool0oooo00H0
oooo1000001D0?ooo`00P@3oool010000000oooo0?ooo`3oool30>RlZ0<0kjn8103oool0103>a]80
XL3_0>NmZP3W_JX40?2_Q`80kjn800L0kjj80>j^R@2AS</0`LKM08:gm`2dd^l0O;_j00H0l:n600L0
l:n709ANSP0004h0DUJh0<78g`21^oT0^]_a0080lK2401<0lJn50?2^QP2FGhh0SUR<08eHS01nChl0
SEbC0>^YR02BFhd0001^09^5^`2YS[P0WXBg0:B]gP2U[=`0YZcK097Qo@2/MiP0jjV700<0TE^>00H0
001G0:miU`3[Z8L0jjR7091JS@2?FXd208mIS@80W7ja00/0Wgj`09]k[`23L[P0P87:0:Nag`2Sbo@0
V<Oh091KSP0005d0SER=09ANSP05091KSP0:095KSP2@Fhh09A:1000Z/02SP[00]kcN0;3?l02Qa?80
QkCc07nbm0L0TEb?00P04a6;09Ih/02k/m80/:oG0=;Bf@3b^i80lKNB0=jWV`H0TEb?01T0T5^?09ak
[P3X^:80gj^O0;BA/@2DM:`0VGN/0>NhY03KZJ<0aib/0?F_N@3KZJ80m:ij0?F_N@3LZJ80mJmi0>Ng
XP3Q[9h0TUf?095MS`0?0740:H?Y0<g<f@2I_o803@1a0080TUf@00T0401b099MT02BGI00401c06eH
Z02;R<X0^[OG0>O7]P3lfIh0100B07@01P2AGI00Tej@09AOT03g[g<0mZid0>NVS080n;1a00L0HX[S
0;75j@2@__D0Uk[`0;c1gP30`M/0k/JZ00<0n;1_1@3oool02@1OBZ80PH790;NdeP3]aJ/0n:m^0?N^
K`2^PZD0VW6R09M_X`0209UaY00409UbY02ILZD0VG:U09YbY@P0oooo1000001H0?ooo`00PP3oool0
10000000oooo0?ooo`3oool30>RlZ0030>n_R03oool0oooo00@0oooo00L0X<7`09o1l03W_JX0ikfZ
0>Bj[03`jXT0l:n70080kjn800T0kjj80>j^R@2EGXh0ZLO_0;nofP2T_>/0a<7G0>BjZ`3_k8h0103`
[hH02@3`[hL0U5j>04U>]@2;P/@0^/KS0<2me`3Y`J`0lK240?6_Q@020?2^QP0A09IOSP2>F8`0SER<
07i?S`2=G9<0TU^=0000H00c9Y80:fKH0:KUn`2>fol0Z<;/0;Rde@2?FHd0SEjF0:agV03[ZHL00`2A
Fhh01@0005l0[gVG0>^XQ`2@FXd0WGnc0080W7nc00H0W7jb09an/@2LO[40YZSH0:JWe`2Tgo/3091K
SP05095KSP2@Fhh0001[08eHS@2DGXh01@2@Fhh2095KSP0808ia[@1jNLD0QM7o0:OFn02/d_@0Y:GG
0:Rmj@0C0007095LS`0801<AR`13>j80/mce02nUl02ddo00l[^B0?6gTP3NYi/2095LS`0M09IcZ@2J
Mj/0VWR[09]h[02@LZd0W7^^0<_1d03Wb;P0aJ^o09Ad[02IMj`0akkB0<CRkP37W:`0hlVm0=^YXP36
Vj/0i[NT0=bYXP37Vj/0ikNR0>6/WP2iTZh0V7:U08e[YP0g;IP0m_6a08VXjP0=07400P2BGI002@0@
0780TUf@099MT00@07<0?BjF0:o5jP3?c=L0b/?C0?ooo`040180M006095MT02CGY00U5n@0?N_L`3f
[W@0ijJ<0P3h/7402P3h/780oooo0?ooo`3oool0VKK/0<W9fP3^aZX0klNZ0>o7Z@3h/6l50?ooo`09
00Ibg`2Z`^/0a/GI0<Nod`3]aj`0hZnR0:j2Y@2JLJ80UfnS0080VG6T203oool4000005`0oooo0023
0?ooo`8000000P3oool00`3X_:P0i;NX0>c3Z`060?ooo`0508MBR`2N`O00WL7a09c2l`3T^Z`00P3`
[hL20>n_R0090>n^R03^[XT0UEj>0100LP2I`_@0c<kK09?6n@38d>00n>fZ00@0l:n601`0l:n709AN
SP3[ZXT0Y<kf0<c?g02CcO/0bm;O0>W2[03a[hD0f:b[0?2^QP2>F8`0SER<0000H@1nChl0W82d09j1
/`2JOK40SGJc0:Z_g02U/>00[lK[09W6mP2CGHh0SeV=08eNUP2/MiP0jjV70`2AFhh00`1=A:L0RebE
0:B5/`0209f0/`0509ao/`2R]>D0X;7T0:>Yf`2TZ=T01P2@Fhh01@2AFhh0T5^>08aGS@2=F8d0U5j>
0080T5^>0`2LO:l01P2NOJl0VWV/08ia[@2WY]@0[=3c0:G9l`/0TEb?02D0SeZ>07IT/@2?V]X0LkGj
0:[7kP2Ya^h0lKNB0<jiaP2dT;40Ug>X09IcZ@2JMj/0VWR[0:JRdP2SZ]/0RL_n09kFn`2WZMP0YZkM
09g;m`24a_d0V]Kl08nUi02U]><0`mc/0<KAh`34]ld0YZcK0<SChP37Vj/0i/Rh0<NY_02iTZh0V7:U
08e[YP2QjoX0WIcB00803@1a0P2BGI002@0@0780TUf@099MT00]8i80JUBV03e;^02>a?X0M/oo0?oo
o`040180M006095MT02CGY00gZ6C0?N_L`3f[W@0ijJ<0P3h/7401P3h/780oooo0?ooo`3oool005[A
09NmlP80blcK0P3_ajT70?ooo`050:6nkP3Fh=l000000>:_XP2^PZD0203oool400000600oooo0025
0?ooo`040000003oool0oooo0>FiZ@L0oooo00L0001204/mW`2L`O80alOJ0<CLj`3`[hL0lK670080
kjn800X0kjj80>j^R@2EGXh0FU^i0:>Re01i[?<0^;kN08jglP2fdNh0l;260`3`[hH0703`[hL0jjZ9
0>^ZR@16=IT0C8_Z08c9o02AaoX0`LgT0>O4/`3H[:/0XXFd09Ql/P2IO[@0VWne09^1]P2LP;@0XZcM
0:FZf`2Pho`0Tn7m091JSP2>GY@0jjV809=MSP2?FHd0SEjF0:agV03[ZHL2095KSP040000G01=A:L0
VGnf0;6nh`80YkOU00<0W]Ol0::nk@2UYmL0202@Fhh01`2AFhh0T5^>0000J`2=F8d0Y8>`09em/02M
OJl00P2LO:l0102V/n80YK?R09G@o02;dol>095LS`0=08mJSP2AZ^L0_]CZ0;[=j025/O40ZKOS0<kG
h03>^LH0]92a0:>Ib`2UW<d0Y9oA0:;Bn@03099MT00309Jnl`0m0000TUf@0080TUf@0100U;gc0000
002BGI00Tej@0?B_N`1dh^L0B@0008jUi02W[=/0YlK`0<C]l02UWLd0XY_>0;O6iP2S`Nh0oooo0P0=
0742099MT0090100LP2@KZP0WgNW02dSTP1kT=`0YJ[J0<3<h`2dmnl0oooo00<04P1d00X06@Ag095M
T02]Q:P0gZ6C0?N_L`3f[W@0ijJ<0?79Z@3h/740n;1b103oool00`00Fm40blcK09RnlP020>o7ZA00
oooo1000001T0?ooo`00QP3oool00`000000oooo0?ooo`070?ooo`0701h;O@1WIK`0`LCL0:g0j038
cMh0jl:Y0?6aQ`020>n_R00:0>n^R03^[XT0UEj>0>n^R02`e_@007G;0:S?m02ma^40i;V[0?6`QP<0
l:n601/0l:n70>^ZR@3[ZXT0DE6c0<[Ch@2aeo<0TlOi0;oHk02feo40_k;=0;BJ_@2N]>L0WkCX09CF
oP2Ce?h0W;g_0;Rce@0005P0001D095KSP2@FXh0SUjD0>^YR02CGHh0001F08eNUP2/MiP00P2AFhh0
2P2OOZl0VWZ^089b^@0oR>/0X/cf0:J`gP2V[mh0X/[d09K6n02DGXh8091KSP05095KSP2@Fhh0:AN5
09Ij/P2UQ;400P2W]>801P2Oeo/0X/cf0:;<mP2RZ=/0YJGF0:Vnj0`0TEb?00P0WGVZ09mjZ@2KMZP0
PFN]02eAa@1Id^<0SLKk0>jkV`80mK1k00<0T5b@08c6n`2BGI003@2BGI00102CGY00m:mk0?F_NP3d
[W/20?J`N@030?ooo`26]oD0oooo00@0oooo0P0=0742099MT00702XQTP2@KZP0WgNW07UNY`2UYMD0
Xj?E0?O//`020?ooo`804P1d0P0I17L02@0028l0VGJZ0>NkZ@3Q[j<0aI^/0>NVS03abJT0lLFT0?R`
LP050?ooo`04001Jd@3;cMX0V;kb0>o7Z@d0oooo0`00001X0?ooo`00Q`3oool00`000000oooo0?oo
o`060?ooo`0606IV_P15H<T0XlCa07Jko02F^>l0_];Y0`3_[hP02@3_[XP0kZj909ENSP3_[XP0AcRK
06ROl02N`o80_KgJ0;Zmg0040?2_QP0W0?2_Q`3[ZXT0jjZ90>VXRP3][8P0Z/K^0:_6kP2ea^L0ZlG]
0:S2k@2J`O<0U<Kh09^ik@2J[nH0WZOL0:o6j`2@Fhh0001H0000E02AFhh0T5Z>08iNU03[ZHP0Tef>
08mIS@2=GYH0[7NH0::2/@2MO[00Wgj_09Yj[P2ZZMH0ZjgI0:_Am02Vc?@0T5^>0000FP2?FHh0U5j>
00P0T5^>00X0Wgb]09Yh[02=L:d0<7?P0:WUnP2:eOl0YjoM0:J^g@2V[Md0>@00302AG8l209]h[00=
09]hZ`2LN:/0WgZY09]fZ02WXM00ZZKC0;_6hP3Tl]H0VO?L0>bnX`3e/7/0T5b@095LT00>099MT004
09=NT03d[g/0mJmj0?B^N`80m[1i1`3oool02P0=07404P1c099_Z02ON:L0N5fW08FHgP2Z/Md0]]_c
0:>ok@28f?l30?ooo`0=0180M00I17L06@Ag0007S@0a9I80VGJZ0<W2d`3Xe<40bk?30>NjY`2k^MP0
lLFT0?R`LP060?ooo`04001LdP2I_O40VKkb0<k?fPP0oooo1000001[0?ooo`00R03oool2000000H0
oooo00D0001I0;70iP36cn40Hjci07fVkP040>n_R0090>n^R03^[XT0UEj>0>n^R02=QLH0[kkU076b
n@1o_?X0/lSZ00@0l:n602<0l:n70>^ZR@3^[HL0jJR:0>f/R03_[XL0[<?Z0<6of02g_n00[KkV0:Zj
i@2TZ=T0XZKI0;R`d@2@Fhh0T5Z>091KSP0005P0001D095KSP0005@0SUjD0>^YR02?FHd0001J05U>
Z`2VQk<0XX:a0:JXf02VZ=L0VMcm0000GP2=F8h0TUf>099LSP020000FP0308mISP2DGXh0T5^>00@0
T5^>0`2LNjh01P2NO:d0VWR/08e`[@2YY]<0[Lka0:O:lP`0TEb?01<0VgR[09]h[02KN:`0VgR/09]i
[02KN:`0VgR[0:FQd@2VXM40XmGi09kDn`0006P0TEb?08iIS`3]_j80k;jS0?gEV02@G900TEb@00h0
TUf@00@0Tej@0?B_N`3e[gX0m:ik0P3f/7T70?ooo`0:00d0L@0B07<0TVnX09mhY`1hGJL0YJWI0:B/
g@2TY]L0/K_Q0?OY/`<0oooo00d04P1d01T4M`002Hd000N=07=V]@1iQmH0_<cV09W:n01BYoP0]N7e
07?1oP3aaJ@0l<BT00h0oooo1000001_0?ooo`00RP3oool00`000000oooo0?ooo`030?ooo`060000
F@16>Yh0BYOb0;_Bj`2?aOX0nnJD0`3_[hP0303_[XP0kZj909ENSP3_[XP00@1Y04V@kP2TaO40`<OP
0<77g`3X_JT0j;jZ0?2_QP80l:n700<0jjZ90>j]Q`3YZ8X00P3_[XL0803a/8H0[kKN0;C=k02e_N00
Z:OF0:BXf@2RY=L0//3U091KSP2@FXh0T5^>0000F00005@0TE^>0000GP2>GY@0Tef>09in/02:L;00
4bf[09ZdjP1dd?h0TE^>0000F02AG8h0001N08eHSP2BGHh0TUb>091KSP2<Ehd0SeV>0`2@Fhh209]k
[P<0W7^^0`2VY=@00`2Qf?/0TEb?095LS`09095LS`D0VgR[0P2KN:`01@2U/=l0Y:oO0:>/gP2<c_h0
n[Md0080TUf?00T0Se^?0000J02AG8l0SUV?03<eY03_`J<0J3En091LT02AG9003P2BGI00102CGY00
m:mk0?F_NP3d[W/20?J`N@L0oooo00L04P1c06UDYP0_C;h0[K;L0;OLl`2Tc?@0[;;L00H0oooo00d0
6@Ag06=;X@002Hd0;46e08Bjn02;f_l0Z<gc0:;6lP2M`O40Jj_g08fkm@2?^_@0_LSS00X0oooo1000
001c0?ooo`00R`3oool00`000000oooo0?ooo`020?ooo`050180MP1ZIKX0`/?K0:joi`39cMd0103_
[hP0203_[XP0kZj909ENSP3_[XP0I5jf08j4a029^oL0V/7c0P31aml0:@3X_ZX0jKfW0?2_Q`3JXIP0
jjZ90>j]Q`3YZ8X0eZ>R0>n^Q`3a/8H0l:n60>b[R03_[XL0<jg_0?6`Q@3`[hH0kjj7091KSP2@FXh0
T5^>0000E00005<0TE^>02PLS02KOk@0YhNb09in/02:L;00YJCE0:ZVd`2icNT0TE^>0000F02AG8h0
001N08eHSP2BGHh0TUb>091KSP2?FHh0U5j>0080W7b_0`2KNjh20:FTe@0409gGo00003T0SeZ>099L
S`T0TEb?1P2KN:/20:F`g`0709gDn`2Mdo/0WM?k0::XfP36aMT0Z;_W095LS`02099MS`0908mKS`02
06X0Tg6Y09ehZ@0c=J@0UiOB099NT02@G900TEb@00h0TUf@00H0/8FX0?B_N`3LZJ40m:ik0>VhXP3f
/7T70?ooo`0606]EY`1YE:H0N6fj0;g7h`2K]NX0[K[S1`3oool02`0I17L0Hd^Q02i2]@2Z]^80]Mcd
0:k=l02XZ=L0YZOF0:^ni`2XdOH0NJgd00P0oooo1000001g0?ooo`00S03oool02P000000oooo0?oo
o`3oool0JFBj0:6^h@1/_Od0_[kI09Jjl02od^T30>n_R0090>n^R03^[XT0k:b90>n^R03YZ8/0]]C`
0<G=h@2`d?00V;oc0080`<OO00X0j;bX0=6V[@3JXIP0f:BO0>V]T@3HXI/0eZ>R0?2_QP3a/8H0l:n6
0P3_[XL20?6`Q@0O0?2_QP3_[XL0T5^>091JSP2@Fhh0001C095KSP2@FXh0:1b<0:2jj`2g`^<0UmKm
09k7m@2e/]H0001K091JSP2AFhh0001H095LSP0005T0SER>099MSP2@Fhh0001O05I7Y@2UQ;00W7b_
0:>Zg02TY]P0VmWm09SHo@03095LS`030000GP2?FXh0TUb?00D0TEb?1P2KN:/20:J_g`0309kDn`2N
e?X0WmCj0080YJ_K00H0Xl?`01L0002BGHl0TEf?0000J@2AG8l2099MS`0908mKS`0206X0Tg6Y09eh
Z@2/Xlh09P0g099NT02@G900TEb@00X0TUf@00X0VWJX09YfZ@2JMZT0TG2Z0;25Z03Sa[X0g:VQ0<FI
ZP3Y^:80j[ZQ1`3oool01P1[EJL0NFfi09?KoP2[hoX0dLkG0:fjh`L0oooo00L0I4fQ06=;X@1dIK<0
_/KP0:K5k`2Q_^d0Q]Wo00T0oooo0`00001k0?ooo`00S@3oool200000080oooo00H0/N7g093AoP2`
bNd0[KgU0>VjY03Y^jH20>n_R00G0>n^R03^[XT0k:b90>n^R03YZ8/0kZf90?2_R02/^^<0`KoI09Vm
l@2J__40W[CX0=S4aP2nWKP0gk^c0=F]/03HXI/0eZ>R0?6`QP3`[hH0f:2J0=BQXP3_[XL00P3a/8D0
403`[hH0kjj7091KSP2@FXh0T5^>0000E`1]Fj`0YH>`08id/P1hQM<0S[C`0:o3j@2J`o@0001H0000
F`2@FXh20000F00=095LSP2=F8h0TUf>099LSP2NNj`0RFf]01<YYP2L]NT0SmOo0;6_eP32gNd0SeZ>
099LS`03095LS`80SeZ>0`2AG8l00`2LNJ/0VgR[09]hZ`0309]hZ`80YZoN00H0WmCj09oCnP2VZm/0
YZ_K0:G3k`0A0005099MS`0>095MS`0006T0TEb?0:5kZP2TO:P0VG>V07MQ[00?BLH0XLgg06:bn`1H
d]h0TUj@091LT00c8hh6099MT080VWJX0P2KMZP02P2JMZP0VWJY09YfZ@2AL:X0YZSH0<cNiP3=fN80
aKK;0:B_h03Z^Z470?ooo`0601@0M02ic^/0O;kl07^dm`3[^Il0nLbK1`3oool0101TCJ40;T>f08jk
m@2BfOh80?ooo`@00000OP3oool008l0oooo00X000000?ooo`3oool0U<;f0:6mk@35a]X0a/OK0>Vk
YP3Z^j@0kjj80P3^[XT0503/[8T0kjj80>VXR`3^[HT0l:n803NRm03^[XP0kJf90:Fdh`2]c?00]<[[
0;NYb`2j_]d0fm7>0;bcd@2i_]h0jlB]0=:X[P3HX9X0e:6R0`3a/8D20>n^Q`0>091KSP2@FXh0T5^>
0000I00_@[D0Xk[Y0:oSn02AgOh0YL[c091KS`2AG8l0001H0000F`2@FXh20000F00=095LSP0006T0
VG^`0:>0[@2NNj`0RFf]07a/]P2U[M`0W;oa0:foi`0005`0SeZ>099LS`03095LS`040000J02AG8l0
Y86]09ai[080W7V[0P2KN:/01@2V[mh0WmCj09oCnP2OdoX0YZ_K0080YL?^2@2BGHl03P2AGHl0001Y
03XYT@2QNjX0Y7bX09UcYP2SVld0Xig?0;31i`000000TUf@099NT02@G900<b>>0P2BGI0409YeZ080
VWJX00`0VgJX0:BMcP2TWLh0Y9g>0:;=mP2Qc?H080en099NT02AGI00VkW]0<g9e`3Cb]070?ooo`05
06iFY@0gB[X0Mjke0:K4kP2T]nH0403oool400000880oooo002@0?ooo`0>0000003oool0oooo072a
n02L`O80a<OL0<C7g@3Z^j@0iKf]0=2TZ`3LYI`0kjj80=nTUP3YZ8/20?2_R00a0>n_R03^[XP0kJf9
0>n_R03VYX`0kJf90>n_R02M^^d0_KoL092gl@2i_]h0T[Sa0<32f`2lVkL0h[Z_0>_6[`3Z_jT0l:n6
0>n^Q`2@Fhh0T5Z>091KSP0005P07A:607Yb_P2g_]l0Y:_L0:RYe`1H0080T5^?095LS`0005P0001K
091JSP2AFhh0TEb>0000GP0U5hP0VG^`0;:ef`2VY=@0XMWk058nV`0004P0ECnK095LS`0005`0SeZ>
099LS`03095LS`0501`<O`2GMjh0Y86]09ai[02X/Mh00P2Qe?X20:3DnP80YL?^00<03`00099MS`2B
GHl02@2BGHl01`2MMjP0WWRW08YYY`0J89T0TZ;P0:nXd02TWLh01@2BGI001@2BGY00T5b@03<SSP2A
KjT0XW^X00@0VWFX00D0Y9c>0:BMcP2Sbo@0Xl_d099NT00209=NT007095MT00P3Gh0WGFU09A^Y@0_
9iL0X/3_0=?:d0070?ooo`0506iFY@2//=/0^KgL09Rjl02:bOd0303oool4000008H0oooo002A0?oo
o`0?0000003oool0oooo0?ooo`2L`?40aLOL0<K8g03U_Jd0d:B[0;nN]P3Q^Jl0e:V]0=VTWP3U^JT0
kjn80080kZj801h0kJf90>n_R03VYX`0kJf90>n_R03YZH/0kZf80?2`Q`2Ybo40=Zk`0;O>j`2gZ<X0
Tk7[0;k9h`3Z_jT0fZbW0>n^Q`2TPJh0UWF/09ak[@2FMZ`0Mfbi07=nd032l?00]K?G095LS`0005X0
T5^?095LS`0005P2091JSP0<095KSP1WDjL0XWj]07][]P1fNl/0/k3E099MS`000680DSjK0000B01E
?i/0TEb?0P2?FXh2095LS`0809ijZP2IM:T0R6ZY03=ih`2]hoT0SmGo0:GPn`2W[=/20:K3kP/0TUf?
102KMZP01P2MMjP0WWRW08YYY`2TWLh0ZZKB0<S5e`H0TUf@00T0TUj@09UaY@0K7YH0TFnY0:9kZ02T
Z=T0Y9oA0:>LcP2RboD00P2CGY000`2AGI001`1^099NT00209=NT006095MT00O7980TVjU09A^Y@1Y
E:H0BE_3203oool01@1/Dj@0Dkoi0;CKm02k`n00aNK^00P0oooo1000002:0?ooo`00TP3oool06000
0000oooo0?ooo`3oool0Mk7f0<C@h`2NbOH0^/oZ0;nN]P2kaN80e:V]0<2O]`3U^JT0i;f_0=6UZ`3J
Y9d0kjn80>BWT`3VYX`0kJf90=nTUP3YZH/0kZf80?2`Q`@0l:n700`0Rk_f09Fnl`3@cmT0glO00<B^
a@2TPJh0UWF/09ak[@2T/>00XJgP0;75j@2IaOH2095LS`0P0000FP2@Fhl0TEb?0000F01^EjP0TE^>
0000G@0bHm<0/[;H0:ZXe02Vc_D0001L099MS`000680DSjK0000G01E?i/0TEb?05a9X`2TP:d0XGf/
09aiZ`2NNZX0VGBY08QZZ@2XY]D0Z:cI0:S5kP2AG8l0TUf?0000H@2AGHl8099MS`@0VgJY0`2KMZP0
1@2UWLh0YIg=0:FLc02Vao40@BbA00@0TUf@00X0VW>V09YdYP2JM:H0WWJV09UaY@1dGJT0QlOm09KS
o@27eol0YJGF102CGY002`2AGI001`1^099NT02TNZD0WgJT08aWX`0O7980TVjU0:fOb@2YX/l0_l_S
00P0oooo00<0K5>T07]Y]03oool01P3oool4000008h0oooo002C0?ooo`8000000P3oool04@2U]>@0
[:oJ0;_0gP23aod0Y<Wc0;b_c@2l_]/0_];Y0<;=h`3AYJ/0_Y^d0=nh/03EZjd0fZBM0>n_R03OY9H0
ej:O0080l;271@3`[hL02`2IbOP0W/_g0:G9l`2S_nd0XkOW09SCo02LcoX0W<[g0:2Uf@3Bb]80/<3V
0080TEb?01X0001J091KS`0005L0001K06iGZ02LNjh0RVj^075kcP2WZ=L0TUf@0000F`0005`0TUf?
0000HP0005`091J7091KS`0006<0G4VS09Qh[P2QOJ`0W7V[0:JQd02VX=00Y=;g0000<@80TUf@00@0
TEb?099MS`2@G8l0TEf?102BGHl409YfZ@<0VgJY0`2TWLh0202ScOH0TUj@099NT02BGI00T5b@044/
T@2BGI00XGVW0P2JLjH02P2ILjH0VWBV09YdYP2NMZH0VG6U0:BKc02TWm40ZL;[0:Nfi02n_]X409=N
T00:095MT00=0700T6fV09mhYP2OMZ@0S6NS07=IYP1FOMd0GM?Y02bXk0l0oooo0`00002B0?ooo`00
U@3oool00`000000oooo0?ooo`020?ooo`0?0:>bh`2b`^H0`Mo^07RXl02U]><0[/[^0;NTa@2nVk@0
_KSE0=F[[@31W[D0eJ^]0<2M]@3GXYl0jL>^00L0l:n700X03GOR0:_3k02[`^X0`LCM0:Flj@2I^>h0
WZoT099MS`2AG8l0001E0P2AG8l06P0005X0T5^?0000F00007@0:1^<0::di@2g^m`0V];k07gBo`2B
GI00001K0000G02BGHl0001R058nV`0T5XL0VgR/0:5lZ`1fI[<0VjcS0;6bf02Qf?/0ITfQ099NT01/
Cih0000a0P2BGI001`2AG8l0TUf?01D4NP2AGHl0TUf?09]gZ@2KMZT0102JMZT30:BMcP80Xlcf00<0
TUf@099NT02BGY000P2BGY001@2BGI00T5b@044/T@2QNZP0XGVW0080VW>V00P0VG>V0:>Jb`2TV//0
Y9[;0:C7lP060000TEf@03/WSPD0Tej@00X0WgFT09U`X`1bFJH0T6fV09mhYP2VY=@0YIk?0:2GbP2^
^n<0N>?X303oool4000009D0oooo002F0?ooo`030000003oool0oooo00D0oooo00/0U5j>0>j^R@3^
[XT0W/ch0;_bl`2Q[n80P:__09g=n02n[//0hkV/0;^ge@020>NnZ`H0l:n700T06G_U0:_0j@2m^]L0
YJGE0:RTdP2c_>40TUf?095LS`0005D00P2AG8l06P0005X0T5^?01dAQP0W6h`0Mfbi08R<d02TZM/0
[koV0000002BGI00001K0000G02BGHl0001R0000H00T5XL0VgR/0:5lZ`2SYmT0YZKF0:o2j00005H0
ITfQ099NT00005d0000a0P2BGI00202AG8l0TUf?01D4NP2GMJ/0Xgf[09]gZ@2KMZT0VWJY0`2TWLh0
0`2Rc?H0TUj@099NT003099MT0@0TUj@00T0WWJU08MUY@0D79L0XGZX0;:`eP2TYMH0Y9c>0:78m02S
b?<0102CGY00102AGI00>bN>09=NT02CGY0309YcY@0709adY@2IL:<0LUVV01=5`P2Yf?P0Ql?k08_U
nP0;0?ooo`@00000V@3oool009L0oooo00<000000?ooo`3oool0103oool0102DGXh0kZj90>j^R@3]
[HT50>n_R00308bhl`2B_O@0cLSE0080ikj[1P3`[hL0900DO^D0Z<C^00l0003`[hL0kjn7099MS`2A
G8l0001E095LS`0005H0T5^?095LS`0M4HH0BSfP062Ll@2A^?80]kCF099MT02AGI00TUf@0000F`00
05`0TUf?0000F`16=i`0A3JK02Pg[02EeOd0Y]_j0:6Xf`39a]L0001F06I=X@2BGY003P1g0000H@80
TUf@00`0TUf?0:1jZ00E17X0UgF[0;Bhg02`/]X0Y:?E09W<n@2CGY00TUj@08mKT02AGI02099NT0<0
TUf@00`0TUj@09YdY`2KM:H0VgBV09ifY@27IJD0LUbZ021Jd028fOl0Z:OE0<6ne`3Pk]X509=NT004
095MT00k9hh0TVjV0:9iYP<0VW>U00P0W7BU09U`X`2SUlP0Xig?0:^oj02N^>X0d^OU09WNoPH0oooo
1000002M0?ooo`00V03oool2000000@0oooo00<0fZ>L0=FYZ`3IXid01`3_[hP00`2L`O40c<OE0<c7
e@020>NnZ`D0l:n70100kjn709ANS`3`[hL0l:n70>n_Q`2BGHl0TEb?0000E@2AG8l0001J07UOZ@2M
Nj`0QFZ/04A^eP2Q[=l0Ul_j0P2BGI00802AGI00TUf@0000F`0005`0TUf?0000H016=i`0@6?>09n_
hP2QbO@0WKc^01/0001TBYh0001F06I=X@2BGY00001Q095LS`2BGI00101Y0659W`2PNZP0S6^X06]a
a`2UZMT0YZKF0:^ih`21j>T0Tej@099NT02?Fi00DcbI0P2BGY0509YdY`80VgBV00H0WWJU0:FIb@2T
V/`0/<GY09jhjP10`]h709=NT00609Q`X`0E6I@0TVjV0:9iYP2JLjD0Y9_<0P2TV<T00`2U`nl0Y/?^
000000060?ooo`@00000X@3oool009X0oooo00P000000?ooo`3oool0oooo0=ZSW03EZJ/0`9bc0>>g
Z@L0kjn800<0W/3a09k1l@2N`O400P3W_Z/40?2_Q`060>n_Q`2DGXl0l:n70?2_Q`3_[hL0TUf?0P00
05D0202AG8l0001U07UOZ@2MNj`0QFZ/0:>Wf@3?b]D0/L?W0P2BGI008P2AGI00TUf@0000F`0005`0
TUf?0000J@16=i`0PhC<0;B`e@2BGY00KE6Q09=NT01TBYh0001F06I=X@2BGY00001U0000L02PNJP0
RVZX00TNWP2b[M<0[JC>0:o=l02ab^d0TUj@08mKT02BGY00Tej@099NT02?Fi00DcbI09EaZ02PNJL4
09YdY`<0Y9[;00<0YI[;0000002CGY001`2CGY002@2JLZD0VW:T09ieY02HL:<05AVD09>Pg@2`/MT0
[]Cd09W4mP080?ooo`<00000Y@3oool009/0oooo00L000000?ooo`3oool0glc50;j/a`30W;<0jl:Z
0080j;bX1P3_[hP309k1l@030<c7e@3X_Z/0l:n70080l:n700H0kZj809ANS`3`[hL0l:n70>j]R02B
GHl3095LS`070000I@1eJkT0VMWm05nSm@2Kf?d0YjOF0000F@02099MT00S095MT00005/0001L099M
S`000680001Y02Lf[019R>T0Yo?b06oBo01]DJ40Tej@06A:WP0005l0ITfQ099NT00>07L0001`09Yf
Z@2:JZP0M66_0:bYe02UW/h0IE:W099MT02BGY00Se^@099NT02CGY00TUj@08mKT01C?9T0UG6X0:1i
Y`2JM:L00P2TVl`20:C7lP<0oooo1@2CGY0209UaY00709UbY02JLZD0VW:U09YbY02NMJ@0V72S071H
Y`080?ooo`@00000Z03oool009`0oooo00L000000?ooo`3oool0oooo0<?8gP2A^O80c/KC0080j;bX
1P3_[hP03@00ElT0W/7a0<c8eP3=b=H0j;j[0>VmZ03_[hL0kZj80=^RVP3`/8H0l:n70>j]R02BGHl0
0P2AG8l09@2QNjT05Pb30:>ch`2g^]/0V/Og05[@]00O0000001I099MT00005X0TEf@099MT00O4hH0
M5VU0:1jZ01cHk80WZWN0;_<i`2Vlo<0TUj@06eAX@2CGY00001M0000EP2BGI00TUj@00h0M`0L3H40
WZSM0;:/dP2XaNh0Y]3f0140001UDZL0TUf@099NT02?Fi000P2BGY001`2MMJD0Ug2T00PHV02IY=`0
/:_C0:O@m@0A00001P3oool01@2CGY00XGRU09YbY02JLZ@0VG:T0080VG6T00<0VG:T09YbY@2JLZD0
203oool400000:`0oooo002M0?ooo`8000000P3oool00`2R`Nl0Xl;_0:C2kP020>RlZ0L0kjn80180
W/7a09k2lP3=b=D0jKfX0=NXY`2oVK00fj:J0?2_Q`3_[hL0TUf?09QaY00005`0NenW0:5kZ@21IJX0
YZKF0;;1iP2XlOD2099MT00G0000F@2BGI00001J095MT02BGI007a>607AIY@2PNZP0Xic>0:JOc`2O
Y]/0MN77099NT01]DJ40Tej@0000G@0006@0TUj@0:1hY`0>07L0Kena07]lb@2b[mD00P3oool0301a
EZ@0S5V?0696V`2BGY00001V05U1VP2RNZL0WGFU09M`Y02RV</0Xi_=0;:lh@P0oooo00D0U6nV0:5h
YP2JLZ@0VW:T09UbY00209UaY0L0oooo1000002`0?ooo`00W`3oool00`000000oooo0?ooo`030:C2
kP030<o7dP3X_:P0j;bX00H0kjn80100W/?b0=3<eP3AdMX0cM?O0;nI/03KXYX0klFW0=j[X02jTZh0
V76T07IKY@003i/0Y;;R0;;MmP1ne?l0MlSo0P2BGI020000F@09099MT02AGI00TEf@0000H@1;>Y`0
BfkC0:6Zg@2RcoL0Tej@0080TUj@00/0001L06eAX@2CGY00001P04DdV01^DZ40X7RW08EVY`0]MN80
TlKi06C?n@020?ooo`0;075FY00006d0HTJK09UbY@26IJD08DS00;6Zd@2/XL`0Y/O`0:G5l02X`>/0
2@3oool00`2DKjH0XGRV0?ooo`070?ooo`@00000]03oool00:00oooo00L000000?ooo`3oool037SR
0<o7dP2U`nl0clOB0080j;bX1P3_[hP03P0FPNH0YLcd07Jhn`2G^_00_MC[0<7Qk`2lf>h0^Y:^09Qa
Y02<J:@0XJOK0::Yg02M^^d0[kcS102BGI002`0005T0TUf@0000H`2KMZP0PFBW000LX@2PZMd0dlW@
0;c:i@2CGY00001K0080TUj@00X0KE6Q09=NT00006@0ACBH01h^Y`2f/mH0[:cG0:>SeP2__^D0ZNSj
0P3oool02027EHl0001]0696V`2ILZD0QVFU069X``2XY]@0bl?C4P3oool400000;P0oooo002Q0?oo
o`050000003oool0oooo00]hhP2U`nl00P3?am820>RlZ0H0kjn800l0=9?`0:g6k032b^00XLcf0:C3
l02S`^l0XkWX09S8n02JcoX0Vlki0:f/eP2BGY00001N099MT00005P0102BGI002@0006<0VgJX085T
Y`1`HK40YIo?0?ooo`0005d0Tej@0000F`02099NT00906eAX@2CGY00001W04DdV01^Gk00Q;Sg0:FX
f036`mL0[[WR00@0oooo00H0001]01/WX02MX]P0/JO>0:S0j`00000@0?ooo`<00000_03oool00:80
oooo0P0000020?ooo`030:C3k`3?am80clOB0080j;bX1P3_[hP03P3_[XT0[l?X0<?5g02_`^P0YZkM
0:BWf02SY]L0U;S`09nej0000000TUj@0000GP2BGI00001H0P2BGI002`1mGZ@0WgRW07iQY`1?LmL0
/j_@0:7=mP0e0000oooo0000G@2CGY00001K0080TUj@00L0Tej@099NT00006L0KUj`09g?n@1hhnP0
Nmki00H0oooo00@0001V06]I[02a[=<0gOgD3P3oool400000;l0oooo002T0?ooo`030000003oool0
oooo00<0Y<?_0P3X_:P50>n_R0090>n^R@3][HT0[k?K0<C2f02X^^H0W<Gd0>^[RP2CGY00TUf@0080
TUj@00/0001H099MT02BGI00TUf@0000H01mGZ@0WgRW07iQY`2TY=@0/;kT0:oZn0020?ooo`0;0000
G@2CGY00TUj@099NT00106L0MENQ09igY@1]G:h0?f7<0;>]d`2kb>@01`3oool0101]Fj`0@7SO09G2
mP1UcoX:0?ooo`@00000``3oool00:D0oooo00@000000?ooo`3oool01gKP0P2T`nl00`3?am80j;bX
0>RlZ0030>n_R0030>n^R@3][HT0kZj90080l:n80P3[ZhX0102CGY00001F099NT02BGY02099MT008
0000HP2MMZL0O5nV06]N/@2Ke_`0WnCl073<oP2HYMh20?ooo`80001M00T0Tej@0000HP2NMZD0OUnT
07EGX@2NMjD0KEb^0:BLc@3[iLX02@3oool00`32`]T0XL3_0?ooo`060?ooo`@00000a`3oool00:H0
oooo00H000000?ooo`3oool01gKP0:C2k`3?am830>RlZ080kjn80P3][HT00`3^[XT0l:n80?2_R002
0>^[RP0=09=NT00007<0TUj@099NT025I:D0WgNV00/2O02MMZL0WgRV0:BXf@2VaO00WkSY03g1e004
0?ooo`80TUj@00P0001R09]dY@1nGj@0B6WA0::Vf02Ub?80ZKkY03>i^Ph0oooo1000003;0?ooo`00
Y`3oool200000080oooo0P2T`^l01`3?am<0j;bX0>RmZ03_[XT0f:NT0>j^R@3_[hP00P3`[hP20>^[
RP0<09=NT02BGY00TUj@0000GP25I:D0WgNV07YMY@1KXoH0S>7m0:3Vo02_^=l0[?7f103oool02@00
06<0W7BU09ieY00607D0VgBU0:RWe@2RXM@0Xj7C0:nkh`0=0?ooo`<00000c`3oool00:T0oooo00<0
00000?ooo`3oool00`2T`nl0103Y_:H0ikbZ0=RWY03^[XT20?2_R00>0>n_R03[ZhX0jj^:099MT000
07<0W7FV09ifY@25I:D0WGJW0:RXe`2UYmP0VKga00fN]@3^[HP50?ooo`0704diV01mG:40WWFT06QI
[@1:TNh0V];k07cNn@0;0?ooo`@00000dP3oool00:X0oooo01T000000?ooo`3oool0Y<?_0:G2kP2U
`nl0dLSB0;nR^`2oUJ`0jL2[0>VmY`3_[XP0jj^:0:MkX`27HIl0001c09aeYP2NMZD0JEfa0:FZfP2U
Y]L0dL?=0:ngg`2CGi00kZf800D0oooo00P0CCVH07eLX@2g/=80ZJOD0:K3kP2J_>l0WkGX06_Cn@H0
oooo1000003F0?ooo`00Z`3oool04`000000oooo0?ooo`1?Q^H0Z;_W0;7=kP2oX[/0_iF/0<;6g@3[
_J@0jKbV0>>[VP2WNj<0Qf6O06a@X02VZ=L0]:S=0:FKc00000000`2BGY000`3AW9l0oooo0?ooo`04
0?ooo`0304diV01dO<d0NL?n00L0oooo1000003J0?ooo`00[03oool00`000000oooo0?ooo`030?oo
o`0@09C1m@2S`^l0XlGa0=C=dP3SZiX0Yg^S08MQW`1/D:00WiO<0;O0h02Zn>P0QejK08UTX@2BGY00
YX6[0=6LW``0oooo1000003N0?ooo`00[@3oool2000000@0oooo00h0YLoe0=;DfP2XdOD0[L__0:V`
g@29aO`0U<Oi0>Bk[@37WZh0XG:M08MNV`29I:40S6VU09Ie[0T0oooo1000003R0?ooo`00[`3oool0
0`000000oooo0?ooo`030?ooo`0:0;79k035bmh0V/Kf0:Fok02U`^h0a=;T0<NN[P2QLYd0QejK08UT
X@P0oooo0`00003V0?ooo`00/03oool00`000000oooo0?ooo`020?ooo`0605a2VP11X?H0[mKd0:oH
m@2JcOT0//o_203oool400000>T0oooo002a0?ooo`060000003oool0oooo0?ooo`1L@YX0M62^203o
ool400000>d0oooo002b0?ooo`80000000<0oooo0000003oool0103oool400000?40oooo002d0?oo
o`80000000<0oooo0000000000000P00003e0?ooo`00]@3oool200000?T0oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 431}, {349.313, 0}} -> {-0.0754552, -0.00803369, \
0.00375303, 0.00375303}}]
}, Closed]],

Cell["and a density plot of the solution", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DensityPlot[\[CapitalPsi][T, x, y], {x, \(-L\), L}, {y, \(-L\), L}, 
        PlotRange \[Rule] All, PlotPoints \[Rule] {nx, ny}, 
        Mesh \[Rule] False];\)\)], "Input",
  CellLabel->"In[43]:=",
  Evaluatable->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00240385 0.5 0.00240385 [
[.01923 -0.0125 -12 -9 ]
[.01923 -0.0125 12 0 ]
[.25962 -0.0125 -12 -9 ]
[.25962 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -9 -9 ]
[.74038 -0.0125 9 0 ]
[.98077 -0.0125 -9 -9 ]
[.98077 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -24 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -24 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -18 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -18 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-200)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-100)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(100)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(200)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-200)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(-100)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(100)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(200)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
120 string
120 120 8 [120 0 0 120 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E0E0D8DDE2EDF1F3191115ECF1F0EFF019171D1E1717F2F0110D0E1110100F12EEF0EFF0
F1F2F2F0F3F3F0F1F2F2F0151513151317EFF5EE17131215EAEDE9E1DFE8EC0F1213F3F1
13111319F1F3F2F3F3F4F4F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F4F4F4F4F4F3F3F2
F1F1EF151316171715110EE0
E4DBDAE4E9ED16151015EDF2F1EC1316182024201BF2F5ED100D13ECEDECEDEDF0EFEFF1
EFF2F2F2F2F014121313151213121515EFF6F017131414EEF0EEE50A08E9ED0F1215F0F4
ED16121219F3F5F4F4F5F5F5F5F5F6F6F6F6F6F6F6F6F6F6F6F5F5F5F5F5F4F4F4F4F3F0
F2F0F2F0F3F4F5F5F3F0E9E4
E4DFE4E30F11100F15EEF4F0EF1612171C21241F19F5F0100D10EBECE7E9E9EEEFEFF1EF
1411121313161314141313121415F0F2F6F01814161214F0F2EB120B0DEFEF12111114F0
F3EE12131317151415161717181818181818181818181818181817171615151515151315
EFF1F1F2F3F4F5F4F3EFE8E4
E6E9E4100F121014EEF5EE14141315151B1F1C1C18F5F0100C0EECE6E2E30B0E12141517
131413131314141316131114F0F2F5F2F11914161317EFF5EE16131515F0F4EF131213EF
F3EF11121113131416181A1C1C1D1D1D1D1D1D1D1D1D1D1D1D1C1C1B1917161618191814
1613121213151616140F0CE6
EEEB0F0F141114ECF4EE161214121314F2F5191718F1F4EE0F0DEBE5E3E60B11181B1A18
1512141211121114F0F2F1F1F5F2F0161514151318F0F6F018151B1C1616F2F114101015
EDF3F0EF131112131615191B1C1D1D1D1D1D1D1D1D1D1D1D1D1C1B191618161715181817
151312121316191B1A140FEE
F2F110131316EBF1EF1412161215ECEBEFEF14131315F1F20E0EEAEAE7E90E151E201B19
1211ECEEEFF0F1F0F3F3F1F3F015141314131415EFF7F119151B1D1C1816F1F5EE151010
15EFF1F4F0F1F0F1EF1514161718181819191919191919181818171416F1F3F015131514
131111111217171E201A14F2
F4F3121315EEEFEEED14161516EAECE7E6ECEC141313F4F20F0D12E8EDEB11131D1E1DF4
F0E8EAEAEEEEF1F3F3F11513151213131016EFF1F5F0191518171B1A151217EFF6EF1510
111315F0F2F0F2F0F2F0F3F5F5F6F6F6F6F6F6F6F6F6F6F6F6F6F5F4F1F3F1F3F1F3F4F3
F2EFEEEDEFEF1A191F1C16F4
F4F3131212EFECEA11131817EEEDE6DFE0EAED101216F2F3130E0E13EBF3EE19171A18F3
EDE5E4E4E8111216181A15151311120F10EBF2F4EF1915171418F1F0150F0F15EFF6EF15
101212151214EFF1F1F2F3F4F5F6F6F6F6F6F6F6F6F6F6F6F6F6F6F5F4F2F1F2F3F4F4F3
F0F0EDEAEAEEEE161A1A16F4
F4F3121210EDEBEB0F161815F0EAE10405E6EB11111317F4F016111015EDF5F1171617EF
EDE5DE0A0B10181D1F1E1A191211EAEBE9F0EFF01A16191415EAEDECE8120F0F15EFF6EE
141312141513151312131315161718181819191919191919181818171716151516161613
14EEEEE8E9E9EB14151815F4
F4F3121110EDEBEC10171915F0EBE40405E3EFED141415F1F7F114141215F2F216131416
EAEBE9E40D131D24272320F6F1E8E7E5E9E61116181D1919EBE9E0DFE7E70E0F0F15EFF5
F1F015141314141312121315181A1C1D1D1D1D1D1D1D1D1D1D1D1D1C1C1C1B1B1B1B1A18
1516110FE4EAECED151514F4
F3F2101010EEECEB0F161918F0EFE7080207E7EE10141316F3F216141615F0F5F0151412
14E9EEEB0E13182126231FF4F2E7DFDFE10B0E1820201EF3F0E4D9D6DDE20B0E0E0F15F0
F1F5F2F0141212121111131615191B1C1D1D1D1D1D1D1D1D1D1D1D1D1D1C1C1C1B1B1A1A
1A19160F0FE8EBEF121313F3
F2F0120F12ECEEEA1011181617ECF0E30704E1E710111515F1F6F116171416F2F1141215
1214EBF1EEEF19161D1F191AECEBE2E0E10B0F1A21211FF5EEE9E0DADAE0E3E8110E0F13
14EFF2F5F1F2F2F1F0EFF0EF151416171818181919191919191918181818181716151516
19171A1610EEEDEE111213F2
F2F2EE120E11ECEEEA1513171315EBEEE2DADEE5E711141316F2F216141716F0F4ED1612
151215EDF2F3EE161818191415EBE7E8E9E713141B1E1A1713EAE9E2E3E1E3E9E7110E11
101315F0F3F3F2EFF1EFEFF1F0F3F4F5F6F6F6F6F6F6F6F6F6F6F6F6F6F6F5F5F3F1F0F1
F01A161815EEF0EF101213F2
EFF2F00F0F11ECEFEFEC1613161214E9E9DED6DBE40F111515F0F6F116161415F0F2ED16
13151216EFEFF3F0F018131512110FE7EEF0EC151716171512120E0EE6E6E8E7EBE71011
1011111413121113EEF0EFF0F2F3F4F5F5F6F6F6F6F6F6F6F6F6F6F6F6F6F5F4F1F2EFEE
F1EF15171414EFF0101215EF
14F0EF110E0F13EBF1F2EE1713151112E3E1D4D3E1E610131316F2F215131515F0F3F3EE
161214121313EDF3F3ED141412130F14EDEFF3F1F01513151212120F100FE8E9ECEDEBEB
11110F111112131214121111121314151617181818181919191918181818171415EFEFEA
EEEE15141513F2F013111214
14F0F4EC130E0E14EEEFF4EF1713140F0EE3DAD0D9E20D0F1314F1F6EF18131318EFF0F4
EE151412121015EFEFF3F0EF161113121314EFF2F5F1F1EF13131112120F1010EAECEFEE
EBE90E0D0F1210121212121212131416181A1C1C1D1D1D1D1D1D1D1D1C1C1B1A1617110F
ECF1EF161616F0F4EF131214
1216EDF3EC130E101313EEF6F01712120FE6E3D5D2DFE111101217EEF5F01313131414EE
F6F2F0151412111313ECF2F2EC13131214131516F0F1F2F1EEED12111310110F1111EBEB
EDEBE5E7E9E80E0D101111111112131615191B1C1D1D1D1D1D1D1D1C1C1C1C1C1C1A1613
EEF2F112151414F0F0141112
131113EFF1EB1310131117F0F6EF16100F10E0DED2D6E4E710121014F1F0111312141217
F1F2F6F3F11811121015EEEFF2EFEF16111516141515EEEFF1F1EEF0EE13121011101110
E7EAE4E1E0E3E3E9EEF0F1F1F0EFF1EF15141617181818181818181716161619171A1A15
15F1F014131512F2F2EE1313
111413EEF1EFEA1411151317EFF5EE150F0C0CE1D8D0DAE30D0E1213EFF3EFEF16111413
1516F1F3F7F1161512111312ECF2F2EC1314131616141414EFF0EEF2F2F0EE131311120F
11E7E8E0DAD8DEE6E9EEF0EFF1EFEFF2F0F3F4F5F5F5F5F5F5F5F5F4F3F2F1EF15171818
16F0F5F0151416F0F3EF1311
16131216ECEFEFEA1412151214F0F3EE120F0EE4E1D2D3E1E2100E1015EDF2F2ED131413
15141617F2F5F5F31811121015EEEFF2EFEE141413161613151113EEF1EFF3EFEE151012
0F12E8E4E2DBDDE00A0D1014F0F2F0F1F2F3F4F4F4F4F4F4F5F5F4F3F0F1EEEEEDF11617
1516F2F215131317EDF3ED16
EF14141215EBEFEFEB15121414EFF3F0130F0E0EE3DBD4DCE7E7120E0F15EEEFF3EFEF16
121617151718F2F9F2171512111312ECF2F1EEEE14141314141312141112EDF3F2EC1212
100F100EE3E6E4E50A0F15161A17151313131313131313131414151314EDECECEBED1414
1716F1F5F014141114F0F3EF
F11412151215EBEFEFEB15121216EDF4EF12100FE6E4DED8E6EDEA130F101313ECF3F3ED
1314141717151BF4F6F5F31811121015EEEEF0F1EEEE131113151214141116EFEFF3EFEF
1510120F11E7ECE90F101A20201E1A16141211111111121213151718151511E7EBECEC14
171516F2F114111414F0F4F1
F5EF1713161215EBEFF0ED13131114F1F114110F0EE7E208E2EAF1EC1410131116EFEFF3
EFEE15151518161818F2F9F2171512111313EDEEF1F2EFF1F2EF15141314131413EDF3F3
EE1612141113EBF2EC16162026241C1A13100F0F0F0F0F101215151A1C191110E9EAEC14
151715EFF3EC16131418EFF5
F0F6EF1713151214EAEFED12111414EFF5F015110FEEEB080B0EEEF3ED151113121413ED
F2F1EFEF17131717141AF3F6F5F3181112111213EEF1F1EFF2F3F1F0151513141116EFF0
F5EF1713151215EDF4EF1A1A23211EF5F1ECEAEAEAEBEBECEEED15181B1E1812E8EBEEF0
19191412ECF0EF15171519F0
18EFF5EE1612151112EDEFEA15121214F1F4141211F1F00F1013F1F1F5EE141412141116
EFEFF1F2ED14141416151718F2F9F1161411121114131114EFF1F0F5F2F1171114131414
EFF6F01813151114F0F4F1181C1D19F4EDE6E3E5E7E9E9E9E9ECEEF31C1E1B1011E7EFF1
1A1A150EEBEDEF18181B1618
1414EBF2EC15131413ECEFF0EF151311F3F3131313F3F31417181916EFF5F0EF16111413
1414EEEFF3EFEE14141416141BF3F5F4F114131113141413151214EFF2F5EE1414131412
17F0F6F017131414EFF3F115151918F0EDE4E2E0E6E9EAE8E5E8ECF2171C1B15ECEFEE16
161A1311E9EBF3F11F1F1C14
140C0CE7EDEB12141213EEF0F2131312F3F4131313F4F5171D221E1719EFF4F3ED131413
14131413ECF2F1EEEE171317161717F1F6F1EE13111513151414121414EEF4EFEE161216
1317EFF5EF17131316EDF3EE18141416E8EAE3070A0E0E0C0AE6ECF1161A1813F0F1EE15
191814ECEEEEED1A191E1B14
120B07DFE4E710111414EFF4F3141312F3F4141314F4F5182028261F1719F0F0F3F0EF17
1215151216EEEEF0F1ED161217171418EFF4F2EFF1EF1412141613141115EDF1F1EC1513
171315F1F4F014141114F0F3F015151111ECE90C0C1315110DECF0EF18191515F0F01514
181314EFF0EB151318171912
F2ECE2DEDAE4E610131419F2F7161311F3F4141414F4F5181F26241F1B151514EEF4F4EE
15151314131312EBF1F2EC141515171418F0F1EFF2F3F0F2F4F21711131014EBF0F0EC17
141615F0F3F013111414EFF3F115131513EDF1EC12171A1510EFEF14141716F0F5F01516
1417EEF3EC1410121618F2F2
EFEAE6DBD3DAE30D0F14141DF4181114F1F4141413F4F5181D20221C1B16151319F1F2F5
F2F0151413131115EEEFF3F0F018131514161214F0F2F2F2F1F5EE1313100F13EAF0F1EF
15161417EDF3ED16131317EEF4F015161213EFEF15151A1514F0F213151416F2F2151314
18EEF4ED140F1017F2F4F2EF
0C0DE2E3D7D5E0E1100F14141A1212EFF5F1161312F4F5171A1FF8F8F41A1A18181918F1
F2F5F1F0161113121313EDF3F3EE1515131515131614141214EEF4EFEE140F0E13EBF2F0
1412161214F0F3EF14151214F1F215131412F1F2EF161617F1F5F0151515F0F5F0151516
F1F3F0130F1116F0F6EF120C
130C0FE2E2D7D8E3E30F1110101211F1F215121215F3F6181A1CF9F7F7F6F921201F1A19
17EFF4F3ED131412141116F0F1F4F2F016151315151516151215EDF1F1EB14101015EDF4
EE16131514EFF3F015131615F0F5F0141415EFF2F1121313F3F114121315F1F014131513
F2F3EE131213F0F5EE150E13
F4160E0FE0DFD7DDE6E9EB1011EEF0F5F0141314F0F6F31C1D20F8F7F6F8FA242629261F
171AF0F0F3F0EF161114131515F0F2F5F2F0151214161416151114EBF0F0EE12131115EE
F4EE17131316EDF3EF15161314F0F115121213EFF00F0F10F1F1111315F0F3F213151415
F0F014121215F2F1130F16F4
F718140E0CE1DFE1E0ECEFEEEFF4F1F017111115F3F41A1B2321201917191F20282C2A26
20181614EDF3F3ED14141315141616F1F2F5F1F2F2EF141215110F13EBF1EF1311151114
F0F3F014141113EFF015141513F1F3EF151311F1EE0F0A0CEFF1111213F2F3F0161616F0
F4EF141415F0F5EF12111AF7
F81818140DE9E8DF0DEAF0F2F3F01514111116EFF7F31B222927201A17171A1D20222220
1E1B171216EEEFF3F1F018131617151617F1F3F0F3F2EEF0EE140E0E13ECF3ED15121414
EFF3F015131411F1F2EF161516EFF2F2131314EEF1E7070AEBF0111213F2F014131513F2
F014131512F2F0131016F5F8
F61718150FEDEA0D0B141415151612121016F0F7F21D1C2629231B1B1716171819191919
191A1514111212EEF1F5EF151514171715171315EFF1EEF0F0EA120E0E13ECF3ED161313
16EDF3EF141415EFF2F112151313EFF011131111EAE407DCEBEF121212F3F212151314F0
F111141314F0F0101215F6F6
F516171312EDEE0F141A1B181614121314EFF7F11B19212420191DF4F6F5F5F5F6F6F6F6
F6F21612130F0E1112EEF5F2F016161416161613151112EAEFEFEA130F0E12EFF2EF1414
1113EFF015121213EFEF14131411F0EE1312120DE8E3D6E0E8EA131312F3F3131415EFF2
F0121415EFF1F0111314F5F5
F5151515EEF0EF1219201E18171214EFF1F6F019161D1F1A1A18F1F7F2F3F4F5F5F5F4F4
F2F6F2F3F013110E0E14EFF1F5F2F0151316141515141114EBEFF0ED111011ECF1EE1312
1311F1F3F0151312F1F2EF161411EFF0EE14110DE6DDD5DBE20E101311F2F2121313F1F0
F1131413F1F0F1131314F4F5
F4141412F0EEEF131A1F191BF0F1EFF4F1F01814191A161AF2F3F6EF1412131414141312
15F1F3F1F5F1EF140E0E1113EEF1F5F1F3F014121514151215EBF1EE110E0F11EDF0ED13
1314EFF3F2141515EFF3F2141311EFEEEF11100DE5DACED8E30C111113EFF1121212F1F2
EF161513F1F2EF151414F4F4
F4141311EEEDEE13191A17F0F2F0EFEE14131214141615EEF5F1F0171113141414141413
12151214F0F1F5EE12110E0E1113EFF2F0F3EFF0EE1612151215ECF2EB140E10ECF0EE13
121113F0F213161415F1F3131313F0EEEE100F0CE5D8CBD8E40C1013EDF0EF111212F2F0
15141714F2F014131513F3F4
F4151311EEEDEF13171515EEEEE810121010141214EFF0F3F01213111217151413131416
121313121414EEF5F1EE12100E0E121012ECECEEEEEA1413161213EFF2EE120E11EDF1EF
141210F1F212161713F3F4141516EEF1EF100F0CE5D8C9D8E40C0F10EFEEEE111213F3F3
13171814F3F212151416F2F4
F2171512EFEEF0131515EEEEE80D0C111016F0F2F0F2F2F0F114121619F3F5F3F3F3F3F0
14121613141217F0F1F4F0EE12100E0F0E0E0CE1E8EBEA17151614EDF1F0101012EDF2F2
131211F1F014141714F4F415171414EFF0100F0CE4D8C9D8E40C0F0FEDEDEE111213F4F4
15181713F2F2131417F1F6F2
16151713F0F1EF161412EEEAE7090C0E14EEF5F0F1F2F016171519F6F2F4F2F1F1F1F0F4
F0F2F1171214131415EFF1F3EEEC11100D0B050ADDE5EEF119191312EDEE13111113EFF2
121211F0F2F0171614F4F516191712F1F1110F0CE4D8C9D8E40C0F0FEDEEF0121314F4F4
15171414EFF1121315F4F216
14191A15F3F014141510EBE7E4060B10EDF5EE1210121615191918F4120C0C0C0D0D10ED
F1F0F5EE14141213121414EDF2F0EDEB0F0A0ADDE3E5EEF11A19140EEDF1F0161311F2F3
121211EFF0F3151514F4F516191712F1F1110F0CE4D8C9D8E40C0F10EFF1EF161515F4F4
141516EEF1EF111314F4F414
161B1B16F4F31316150FE9E3DD08E5EEF4EE151012131B181A1614F10E0A0A0B0D0B0B0F
0E10ECF4F1EF151413141116EEEEF0F0EBEAE6E8E7ECEB1816181110EBF1F0171412F3F3
131211F0F2F0161514F4F415171414EFF0100F0CE4D8C9D8E40C0F10F1F014151816F5F4
141312EFEDEE101213F4F516
171C1C17F5F415171311E6E1E0E0EEEEEF161011151AF419131412F0EDEBEAEBE90E0C0E
0B0B12EEF0F4F1F0171214131414EEF0EDEFEEEAEDED1613171314EAEFEE15141512F3F3
131312F1F014131512F3F4141516EEF1EF100F0CE4D8C9D8E50C1011F2F213181A17F5F4
131211EDECED101213F4F517
181C1C18F5F5151718EFECE4E4EBE91213111017F2F6F31114EFF1EFECEFECEBECE9ECEA
0F0D0B0F11EEF1F5EE1414131413151213F0EF12111514161315EBEFF0EE15161415F2F4
141312F2F212151314F1F3131313F0EEEE100F0CE4D8C9D8E50D1012F3F4161B1B17F5F4
131210ECEBEC101213F4F518
181C1C18F5F516181AF2F2EDEAEC1411131116EFF6EE100FEBF4ED1111EDEFEDEAEDECED
EBEA100B0C1012EDF5F1F01711141514131616131516161215ECF0F0EC17141615F0F5F1
161311F2F3131416F0F3F3141311EFEEEF11100CE4D8C9D8E50D1012F4F5171C1C17F5F4
131210ECEBEC0F1213F4F518
181C1C17F5F5161A1A1DF3F0141413151216EEF5EC0F0AE9F1EF13111317141112EDEEEB
EEEEE70E0E0D0D14EFF1F5EE131215121414141515121413ECF1F1EC1513171315F2F215
121114F1F4141413F2F3F0161411EFF0ED13100CE4D8CBD9E50D1012F4F5171C1C18F5F4
13120FECEBEC101213F4F518
171B1B16F4F4161C1F1B1C191416151215EDF4EC11080DEBF0EE15191D1C1A1714151111
EAEFEEEBEB110C0D1012EDF4EFF1EE12101010100F12EDEFF2EFEE1612161317EFF6F014
1213EFF5F1161311F1F015131411F0EE1211110CE3D8CEDAE60D1012F4F5171C1C17F5F4
131210ECEBEC101213F4F517
171A1913F3F3141A201F1B1816131413ECF2EF100A0DEAF0EE15161D1E1C1A1919181612
15EDECEEEFE80F0F0D0D13EEEFF1F1EDEDEDEDEDECEBF0F2EC131312141217F0F6EF1611
1013F1F216121214F1F313151313EFF01113100EE2DAD5DDE70D1012F3F4161B1B17F5F4
131210EDECED111213F4F517
16181514EFEF0F13181916171213EEEFF2EFEE0F0B0FEDF2EF1518191B17151517151717
141312EAEFEEEBEB120C0D1011EDEFEDEFEDECECEDEFEEEE161113121414EEF6EF150F0F
14EDF5F0141314F0F5F1171616EFF2F1121312EAE8E0D5E3E90E1112F2F313181A17F5F4
131210EEEDEF121314F4F516
151617EFEFE80C0D111214EFF1EEF1F1EB100F0B11EBF3ED17141717F2F1EFF0EF141514
16151115EDECEEEFE80F0F0D0D110F11EDEFEEEEF0EE141412141116EFF0F4EE150F0E13
ECF4EE17131215F2F217151613F1F3EF151210EDEADA06E4EC0F1111F1F014151816F5F4
131211EFF1EE161514F4F515
151616F2ECE8E6EBEEF0EFF2F1EEEFED130C0C11EAF2ED1513161213EDECEBECEFEEED14
141214121211EAEFEEECEB100F0E10101412121213161314131413EDF3F3ED140E0E13EB
F1EF13111414F0F5F116171415F0F115121112EDEA0905EAEF101110EFF1EE161515F4F4
131312F1F014141715F4F515
151718F1F0EAEAECEFEEF0F1ED110F110D0C11EAF1EF1311151214E9EDEBE8EAEAEFF0EE
ED141412131015EDEDEFEFECEB111110121415171616151216EFEFF2EFEE150F0E13EBF0
F1EE13131115F2F216141615F0F5F0151415EFF2EA0B0AEEF0111110EDEDEF121314F4F4
131313F3F213171814F4F415
161A191BF0EFEEEFED120F11120E0F0D0F10EAF1F1EE13131114EAEEEEE70F0D11ECEEF0
F1EEEE161113121313EDEDF0F0EDEC121115131514161313EDF3F2EC1212100F14ECF1F1
EB14101116EFF6F116151215F1F216141513F2EF100B0DF0F111110FECECED111213F4F4
131313F3F414181719F3F416
171D201A19141111131011100F110F11ECEEF1EEEE16101014EAEFEFEA131013121414EE
EEF1F2EC13141214131413EDEEF1F1EEF0EF131014F1F3F1F4F0EF150F110F14EEF4EFEE
140F0F15EEF6F018141317EEF4F015161315F1F10F0E0EF0F111110FECEBEC101213F4F4
131313F4F414171CF1F7F417
171E24211B1613121210131011EDEFEDF1F2EC1213100F13EAEFEFEB1512171918161314
14EEEFF3F0EF17121516131414EFF0EFF2F2F0F1F1F5F1F3F0141310101213EDF5EE1313
100F14EDF4EE17131514F0F3F115141615F0F4EF110D10EEF112110FECEAEC0F1213F4F4
131313F3F313171618F3F417
171C201D161613111012EEF0EEF1F1EEF0EF1611131014EBF0EFEB151217161919141616
131414EDF3F3EE151514161614151214EFF2F2F3F4F115121511121015EEF0F4EE161113
1014ECF2F01412151214F0F4F015151215F1F1130E10ECF1F112120FECEAEC0F1113F3F3
131313F2F115141614F4F517
1517171716EFF1F0F0EFF2F2EEF0EF13121513141115EDF1F1EC1512161318F1F0141413
16161317F0F1F4F2F016151415151513161413131416121312111313EDF3F3EE16121512
16EDF2F2EF13131216EEF4EE17131418EFF5EF110D11EDF1EF151310ECEBEC101213F3F3
131313F2F3F0161515F5F515
131117EFEFF0EFF1EFF0F1EF141215131514121414EEF4EFEE1612151216ECEFEEECEC14
151417151616F0F2F6F2F0151316131514141313131312141113EFF0F3F0EF1611141216
EFF4F0EF16111015EDF4EE16131515F1F5ED140E10ECF1EF14131410ECEBED101213F3F2
111315EFF3F2131416F6F513
100FEDF1F0ECEFEE1311131613151515131515F0F2F5EE141412141115ECEFEBE9EBEEEE
EF17131617141616F1F2F5F0F2F0141213131313131113EFF1F0F4F1EF141311111314EE
F6EE1413110F14ECF2F01412151215F1F0110D0D11EEF2EF1517140FECEDEF121313F2F0
13111113EFF1111418F4F610
0D0FEDF1EB121216141515141513161214F0F2F5F2F1171214131414EDF3ECECECECEBF0
F2ED1515141717151616F0F1F3F3F0F2F3F4F4F3F3F2F0F3F3F0EF141311110F15EFF0F5
EF1712131014EBF0F1EE14141317EEF4EE0F0C13ECF4ED1714161111ECEFEE161514F2F2
EF141211F1EF14131419F20D
10EAF1EC15131718171416131214EFF1F0F5F2F1161513141116EFF0F4ED120F101012EE
F0F4F1F01515141716141515F0F2F2F3F3F3F3F3F3F3F2F2EF14131112101212ECF3F3EE
1713161215ECF0F0EC16131317EFF4EC110A12EDF5EE1511141215ECF1EF15151816EEF1
F1121212F2F3F0161516F310
0EEEEF13131A1B161515EFF2F1EFF3F3F1F016161415131413EDF3F3EE16121617161315
15F0F1F4F0EF151513151412151312121213131313121213151212111213EDEEF2EFEF17
13161316EDF2F1EC15121414F0F4EB100911ECF5EE150F101313EDF3F0F117191A1210EC
EF101214EFF3F2141516F20E
0CEDF213181B1618EFEFF1F2EFF1F2F015151416161217EFF0F3F0EF1713181919191817
141514EEF3F3F1EF1412151212121212111111121212121212111313EDEEF1F2EC131413
151217EFF4F0EE1612141114F1EF0F0910ECF4EE150F0F15EEEFF3ED13151619160F0EEA
EC12111214F0F3131416F10C
0FEEF017191618EDF1F0EEEE13111315121415131514EEF3F3ED13141315151815151714
16151217F0F2F0F4F0F1EF1310111110100F0F10101112121114EFF0F2F1EEEE16111413
1414EEF6EE141312131115EDF3EC0C0CECF3ED15101014ECF1F1EC14101313171211E6EB
EEEE151312F2F3131414EF0F
ECEF14141716EFF1F0EB12131314141312151214F0F1F4F0EF161114131414EFF1F1EF14
14131413161214EFF0F3F3F0F1F0EFEDECECECECEDEFF1F2F2F1F5F0F1EF131312141116
EFF0F5EF161113111212ECF3EA0F080EEEF013111313EEF1F0EB130F111416F1F2EEEEEB
EFF3161514F4F4131313F1EC
F0F012161415EFF0EB1411151513151113EFF1F0F5F2F0151513141116EFEEF0EEEEEFEE
ED1313121414131415F0F2F2F1EFF0EDECEBEBECEDF0EFF2F3F4F11512151112111314ED
F3F3EE1612141014ECECF0E80D070DE8F2EE13131113EFF1EB130E0F16F0F2F5F0F0EFEF
F2F51B1715F4F4131312F0F0
F1EF161617F0F1EE121216141514EEF0EFF2F3F1F016151415131413ECF2F0ECECECEBF0
F0EEEE1414131414121514131214EEEFEDECECEDEFEE1412141517141514121314EFF1F4
F0EF1712141012E7EBEBE30A050CE6EFEE13111217EEF4EC130E0F15EFF5F2EF13101113
161D1C1B16F5F4131312F0F1
F014141714F2F2EE14161518EEEEF0F1EFF1F016161417161217EFF0F3EFED120F0F11EC
EEF1F2F0EF1412151213151616141512101010101215141617161515131414EEF0F4F1EF
141412120E10E4E7E3D8060509E4EDF0EE131314F0F5ED140F0F15EFF6EE141312131416
1A1E211C17F5F4131312F2F0
F213161612F1EF13131716EFF0EEECED141317151717141515EEF3F3ED13141315151213
13EEF1EFF4F0F1EF131215141616141312111112131516171417141214EFF0F2F3ED1414
121310100DE1E3DCD30404E1E7ECEFEC16131315F2F113101016EFF6EF16101313171619
181D1F1B15F4F4131313F3F2
F414161414EFF011161612EFEDEB101314181917151616F0F2F4F0EF1712161717171513
11141113EFF0F2F2EFF1EF1513141413121212121314141315F0F2F1F0F4F0F1F0161113
130F11E7E3E0D7D5DBDDE3EBEEECEE17131616F0F5EF131214F0F5EE1611121416F2F6F3
1919171511F2F3131313F4F4
F4141516EFF1F012151313ECEEEC13171B19151616F0F2F5F2F015141315131614121214
111213121314EFF1EFF2F3F1F3F4F4F3F2F1F1F2F3F4F4F3F1F3F3F0F2F0141214121210
100DE2E5DCD6D5DBE3E5EBEEED131415181612F2F013111215F2F214101218F1F3F1F1F2
F3F2110C0FEEF1131313F4F4
F4141313F0EFEF121415EEEFEC12141B191816EFF0F4F2F016151314131414EEEFEEEEEB
111110121311141114F0F3F3F4F4F4F3F1F4F4F1F3F4F4F3F3F2EF1311151213120F100E
E6E3E1DAD8DBE2E3E60E0E1115131617161011EEF0101316F1F5F0141315F1F6EC0D0E0E
EBEF0B0AE4EEF0131414F4F4
F4131311EFEFF0131313F1EFEF12171A18F2F0F2F3EE15151415141116EFEEEFEBEAE9EA
E8E70E0E12111313131715151516151417F3F418151515141313141112121210100EE6E3
E2DCDADCE2E3E50E0F101313141513151110E8EFF0121314F4F214121316F3ED0F0FEA0B
0CE9E4E1E7ECED151514F4F4
F4131311F0F1EF151413F0F1EF17191616F0F1EEEF17131515121211EBF2ECEAE8E6E3DE
E3E5E4EAEB121217151718181919191A191E1F1A1B1916141312110F12100D0EE6E4E2DA
D6D9E0E2E50E0F0E11131216141213EEEEE9ECEEF1141414F4F3121316F2F20F0DEFF40D
09E6E3DFE4E912131614F4F4
F4141312F1F014141613F1F014151917F0F2EE10141416131211E9EAEFE70C0909060306
D8DDDFE4EBEDF3F41C1B1D1E1F2022262224262521211A1513100D0EE9EBE9E5E5DCD5D2
D8E2E00D0F0E1010131114F0F3F2EFF0EDECEEEEF2181615F4F3131314F4F10D0FF6F20F
09E5E1E0E9EA13161613F3F4
F4141312F2F212161612F2F212171713F1F2ED1315171214EAE6E6E6DE0A07080B0808DC
E3E0E1E5EBEDF3F7F7FAFBFCFCFDFEFD322C2E2B2BF9FAF6F2EEEAE4E6E4DDDCD5D8D6DB
E5E30F0D11101212EEF0F0F4F0F1F1EFEEEFEE1518191815F4F3131313F3F10D11F1170C
0AE6E4E7E61312171314F2F4
F2161211F2F314161414F0F214171415EFEF1413181314E7E7DEDAD50605090DEAEDEAED
E7E7E9ECEB121216191C1E1F1F212328262B2D292126F7F5F0EFE9E3DED4020002D6E3E4
E7110E110F14EDEEF1F1F0EF13101111111216151A1D1813F2F2111214F3F0100C130E0A
0CE7EAE6110F131216EFF6F2
18121012F1F4141515EFF3F2141516F0F3F113161517E9E8DDD5D4DBDEE7ECEDF2EEF0ED
100D0E10131113141617181819191B1C1F2121201D19191413EBE9E8E2E0D9DBDDE8E40E
100F101212ECF1F1EEED131311121212121315181918130FEFEF0F1115F1F4EC10090C0C
E4EDE60F0C0F1213EEF6F018
121216EDF4F0161311F1F2EF161514F2F3F0171819F0EEE4DEDCDDE2E9EAEFF1EF131214
111212121211151414151516161617171818181819151514111111EAEAE6E9E9ECE8120F
121015EEEFF2EEED12121112111513131313141515130E0CE8E90E0E1016EEF3E80EE4E5
EAE90D0B0C13EDEFF4EF1712
1413EFF3F014121112EEEF14131512F2F116161B19F5EFEAE4E5E7EAEA11101315131415
141214121013EFF2F3F4F4F5F5F5F5F5F5F4F3F3F0151315121210120F10ECF0EE161214
1216EEF3F2EC12121012111314EFF2F2F3F3F4F4F3F1EDE5E4E5E3110F1015EDF1E6E6E4
E8E60C0A10E9F0F1EE171314
1113EFF3EF131212EDF1F012141314F1F3151B1F1EF6F4ED0F0D0E101311131414141315
1213EFF1F0EFF2F3F1F3F4F4F4F4F4F4F3F1F3F1F2F0F2F0151311131312161517141613
17EFF5F0EF150F11111314EFF0F2F3F0F2F3F4F3F3F0EBE8E0DEE6E710121116EDE9E6E4
E60C080FE7EDEEEB16131611
15ECF2EC16121113EEF1EE141414EEF4F0191E231E1C17151112121212131215121113EE
F0EFF2F2EFF1F2EF14121313131314131214EFF1F0F1F0F5F1F015141315171717161217
F0F6EF141411111314EFF1F4F0F1EF1311131313120F0FE4E5DDDFE40E0F1413110DE7EA
E70C0DE9ECEBE81413171315
ECF0EE13111413EDF0EE13121213EEED12141E221F1A161514121412111013EEF0EFEEF2
F2EFF1EF13111315131414131313131415131613121113EFF1F5F1EF14141214121314EF
F6F01712141116EFF0F4F1EF131114121313131312110D0FE2E3DDE2E2111115120EEDEB
0E0B0DECEAE80F11181617EC
F0EEEC13151314EDEFEC131414EDEEEA0B101719171815131113EEF0F0F0EEF1F0F1EEF0
EF131215121313141413151211111215131414131313111415EFF1F3EFED110D10ECEFF4
EF1814161317EEF3F3ED131311121312151414141314100D0EDFE0DCE4E513131411F1F0
0E0E0EEBEAEA0F161918EFF0
ECEA11121716EEEFEB11121513EEE9E3090C101215F0F3F2F1EFF1F0F1EFF0F0F1EE1312
15131414121513121113EEEFEEEEEFEE1312131314161213111313ECF2EFEAE9E8EEF1EE
1714171418F0F5F0EF16101212151214F0F3F3EFF3F0160F0C0ADDD8DAE7EB131312F2F2
10100EEBEAEC11181915F0EC
EBEB0E151815F1EEEC0F151612ECE5E2E1E8EDEFEFF3F3F0F1F1F0F1EF13111213151315
1515131415EFF2F2F1EFF0EEECECEEF0EFF2F3F3F4F1151412121015EEEDEDE9E9EEEB16
13171419F1F7EF141412121415F0F2F0F3F3EB10ECF2EF130E0AE2D8D2DFEA101212F3F3
11100FEBEBED12181914EFEB
EBEB0E141715F1EEEC0F141713EEE6E0E2E8EEEEF0F2EF14111212131513161615141413
151214EFF0F3F3F0F1F0EFEEEDEDEEEFF1F2F3F3F1F5F2F0151411111312EAEFF0EC1613
171419F1F7F11812141217F1F2F5F0F1F2EF110AEBEFF112100CE3D8CEDBE70E1112F3F3
12110FECEBED12181914EFEB
ECE910111616F0F1EC11111616EFEEE8EAEAEB1211131613141413131415161416131113
EFF1F0F4F0F1EF1310111110101010111212121114F0F2F5F2F11712141217F2F2191417
1419F1F7F11914161317F0F6F1EF131013150F0EEDF0EE14110CE4D8CCDAE60D1012F3F3
11110FECEBED12181A15F0EC
EFEDE915131316ECF2EC16141519F0F0EC121212141515151315121112121214EFF1EFEE
F2F3F1EF14121512131312121212121213131313121415F0F2F6F0171317171B1B171815
19F1F7F11915171418F0F6EF1412101816181410EFEE1311110CE3D8CFDAE60D1012F3F2
101010EEECEC10171B19F0EF
ECEFF0EE14141113EFF2EF1517171915151213141316141214EEF0EFF0F1F1EFF1F0F1EE
F1F01515131514131614131313131313131314161213121415EFF6F01814191B1B1A1519
F1F7F11915181418EFF5EF1611121DF61E1A1414EFF01113100EE2DBD5DDE70D1113F3F1
130F12ECEEEB12141B1718EC
16ECF2EF13111313EEF3F016151B1B181512151214F1F3F2EFF1EFEFF1EFF1F1F1F1EF14
1317141616131516F1F4F4F4F4F4F4F4F4F4F4F1161513141116EFF6F0171216161318F0
F7F11915181418EFF5F215121517F6FB1C1817F0F2F2131313EAE8E1D6E3E80D1115F0F5
EF120F11ECEFEC14181A1416
1315EDF4EE16111115ECF3F0161819151514EFF1F0F4F1F2F1F0EFF0EF14121313131513
161716131415F0F2F5F1F3F3F4F4F4F4F3F3F2F5F2F01711131116EFF5ED110F0F12EEF6
F01914171519F0F6F2F216151318F8F61B1714F2F3EF151412EFEBDC08E5EA11101114F1
F2101011EBEFED1212171813
141115EEF5EF17121011EEF00F111116EFEFF1F2F0EF1411121111131514161614131415
15131414EEEFF4F1EF14121313141413131214F0F1F5EE1313101015EDF2EBEBEBECF3EF
1713171419F1F7EF1516141319F2F71B161612F1F014131411EFEB0B08E8F1EE141312F3
F1120F0E11EDEFEA12141414
14121115EEF6F215120FEEEB0B0B0FEBF1F1EEEE14141314141313131516161415121111
1012EDEDF0F1EC1313121314141313131313121313EDF4EFEE140F0F13EAEDE9EAEFEC16
12151318F0F7F01713151318F1F8F418161213F0F213151314F0F00E0C10EFF2121316F1
F5EE150F10EDF0EFEEEE1414
F018121013F1F4141210EDEAE5E8EAF0EEED1313121415131613131314141214EEF0EEEE
EEEDF0EFF0EC15111313161514141414141612121014ECF1F1EB14100F11ECECEEEB1512
141615EFF6F01713161318F1F7F21A151417EDF4F0151414F0F5F0151312F3F114121318
EFF5EF110E14EDEEF1F2F0F0
F4F1161311F3F4141311EDE9E6E9EEEA1112101212151314F0F2F2F3F3F3F2EFF0EEEDED
EFEDEFF1F01712131516F2F5F4F4F4F4F4F11514110F13EBF0F1EE121113F0F5EE161315
15F2F2F5EF1611141217F0F7F119141615F0F3F014121215F2F217161918F2F5F0141412
15F2F1130F101213EFF0EFF4
F0F4141313F4F4141414F1EEECEBEC140F11111315F0F2F0F3F3F0F2F3F3F2F1EFEEEEEF
EE13111418161615F2F2F2F2F3F3F4F3F2F6F2F0160F0E13EBF1EF1311131DF31D151713
15F2F4EE1510111314EFF7F11915171315F1F3EF131214F0F6F1181D201918F3F2141214
15F1F5EE14101213161110F0
F3F4141313F4F415171AF5F4EF131311111314EFF1F5F0F1F2EF13111212121110101011
141317191A191314F0EE0E0E1113131215F0F2F6EF150F0E13ECF4EE18161A221C1B1518
EFF5EE150F0F14EEF0F5F01915181418EFF5EE16111014F2F3181821231D18F1F5EE1713
1318EFF5ED131516181411F3
F4F4141314F4F5161B1C1E191914141116EFF0F4F1EF1311121411121211111110101011
13151718181412ECEFEC0B0D10131415141515EFF6EF150F0F14EEF6F31B1F23211A1BF1
F6EF150F0E13EBF1F2EE1814171519F0F6EF17111116EDF5F1181C202A1F1717F1F3EF14
151317EEF3EFF2181A1814F4
F4F4141313F4F4161C23221E1B171216EEF3F3ED131311121312111411100F0F0F0F0F0F
10111212120F0EEAECE90D0E1113161417171318F0F6EF17111013F2F61A2026201AF3F7
EF16111014EBEFF0EC1614171519F1F7F017121413EFF3F117171C2CFB251B18F0F3EF13
12161213EEF0F113181915F4
F4F4131313F3F2131A22231E171614EEF4F0EF1610121215131113EDEFEDECEBEBEBEBEB
ECEDEDEEEFEEEBEDE8ECEFF1F2F2F0151615171317EFF6F2161312F3F51920241B1AF4F3
15121313EEF0F0EB1513171419F1F7F01813151113F0F3F1181B23FCFF231F1818ECF1EC
16141614EDEFEC13141715F4
F4F4131312F1EF13141B1A1519F0F1F4EE141411111314F0F3F1EFF0EDEBEBEAEAEAEAEA
EAEBECEEEBECECEC0C10F0F3F1F3F2F0F01814161113F2F4151413F4F5191F211DF4F7F1
15141113EFF1EB1412161419F1F7F01712151114ECF3EE19191F26FDFD26221D1210EBF0
EF16171312EBEEEE151514F4
F4F4131211EEEFEA0F0F1414EDF3F3EE1612141116EFF0F4F1F2F1EFEDECECECEBEBEBEB
EBEBECE90D090DEF1111181617F0F0F3F4EF17121210F3F4141414F5F6181E1E1AF6F315
121317EDF3EB1310131218F0F7F01611120F12EAF0EA14141D2221252520221C120BE8EB
EE12161510ECECEF121314F4
F4F4131210ECE9E60A0DEBEEF3F0EF1713151317EEF4F3EE1412121110100F0F0F0F0F0E
0E0D0C0D090C11F4191C201E1A1918F1F2F5EF150D0FF3F5151414F4F6181D1E19F6F412
1416F1F4EB120E101415F0F7F0171010110FE5EAE50B0B141A1D1D1C1B1C1A14110BE3E7
EA14151611ECEBED101213F4
F4F4131210ECE7E5E3E7EEF1EC131413151217EFF5F1F018131616141212111111111110
0F0C0E0C10EEF5F61F242C2D28221A1917F0F7EE1111F4F4181413F4F6191E1D18F5F413
1415F4EF0E0A0D15F0F3F7F118111014EAE6E4E0DE070B111517181817161413EBE7E5E5
EFEE1B1611EDEBEC101213F4
F4F4141413EFE9E6E8EDECED151114131515EFF6EF151616191815161312121212121211
0F11EDF0F0F6F21F1E2B363D372F2821181CF2F7F3F4F31B151315F3F61A1E1E18F5F413
1415F4EF0D0B10EEF6F3F31B151417EBEBE2DBD9E0E4ECF1F4F5F6F6F5F5F3EFEFEAE7EA
EE18171712EDEBEC0F1213F4
F4F4151617F1F2EBEDEC121212141218F1F3F6F018131717151616F0F2F2F3F3F3F3F3F2
F1EFF3F0F2F11A18222B31343432302C241B1FF5F7F51B141515F1F7F41D211E18F5F312
1418F3F5EFF0F1F6F0181A1A1C1CF4F2EAE3DFE0E4EBEDF2F4F5F6F6F5F5F3F1EFEDECF0
F2191B1812ECEAEC0F1113F4
F4F41519191EF11511141112111415EFF6F3F1191417151616F0F1F3F2F0F2F3F3F3F3F2
F1F1EE12111413191D2123232425282B2C271F1F1B1A15151215F3F41A1B241F18F4F115
14161DF3F5F4F5F31C181F242220F7F3EDEAE8E9ECEC1313161717171715141211101114
1A1B1E1811EBEAEB0F1213F4
F4F3141A1F1C1F161513111314EFF2F6EF161614151318F1F2F4EFF0EE12101212121110
0E0E0F0D0F1015161718191A1A1C2121292E29221C17131414EEF6F31B21272018F3F3F0
191B1B1C1816161A19202528251E1C15110F0F0F111414181A1C1C1B1A18151311111215
191D1C140DE9E9EB0F1213F4
F4F216171F201C18131313EEEFF4F2F1191315141514EEF5F1EE1210121011121212100E
0F0E0E0F0F12EFF3F4F5F5F5F5F6F522202A2A21181615EEF0F5F01A1A24282119F3F2F3
171E23201B1816171A1D20201F1C1815131211121315171A1B1C1C1B1815161211111215
141613110CE4E7EB101314F4
F1F5F0161819151514EDEEF1F2ED141615171317F0F0F3EC11100E100F13131313121011
EDF0F0F1F1F0F3F3F1F3F3F3F2F1F7F61F2222181AEFEFF1F2EE17141B2125201BF1F3F3
171E24211919161516181919181716141413131313141617171717161315EFF0EEEEEFEE
131012EBE7E6E7ED121517F1
15F0F00E0E1314EEEEF1F0EEEE161216161317EEF3F2EB110C0D121013F0F3F3F3F3F2EF
F2F2EFF1F2F2F2EF131111100D0EF2F71B1C181AEEF1F0EEEE1510131A1D1C1D1716F1F3
171D20191BF2F3F3F4F5F5F6F6F5F5F4F4F4F4F4F4F4F5F5F5F5F5F4F3F0F1EEECECEDF0
EEF0EEEFEAE8ECF115181515
11EEEA0A0DEBEEF1F1EEED13131214131515EFF4EFED110A0F12EFF2F1F5F1F3F3F3F3F2
F2EF1411121313151112100D0E0FF3F41A1716EFF1F0EA1212100F15F1F31C171713F3F4
161A191CF0F4F2F0F2F4F4F5F5F5F4F4F4F4F4F4F4F4F4F4F5F5F4F4F3F1EFEEEDEDEDEF
F1F1F1EFEEEEF2F41C1C1811
11EBE8E2E6EEECEFEE13131112111415F0F2F6EE13100B12EDF0F4F0F2F0141213131312
131513141413131211141012EFF3F21B151415EFF0EA1310120F12E9EEF0F0161514F4F4
15171AF3F4EEEC1110121414141414141414141414141414141414141312111010101011
111212131314171D1E201911
0EE7E2E1E1E30C0E141314121313EEF0F5F2F218110F14EDF4F0EE121115131414131212
131414131613121113EFF1F0F6F119141614EFF1EE1210131012E7E9E4E8EE121313F4F4
141517F6F00D0D0D10121314141414141414141414141414141414141313121212121212
12131416181A1C1F221F160E
0CE0DCD406080C1314161216EEEEF1F3EF1718171614F0F4EC11110F1112131215121111
12121214F0F2F2F1F0F2F3F1F11914161314F0F3EF13131113E8EAE3E0E5EB101213F3F3
111317F3F20E0D1012131414141414141414141414141414141414141414131313131212
12131614181A1C1D1C180F0C
E0E0D8DDE2EDF1F3191115ECF1F0EFF019171D1E1717F2F0110D0E1110100F12EEF0EFF0
F1F2F2F0F3F3F0F1F2F2F0151513151317EFF5EE17131215EAEDE9E1DFE8EC0F1213F3F1
13111319F1F3F2F3F3F4F4F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F4F4F4F4F4F3F3F2
F1F1EF151316171715110EE0
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[43]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00:03oool6000000@0oooo100000050?ooo`@00000A@3oool7000000<0oooo100000050?oo
o`@00000B`3oool4000004h0oooo1`0000030?ooo`@000001@3oool4000004H0oooo1P0000040?oo
o`@000001@3oool4000000@0oooo000X0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`010?ooo`00:@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`010?ooo`00:P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`010?ooo`007`3oool6000000H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`0i0?ooo`H000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0040oooo000/0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0040oooo000X0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`010?ooo`00:03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0@`3oool3000000D0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04`0oooo0`0000050?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0040oooo000Y0?ooo`@000001@3oool4
000000D0oooo100000180?ooo`030000003oool0oooo00@0oooo100000050?ooo`@00000B`3oool4
00000540oooo00<000000?ooo`3oool0103oool4000000D0oooo100000170?ooo`@000001@3oool4
000000D0oooo100000040?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00:03o
oooo0000088000001`3oool002P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo000:0?ooo`H00000103oool4000000D0oooo100000070?ooo`030000
003oool0oooo0?l0ooooOP3oool00`000000oooo0?ooo`050?ooo`002P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooogh0oooo00<000000?ooo`3o
ool01@3oool000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0
ooooOP3oool00`000000oooo0?ooo`050?ooo`00303oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0
oooo1000003o0?ooog/0oooo0`0000070?ooo`0000<0oooo000000000000100000060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`H0h>3P0`3Hf=P30=gMg@<0
h^;R0`3]kNd30?7al@<0lo?c0`0I6AT4014A4@<05ADE0`3/k>`30?7al@<0l?3`0`3_knl30?3`l0<0
6ATI0`0G5aL301dM7@<07QhN1`0G5aL30?;blP<0l?3`0`0A4A4300d=3@<03Ph>0`0A4A46010@40<0
3`l?0`0B4Q840>k^kP<0l?3`0`3_knl30?3`l0<0lO7a1P3bl_830?3`l0H0lo?c0`3`l?030?7al@L0
l_;b0`3`l?0601DE5@<04a<C0`0E5AD301<C4`<05aLG0`3_knl30?Gem@@0k^k^0`0G5aL301<C4`<0
4Q8B0`0E5AD30>[ZjP<0kNg]0`3YjNT30>7Qh@<0gmoO0`3Xj>P30>c/k0@03`l?0`0B4Q8301<C4`<0
lo?c0`3alO4301<C4`<04A4A0`0C4a<301TI6@<0lO7a0`3clo<30?;blPL0lo?c1P3dm?@d0?GemA00
m?Cd1P3clo<30?;blPH0lO7a0`3_knl301DE5@<04a<C0`0F5QH701LG5`<05ADE0`0A4A4300h>3P<0
h>3P1P3oool00`000000oooo0?ooo`050?ooo`003P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool60>3Ph0<0f=SH0`3MgMd30>;RhP<0kNg]0`3alO430??cl`<0
6ATI100A4A4301DE5@<0k>c/0`3alO430?3`l0<0kno_0`3`l?0301TI6@<05aLG0`0M7Ad301hN7PL0
5aLG0`3bl_830?3`l0<04A4A0`0=3@d300h>3P<04A4A1P0@410300l?3`<04Q8B103^k^h30?3`l0<0
kno_0`3`l?030?7al@H0l_;b0`3`l?060??cl`<0l?3`0`3alO470?;blP<0l?3`1P0E5AD301<C4`<0
5ADE0`0C4a<301LG5`<0kno_0`3emOD40>k^kP<05aLG0`0C4a<3018B4P<05ADE0`3Zj^X30>g]k@<0
jNWY0`3QhN430=oOg`<0j>SX0`3/k>`400l?3`<04Q8B0`0C4a<30??cl`<0lO7a0`0C4a<3014A4@<0
4a<C0`0I6AT30?7al@<0lo?c0`3bl_870??cl`H0m?Cd=03emOD@0?Cdm0H0lo?c0`3bl_860?7al@<0
kno_0`0E5AD301<C4`<05QHF1`0G5aL301DE5@<04A4A0`0>3Ph30>3Ph0H0oooo00<000000?ooo`3o
ool01@3oool000X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool60>3Ph0<0f=SH0`3MgMd30>;RhP<0kNg]0`3alO430??cl`<06ATI100A4A4301DE
5@<0k>c/0`3alO430?3`l0<0kno_0`3`l?0301TI6@<05aLG0`0M7Ad301hN7PL05aLG0`3bl_830?3`
l0<04A4A0`0=3@d300h>3P<04A4A1P0@410300l?3`<04Q8B103^k^h30?3`l0<0kno_0`3`l?030?7a
l@H0l_;b0`3`l?060??cl`<0l?3`0`3alO470?;blP<0l?3`1P0E5AD301<C4`<05ADE0`0C4a<301LG
5`<0kno_0`3emOD40>k^kP<05aLG0`0C4a<3018B4P<05ADE0`3Zj^X30>g]k@<0jNWY0`3QhN430=oO
g`<0j>SX0`3/k>`400l?3`<04Q8B0`0C4a<30??cl`<0lO7a0`0C4a<3014A4@<04a<C0`0I6AT30?7a
l@<0lo?c0`3bl_870??cl`H0m?Cd=03emOD@0?Cdm0H0lo?c0`3bl_860?7al@<0kno_0`0E5AD301<C
4`<05QHF1`0G5aL301DE5@<04A4A0`0>3Ph30>3Ph0H0oooo00<000000?ooo`3oool01@3oool000X0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool6
0>3Ph0<0f=SH0`3MgMd30>;RhP<0kNg]0`3alO430??cl`<06ATI100A4A4301DE5@<0k>c/0`3alO43
0?3`l0<0kno_0`3`l?0301TI6@<05aLG0`0M7Ad301hN7PL05aLG0`3bl_830?3`l0<04A4A0`0=3@d3
00h>3P<04A4A1P0@410300l?3`<04Q8B103^k^h30?3`l0<0kno_0`3`l?030?7al@H0l_;b0`3`l?06
0??cl`<0l?3`0`3alO470?;blP<0l?3`1P0E5AD301<C4`<05ADE0`0C4a<301LG5`<0kno_0`3emOD4
0>k^kP<05aLG0`0C4a<3018B4P<05ADE0`3Zj^X30>g]k@<0jNWY0`3QhN430=oOg`<0j>SX0`3/k>`4
00l?3`<04Q8B0`0C4a<30??cl`<0lO7a0`0C4a<3014A4@<04a<C0`0I6AT30?7al@<0lo?c0`3bl_87
0??cl`H0m?Cd=03emOD@0?Cdm0H0lo?c0`3bl_860?7al@<0kno_0`0E5AD301<C4`<05QHF1`0G5aL3
01DE5@<04A4A0`0>3Ph30>3Ph0H0oooo00<000000?ooo`3oool01@3oool000/0oooo100000050?oo
o`@000001@3oool4000000L0oooo00<000000?ooo`3oool01@3oool30>CTi0<0fm_K0`3Jf]X30>CT
i0<0jNWY0`3]kNd301HF5P<05ADE0`0@410401DE5@<0kNg]0`3bl_830?7al@<0k>c/0`0C4a<301HF
5P<061PH0`0P820302@T90<0820P0`0K6a/40?;blP<0mOGe0`3]kNd3010@40<03@d=0`0C4a<30>c/
k0<0kNg]0`3/k>`60>g]k@@0l?3`1P3_knl30?7al@<0kno_303bl_830?3`l0<051@D0`0B4Q8701<C
4`<05ADE0`0B4Q8301<C4`<04Q8B1P0E5AD30>o_k`<0m_Kf0`3`l?0401LG5`<04a<C1P0D51@30>k^
kP<0l?3`0`3^k^h30>GUi@<02PX:0`0820P30>WYj@<0kNg]100?3`l3018B4P<05ADE0`3`l?030?Cd
m0<0kNg]0`0F5QH6018B4P<06ATI0`3clo<30?Gem@L0m?Cd3`3emODR0?KfmPl0mOGe3@3dm?@30??c
l`<0l?3`0`3bl_830?3`l0<0l_;b0`3`l?030??cl`<0m?Cd1`3emOD30??cl`<0l?3`0`3YjNT30>CT
i0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool30>CTi0<0
fm_K0`3Jf]X30>CTi0<0jNWY0`3]kNd301HF5P<05ADE0`0@410401DE5@<0kNg]0`3bl_830?7al@<0
k>c/0`0C4a<301HF5P<061PH0`0P820302@T90<0820P0`0K6a/40?;blP<0mOGe0`3]kNd3010@40<0
3@d=0`0C4a<30>c/k0<0kNg]0`3/k>`60>g]k@@0l?3`1P3_knl30?7al@<0kno_303bl_830?3`l0<0
51@D0`0B4Q8701<C4`<05ADE0`0B4Q8301<C4`<04Q8B1P0E5AD30>o_k`<0m_Kf0`3`l?0401LG5`<0
4a<C1P0D51@30>k^kP<0l?3`0`3^k^h30>GUi@<02PX:0`0820P30>WYj@<0kNg]100?3`l3018B4P<0
5ADE0`3`l?030?Cdm0<0kNg]0`0F5QH6018B4P<06ATI0`3clo<30?Gem@L0m?Cd3`3emODR0?KfmPl0
mOGe3@3dm?@30??cl`<0l?3`0`3bl_830?3`l0<0l_;b0`3`l?030??cl`<0m?Cd1`3emOD30??cl`<0
l?3`0`3YjNT30>CTi0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
1@3oool30>CTi0<0fm_K0`3Jf]X30>CTi0<0jNWY0`3]kNd301HF5P<05ADE0`0@410401DE5@<0kNg]
0`3bl_830?7al@<0k>c/0`0C4a<301HF5P<061PH0`0P820302@T90<0820P0`0K6a/40?;blP<0mOGe
0`3]kNd3010@40<03@d=0`0C4a<30>c/k0<0kNg]0`3/k>`60>g]k@@0l?3`1P3_knl30?7al@<0kno_
303bl_830?3`l0<051@D0`0B4Q8701<C4`<05ADE0`0B4Q8301<C4`<04Q8B1P0E5AD30>o_k`<0m_Kf
0`3`l?0401LG5`<04a<C1P0D51@30>k^kP<0l?3`0`3^k^h30>GUi@<02PX:0`0820P30>WYj@<0kNg]
100?3`l3018B4P<05ADE0`3`l?030?Cdm0<0kNg]0`0F5QH6018B4P<06ATI0`3clo<30?Gem@L0m?Cd
3`3emODR0?KfmPl0mOGe3@3dm?@30??cl`<0l?3`0`3bl_830?3`l0<0l_;b0`3`l?030??cl`<0m?Cd
1`3emOD30??cl`<0l?3`0`3YjNT30>CTi0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool01@3oool30>CTi0<0gmoO0`3Ti>@30>?Sh`<03`l?0`0A4A43010@40<03`l?0`0E
5AD40>k^kP<0m?Cd0`3`l?030>o_k`<05QHF0`0B4Q8301LG5`<071`L0`0Q8B4302@T90<07alO0`0I
6AT40?Gem@<0l?3`0`0@410300d=3@<0410@0`3[jn/30>c/k0<0inOW1P3YjNT30>k^kPL0kno_0`3a
lO430>o_k`<051@D0`0A4A43018B4PH04a<C0`0F5QH301<C4`L051@D1P0C4a<3018B4P<051@D0`0E
5AD30?3`l0<0l_;b0`3fm_H30?3`l0<061PH100D51@301HF5P<04Q8B0`0D51@30?3`l0<0l_;b0`3[
jn/3018B4P<02`/;0`0=3@d60>o_k`@04Q8B1P0A4A4301@D50<0l?3`0`3clo<30>k^kP<04Q8B1P0C
4a<301LG5`<05ADE100D51@301DE5@<05QHF1P0G5aL[01PH60H05aLG0`0F5QH@01DE5@<04a<C0`0E
5AD30>o_k`H0lO7a0`3bl_830??cl`<0m?Cd103emOD30?Cdm0<0lo?c0`3_knl30>SXj0<0i>CT1P3o
ool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0i>CT0`3Ogml3
0>CTi0<0hn?S0`0?3`l3014A4@<0410@0`0?3`l301DE5@@0k^k^0`3dm?@30?3`l0<0kno_0`0F5QH3
018B4P<05aLG0`0L71`3024Q8@<092@T0`0O7al301TI6@@0mOGe0`3`l?03010@40<03@d=0`0@4103
0>_[j`<0k>c/0`3WinL60>WYj@<0k^k^1`3_knl30?7al@<0kno_0`0D51@3014A4@<04Q8B1P0C4a<3
01HF5P<04a<C1`0D51@601<C4`<04Q8B0`0D51@301DE5@<0l?3`0`3bl_830?KfmP<0l?3`0`0H61P4
01@D50<05QHF0`0B4Q8301@D50<0l?3`0`3bl_830>_[j`<04Q8B0`0;2`/300d=3@H0kno_100B4Q86
014A4@<051@D0`3`l?030??cl`<0k^k^0`0B4Q8601<C4`<05aLG0`0E5AD401@D50<05ADE0`0F5QH6
01LG5b/061PH1P0G5aL301HF5Q005ADE0`0C4a<301DE5@<0kno_1P3alO430?;blP<0lo?c0`3dm?@4
0?Gem@<0m?Cd0`3clo<30>o_k`<0j>SX0`3Ti>@60?ooo`030000003oool0oooo00D0oooo000X0?oo
o`030000003oool0oooo00D0oooo0`3Ti>@30=oOg`<0i>CT0`3Shn<300l?3`<04A4A0`0@410300l?
3`<05ADE103^k^h30?Cdm0<0l?3`0`3_knl301HF5P<04Q8B0`0G5aL301`L70<08B4Q0`0T92@301lO
7`<06ATI103emOD30?3`l0<0410@0`0=3@d3010@40<0jn_[0`3/k>`30>OWi`H0jNWY0`3^k^h70>o_
k`<0lO7a0`3_knl301@D50<04A4A0`0B4Q8601<C4`<05QHF0`0C4a<701@D50H04a<C0`0B4Q8301@D
50<05ADE0`3`l?030?;blP<0m_Kf0`3`l?0301PH60@051@D0`0F5QH3018B4P<051@D0`3`l?030?;b
lP<0jn_[0`0B4Q8300/;2`<03@d=1P3_knl4018B4PH04A4A0`0D51@30?3`l0<0lo?c0`3^k^h3018B
4PH04a<C0`0G5aL301DE5@@051@D0`0E5AD301HF5PH05aLG:`0H61P601LG5`<05QHF400E5AD301<C
4`<05ADE0`3_knl60?7al@<0l_;b0`3clo<30?Cdm0@0mOGe0`3dm?@30??cl`<0kno_0`3Xj>P30>CT
i0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool30>KViP<0
jNWY0`3Ti>@3010@40<03`l?0`0B4Q83010@40<051@D0`3^k^h40?Gem@<0k^k^1P0D51@301<C4`H0
5ADE0`0K6a/301lO7`H071`L0`0H61P40?Gem@<0l?3`0`0@410300`<30<03Ph>0`3/k>`30>KViP<0
h^;R0`3Shn<300/;2`<03Ph>100B4Q8301@D50<05ADE0`0G5aL301<C4`<051@D2@0C4a<601@D50<0
4a<C100F5QH301<C4`<04A4A0`0D51@30?3`l0<0l_;b0`3emOD30?;blP<0lO7a0`0I6AT301@D50@0
5QHF0`0C4a<301LG5`<0kno_0`3emOD30>k^kP<05QHF0`0C4a<601DE5@<0l?3`0`3dm?@40>o_k`<0
4a<C0`0B4Q8301<C4`<0kno_0`3clo<30>o_k`<04A4A0`0B4Q83014A4@H04a<C100D51@301HF5P<0
61PH0`0J6QX601`L72D07AdM1P0L71`301/K6`<06ATI0`0G5aL701HF5P<061PH0`0I6AT301PH60<0
51@D0`0F5QH301<C4`H04Q8B0`0C4a<301DE5@L05QHF0`0D51@300l?3`<030`<0`3Vi^H60?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3Vi^H30>WYj@<0i>CT
0`0@410300l?3`<04Q8B0`0@410301@D50<0k^k^103emOD30>k^kPH051@D0`0C4a<601DE5@<06a/K
0`0O7al601`L70<061PH103emOD30?3`l0<0410@0`0<30`300h>3P<0k>c/0`3Vi^H30>;RhP<0hn?S
0`0;2`/300h>3P@04Q8B0`0D51@301DE5@<05aLG0`0C4a<301@D50T04a<C1P0D51@301<C4`@05QHF
0`0C4a<3014A4@<051@D0`3`l?030?;blP<0mOGe0`3bl_830?7al@<06ATI0`0D51@401HF5P<04a<C
0`0G5aL30>o_k`<0mOGe0`3^k^h301HF5P<04a<C1P0E5AD30?3`l0<0m?Cd103_knl301<C4`<04Q8B
0`0C4a<30>o_k`<0lo?c0`3_knl3014A4@<04Q8B0`0A4A4601<C4`@051@D0`0F5QH301PH60<06QXJ
1P0L71`U01dM7@H071`L0`0K6a/301TI6@<05aLG1`0F5QH301PH60<06ATI0`0H61P301@D50<05QHF
0`0C4a<6018B4P<04a<C0`0E5AD701HF5P<051@D0`0?3`l300`<30<0i^KV1P3oool00`000000oooo
0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0i^KV0`3YjNT30>CTi0<0410@0`0?
3`l3018B4P<0410@0`0D51@30>k^kP@0mOGe0`3^k^h601@D50<04a<C1P0E5AD301/K6`<07alO1P0L
71`301PH60@0mOGe0`3`l?03010@40<030`<0`0>3Ph30>c/k0<0i^KV0`3Rh^830>?Sh`<02`/;0`0>
3Ph4018B4P<051@D0`0E5AD301LG5`<04a<C0`0D51@901<C4`H051@D0`0C4a<401HF5P<04a<C0`0A
4A4301@D50<0l?3`0`3bl_830?Gem@<0l_;b0`3alO4301TI6@<051@D100F5QH301<C4`<05aLG0`3_
knl30?Gem@<0k^k^0`0F5QH301<C4`H05ADE0`3`l?030?Cdm0@0kno_0`0C4a<3018B4P<04a<C0`3_
knl30??cl`<0kno_0`0A4A43018B4P<04A4A1P0C4a<401@D50<05QHF0`0H61P301XJ6PH071`L9@0M
7Ad601`L70<06a/K0`0I6AT301LG5`L05QHF0`0H61P301TI6@<061PH0`0D51@301HF5P<04a<C1P0B
4Q8301<C4`<05ADE1`0F5QH301@D50<03`l?0`0<30`30>KViPH0oooo00<000000?ooo`3oool01@3o
ool002P0oooo00<000000?ooo`3oool01@3oool30>k^kP<0jn_[1P0?3`l301@D50<04A4A0`0D51@3
0>c/k0<0m?Cd103^k^h301HF5P<04Q8B0`0D51@3018B4P<04a<C0`0D51@30?;blP<0mOGe0`0I6AT3
01LG5`<061PH103alO430?Cdm0<0k^k^0`0?3`l300d=3@<0jn_[0`3UiND30>?Sh`<0i^KV0`0;2`/3
014A4@@061PH0`0K6a/301XJ6P<061PH0`0E5AD3018B4P<051@D0`0B4Q83014A4@<04Q8B0`0A4A43
01@D50@0l?3`0`3bl_860?7al@<0mOGe0`3bl_830?3`l0<05QHF0`0E5AD301@D50<05ADE100C4a<3
01PH60<0l?3`0`3fm_H30?3`l0<061PH0`0E5AD301/K6`<071`L1P0F5QH30?;blP@0lO7a0`0D51@6
010@40<05ADE0`3]kNd30??cl`<0l?3`0`3_knl301<C4`<04A4A0`0B4Q8401<C4`<05QHF0`0E5AD3
01TI6@<06a/K0`0L71`U01dM7@<071`L0`0K6a/301TI6@<05QHF0`0H61P401HF5P<05aLG0`0E5AD6
01PH60<05aLG0`0E5AD301<C4`H04Q8B0`0C4a<301HF5P@06ATI0`0K6a/301XJ6P<051@D0`0?3`l3
0>k^kPH0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool30>k^
kP<0jn_[1P0?3`l301@D50<04A4A0`0D51@30>c/k0<0m?Cd103^k^h301HF5P<04Q8B0`0D51@3018B
4P<04a<C0`0D51@30?;blP<0mOGe0`0I6AT301LG5`<061PH103alO430?Cdm0<0k^k^0`0?3`l300d=
3@<0jn_[0`3UiND30>?Sh`<0i^KV0`0;2`/3014A4@@061PH0`0K6a/301XJ6P<061PH0`0E5AD3018B
4P<051@D0`0B4Q83014A4@<04Q8B0`0A4A4301@D50@0l?3`0`3bl_860?7al@<0mOGe0`3bl_830?3`
l0<05QHF0`0E5AD301@D50<05ADE100C4a<301PH60<0l?3`0`3fm_H30?3`l0<061PH0`0E5AD301/K
6`<071`L1P0F5QH30?;blP@0lO7a0`0D51@6010@40<05ADE0`3]kNd30??cl`<0l?3`0`3_knl301<C
4`<04A4A0`0B4Q8401<C4`<05QHF0`0E5AD301TI6@<06a/K0`0L71`U01dM7@<071`L0`0K6a/301TI
6@<05QHF0`0H61P401HF5P<05aLG0`0E5AD601PH60<05aLG0`0E5AD301<C4`H04Q8B0`0C4a<301HF
5P@06ATI0`0K6a/301XJ6P<051@D0`0?3`l30>k^kPH0oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool01@3oool30>k^kP<0jn_[1P0?3`l301@D50<04A4A0`0D51@30>c/k0<0
m?Cd103^k^h301HF5P<04Q8B0`0D51@3018B4P<04a<C0`0D51@30?;blP<0mOGe0`0I6AT301LG5`<0
61PH103alO430?Cdm0<0k^k^0`0?3`l300d=3@<0jn_[0`3UiND30>?Sh`<0i^KV0`0;2`/3014A4@@0
61PH0`0K6a/301XJ6P<061PH0`0E5AD3018B4P<051@D0`0B4Q83014A4@<04Q8B0`0A4A4301@D50@0
l?3`0`3bl_860?7al@<0mOGe0`3bl_830?3`l0<05QHF0`0E5AD301@D50<05ADE100C4a<301PH60<0
l?3`0`3fm_H30?3`l0<061PH0`0E5AD301/K6`<071`L1P0F5QH30?;blP@0lO7a0`0D51@6010@40<0
5ADE0`3]kNd30??cl`<0l?3`0`3_knl301<C4`<04A4A0`0B4Q8401<C4`<05QHF0`0E5AD301TI6@<0
6a/K0`0L71`U01dM7@<071`L0`0K6a/301TI6@<05QHF0`0H61P401HF5P<05aLG0`0E5AD601PH60<0
5aLG0`0E5AD301<C4`H04Q8B0`0C4a<301HF5P@06ATI0`0K6a/301XJ6P<051@D0`0?3`l30>k^kPH0
oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool30?;blP<0lO7a
0`0@410601<C4`<05QHF0`3[jn/30?7al@<0kno_100D51@3018B4P<05QHF0`0B4Q8301DE5@<0k>c/
0`3[jn/60>o_k`<051@D1P0C4a<401DE5@<0lO7a0`3bl_8600h>3PH0j^[Z0`3WinL30>WYj@<03Ph>
0`0E5AD401hN7P<0820P0`0K6a/301TI6@<04Q8B0`0A4A430>c/k0<0k^k^0`3_knl30?3`l0<0lO7a
0`3`l?070??cl`<0lO7a0`3clo<30?3`l0<05ADE0`0D51@301<C4`<051@D0`0C4a<301@D50@05ADE
0`3_knl30?Ogm`<0lO7a0`0I6AT301DE5@<06a/K0`0M7Ad301`L70<061PH0`0F5QH30?7al@@0mOGe
0`3^k^h301DE5@H0410@0`0E5AD30>o_k`<0lO7a0`3dm?@30?3`l0<0lO7a0`3`l?040?7al@<0kno_
0`0E5AD301@D50<05QHF0`0G5aL901PH61H06ATI2@0H61P301LG5`<051@D0`0F5QH30?7al@@0lo?c
0`3`l?0301DE5@<04a<C0`0E5AD301@D50<04a<C2@0A4A43018B4PL05aLG0`0N7Qh3020P80<06QXJ
0`0D51@30?;blPH0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3o
ool30?;blP<0lO7a0`0@410601<C4`<05QHF0`3[jn/30?7al@<0kno_100D51@3018B4P<05QHF0`0B
4Q8301DE5@<0k>c/0`3[jn/60>o_k`<051@D1P0C4a<401DE5@<0lO7a0`3bl_8600h>3PH0j^[Z0`3W
inL30>WYj@<03Ph>0`0E5AD401hN7P<0820P0`0K6a/301TI6@<04Q8B0`0A4A430>c/k0<0k^k^0`3_
knl30?3`l0<0lO7a0`3`l?070??cl`<0lO7a0`3clo<30?3`l0<05ADE0`0D51@301<C4`<051@D0`0C
4a<301@D50@05ADE0`3_knl30?Ogm`<0lO7a0`0I6AT301DE5@<06a/K0`0M7Ad301`L70<061PH0`0F
5QH30?7al@@0mOGe0`3^k^h301DE5@H0410@0`0E5AD30>o_k`<0lO7a0`3dm?@30?3`l0<0lO7a0`3`
l?040?7al@<0kno_0`0E5AD301@D50<05QHF0`0G5aL901PH61H06ATI2@0H61P301LG5`<051@D0`0F
5QH30?7al@@0lo?c0`3`l?0301DE5@<04a<C0`0E5AD301@D50<04a<C2@0A4A43018B4PL05aLG0`0N
7Qh3020P80<06QXJ0`0D51@30?;blPH0oooo00<000000?ooo`3oool01@3oool002P0oooo0`000005
0?ooo`<0l_;b0`3alO43010@40H04a<C0`0F5QH30>_[j`<0lO7a0`3_knl401@D50<04Q8B0`0F5QH3
018B4P<05ADE0`3/k>`30>_[j`H0kno_0`0D51@601<C4`@05ADE0`3alO430?;blPH03Ph>1P3Zj^X3
0>OWi`<0jNWY0`0>3Ph301DE5@@07QhN0`0P820301/K6`<06ATI0`0B4Q83014A4@<0k>c/0`3^k^h3
0>o_k`<0l?3`0`3alO430?3`l0L0lo?c0`3alO430??cl`<0l?3`0`0E5AD301@D50<04a<C0`0D51@3
01<C4`<051@D100E5AD30>o_k`<0moOg0`3alO4301TI6@<05ADE0`0K6a/301dM7@<071`L0`0H61P3
01HF5P<0lO7a103emOD30>k^kP<05ADE1P0@410301DE5@<0kno_0`3alO430?Cdm0<0l?3`0`3alO43
0?3`l0@0lO7a0`3_knl301DE5@<051@D0`0F5QH301LG5`T061PH5P0I6AT901PH60<05aLG0`0D51@3
01HF5P<0lO7a103clo<30?3`l0<05ADE0`0C4a<301DE5@<051@D0`0C4a<9014A4@<04Q8B1`0G5aL3
01hN7P<0820P0`0J6QX301@D50<0l_;b1@3oool2000000L0oooo000X0?ooo`030000003oool0oooo
00D0oooo0`3dm?@30??cl`<04Q8B0`0C4a<301DE5@<0k^k^0`3_knl30>k^kP<0kNg]100D51@301HF
5P<05ADE0`0F5QH30>[ZjP<0k>c/0`3WinL30>KViPH0k>c/0`0D51@701<C4`<0m?Cd0`3bl_8300l?
3`<03@d=0`0B4Q830>SXj0<0kNg]0`3[jn/3014A4@<04a<C100M7Ad301hN7P<07AdM0`3dm?@30?3`
l0<0j>SX1P3Zj^X60>k^kP<0lO7a1`3clo<30?7al@<05ADE0`0C4a<301DE5@<04Q8B1P0C4a<3010@
40<05QHF0`3_knl40?7al@<0mOGe0`3`l?0301TI6@<05ADE0`0H61P301LG5`<06a/K0`0J6QX301DE
5@<04Q8B0`0G5aL40>o_k`<0m_Kf0`3_knl301DE5@<0410@0`0A4A4301<C4`<05ADE0`3`l?030?;b
lP<0l?3`0`3bl_840?3`l0<0l_;b0`3`l?030??cl`H0mOGe:03fm_H30?Gem@<0m?Cd0`3alO430??c
l`@0lO7a0`3clo<30?7al@<0lo?c0`3dm?@30??cl`<0l_;b0`3_knl30>k^kP<0kNg]1P3_knl401XJ
6P<06ATI0`0O7al301`L70<05QHF0`3dm?@60?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo00D0oooo0`3dm?@30??cl`<04Q8B0`0C4a<301DE5@<0k^k^0`3_knl30>k^kP<0
kNg]100D51@301HF5P<05ADE0`0F5QH30>[ZjP<0k>c/0`3WinL30>KViPH0k>c/0`0D51@701<C4`<0
m?Cd0`3bl_8300l?3`<03@d=0`0B4Q830>SXj0<0kNg]0`3[jn/3014A4@<04a<C100M7Ad301hN7P<0
7AdM0`3dm?@30?3`l0<0j>SX1P3Zj^X60>k^kP<0lO7a1`3clo<30?7al@<05ADE0`0C4a<301DE5@<0
4Q8B1P0C4a<3010@40<05QHF0`3_knl40?7al@<0mOGe0`3`l?0301TI6@<05ADE0`0H61P301LG5`<0
6a/K0`0J6QX301DE5@<04Q8B0`0G5aL40>o_k`<0m_Kf0`3_knl301DE5@<0410@0`0A4A4301<C4`<0
5ADE0`3`l?030?;blP<0l?3`0`3bl_840?3`l0<0l_;b0`3`l?030??cl`H0mOGe:03fm_H30?Gem@<0
m?Cd0`3alO430??cl`@0lO7a0`3clo<30?7al@<0lo?c0`3dm?@30??cl`<0l_;b0`3_knl30>k^kP<0
kNg]1P3_knl401XJ6P<06ATI0`0O7al301`L70<05QHF0`3dm?@60?ooo`030000003oool0oooo00D0
oooo000X0?ooo`030000003oool0oooo00D0oooo0`3dm?@30??cl`<04Q8B0`0C4a<301DE5@<0k^k^
0`3_knl30>k^kP<0kNg]100D51@301HF5P<05ADE0`0F5QH30>[ZjP<0k>c/0`3WinL30>KViPH0k>c/
0`0D51@701<C4`<0m?Cd0`3bl_8300l?3`<03@d=0`0B4Q830>SXj0<0kNg]0`3[jn/3014A4@<04a<C
100M7Ad301hN7P<07AdM0`3dm?@30?3`l0<0j>SX1P3Zj^X60>k^kP<0lO7a1`3clo<30?7al@<05ADE
0`0C4a<301DE5@<04Q8B1P0C4a<3010@40<05QHF0`3_knl40?7al@<0mOGe0`3`l?0301TI6@<05ADE
0`0H61P301LG5`<06a/K0`0J6QX301DE5@<04Q8B0`0G5aL40>o_k`<0m_Kf0`3_knl301DE5@<0410@
0`0A4A4301<C4`<05ADE0`3`l?030?;blP<0l?3`0`3bl_840?3`l0<0l_;b0`3`l?030??cl`H0mOGe
:03fm_H30?Gem@<0m?Cd0`3alO430??cl`@0lO7a0`3clo<30?7al@<0lo?c0`3dm?@30??cl`<0l_;b
0`3_knl30>k^kP<0kNg]1P3_knl401XJ6P<06ATI0`0O7al301`L70<05QHF0`3dm?@60?ooo`030000
003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3dm?@30??cl`<04a<C1P0B
4Q830>o_k`<0k>c/0`3Zj^X3014A4@@04a<C0`0H61P301LG5`<0k^k^0`3]kNd30>KViP<0gmoO0`3P
h>030>[ZjP<0kNg]0`0@4103018B4P@05QHF0`3bl_830??cl`<04a<C1P0>3Ph301<C4`<0jn_[0`3c
lo<30>k^kP<06ATI100G5aL301XJ6P<061PH0`3clo<30>g]k@<0iNGU1P3Ti>@30>SXj0<04A4A0`0B
4Q8301HF5P@061PH0`0J6QX601DE5@<04a<C0`0A4A43018B4P<03`l?0`0@41030>_[j`<0l_;b103d
m?@30>o_k`<06ATI0`0E5AD301LG5`<051@D0`0H61P30?7al@<0l?3`0`0E5AD600l?3`@05ADE0`3_
knl30?KfmP<0kno_0`0E5AD3010@40H04Q8B0`0E5AD3018B4P<051@D0`3_knl70?7al@<0l_;b0`3c
lo<30?Cdm0<0mOGe:`3fm_H30?Gem@<0m?Cd0`3bl_840?7al@<0l_;b0`3clo<60?Cdm0<0lo?c1P3`
l?030>g]k@H0j^[Z1`3^k^h301HF5PH06QXJ0`0F5QH30?Cdm0H0oooo00<000000?ooo`3oool01@3o
ool002P0oooo00<000000?ooo`3oool01@3oool30?Cdm0<0lo?c0`0C4a<6018B4P<0kno_0`3/k>`3
0>[ZjP<04A4A100C4a<301PH60<05aLG0`3^k^h30>g]k@<0i^KV0`3Ogml30>3Ph0<0j^[Z0`3]kNd3
010@40<04Q8B100F5QH30?;blP<0lo?c0`0C4a<600h>3P<04a<C0`3[jn/30??cl`<0k^k^0`0I6AT4
01LG5`<06QXJ0`0H61P30??cl`<0kNg]0`3UiND60>CTi0<0j>SX0`0A4A43018B4P<05QHF100H61P3
01XJ6PH05ADE0`0C4a<3014A4@<04Q8B0`0?3`l3010@40<0jn_[0`3bl_840?Cdm0<0kno_0`0I6AT3
01DE5@<05aLG0`0D51@301PH60<0lO7a0`3`l?0301DE5@H03`l?100E5AD30>o_k`<0m_Kf0`3_knl3
01DE5@<0410@1P0B4Q8301DE5@<04Q8B0`0D51@30>o_k`L0lO7a0`3bl_830??cl`<0m?Cd0`3emOD[
0?KfmP<0mOGe0`3dm?@30?;blP@0lO7a0`3bl_830??cl`H0m?Cd0`3clo<60?3`l0<0kNg]1P3Zj^X7
0>k^kP<05QHF1P0J6QX301HF5P<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`050?ooo`<0m?Cd0`3clo<301<C4`H04Q8B0`3_knl30>c/k0<0j^[Z0`0A4A4401<C
4`<061PH0`0G5aL30>k^kP<0kNg]0`3Vi^H30=oOg`<0h>3P0`3Zj^X30>g]k@<0410@0`0B4Q8401HF
5P<0l_;b0`3clo<301<C4`H03Ph>0`0C4a<30>_[j`<0lo?c0`3^k^h301TI6@@05aLG0`0J6QX301PH
60<0lo?c0`3]kNd30>GUi@H0i>CT0`3Xj>P3014A4@<04Q8B0`0F5QH401PH60<06QXJ1P0E5AD301<C
4`<04A4A0`0B4Q8300l?3`<0410@0`3[jn/30?;blP@0m?Cd0`3_knl301TI6@<05ADE0`0G5aL301@D
50<061PH0`3alO430?3`l0<05ADE1P0?3`l401DE5@<0kno_0`3fm_H30>o_k`<05ADE0`0@4106018B
4P<05ADE0`0B4Q8301@D50<0kno_1`3alO430?;blP<0lo?c0`3dm?@30?GemB/0m_Kf0`3emOD30?Cd
m0<0l_;b103alO430?;blP<0lo?c1P3dm?@30??cl`H0l?3`0`3]kNd60>[ZjPL0k^k^0`0F5QH601XJ
6P<05QHF0`3dm?@60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0
oooo0`3dm?@30??cl`H04Q8B0`0@41030>g]k@H0jn_[0`0?3`l401HF5P<061PH0`0E5AD30?3`l0<0
j^[Z0`3QhN4300@410<01@D50`3Vi^H30>_[j`H04A4A100C4a<301LG5`<0m?Cd0`3`l?0301HF5P<0
4A4A0`0@410301DE5@<0kNg]0`3emOD30?7al@@05aLG0`0F5QH301LG5`<0kno_0`3]kNd30>GUi@<0
g]kN0`0:2PX300/;2`<0410@0`0H61P301dM7@@07alO0`0N7Qh301XJ6P<06ATI0`0B4Q83014A4@<0
j^[Z0`3[jn/30>WYj@<0l?3`0`3_knl40?3`l0<06QXJ0`0F5QH301TI6@<051@D0`0E5AD30>[ZjP<0
kNg]0`3/k>`30>SXj0<04Q8B1`0?3`l301DE5@<0kno_0`3fm_H30>k^kP<051@D0`0C4a<3018B4P<0
51@D0`0E5AD301<C4`<05ADE100C4a<3018B4PH04a<C0`0E5AD301HF5P<05aLG2@0H61PF01TI6@T0
61PH1P0G5aL301HF5PL05ADE2@0F5QH301<C4`<051@D1P3^k^h30>SXj0H0jNWY103[jn/301@D50<0
5ADE0`0H61P301DE5@<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`050?ooo`<0m?Cd0`3clo<6018B4P<0410@0`3]kNd60>_[j`<03`l?100F5QH301PH60<05ADE
0`3`l?030>[ZjP<0hN7Q0`0410@300D51@<0i^KV0`3[jn/6014A4@@04a<C0`0G5aL30?Cdm0<0l?3`
0`0F5QH3014A4@<0410@0`0E5AD30>g]k@<0mOGe0`3alO4401LG5`<05QHF0`0G5aL30>o_k`<0kNg]
0`3UiND30=kNgP<02PX:0`0;2`/3010@40<061PH0`0M7Ad401lO7`<07QhN0`0J6QX301TI6@<04Q8B
0`0A4A430>[ZjP<0jn_[0`3YjNT30?3`l0<0kno_103`l?0301XJ6P<05QHF0`0I6AT301@D50<05ADE
0`3Zj^X30>g]k@<0k>c/0`3Xj>P3018B4PL03`l?0`0E5AD30>o_k`<0m_Kf0`3^k^h301@D50<04a<C
0`0B4Q8301@D50<05ADE0`0C4a<301DE5@@04a<C0`0B4Q8601<C4`<05ADE0`0F5QH301LG5`T061PH
5P0I6AT901PH60H05aLG0`0F5QH701DE5@T05QHF0`0C4a<301@D50H0k^k^0`3Xj>P60>WYj@@0jn_[
0`0D51@301DE5@<061PH0`0E5AD30?Cdm0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool01@3oool30?Cdm0<0lo?c1P0B4Q83010@40<0kNg]1P3[jn/300l?3`@05QHF0`0H
61P301DE5@<0l?3`0`3Zj^X30>7Qh@<010@40`051@D30>KViP<0jn_[1P0A4A4401<C4`<05aLG0`3d
m?@30?3`l0<05QHF0`0A4A43010@40<05ADE0`3]kNd30?Gem@<0lO7a100G5aL301HF5P<05aLG0`3_
knl30>g]k@<0iNGU0`3Ng]h300X:2P<02`/;0`0@410301PH60<07AdM100O7al301hN7P<06QXJ0`0I
6AT3018B4P<04A4A0`3Zj^X30>_[j`<0jNWY0`3`l?030>o_k`@0l?3`0`0J6QX301HF5P<06ATI0`0D
51@301DE5@<0j^[Z0`3]kNd30>c/k0<0j>SX0`0B4Q8700l?3`<05ADE0`3_knl30?KfmP<0k^k^0`0D
51@301<C4`<04Q8B0`0D51@301DE5@<04a<C0`0E5AD401<C4`<04Q8B1P0C4a<301DE5@<05QHF0`0G
5aL901PH61H06ATI2@0H61P601LG5`<05QHF1`0E5AD901HF5P<04a<C0`0D51@60>k^kP<0j>SX1P3Y
jNT40>_[j`<051@D0`0E5AD301PH60<05ADE0`3dm?@60?ooo`030000003oool0oooo00D0oooo000X
0?ooo`030000003oool0oooo00D0oooo0`3dm?@30??cl`<04Q8B0`0A4A43010@40<0kNg]0`3[jn/3
0>c/k0<0410@100G5aL301TI6@<05ADE0`3`l?030>_[j`<0i>CT0`0410@300D51@<0hn?S0`3_knl3
0>g]k@L051@D0`0E5AD30?7al@<0moOg0`3alO4601@D50<04Q8B0`0E5AD60?;blP@05QHF0`0C4a<3
01@D50<05QHF0`3Zj^X30>_[j`<0jNWY0`3Ti>@300d=3@<04a<C0`0M7Ad302@T90@09bLW0`0S8b<3
020P80<0m_Kf0`3alO430>SXj0<0inOW0`3UiND30>WYj@<0i^KV0`0A4A4401HF5P<061PH0`0M7Ad6
01TI6@<0jn_[0`3YjNT30>3Ph0<0gmoO1P3WinL300h>3PL03`l?0`0E5AD30>o_k`<0mOGe0`3alO43
0?3`l0<05ADE0`0D51@301<C4`H051@D100C4a<6018B4P<04a<C0`0E5AD301PH60<06QXJ0`0L71`U
01dM7@T071`L3@0K6a/301XJ6P<061PH0`0E5AD301HF5P<04A4A0`0?3`l30>CTi0<0j^[Z103/k>`3
0>g]k@H05ADE0`0D51@30?Cdm0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool01@3oool30?Cdm0<0lo?c0`0B4Q83014A4@<0410@0`3]kNd30>_[j`<0k>c/0`0@410401LG
5`<06ATI0`0E5AD30?3`l0<0jn_[0`3Ti>@300@410<01@D50`3Shn<30>o_k`<0kNg]1`0D51@301DE
5@<0lO7a0`3gmoL30?7al@H051@D0`0B4Q8301DE5@H0l_;b100F5QH301<C4`<051@D0`0F5QH30>[Z
jP<0jn_[0`3YjNT30>CTi0<03@d=0`0C4a<301dM7@<092@T100W9bL302<S8`<0820P0`3fm_H30?7a
l@<0j>SX0`3WinL30>GUi@<0jNWY0`3Vi^H3014A4@@05QHF0`0H61P301dM7@H06ATI0`3[jn/30>WY
j@<0h>3P0`3Ogml60>OWi`<03Ph>1`0?3`l301DE5@<0kno_0`3emOD30?7al@<0l?3`0`0E5AD301@D
50<04a<C1P0D51@401<C4`H04Q8B0`0C4a<301DE5@<061PH0`0J6QX301`L72D07AdM2@0L71`=01/K
6`<06QXJ0`0H61P301DE5@<05QHF0`0A4A4300l?3`<0i>CT0`3Zj^X40>c/k0<0kNg]1P0E5AD301@D
50<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0
m?Cd0`3clo<3018B4P<04A4A0`0@41030>g]k@<0jn_[0`3/k>`3010@40@05aLG0`0I6AT301DE5@<0
l?3`0`3[jn/30>CTi0<010@40`051@D30>?Sh`<0kno_0`3]kNd701@D50<05ADE0`3alO430?Ogm`<0
lO7a1P0D51@3018B4P<05ADE1P3bl_8401HF5P<04a<C0`0D51@301HF5P<0j^[Z0`3[jn/30>WYj@<0
i>CT0`0=3@d301<C4`<07AdM0`0T92@402LW9`<08b<S0`0P82030?KfmP<0lO7a0`3Xj>P30>OWi`<0
iNGU0`3YjNT30>KViP<04A4A100F5QH301PH60<07AdM1P0I6AT30>_[j`<0jNWY0`3Ph>030=oOg`H0
inOW0`0>3Ph700l?3`<05ADE0`3_knl30?Gem@<0lO7a0`3`l?0301DE5@<051@D0`0C4a<601@D50@0
4a<C1P0B4Q8301<C4`<05ADE0`0H61P301XJ6P<071`L9@0M7Ad901`L70d06a/K0`0J6QX301PH60<0
5ADE0`0F5QH3014A4@<03`l?0`3Ti>@30>[ZjP@0k>c/0`3]kNd601DE5@<051@D0`3dm?@60?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3clo<30?;blPT0410@
0`3^k^h30>c/k0<0jn_[0`0?3`l401HF5P<06ATI0`0H61P30?3`l0<0kno_0`3WinL300P820<00P82
0`071`L30>OWi`<0k^k^0`0@410401@D50<04a<C0`0F5QH30??cl`<0l_;b0`0F5QH301@D50<05QHF
0`0E5AD30?3`l0<0mOGe103`l?0301DE5@<051@D0`0B4Q8301@D50<0jNWY0`3^k^h30>_[j`<03Ph>
0`0C4a<301PH60<08B4Q100V9RH302<S8`<07alO0`3dm?@30?;blP<0inOW1P3Ogml30>7Qh@<02`/;
0`0>3Ph401PH60H0820P0`0N7Qh30??cl`<0l?3`0`3Ti>@30=WIf@<0e]KF0`3MgMd30>;RhP<02`/;
1`0>3Ph300l?3`<05ADE0`3`l?030?7al@<0mOGe0`3bl_830?3`l0<051@D2P0B4Q86014A4@<04a<C
0`0F5QH301DE5@<06ATI0`0K6a/301`L72P07AdM2P0L71`601/K6`T06QXJ0`0I6AT301HF5PH03`l?
0`3Xj>P40>_[j`<0kno_0`0B4Q8601<C4`<0lo?c1P3oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`050?ooo`<0lo?c0`3bl_89010@40<0k^k^0`3/k>`30>_[j`<03`l?100F
5QH301TI6@<061PH0`3`l?030>o_k`<0inOW0`0820P300820P<01`L70`3WinL30>k^kP<0410@100D
51@301<C4`<05QHF0`3clo<30?;blP<05QHF0`0D51@301HF5P<05ADE0`3`l?030?Gem@@0l?3`0`0E
5AD301@D50<04Q8B0`0D51@30>WYj@<0k^k^0`3[jn/300h>3P<04a<C0`0H61P3024Q8@@09RHV0`0S
8b<301lO7`<0m?Cd0`3bl_830>OWi`H0gmoO0`3QhN4300/;2`<03Ph>100H61P6020P80<07QhN0`3c
lo<30?3`l0<0i>CT0`3IfMT30=KFeP<0gMgM0`3Rh^8300/;2`L03Ph>0`0?3`l301DE5@<0l?3`0`3a
lO430?Gem@<0l_;b0`3`l?0301@D50X04Q8B1P0A4A4301<C4`<05QHF0`0E5AD301TI6@<06a/K0`0L
71`X01dM7@X071`L1P0K6a/901XJ6P<06ATI0`0F5QH600l?3`<0j>SX103[jn/30>o_k`<04Q8B1P0C
4a<30??cl`H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool3
0??cl`<0l_;b2@0@41030>k^kP<0k>c/0`3[jn/300l?3`@05QHF0`0I6AT301PH60<0l?3`0`3_knl3
0>OWi`<020P80`020P8300L71`<0inOW0`3^k^h3010@40@051@D0`0C4a<301HF5P<0lo?c0`3bl_83
01HF5P<051@D0`0F5QH301DE5@<0l?3`0`3emOD40?3`l0<05ADE0`0D51@3018B4P<051@D0`3YjNT3
0>k^kP<0jn_[0`0>3Ph301<C4`<061PH0`0Q8B4402HV9P<08b<S0`0O7al30?Cdm0<0l_;b0`3WinL6
0=oOg`<0hN7Q0`0;2`/300h>3P@061PH1P0P820301hN7P<0lo?c0`3`l?030>CTi0<0fMWI0`3Fe]H3
0=gMg@<0h^;R0`0;2`/700h>3P<03`l?0`0E5AD30?3`l0<0lO7a0`3emOD30?;blP<0l?3`0`0D51@:
018B4PH04A4A0`0C4a<301HF5P<05ADE0`0I6AT301/K6`<071`L:00M7Ad:01`L70H06a/K2@0J6QX3
01TI6@<05QHF1P0?3`l30>SXj0@0jn_[0`3_knl3018B4PH04a<C0`3clo<60?ooo`030000003oool0
oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3bl_830?3`l0<04Q8B0`0?3`l3018B
4P<0k>c/0`3^k^h30>[ZjP<0410@100A4A4301PH60<05QHF0`0G5aL30>c/k0<0l?3`0`3Shn<300L7
1`<010@40`3QhN430>OWi`<0410@100A4A4601DE5@<0lO7a0`3fm_H30?7al@<05QHF0`0G5aL301@D
50<05QHF0`3bl_840?7al@<051@D0`0B4Q8301DE5@<04Q8B0`0D51@30>_[j`<0lO7a0`3^k^h30>o_
k`<06ATI0`0F5QH401dM7@<07alO0`0I6AT301XJ6P<0k>c/0`3[jn/30>;RhP<0h>3P0`3QhN4300/;
2`<03`l?100J6QX6024Q8@<07alO0`3emOD30>k^kP<0jNWY0`3Ph>060=[JfP<0h>3P0`3Shn<40>SX
j0<04A4A0`0>3Ph300l?3`<04a<C0`0D51@30>o_k`<0l_;b0`3emOD30?7al@H0l_;b103alO430?3`
l0<0kno_0`3`l?030>o_k`<05ADE0`0D51@301HF5P<05aLG2P0H61PE01TI6A0061PH0`0G5aL301HF
5PH05ADE0`0F5QH301TI6@<05aLG0`0J6QX301HF5P<0410@0`3^k^h40>g]k@<0k^k^0`0A4A43018B
4P<04a<C0`3bl_860?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0
oooo0`3bl_830?3`l0<04Q8B0`0?3`l3018B4P<0k>c/0`3^k^h30>[ZjP<0410@100A4A4301PH60<0
5QHF0`0G5aL30>c/k0<0l?3`0`3Shn<300L71`<010@40`3QhN430>OWi`<0410@100A4A4601DE5@<0
lO7a0`3fm_H30?7al@<05QHF0`0G5aL301@D50<05QHF0`3bl_840?7al@<051@D0`0B4Q8301DE5@<0
4Q8B0`0D51@30>_[j`<0lO7a0`3^k^h30>o_k`<06ATI0`0F5QH401dM7@<07alO0`0I6AT301XJ6P<0
k>c/0`3[jn/30>;RhP<0h>3P0`3QhN4300/;2`<03`l?100J6QX6024Q8@<07alO0`3emOD30>k^kP<0
jNWY0`3Ph>060=[JfP<0h>3P0`3Shn<40>SXj0<04A4A0`0>3Ph300l?3`<04a<C0`0D51@30>o_k`<0
l_;b0`3emOD30?7al@H0l_;b103alO430?3`l0<0kno_0`3`l?030>o_k`<05ADE0`0D51@301HF5P<0
5aLG2P0H61PE01TI6A0061PH0`0G5aL301HF5PH05ADE0`0F5QH301TI6@<05aLG0`0J6QX301HF5P<0
410@0`3^k^h40>g]k@<0k^k^0`0A4A43018B4P<04a<C0`3bl_860?ooo`030000003oool0oooo00D0
oooo000X0?ooo`<000001@3oool30?;blP<0l?3`0`0B4Q8300l?3`<04Q8B0`3/k>`30>k^kP<0j^[Z
0`0@4104014A4@<061PH0`0F5QH301LG5`<0k>c/0`3`l?030>?Sh`<01`L70`0410@30>7Qh@<0inOW
0`0@4104014A4@H05ADE0`3alO430?KfmP<0lO7a0`0F5QH301LG5`<051@D0`0F5QH30?;blP@0lO7a
0`0D51@3018B4P<05ADE0`0B4Q8301@D50<0jn_[0`3alO430>k^kP<0kno_0`0I6AT301HF5P@07AdM
0`0O7al301TI6@<06QXJ0`3/k>`30>_[j`<0h^;R0`3Ph>030>7Qh@<02`/;0`0?3`l401XJ6PH08B4Q
0`0O7al30?Gem@<0k^k^0`3YjNT30>3Ph0H0f][J0`3Ph>030>?Sh`@0j>SX0`0A4A4300h>3P<03`l?
0`0C4a<301@D50<0kno_0`3bl_830?Gem@<0lO7a1P3bl_840?7al@<0l?3`0`3_knl30?3`l0<0kno_
0`0E5AD301@D50<05QHF0`0G5aL:01PH61D06ATI400H61P301LG5`<05QHF1P0E5AD301HF5P<06ATI
0`0G5aL301XJ6P<05QHF0`0@41030>k^kP@0kNg]0`3^k^h3014A4@<04Q8B0`0C4a<30?;blPD0oooo
0P0000070?ooo`00:03oool00`000000oooo0?ooo`050?ooo`H0l_;b0`3^k^h3018B4P<03Ph>0`0A
4A430>c/k0<0k^k^0`3Zj^X401DE5@<04a<C0`0G5aL301<C4`<05ADE0`3[jn/30>k^kP<0h^;R0`3J
f]X30=kNgP<0iNGU0`3WinL4014A4@<051@D0`0C4a<301HF5PH0l_;b0`0F5QH301@D50<05aLG0`0F
5QH30?3`l0@0m?Cd0`3]kNd301HF5P<04Q8B0`0E5AD3018B4P<05ADE0`3]kNd30?;blP<0lo?c0`3^
k^h301HF5PL061PH0`0I6AT301@D50<05ADE0`3[jn/30>OWi`<0j>SX0`3YjNT30>OWi`<04a<C100D
51@301/K6`<07QhN0`0J6QX301LG5`<04a<C0`3Zj^X30>WYj@<0h^;R0`3Shn<30>7Qh@<0hn?S103Y
jNT30>OWi`<04A4A0`0>3Ph3014A4@<0410@0`0C4a<301DE5@<0l?3`1P3clo<30?;blP@0kno_0`3a
lO460>o_k`<0lO7a0`3`l?030??cl`<0m?Cd0`3emOD[0?KfmPL0mOGe0`3clo<30?7al@<0l?3`0`3a
lO430?3`l0<06QXJ0`0F5QH301PH60<05ADE0`3^k^h40?3`l0<0kno_0`0@4103018B4P<04a<C0`3b
l_860?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo1P3bl_83
0>k^kP<04Q8B0`0>3Ph3014A4@<0k>c/0`3^k^h30>[ZjP@05ADE0`0C4a<301LG5`<04a<C0`0E5AD3
0>_[j`<0k^k^0`3Rh^830=[JfP<0g]kN0`3UiND30>OWi`@04A4A0`0D51@301<C4`<05QHF1P3bl_83
01HF5P<051@D0`0G5aL301HF5P<0l?3`103dm?@30>g]k@<05QHF0`0B4Q8301DE5@<04Q8B0`0E5AD3
0>g]k@<0l_;b0`3clo<30>k^kP<05QHF1`0H61P301TI6@<051@D0`0E5AD30>_[j`<0inOW0`3Xj>P3
0>WYj@<0inOW0`0C4a<401@D50<06a/K0`0N7Qh301XJ6P<05aLG0`0C4a<30>[ZjP<0jNWY0`3Rh^83
0>?Sh`<0hN7Q0`3Shn<40>WYj@<0inOW0`0A4A4300h>3P<04A4A0`0@410301<C4`<05ADE0`3`l?06
0??cl`<0l_;b103_knl30?7al@H0kno_0`3alO430?3`l0<0lo?c0`3dm?@30?GemB/0m_Kf1`3emOD3
0??cl`<0lO7a0`3`l?030?7al@<0l?3`0`0J6QX301HF5P<061PH0`0E5AD30>k^kP@0l?3`0`3_knl3
010@40<04Q8B0`0C4a<30?;blPH0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool01@3oool60?;blP<0k^k^0`0B4Q8300h>3P<04A4A0`3/k>`30>k^kP<0j^[Z100E5AD301<C
4`<05aLG0`0C4a<301DE5@<0jn_[0`3^k^h30>;RhP<0f][J0`3Ng]h30>GUi@<0inOW100A4A4301@D
50<04a<C0`0F5QH60?;blP<05QHF0`0D51@301LG5`<05QHF0`3`l?040?Cdm0<0kNg]0`0F5QH3018B
4P<05ADE0`0B4Q8301DE5@<0kNg]0`3bl_830??cl`<0k^k^0`0F5QH701PH60<06ATI0`0D51@301DE
5@<0jn_[0`3WinL30>SXj0<0jNWY0`3WinL301<C4`@051@D0`0K6a/301hN7P<06QXJ0`0G5aL301<C
4`<0j^[Z0`3YjNT30>;RhP<0hn?S0`3QhN430>?Sh`@0jNWY0`3WinL3014A4@<03Ph>0`0A4A43010@
40<04a<C0`0E5AD30?3`l0H0lo?c0`3bl_840>o_k`<0lO7a1P3_knl30?7al@<0l?3`0`3clo<30?Cd
m0<0mOGe:`3fm_H70?Gem@<0lo?c0`3alO430?3`l0<0lO7a0`3`l?0301XJ6P<05QHF0`0H61P301DE
5@<0k^k^103`l?030>o_k`<0410@0`0B4Q8301<C4`<0l_;b1P3oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`050?ooo`<0kno_0`3bl_830?3`l0H03`l?0`0A4A430>c/k0H0
kno_103/k>`301HF5P<04a<C0`0F5QH3018B4P<051@D1P3YjNT30=kNgP<0e]KF0`3Kfm/30>CTi0@0
3`l?0`0A4A4601DE5@<0l?3`0`3fm_H30?7al@H05QHF0`0D51@301DE5@@0l?3`0`3bl_830>g]k@<0
5QHF0`0C4a<301DE5@<04Q8B0`0F5QH60>o_k`<0lo?c1`3`l?0301PH60<04a<C0`0E5AD3018B4P<0
4A4A0`0?3`l30>OWi`<0k^k^0`3`l?030>c/k0@05ADE0`0G5aL301HF5P<05aLG0`0E5AD6018B4PH0
3Ph>1P3Vi^H30>SXj0@0inOW0`3[jn/30>OWi`<0410@0`0A4A43010@40H04A4A0`0D51@301<C4`<0
4Q8B0`0A4A4401<C4`<0k^k^0`3`l?030>o_k`<0l?3`0`3bl_830??cl`<0m?Cd1P3emODX0?KfmP@0
mOGe0`3dm?@30?7al@<0l_;b0`3_knl30>k^kP<0lO7a0`3_knl301DE5@<05aLG1P0D51@40>o_k`<0
l?3`0`0@4103018B4P<05ADE0`3_knl60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo00D0oooo0`3_knl30?;blP<0l?3`1P0?3`l3014A4@<0k>c/1P3_knl40>c/k0<05QHF
0`0C4a<301HF5P<04Q8B0`0D51@60>WYj@<0g]kN0`3Fe]H30=_Kf`<0i>CT100?3`l3014A4@H05ADE
0`3`l?030?KfmP<0lO7a1P0F5QH301@D50<05ADE103`l?030?;blP<0kNg]0`0F5QH301<C4`<05ADE
0`0B4Q8301HF5PH0kno_0`3clo<70?3`l0<061PH0`0C4a<301DE5@<04Q8B0`0A4A4300l?3`<0inOW
0`3^k^h30?3`l0<0k>c/100E5AD301LG5`<05QHF0`0G5aL301DE5@H04Q8B1P0>3Ph60>KViP<0j>SX
103WinL30>_[j`<0inOW0`0@4103014A4@<0410@1P0A4A4301@D50<04a<C0`0B4Q83014A4@@04a<C
0`3^k^h30?3`l0<0kno_0`3`l?030?;blP<0lo?c0`3dm?@60?GemBP0m_Kf103emOD30?Cdm0<0lO7a
0`3bl_830>o_k`<0k^k^0`3alO430>o_k`<05ADE0`0G5aL601@D50@0kno_0`3`l?03010@40<04Q8B
0`0E5AD30>o_k`H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3o
ool30>o_k`<0l_;b0`3`l?0600l?3`<04A4A0`3/k>`60>o_k`@0k>c/0`0F5QH301<C4`<05QHF0`0B
4Q8301@D50H0jNWY0`3Ng]h30=KFeP<0fm_K0`3Ti>@400l?3`<04A4A1P0E5AD30?3`l0<0m_Kf0`3a
lO4601HF5P<051@D0`0E5AD40?3`l0<0l_;b0`3]kNd301HF5P<04a<C0`0E5AD3018B4P<05QHF1P3_
knl30??cl`L0l?3`0`0H61P301<C4`<05ADE0`0B4Q83014A4@<03`l?0`3WinL30>k^kP<0l?3`0`3/
k>`401DE5@<05aLG0`0F5QH301LG5`<05ADE1P0B4Q8600h>3PH0i^KV0`3Xj>P40>OWi`<0jn_[0`3W
inL3010@40<04A4A0`0@4106014A4@<051@D0`0C4a<3018B4P<04A4A100C4a<30>k^kP<0l?3`0`3_
knl30?3`l0<0l_;b0`3clo<30?Cdm0H0mOGe:03fm_H40?Gem@<0m?Cd0`3alO430?;blP<0kno_0`3^
k^h30?7al@<0kno_0`0E5AD301LG5`H051@D103_knl30?3`l0<0410@0`0B4Q8301DE5@<0kno_1P3o
ool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<051@D0`3`l?03
0>o_k`<04A4A0`0>3Ph300l?3`<04a<C0`3[jn/30?7al@@0l_;b0`3^k^h301LG5`<04a<C0`0E5AD3
014A4@<04Q8B0`3Shn<30>7Qh@<0e=CD0`3Cdm<30>7Qh@@0i^KV0`0@410601<C4`<05QHF1P3bl_83
01DE5@<04a<C1P0E5AD40?3`l0H0lo?c0`3^k^h301HF5P<04Q8B0`0D51@3018B4PH04a<C0`3]kNd7
0??cl`<0kNg]1P0D51@3018B4P<04a<C0`0?3`l301@D50<0kNg]0`3_knl30??cl`@0lO7a0`3`l?03
01DE5@<04a<C0`0E5AD9018B4P<03`l?0`0@410300l?3`<0j>SX103YjNT30>c/k0<0kNg]1P3[jn/6
014A4@<03`l?1P0A4A43018B4P<04a<C100B4Q8301@D50<04Q8B1P0A4A43018B4P<04a<C0`0D51@3
01DE5@<05QHF0`0G5aL=01PH60`06ATI300H61P401LG5`<051@D0`0E5AD60>o_k`<0j^[Z1P3^k^h3
01DE5@<051@D0`0E5AD301<C4`@0l_;b0`3`l?0301<C4`<04A4A0`0B4Q8301@D50H0oooo00<00000
0?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool301@D50<0l?3`0`3_knl3014A
4@<03Ph>0`0?3`l301<C4`<0jn_[0`3alO440?;blP<0k^k^0`0G5aL301<C4`<05ADE0`0A4A43018B
4P<0hn?S0`3QhN430=CDe0<0dm?C0`3QhN440>KViP<0410@1P0C4a<301HF5PH0l_;b0`0E5AD301<C
4`H05ADE103`l?060??cl`<0k^k^0`0F5QH3018B4P<051@D0`0B4Q8601<C4`<0kNg]1`3clo<30>g]
k@H051@D0`0B4Q8301<C4`<03`l?0`0D51@30>g]k@<0kno_0`3clo<40?7al@<0l?3`0`0E5AD301<C
4`<05ADE2@0B4Q8300l?3`<0410@0`0?3`l30>SXj0@0jNWY0`3/k>`30>g]k@H0jn_[1P0A4A4300l?
3`H04A4A0`0B4Q8301<C4`@04Q8B0`0D51@3018B4PH04A4A0`0B4Q8301<C4`<051@D0`0E5AD301HF
5P<05aLG3@0H61P<01TI6@`061PH100G5aL301@D50<05ADE1P3_knl30>[ZjPH0k^k^0`0E5AD301@D
50<05ADE0`0C4a<40?;blP<0l?3`0`0C4a<3014A4@<04Q8B0`0D51@60?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0D51@30?3`l0<0kno_0`0A4A4300h>3P<0
3`l?0`0C4a<30>_[j`<0lO7a103bl_830>k^kP<05aLG0`0C4a<301DE5@<04A4A0`0B4Q830>?Sh`<0
hN7Q0`3De=@30=?Cd`<0hN7Q103Vi^H3010@40H04a<C0`0F5QH60?;blP<05ADE0`0C4a<601DE5@@0
l?3`1P3clo<30>k^kP<05QHF0`0B4Q8301@D50<04Q8B1P0C4a<30>g]k@L0lo?c0`3]kNd601@D50<0
4Q8B0`0C4a<300l?3`<051@D0`3]kNd30>o_k`<0lo?c103alO430?3`l0<05ADE0`0C4a<301DE5@T0
4Q8B0`0?3`l3010@40<03`l?0`3Xj>P40>WYj@<0k>c/0`3]kNd60>_[j`H04A4A0`0?3`l6014A4@<0
4Q8B0`0C4a<4018B4P<051@D0`0B4Q86014A4@<04Q8B0`0C4a<301@D50<05ADE0`0F5QH301LG5`d0
61PH300I6AT<01PH60@05aLG0`0D51@301DE5@H0kno_0`3Zj^X60>k^kP<05ADE0`0D51@301DE5@<0
4a<C103bl_830?3`l0<04a<C0`0A4A43018B4P<051@D1P3oool00`000000oooo0?ooo`050?ooo`00
:03oool00`000000oooo0?ooo`050?ooo`<051@D0`3`l?030>o_k`<04A4A0`0>3Ph300l?3`<04a<C
0`3[jn/30?7al@@0l_;b0`3^k^h301LG5`<04a<C0`0E5AD3014A4@<04Q8B0`3Shn<30>7Qh@<0e=CD
0`3Cdm<30>7Qh@@0i^KV0`0@410601<C4`<05QHF1P3bl_8301DE5@<04a<C1P0E5AD40?3`l0H0lo?c
0`3^k^h301HF5P<04Q8B0`0D51@3018B4PH04a<C0`3]kNd70??cl`<0kNg]1P0D51@3018B4P<04a<C
0`0?3`l301@D50<0kNg]0`3_knl30??cl`@0lO7a0`3`l?0301DE5@<04a<C0`0E5AD9018B4P<03`l?
0`0@410300l?3`<0j>SX103YjNT30>c/k0<0kNg]1P3[jn/6014A4@<03`l?1P0A4A43018B4P<04a<C
100B4Q8301@D50<04Q8B1P0A4A43018B4P<04a<C0`0D51@301DE5@<05QHF0`0G5aL=01PH60`06ATI
300H61P401LG5`<051@D0`0E5AD60>o_k`<0j^[Z1P3^k^h301DE5@<051@D0`0E5AD301<C4`@0l_;b
0`3`l?0301<C4`<04A4A0`0B4Q8301@D50H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool01@3oool301@D50<0l?3`0`3dm?@30>c/k0<04a<C1P0>3Ph301@D50<0k^k^103_
knl30?Cdm0<0kno_0`0G5aL301<C4`<051@D0`0?3`l300h>3P<0hn?S0`3Jf]X30=3@d0<0fMWI103R
h^8300d=3@<03`l?0`0C4a<301@D50<0lO7a0`3fm_H30>o_k`<061PH1P0C4a<401PH60<0kno_0`3`
l?030?Cdm0<0k^k^0`0E5AD301@D50H04Q8B0`0@410301DE5@L0kno_0`3clo<30?3`l0<0kno_0`0F
5QH3014A4@<04a<C0`0B4Q8301<C4`<051@D0`3_knl40?;blP<0mOGe1P3alO430>o_k`H04a<C0`0A
4A46018B4P<03`l?1`0@41030>[ZjP<0k>c/0`3_knl30>k^kP<0jn_[0`3YjNT300h>3P<03@d=0`0?
3`l3018B4P<0410@4`0B4Q8301<C4`<051@D0`0F5QH301PH60<06QXJ1`0L71`H01dM7@H071`L100K
6a/301XJ6P<05QHF0`0G5aL3014A4@<03`l?0`3/k>`30?7al@<0kno_2@0F5QH40?3`l0<0m?Cd0`3_
knl301<C4`<04Q8B0`0D51@60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0
oooo00D0oooo0`0D51@30?3`l0<0m?Cd0`3/k>`301<C4`H03Ph>0`0D51@30>k^kP@0kno_0`3dm?@3
0>o_k`<05aLG0`0C4a<301@D50<03`l?0`0>3Ph30>?Sh`<0f][J0`3@d=030=WIf@@0h^;R0`0=3@d3
00l?3`<04a<C0`0D51@30?7al@<0m_Kf0`3_knl301PH60H04a<C100H61P30>o_k`<0l?3`0`3dm?@3
0>k^kP<05ADE0`0D51@6018B4P<0410@0`0E5AD70>o_k`<0lo?c0`3`l?030>o_k`<05QHF0`0A4A43
01<C4`<04Q8B0`0C4a<301@D50<0kno_103bl_830?Gem@H0lO7a0`3_knl601<C4`<04A4A1P0B4Q83
00l?3`L0410@0`3Zj^X30>c/k0<0kno_0`3^k^h30>_[j`<0jNWY0`0>3Ph300d=3@<03`l?0`0B4Q83
010@41<04Q8B0`0C4a<301@D50<05QHF0`0H61P301XJ6PL071`L600M7Ad601`L70@06a/K0`0J6QX3
01HF5P<05aLG0`0A4A4300l?3`<0k>c/0`3alO430>o_k`T05QHF103`l?030?Cdm0<0kno_0`0C4a<3
018B4P<051@D1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?oo
o`<051@D0`3`l?030?Cdm0<0k>c/0`0C4a<600h>3P<051@D0`3^k^h40>o_k`<0m?Cd0`3_knl301LG
5`<04a<C0`0D51@300l?3`<03Ph>0`3Shn<30=[JfP<0d=3@0`3IfMT40>;RhP<03@d=0`0?3`l301<C
4`<051@D0`3alO430?KfmP<0kno_0`0H61P601<C4`@061PH0`3_knl30?3`l0<0m?Cd0`3^k^h301DE
5@<051@D1P0B4Q83010@40<05ADE1`3_knl30??cl`<0l?3`0`3_knl301HF5P<04A4A0`0C4a<3018B
4P<04a<C0`0D51@30>o_k`@0l_;b0`3emOD60?7al@<0kno_1P0C4a<3014A4@H04Q8B0`0?3`l7010@
40<0j^[Z0`3/k>`30>o_k`<0k^k^0`3[jn/30>WYj@<03Ph>0`0=3@d300l?3`<04Q8B0`0@410C018B
4P<04a<C0`0D51@301HF5P<061PH0`0J6QX701`L71P07AdM1P0L71`401/K6`<06QXJ0`0F5QH301LG
5`<04A4A0`0?3`l30>c/k0<0lO7a0`3_knl901HF5P@0l?3`0`3dm?@30>o_k`<04a<C0`0B4Q8301@D
50H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool3018B4P<0
5QHF0`3]kNd30??cl`<0k>c/0`0C4a<300h>3P<0410@1`0C4a<30>k^kP<0m_Kf0`3`l?0301LG5`H0
4Q8B0`0?3`l30>KViP<0hn?S0`3EeMD30=;BdP@0gmoO0`3QhN43014A4@<0410@0`0B4Q8301LG5`<0
k^k^0`3emOD30?3`l0X04a<C1P0D51@30>k^kP<0m_Kf0`3bl_830?3`l0<05ADE0`0D51@3018B4P<0
4A4A1`0C4a<30>c/k0H0l_;b0`3/k>`601<C4`<04Q8B0`0D51@301<C4`<05ADE100F5QH30?3`l0<0
lO7a0`3bl_830?7al@<0k^k^0`3]kNd3018B4P<04A4A0`0C4a<3010@40<04A4A100?3`l6014A4@H0
jn_[0`3]kNd30>_[j`<0iNGU0`3WinL30>WYj@<0j>SX0`0>3Ph400d=3@<0410@300A4A43018B4P<0
4a<C0`0F5QH301DE5@<06ATI100K6a/301`L71D07AdM4`0L71`301XJ6P<05QHF0`0C4a<30>k^kP<0
l_;b0`3alO43018B4P<05ADE1`0D51@60?3`l0<051@D0`0A4A43018B4PH0oooo00<000000?ooo`3o
ool01@3oool002P0oooo00<000000?ooo`3oool01@3oool3018B4P<05QHF0`3]kNd30??cl`<0k>c/
0`0C4a<300h>3P<0410@1`0C4a<30>k^kP<0m_Kf0`3`l?0301LG5`H04Q8B0`0?3`l30>KViP<0hn?S
0`3EeMD30=;BdP@0gmoO0`3QhN43014A4@<0410@0`0B4Q8301LG5`<0k^k^0`3emOD30?3`l0X04a<C
1P0D51@30>k^kP<0m_Kf0`3bl_830?3`l0<05ADE0`0D51@3018B4P<04A4A1`0C4a<30>c/k0H0l_;b
0`3/k>`601<C4`<04Q8B0`0D51@301<C4`<05ADE100F5QH30?3`l0<0lO7a0`3bl_830?7al@<0k^k^
0`3]kNd3018B4P<04A4A0`0C4a<3010@40<04A4A100?3`l6014A4@H0jn_[0`3]kNd30>_[j`<0iNGU
0`3WinL30>WYj@<0j>SX0`0>3Ph400d=3@<0410@300A4A43018B4P<04a<C0`0F5QH301DE5@<06ATI
100K6a/301`L71D07AdM4`0L71`301XJ6P<05QHF0`0C4a<30>k^kP<0l_;b0`3alO43018B4P<05ADE
1`0D51@60?3`l0<051@D0`0A4A43018B4PH0oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool01@3oool3018B4P<05QHF0`3]kNd30??cl`<0k>c/0`0C4a<300h>3P<0410@1`0C
4a<30>k^kP<0m_Kf0`3`l?0301LG5`H04Q8B0`0?3`l30>KViP<0hn?S0`3EeMD30=;BdP@0gmoO0`3Q
hN43014A4@<0410@0`0B4Q8301LG5`<0k^k^0`3emOD30?3`l0X04a<C1P0D51@30>k^kP<0m_Kf0`3b
l_830?3`l0<05ADE0`0D51@3018B4P<04A4A1`0C4a<30>c/k0H0l_;b0`3/k>`601<C4`<04Q8B0`0D
51@301<C4`<05ADE100F5QH30?3`l0<0lO7a0`3bl_830?7al@<0k^k^0`3]kNd3018B4P<04A4A0`0C
4a<3010@40<04A4A100?3`l6014A4@H0jn_[0`3]kNd30>_[j`<0iNGU0`3WinL30>WYj@<0j>SX0`0>
3Ph400d=3@<0410@300A4A43018B4P<04a<C0`0F5QH301DE5@<06ATI100K6a/301`L71D07AdM4`0L
71`301XJ6P<05QHF0`0C4a<30>k^kP<0l_;b0`3alO43018B4P<05ADE1`0D51@60?3`l0<051@D0`0A
4A43018B4PH0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool3
01<C4`<04A4A0`0C4a<30>o_k`<0lO7a0`3[jn/301<C4`<0410@0`0C4a<4014A4@<05aLG0`3`l?03
0?KfmP<0kno_0`0F5QH3010@40<03`l?0`0@41030>3Ph0<0g]kN0`3Bd]840=KFeP<0i>CT0`3WinL3
010@40<04Q8B0`0@410301@D50<0lO7a0`3`l?03014A4@<04a<C100B4Q8301@D50<04Q8B0`0G5aL3
0?7al@<0l_;b0`3fm_H30??cl`<0lO7a0`0H61P3014A4@<04Q8B100@410301DE5@<0k^k^0`3_knl3
0?;blPH0kno_0`0F5QH3014A4@<05ADE0`0F5QH401@D50H05ADE0`3^k^h30>o_k`H0lO7a0`3^k^h3
0?3`l0<0k^k^0`0C4a<3018B4P@0410@0`0A4A43010@40<04A4A0`0@41030>OWi`<0j^[Z0`3Ti>@3
0>7Qh@<0h>3P1P3Shn<40>WYj@<0k^k^0`3`l?060?7al@<0l?3`0`3_knl30?7al@<0kno_0`0E5AD3
01@D50@05QHF0`0G5aLE01PH60<05aLG2P0F5QH301TI6@<05aLG1P0J6QX601DE5@<0lO7a0`3`l?03
01@D50<04a<C0`0E5AD4018B4PH0l_;b0`3^k^h601<C4`H0oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool01@3oool301<C4`<04A4A0`0C4a<30>o_k`<0lO7a0`3[jn/301<C
4`<0410@0`0C4a<4014A4@<05aLG0`3`l?030?KfmP<0kno_0`0F5QH3010@40<03`l?0`0@41030>3P
h0<0g]kN0`3Bd]840=KFeP<0i>CT0`3WinL3010@40<04Q8B0`0@410301@D50<0lO7a0`3`l?03014A
4@<04a<C100B4Q8301@D50<04Q8B0`0G5aL30?7al@<0l_;b0`3fm_H30??cl`<0lO7a0`0H61P3014A
4@<04Q8B100@410301DE5@<0k^k^0`3_knl30?;blPH0kno_0`0F5QH3014A4@<05ADE0`0F5QH401@D
50H05ADE0`3^k^h30>o_k`H0lO7a0`3^k^h30?3`l0<0k^k^0`0C4a<3018B4P@0410@0`0A4A43010@
40<04A4A0`0@41030>OWi`<0j^[Z0`3Ti>@30>7Qh@<0h>3P1P3Shn<40>WYj@<0k^k^0`3`l?060?7a
l@<0l?3`0`3_knl30?7al@<0kno_0`0E5AD301@D50@05QHF0`0G5aLE01PH60<05aLG2P0F5QH301TI
6@<05aLG1P0J6QX601DE5@<0lO7a0`3`l?0301@D50<04a<C0`0E5AD4018B4PH0l_;b0`3^k^h601<C
4`H0oooo00<000000?ooo`3oool01@3oool002P0oooo0`0000050?ooo`<04a<C0`0A4A4301<C4`<0
kno_0`3alO430>_[j`<04a<C0`0@410301<C4`@04A4A0`0G5aL30?3`l0<0m_Kf0`3_knl301HF5P<0
410@0`0?3`l3010@40<0h>3P0`3Ng]h30=;BdP@0e]KF0`3Ti>@30>OWi`<0410@0`0B4Q83010@40<0
51@D0`3alO430?3`l0<04A4A0`0C4a<4018B4P<051@D0`0B4Q8301LG5`<0lO7a0`3bl_830?KfmP<0
lo?c0`3alO4301PH60<04A4A0`0B4Q84010@40<05ADE0`3^k^h30>o_k`<0l_;b1P3_knl301HF5P<0
4A4A0`0E5AD301HF5P@051@D1P0E5AD30>k^kP<0kno_1P3alO430>k^kP<0l?3`0`3^k^h301<C4`<0
4Q8B100@4103014A4@<0410@0`0A4A43010@40<0inOW0`3Zj^X30>CTi0<0hN7Q0`3Ph>060>?Sh`@0
jNWY0`3^k^h30?3`l0H0lO7a0`3`l?030>o_k`<0lO7a0`3_knl301DE5@<051@D100F5QH301LG5aD0
61PH0`0G5aL:01HF5P<06ATI0`0G5aL601XJ6PH05ADE0`3alO430?3`l0<051@D0`0C4a<301DE5@@0
4Q8B1P3bl_830>k^kPH04a<C1@3oool2000000L0oooo000X0?ooo`030000003oool0oooo00D0oooo
0`0A4A4301@D50<04a<C0`3^k^h30?7al@<0kno_0`3Zj^X301@D50<04A4A100E5AD301<C4`<05aLG
0`3_knl30?Gem@<0k^k^0`0E5AD300l?3`H030`<0`3QhN430=SHf0@0d=3@0`3Jf]X30>?Sh`<03@d=
0`0>3Ph3018B4P<04a<C0`3_knl30??cl`H0kno_100F5QH3014A4@<051@D0`0C4a<301DE5@<05QHF
0`3alO430??cl`<0moOg0`3alO4301HF5P<05ADE100B4Q83014A4@<04a<C0`0B4Q830>c/k0H0l_;b
0`3/k>`301<C4`<051@D0`0C4a<701HF5PT051@D0`3_knl30?3`l0<0k^k^1P3bl_830?3`l0<0k^k^
1`0C4a<3014A4@<04Q8B0`0?3`l3014A4@<0inOW0`3Xj>P30>3Ph0<0f][J0`3Hf=P30=kNgP@0i^KV
0`3YjNT30>k^kP<0l?3`0`3_knl30?7al@H0kno_0`3bl_830?3`l0<0lo?c103dm?@H0?Gem@<0m?Cd
0`3clo<30?;blP@0lO7a0`3_knl301DE5@<05aLG1P0H61P301HF5P<0l?3`0`3emOD30?3`l0<05ADE
0`0D51@401HF5P<0l?3`0`3clo<30>o_k`<04a<C0`0A4A460?ooo`030000003oool0oooo00D0oooo
000X0?ooo`030000003oool0oooo00D0oooo0`0A4A4301@D50<04a<C0`3^k^h30?7al@<0kno_0`3Z
j^X301@D50<04A4A100E5AD301<C4`<05aLG0`3_knl30?Gem@<0k^k^0`0E5AD300l?3`H030`<0`3Q
hN430=SHf0@0d=3@0`3Jf]X30>?Sh`<03@d=0`0>3Ph3018B4P<04a<C0`3_knl30??cl`H0kno_100F
5QH3014A4@<051@D0`0C4a<301DE5@<05QHF0`3alO430??cl`<0moOg0`3alO4301HF5P<05ADE100B
4Q83014A4@<04a<C0`0B4Q830>c/k0H0l_;b0`3/k>`301<C4`<051@D0`0C4a<701HF5PT051@D0`3_
knl30?3`l0<0k^k^1P3bl_830?3`l0<0k^k^1`0C4a<3014A4@<04Q8B0`0?3`l3014A4@<0inOW0`3X
j>P30>3Ph0<0f][J0`3Hf=P30=kNgP@0i^KV0`3YjNT30>k^kP<0l?3`0`3_knl30?7al@H0kno_0`3b
l_830?3`l0<0lo?c103dm?@H0?Gem@<0m?Cd0`3clo<30?;blP@0lO7a0`3_knl301DE5@<05aLG1P0H
61P301HF5P<0l?3`0`3emOD30?3`l0<05ADE0`0D51@401HF5P<0l?3`0`3clo<30>o_k`<04a<C0`0A
4A460?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0A4A43
01@D50<04a<C0`3^k^h30?7al@<0kno_0`3Zj^X301@D50<04A4A100E5AD301<C4`<05aLG0`3_knl3
0?Gem@<0k^k^0`0E5AD300l?3`H030`<0`3QhN430=SHf0@0d=3@0`3Jf]X30>?Sh`<03@d=0`0>3Ph3
018B4P<04a<C0`3_knl30??cl`H0kno_100F5QH3014A4@<051@D0`0C4a<301DE5@<05QHF0`3alO43
0??cl`<0moOg0`3alO4301HF5P<05ADE100B4Q83014A4@<04a<C0`0B4Q830>c/k0H0l_;b0`3/k>`3
01<C4`<051@D0`0C4a<701HF5PT051@D0`3_knl30?3`l0<0k^k^1P3bl_830?3`l0<0k^k^1`0C4a<3
014A4@<04Q8B0`0?3`l3014A4@<0inOW0`3Xj>P30>3Ph0<0f][J0`3Hf=P30=kNgP@0i^KV0`3YjNT3
0>k^kP<0l?3`0`3_knl30?7al@H0kno_0`3bl_830?3`l0<0lo?c103dm?@H0?Gem@<0m?Cd0`3clo<3
0?;blP@0lO7a0`3_knl301DE5@<05aLG1P0H61P301HF5P<0l?3`0`3emOD30?3`l0<05ADE0`0D51@4
01HF5P<0l?3`0`3clo<30>o_k`<04a<C0`0A4A460?ooo`030000003oool0oooo00D0oooo000X0?oo
o`030000003oool0oooo00D0oooo0`0F5QH301<C4`<04Q8B0`0F5QH30>c/k0H0kno_0`3Zj^X301@D
50@04Q8B0`0E5AD3018B4P<051@D0`3`l?030??cl`<0k^k^0`0B4Q8300l?3`<03Ph>0`3Ti>@30>7Q
h@@0d];B0`3Cdm<30>7Qh@<0h^;R0`0@410300h>3P<0410@0`0E5AD30>g]k@H0l_;b103]kNd301<C
4`<051@D0`0C4a<301DE5@<051@D0`0F5QH301LG5`<0l_;b1P3emOD30??cl`@061PH0`0A4A43018B
4P<0410@0`0E5AD30>k^kP<0kno_0`3bl_830>o_k`<0k^k^1`0D51@301<C4`H05QHF0`0C4a<301DE
5@<04A4A0`0C4a<30>k^kP<0lO7a0`3_knl30??cl`@0kno_0`3^k^h301DE5@<0410@0`0B4Q8300l?
3`<04Q8B0`3Xj>P30>CTi0<0h^;R0`3Kfm/30=gMg@@0h>3P0`0:2PX300d=3@<0410@0`0D51@30?3`
l0<0l_;b0`3`l?030?7al@<0l_;b0`3clo<C0?Cdm0H0mOGe0`3dm?@30??cl`<0l?3`0`3alO470>k^
kP<0kNg]0`3alO4301HF5P<05aLG0`0E5AD301HF5PH0l_;b0`0E5AD701<C4`<05aLG0`3]kNd30??c
l`<0kNg]0`0F5QH60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0
oooo0`0F5QH301<C4`<04Q8B0`0F5QH30>c/k0H0kno_0`3Zj^X301@D50@04Q8B0`0E5AD3018B4P<0
51@D0`3`l?030??cl`<0k^k^0`0B4Q8300l?3`<03Ph>0`3Ti>@30>7Qh@@0d];B0`3Cdm<30>7Qh@<0
h^;R0`0@410300h>3P<0410@0`0E5AD30>g]k@H0l_;b103]kNd301<C4`<051@D0`0C4a<301DE5@<0
51@D0`0F5QH301LG5`<0l_;b1P3emOD30??cl`@061PH0`0A4A43018B4P<0410@0`0E5AD30>k^kP<0
kno_0`3bl_830>o_k`<0k^k^1`0D51@301<C4`H05QHF0`0C4a<301DE5@<04A4A0`0C4a<30>k^kP<0
lO7a0`3_knl30??cl`@0kno_0`3^k^h301DE5@<0410@0`0B4Q8300l?3`<04Q8B0`3Xj>P30>CTi0<0
h^;R0`3Kfm/30=gMg@@0h>3P0`0:2PX300d=3@<0410@0`0D51@30?3`l0<0l_;b0`3`l?030?7al@<0
l_;b0`3clo<C0?Cdm0H0mOGe0`3dm?@30??cl`<0l?3`0`3alO470>k^kP<0kNg]0`3alO4301HF5P<0
5aLG0`0E5AD301HF5PH0l_;b0`0E5AD701<C4`<05aLG0`3]kNd30??cl`<0kNg]0`0F5QH60?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0F5QH301<C4`<04Q8B
0`0F5QH30>c/k0H0kno_0`3Zj^X301@D50@04Q8B0`0E5AD3018B4P<051@D0`3`l?030??cl`<0k^k^
0`0B4Q8300l?3`<03Ph>0`3Ti>@30>7Qh@@0d];B0`3Cdm<30>7Qh@<0h^;R0`0@410300h>3P<0410@
0`0E5AD30>g]k@H0l_;b103]kNd301<C4`<051@D0`0C4a<301DE5@<051@D0`0F5QH301LG5`<0l_;b
1P3emOD30??cl`@061PH0`0A4A43018B4P<0410@0`0E5AD30>k^kP<0kno_0`3bl_830>o_k`<0k^k^
1`0D51@301<C4`H05QHF0`0C4a<301DE5@<04A4A0`0C4a<30>k^kP<0lO7a0`3_knl30??cl`@0kno_
0`3^k^h301DE5@<0410@0`0B4Q8300l?3`<04Q8B0`3Xj>P30>CTi0<0h^;R0`3Kfm/30=gMg@@0h>3P
0`0:2PX300d=3@<0410@0`0D51@30?3`l0<0l_;b0`3`l?030?7al@<0l_;b0`3clo<C0?Cdm0H0mOGe
0`3dm?@30??cl`<0l?3`0`3alO470>k^kP<0kNg]0`3alO4301HF5P<05aLG0`0E5AD301HF5PH0l_;b
0`0E5AD701<C4`<05aLG0`3]kNd30??cl`<0kNg]0`0F5QH60?ooo`030000003oool0oooo00D0oooo
000X0?ooo`030000003oool0oooo00D0oooo0`3_knl601@D50<04Q8B0`0E5AD30>_[j`H0kno_0`3[
jn/401DE5@<04Q8B1P0D51@30>o_k`<0lo?c0`3`l?0301<C4`<03`l?1P0>3Ph30>?Sh`@0fm_K0`3D
e=@30=cLg0H0inOW0`0B4Q8300h>3P<03`l?0`0E5AD30>k^kP<0kno_103clo<60>o_k`<05QHF0`0B
4Q8301HF5P<05aLG0`0E5AD301LG5`<061PH0`3bl_830?Win@@0l_;b0`0G5aL301DE5@<04Q8B0`0A
4A4301<C4`<04Q8B0`3/k>`30?;blP<0lO7a1`3^k^h601@D50<04a<C1P0D51@301<C4`<04Q8B0`0D
51@3014A4@<04Q8B0`3]kNd40??cl`<0l_;b0`3/k>`6018B4P<0410@0`0?3`l3010@40<03Ph>0`3S
hn<30>KViP<0i>CT103UiND300X:2P<03`l?0`0E5AD301HF5P<06QXJ0`0G5aL301DE5A`04a<C1P0D
51@301DE5@<04a<C0`0D51@30>g]k@L0k>c/0`3[jn/30>g]k@H051@D0`0G5aL301HF5P<0lO7a0`3e
mOD30?3`l0L051@D0`0A4A4301@D50<0l?3`0`3clo<30>o_k`H0oooo00<000000?ooo`3oool01@3o
ool002P0oooo00<000000?ooo`3oool01@3oool30>o_k`H051@D0`0B4Q8301DE5@<0jn_[1P3_knl3
0>_[j`@05ADE0`0B4Q8601@D50<0kno_0`3clo<30?3`l0<04a<C0`0?3`l600h>3P<0hn?S103Kfm/3
0=CDe0<0g=cL1P3WinL3018B4P<03Ph>0`0?3`l301DE5@<0k^k^0`3_knl40??cl`H0kno_0`0F5QH3
018B4P<05QHF0`0G5aL301DE5@<05aLG0`0H61P30?;blP<0nOWi103bl_8301LG5`<05ADE0`0B4Q83
014A4@<04a<C0`0B4Q830>c/k0<0l_;b0`3alO470>k^kPH051@D0`0C4a<601@D50<04a<C0`0B4Q83
01@D50<04A4A0`0B4Q830>g]k@@0lo?c0`3bl_830>c/k0H04Q8B0`0@410300l?3`<0410@0`0>3Ph3
0>?Sh`<0i^KV0`3Ti>@40>GUi@<02PX:0`0?3`l301DE5@<05QHF0`0J6QX301LG5`<05ADE700C4a<6
01@D50<05ADE0`0C4a<301@D50<0kNg]1`3/k>`30>_[j`<0kNg]1P0D51@301LG5`<05QHF0`3alO43
0?Gem@<0l?3`1`0D51@3014A4@<051@D0`3`l?030??cl`<0kno_1P3oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0kno_1P0D51@3018B4P<05ADE0`3[jn/60>o_
k`<0jn_[100E5AD3018B4PH051@D0`3_knl30??cl`<0l?3`0`0C4a<300l?3`H03Ph>0`3Shn<40=_K
f`<0e=CD0`3Lg=`60>OWi`<04Q8B0`0>3Ph300l?3`<05ADE0`3^k^h30>o_k`@0lo?c1P3_knl301HF
5P<04Q8B0`0F5QH301LG5`<05ADE0`0G5aL301PH60<0l_;b0`3inOT40?;blP<05aLG0`0E5AD3018B
4P<04A4A0`0C4a<3018B4P<0k>c/0`3bl_830?7al@L0k^k^1P0D51@301<C4`H051@D0`0C4a<3018B
4P<051@D0`0A4A43018B4P<0kNg]103clo<30?;blP<0k>c/1P0B4Q83010@40<03`l?0`0@410300h>
3P<0hn?S0`3Vi^H30>CTi0@0iNGU0`0:2PX300l?3`<05ADE0`0F5QH301XJ6P<05aLG0`0E5ADL01<C
4`H051@D0`0E5AD301<C4`<051@D0`3]kNd70>c/k0<0jn_[0`3]kNd601@D50<05aLG0`0F5QH30?7a
l@<0mOGe0`3`l?0701@D50<04A4A0`0D51@30?3`l0<0lo?c0`3_knl60?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3alO4301@D50<04Q8B0`0E5AD3018B4P<0
5ADE0`3[jn/60>o_k`@0jn_[0`0E5AD6018B4P<05QHF0`3]kNd30?Cdm0<0kno_0`0B4Q83010@40<0
3`l?0`3Vi^H40>CTi0<0g]kN0`3Hf=P30>KViP<0kNg]0`3Zj^X301<C4`<03`l?0`0@410601<C4`@0
k>c/1P3clo<30>g]k@<04a<C1P0D51@601LG5`<05ADE0`0K6a/30?Cdm0@0m_Kf0`3emOD30??cl`<0
61PH0`0A4A43018B4P<0410@0`0E5AD60>k^kP<0l?3`103alO460>k^kP<04a<C0`0A4A4301<C4`<0
5ADE0`0B4Q8601@D50<04A4A0`0F5QH70>o_k`<0lo?c1P3_knl301DE5@<0410@0`0B4Q8300l?3`<0
4A4A0`3WinL30>c/k0@0jNWY0`0?3`l3010@40<06QXJ1P0P820301hN7P<06QXJ0`0F5QH301@D50<0
4Q8B3@0A4A46018B4P<04a<C0`0E5AD301LG5`<061PH1P0E5AD4014A4@<0inOW0`3[jn/60>c/k0<0
51@D0`0G5aL301DE5@<05QHF0`3bl_830?7al@<051@D100A4A4601@D50<0l?3`0`3dm?@30?7al@H0
oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool30?7al@<051@D
0`0B4Q8301DE5@<04Q8B0`0E5AD30>_[j`H0kno_103[jn/301DE5@H04Q8B0`0F5QH30>g]k@<0m?Cd
0`3_knl3018B4P<0410@0`0?3`l30>KViP@0i>CT0`3Ng]h30=SHf0<0i^KV0`3]kNd30>[ZjP<04a<C
0`0?3`l3010@40H04a<C103/k>`60??cl`<0kNg]0`0C4a<601@D50H05aLG0`0E5AD301/K6`<0m?Cd
103fm_H30?Gem@<0lo?c0`0H61P3014A4@<04Q8B0`0@410301DE5@H0k^k^0`3`l?040?7al@H0k^k^
0`0C4a<3014A4@<04a<C0`0E5AD3018B4PH051@D0`0A4A4301HF5PL0kno_0`3clo<60>o_k`<05ADE
0`0@4103018B4P<03`l?0`0A4A430>OWi`<0k>c/103YjNT300l?3`<0410@0`0J6QX6020P80<07QhN
0`0J6QX301HF5P<051@D0`0B4Q8=014A4@H04Q8B0`0C4a<301DE5@<05aLG0`0H61P601DE5@@04A4A
0`3WinL30>_[j`H0k>c/0`0D51@301LG5`<05ADE0`0F5QH30?;blP<0lO7a0`0D51@4014A4@H051@D
0`3`l?030?Cdm0<0lO7a1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?oo
o`050?ooo`<0lO7a0`0D51@3018B4P<05ADE0`0B4Q8301DE5@<0jn_[1P3_knl40>_[j`<05ADE1P0B
4Q8301HF5P<0kNg]0`3dm?@30>o_k`<04Q8B0`0@410300l?3`<0i^KV103Ti>@30=kNgP<0f=SH0`3V
i^H30>g]k@<0j^[Z0`0C4a<300l?3`<0410@1P0C4a<40>c/k0H0lo?c0`3]kNd301<C4`H051@D1P0G
5aL301DE5@<06a/K0`3dm?@40?KfmP<0mOGe0`3clo<301PH60<04A4A0`0B4Q83010@40<05ADE1P3^
k^h30?3`l0@0lO7a1P3^k^h301<C4`<04A4A0`0C4a<301DE5@<04Q8B1P0D51@3014A4@<05QHF1`3_
knl30??cl`H0kno_0`0E5AD3010@40<04Q8B0`0?3`l3014A4@<0inOW0`3/k>`40>WYj@<03`l?0`0@
410301XJ6PH0820P0`0N7Qh301XJ6P<05QHF0`0D51@3018B4Pd04A4A1P0B4Q8301<C4`<05ADE0`0G
5aL301PH60H05ADE100A4A430>OWi`<0jn_[1P3/k>`301@D50<05aLG0`0E5AD301HF5P<0l_;b0`3a
lO4301@D50@04A4A1P0D51@30?3`l0<0m?Cd0`3alO460?ooo`030000003oool0oooo00D0oooo000X
0?ooo`030000003oool0oooo00D0oooo0`3emOD30>o_k`<05aLG0`0C4a<301HF5P<04Q8B0`0E5AD3
0>_[j`<0kno_103`l?030>g]k@H04a<C0`0A4A4301@D50H0lO7a0`0D51@3014A4@<03`l?0`0>3Ph4
0>OWi`<0h^;R0`0820P30>;RhP<0j^[Z0`3alO430>c/k0<051@D0`0@410301<C4`<04A4A100F5QH6
0>o_k`<0lo?c0`3_knl30>k^kPT05ADE0`0H61P301HF5PL061PH0`3bl_830?Win@<0l_;b0`0G5aL3
01DE5@<04Q8B0`0A4A4601<C4`<0kNg]103^k^h30?7al@<0l_;b0`3_knl30?7al@<0l_;b0`3_knl3
01DE5@<051@D0`0C4a<301@D50<04a<C100D51@301<C4`<0kNg]1P3clo<30>k^kP<05QHF0`0B4Q83
01@D50<04A4A0`0C4a<30>_[j`@0l_;b0`3/k>`601HF5P<0820P0`0V9RH302@T90<071`L0`0J6QX3
01<C4`<0410@400?3`l3010@40<04Q8B1P0E5AD301XJ6P<071`L0`0I6AT4014A4@<0410@0`3YjNT3
0>[ZjP<0k>c/0`0D51@301DE5@<05aLG0`0E5AD30>o_k`<0lo?c0`3/k>`401HF5P<04a<C0`0D51@3
01PH60<0kno_0`3emOD60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo
00D0oooo0`3emOD30>o_k`<05aLG0`0C4a<301HF5P<04Q8B0`0E5AD30>_[j`<0kno_103`l?030>g]
k@H04a<C0`0A4A4301@D50H0lO7a0`0D51@3014A4@<03`l?0`0>3Ph40>OWi`<0h^;R0`0820P30>;R
hP<0j^[Z0`3alO430>c/k0<051@D0`0@410301<C4`<04A4A100F5QH60>o_k`<0lo?c0`3_knl30>k^
kPT05ADE0`0H61P301HF5PL061PH0`3bl_830?Win@<0l_;b0`0G5aL301DE5@<04Q8B0`0A4A4601<C
4`<0kNg]103^k^h30?7al@<0l_;b0`3_knl30?7al@<0l_;b0`3_knl301DE5@<051@D0`0C4a<301@D
50<04a<C100D51@301<C4`<0kNg]1P3clo<30>k^kP<05QHF0`0B4Q8301@D50<04A4A0`0C4a<30>_[
j`@0l_;b0`3/k>`601HF5P<0820P0`0V9RH302@T90<071`L0`0J6QX301<C4`<0410@400?3`l3010@
40<04Q8B1P0E5AD301XJ6P<071`L0`0I6AT4014A4@<0410@0`3YjNT30>[ZjP<0k>c/0`0D51@301DE
5@<05aLG0`0E5AD30>o_k`<0lo?c0`3/k>`401HF5P<04a<C0`0D51@301PH60<0kno_0`3emOD60?oo
o`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3emOD30>o_k`<0
5aLG0`0C4a<301HF5P<04Q8B0`0E5AD30>_[j`<0kno_103`l?030>g]k@H04a<C0`0A4A4301@D50H0
lO7a0`0D51@3014A4@<03`l?0`0>3Ph40>OWi`<0h^;R0`0820P30>;RhP<0j^[Z0`3alO430>c/k0<0
51@D0`0@410301<C4`<04A4A100F5QH60>o_k`<0lo?c0`3_knl30>k^kPT05ADE0`0H61P301HF5PL0
61PH0`3bl_830?Win@<0l_;b0`0G5aL301DE5@<04Q8B0`0A4A4601<C4`<0kNg]103^k^h30?7al@<0
l_;b0`3_knl30?7al@<0l_;b0`3_knl301DE5@<051@D0`0C4a<301@D50<04a<C100D51@301<C4`<0
kNg]1P3clo<30>k^kP<05QHF0`0B4Q8301@D50<04A4A0`0C4a<30>_[j`@0l_;b0`3/k>`601HF5P<0
820P0`0V9RH302@T90<071`L0`0J6QX301<C4`<0410@400?3`l3010@40<04Q8B1P0E5AD301XJ6P<0
71`L0`0I6AT4014A4@<0410@0`3YjNT30>[ZjP<0k>c/0`0D51@301DE5@<05aLG0`0E5AD30>o_k`<0
lo?c0`3/k>`401HF5P<04a<C0`0D51@301PH60<0kno_0`3emOD60?ooo`030000003oool0oooo00D0
oooo000X0?ooo`030000003oool0oooo00D0oooo0`3`l?030?KfmP<0kno_0`0G5aL301<C4`<05ADE
0`0B4Q8301@D50<0j^[Z103_knl30>g]k@<04Q8B0`0A4A4601@D50<0kno_0`3emOD30?3`l0<05ADE
0`0A4A4300l?3`@0k^k^0`3[jn/300P820<02`/;0`0>3Ph30>k^kP<0lo?c0`3]kNd301DE5@<04A4A
0`0C4a<4018B4P<051@D0`0C4a<30>g]k@<0l_;b0`3alO460>o_k`<05aLG0`0C4a<601LG5`@051@D
0`0J6QX30??cl`<0m_Kf0`3emOD30??cl`<061PH0`0A4A43018B4P<04A4A0`0B4Q8401<C4`<0k^k^
1P3alO430>o_k`<0l_;b0`3clo<30?7al@<0l?3`1P0E5AD301<C4`@051@D0`0A4A4301HF5P<0kno_
0`3`l?030?Gem@<0kno_0`0G5aL301<C4`<05ADE0`0B4Q8301DE5@@0kNg]0`3dm?@30>o_k`H06QXJ
0`0S8b<3024Q8@<07QhN0`3emOD30?7al@<0k>c/2P3Zj^X60>_[j`<0k>c/0`3^k^h30>g]k@<05ADE
0`0H61P301/K6`<07QhN100H61P3018B4P<0j>SX0`3[jn/30>k^kP<0l?3`1P0I6AT301@D50<04Q8B
0`3/k>`30?3`l0@0kno_0`0E5AD301LG5`<05ADE0`0I6AT30?3`l0H0oooo00<000000?ooo`3oool0
1@3oool002P0oooo00<000000?ooo`3oool01@3oool30?3`l0<0m_Kf0`3_knl301LG5`<04a<C0`0E
5AD3018B4P<051@D0`3Zj^X40>o_k`<0kNg]0`0B4Q83014A4@H051@D0`3_knl30?Gem@<0l?3`0`0E
5AD3014A4@<03`l?103^k^h30>_[j`<020P80`0;2`/300h>3P<0k^k^0`3clo<30>g]k@<05ADE0`0A
4A4301<C4`@04Q8B0`0D51@301<C4`<0kNg]0`3bl_830?7al@H0kno_0`0G5aL301<C4`H05aLG100D
51@301XJ6P<0lo?c0`3fm_H30?Gem@<0lo?c0`0H61P3014A4@<04Q8B0`0A4A43018B4P@04a<C0`3^
k^h60?7al@<0kno_0`3bl_830??cl`<0lO7a0`3`l?0601DE5@<04a<C100D51@3014A4@<05QHF0`3_
knl30?3`l0<0mOGe0`3_knl301LG5`<04a<C0`0E5AD3018B4P<05ADE103]kNd30?Cdm0<0kno_1P0J
6QX302<S8`<08B4Q0`0N7Qh30?Gem@<0lO7a0`3/k>`:0>[ZjPH0jn_[0`3/k>`30>k^kP<0kNg]0`0E
5AD301PH60<06a/K0`0N7Qh401PH60<04Q8B0`3Xj>P30>_[j`<0k^k^0`3`l?0601TI6@<051@D0`0B
4Q830>c/k0<0l?3`103_knl301DE5@<05aLG0`0E5AD301TI6@<0l?3`1P3oool00`000000oooo0?oo
o`050?ooo`00:03oool3000000D0oooo0`3`l?030?KfmP<0kno_0`0G5aL301<C4`<05ADE0`0B4Q83
01@D50<0j^[Z103_knl30>g]k@<04Q8B0`0A4A4601@D50<0kno_0`3emOD30?3`l0<05ADE0`0A4A43
00l?3`@0k^k^0`3[jn/300P820<02`/;0`0>3Ph30>k^kP<0lo?c0`3]kNd301DE5@<04A4A0`0C4a<4
018B4P<051@D0`0C4a<30>g]k@<0l_;b0`3alO460>o_k`<05aLG0`0C4a<601LG5`@051@D0`0J6QX3
0??cl`<0m_Kf0`3emOD30??cl`<061PH0`0A4A43018B4P<04A4A0`0B4Q8401<C4`<0k^k^1P3alO43
0>o_k`<0l_;b0`3clo<30?7al@<0l?3`1P0E5AD301<C4`@051@D0`0A4A4301HF5P<0kno_0`3`l?03
0?Gem@<0kno_0`0G5aL301<C4`<05ADE0`0B4Q8301DE5@@0kNg]0`3dm?@30>o_k`H06QXJ0`0S8b<3
024Q8@<07QhN0`3emOD30?7al@<0k>c/2P3Zj^X60>_[j`<0k>c/0`3^k^h30>g]k@<05ADE0`0H61P3
01/K6`<07QhN100H61P3018B4P<0j>SX0`3[jn/30>k^kP<0l?3`1P0I6AT301@D50<04Q8B0`3/k>`3
0?3`l0@0kno_0`0E5AD301LG5`<05ADE0`0I6AT30?3`l0D0oooo0P0000070?ooo`00:03oool00`00
0000oooo0?ooo`050?ooo`<061PH0`3_knl30?Gem@<0k^k^0`0F5QH3018B4P<05ADE0`0A4A43018B
4P@0kNg]0`3_knl30>[ZjP<05ADE1P0B4Q8301@D50<0lO7a0`3dm?@301@D50<04Q8B0`0A4A440?7a
l@<0l?3`0`0?3`l3010@40<04a<C1P3alO430?Gem@<0k^k^1P0D51@4018B4P<051@D0`0A4A4301HF
5PH0kno_0`3alO430?;blP<0kNg]2@0D51@401HF5P<05ADE0`0G5aL301PH60<0l_;b0`3inOT30?7a
l@<05QHF0`0D51@3014A4@<04Q8B100A4A4301@D50<04a<C0`0A4A4301@D50<0kno_0`3alO430?3`
l0<0mOGe0`3bl_830?7al@<05aLG100A4A4301@D50<04a<C1P0D51@30>o_k`<0m_Kf0`3`l?0301PH
60<04a<C0`0E5AD3014A4@@051@D0`3`l?030?Cdm0<0lO7a0`0H61P301`L70<07AdM0`0I6AT30?Cd
m0<0kNg]0`3Vi^H40>?Sh`<0iNGU0`3WinL<0>WYj@<0k>c/0`3^k^h30??cl`<071`L0`0N7Qh401/K
6`<0410@0`0A4A430>OWi`<0kno_0`3alO4601XJ6P<05ADE0`0>3Ph30>_[j`<0kNg]103_knl601PH
60<06a/K0`0F5QH301PH60H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool01@3oool301PH60<0kno_0`3emOD30>k^kP<05QHF0`0B4Q8301DE5@<04A4A0`0B4Q840>g]k@<0
kno_0`3Zj^X301DE5@H04Q8B0`0D51@30?7al@<0m?Cd0`0D51@3018B4P<04A4A103alO430?3`l0<0
3`l?0`0@410301<C4`H0lO7a0`3emOD30>k^kPH051@D100B4Q8301@D50<04A4A0`0F5QH60>o_k`<0
lO7a0`3bl_830>g]k@T051@D100F5QH301DE5@<05aLG0`0H61P30?;blP<0nOWi0`3alO4301HF5P<0
51@D0`0A4A43018B4P@04A4A0`0D51@301<C4`<04A4A0`0D51@30>o_k`<0lO7a0`3`l?030?Gem@<0
l_;b0`3alO4301LG5`@04A4A0`0D51@301<C4`H051@D0`3_knl30?KfmP<0l?3`0`0H61P301<C4`<0
5ADE0`0A4A4401@D50<0l?3`0`3dm?@30?7al@<061PH0`0L71`301dM7@<06ATI0`3dm?@30>g]k@<0
i^KV103Shn<30>GUi@<0inOW303YjNT30>c/k0<0k^k^0`3clo<301`L70<07QhN100K6a/3010@40<0
4A4A0`3WinL30>o_k`<0lO7a1P0J6QX301DE5@<03Ph>0`3[jn/30>g]k@@0kno_1P0H61P301/K6`<0
5QHF0`0H61P60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo
0`0H61P30>o_k`<0mOGe0`3^k^h301HF5P<04Q8B0`0E5AD3014A4@<04Q8B103]kNd30>o_k`<0j^[Z
0`0E5AD6018B4P<051@D0`3alO430?Cdm0<051@D0`0B4Q83014A4@@0lO7a0`3`l?0300l?3`<0410@
0`0C4a<60?7al@<0mOGe0`3^k^h601@D50@04Q8B0`0D51@3014A4@<05QHF1P3_knl30?7al@<0l_;b
0`3]kNd901@D50@05QHF0`0E5AD301LG5`<061PH0`3bl_830?Win@<0lO7a0`0F5QH301@D50<04A4A
0`0B4Q84014A4@<051@D0`0C4a<3014A4@<051@D0`3_knl30?7al@<0l?3`0`3emOD30?;blP<0lO7a
0`0G5aL4014A4@<051@D0`0C4a<601@D50<0kno_0`3fm_H30?3`l0<061PH0`0C4a<301DE5@<04A4A
100D51@30?3`l0<0m?Cd0`3alO4301PH60<071`L0`0M7Ad301TI6@<0m?Cd0`3]kNd30>KViP@0hn?S
0`3UiND30>OWi``0jNWY0`3/k>`30>k^kP<0lo?c0`0L71`301hN7P@06a/K0`0@4103014A4@<0inOW
0`3_knl30?7al@H06QXJ0`0E5AD300h>3P<0jn_[0`3]kNd40>o_k`H061PH0`0K6a/301HF5P<061PH
1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`H051@D0`3[
jn/30?;blP<0k>c/0`0E5AD301<C4`<051@D0`0C4a<40>c/k0<0kno_0`3`l?030>o_k`<05ADE0`0C
4a<3014A4@H0lo?c2@0C4a<70??cl`<051@D0`0G5aL301PH60<06ATI0`0F5QH30>o_k`<0mOGe0`3`
l?030>o_k`@05QHF0`0A4A4301@D50<04a<C1P0D51@30>k^kP<0kno_0`3clo<30>o_k`<0k^k^2P0D
51@301HF5P<051@D0`0K6a/30??cl`<0mOGe0`3dm?@30?7al@<051@D0`0C4a<4014A4@<04a<C1P0D
51@301<C4`<05ADE0`0B4Q8301@D50<0kno_0`3bl_830?Gem@<0k^k^1`0D51@301<C4`<051@D0`0B
4Q8301LG5`<0l?3`0`3fm_H30?3`l0<05aLG0`0C4a<701@D50<0kno_0`3clo<30?7al@H05ADE0`0I
6AT301PH60<0l?3`0`3]kNd30>CTi0@0h^;R0`3Ph>030>KViP<0jNWY0`3Zj^X30>SXj0<0iNGU0`3X
j>P30>c/k0<0l_;b0`0G5aL301`L70@06a/K0`0E5AD30>c/k0<0kno_0`3^k^h601HF5P<06QXJ0`0C
4a<3014A4@<0jNWY0`3[jn/40??cl`<0lO7a1P0O7al301`L70<051@D1P3oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`H051@D0`3[jn/30?;blP<0k>c/0`0E5AD3
01<C4`<051@D0`0C4a<40>c/k0<0kno_0`3`l?030>o_k`<05ADE0`0C4a<3014A4@H0lo?c2@0C4a<7
0??cl`<051@D0`0G5aL301PH60<06ATI0`0F5QH30>o_k`<0mOGe0`3`l?030>o_k`@05QHF0`0A4A43
01@D50<04a<C1P0D51@30>k^kP<0kno_0`3clo<30>o_k`<0k^k^2P0D51@301HF5P<051@D0`0K6a/3
0??cl`<0mOGe0`3dm?@30?7al@<051@D0`0C4a<4014A4@<04a<C1P0D51@301<C4`<05ADE0`0B4Q83
01@D50<0kno_0`3bl_830?Gem@<0k^k^1`0D51@301<C4`<051@D0`0B4Q8301LG5`<0l?3`0`3fm_H3
0?3`l0<05aLG0`0C4a<701@D50<0kno_0`3clo<30?7al@H05ADE0`0I6AT301PH60<0l?3`0`3]kNd3
0>CTi0@0h^;R0`3Ph>030>KViP<0jNWY0`3Zj^X30>SXj0<0iNGU0`3Xj>P30>c/k0<0l_;b0`0G5aL3
01`L70@06a/K0`0E5AD30>c/k0<0kno_0`3^k^h601HF5P<06QXJ0`0C4a<3014A4@<0jNWY0`3[jn/4
0??cl`<0lO7a1P0O7al301`L70<051@D1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`050?ooo`H051@D0`3[jn/30?;blP<0k>c/0`0E5AD301<C4`<051@D0`0C4a<40>c/
k0<0kno_0`3`l?030>o_k`<05ADE0`0C4a<3014A4@H0lo?c2@0C4a<70??cl`<051@D0`0G5aL301PH
60<06ATI0`0F5QH30>o_k`<0mOGe0`3`l?030>o_k`@05QHF0`0A4A4301@D50<04a<C1P0D51@30>k^
kP<0kno_0`3clo<30>o_k`<0k^k^2P0D51@301HF5P<051@D0`0K6a/30??cl`<0mOGe0`3dm?@30?7a
l@<051@D0`0C4a<4014A4@<04a<C1P0D51@301<C4`<05ADE0`0B4Q8301@D50<0kno_0`3bl_830?Ge
m@<0k^k^1`0D51@301<C4`<051@D0`0B4Q8301LG5`<0l?3`0`3fm_H30?3`l0<05aLG0`0C4a<701@D
50<0kno_0`3clo<30?7al@H05ADE0`0I6AT301PH60<0l?3`0`3]kNd30>CTi0@0h^;R0`3Ph>030>KV
iP<0jNWY0`3Zj^X30>SXj0<0iNGU0`3Xj>P30>c/k0<0l_;b0`0G5aL301`L70@06a/K0`0E5AD30>c/
k0<0kno_0`3^k^h601HF5P<06QXJ0`0C4a<3014A4@<0jNWY0`3[jn/40??cl`<0lO7a1P0O7al301`L
70<051@D1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0
51@D1P0<30`30>OWi`<0kNg]0`3[jn/3018B4P<051@D0`0B4Q8401<C4`<0k^k^0`3`l?030?;blPH0
4a<C0`0B4Q830??cl`<0m?Cd2@0C4a<40?Cdm0<0mOGe0`0G5aL301dM7@<08R8R0`0N7Qh301LG5`<0
6ATI0`3_knl30?Cdm0<0lo?c103]kNd301<C4`<051@D0`0C4a<301@D50<04a<C0`0D51@301<C4`<0
k>c/0`3bl_830?7al@L0k^k^0`0G5aL301<C4`<05aLG0`0F5QH601LG5`<0lO7a0`3fm_H30?7al@<0
k^k^100C4a<3014A4@<05ADE0`0C4a<301DE5@H051@D0`0B4Q8601@D50<0k^k^0`3dm?@40>o_k`<0
k^k^0`0F5QH3018B4P<05QHF0`0C4a<301LG5`<0kno_0`3emOD30>o_k`<05aLG1`0C4a<301HF5P<0
kNg]0`3clo<30>k^kP<061PH1P0D51@301HF5P<0j>SX0`3Zj^X40>?Sh`<01`L70`0:2PX600h>3P<0
30`<0`0:2PX30>KViP<0k>c/0`3alO4301HF5P<06QXJ100H61P301<C4`<0l?3`0`3alO430>k^kP<0
5ADE0`0I6AT301PH60<051@D0`3/k>`60>k^kP@0kNg]0`0J6QX301TI6@<07QhN0`0K6a/301@D50H0
oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool301@D50H030`<
0`3WinL30>g]k@<0jn_[0`0B4Q8301@D50<04Q8B100C4a<30>k^kP<0l?3`0`3bl_8601<C4`<04Q8B
0`3clo<30?Cdm0T04a<C103dm?@30?Gem@<05aLG0`0M7Ad3028R8P<07QhN0`0G5aL301TI6@<0kno_
0`3dm?@30??cl`@0kNg]0`0C4a<301@D50<04a<C0`0D51@301<C4`<051@D0`0C4a<30>c/k0<0l_;b
0`3alO470>k^kP<05aLG0`0C4a<301LG5`<05QHF1P0G5aL30?7al@<0m_Kf0`3alO430>k^kP@04a<C
0`0A4A4301DE5@<04a<C0`0E5AD601@D50<04Q8B1P0D51@30>k^kP<0m?Cd103_knl30>k^kP<05QHF
0`0B4Q8301HF5P<04a<C0`0G5aL30>o_k`<0mOGe0`3_knl301LG5`L04a<C0`0F5QH30>g]k@<0lo?c
0`3^k^h301PH60H051@D0`0F5QH30>SXj0<0j^[Z103Shn<300L71`<02PX:1P0>3Ph300`<30<02PX:
0`3Vi^H30>c/k0<0lO7a0`0F5QH301XJ6P@061PH0`0C4a<30?3`l0<0lO7a0`3^k^h301DE5@<06ATI
0`0H61P301@D50<0k>c/1P3^k^h40>g]k@<06QXJ0`0I6AT301hN7P<06a/K0`0D51@60?ooo`030000
003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0D51@600`<30<0inOW0`3]
kNd30>_[j`<04Q8B0`0D51@3018B4P@04a<C0`3^k^h30?3`l0<0l_;b1P0C4a<3018B4P<0lo?c0`3d
m?@901<C4`@0m?Cd0`3emOD301LG5`<07AdM0`0R8R8301hN7P<05aLG0`0I6AT30>o_k`<0m?Cd0`3c
lo<40>g]k@<04a<C0`0D51@301<C4`<051@D0`0C4a<301@D50<04a<C0`3/k>`30?;blP<0lO7a1`3^
k^h301LG5`<04a<C0`0G5aL301HF5PH05aLG0`3alO430?KfmP<0lO7a0`3^k^h401<C4`<04A4A0`0E
5AD301<C4`<05ADE1P0D51@3018B4PH051@D0`3^k^h30?Cdm0@0kno_0`3^k^h301HF5P<04Q8B0`0F
5QH301<C4`<05aLG0`3_knl30?Gem@<0kno_0`0G5aL701<C4`<05QHF0`3]kNd30??cl`<0k^k^0`0H
61P601@D50<05QHF0`3Xj>P30>[ZjP@0hn?S0`071`L300X:2PH03Ph>0`0<30`300X:2P<0i^KV0`3/
k>`30?7al@<05QHF0`0J6QX401PH60<04a<C0`3`l?030?7al@<0k^k^0`0E5AD301TI6@<061PH0`0D
51@30>c/k0H0k^k^103]kNd301XJ6P<06ATI0`0N7Qh301/K6`<051@D1P3oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<04Q8B0`0;2`/300L71`<0gmoO0`3Ti>@3
0>OWi`<0410@0`0A4A4701@D50<0kno_0`3dm?@30??cl`<051@D0`0C4a<3018B4P<0lo?c0`3dm?@3
01@D50<04a<C0`0D51@40?Cdm0<0mOGe0`0H61P3020P80<0:2PX0`0V9RH301lO7`<05aLG0`0I6AT6
0?3`l0@0lo?c0`3`l?030>o_k`<05aLG0`0B4Q8601DE5@<04Q8B0`0F5QH60>k^kP<0l?3`103alO43
0>g]k@<05QHF0`0B4Q8601LG5`<051@D0`0H61P30>o_k`<0m?Cd0`3bl_840>o_k`<0lO7a0`3_knl3
01@D50<04Q8B0`0D51@301HF5P<04a<C0`0D51@3014A4@<05ADE0`3]kNd70?7al@<0k>c/0`0E5AD3
01<C4`<05aLG0`0C4a<301DE5@<0lO7a0`3dm?@30?3`l0L051@D0`0A4A4301@D50<0l?3`0`3clo<3
0?3`l0H05ADE1P0A4A430>c/k0@0jNWY1P0<30`301<C4`<05ADE0`0A4A4300d=3@<0k>c/0`3`l?03
0>o_k`<061PH0`0I6AT701DE5@H0l?3`0`0E5AD301@D50<061PH0`0C4a<301@D50<0kno_0`3`l?03
0>_[j`@05ADE0`0C4a<301PH60<05aLG0`0I6AT3018B4PH0oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool01@3oool3018B4P<02`/;0`071`L30=oOg`<0i>CT0`3WinL3010@
40<04A4A1`0D51@30>o_k`<0m?Cd0`3clo<301@D50<04a<C0`0B4Q830??cl`<0m?Cd0`0D51@301<C
4`<051@D103dm?@30?Gem@<061PH0`0P820302PX:0<09RHV0`0O7al301LG5`<06ATI1P3`l?040??c
l`<0l?3`0`3_knl301LG5`<04Q8B1P0E5AD3018B4P<05QHF1P3^k^h30?3`l0@0lO7a0`3]kNd301HF
5P<04Q8B1P0G5aL301@D50<061PH0`3_knl30?Cdm0<0l_;b103_knl30?7al@<0kno_0`0D51@3018B
4P<051@D0`0F5QH301<C4`<051@D0`0A4A4301DE5@<0kNg]1`3alO430>c/k0<05ADE0`0C4a<301LG
5`<04a<C0`0E5AD30?7al@<0m?Cd0`3`l?0701@D50<04A4A0`0D51@30?3`l0<0lo?c0`3`l?0601DE
5@H04A4A0`3/k>`40>WYj@H030`<0`0C4a<301DE5@<04A4A0`0=3@d30>c/k0<0l?3`0`3_knl301PH
60<06ATI1`0E5AD60?3`l0<05ADE0`0D51@301PH60<04a<C0`0D51@30>o_k`<0l?3`0`3[jn/401DE
5@<04a<C0`0H61P301LG5`<06ATI0`0B4Q860?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo00D0oooo0`0B4Q8300/;2`<01`L70`3Ogml30>CTi0<0inOW0`0@4103014A4@L0
51@D0`3_knl30?Cdm0<0lo?c0`0D51@301<C4`<04Q8B0`3clo<30?Cdm0<051@D0`0C4a<301@D50@0
m?Cd0`3emOD301PH60<0820P0`0X:2P302HV9P<07alO0`0G5aL301TI6@H0l?3`103clo<30?3`l0<0
kno_0`0G5aL3018B4PH05ADE0`0B4Q8301HF5PH0k^k^0`3`l?040?7al@<0kNg]0`0F5QH3018B4PH0
5aLG0`0D51@301PH60<0kno_0`3dm?@30?;blP@0kno_0`3alO430>o_k`<051@D0`0B4Q8301@D50<0
5QHF0`0C4a<301@D50<04A4A0`0E5AD30>g]k@L0lO7a0`3/k>`301DE5@<04a<C0`0G5aL301<C4`<0
5ADE0`3alO430?Cdm0<0l?3`1`0D51@3014A4@<051@D0`3`l?030??cl`<0l?3`1P0E5AD6014A4@<0
k>c/103YjNT600`<30<04a<C0`0E5AD3014A4@<03@d=0`3/k>`30?3`l0<0kno_0`0H61P301TI6@L0
5ADE1P3`l?0301DE5@<051@D0`0H61P301<C4`<051@D0`3_knl30?3`l0<0jn_[100E5AD301<C4`<0
61PH0`0G5aL301TI6@<04Q8B1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`050?ooo`<0l_;b0`3/k>`30>;RhP<0g]kN0`3Jf]X30>CTi0<0i^KV0`0@410301<C4`@051@D
0`0I6AT30?;blP<0moOg0`0F5QH301<C4`<04A4A0`3clo<30?Cdm0T051@D103dm?@30?Gem@<061PH
0`0O7al302HV9P<092@T0`0O7al301/K6`H05ADE0`0D51@40>k^kPH0m?Cd0`3^k^h601DE5@<04a<C
0`0D51@601<C4`<04Q8B0`3[jn/40?7al@<0l_;b0`3/k>`301@D50H05ADE0`0G5aL301@D50<061PH
0`3`l?030?7al@@0kno_0`3bl_830??cl`<0l?3`0`3bl_830?Cdm0<0l_;b0`0G5aL3014A4@<04a<C
0`0@410301@D50@0jn_[1P3`l?030>c/k0<05aLG0`0D51@301HF5P<05ADE0`3`l?030??cl`<0l?3`
0`0C4a<4014A4@H051@D0`3_knl30??cl`<0lO7a0`0E5AD301<C4`<05ADE0`0C4a<30>g]k@@0lO7a
0`3/k>`3018B4P<05aLG0`0J6QX301DE5@<0410@1P3_knl601@D50<05aLG100F5QH30?3`l0<0mOGe
0`3`l?0301DE5@<05QHF0`0D51@301LG5`<0k^k^0`3clo<30>c/k0<051@D100@4103018B4P<05QHF
0`0H61P60?;blPH0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3o
ool30?;blP<0k>c/0`3Rh^830=kNgP<0f][J0`3Ti>@30>KViP<0410@0`0C4a<401@D50<06ATI0`3b
l_830?Ogm`<05QHF0`0C4a<3014A4@<0lo?c0`3dm?@901@D50@0m?Cd0`3emOD301PH60<07alO0`0V
9RH302@T90<07alO0`0K6a/601DE5@<051@D103^k^h60?Cdm0<0k^k^1P0E5AD301<C4`<051@D1P0C
4a<3018B4P<0jn_[103alO430?;blP<0k>c/0`0D51@601DE5@<05aLG0`0D51@301PH60<0l?3`0`3a
lO440>o_k`<0l_;b0`3clo<30?3`l0<0l_;b0`3dm?@30?;blP<05aLG0`0A4A4301<C4`<0410@0`0D
51@40>_[j`H0l?3`0`3/k>`301LG5`<051@D0`0F5QH301DE5@<0l?3`0`3clo<30?3`l0<04a<C100A
4A4601@D50<0kno_0`3clo<30?7al@<05ADE0`0C4a<301DE5@<04a<C0`3]kNd40?7al@<0k>c/0`0B
4Q8301LG5`<06QXJ0`0E5AD3010@40H0kno_1P0D51@301LG5`@05QHF0`3`l?030?Gem@<0l?3`0`0E
5AD301HF5P<051@D0`0G5aL30>k^kP<0lo?c0`3/k>`301@D50@0410@0`0B4Q8301HF5P<061PH1P3b
l_860?ooo`030000003oool0oooo00D0oooo000:0?ooo`L000000`3oool4000000D0oooo10000007
0?ooo`030000003oool0oooo00D0oooo0`3bl_830>c/k0<0h^;R0`3Ng]h30=[JfP<0i>CT0`3Vi^H3
010@40<04a<C100D51@301TI6@<0l_;b0`3gmoL301HF5P<04a<C0`0A4A430??cl`<0m?Cd2@0D51@4
0?Cdm0<0mOGe0`0H61P301lO7`<09RHV0`0T92@301lO7`<06a/K1P0E5AD301@D50@0k^k^1P3dm?@3
0>k^kPH05ADE0`0C4a<301@D50H04a<C0`0B4Q830>_[j`@0lO7a0`3bl_830>c/k0<051@D1P0E5AD3
01LG5`<051@D0`0H61P30?3`l0<0lO7a103_knl30?;blP<0lo?c0`3`l?030?;blP<0m?Cd0`3bl_83
01LG5`<04A4A0`0C4a<3010@40<051@D103[jn/60?3`l0<0k>c/0`0G5aL301@D50<05QHF0`0E5AD3
0?3`l0<0lo?c0`3`l?0301<C4`@04A4A1P0D51@30>o_k`<0lo?c0`3alO4301DE5@<04a<C0`0E5AD3
01<C4`<0kNg]103alO430>c/k0<04Q8B0`0G5aL301XJ6P<05ADE0`0@41060>o_k`H051@D0`0G5aL4
01HF5P<0l?3`0`3emOD30?3`l0<05ADE0`0F5QH301@D50<05aLG0`3^k^h30??cl`<0k>c/0`0D51@4
010@40<04Q8B0`0F5QH301PH60H0l_;b1P3oool00`000000oooo0?ooo`050?ooo`003@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool30?;blP<0k>c/0`3Rh^83
0=kNgP<0f][J0`3Ti>@30>KViP<0410@0`0C4a<401@D50<06ATI0`3bl_830?Ogm`<05QHF0`0C4a<3
014A4@<0lo?c0`3dm?@901@D50@0m?Cd0`3emOD301PH60<07alO0`0V9RH302@T90<07alO0`0K6a/6
01DE5@<051@D103^k^h60?Cdm0<0k^k^1P0E5AD301<C4`<051@D1P0C4a<3018B4P<0jn_[103alO43
0?;blP<0k>c/0`0D51@601DE5@<05aLG0`0D51@301PH60<0l?3`0`3alO440>o_k`<0l_;b0`3clo<3
0?3`l0<0l_;b0`3dm?@30?;blP<05aLG0`0A4A4301<C4`<0410@0`0D51@40>_[j`H0l?3`0`3/k>`3
01LG5`<051@D0`0F5QH301DE5@<0l?3`0`3clo<30?3`l0<04a<C100A4A4601@D50<0kno_0`3clo<3
0?7al@<05ADE0`0C4a<301DE5@<04a<C0`3]kNd40?7al@<0k>c/0`0B4Q8301LG5`<06QXJ0`0E5AD3
010@40H0kno_1P0D51@301LG5`@05QHF0`3`l?030?Gem@<0l?3`0`0E5AD301HF5P<051@D0`0G5aL3
0>k^kP<0lo?c0`3/k>`301@D50@0410@0`0B4Q8301HF5P<061PH1P3bl_860?ooo`030000003oool0
oooo00D0oooo000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`<0kno_0`3Zj^X30>KViP<0fm_K0`3Cdm<30=[JfP<0hn?S0`0=3@d300l?3`L051@D0`0M7Ad3
0?Cdm0<061PH0`0A4A4301@D50<0lO7a0`3dm?@601@D50<04a<C103dm?@30?Gem@<061PH0`0M7Ad3
020P80<08R8R0`0L71`301/K6`<05QHF0`0E5AD301<C4`@06ATI0`3alO430?;blP<0mOGe0`3bl_83
0?3`l0<05ADE0`0D51@601<C4`<04A4A0`0E5AD40>k^kP<0kno_0`3clo<60?3`l0<061PH0`0C4a<3
01DE5@<051@D0`0F5QH3018B4P@051@D0`3`l?090?;blP<0lO7a0`3emOD30>k^kPH04a<C0`0@4103
00l?3`@04a<C0`3Zj^X30?3`l0<0lO7a0`3_knl301DE5@<05QHF0`0D51@301LG5`<0kNg]0`3clo<3
0>g]k@@05QHF1P0C4a<301LG5`<0k^k^0`3dm?@30?3`l0<05ADE0`0F5QH3018B4P<04a<C1`3_knl6
01DE5@<06QXJ0`0E5AD301@D50<0l?3`0`3bl_8301<C4`<05ADE0`0D51@401HF5PH0l_;b0`0E5AD3
01<C4`<051@D0`0H61P30>k^kP<0m?Cd0`3]kNd301@D50<03`l?100@410301LG5`<0l_;b0`3dm?@3
0?;blP<0kno_1P3oool00`000000oooo0?ooo`050?ooo`003@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool30>o_k`<0j^[Z0`3Vi^H30=_Kf`<0dm?C0`3Jf]X3
0>?Sh`<03@d=0`0?3`l701@D50<07AdM0`3dm?@301PH60<04A4A0`0D51@30?7al@<0m?Cd1P0D51@3
01<C4`@0m?Cd0`3emOD301PH60<07AdM0`0P8203028R8P<071`L0`0K6a/301HF5P<05ADE0`0C4a<4
01TI6@<0lO7a0`3bl_830?Gem@<0l_;b0`3`l?0301DE5@<051@D1P0C4a<3014A4@<05ADE103^k^h3
0>o_k`<0lo?c1P3`l?0301PH60<04a<C0`0E5AD301@D50<05QHF0`0B4Q8401@D50<0l?3`2@3bl_83
0?7al@<0mOGe0`3^k^h601<C4`<0410@0`0?3`l401<C4`<0j^[Z0`3`l?030?7al@<0kno_0`0E5AD3
01HF5P<051@D0`0G5aL30>g]k@<0lo?c0`3]kNd401HF5PH04a<C0`0G5aL30>k^kP<0m?Cd0`3`l?03
01DE5@<05QHF0`0B4Q8301<C4`L0kno_1P0E5AD301XJ6P<05ADE0`0D51@30?3`l0<0l_;b0`0C4a<3
01DE5@<051@D100F5QH60?;blP<05ADE0`0C4a<301@D50<061PH0`3^k^h30?Cdm0<0kNg]0`0D51@3
00l?3`@0410@0`0G5aL30?;blP<0m?Cd0`3bl_830>o_k`H0oooo00<000000?ooo`3oool01@3oool0
00030?ooo`000000000000@000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo10000004
0?ooo`<0kno_0`3Zj^X30>KViP<0fm_K0`3Cdm<30=[JfP<0hn?S0`0=3@d300l?3`L051@D0`0M7Ad3
0?Cdm0<061PH0`0A4A4301@D50<0lO7a0`3dm?@601@D50<04a<C103dm?@30?Gem@<061PH0`0M7Ad3
020P80<08R8R0`0L71`301/K6`<05QHF0`0E5AD301<C4`@06ATI0`3alO430?;blP<0mOGe0`3bl_83
0?3`l0<05ADE0`0D51@601<C4`<04A4A0`0E5AD40>k^kP<0kno_0`3clo<60?3`l0<061PH0`0C4a<3
01DE5@<051@D0`0F5QH3018B4P@051@D0`3`l?090?;blP<0lO7a0`3emOD30>k^kPH04a<C0`0@4103
00l?3`@04a<C0`3Zj^X30?3`l0<0lO7a0`3_knl301DE5@<05QHF0`0D51@301LG5`<0kNg]0`3clo<3
0>g]k@@05QHF1P0C4a<301LG5`<0k^k^0`3dm?@30?3`l0<05ADE0`0F5QH3018B4P<04a<C1`3_knl6
01DE5@<06QXJ0`0E5AD301@D50<0l?3`0`3bl_8301<C4`<05ADE0`0D51@401HF5PH0l_;b0`0E5AD3
01<C4`<051@D0`0H61P30>k^kP<0m?Cd0`3]kNd301@D50<03`l?100@410301LG5`<0l_;b0`3dm?@3
0?;blP<0kno_103oool3000000L0oooo000=0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`<030`<0`0=3@d30>;RhP<0hn?S0`3GemL30=GEe@<0h>3P0`3QhN43
010@40@03`l?1P0D51@301XJ6PH04Q8B0`3_knl30?Gem@<0lO7a0`0F5QH301<C4`<04Q8B103dm?@3
0?Gem@<05aLG0`0J6QX301lO7`H0n?Sh0`3dm?@601XJ6PL061PH0`0I6AT301PH60<0lO7a0`3bl_83
0?Gem@<0lO7a0`3`l?0301HF5P<04A4A0`0C4a<3018B4PL04a<C0`3]kNd60??cl`<0k^k^1P0E5AD3
01<C4`H05ADE100C4a<301HF5PH051@D0`0B4Q8301@D50<0k^k^0`3dm?@30>o_k`<0k^k^0`0D51@3
00l?3`@03Ph>0`0C4a<30>_[j`<0l_;b0`3`l?0301@D50<04Q8B0`0F5QH3018B4P<051@D0`3`l?03
0??cl`@0kno_0`0D51@301DE5@<04Q8B0`0D51@30?7al@<0l_;b0`0E5AD301<C4`<051@D0`0B4Q84
0?7al@<0l_;b0`3_knl601HF5P<05aLG0`3alO430?Gem@<0l?3`2@0E5AD40?3`l0<0mOGe0`3`l?06
01DE5@<05QHF0`3alO430??cl`<0l?3`0`0C4a<300l?3`<04A4A100F5QH30?3`l0<0m_Kf0`3_knl3
018B4P<030`<1P3oool00`000000oooo0?ooo`050?ooo`003@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool300`<30<03@d=0`3Rh^830>?Sh`<0emOG0`3EeMD3
0>3Ph0<0hN7Q0`0@410400l?3`H051@D0`0J6QX6018B4P<0kno_0`3emOD30?7al@<05QHF0`0C4a<3
018B4P@0m?Cd0`3emOD301LG5`<06QXJ0`0O7al60?Shn0<0m?Cd1P0J6QX701PH60<06ATI0`0H61P3
0?7al@<0l_;b0`3emOD30?7al@<0l?3`0`0F5QH3014A4@<04a<C0`0B4Q8701<C4`<0kNg]1P3clo<3
0>k^kPH05ADE0`0C4a<601DE5@@04a<C0`0F5QH601@D50<04Q8B0`0D51@30>k^kP<0m?Cd0`3_knl3
0>k^kP<051@D0`0?3`l400h>3P<04a<C0`3[jn/30?;blP<0l?3`0`0D51@3018B4P<05QHF0`0B4Q83
01@D50<0l?3`0`3clo<40>o_k`<051@D0`0E5AD3018B4P<051@D0`3alO430?;blP<05ADE0`0C4a<3
01@D50<04Q8B103alO430?;blP<0kno_1P0F5QH301LG5`<0lO7a0`3emOD30?3`l0T05ADE103`l?03
0?Gem@<0l?3`1P0E5AD301HF5P<0lO7a0`3clo<30?3`l0<04a<C0`0?3`l3014A4@@05QHF0`3`l?03
0?KfmP<0kno_0`0B4Q8300`<30H0oooo00<000000?ooo`3oool01@3oool000/0oooo0`0000050?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool300`<30<03@d=0`3Rh^830>?Sh`<0emOG0`3EeMD3
0>3Ph0<0hN7Q0`0@410400l?3`H051@D0`0J6QX6018B4P<0kno_0`3emOD30?7al@<05QHF0`0C4a<3
018B4P@0m?Cd0`3emOD301LG5`<06QXJ0`0O7al60?Shn0<0m?Cd1P0J6QX701PH60<06ATI0`0H61P3
0?7al@<0l_;b0`3emOD30?7al@<0l?3`0`0F5QH3014A4@<04a<C0`0B4Q8701<C4`<0kNg]1P3clo<3
0>k^kPH05ADE0`0C4a<601DE5@@04a<C0`0F5QH601@D50<04Q8B0`0D51@30>k^kP<0m?Cd0`3_knl3
0>k^kP<051@D0`0?3`l400h>3P<04a<C0`3[jn/30?;blP<0l?3`0`0D51@3018B4P<05QHF0`0B4Q83
01@D50<0l?3`0`3clo<40>o_k`<051@D0`0E5AD3018B4P<051@D0`3alO430?;blP<05ADE0`0C4a<3
01@D50<04Q8B103alO430?;blP<0kno_1P0F5QH301LG5`<0lO7a0`3emOD30?3`l0T05ADE103`l?03
0?Gem@<0l?3`1P0E5AD301HF5P<0lO7a0`3clo<30?3`l0<04a<C0`0?3`l3014A4@@05QHF0`3`l?03
0?KfmP<0kno_0`0B4Q8300`<30H0oooo00<000000?ooo`3oool01@3oool000d0oooo00<000000?oo
o`3oool0103oool4000000D0oooo100000070?ooo`030000003oool0oooo00D0oooo0`0C4a<300`<
30<03`l?1P3Rh^830=OGe`<0f=SH1P3Shn<400l?3`<04A4A1P0@4103018B4P<04A4A0`3alO430?;b
lP<05ADE1P0B4Q8301DE5@@0lo?c0`3fm_H301PH60<06QXJ0`0L71`30?Win@H0moOg0`3fm_H30?Wi
n@<08B4Q100P820301lO7`<06QXJ0`0I6AT301LG5`<0kno_0`3dm?@30??cl`<0kNg]0`0C4a<301@D
50<04Q8B100D51@3014A4@<05QHF0`3`l?030?7al@<0m?Cd0`3bl_830?3`l0<05QHF0`0E5AD301<C
4`X05ADE0`0F5QH301DE5@<04Q8B0`0E5AD30>g]k@H0lO7a0`3[jn/301@D50L0410@0`0E5AD30>g]
k@<0m?Cd0`3^k^h301HF5P<04a<C0`0E5AD301@D50<0kno_0`3clo<40?3`l0<05ADE0`0C4a<301HF
5P<05ADE0`3`l?030?Gem@<0l?3`1P0D51@301DE5@@0kno_0`3bl_830?7al@<04Q8B1P0C4a<30??c
l`<0lO7a0`0D51@3018B4P<04a<C0`0E5AD40?7al@<0l?3`0`0D51@301<C4`<05ADE0`0C4a<30?;b
lP<0lo?c0`3^k^h301<C4`<04Q8B0`0C4a<40?3`l0<0mOGe0`3^k^h301DE5@<03Ph>0`0C4a<60?oo
o`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0C4a<300`<30<0
3`l?1P3Rh^830=OGe`<0f=SH1P3Shn<400l?3`<04A4A1P0@4103018B4P<04A4A0`3alO430?;blP<0
5ADE1P0B4Q8301DE5@@0lo?c0`3fm_H301PH60<06QXJ0`0L71`30?Win@H0moOg0`3fm_H30?Win@<0
8B4Q100P820301lO7`<06QXJ0`0I6AT301LG5`<0kno_0`3dm?@30??cl`<0kNg]0`0C4a<301@D50<0
4Q8B100D51@3014A4@<05QHF0`3`l?030?7al@<0m?Cd0`3bl_830?3`l0<05QHF0`0E5AD301<C4`X0
5ADE0`0F5QH301DE5@<04Q8B0`0E5AD30>g]k@H0lO7a0`3[jn/301@D50L0410@0`0E5AD30>g]k@<0
m?Cd0`3^k^h301HF5P<04a<C0`0E5AD301@D50<0kno_0`3clo<40?3`l0<05ADE0`0C4a<301HF5P<0
5ADE0`3`l?030?Gem@<0l?3`1P0D51@301DE5@@0kno_0`3bl_830?7al@<04Q8B1P0C4a<30??cl`<0
lO7a0`0D51@3018B4P<04a<C0`0E5AD40?7al@<0l?3`0`0D51@301<C4`<05ADE0`0C4a<30?;blP<0
lo?c0`3^k^h301<C4`<04Q8B0`0C4a<40?3`l0<0mOGe0`3^k^h301DE5@<03Ph>0`0C4a<60?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0C4a<300`<30<03`l?
1P3Rh^830=OGe`<0f=SH1P3Shn<400l?3`<04A4A1P0@4103018B4P<04A4A0`3alO430?;blP<05ADE
1P0B4Q8301DE5@@0lo?c0`3fm_H301PH60<06QXJ0`0L71`30?Win@H0moOg0`3fm_H30?Win@<08B4Q
100P820301lO7`<06QXJ0`0I6AT301LG5`<0kno_0`3dm?@30??cl`<0kNg]0`0C4a<301@D50<04Q8B
100D51@3014A4@<05QHF0`3`l?030?7al@<0m?Cd0`3bl_830?3`l0<05QHF0`0E5AD301<C4`X05ADE
0`0F5QH301DE5@<04Q8B0`0E5AD30>g]k@H0lO7a0`3[jn/301@D50L0410@0`0E5AD30>g]k@<0m?Cd
0`3^k^h301HF5P<04a<C0`0E5AD301@D50<0kno_0`3clo<40?3`l0<05ADE0`0C4a<301HF5P<05ADE
0`3`l?030?Gem@<0l?3`1P0D51@301DE5@@0kno_0`3bl_830?7al@<04Q8B1P0C4a<30??cl`<0lO7a
0`0D51@3018B4P<04a<C0`0E5AD40?7al@<0l?3`0`0D51@301<C4`<05ADE0`0C4a<30?;blP<0lo?c
0`3^k^h301<C4`<04Q8B0`0C4a<40?3`l0<0mOGe0`3^k^h301DE5@<03Ph>0`0C4a<60?ooo`030000
003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3dm?@301HF5P<03Ph>0`0?
3`l30>3Ph0<0gmoO0`3GemL30=gMg@<0i^KV103YjNT30>_[j`<0410@0`0A4A430>k^kP<0l?3`0`3e
mOD30?3`l0<051@D0`0C4a<301@D50<0l?3`103fm_H30??cl`<071`L0`0M7Ad3020P80<0n?Sh0`3g
moL30?KfmP<0n?Sh0`3jn_X302@T90@09RHV0`0Y:BT302HV9P<07alO0`0G5aL301XJ6PH0l?3`0`3c
lo<30?3`l0<0kno_0`0F5QH4014A4@<051@D0`0C4a<601DE5@<0l?3`0`3bl_830?Gem@<0l_;b0`3`
l?0301DE5@@04Q8B0`0D51@301HF5P<051@D0`0F5QH301DE5@<04A4A0`0D51@30>_[j`H0l?3`0`3^
k^h4018B4P<04a<C0`0A4A4301DE5@<0k^k^0`3dm?@30>k^kP<05aLG1P0C4a<301HF5P<0kNg]103c
lo<30>o_k`<05ADE0`0F5QH301<C4`<051@D0`3`l?030?7al@<05ADE1P0B4Q8401<C4`<0kno_0`3`
l?0600l?3`<0410@1P3alO43014A4@<04a<C0`0E5AD30?3`l0@0lo?c0`3bl_8301<C4`<05ADE0`0D
51@301DE5@H0l?3`0`0D51@6018B4P<05ADE103bl_830?7al@<04a<C0`0?3`l301HF5P<0m?Cd1P3o
ool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0m?Cd0`0F5QH3
00h>3P<03`l?0`3Ph>030=oOg`<0emOG0`3MgMd30>KViP@0jNWY0`3[jn/3010@40<04A4A0`3^k^h3
0?3`l0<0mOGe0`3`l?0301@D50<04a<C0`0D51@30?3`l0@0m_Kf0`3clo<301`L70<07AdM0`0P8203
0?Shn0<0moOg0`3fm_H30?Shn0<0n_[j0`0T92@402HV9P<0:BTY0`0V9RH301lO7`<05aLG0`0J6QX6
0?3`l0<0lo?c0`3`l?030>o_k`<05QHF100A4A4301@D50<04a<C1P0E5AD30?3`l0<0l_;b0`3emOD3
0?;blP<0l?3`0`0E5AD4018B4P<051@D0`0F5QH301@D50<05QHF0`0E5AD3014A4@<051@D0`3[jn/6
0?3`l0<0k^k^100B4Q8301<C4`<04A4A0`0E5AD30>k^kP<0m?Cd0`3^k^h301LG5`H04a<C0`0F5QH3
0>g]k@@0lo?c0`3_knl301DE5@<05QHF0`0C4a<301@D50<0l?3`0`3alO4301DE5@H04Q8B100C4a<3
0>o_k`<0l?3`1P0?3`l3010@40H0lO7a0`0A4A4301<C4`<05ADE0`3`l?040??cl`<0l_;b0`0C4a<3
01DE5@<051@D0`0E5AD60?3`l0<051@D1P0B4Q8301DE5@@0l_;b0`3alO4301<C4`<03`l?0`0F5QH3
0?Cdm0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool30?Cd
m0<05QHF0`0>3Ph300l?3`<0h>3P0`3Ogml30=OGe`<0gMgM0`3Vi^H40>WYj@<0jn_[0`0@4103014A
4@<0k^k^0`3`l?030?Gem@<0l?3`0`0D51@301<C4`<051@D0`3`l?040?KfmP<0lo?c0`0L71`301dM
7@<0820P0`3hn?P30?Ogm`<0m_Kf0`3hn?P30?[jnP<092@T100V9RH302TY:@<09RHV0`0O7al301LG
5`<06QXJ1P3`l?030??cl`<0l?3`0`3_knl301HF5P@04A4A0`0D51@301<C4`H05ADE0`3`l?030?;b
lP<0mOGe0`3bl_830?3`l0<05ADE100B4Q8301@D50<05QHF0`0D51@301HF5P<05ADE0`0A4A4301@D
50<0jn_[1P3`l?030>k^kP@04Q8B0`0C4a<3014A4@<05ADE0`3^k^h30?Cdm0<0k^k^0`0G5aL601<C
4`<05QHF0`3]kNd40??cl`<0kno_0`0E5AD301HF5P<04a<C0`0D51@30?3`l0<0lO7a0`0E5AD6018B
4P@04a<C0`3_knl30?3`l0H03`l?0`0@41060?7al@<04A4A0`0C4a<301DE5@<0l?3`103clo<30?;b
lP<04a<C0`0E5AD301@D50<05ADE1P3`l?0301@D50H04Q8B0`0E5AD40?;blP<0lO7a0`0C4a<300l?
3`<05QHF0`3dm?@60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0
oooo0`3gmoL301PH60<051@D0`0>3Ph300`<30<0hN7Q0`3Ogml30>7Qh@<0h>3P103/k>`30>o_k`<0
k^k^0`3_knl30?Cdm0<0lO7a0`3`l?0301LG5`H04A4A0`0E5AD30??cl`@0m?Cd0`0J6QX301/K6`<0
8b<S0`0Q8B43020P80<06ATI0`0G5aL301TI6@<07alO0`0P820402PX:0<0;2`/0`0Z:RX302HV9P<0
820P0`0H61P301HF5P<051@D0`3]kNd60??cl`<0kNg]1`0D51@301<C4`<05ADE0`0D51@601HF5P<0
lO7a0`3bl_830?Gem@<0lO7a1`3bl_830>o_k`<051@D0`0B4Q8301DE5@<04A4A0`0?3`l301<C4`<0
jn_[0`3alO430>o_k`@04a<C0`0A4A4301DE5@<04A4A0`0D51@30?3`l0<0lo?c0`3`l?0601@D50<0
4A4A0`0C4a<40>o_k`<0l?3`0`0E5AD301@D50<05ADE0`0C4a<30?7al@<0lo?c0`3_knl301DE5@<0
4a<C100A4A430?7al@<0k^k^0`0?3`l300X:2P<030`<0`3_knl30?7al@<04A4A0`0B4Q8301<C4`<0
l_;b103clo<30?3`l0T05QHF0`3`l?030?Cdm0<0kno_1P0D51@301DE5@<0l?3`103emOD30>o_k`<0
4Q8B0`0A4A4301XJ6P<0moOg1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`050?ooo`<0moOg0`0H61P301@D50<03Ph>0`0<30`30>7Qh@<0gmoO0`3QhN430>3Ph0@0k>c/
0`3_knl30>k^kP<0kno_0`3dm?@30?7al@<0l?3`0`0G5aL6014A4@<05ADE0`3clo<40?Cdm0<06QXJ
0`0K6a/302<S8`<08B4Q0`0P820301TI6@<05aLG0`0I6AT301lO7`<0820P100X:2P302`/;0<0:RXZ
0`0V9RH3020P80<061PH0`0F5QH301@D50<0kNg]1P3clo<30>g]k@L051@D0`0C4a<301DE5@<051@D
1P0F5QH30?7al@<0l_;b0`3emOD30?7al@L0l_;b0`3_knl301@D50<04Q8B0`0E5AD3014A4@<03`l?
0`0C4a<30>_[j`<0lO7a0`3_knl401<C4`<04A4A0`0E5AD3014A4@<051@D0`3`l?030??cl`<0l?3`
1P0D51@3014A4@<04a<C103_knl30?3`l0<05ADE0`0D51@301DE5@<04a<C0`3alO430??cl`<0kno_
0`0E5AD301<C4`@04A4A0`3alO430>k^kP<03`l?0`0:2PX300`<30<0kno_0`3alO43014A4@<04Q8B
0`0C4a<30?;blP@0lo?c0`3`l?0901HF5P<0l?3`0`3dm?@30>o_k`H051@D0`0E5AD30?3`l0@0mOGe
0`3_knl3018B4P<04A4A0`0J6QX30?Ogm`H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool01@3oool30?Ogm`<061PH0`0D51@300h>3P<030`<0`3QhN430=oOg`<0hN7Q0`3P
h>040>c/k0<0kno_0`3^k^h30>o_k`<0m?Cd0`3alO430?3`l0<05aLG1P0A4A4301DE5@<0lo?c103d
m?@301XJ6P<06a/K0`0S8b<3024Q8@<0820P0`0I6AT301LG5`<06ATI0`0O7al3020P80@0:2PX0`0/
;2`302XZ:P<09RHV0`0P820301PH60<05QHF0`0D51@30>g]k@H0lo?c0`3]kNd701@D50<04a<C0`0E
5AD301@D50H05QHF0`3alO430?;blP<0mOGe0`3alO470?;blP<0kno_0`0D51@3018B4P<05ADE0`0A
4A4300l?3`<04a<C0`3[jn/30?7al@<0kno_100C4a<3014A4@<05ADE0`0A4A4301@D50<0l?3`0`3c
lo<30?3`l0H051@D0`0A4A4301<C4`@0kno_0`3`l?0301DE5@<051@D0`0E5AD301<C4`<0lO7a0`3c
lo<30>o_k`<05ADE0`0C4a<4014A4@<0lO7a0`3^k^h300l?3`<02PX:0`0<30`30>o_k`<0lO7a0`0A
4A43018B4P<04a<C0`3bl_840??cl`<0l?3`2@0F5QH30?3`l0<0m?Cd0`3_knl601@D50<05ADE0`3`
l?040?Gem@<0kno_0`0B4Q83014A4@<06QXJ0`3gmoL60?ooo`030000003oool0oooo00D0oooo000X
0?ooo`030000003oool0oooo00D0oooo0`3hn?P601PH60<051@D0`0=3@d30>WYj@<0j>SX0`3Ogml3
00d=3@@0j^[Z0`3`l?030?;blP<0lo?c0`3`l?0301DE5@<051@D1P0A4A4301HF5P<0kno_0`3gmoL4
0??cl`<06a/K0`0R8R8302TY:@<09bLW0`0P820301XJ6PH05aLG0`0J6QX301dM7@@0820P1P0R8R83
020P80<07QhN0`0K6a/301LG5`<04Q8B0`0F5QH30>k^kP<0kno_0`3clo<40?7al@<0l?3`0`0H61P3
01<C4`<05QHF0`0G5aL301DE5@<05QHF0`0G5aL30?7al@<0lo?c103`l?030??cl`<0l_;b0`3^k^h3
0?3`l0<0k^k^0`0D51@600h>3P<04a<C0`3/k>`30??cl`@0kNg]0`0E5AD3018B4PH051@D0`3_knl3
0??cl`<0l?3`0`0E5AD301<C4`<051@D0`0A4A440?7al@<0l_;b0`3_knl301HF5P<05ADE0`0F5QH3
0>o_k`H0l_;b1P0C4a<401@D50<0k^k^0`3alO430>OWi`<01`L70`0:2PX30>_[j`<0l?3`0`0A4A43
018B4P<04a<C0`3bl_840?3`l0<051@D0`0C4a<301DE5@<04a<C0`3bl_830?3`l0<051@D0`0C4a<3
01DE5@<04Q8B0`3bl_840?3`l0<04a<C0`0@410301HF5P<0mOGe0`3hn?P60?ooo`030000003oool0
oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3hn?P601PH60<051@D0`0=3@d30>WY
j@<0j>SX0`3Ogml300d=3@@0j^[Z0`3`l?030?;blP<0lo?c0`3`l?0301DE5@<051@D1P0A4A4301HF
5P<0kno_0`3gmoL40??cl`<06a/K0`0R8R8302TY:@<09bLW0`0P820301XJ6PH05aLG0`0J6QX301dM
7@@0820P1P0R8R83020P80<07QhN0`0K6a/301LG5`<04Q8B0`0F5QH30>k^kP<0kno_0`3clo<40?7a
l@<0l?3`0`0H61P301<C4`<05QHF0`0G5aL301DE5@<05QHF0`0G5aL30?7al@<0lo?c103`l?030??c
l`<0l_;b0`3^k^h30?3`l0<0k^k^0`0D51@600h>3P<04a<C0`3/k>`30??cl`@0kNg]0`0E5AD3018B
4PH051@D0`3_knl30??cl`<0l?3`0`0E5AD301<C4`<051@D0`0A4A440?7al@<0l_;b0`3_knl301HF
5P<05ADE0`0F5QH30>o_k`H0l_;b1P0C4a<401@D50<0k^k^0`3alO430>OWi`<01`L70`0:2PX30>_[
j`<0l?3`0`0A4A43018B4P<04a<C0`3bl_840?3`l0<051@D0`0C4a<301DE5@<04a<C0`3bl_830?3`
l0<051@D0`0C4a<301DE5@<04Q8B0`3bl_840?3`l0<04a<C0`0@410301HF5P<0mOGe0`3hn?P60?oo
o`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3hn?P601PH60<0
51@D0`0=3@d30>WYj@<0j>SX0`3Ogml300d=3@@0j^[Z0`3`l?030?;blP<0lo?c0`3`l?0301DE5@<0
51@D1P0A4A4301HF5P<0kno_0`3gmoL40??cl`<06a/K0`0R8R8302TY:@<09bLW0`0P820301XJ6PH0
5aLG0`0J6QX301dM7@@0820P1P0R8R83020P80<07QhN0`0K6a/301LG5`<04Q8B0`0F5QH30>k^kP<0
kno_0`3clo<40?7al@<0l?3`0`0H61P301<C4`<05QHF0`0G5aL301DE5@<05QHF0`0G5aL30?7al@<0
lo?c103`l?030??cl`<0l_;b0`3^k^h30?3`l0<0k^k^0`0D51@600h>3P<04a<C0`3/k>`30??cl`@0
kNg]0`0E5AD3018B4PH051@D0`3_knl30??cl`<0l?3`0`0E5AD301<C4`<051@D0`0A4A440?7al@<0
l_;b0`3_knl301HF5P<05ADE0`0F5QH30>o_k`H0l_;b1P0C4a<401@D50<0k^k^0`3alO430>OWi`<0
1`L70`0:2PX30>_[j`<0l?3`0`0A4A43018B4P<04a<C0`3bl_840?3`l0<051@D0`0C4a<301DE5@<0
4a<C0`3bl_830?3`l0<051@D0`0C4a<301DE5@<04Q8B0`3bl_840?3`l0<04a<C0`0@410301HF5P<0
mOGe0`3hn?P60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo
0`3fm_H301LG5`<061PH0`0E5AD300l?3`<0kNg]0`3Zj^X300d=3@<02`/;1`0D51@601DE5@<05QHF
1P0B4Q83010@40<05QHF0`3`l?030?Ogm`<0l_;b100M7Ad301`L70<09RHV0`0Y:BT302<S8`H06a/K
0`0G5aL301HF5P<05aLG0`0H61P@01TI6@<06QXJ0`0E5AD301@D50<04A4A1P0B4Q830>k^kP@0lO7a
0`3emOD30>o_k`H05ADE0`0D51@601LG5`<05ADE0`0G5aL301<C4`@05ADE0`3_knl30?7al@<0k^k^
1P3`l?030>[ZjP<04Q8B1P0>3Ph301<C4`<0k>c/103clo<30>g]k@<05QHF1P0C4a<301HF5P<0kNg]
0`3clo<30>o_k`H051@D0`0E5AD40>o_k`<0l_;b0`3alO43018B4P<05ADE1P0C4a<30>o_k`<0l?3`
0`0A4A4301<C4`L04A4A0`3Zj^X30>CTi0<01`L70`3Lg=`30>_[j`<0kno_2@0B4Q830??cl`@0l_;b
0`0B4Q8301DE5@<04a<C0`0D51@30?3`l0<0lO7a0`0A4A4301@D50<04a<C0`0D51@70?3`l0<0410@
0`0B4Q8301DE5@H0m_Kf1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?oo
o`050?ooo`<0m_Kf0`0G5aL301PH60<05ADE0`0?3`l30>g]k@<0j^[Z0`0=3@d300/;2`L051@D1P0E
5AD301HF5PH04Q8B0`0@410301HF5P<0l?3`0`3gmoL30?;blP@07AdM0`0L71`302HV9P<0:BTY0`0S
8b<601/K6`<05aLG0`0F5QH301LG5`<061PH400I6AT301XJ6P<05ADE0`0D51@3014A4@H04Q8B0`3^
k^h40?7al@<0mOGe0`3_knl601DE5@<051@D1P0G5aL301DE5@<05aLG0`0C4a<401DE5@<0kno_0`3a
lO430>k^kPH0l?3`0`3Zj^X3018B4PH03Ph>0`0C4a<30>c/k0@0lo?c0`3]kNd301HF5PH04a<C0`0F
5QH30>g]k@<0lo?c0`3_knl601@D50<05ADE103_knl30?;blP<0lO7a0`0B4Q8301DE5@H04a<C0`3_
knl30?3`l0<04A4A0`0C4a<7014A4@<0j^[Z0`3Ti>@300L71`<0g=cL0`3[jn/30>o_k`T04Q8B0`3c
lo<40?;blP<04Q8B0`0E5AD301<C4`<051@D0`3`l?030?7al@<04A4A0`0D51@301<C4`<051@D1`3`
l?03010@40<04Q8B0`0E5AD60?KfmPH0oooo00<000000?ooo`3oool01@3oool002P0oooo0`000005
0?ooo`<0m_Kf0`0G5aL301PH60<05ADE0`0?3`l30>g]k@<0j^[Z0`0=3@d300/;2`L051@D1P0E5AD3
01HF5PH04Q8B0`0@410301HF5P<0l?3`0`3gmoL30?;blP@07AdM0`0L71`302HV9P<0:BTY0`0S8b<6
01/K6`<05aLG0`0F5QH301LG5`<061PH400I6AT301XJ6P<05ADE0`0D51@3014A4@H04Q8B0`3^k^h4
0?7al@<0mOGe0`3_knl601DE5@<051@D1P0G5aL301DE5@<05aLG0`0C4a<401DE5@<0kno_0`3alO43
0>k^kPH0l?3`0`3Zj^X3018B4PH03Ph>0`0C4a<30>c/k0@0lo?c0`3]kNd301HF5PH04a<C0`0F5QH3
0>g]k@<0lo?c0`3_knl601@D50<05ADE103_knl30?;blP<0lO7a0`0B4Q8301DE5@H04a<C0`3_knl3
0?3`l0<04A4A0`0C4a<7014A4@<0j^[Z0`3Ti>@300L71`<0g=cL0`3[jn/30>o_k`T04Q8B0`3clo<4
0?;blP<04Q8B0`0E5AD301<C4`<051@D0`3`l?030?7al@<04A4A0`0D51@301<C4`<051@D1`3`l?03
010@40<04Q8B0`0E5AD60?KfmPD0oooo0P0000070?ooo`00:03oool00`000000oooo0?ooo`050?oo
o`<0mOGe0`0F5QH301LG5`<04a<C0`0B4Q830>g]k@<0k^k^0`0?3`l301@D50@06QXJ0`0K6a/301PH
60<05QHF0`0D51@3018B4P<04a<C0`0D51@30>o_k`<0moOg0`3alO4301/K6`@06ATI0`0Q8B4302@T
90<0820P0`0I6AT301dM7@<0m?Cd0`3fm_H90?GemA00m_Kf0`3bl_8301HF5P<04Q8B0`0C4a<300l?
3`<03Ph>0`0A4A44018B4P<0k^k^0`3emOD30?;blP<0l?3`1P0F5QH301@D50T05QHF100C4a<301DE
5@<04A4A0`0B4Q830>[ZjPH0kno_0`3Zj^X301<C4`<03`l?0`0>3Ph3018B4P@0kno_0`3bl_830>o_
k`H051@D0`0A4A4301<C4`<0kno_0`3`l?0301DE5@H04Q8B100C4a<60>o_k`<051@D0`0C4a<301@D
50<04A4A0`3`l?030>k^kP<04a<C1`0B4Q8300d=3@<0j>SX0`3Shn<30=KFeP<0h>3P0`3Xj>P30>[Z
jPH04a<C0`0B4Q870??cl`<04a<C0`0D51@301DE5@<0kno_0`3bl_830?3`l0<04Q8B0`0D51@301DE
5@<0kno_0`3alO440?3`l0<04A4A0`0C4a<301@D50H0mOGe1P3oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`050?ooo`<0mOGe0`0F5QH301LG5`<04a<C0`0B4Q830>g]k@<0
k^k^0`0?3`l301@D50@06QXJ0`0K6a/301PH60<05QHF0`0D51@3018B4P<04a<C0`0D51@30>o_k`<0
moOg0`3alO4301/K6`@06ATI0`0Q8B4302@T90<0820P0`0I6AT301dM7@<0m?Cd0`3fm_H90?GemA00
m_Kf0`3bl_8301HF5P<04Q8B0`0C4a<300l?3`<03Ph>0`0A4A44018B4P<0k^k^0`3emOD30?;blP<0
l?3`1P0F5QH301@D50T05QHF100C4a<301DE5@<04A4A0`0B4Q830>[ZjPH0kno_0`3Zj^X301<C4`<0
3`l?0`0>3Ph3018B4P@0kno_0`3bl_830>o_k`H051@D0`0A4A4301<C4`<0kno_0`3`l?0301DE5@H0
4Q8B100C4a<60>o_k`<051@D0`0C4a<301@D50<04A4A0`3`l?030>k^kP<04a<C1`0B4Q8300d=3@<0
j>SX0`3Shn<30=KFeP<0h>3P0`3Xj>P30>[ZjPH04a<C0`0B4Q870??cl`<04a<C0`0D51@301DE5@<0
kno_0`3bl_830?3`l0<04Q8B0`0D51@301DE5@<0kno_0`3alO440?3`l0<04A4A0`0C4a<301@D50H0
mOGe1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0mOGe
0`0F5QH301LG5`<04a<C0`0B4Q830>g]k@<0k^k^0`0?3`l301@D50@06QXJ0`0K6a/301PH60<05QHF
0`0D51@3018B4P<04a<C0`0D51@30>o_k`<0moOg0`3alO4301/K6`@06ATI0`0Q8B4302@T90<0820P
0`0I6AT301dM7@<0m?Cd0`3fm_H90?GemA00m_Kf0`3bl_8301HF5P<04Q8B0`0C4a<300l?3`<03Ph>
0`0A4A44018B4P<0k^k^0`3emOD30?;blP<0l?3`1P0F5QH301@D50T05QHF100C4a<301DE5@<04A4A
0`0B4Q830>[ZjPH0kno_0`3Zj^X301<C4`<03`l?0`0>3Ph3018B4P@0kno_0`3bl_830>o_k`H051@D
0`0A4A4301<C4`<0kno_0`3`l?0301DE5@H04Q8B100C4a<60>o_k`<051@D0`0C4a<301@D50<04A4A
0`3`l?030>k^kP<04a<C1`0B4Q8300d=3@<0j>SX0`3Shn<30=KFeP<0h>3P0`3Xj>P30>[ZjPH04a<C
0`0B4Q870??cl`<04a<C0`0D51@301DE5@<0kno_0`3bl_830?3`l0<04Q8B0`0D51@301DE5@<0kno_
0`3alO440?3`l0<04A4A0`0C4a<301@D50H0mOGe1P3oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`050?ooo`<0mOGe2@0E5AD30>k^kP<0l?3`0`3_knl3018B4P<06ATI100P
820301hN7P<061PH0`0G5aL3018B4P<051@D0`3_knl30?7al@<0m_Kf0`3`l?0301TI6@<05QHF100M
7Ad301lO7`H06QXJ0`0H61P30?7al@<0moOg0`3bl_830??cl`<0m?Cd2P3emOD60?Cdm0<0l_;b0`3f
m_H30?;blP<0lo?c0`3`l?0301<C4`<04A4A1`0>3Ph301@D50<0kno_0`3alO430?Gem@<0l_;b0`3`
l?0301DE5@<04a<C0`0F5QH301@D50L05ADE0`0D51@3014A4@<051@D0`3[jn/30>o_k`<0l?3`0`3]
kNd3014A4@<0410@0`0A4A440>c/k0<0lO7a0`3^k^h301<C4`<04Q8B0`0C4a<3014A4@<0lO7a0`3c
lo<30?3`l0<05ADE0`0C4a<4018B4P<0lO7a0`3bl_830>o_k`<05QHF0`0D51@3014A4@<0kno_0`3`
l?030>k^kP<051@D100A4A4300d=3@<0i^KV0`3MgMd30=GEe@<0fm_K0`3Rh^8300h>3P<0410@0`0C
4a<3014A4@L0l_;b0`0B4Q8601<C4`<0lO7a0`3`l?030?7al@<04a<C0`0D51@301<C4`<0lO7a0`3`
l?040?7al@H04a<C0`0D51@30?Cdm0<0mOGe1P3oool00`000000oooo0?ooo`050?ooo`00:03oool0
0`000000oooo0?ooo`050?ooo`<0mOGe2@0E5AD30>k^kP<0l?3`0`3_knl3018B4P<06ATI100P8203
01hN7P<061PH0`0G5aL3018B4P<051@D0`3_knl30?7al@<0m_Kf0`3`l?0301TI6@<05QHF100M7Ad3
01lO7`H06QXJ0`0H61P30?7al@<0moOg0`3bl_830??cl`<0m?Cd2P3emOD60?Cdm0<0l_;b0`3fm_H3
0?;blP<0lo?c0`3`l?0301<C4`<04A4A1`0>3Ph301@D50<0kno_0`3alO430?Gem@<0l_;b0`3`l?03
01DE5@<04a<C0`0F5QH301@D50L05ADE0`0D51@3014A4@<051@D0`3[jn/30>o_k`<0l?3`0`3]kNd3
014A4@<0410@0`0A4A440>c/k0<0lO7a0`3^k^h301<C4`<04Q8B0`0C4a<3014A4@<0lO7a0`3clo<3
0?3`l0<05ADE0`0C4a<4018B4P<0lO7a0`3bl_830>o_k`<05QHF0`0D51@3014A4@<0kno_0`3`l?03
0>k^kP<051@D100A4A4300d=3@<0i^KV0`3MgMd30=GEe@<0fm_K0`3Rh^8300h>3P<0410@0`0C4a<3
014A4@L0l_;b0`0B4Q8601<C4`<0lO7a0`3`l?030?7al@<04a<C0`0D51@301<C4`<0lO7a0`3`l?04
0?7al@H04a<C0`0D51@30?Cdm0<0mOGe1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`050?ooo`<0mOGe2@0E5AD30>k^kP<0l?3`0`3_knl3018B4P<06ATI100P820301hN
7P<061PH0`0G5aL3018B4P<051@D0`3_knl30?7al@<0m_Kf0`3`l?0301TI6@<05QHF100M7Ad301lO
7`H06QXJ0`0H61P30?7al@<0moOg0`3bl_830??cl`<0m?Cd2P3emOD60?Cdm0<0l_;b0`3fm_H30?;b
lP<0lo?c0`3`l?0301<C4`<04A4A1`0>3Ph301@D50<0kno_0`3alO430?Gem@<0l_;b0`3`l?0301DE
5@<04a<C0`0F5QH301@D50L05ADE0`0D51@3014A4@<051@D0`3[jn/30>o_k`<0l?3`0`3]kNd3014A
4@<0410@0`0A4A440>c/k0<0lO7a0`3^k^h301<C4`<04Q8B0`0C4a<3014A4@<0lO7a0`3clo<30?3`
l0<05ADE0`0C4a<4018B4P<0lO7a0`3bl_830>o_k`<05QHF0`0D51@3014A4@<0kno_0`3`l?030>k^
kP<051@D100A4A4300d=3@<0i^KV0`3MgMd30=GEe@<0fm_K0`3Rh^8300h>3P<0410@0`0C4a<3014A
4@L0l_;b0`0B4Q8601<C4`<0lO7a0`3`l?030?7al@<04a<C0`0D51@301<C4`<0lO7a0`3`l?040?7a
l@H04a<C0`0D51@30?Cdm0<0mOGe1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000
oooo0?ooo`050?ooo`<0m?Cd1P0D51@3018B4P<0l?3`0`3^k^h30>o_k`<04a<C0`0J6QX401lO7`<0
6ATI0`0K6a/30?3`l0<0lO7a0`3_knl30?Cdm0<0lO7a0`3`l?0301PH60<051@D0`0I6AT401XJ6P<0
5QHF0`0J6QX30?;blP<0lo?c0`3fm_H30>o_k`<051@D0`0B4Q8301<C4`X051@D0`0C4a<3018B4P<0
5ADE0`3alO430??cl`<0lO7a0`3emOD30?7al@<0kno_0`0D51@700h>3P<04A4A0`0C4a<30>k^kP<0
lO7a0`3emOD30?7al@<0lo?c0`3`l?0301@D50@04Q8B0`0E5AD301@D50<05ADE0`0B4Q8301DE5@<0
jn_[0`3alO430>k^kP<04A4A0`0>3Ph300l?3`@04A4A0`3]kNd30?3`l0<0kNg]1P0C4a<301@D50<0
kno_0`3clo<30?;blP<051@D1`0E5AD30>o_k`<0lo?c0`3bl_8301@D50<04a<C0`0A4A430>o_k`<0
k^k^0`3_knl3014A4@@0410@0`0=3@d30>GUi@<0f][J0`3>c/h30=SHf0<0hn?S0`0<30`6014A4@<0
4a<C0`3_knl40?7al@T04Q8B0`3alO430?;blP<0kno_0`0F5QH301DE5@<04a<C0`3alO430?;blP@0
kno_0`0E5AD601@D50H0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`050?ooo`<0m?Cd1P0D51@3018B4P<0l?3`0`3^k^h30>o_k`<04a<C0`0J6QX401lO7`<06ATI
0`0K6a/30?3`l0<0lO7a0`3_knl30?Cdm0<0lO7a0`3`l?0301PH60<051@D0`0I6AT401XJ6P<05QHF
0`0J6QX30?;blP<0lo?c0`3fm_H30>o_k`<051@D0`0B4Q8301<C4`X051@D0`0C4a<3018B4P<05ADE
0`3alO430??cl`<0lO7a0`3emOD30?7al@<0kno_0`0D51@700h>3P<04A4A0`0C4a<30>k^kP<0lO7a
0`3emOD30?7al@<0lo?c0`3`l?0301@D50@04Q8B0`0E5AD301@D50<05ADE0`0B4Q8301DE5@<0jn_[
0`3alO430>k^kP<04A4A0`0>3Ph300l?3`@04A4A0`3]kNd30?3`l0<0kNg]1P0C4a<301@D50<0kno_
0`3clo<30?;blP<051@D1`0E5AD30>o_k`<0lo?c0`3bl_8301@D50<04a<C0`0A4A430>o_k`<0k^k^
0`3_knl3014A4@@0410@0`0=3@d30>GUi@<0f][J0`3>c/h30=SHf0<0hn?S0`0<30`6014A4@<04a<C
0`3_knl40?7al@T04Q8B0`3alO430?;blP<0kno_0`0F5QH301DE5@<04a<C0`3alO430?;blP@0kno_
0`0E5AD601@D50H0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?oo
o`050?ooo`<0m?Cd1P0D51@3018B4P<0l?3`0`3^k^h30>o_k`<04a<C0`0J6QX401lO7`<06ATI0`0K
6a/30?3`l0<0lO7a0`3_knl30?Cdm0<0lO7a0`3`l?0301PH60<051@D0`0I6AT401XJ6P<05QHF0`0J
6QX30?;blP<0lo?c0`3fm_H30>o_k`<051@D0`0B4Q8301<C4`X051@D0`0C4a<3018B4P<05ADE0`3a
lO430??cl`<0lO7a0`3emOD30?7al@<0kno_0`0D51@700h>3P<04A4A0`0C4a<30>k^kP<0lO7a0`3e
mOD30?7al@<0lo?c0`3`l?0301@D50@04Q8B0`0E5AD301@D50<05ADE0`0B4Q8301DE5@<0jn_[0`3a
lO430>k^kP<04A4A0`0>3Ph300l?3`@04A4A0`3]kNd30?3`l0<0kNg]1P0C4a<301@D50<0kno_0`3c
lo<30?;blP<051@D1`0E5AD30>o_k`<0lo?c0`3bl_8301@D50<04a<C0`0A4A430>o_k`<0k^k^0`3_
knl3014A4@@0410@0`0=3@d30>GUi@<0f][J0`3>c/h30=SHf0<0hn?S0`0<30`6014A4@<04a<C0`3_
knl40?7al@T04Q8B0`3alO430?;blP<0kno_0`0F5QH301DE5@<04a<C0`3alO430?;blP@0kno_0`0E
5AD601@D50H0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`05
0?ooo`<0m?Cd0`0D51@301<C4`<04A4A0`3^k^h30>g]k@<0k^k^0`0C4a<301TI6@@06QXJ0`0G5aL3
0?3`l0<0l_;b0`3`l?030>o_k`<0k^k^0`0D51@301<C4`<04Q8B1P0D51@401HF5P<05ADE0`3^k^h3
0?Gem@<0lO7a0`3`l?0301LG5`<04A4A0`0C4a<@01@D50<04a<C0`0B4Q8301DE5@<04Q8B0`0D51@3
0?3`l0<0lO7a0`3emOD30>k^kP@04Q8B0`0A4A4600h>3P<04A4A0`0C4a<30>o_k`<0l_;b0`3`l?03
0??cl`<0kno_103`l?030>k^kP<05QHF0`0B4Q8301DE5@<04Q8B0`0E5AD30>c/k0<0l_;b0`3[jn/3
01@D50<03Ph>100@41030>c/k0<0l?3`0`3^k^h301<C4`<04Q8B0`0A4A4301<C4`<0l?3`0`3bl_83
01<C4`<05QHF100D51@301DE5@<0lO7a0`3clo<901<C4`<0l?3`1P3^k^h3010@40@03`l?0`0<30`3
0>GUi@<0f=SH0`3;bl/30=SHf0<0i>CT0`0<30`3010@40<04a<C0`3]kNd30?3`l0@0kno_0`0A4A46
018B4P<0l_;b0`3`l?0301DE5@<051@D0`0G5aL301@D50<0l_;b0`3`l?0401@D50<04a<C0`0E5AD3
01<C4`<0lo?c0`3dm?@60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo
00D0oooo0`3dm?@301@D50<04a<C0`0A4A430>k^kP<0kNg]0`3^k^h301<C4`<06ATI100J6QX301LG
5`<0l?3`0`3bl_830?3`l0<0kno_0`3^k^h301@D50<04a<C0`0B4Q8601@D50@05QHF0`0E5AD30>k^
kP<0mOGe0`3alO430?3`l0<05aLG0`0A4A4301<C4a0051@D0`0C4a<3018B4P<05ADE0`0B4Q8301@D
50<0l?3`0`3alO430?Gem@<0k^k^100B4Q83014A4@H03Ph>0`0A4A4301<C4`<0kno_0`3bl_830?3`
l0<0lo?c0`3_knl40?3`l0<0k^k^0`0F5QH3018B4P<05ADE0`0B4Q8301DE5@<0k>c/0`3bl_830>_[
j`<051@D0`0>3Ph4010@40<0k>c/0`3`l?030>k^kP<04a<C0`0B4Q83014A4@<04a<C0`3`l?030?;b
lP<04a<C0`0F5QH401@D50<05ADE0`3alO430??cl`T04a<C0`3`l?060>k^kP<0410@100?3`l300`<
30<0iNGU0`3Hf=P30<_;b`<0f=SH0`3Ti>@300`<30<0410@0`0C4a<30>g]k@<0l?3`103_knl3014A
4@H04Q8B0`3bl_830?3`l0<05ADE0`0D51@301LG5`<051@D0`3bl_830?3`l0@051@D0`0C4a<301DE
5@<04a<C0`3clo<30?Cdm0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool01@3oool30?Cdm0<051@D0`0C4a<3014A4@<0k^k^0`3]kNd30>k^kP<04a<C0`0I6AT401XJ6P<0
5aLG0`3`l?030?;blP<0l?3`0`3_knl30>k^kP<051@D0`0C4a<3018B4PH051@D100F5QH301DE5@<0
k^k^0`3emOD30?7al@<0l?3`0`0G5aL3014A4@<04a<C400D51@301<C4`<04Q8B0`0E5AD3018B4P<0
51@D0`3`l?030?7al@<0mOGe0`3^k^h4018B4P<04A4A1P0>3Ph3014A4@<04a<C0`3_knl30?;blP<0
l?3`0`3clo<30>o_k`@0l?3`0`3^k^h301HF5P<04Q8B0`0E5AD3018B4P<05ADE0`3/k>`30?;blP<0
jn_[0`0D51@300h>3P@0410@0`3/k>`30?3`l0<0k^k^0`0C4a<3018B4P<04A4A0`0C4a<30?3`l0<0
l_;b0`0C4a<301HF5P@051@D0`0E5AD30?7al@<0lo?c2@0C4a<30?3`l0H0k^k^0`0@410400l?3`<0
30`<0`3UiND30=SHf0<0bl_;0`3Hf=P30>CTi0<030`<0`0@410301<C4`<0kNg]0`3`l?040>o_k`<0
4A4A1P0B4Q830?;blP<0l?3`0`0E5AD301@D50<05aLG0`0D51@30?;blP<0l?3`100D51@301<C4`<0
5ADE0`0C4a<30??cl`<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`050?ooo`<0m?Cd0`0E5AD301<C4`<04A4A0`3^k^h30>g]k@<0kno_0`0C4a<301LG5`L05ADE
1P3^k^h30>SXj0<0410@0`0B4Q86010@40<051@D0`0B4Q8301@D50@0kno_0`3`l?030??cl`<0l?3`
0`0B4Q8301<C4`<04A4A0`0B4Q8301LG5`<05ADE0`0D51@701<C4`<051@D0`0F5QH3018B4PH04a<C
0`0B4Q8601@D50<0k^k^0`3emOD40?7al@<0k^k^0`0B4Q83010@40H03Ph>0`0B4Q83010@40<04Q8B
1P3/k>`70>k^kP<0j^[Z0`0D51@301<C4`<05QHF0`0B4Q8301<C4`<0kno_0`3bl_830>k^kP<04Q8B
100>3Ph3014A4@<0kNg]0`3alO430>o_k`<051@D0`0B4Q83010@40<0lO7a0`3bl_83018B4P<05QHF
100G5aL301<C4`<0lo?c0`3dm?@301@D50<05ADE0`0F5QH30>k^kP<0lO7a0`3_knl3010@40@03`l?
0`0<30`30>GUi@<0f=SH0`39bLT30=SHf0<0i>CT0`0<30`300l?3`<0410@0`3_knl70>k^kP<04A4A
0`0B4Q8301<C4`H0lo?c0`0C4a<301LG5`<061PH0`0D51@30??cl`<0l_;b100B4Q8301DE5@<051@D
0`0F5QH30?;blP<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?oo
o`050?ooo`<0m?Cd0`0E5AD301<C4`<04A4A0`3^k^h30>g]k@<0kno_0`0C4a<301LG5`L05ADE1P3^
k^h30>SXj0<0410@0`0B4Q86010@40<051@D0`0B4Q8301@D50@0kno_0`3`l?030??cl`<0l?3`0`0B
4Q8301<C4`<04A4A0`0B4Q8301LG5`<05ADE0`0D51@701<C4`<051@D0`0F5QH3018B4PH04a<C0`0B
4Q8601@D50<0k^k^0`3emOD40?7al@<0k^k^0`0B4Q83010@40H03Ph>0`0B4Q83010@40<04Q8B1P3/
k>`70>k^kP<0j^[Z0`0D51@301<C4`<05QHF0`0B4Q8301<C4`<0kno_0`3bl_830>k^kP<04Q8B100>
3Ph3014A4@<0kNg]0`3alO430>o_k`<051@D0`0B4Q83010@40<0lO7a0`3bl_83018B4P<05QHF100G
5aL301<C4`<0lo?c0`3dm?@301@D50<05ADE0`0F5QH30>k^kP<0lO7a0`3_knl3010@40@03`l?0`0<
30`30>GUi@<0f=SH0`39bLT30=SHf0<0i>CT0`0<30`300l?3`<0410@0`3_knl70>k^kP<04A4A0`0B
4Q8301<C4`H0lo?c0`0C4a<301LG5`<061PH0`0D51@30??cl`<0l_;b100B4Q8301DE5@<051@D0`0F
5QH30?;blP<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`05
0?ooo`<0m?Cd0`0E5AD301<C4`<04A4A0`3^k^h30>g]k@<0kno_0`0C4a<301LG5`L05ADE1P3^k^h3
0>SXj0<0410@0`0B4Q86010@40<051@D0`0B4Q8301@D50@0kno_0`3`l?030??cl`<0l?3`0`0B4Q83
01<C4`<04A4A0`0B4Q8301LG5`<05ADE0`0D51@701<C4`<051@D0`0F5QH3018B4PH04a<C0`0B4Q86
01@D50<0k^k^0`3emOD40?7al@<0k^k^0`0B4Q83010@40H03Ph>0`0B4Q83010@40<04Q8B1P3/k>`7
0>k^kP<0j^[Z0`0D51@301<C4`<05QHF0`0B4Q8301<C4`<0kno_0`3bl_830>k^kP<04Q8B100>3Ph3
014A4@<0kNg]0`3alO430>o_k`<051@D0`0B4Q83010@40<0lO7a0`3bl_83018B4P<05QHF100G5aL3
01<C4`<0lo?c0`3dm?@301@D50<05ADE0`0F5QH30>k^kP<0lO7a0`3_knl3010@40@03`l?0`0<30`3
0>GUi@<0f=SH0`39bLT30=SHf0<0i>CT0`0<30`300l?3`<0410@0`3_knl70>k^kP<04A4A0`0B4Q83
01<C4`H0lo?c0`0C4a<301LG5`<061PH0`0D51@30??cl`<0l_;b100B4Q8301DE5@<051@D0`0F5QH3
0?;blP<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?oo
o`<0l_;b0`0G5aL301DE5@<04Q8B0`3_knl30>k^kP<0l?3`0`0C4a<701DE5@H0k^k^0`3Xj>P300d=
3@<030`<0`0A4A43010@40<05QHF0`3`l?030?;blP<0l?3`1`3bl_830?3`l0<0lO7a0`0D51@3018B
4P<05QHF0`0I6AT30??cl`<0mOGe3@3clo<30?3`l0<051@D0`0B4Q8301HF5P<04a<C0`0D51@3018B
4P<05aLG0`3`l?040?7al@<0m?Cd0`3`l?030>k^kP<04Q8B0`0@410300h>3P<03`l?1P0>3Ph300`<
30@0hN7Q0`3Xj>P30>_[j`<0j^[Z0`0G5aL301DE5@<05QHF0`0D51@30>g]k@<0lO7a0`3`l?07010@
40<04Q8B0`3]kNd60?;blP<04a<C0`0B4Q83014A4@<0lO7a0`3`l?0601@D50@05aLG0`0D51@60?Cd
m0<05ADE0`0G5aL601@D50<0kno_0`3`l?03010@40@03`l?0`0<30`30>CTi0<0f=SH0`39bLT30=SH
f0<0i>CT0`0<30`600l?3`H0kNg]103^k^h3014A4@<04Q8B0`0C4a<60?Cdm0<05ADE0`0H61P301LG
5`<04a<C1P3bl_8401<C4`<051@D0`0G5aL30?7al@<0m_Kf0`3bl_860?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3bl_8301LG5`<05ADE0`0B4Q830>o_k`<0
k^k^0`3`l?0301<C4`L05ADE1P3^k^h30>SXj0<03@d=0`0<30`3014A4@<0410@0`0F5QH30?3`l0<0
l_;b0`3`l?070?;blP<0l?3`0`3alO4301@D50<04Q8B0`0F5QH301TI6@<0lo?c0`3emOD=0??cl`<0
l?3`0`0D51@3018B4P<05QHF0`0C4a<301@D50<04Q8B0`0G5aL30?3`l0@0lO7a0`3dm?@30?3`l0<0
k^k^0`0B4Q83010@40<03Ph>0`0?3`l600h>3P<030`<103QhN430>SXj0<0jn_[0`3Zj^X301LG5`<0
5ADE0`0F5QH301@D50<0kNg]0`3alO430?3`l0L0410@0`0B4Q830>g]k@H0l_;b0`0C4a<3018B4P<0
4A4A0`3alO430?3`l0H051@D100G5aL301@D50H0m?Cd0`0E5AD301LG5`H051@D0`3_knl30?3`l0<0
410@100?3`l300`<30<0i>CT0`3Hf=P30<W9b@<0f=SH0`3Ti>@300`<30H03`l?1P3]kNd40>k^kP<0
4A4A0`0B4Q8301<C4`H0m?Cd0`0E5AD301PH60<05aLG0`0C4a<60?;blP@04a<C0`0D51@301LG5`<0
lO7a0`3fm_H30?;blPH0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
1@3oool30?;blP<05aLG0`0E5AD3018B4P<0kno_0`3^k^h30?3`l0<04a<C1`0E5AD60>k^kP<0j>SX
0`0=3@d300`<30<04A4A0`0@410301HF5P<0l?3`0`3bl_830?3`l0L0l_;b0`3`l?030?7al@<051@D
0`0B4Q8301HF5P<06ATI0`3clo<30?Gem@d0lo?c0`3`l?0301@D50<04Q8B0`0F5QH301<C4`<051@D
0`0B4Q8301LG5`<0l?3`103alO430?Cdm0<0l?3`0`3^k^h3018B4P<0410@0`0>3Ph300l?3`H03Ph>
0`0<30`40>7Qh@<0j>SX0`3[jn/30>[ZjP<05aLG0`0E5AD301HF5P<051@D0`3]kNd30?7al@<0l?3`
1`0@4103018B4P<0kNg]1P3bl_8301<C4`<04Q8B0`0A4A430?7al@<0l?3`1P0D51@401LG5`<051@D
1P3dm?@301DE5@<05aLG1P0D51@30>o_k`<0l?3`0`0@410400l?3`<030`<0`3Ti>@30=SHf0<0bLW9
0`3Hf=P30>CTi0<030`<1P0?3`l60>g]k@@0k^k^0`0A4A43018B4P<04a<C1P3dm?@301DE5@<061PH
0`0G5aL301<C4`H0l_;b100C4a<301@D50<05aLG0`3alO430?KfmP<0l_;b1P3oool00`000000oooo
0?ooo`050?ooo`00:03oool3000000D0oooo0`0F5QH301DE5@<05aLG0`0C4a<30?3`l0<0lO7a0`3_
knl301HF5P<051@D100B4Q830>k^kP<0j^[Z0`3WinL300T92@<030`<0`0>3Ph301@D50<0k^k^0`3e
mOD30?3`l0<0lO7a103bl_830?3`l0<05QHF0`0G5aL301DE5@<06ATI0`3fm_H30?;blP<0m?Cd0`3b
l_8:0?7al@<0l?3`0`3dm?@30?3`l0<0l_;b0`3alO4301LG5`<04Q8B0`0D51@301<C4`<051@D100E
5AD30>o_k`<0lO7a0`3clo<30>k^kP<0k>c/0`0A4A43010@40<03@d=0`0;2`/300D51@@02PX:0`3M
gMd30>GUi@<0k^k^0`3alO4601TI6@<04a<C0`0B4Q830>g]k@<0k^k^0`0C4a<7014A4@<04a<C0`3_
knl30?;blPH04Q8B0`0A4A430?3`l0<0l_;b0`3`l?0301LG5`@05QHF0`0D51@30?Cdm0<0mOGe0`0F
5QH301TI6@<05aLG0`0B4Q860?7al@<04A4A100?3`l300`<30<0i>CT0`3Hf=P30<W9b@<0f=SH0`3T
i>@300`<30H03`l?0`3]kNd30>k^kP@0l?3`0`0B4Q8301<C4`<051@D1P3dm?@301DE5@<05aLG1P0D
51@30>o_k`<0lO7a100B4Q8301<C4`<05ADE0`3dm?@30?;blP<05QHF1@3oool2000000L0oooo000X
0?ooo`030000003oool0oooo00D0oooo0`0F5QH301DE5@<05aLG0`0C4a<30?3`l0<0lO7a0`3_knl3
01HF5P<051@D100B4Q830>k^kP<0j^[Z0`3WinL300T92@<030`<0`0>3Ph301@D50<0k^k^0`3emOD3
0?3`l0<0lO7a103bl_830?3`l0<05QHF0`0G5aL301DE5@<06ATI0`3fm_H30?;blP<0m?Cd0`3bl_8:
0?7al@<0l?3`0`3dm?@30?3`l0<0l_;b0`3alO4301LG5`<04Q8B0`0D51@301<C4`<051@D100E5AD3
0>o_k`<0lO7a0`3clo<30>k^kP<0k>c/0`0A4A43010@40<03@d=0`0;2`/300D51@@02PX:0`3MgMd3
0>GUi@<0k^k^0`3alO4601TI6@<04a<C0`0B4Q830>g]k@<0k^k^0`0C4a<7014A4@<04a<C0`3_knl3
0?;blPH04Q8B0`0A4A430?3`l0<0l_;b0`3`l?0301LG5`@05QHF0`0D51@30?Cdm0<0mOGe0`0F5QH3
01TI6@<05aLG0`0B4Q860?7al@<04A4A100?3`l300`<30<0i>CT0`3Hf=P30<W9b@<0f=SH0`3Ti>@3
00`<30H03`l?0`3]kNd30>k^kP@0l?3`0`0B4Q8301<C4`<051@D1P3dm?@301DE5@<05aLG1P0D51@3
0>o_k`<0lO7a100B4Q8301<C4`<05ADE0`3dm?@30?;blP<05QHF1P3oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<05QHF0`0E5AD301LG5`<04a<C0`3`l?030?7a
l@<0kno_0`0F5QH301@D50@04Q8B0`3^k^h30>[ZjP<0inOW0`092@T300`<30<03Ph>0`0D51@30>k^
kP<0mOGe0`3`l?030?7al@@0l_;b0`3`l?0301HF5P<05aLG0`0E5AD301TI6@<0m_Kf0`3bl_830?Cd
m0<0l_;b2P3alO430?3`l0<0m?Cd0`3`l?030?;blP<0lO7a0`0G5aL3018B4P<051@D0`0C4a<301@D
50@05ADE0`3_knl30?7al@<0lo?c0`3^k^h30>c/k0<04A4A0`0@410300d=3@<02`/;0`051@D400X:
2P<0gMgM0`3UiND30>k^kP<0lO7a1P0I6AT301<C4`<04Q8B0`3]kNd30>k^kP<04a<C1`0A4A4301<C
4`<0kno_0`3bl_86018B4P<04A4A0`3`l?030?;blP<0l?3`0`0G5aL401HF5P<051@D0`3dm?@30?Ge
m@<05QHF0`0I6AT301LG5`<04Q8B1P3alO43014A4@@03`l?0`0<30`30>CTi0<0f=SH0`39bLT30=SH
f0<0i>CT0`0<30`600l?3`<0kNg]0`3^k^h40?3`l0<04Q8B0`0C4a<301@D50H0m?Cd0`0E5AD301LG
5`H051@D0`3_knl30?7al@@04Q8B0`0C4a<301DE5@<0m?Cd0`3bl_8301HF5PH0oooo00<000000?oo
o`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool301@D50<06ATI0`0J6QX301DE5@<0
lo?c0`3`l?0601@D50<05ADE100@41030>_[j`<0inOW0`3Ti>@300H61P<02`/;0`0@41030>g]k@<0
mOGe0`3^k^h3018B4P<0410@100B4Q8301HF5P<05ADE1P0I6AT301PH60<0m?Cd0`0B4Q8900`<30L0
3@d=0`0@41030>g]k@<0lO7a0`3`l?030?Gem@<0k^k^1P0D51@3018B4P<04a<C100B4Q8601@D50<0
kNg]0`3bl_830?3`l0<0kNg]0`3[jn/300l?3`H02PX:103MgMd30>?Sh`<0iNGU0`3^k^h30?7al@<0
6QXJ0`0I6AT301@D50<03Ph>0`3]kNd30?7al@<0l?3`100F5QH301<C4`<04A4A0`3bl_830??cl`H0
4Q8B0`0A4A430>o_k`<0l?3`0`3clo<701DE5@<051@D0`3dm?@30?Gem@<05QHF0`0I6AT301LG5`<0
4Q8B1P3alO43014A4@@03`l?0`0<30`30>CTi0<0f=SH0`39bLT30=SHf0<0i>CT0`0<30`300l?3`<0
410@0`3_knl30?7al@@0kno_0`0F5QH601DE5@H0m?Cd0`0D51@301DE5@<05QHF0`3^k^h30?7al@<0
kno_100A4A4301<C4`<051@D1P3dm?@301@D50H0oooo00<000000?ooo`3oool01@3oool002P0oooo
00<000000?ooo`3oool01@3oool301@D50<06ATI0`0J6QX301DE5@<0lo?c0`3`l?0601@D50<05ADE
100@41030>_[j`<0inOW0`3Ti>@300H61P<02`/;0`0@41030>g]k@<0mOGe0`3^k^h3018B4P<0410@
100B4Q8301HF5P<05ADE1P0I6AT301PH60<0m?Cd0`0B4Q8900`<30L03@d=0`0@41030>g]k@<0lO7a
0`3`l?030?Gem@<0k^k^1P0D51@3018B4P<04a<C100B4Q8601@D50<0kNg]0`3bl_830?3`l0<0kNg]
0`3[jn/300l?3`H02PX:103MgMd30>?Sh`<0iNGU0`3^k^h30?7al@<06QXJ0`0I6AT301@D50<03Ph>
0`3]kNd30?7al@<0l?3`100F5QH301<C4`<04A4A0`3bl_830??cl`H04Q8B0`0A4A430>o_k`<0l?3`
0`3clo<701DE5@<051@D0`3dm?@30?Gem@<05QHF0`0I6AT301LG5`<04Q8B1P3alO43014A4@@03`l?
0`0<30`30>CTi0<0f=SH0`39bLT30=SHf0<0i>CT0`0<30`300l?3`<0410@0`3_knl30?7al@@0kno_
0`0F5QH601DE5@H0m?Cd0`0D51@301DE5@<05QHF0`3^k^h30?7al@<0kno_100A4A4301<C4`<051@D
1P3dm?@301@D50H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3o
ool301@D50<06ATI0`0J6QX301DE5@<0lo?c0`3`l?0601@D50<05ADE100@41030>_[j`<0inOW0`3T
i>@300H61P<02`/;0`0@41030>g]k@<0mOGe0`3^k^h3018B4P<0410@100B4Q8301HF5P<05ADE1P0I
6AT301PH60<0m?Cd0`0B4Q8900`<30L03@d=0`0@41030>g]k@<0lO7a0`3`l?030?Gem@<0k^k^1P0D
51@3018B4P<04a<C100B4Q8601@D50<0kNg]0`3bl_830?3`l0<0kNg]0`3[jn/300l?3`H02PX:103M
gMd30>?Sh`<0iNGU0`3^k^h30?7al@<06QXJ0`0I6AT301@D50<03Ph>0`3]kNd30?7al@<0l?3`100F
5QH301<C4`<04A4A0`3bl_830??cl`H04Q8B0`0A4A430>o_k`<0l?3`0`3clo<701DE5@<051@D0`3d
m?@30?Gem@<05QHF0`0I6AT301LG5`<04Q8B1P3alO43014A4@@03`l?0`0<30`30>CTi0<0f=SH0`39
bLT30=SHf0<0i>CT0`0<30`300l?3`<0410@0`3_knl30?7al@@0kno_0`0F5QH601DE5@H0m?Cd0`0D
51@301DE5@<05QHF0`3^k^h30?7al@<0kno_100A4A4301<C4`<051@D1P3dm?@301@D50H0oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool301@D50<06ATI0`0J6QX3
01DE5@<0lo?c0`3`l?0601@D50<05ADE100@41030>_[j`<0inOW0`3Ti>@300H61P<02`/;0`0@4103
0>g]k@<0mOGe0`3^k^h3018B4P<0410@100B4Q8301HF5P<05ADE1P0I6AT301PH60<0m?Cd0`0B4Q89
00`<30L03@d=0`0@41030>g]k@<0lO7a0`3`l?030?Gem@<0k^k^1P0D51@3018B4P<04a<C100B4Q86
01@D50<0kNg]0`3bl_830?3`l0<0kNg]0`3[jn/300l?3`H02PX:103MgMd30>?Sh`<0iNGU0`3^k^h3
0?7al@<06QXJ0`0I6AT301@D50<03Ph>0`3]kNd30?7al@<0l?3`100F5QH301<C4`<04A4A0`3bl_83
0??cl`H04Q8B0`0A4A430>o_k`<0l?3`0`3clo<701DE5@<051@D0`3dm?@30?Gem@<05QHF0`0I6AT3
01LG5`<04Q8B1P3alO43014A4@@03`l?0`0<30`30>CTi0<0f=SH0`39bLT30=SHf0<0i>CT0`0<30`3
00l?3`<0410@0`3_knl30?7al@@0kno_0`0F5QH601DE5@H0m?Cd0`0D51@301DE5@<05QHF0`3^k^h3
0?7al@<0kno_100A4A4301<C4`<051@D1P3dm?@301@D50H0oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool01@3oool301HF5PH06a/K0`0F5QH30?Cdm0<0lo?c0`0C4a<301HF
5P<05ADE100?3`l30>WYj@<0hn?S0`3MgMd300P820<0iNGU0`3^k^h30?Cdm0<0k^k^0`0E5AD3010@
40<04Q8B100C4a<301/K6`<061PH0`0J6QX301HF5P<051@D0`3alO4300h>3PH02PX:0`0;2`/400d=
3@H02`/;0`0?3`l300h>3P<0410@0`3/k>`30?Cdm0<0lO7a0`3_knl301DE5@<051@D100C4a<301@D
50<04A4A0`0F5QH60>k^kPH0l?3`0`3[jn/30>[ZjP<0i^KV103Xj>P30>OWi`<0k>c/0`3[jn/301PH
60<05QHF0`0H61P3014A4@<0410@0`3[jn/30?7al@<0l?3`100G5aL301@D50<04Q8B1P3clo<301<C
4`<04Q8B0`0A4A430?3`l0<0l_;b0`3`l?0301HF5P@05ADE0`0D51@60?Cdm0<05ADE0`0G5aL601@D
50<0kno_0`3`l?03010@40@03`l?0`0<30`30>CTi0<0f=SH0`39bLT30=SHf0<0i>CT0`0<30`300l?
3`<0410@0`3alO430?3`l0@051@D0`0E5AD301PH60<05QHF0`3emOD30?Cdm0<051@D0`0C4a<3018B
4P<0kno_0`3]kNd30>k^kP@0410@0`0B4Q8301<C4`<0m?Cd0`3emOD301HF5PH0oooo00<000000?oo
o`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool301HF5PH06a/K0`0F5QH30?Cdm0<0
lo?c0`0C4a<301HF5P<05ADE100?3`l30>WYj@<0hn?S0`3MgMd300P820<0iNGU0`3^k^h30?Cdm0<0
k^k^0`0E5AD3010@40<04Q8B100C4a<301/K6`<061PH0`0J6QX301HF5P<051@D0`3alO4300h>3PH0
2PX:0`0;2`/400d=3@H02`/;0`0?3`l300h>3P<0410@0`3/k>`30?Cdm0<0lO7a0`3_knl301DE5@<0
51@D100C4a<301@D50<04A4A0`0F5QH60>k^kPH0l?3`0`3[jn/30>[ZjP<0i^KV103Xj>P30>OWi`<0
k>c/0`3[jn/301PH60<05QHF0`0H61P3014A4@<0410@0`3[jn/30?7al@<0l?3`100G5aL301@D50<0
4Q8B1P3clo<301<C4`<04Q8B0`0A4A430?3`l0<0l_;b0`3`l?0301HF5P@05ADE0`0D51@60?Cdm0<0
5ADE0`0G5aL601@D50<0kno_0`3`l?03010@40@03`l?0`0<30`30>CTi0<0f=SH0`39bLT30=SHf0<0
i>CT0`0<30`300l?3`<0410@0`3alO430?3`l0@051@D0`0E5AD301PH60<05QHF0`3emOD30?Cdm0<0
51@D0`0C4a<3018B4P<0kno_0`3]kNd30>k^kP@0410@0`0B4Q8301<C4`<0m?Cd0`3emOD301HF5PH0
oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool301HF5PH06a/K
0`0F5QH30?Cdm0<0lo?c0`0C4a<301HF5P<05ADE100?3`l30>WYj@<0hn?S0`3MgMd300P820<0iNGU
0`3^k^h30?Cdm0<0k^k^0`0E5AD3010@40<04Q8B100C4a<301/K6`<061PH0`0J6QX301HF5P<051@D
0`3alO4300h>3PH02PX:0`0;2`/400d=3@H02`/;0`0?3`l300h>3P<0410@0`3/k>`30?Cdm0<0lO7a
0`3_knl301DE5@<051@D100C4a<301@D50<04A4A0`0F5QH60>k^kPH0l?3`0`3[jn/30>[ZjP<0i^KV
103Xj>P30>OWi`<0k>c/0`3[jn/301PH60<05QHF0`0H61P3014A4@<0410@0`3[jn/30?7al@<0l?3`
100G5aL301@D50<04Q8B1P3clo<301<C4`<04Q8B0`0A4A430?3`l0<0l_;b0`3`l?0301HF5P@05ADE
0`0D51@60?Cdm0<05ADE0`0G5aL601@D50<0kno_0`3`l?03010@40@03`l?0`0<30`30>CTi0<0f=SH
0`39bLT30=SHf0<0i>CT0`0<30`300l?3`<0410@0`3alO430?3`l0@051@D0`0E5AD301PH60<05QHF
0`3emOD30?Cdm0<051@D0`0C4a<3018B4P<0kno_0`3]kNd30>k^kP@0410@0`0B4Q8301<C4`<0m?Cd
0`3emOD301HF5PH0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3o
ool301LG5`H071`L0`0G5aL30?Gem@<0m?Cd0`0E5AD301LG5`<04a<C100A4A430>KViP<0hN7Q1P3P
h>060>k^kP<0kno_0`0F5QH3010@40<04A4A0`0E5AD401XJ6P<0m?Cd0`0I6AT301<C4`<051@D0`0B
4Q830?3`l0<0kNg]0`3[jn/30>[ZjP<0jn_[103YjNT300h>3P<030`<0`0>3Ph600/;2`<04Q8B0`3^
k^h30?3`l0<0m?Cd0`3alO430?3`l0@05aLG0`0B4Q8301@D50<04a<C1P0D51@30>k^kP<0l?3`0`3]
kNd30>o_k`<0k^k^103Zj^X60>g]k@<05QHF0`0C4a<301LG5`<04a<C0`0D51@30>[ZjP<0kno_0`3^
k^h301DE5@@051@D0`0E5AD3018B4PH0lo?c1P0C4a<3018B4P<0lO7a0`3`l?0301@D50<04a<C100E
5AD3018B4P<0lo?c0`3dm?@301@D50<05ADE0`0F5QH30>k^kP<0lO7a0`3_knl3010@40@03`l?0`0<
30`30>CTi0<0f=SH0`39bLT30=SHf0<0iNGU0`0<30`3010@40<04A4A1P3bl_8401<C4`<061PH0`0J
6QX301LG5`<0mOGe0`3dm?@301<C4`<04Q8B0`0A4A430>g]k@<0k>c/0`3]kNd4010@40<04Q8B0`0C
4a<30?Cdm0<0mOGe0`0G5aL60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0
oooo00D0oooo0`0G5aL601`L70<05aLG0`3emOD30?Cdm0<05ADE0`0G5aL301<C4`@04A4A0`3Vi^H3
0>7Qh@H0h>3P1P3^k^h30>o_k`<05QHF0`0@4103014A4@<05ADE100J6QX30?Cdm0<06ATI0`0C4a<3
01@D50<04Q8B0`3`l?030>g]k@<0jn_[0`3Zj^X30>_[j`@0jNWY0`0>3Ph300`<30<03Ph>1P0;2`/3
018B4P<0k^k^0`3`l?030?Cdm0<0lO7a0`3`l?0401LG5`<04Q8B0`0D51@301<C4`H051@D0`3^k^h3
0?3`l0<0kNg]0`3_knl30>k^kP@0j^[Z1P3]kNd301HF5P<04a<C0`0G5aL301<C4`<051@D0`3Zj^X3
0>o_k`<0k^k^0`0E5AD401@D50<05ADE0`0B4Q860??cl`H04a<C0`0B4Q830?7al@<0l?3`0`0D51@3
01<C4`@05ADE0`0B4Q830??cl`<0m?Cd0`0D51@301DE5@<05QHF0`3^k^h30?7al@<0kno_0`0@4104
00l?3`<030`<0`3Ti>@30=SHf0<0bLW90`3Hf=P30>GUi@<030`<0`0@4103014A4@H0l_;b100C4a<3
01PH60<06QXJ0`0G5aL30?Gem@<0m?Cd0`0C4a<3018B4P<04A4A0`3]kNd30>c/k0<0kNg]100@4103
018B4P<04a<C0`3dm?@30?Gem@<05aLG1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`050?ooo`<05aLG1P0L71`301LG5`<0mOGe0`3dm?@301DE5@<05aLG0`0C4a<4014A
4@<0i^KV0`3QhN460>3Ph0H0k^k^0`3_knl301HF5P<0410@0`0A4A4301DE5@@06QXJ0`3dm?@301TI
6@<04a<C0`0D51@3018B4P<0l?3`0`3]kNd30>_[j`<0j^[Z0`3[jn/40>WYj@<03Ph>0`0<30`300h>
3PH02`/;0`0B4Q830>k^kP<0l?3`0`3dm?@30?7al@<0l?3`100G5aL3018B4P<051@D0`0C4a<601@D
50<0k^k^0`3`l?030>g]k@<0kno_0`3^k^h40>[ZjPH0kNg]0`0F5QH301<C4`<05aLG0`0C4a<301@D
50<0j^[Z0`3_knl30>k^kP<05ADE100D51@301DE5@<04Q8B1P3clo<601<C4`<04Q8B0`3alO430?3`
l0<051@D0`0C4a<401DE5@<04Q8B0`3clo<30?Cdm0<051@D0`0E5AD301HF5P<0k^k^0`3alO430>o_
k`<0410@100?3`l300`<30<0i>CT0`3Hf=P30<W9b@<0f=SH0`3UiND300`<30<0410@0`0A4A460?;b
lP@04a<C0`0H61P301XJ6P<05aLG0`3emOD30?Cdm0<04a<C0`0B4Q83014A4@<0kNg]0`3/k>`30>g]
k@@0410@0`0B4Q8301<C4`<0m?Cd0`3emOD301LG5`H0oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool01@3oool301PH60H071`L0`0H61P60?Gem@<05ADE0`0G5aL301PH60@0
kno_0`3/k>`60>CTi0<0jn_[0`3YjNT3018B4P<04a<C0`0A4A43010@40<05aLG0`3bl_840?KfmP<0
lo?c0`0A4A4301@D50<0kno_0`3alO430>o_k`<0k>c/0`3_knl30>c/k0<0jn_[103/k>`30>WYj@<0
k>c/0`3Zj^X300l?3`<03@d=0`0;2`/300l?3`<04A4A0`3^k^h30?7al@<0mOGe103^k^h601@D50<0
4a<C0`0D51@301<C4`<05ADE0`0B4Q8301<C4`<0l?3`0`3_knl4018B4P<04A4A0`0E5AD301@D50<0
5QHF0`0C4a<301DE5@<0jn_[0`3_knl30?3`l0<0k^k^0`0E5AD401HF5P<051@D0`0E5AD30?;blP<0
m?Cd0`0D51@301<C4`<04Q8B1P3bl_83018B4P<05ADE100C4a<301@D50<0lO7a0`3clo<901<C4`<0
l?3`1P3^k^h3010@40@03`l?0`0<30`30>CTi0<0f=SH0`39bLT30=SHf0<0iNGU0`0=3@d3010@40<0
4Q8B0`3clo<30?Cdm0@05QHF1P0K6a/301LG5`<0mOGe0`3dm?@301<C4`<04Q8B0`0@41030>c/k0<0
jn_[0`3/k>`4010@40<04Q8B0`0C4a<30?Cdm0<0mOGe0`0H61P60?ooo`030000003oool0oooo00D0
oooo000X0?ooo`030000003oool0oooo00D0oooo0`0H61P601`L70<061PH1P3emOD301DE5@<05aLG
0`0H61P40>o_k`<0k>c/1P3Ti>@30>_[j`<0jNWY0`0B4Q8301<C4`<04A4A0`0@410301LG5`<0l_;b
103fm_H30??cl`<04A4A0`0D51@30>o_k`<0lO7a0`3_knl30>c/k0<0kno_0`3/k>`30>_[j`@0k>c/
0`3YjNT30>c/k0<0j^[Z0`0?3`l300d=3@<02`/;0`0?3`l3014A4@<0k^k^0`3alO430?Gem@@0k^k^
1P0D51@301<C4`<051@D0`0C4a<301DE5@<04Q8B0`0C4a<30?3`l0<0kno_100B4Q83014A4@<05ADE
0`0D51@301HF5P<04a<C0`0E5AD30>_[j`<0kno_0`3`l?030>k^kP<05ADE100F5QH301@D50<05ADE
0`3bl_830?Cdm0<051@D0`0C4a<3018B4PH0l_;b0`0B4Q8301DE5@@04a<C0`0D51@30?7al@<0lo?c
2@0C4a<30?3`l0H0k^k^0`0@410400l?3`<030`<0`3Ti>@30=SHf0<0bLW90`3Hf=P30>GUi@<03@d=
0`0@4103018B4P<0lo?c0`3dm?@401HF5PH06a/K0`0G5aL30?Gem@<0m?Cd0`0C4a<3018B4P<0410@
0`3/k>`30>_[j`<0k>c/100@4103018B4P<04a<C0`3dm?@30?Gem@<061PH1P3oool00`000000oooo
0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<061PH1P0L71`301PH60H0mOGe0`0E
5AD301LG5`<061PH103_knl30>c/k0H0i>CT0`3[jn/30>WYj@<04Q8B0`0C4a<3014A4@<0410@0`0G
5aL30?;blP@0m_Kf0`3clo<3014A4@<051@D0`3_knl30?7al@<0kno_0`3/k>`30>o_k`<0k>c/0`3[
jn/40>c/k0<0jNWY0`3/k>`30>[ZjP<03`l?0`0=3@d300/;2`<03`l?0`0A4A430>k^kP<0lO7a0`3e
mOD40>k^kPH051@D0`0C4a<301@D50<04a<C0`0E5AD3018B4P<04a<C0`3`l?030>o_k`@04Q8B0`0A
4A4301DE5@<051@D0`0F5QH301<C4`<05ADE0`3[jn/30>o_k`<0l?3`0`3^k^h301DE5@@05QHF0`0D
51@301DE5@<0l_;b0`3dm?@301@D50<04a<C0`0B4Q860?;blP<04Q8B0`0E5AD401<C4`<051@D0`3a
lO430??cl`T04a<C0`3`l?060>k^kP<0410@100?3`l300`<30<0i>CT0`3Hf=P30<W9b@<0f=SH0`3U
iND300d=3@<0410@0`0B4Q830??cl`<0m?Cd100F5QH601/K6`<05aLG0`3emOD30?Cdm0<04a<C0`0B
4Q83010@40<0k>c/0`3[jn/30>c/k0@0410@0`0B4Q8301<C4`<0m?Cd0`3emOD301PH60H0oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool301PH60H071`L0`0H61P6
0?Gem@<05QHF0`0H61P301XJ6PL0l_;b0`3]kNd30>[ZjP<0k>c/0`0D51@3014A4@<04a<C0`0A4A43
01HF5P<0kno_0`3fm_H40>k^kP<0410@0`0?3`l30>_[j`<0m?Cd0`3]kNd6014A4@<0kNg]0`3_knl3
0>g]k@@0j^[Z0`3]kNd30>c/k0<0kNg]0`3[jn/30>[ZjP<0410@0`0;2`/300`<30<0410@0`0B4Q83
0>g]k@@0mOGe0`3alO430?3`l0<05aLG0`0A4A4301@D50<05ADE0`0D51@301<C4`H05QHF100C4a<3
01DE5@H05QHF0`0B4Q8301DE5@<0k>c/1P3`l?030>c/k0<05aLG0`0D51@401HF5P<05ADE0`3`l?03
0?Gem@<0lO7a0`0F5QH301<C4`<04A4A0`3bl_830??cl`<04a<C0`0D51@401HF5P<0l?3`1P3clo<3
01@D50<04a<C0`0A4A430>o_k`<0k^k^0`3_knl3014A4@@0410@0`0<30`30>CTi0<0f=SH0`39bLT3
0=SHf0<0iNGU0`0=3@d3010@40<04Q8B0`3dm?@30?Gem@@05aLG1P0L71`301LG5`<0mOGe0`3dm?@3
01<C4`<04Q8B0`0@41030>c/k0<0jn_[0`3/k>`400l?3`<04Q8B0`0C4a<30?Cdm0<0mOGe0`0H61P6
0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0H61P601`L
70<061PH1P3emOD301HF5P<061PH0`0J6QX70?;blP<0kNg]0`3Zj^X30>c/k0<051@D0`0A4A4301<C
4`<04A4A0`0F5QH30>o_k`<0m_Kf103^k^h3010@40<03`l?0`3[jn/30?Cdm0<0kNg]1P0A4A430>g]
k@<0kno_0`3]kNd40>[ZjP<0kNg]0`3/k>`30>g]k@<0jn_[0`3Zj^X3010@40<02`/;0`0<30`3010@
40<04Q8B0`3]kNd40?Gem@<0lO7a0`3`l?0301LG5`<04A4A0`0D51@301DE5@<051@D0`0C4a<601HF
5P@04a<C0`0E5AD601HF5P<04Q8B0`0E5AD30>c/k0H0l?3`0`3/k>`301LG5`<051@D100F5QH301DE
5@<0l?3`0`3emOD30?7al@<05QHF0`0C4a<3014A4@<0l_;b0`3clo<301<C4`<051@D100F5QH30?3`
l0H0lo?c0`0D51@301<C4`<04A4A0`3_knl30>k^kP<0kno_0`0A4A44010@40<030`<0`3Ti>@30=SH
f0<0bLW90`3Hf=P30>GUi@<03@d=0`0@4103018B4P<0m?Cd0`3emOD401LG5`H071`L0`0G5aL30?Ge
m@<0m?Cd0`0C4a<3018B4P<0410@0`3/k>`30>_[j`<0k>c/100?3`l3018B4P<04a<C0`3dm?@30?Ge
m@<061PH1P3oool00`000000oooo0?ooo`050?ooo`00:03oool3000000D0oooo0`0H61P601`L70<0
61PH1P3emOD301HF5P<061PH0`0J6QX70?;blP<0kNg]0`3Zj^X30>c/k0<051@D0`0A4A4301<C4`<0
4A4A0`0F5QH30>o_k`<0m_Kf103^k^h3010@40<03`l?0`3[jn/30?Cdm0<0kNg]1P0A4A430>g]k@<0
kno_0`3]kNd40>[ZjP<0kNg]0`3/k>`30>g]k@<0jn_[0`3Zj^X3010@40<02`/;0`0<30`3010@40<0
4Q8B0`3]kNd40?Gem@<0lO7a0`3`l?0301LG5`<04A4A0`0D51@301DE5@<051@D0`0C4a<601HF5P@0
4a<C0`0E5AD601HF5P<04Q8B0`0E5AD30>c/k0H0l?3`0`3/k>`301LG5`<051@D100F5QH301DE5@<0
l?3`0`3emOD30?7al@<05QHF0`0C4a<3014A4@<0l_;b0`3clo<301<C4`<051@D100F5QH30?3`l0H0
lo?c0`0D51@301<C4`<04A4A0`3_knl30>k^kP<0kno_0`0A4A44010@40<030`<0`3Ti>@30=SHf0<0
bLW90`3Hf=P30>GUi@<03@d=0`0@4103018B4P<0m?Cd0`3emOD401LG5`H071`L0`0G5aL30?Gem@<0
m?Cd0`0C4a<3018B4P<0410@0`3/k>`30>_[j`<0k>c/100?3`l3018B4P<04a<C0`3dm?@30?Gem@<0
61PH1@3oool2000000L0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0H61P601`L70<05aLG
1P3emOD301HF5PH06QXJ100M7Ad30??cl`<0l?3`1P0D51@301<C4`<05ADE0`0B4Q8301HF5P<0k^k^
0`3emOD30>c/k0@03`l?0`0:2PX30>WYj@<0lO7a0`3_knl301<C4`<04A4A0`0C4a<301LG5`<051@D
0`0A4A44018B4P<0kNg]0`3^k^h30>_[j`H0k^k^0`3WinL600h>3PH03@d=0`0D51@40>o_k`<0lO7a
0`3emOD30>k^kP<04a<C0`0B4Q8301DE5@<04Q8B2@0D51@701DE5@<04Q8B0`0D51@301<C4`<0k>c/
1P3alO430>c/k0<05ADE0`0C4a<301LG5`@04a<C0`0E5AD60?;blP<05ADE0`0B4Q83014A4@<051@D
0`3alO430?Cdm0H051@D100C4a<30?;blP<0lo?c0`3`l?0301HF5P<051@D0`0A4A430>o_k`<0l?3`
0`3]kNd301<C4`@0410@0`0<30`30>CTi0<0f=SH0`3;bl/30=WIf@<0iNGU0`0=3@d3010@40<04Q8B
0`3dm?@30?Gem@@05aLG1P0L71`301PH60<0mOGe0`3dm?@301<C4`<04Q8B0`0?3`l30>c/k0<0jn_[
0`3/k>`4010@40<04Q8B0`0C4a<30?Cdm0<0mOGe0`0H61P60?ooo`030000003oool0oooo00D0oooo
000X0?ooo`030000003oool0oooo00D0oooo0`0H61P601`L70<05aLG1P3emOD301HF5PH06QXJ100M
7Ad30??cl`<0l?3`1P0D51@301<C4`<05ADE0`0B4Q8301HF5P<0k^k^0`3emOD30>c/k0@03`l?0`0:
2PX30>WYj@<0lO7a0`3_knl301<C4`<04A4A0`0C4a<301LG5`<051@D0`0A4A44018B4P<0kNg]0`3^
k^h30>_[j`H0k^k^0`3WinL600h>3PH03@d=0`0D51@40>o_k`<0lO7a0`3emOD30>k^kP<04a<C0`0B
4Q8301DE5@<04Q8B2@0D51@701DE5@<04Q8B0`0D51@301<C4`<0k>c/1P3alO430>c/k0<05ADE0`0C
4a<301LG5`@04a<C0`0E5AD60?;blP<05ADE0`0B4Q83014A4@<051@D0`3alO430?Cdm0H051@D100C
4a<30?;blP<0lo?c0`3`l?0301HF5P<051@D0`0A4A430>o_k`<0l?3`0`3]kNd301<C4`@0410@0`0<
30`30>CTi0<0f=SH0`3;bl/30=WIf@<0iNGU0`0=3@d3010@40<04Q8B0`3dm?@30?Gem@@05aLG1P0L
71`301PH60<0mOGe0`3dm?@301<C4`<04Q8B0`0?3`l30>c/k0<0jn_[0`3/k>`4010@40<04Q8B0`0C
4a<30?Cdm0<0mOGe0`0H61P60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0
oooo00D0oooo0`0H61P601`L70<05aLG1P3emOD301HF5PH06QXJ100M7Ad30??cl`<0l?3`1P0D51@3
01<C4`<05ADE0`0B4Q8301HF5P<0k^k^0`3emOD30>c/k0@03`l?0`0:2PX30>WYj@<0lO7a0`3_knl3
01<C4`<04A4A0`0C4a<301LG5`<051@D0`0A4A44018B4P<0kNg]0`3^k^h30>_[j`H0k^k^0`3WinL6
00h>3PH03@d=0`0D51@40>o_k`<0lO7a0`3emOD30>k^kP<04a<C0`0B4Q8301DE5@<04Q8B2@0D51@7
01DE5@<04Q8B0`0D51@301<C4`<0k>c/1P3alO430>c/k0<05ADE0`0C4a<301LG5`@04a<C0`0E5AD6
0?;blP<05ADE0`0B4Q83014A4@<051@D0`3alO430?Cdm0H051@D100C4a<30?;blP<0lo?c0`3`l?03
01HF5P<051@D0`0A4A430>o_k`<0l?3`0`3]kNd301<C4`@0410@0`0<30`30>CTi0<0f=SH0`3;bl/3
0=WIf@<0iNGU0`0=3@d3010@40<04Q8B0`3dm?@30?Gem@@05aLG1P0L71`301PH60<0mOGe0`3dm?@3
01<C4`<04Q8B0`0?3`l30>c/k0<0jn_[0`3/k>`4010@40<04Q8B0`0C4a<30?Cdm0<0mOGe0`0H61P6
0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0G5aL601/K
6`<05QHF1P3dm?@301HF5P<071`L0`0O7al401/K6`<071`L0`0I6AT301@D50<05QHF0`0E5AD3018B
4P<05ADE0`3]kNd30?Cdm0<0k>c/0`0A4A4400P820<03@d=0`3[jn/30?3`l0<0k^k^0`0E5AD301TI
6@<07AdM0`0L71`301XJ6P<05aLG100D51@301DE5@H04A4A0`3Zj^X30>o_k`<0k^k^1P3[jn/3014A
4@<030`<0`0=3@d4010@40<04Q8B0`3]kNd30?Cdm0<0kno_0`3alO430>k^kP<04Q8B3@0@410300l?
3`<04Q8B0`3]kNd30>o_k`<0l_;b0`3_knl30>k^kP<05QHF0`0B4Q8301HF5P<04a<C100G5aL30>o_
k`<0m_Kf0`3`l?0301@D50<04Q8B0`0C4a<30>o_k`<0mOGe0`3alO4301HF5P<04a<C100A4A430?7a
l@<0l?3`0`0E5AD301<C4`<051@D0`0A4A430?3`l0<0k^k^0`0B4Q87014A4@<030`<0`3Shn<30=SH
f0<0c/k>0`3Jf]X30>KViP<03@d=0`0@4103018B4P<0m?Cd0`3emOD401LG5`H071`L0`0G5aL30?Ge
m@<0m?Cd0`0C4a<3018B4P<0410@0`3/k>`30>_[j`<0k>c/100@4103018B4P<04a<C0`3dm?@30?Ge
m@<05aLG1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0
5aLG1P0K6a/301HF5PH0m?Cd0`0F5QH301`L70<07alO100K6a/301`L70<06ATI0`0D51@301HF5P<0
5ADE0`0B4Q8301DE5@<0kNg]0`3dm?@30>c/k0<04A4A100820P300d=3@<0jn_[0`3`l?030>k^kP<0
5ADE0`0I6AT301dM7@<071`L0`0J6QX301LG5`@051@D0`0E5AD6014A4@<0j^[Z0`3_knl30>k^kPH0
jn_[0`0A4A4300`<30<03@d=100@4103018B4P<0kNg]0`3dm?@30>o_k`<0lO7a0`3^k^h3018B4Pd0
410@0`0?3`l3018B4P<0kNg]0`3_knl30?;blP<0kno_0`3^k^h301HF5P<04Q8B0`0F5QH301<C4`@0
5aLG0`3_knl30?KfmP<0l?3`0`0D51@3018B4P<04a<C0`3_knl30?Gem@<0lO7a0`0F5QH301<C4`@0
4A4A0`3alO430?3`l0<05ADE0`0C4a<301@D50<04A4A0`3`l?030>k^kP<04Q8B1`0A4A4300`<30<0
hn?S0`3Hf=P30<k>cP<0f][J0`3Vi^H300d=3@<0410@0`0B4Q830?Cdm0<0mOGe100G5aL601`L70<0
5aLG0`3emOD30?Cdm0<04a<C0`0B4Q83010@40<0k>c/0`3[jn/30>c/k0@0410@0`0B4Q8301<C4`<0
m?Cd0`3emOD301LG5`H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
1@3oool301LG5`H06a/K0`0F5QH60?Cdm0<05QHF0`0L71`301lO7`@06a/K0`0L71`301TI6@<051@D
0`0F5QH301DE5@<04Q8B0`0E5AD30>g]k@<0m?Cd0`3/k>`3014A4@@020P80`0=3@d30>_[j`<0l?3`
0`3^k^h301DE5@<06ATI0`0M7Ad301`L70<06QXJ0`0G5aL401@D50<05ADE1P0A4A430>[ZjP<0kno_
0`3^k^h60>_[j`<04A4A0`0<30`300d=3@@0410@0`0B4Q830>g]k@<0m?Cd0`3_knl30?7al@<0k^k^
0`0B4Q8=010@40<03`l?0`0B4Q830>g]k@<0kno_0`3bl_830>o_k`<0k^k^0`0F5QH3018B4P<05QHF
0`0C4a<401LG5`<0kno_0`3fm_H30?3`l0<051@D0`0B4Q8301<C4`<0kno_0`3emOD30?7al@<05QHF
0`0C4a<4014A4@<0lO7a0`3`l?0301DE5@<04a<C0`0D51@3014A4@<0l?3`0`3^k^h3018B4PL04A4A
0`0<30`30>?Sh`<0f=SH0`3>c/h30=[JfP<0i^KV0`0=3@d3010@40<04Q8B0`3dm?@30?Gem@@05aLG
1P0L71`301LG5`<0mOGe0`3dm?@301<C4`<04Q8B0`0@41030>c/k0<0jn_[0`3/k>`4010@40<04Q8B
0`0C4a<30?Cdm0<0mOGe0`0G5aL60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003o
ool0oooo00D0oooo0`0G5aL301XJ6P<06ATI0`0C4a<60??cl`<051@D0`0J6QX3020P80@07alO0`0K
6a/301PH60<05QHF0`0C4a<301@D50<04a<C0`3/k>`30?;blP<0kno_0`0@410300X:2P@03@d=0`3Z
j^X30?3`l0<0k^k^0`0E5AD301HF5P<07AdM0`0N7Qh301`L70<06QXJ1`0I6AT301PH60<05QHF0`0B
4Q8301DE5@<0kNg]0`3/k>`30>k^kP<0kno_0`3Xj>P600l?3`L03@d=0`0C4a<30>k^kP<0kno_1P3a
lO4@0>g]k@<0k>c/0`3[jn/30?3`l0<0l_;b0`3/k>`601<C4`<04Q8B0`0D51@3018B4P<05aLG103`
l?030?KfmP<0kno_0`0F5QH3014A4@<0410@0`0C4a<30?7al@<0l_;b0`0F5QH6018B4P@051@D0`3a
lO430??cl`<04a<C0`0E5AD601<C4`<0kno_0`3`l?03014A4@<04a<C100@410300h>3P<0h^;R0`3J
f]X30=GEe@<0gMgM0`3WinL300d=3@<0410@0`0B4Q830??cl`<0m?Cd100F5QH601/K6`<05aLG0`3e
mOD30?Cdm0<04a<C0`0B4Q83010@40<0kNg]0`3/k>`30>g]k@@04A4A0`0B4Q8301<C4`<0m?Cd0`3e
mOD301LG5`H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool3
01LG5`<06QXJ0`0I6AT301<C4`H0lo?c0`0D51@301XJ6P<0820P100O7al301/K6`<061PH0`0F5QH3
01<C4`<051@D0`0C4a<30>c/k0<0l_;b0`3_knl3010@40<02PX:100=3@d30>[ZjP<0l?3`0`3^k^h3
01DE5@<05QHF0`0M7Ad301hN7P<071`L0`0J6QX701TI6@<061PH0`0F5QH3018B4P<05ADE0`3]kNd3
0>c/k0<0k^k^0`3_knl30>SXj0H03`l?1`0=3@d301<C4`<0k^k^0`3_knl60?7alA00kNg]0`3/k>`3
0>_[j`<0l?3`0`3bl_830>c/k0H04a<C0`0B4Q8301@D50<04Q8B0`0G5aL40?3`l0<0m_Kf0`3_knl3
01HF5P<04A4A0`0@410301<C4`<0lO7a0`3bl_8301HF5PH04Q8B100D51@30?7al@<0lo?c0`0C4a<3
01DE5@H04a<C0`3_knl30?3`l0<04A4A0`0C4a<4010@40<03Ph>0`3Rh^830=[JfP<0eMGE0`3MgMd3
0>OWi`<03@d=0`0@4103018B4P<0lo?c0`3dm?@401HF5PH06a/K0`0G5aL30?Gem@<0m?Cd0`0C4a<3
018B4P<0410@0`3]kNd30>c/k0<0kNg]100A4A43018B4P<04a<C0`3dm?@30?Gem@<05aLG1P3oool0
0`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<05aLG0`0J6QX301TI
6@<04a<C1P3clo<301@D50<06QXJ0`0P820401lO7`<06a/K0`0H61P301HF5P<04a<C0`0D51@301<C
4`<0k>c/0`3bl_830>o_k`<0410@0`0:2PX400d=3@<0j^[Z0`3`l?030>k^kP<05ADE0`0F5QH301dM
7@<07QhN0`0L71`301XJ6PL06ATI0`0H61P301HF5P<04Q8B0`0E5AD30>g]k@<0k>c/0`3^k^h30>o_
k`<0j>SX1P0?3`l700d=3@<04a<C0`3^k^h30>o_k`H0lO7a403]kNd30>c/k0<0jn_[0`3`l?030?;b
lP<0k>c/1P0C4a<3018B4P<051@D0`0B4Q8301LG5`@0l?3`0`3fm_H30>o_k`<05QHF0`0A4A43010@
40<04a<C0`3alO430?;blP<05QHF1P0B4Q8401@D50<0lO7a0`3clo<301<C4`<05ADE1P0C4a<30>o_
k`<0l?3`0`0A4A4301<C4`@0410@0`0>3Ph30>;RhP<0f][J0`3EeMD30=gMg@<0inOW0`0=3@d3010@
40<04Q8B0`3clo<30?Cdm0@05QHF1P0K6a/301LG5`<0mOGe0`3dm?@301<C4`<04Q8B0`0@41030>g]
k@<0k>c/0`3]kNd4014A4@<04Q8B0`0C4a<30?Cdm0<0mOGe0`0G5aL60?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0F5QH301PH60<05ADE0`0D51@60>o_k`<0
3`l?0`0C4a<301PH60@06ATI0`0F5QH301LG5`<04Q8B0`0C4a<30>k^kP<0kno_0`3bl_830>o_k`<0
k^k^0`0?3`l300/;2`@03`l?0`3]kNd30?;blP<0kno_0`0E5AD301PH60<06ATI0`0K6a/301LG5`H0
5ADE100G5aL301DE5@H05aLG0`0D51@301<C4`<04Q8B0`3Zj^X30>o_k`<0k^k^1P3[jn/4018B4P<0
30`<0`0=3@d3010@40<04A4A0`3]kNd30>o_k`<0kNg]0`3_knl30>g]k@L0k>c/0`3]kNd30>o_k`H0
k^k^0`0F5QH3014A4@<04a<C0`0B4Q8601@D50<0k^k^103fm_H30>o_k`<05ADE1P0?3`l301@D50<0
kNg]0`3emOD30?3`l0<051@D0`0C4a<301@D50@0l?3`0`3emOD30?7al@<05aLG1P0F5QH30>o_k`<0
l_;b0`3alO43018B4P<04a<C100B4Q830>[ZjP<0j>SX0`3Ph>030=GEe@<0hn?S0`3YjNT300h>3P<0
4A4A0`0B4Q830?;blP<0lo?c100C4a<301PH60<06QXJ0`0G5aL30?Gem@<0m?Cd0`0C4a<3018B4P<0
410@0`3^k^h30>g]k@<0kno_100B4Q8301<C4`<051@D0`3dm?@30?Gem@<05QHF1P3oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<05QHF0`0H61P301DE5@<051@D
1P3_knl300l?3`<04a<C0`0H61P401TI6@<05QHF0`0G5aL3018B4P<04a<C0`3^k^h30>o_k`<0l_;b
0`3_knl30>k^kP<03`l?0`0;2`/400l?3`<0kNg]0`3bl_830>o_k`<05ADE0`0H61P301TI6@<06a/K
0`0G5aL601DE5@@05aLG0`0E5AD601LG5`<051@D0`0C4a<3018B4P<0j^[Z0`3_knl30>k^kPH0jn_[
100B4Q8300`<30<03@d=0`0@4103014A4@<0kNg]0`3_knl30>g]k@<0kno_0`3]kNd70>c/k0<0kNg]
0`3_knl60>k^kP<05QHF0`0A4A4301<C4`<04Q8B1P0D51@30>k^kP@0m_Kf0`3_knl301DE5@H03`l?
0`0D51@30>g]k@<0mOGe0`3`l?0301@D50<04a<C0`0D51@40?3`l0<0mOGe0`3alO4301LG5`H05QHF
0`3_knl30?;blP<0lO7a0`0B4Q8301<C4`@04Q8B0`3Zj^X30>SXj0<0h>3P0`3EeMD30>?Sh`<0jNWY
0`0>3Ph3014A4@<04Q8B0`3bl_830??cl`@04a<C0`0H61P301XJ6P<05aLG0`3emOD30?Cdm0<04a<C
0`0B4Q83010@40<0k^k^0`3]kNd30>o_k`@04Q8B0`0C4a<301@D50<0m?Cd0`3emOD301HF5PH0oooo
00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool301HF5P<061PH0`0E
5AD301@D50H0kno_0`0?3`l301<C4`<061PH100I6AT301HF5P<05aLG0`0B4Q8301<C4`<0k^k^0`3_
knl30?;blP<0kno_0`3^k^h300l?3`<02`/;100?3`l30>g]k@<0l_;b0`3_knl301DE5@<061PH0`0I
6AT301/K6`<05aLG1P0E5AD401LG5`<05ADE1P0G5aL301@D50<04a<C0`0B4Q830>[ZjP<0kno_0`3^
k^h60>_[j`@04Q8B0`0<30`300d=3@<0410@0`0A4A430>g]k@<0kno_0`3]kNd30>o_k`<0kNg]1`3/
k>`30>g]k@<0kno_1P3^k^h301HF5P<04A4A0`0C4a<3018B4PH051@D0`3^k^h40?KfmP<0kno_0`0E
5AD600l?3`<051@D0`3]kNd30?Gem@<0l?3`0`0D51@301<C4`<051@D103`l?030?Gem@<0lO7a0`0G
5aL601HF5P<0kno_0`3bl_830?7al@<04Q8B0`0C4a<4018B4P<0j^[Z0`3Xj>P30>3Ph0<0eMGE0`3S
hn<30>WYj@<03Ph>0`0A4A43018B4P<0l_;b0`3clo<401<C4`<061PH0`0J6QX301LG5`<0mOGe0`3d
m?@301<C4`<04Q8B0`0@41030>k^kP<0kNg]0`3_knl4018B4P<04a<C0`0D51@30?Cdm0<0mOGe0`0F
5QH60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0E5AD3
01HF5P<05aLG1P3_knl30>SXj0<030`<0`0=3@d3014A4@@04Q8B0`0D51@30>o_k`<0lO7a0`3^k^h6
0?7al@<0jn_[0`0@410300l?3`<02`/;0`0A4A440>_[j`<0lo?c0`3]kNd301LG5`<051@D1P0G5aL3
0?;blP<0lO7a0`3_knl30?3`l0@0kno_0`0D51@301DE5@<051@D0`0F5QH301DE5@<04A4A0`0E5AD3
0>g]k@<0k>c/0`3^k^h30>o_k`@0j>SX1P0?3`l600d=3@<04A4A0`0?3`l3014A4@<0kNg]0`3_knl7
0>k^kP<0l?3`0`3^k^h601@D50<04Q8B0`0D51@3014A4@<05QHF0`3_knl30?3`l0<0m?Cd103^k^h3
01DE5@<03`l?0`0>3Ph301<C4`<0k>c/0`3dm?@30>k^kP<05aLG0`0C4a<3018B4P<05ADE1`3bl_83
01LG5`<05ADE0`0F5QH301<C4`<0lO7a0`3clo<30>o_k`<05ADE0`0B4Q84010@40<0kNg]0`3Zj^X3
0=[JfP<01PH60`3Ti>@30>c/k0<03`l?1P0A4A430?7al@<0l?3`100D51@301DE5@<061PH0`0F5QH3
0?Gem@<0m?Cd0`0C4a<3018B4P<04A4A0`3_knl30?7al@<0k^k^100F5QH301DE5@<051@D0`3dm?@3
0?Gem@<05ADE1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?oo
o`<05ADE0`0F5QH301LG5`H0kno_0`3Xj>P300`<30<03@d=0`0A4A44018B4P<051@D0`3_knl30?7a
l@<0k^k^1P3alO430>_[j`<0410@0`0?3`l300/;2`<04A4A103[jn/30??cl`<0kNg]0`0G5aL301@D
50H05aLG0`3bl_830?7al@<0kno_0`3`l?040>o_k`<051@D0`0E5AD301@D50<05QHF0`0E5AD3014A
4@<05ADE0`3]kNd30>c/k0<0k^k^0`3_knl40>SXj0H03`l?1P0=3@d3014A4@<03`l?0`0A4A430>g]
k@<0kno_1`3^k^h30?3`l0<0k^k^1P0D51@3018B4P<051@D0`0A4A4301HF5P<0kno_0`3`l?030?Cd
m0@0k^k^0`0E5AD300l?3`<03Ph>0`0C4a<30>c/k0<0m?Cd0`3^k^h301LG5`<04a<C0`0B4Q8301DE
5@L0l_;b0`0G5aL301DE5@<05QHF0`0C4a<30?7al@<0lo?c0`3_knl301DE5@<04Q8B100@41030>g]
k@<0j^[Z0`3Jf]X300H61P<0i>CT0`3/k>`300l?3`H04A4A0`3alO430?3`l0@051@D0`0E5AD301PH
60<05QHF0`3emOD30?Cdm0<04a<C0`0B4Q83014A4@<0kno_0`3alO430>k^kP@05QHF0`0E5AD301@D
50<0m?Cd0`3emOD301DE5@H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool01@3oool301DE5@<05QHF0`0G5aL60>o_k`<0j>SX0`0<30`300d=3@<04A4A100B4Q8301@D50<0
kno_0`3alO430>k^kPH0lO7a0`3[jn/3010@40<03`l?0`0;2`/3014A4@@0jn_[0`3clo<30>g]k@<0
5aLG0`0D51@601LG5`<0l_;b0`3alO430>o_k`<0l?3`103_knl301@D50<05ADE0`0D51@301HF5P<0
5ADE0`0A4A4301DE5@<0kNg]0`3/k>`30>k^kP<0kno_103Xj>P600l?3`H03@d=0`0A4A4300l?3`<0
4A4A0`3]kNd30>o_k`L0k^k^0`3`l?030>k^kPH051@D0`0B4Q8301@D50<04A4A0`0F5QH30>o_k`<0
l?3`0`3dm?@40>k^kP<05ADE0`0?3`l300h>3P<04a<C0`3/k>`30?Cdm0<0k^k^0`0G5aL301<C4`<0
4Q8B0`0E5AD70?;blP<05aLG0`0E5AD301HF5P<04a<C0`3alO430??cl`<0kno_0`0E5AD3018B4P@0
410@0`3]kNd30>[ZjP<0f][J0`061PH30>CTi0<0k>c/0`0?3`l6014A4@<0lO7a0`3`l?0401@D50<0
5ADE0`0H61P301HF5P<0mOGe0`3dm?@301<C4`<04Q8B0`0A4A430>o_k`<0lO7a0`3^k^h401HF5P<0
5ADE0`0D51@30?Cdm0<0mOGe0`0E5AD60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo00D0oooo0`0E5AD601HF5P<0l_;b0`3/k>`30>SXj0<0i^KV0`3[jn/30>k^kP@0l?3`
0`3_knl30?;blP<0lO7a0`3^k^h30>o_k`<0kNg]0`0C4a<600`<30<04A4A0`3Zj^X40?;blP<0kNg]
0`0E5AD301<C4`<05QHF0`0B4Q8301<C4`<0kNg]0`3/k>`30>_[j`<0k>c/103_knl30>k^kP<0kNg]
1P0D51@3018B4P<051@D1P0B4Q83014A4@<0j^[Z0`3_knl40>k^kP<0k>c/0`3[jn/3010@40<03`l?
0`0>3Ph6010@40<051@D2P0B4Q8301<C4`<05QHF0`0C4a<301@D50<04a<C0`0D51@301<C4`<0kNg]
1P3clo<30>g]k@@051@D1P0>3Ph301<C4`<0jn_[0`3alO430>o_k`<04a<C0`0A4A4601@D50<0l?3`
103emOD30?7al@<05QHF0`0G5aL301@D50<05ADE0`3`l?030?7al@<05ADE0`0B4Q83014A4@@04Q8B
0`3]kNd30>[ZjP<02@T90`051@D30>[ZjP<0kno_0`0@4103014A4@<0410@0`3_knl30?7al@@0k^k^
0`0F5QH601DE5@H0m?Cd1P0C4a<3018B4P<0lO7a0`3`l?0701@D50<05aLG0`0E5AD30?Cdm0<0mOGe
0`0E5AD60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0E
5AD601HF5P<0l_;b0`3/k>`30>SXj0<0i^KV0`3[jn/30>k^kP@0l?3`0`3_knl30?;blP<0lO7a0`3^
k^h30>o_k`<0kNg]0`0C4a<600`<30<04A4A0`3Zj^X40?;blP<0kNg]0`0E5AD301<C4`<05QHF0`0B
4Q8301<C4`<0kNg]0`3/k>`30>_[j`<0k>c/103_knl30>k^kP<0kNg]1P0D51@3018B4P<051@D1P0B
4Q83014A4@<0j^[Z0`3_knl40>k^kP<0k>c/0`3[jn/3010@40<03`l?0`0>3Ph6010@40<051@D2P0B
4Q8301<C4`<05QHF0`0C4a<301@D50<04a<C0`0D51@301<C4`<0kNg]1P3clo<30>g]k@@051@D1P0>
3Ph301<C4`<0jn_[0`3alO430>o_k`<04a<C0`0A4A4601@D50<0l?3`103emOD30?7al@<05QHF0`0G
5aL301@D50<05ADE0`3`l?030?7al@<05ADE0`0B4Q83014A4@@04Q8B0`3]kNd30>[ZjP<02@T90`05
1@D30>[ZjP<0kno_0`0@4103014A4@<0410@0`3_knl30?7al@@0k^k^0`0F5QH601DE5@H0m?Cd1P0C
4a<3018B4P<0lO7a0`3`l?0701@D50<05aLG0`0E5AD30?Cdm0<0mOGe0`0E5AD60?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0E5AD601HF5P<0l_;b0`3/k>`3
0>SXj0<0i^KV0`3[jn/30>k^kP@0l?3`0`3_knl30?;blP<0lO7a0`3^k^h30>o_k`<0kNg]0`0C4a<6
00`<30<04A4A0`3Zj^X40?;blP<0kNg]0`0E5AD301<C4`<05QHF0`0B4Q8301<C4`<0kNg]0`3/k>`3
0>_[j`<0k>c/103_knl30>k^kP<0kNg]1P0D51@3018B4P<051@D1P0B4Q83014A4@<0j^[Z0`3_knl4
0>k^kP<0k>c/0`3[jn/3010@40<03`l?0`0>3Ph6010@40<051@D2P0B4Q8301<C4`<05QHF0`0C4a<3
01@D50<04a<C0`0D51@301<C4`<0kNg]1P3clo<30>g]k@@051@D1P0>3Ph301<C4`<0jn_[0`3alO43
0>o_k`<04a<C0`0A4A4601@D50<0l?3`103emOD30?7al@<05QHF0`0G5aL301@D50<05ADE0`3`l?03
0?7al@<05ADE0`0B4Q83014A4@@04Q8B0`3]kNd30>[ZjP<02@T90`051@D30>[ZjP<0kno_0`0@4103
014A4@<0410@0`3_knl30?7al@@0k^k^0`0F5QH601DE5@H0m?Cd1P0C4a<3018B4P<0lO7a0`3`l?07
01@D50<05aLG0`0E5AD30?Cdm0<0mOGe0`0E5AD60?ooo`030000003oool0oooo00D0oooo000X0?oo
o`<000001@3oool301DE5@<05aLG0`0H61P30?7al@<0l?3`1P3Zj^X30>c/k0<0kno_103^k^h30?3`
l0<0lO7a0`3]kNd3014A4@<03`l?0`0A4A4300d=3@<030`<0`0A4A430>[ZjP<0lO7a103_knl301<C
4`<04A4A0`0E5AD3018B4P<051@D0`3YjNT30>g]k@<0jn_[0`3Xj>P70>[ZjP<0kno_0`3`l?030>k^
kP<0kNg]1P0D51@3018B4P<04a<C0`0@410301DE5@L0kNg]1P3_knl30>c/k0<0jn_[1P0A4A43010@
40<04Q8B0`0D51@301DE5@@05aLG1P0F5QH301DE5@<04Q8B0`0F5QH60>o_k`<0l_;b0`3_knl30>k^
kP<05ADE100?3`l300h>3P<04a<C0`3[jn/30?3`l0<0lO7a0`3^k^h601<C4`<04A4A0`0E5AD70?;b
lP<05QHF0`0D51@301HF5P<05ADE0`3`l?030?Gem@<0l?3`0`0E5AD301@D50<05ADE103_knl30?;b
lP<0j^[Z0`0;2`/300X:2P<0k^k^0`3`l?06014A4@<0410@1P3]kNd40>o_k`<04Q8B0`0C4a<301@D
50H0m?Cd2@0C4a<30??cl`<0l_;b0`0C4a<401LG5`<061PH0`0D51@60?Cdm0<05ADE1@3oool20000
00L0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0E5AD301LG5`<061PH0`3alO430?3`l0H0
j^[Z0`3/k>`30>o_k`@0k^k^0`3`l?030?7al@<0kNg]0`0A4A4300l?3`<04A4A0`0=3@d300`<30<0
4A4A0`3Zj^X30?7al@@0kno_0`0C4a<3014A4@<05ADE0`0B4Q8301@D50<0jNWY0`3]kNd30>_[j`<0
j>SX1`3Zj^X30>o_k`<0l?3`0`3^k^h30>g]k@H051@D0`0B4Q8301<C4`<0410@0`0E5AD70>g]k@H0
kno_0`3/k>`30>_[j`H04A4A0`0@4103018B4P<051@D0`0E5AD401LG5`H05QHF0`0E5AD3018B4P<0
5QHF1P3_knl30?;blP<0kno_0`3^k^h301DE5@@03`l?0`0>3Ph301<C4`<0jn_[0`3`l?030?7al@<0
k^k^1P0C4a<3014A4@<05ADE1`3bl_8301HF5P<051@D0`0F5QH301DE5@<0l?3`0`3emOD30?3`l0<0
5ADE0`0D51@301DE5@@0kno_0`3bl_830>[ZjP<02`/;0`0:2PX30>k^kP<0l?3`1P0A4A43010@40H0
kNg]103_knl3018B4P<04a<C0`0D51@60?Cdm0T04a<C0`3clo<30?;blP<04a<C100G5aL301PH60<0
51@D1P3dm?@301DE5@H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
1@3oool301DE5@<05aLG0`0H61P30?7al@<0l?3`1P3Zj^X30>c/k0<0kno_103^k^h30?3`l0<0lO7a
0`3]kNd3014A4@<03`l?0`0A4A4300d=3@<030`<0`0A4A430>[ZjP<0lO7a103_knl301<C4`<04A4A
0`0E5AD3018B4P<051@D0`3YjNT30>g]k@<0jn_[0`3Xj>P70>[ZjP<0kno_0`3`l?030>k^kP<0kNg]
1P0D51@3018B4P<04a<C0`0@410301DE5@L0kNg]1P3_knl30>c/k0<0jn_[1P0A4A43010@40<04Q8B
0`0D51@301DE5@@05aLG1P0F5QH301DE5@<04Q8B0`0F5QH60>o_k`<0l_;b0`3_knl30>k^kP<05ADE
100?3`l300h>3P<04a<C0`3[jn/30?3`l0<0lO7a0`3^k^h601<C4`<04A4A0`0E5AD70?;blP<05QHF
0`0D51@301HF5P<05ADE0`3`l?030?Gem@<0l?3`0`0E5AD301@D50<05ADE103_knl30?;blP<0j^[Z
0`0;2`/300X:2P<0k^k^0`3`l?06014A4@<0410@1P3]kNd40>o_k`<04Q8B0`0C4a<301@D50H0m?Cd
2@0C4a<30??cl`<0l_;b0`0C4a<401LG5`<061PH0`0D51@60?Cdm0<05ADE1P3oool00`000000oooo
0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<05QHF0`0J6QX301TI6@<06a/K0`3`
l?030>o_k`<0k^k^0`3_knl30>g]k@@04Q8B0`0?3`l3014A4@<04Q8B0`0>3Ph300l?3`<03@d=0`0?
3`l3010@40<0j^[Z1P3alO440>k^kPH04a<C0`0A4A4301@D50<0j^[Z1P3^k^h30>OWi`<03`l?0`0=
3@d4014A4@<0k>c/0`3^k^h30?3`l0<0lO7a1P3^k^h301HF5P<04A4A0`0C4a<3018B4PL04a<C1P3]
kNd60?3`l0<0kNg]0`3/k>`3018B4P<04A4A0`0E5AD301<C4`@05ADE0`0D51@301HF5PH04a<C0`3]
kNd30??cl`<0l_;b0`3/k>`6018B4P<0410@100?3`l301@D50<0k>c/1P3alO430>_[j`<051@D0`0@
4103014A4@<05QHF0`3_knl30?KfmP@0lO7a0`0F5QH301DE5@<04Q8B0`0E5AD30?7al@<0l_;b0`0F
5QH301@D50<05ADE0`0C4a<40?;blP<0kno_0`0@410300/;2`<03@d=0`3`l?030?7al@H04A4A0`0?
3`l60>c/k0@0kNg]0`0A4A43018B4P<04a<C1P3dm?@901<C4`<0lo?c0`3dm?@301@D50@061PH0`0G
5aL301TI6@<0lo?c0`3dm?@301HF5PH0oooo00<000000?ooo`3oool01@3oool002P0oooo00<00000
0?ooo`3oool01@3oool301HF5P<06QXJ0`0I6AT301/K6`<0l?3`0`3_knl30>k^kP<0kno_0`3]kNd4
018B4P<03`l?0`0A4A43018B4P<03Ph>0`0?3`l300d=3@<03`l?0`0@41030>[ZjPH0lO7a103^k^h6
01<C4`<04A4A0`0D51@30>[ZjPH0k^k^0`3WinL300l?3`<03@d=100A4A430>c/k0<0k^k^0`3`l?03
0?7al@H0k^k^0`0F5QH3014A4@<04a<C0`0B4Q8701<C4`H0kNg]1P3`l?030>g]k@<0k>c/0`0B4Q83
014A4@<05ADE0`0C4a<401DE5@<051@D0`0F5QH601<C4`<0kNg]0`3clo<30?;blP<0k>c/1P0B4Q83
010@40@03`l?0`0D51@30>c/k0H0lO7a0`3[jn/301@D50<0410@0`0A4A4301HF5P<0kno_0`3fm_H4
0?7al@<05QHF0`0E5AD3018B4P<05ADE0`3alO430?;blP<05QHF0`0D51@301DE5@<04a<C103bl_83
0>o_k`<0410@0`0;2`/300d=3@<0l?3`0`3alO46014A4@<03`l?1P3/k>`40>g]k@<04A4A0`0B4Q83
01<C4`H0m?Cd2@0C4a<30??cl`<0m?Cd0`0D51@401PH60<05aLG0`0I6AT30??cl`<0m?Cd0`0F5QH6
0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0F5QH301XJ
6P<06ATI0`0K6a/30?3`l0<0kno_0`3^k^h30>o_k`<0kNg]100B4Q8300l?3`<04A4A0`0B4Q8300h>
3P<03`l?0`0=3@d300l?3`<0410@0`3Zj^X60?7al@@0k^k^1P0C4a<3014A4@<051@D0`3Zj^X60>k^
kP<0inOW0`0?3`l300d=3@@04A4A0`3/k>`30>k^kP<0l?3`0`3alO460>k^kP<05QHF0`0A4A4301<C
4`<04Q8B1`0C4a<60>g]k@H0l?3`0`3]kNd30>c/k0<04Q8B0`0A4A4301DE5@<04a<C100E5AD301@D
50<05QHF1P0C4a<30>g]k@<0lo?c0`3bl_830>c/k0H04Q8B0`0@410400l?3`<051@D0`3/k>`60?7a
l@<0jn_[0`0D51@3010@40<04A4A0`0F5QH30>o_k`<0m_Kf103alO4301HF5P<05ADE0`0B4Q8301DE
5@<0lO7a0`3bl_8301HF5P<051@D0`0E5AD301<C4`@0l_;b0`3_knl3010@40<02`/;0`0=3@d30?3`
l0<0lO7a1P0A4A4300l?3`H0k>c/103]kNd3014A4@<04Q8B0`0C4a<60?Cdm0T04a<C0`3clo<30?Cd
m0<051@D100H61P301LG5`<06ATI0`3clo<30?Cdm0<05QHF1P3oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`050?ooo`<05aLG0`0M7Ad3020P80<06QXJ0`0I6AT301@D50H0
4A4A0`0C4a<4010@40<04A4A0`0@410300l?3`<04A4A0`0?3`l3014A4@<0k>c/0`3^k^h30?7al@H0
k^k^100F5QH6010@40<051@D0`3Zj^X60>o_k`<0j^[Z0`0C4a<3010@40<04a<C100B4Q8601@D50H0
k^k^0`3alO430?;blP<0k>c/0`0C4a<301@D50<04Q8B0`0D51@401<C4`<051@D0`0C4a<30>g]k@<0
k^k^1P3alO430>k^kP<0l?3`0`3_knl301<C4`@0410@0`0D51@30?7al@<0lo?c0`3alO430?Cdm0<0
l?3`0`3_knl301DE5@<03`l?0`0A4A4300l?3`@051@D0`3^k^h30?Cdm0<0kno_0`3^k^h301@D50H0
3`l?0`0E5AD30>k^kP<0m_Kf0`3`l?0401PH60<051@D0`0C4a<301LG5`<0k^k^0`3dm?@30?3`l0<0
5ADE0`0F5QH301<C4`<05ADE1`3alO4300l?3`H03Ph>0`3`l?030?7al@H04A4A0`0?3`l30>c/k0<0
jn_[103/k>`3010@40<04Q8B0`0C4a<60?Cdm0T04a<C1P3dm?@301@D50@05aLG0`0L71`30?7al@<0
moOg0`3dm?@301LG5`H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
1@3oool301LG5`<07AdM0`0P820301XJ6P<06ATI0`0D51@6014A4@<04a<C100@4103014A4@<0410@
0`0?3`l3014A4@<03`l?0`0A4A430>c/k0<0k^k^0`3alO460>k^kP@05QHF1P0@410301@D50<0j^[Z
1P3_knl30>[ZjP<04a<C0`0@410301<C4`@04Q8B1P0D51@60>k^kP<0lO7a0`3bl_830>c/k0<04a<C
0`0D51@3018B4P<051@D100C4a<301@D50<04a<C0`3]kNd30>k^kPH0lO7a0`3^k^h30?3`l0<0kno_
0`0C4a<4010@40<051@D0`3alO430??cl`<0lO7a0`3dm?@30?3`l0<0kno_0`0E5AD300l?3`<04A4A
0`0?3`l401@D50<0k^k^0`3dm?@30>o_k`<0k^k^0`0D51@600l?3`<05ADE0`3^k^h30?KfmP<0l?3`
100H61P301@D50<04a<C0`0G5aL30>k^kP<0m?Cd0`3`l?0301DE5@<05QHF0`0C4a<301DE5@L0lO7a
0`0?3`l600h>3P<0l?3`0`3alO46014A4@<03`l?0`3/k>`30>_[j`@0k>c/0`0@4103018B4P<04a<C
1P3dm?@901<C4`H0m?Cd0`0D51@401LG5`<071`L0`3alO430?Ogm`<0m?Cd0`0G5aL60?ooo`030000
003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0G5aL301dM7@<0820P0`0J
6QX301TI6@<051@D1P0A4A4301<C4`@0410@0`0A4A43010@40<03`l?0`0A4A4300l?3`<04A4A0`3/
k>`30>k^kP<0lO7a1P3^k^h401HF5PH0410@0`0D51@30>[ZjPH0kno_0`3Zj^X301<C4`<0410@0`0C
4a<4018B4PH051@D1P3^k^h30?7al@<0l_;b0`3/k>`301<C4`<051@D0`0B4Q8301@D50@04a<C0`0D
51@301<C4`<0kNg]0`3^k^h60?7al@<0k^k^0`3`l?030>o_k`<04a<C100@410301@D50<0lO7a0`3c
lo<30?7al@<0m?Cd0`3`l?030>o_k`<05ADE0`0?3`l3014A4@<03`l?100D51@30>k^kP<0m?Cd0`3_
knl30>k^kP<051@D1P0?3`l301DE5@<0k^k^0`3fm_H30?3`l0@061PH0`0D51@301<C4`<05aLG0`3^
k^h30?Cdm0<0l?3`0`0E5AD301HF5P<04a<C0`0E5AD70?7al@<03`l?1P0>3Ph30?3`l0<0lO7a1P0A
4A4300l?3`<0k>c/0`3[jn/40>c/k0<0410@0`0B4Q8301<C4`H0m?Cd2@0C4a<60?Cdm0<051@D100G
5aL301`L70<0lO7a0`3gmoL30?Cdm0<05aLG1P3oool00`000000oooo0?ooo`050?ooo`00:03oool0
0`000000oooo0?ooo`050?ooo`<05aLG0`0N7Qh302@T90<08B4Q0`0K6a/301HF5P<04a<C1P0B4Q84
010@40<04a<C0`0@4103014A4@<0kNg]0`3_knl30>g]k@<0lO7a0`3bl_830>c/k0<04Q8B0`0C4a<4
010@40<03`l?0`0C4a<30>[ZjPH0kno_0`3[jn/301DE5@<04Q8B0`0G5aL301TI6@@061PH0`0F5QH3
01<C4`H051@D0`3^k^h30>o_k`<0lo?c0`3`l?030>o_k`<05aLG0`0B4Q8401DE5@<05QHF0`0C4a<6
01@D50<0kno_0`3`l?030>o_k`H0l_;b0`3`l?070?7al@<0mOGe0`3alO430??cl`<0l?3`0`0D51@3
01<C4`H0410@0`0B4Q8301<C4`@0kNg]0`3emOD30>k^kPH04a<C0`0@410300l?3`<051@D0`3]kNd3
0?Cdm0<0k^k^0`0G5aL401<C4`<05ADE0`0D51@30?3`l0<0lo?c0`3alO4301DE5@<051@D0`0F5QH3
01DE5@<0l?3`103dm?@30>o_k`<04A4A0`0=3@d3010@40<0k^k^0`3alO43018B4P<04A4A0`0?3`l3
0>c/k0<0j^[Z103/k>`300l?3`<04Q8B0`0C4a<60?Cdm0T04a<C1P3clo<301<C4`@05aLG0`0F5QH3
01PH60<0lo?c0`3dm?@301LG5`H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool01@3oool301LG5`<07QhN0`0T92@3024Q8@<06a/K0`0F5QH301<C4`H04Q8B100@410301<C
4`<0410@0`0A4A430>g]k@<0kno_0`3]kNd30?7al@<0l_;b0`3/k>`3018B4P<04a<C100@410300l?
3`<04a<C0`3Zj^X60>o_k`<0jn_[0`0E5AD3018B4P<05aLG0`0I6AT401PH60<05QHF0`0C4a<601@D
50<0k^k^0`3_knl30??cl`<0l?3`0`3_knl301LG5`<04Q8B100E5AD301HF5P<04a<C1P0D51@30>o_
k`<0l?3`0`3_knl60?;blP<0l?3`1`3alO430?Gem@<0lO7a0`3clo<30?3`l0<051@D0`0C4a<6010@
40<04Q8B0`0C4a<40>g]k@<0mOGe0`3^k^h601<C4`<0410@0`0?3`l301@D50<0kNg]0`3dm?@30>k^
kP<05aLG100C4a<301DE5@<051@D0`3`l?030??cl`<0lO7a0`0E5AD301@D50<05QHF0`0E5AD30?3`
l0@0m?Cd0`3_knl3014A4@<03@d=0`0@41030>k^kP<0lO7a0`0B4Q83014A4@<03`l?0`3/k>`30>[Z
jP@0k>c/0`0?3`l3018B4P<04a<C1P3dm?@901<C4`H0lo?c0`0C4a<401LG5`<05QHF0`0H61P30??c
l`<0m?Cd0`0G5aL60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0
oooo0`0G5aL301hN7P<092@T0`0Q8B4301/K6`<05QHF0`0C4a<6018B4P@0410@0`0C4a<3010@40<0
4A4A0`3]kNd30>o_k`<0kNg]0`3alO430?;blP<0k>c/0`0B4Q8301<C4`@0410@0`0?3`l301<C4`<0
j^[Z1P3_knl30>_[j`<05ADE0`0B4Q8301LG5`<06ATI100H61P301HF5P<04a<C1P0D51@30>k^kP<0
kno_0`3clo<30?3`l0<0kno_0`0G5aL3018B4P@05ADE0`0F5QH301<C4`H051@D0`3_knl30?3`l0<0
kno_1P3bl_830?3`l0L0lO7a0`3emOD30?7al@<0lo?c0`3`l?0301@D50<04a<C1P0@4103018B4P<0
4a<C103]kNd30?Gem@<0k^k^1P0C4a<3010@40<03`l?0`0D51@30>g]k@<0m?Cd0`3^k^h301LG5`@0
4a<C0`0E5AD301@D50<0l?3`0`3clo<30?7al@<05ADE0`0D51@301HF5P<05ADE0`3`l?040?Cdm0<0
kno_0`0A4A4300d=3@<0410@0`3^k^h30?7al@<04Q8B0`0A4A4300l?3`<0k>c/0`3Zj^X40>c/k0<0
3`l?0`0B4Q8301<C4`H0m?Cd2@0C4a<60??cl`<04a<C100G5aL301HF5P<061PH0`3clo<30?Cdm0<0
5aLG1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<05aLG
0`0N7Qh302@T90<08B4Q0`0K6a/301HF5P<04a<C1P0B4Q84010@40<04a<C0`0@4103014A4@<0kNg]
0`3_knl30>g]k@<0lO7a0`3bl_830>c/k0<04Q8B0`0C4a<4010@40<03`l?0`0C4a<30>[ZjPH0kno_
0`3[jn/301DE5@<04Q8B0`0G5aL301TI6@@061PH0`0F5QH301<C4`H051@D0`3^k^h30>o_k`<0lo?c
0`3`l?030>o_k`<05aLG0`0B4Q8401DE5@<05QHF0`0C4a<601@D50<0kno_0`3`l?030>o_k`H0l_;b
0`3`l?070?7al@<0mOGe0`3alO430??cl`<0l?3`0`0D51@301<C4`H0410@0`0B4Q8301<C4`@0kNg]
0`3emOD30>k^kPH04a<C0`0@410300l?3`<051@D0`3]kNd30?Cdm0<0k^k^0`0G5aL401<C4`<05ADE
0`0D51@30?3`l0<0lo?c0`3alO4301DE5@<051@D0`0F5QH301DE5@<0l?3`103dm?@30>o_k`<04A4A
0`0=3@d3010@40<0k^k^0`3alO43018B4P<04A4A0`0?3`l30>c/k0<0j^[Z103/k>`300l?3`<04Q8B
0`0C4a<60?Cdm0T04a<C1P3clo<301<C4`@05aLG0`0F5QH301PH60<0lo?c0`3dm?@301LG5`H0oooo
00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool301LG5`<071`L0`0P
820301dM7@H05QHF0`0C4a<3014A4@<0410@100B4Q830>k^kP<0l?3`0`3^k^h60?7al@<0k^k^0`3`
l?030>o_k`<05QHF0`0A4A4301<C4`@0410@0`0D51@30>_[j`<0l?3`0`3_knl30>_[j`<05ADE0`0B
4Q8301LG5`<05QHF1`0I6AT301@D50H05QHF0`0C4a<601@D50<0kNg]1P3clo<30>k^kPL05ADE0`0D
51@601HF5P<051@D0`0E5AD3018B4P<051@D0`3_knl60?;blP@0lo?c0`3dm?@30?7al@<05ADE0`0B
4Q8301DE5@<04A4A0`0B4Q83010@40<05ADE0`3^k^h30?3`l0@0m?Cd0`3^k^h301HF5P<04A4A0`0C
4a<3010@40<051@D0`3/k>`30?;blP<0l?3`0`0D51@3018B4P@05ADE0`0B4Q8301@D50<0l?3`0`3d
m?@30?3`l0H05ADE0`0B4Q8301DE5@L0lO7a0`0C4a<300h>3P<0410@0`3/k>`60?7al@H04Q8B0`0?
3`l30>c/k0<0j^[Z103/k>`300l?3`<04A4A0`0C4a<60??cl`T04a<C0`3bl_830?7al@<05ADE100D
51@301HF5P<051@D0`3dm?@30?Gem@<05aLG1P3oool00`000000oooo0?ooo`050?ooo`00:03oool0
0`000000oooo0?ooo`050?ooo`<05aLG0`0L71`3020P80<07AdM1P0F5QH301<C4`<04A4A0`0@4104
018B4P<0k^k^0`3`l?030>k^kPH0lO7a0`3^k^h30?3`l0<0kno_0`0F5QH3014A4@<04a<C100@4103
01@D50<0jn_[0`3`l?030>o_k`<0jn_[0`0E5AD3018B4P<05aLG0`0F5QH701TI6@<051@D1P0F5QH3
01<C4`H051@D0`3]kNd60??cl`<0k^k^1`0E5AD301@D50H05QHF0`0D51@301DE5@<04Q8B0`0D51@3
0>o_k`H0l_;b103clo<30?Cdm0<0lO7a0`0E5AD3018B4P<05ADE0`0A4A43018B4P<0410@0`0E5AD3
0>k^kP<0l?3`103dm?@30>k^kP<05QHF0`0A4A4301<C4`<0410@0`0D51@30>c/k0<0l_;b0`3`l?03
01@D50<04Q8B100E5AD3018B4P<051@D0`3`l?030?Cdm0<0l?3`1P0E5AD3018B4P<05ADE1`3alO43
01<C4`<03Ph>0`0@41030>c/k0H0lO7a1P0B4Q8300l?3`<0k>c/0`3Zj^X40>c/k0<03`l?0`0A4A43
01<C4`H0lo?c2@0C4a<30?;blP<0lO7a0`0E5AD401@D50<05QHF0`0D51@30?Cdm0<0mOGe0`0G5aL6
0?ooo`030000003oool0oooo00D0oooo000M0?ooo`@000001`3oool00`000000oooo0?ooo`050?oo
o`<05aLG0`0L71`3020P80<07AdM1P0F5QH301<C4`<04A4A0`0@4104018B4P<0k^k^0`3`l?030>k^
kPH0lO7a0`3^k^h30?3`l0<0kno_0`0F5QH3014A4@<04a<C100@410301@D50<0jn_[0`3`l?030>o_
k`<0jn_[0`0E5AD3018B4P<05aLG0`0F5QH701TI6@<051@D1P0F5QH301<C4`H051@D0`3]kNd60??c
l`<0k^k^1`0E5AD301@D50H05QHF0`0D51@301DE5@<04Q8B0`0D51@30>o_k`H0l_;b103clo<30?Cd
m0<0lO7a0`0E5AD3018B4P<05ADE0`0A4A43018B4P<0410@0`0E5AD30>k^kP<0l?3`103dm?@30>k^
kP<05QHF0`0A4A4301<C4`<0410@0`0D51@30>c/k0<0l_;b0`3`l?0301@D50<04Q8B100E5AD3018B
4P<051@D0`3`l?030?Cdm0<0l?3`1P0E5AD3018B4P<05ADE1`3alO4301<C4`<03Ph>0`0@41030>c/
k0H0lO7a1P0B4Q8300l?3`<0k>c/0`3Zj^X40>c/k0<03`l?0`0A4A4301<C4`H0lo?c2@0C4a<30?;b
lP<0lO7a0`0E5AD401@D50<05QHF0`0D51@30?Cdm0<0mOGe0`0G5aL60?ooo`030000003oool0oooo
00D0oooo000L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`<05ADE2@0G5aL301HF5P<0kno_0`3alO460?3`l0@0kno_1P3bl_830>k^kP<0
l?3`0`3_knl301<C4`<04Q8B0`0E5AD301<C4`<051@D0`0A4A4401DE5@<0kNg]1P3alO430>c/k0<0
5ADE0`0B4Q8301HF5P<04a<C0`0H61P30?7al@@0l?3`1P0D51@301<C4`H05QHF0`0C4a<301LG5`<0
l?3`0`3alO430?Cdm0<0l_;b103`l?0301HF5P<05ADE0`0D51@901DE5@<04a<C0`0F5QH301@D50L0
4a<C0`0D51@301HF5P<04Q8B0`0C4a<3018B4P<04A4A1P0C4a<30>g]k@H0lo?c103^k^h301HF5P<0
4Q8B0`0E5AD3018B4P<05QHF0`3]kNd60?;blP<0kno_1P0C4a<4018B4P<05QHF0`3^k^h30?Cdm0<0
k^k^0`0G5aL301<C4`<051@D0`0H61P30>o_k`<0mOGe103_knl3014A4@<03@d=0`0A4A430>g]k@<0
lO7a0`3_knl301DE5@<04a<C0`0@41030>c/k0<0jn_[103/k>`3010@40<04Q8B0`0C4a<60??cl`T0
4a<C0`3bl_830??cl`<0l?3`100F5QH601DE5@H0mOGe0`0E5AD60?ooo`030000003oool0oooo00D0
oooo000L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`<05ADE2@0G5aL301HF5P<0kno_0`3alO460?3`l0@0kno_1P3bl_830>k^kP<0l?3`
0`3_knl301<C4`<04Q8B0`0E5AD301<C4`<051@D0`0A4A4401DE5@<0kNg]1P3alO430>c/k0<05ADE
0`0B4Q8301HF5P<04a<C0`0H61P30?7al@@0l?3`1P0D51@301<C4`H05QHF0`0C4a<301LG5`<0l?3`
0`3alO430?Cdm0<0l_;b103`l?0301HF5P<05ADE0`0D51@901DE5@<04a<C0`0F5QH301@D50L04a<C
0`0D51@301HF5P<04Q8B0`0C4a<3018B4P<04A4A1P0C4a<30>g]k@H0lo?c103^k^h301HF5P<04Q8B
0`0E5AD3018B4P<05QHF0`3]kNd60?;blP<0kno_1P0C4a<4018B4P<05QHF0`3^k^h30?Cdm0<0k^k^
0`0G5aL301<C4`<051@D0`0H61P30>o_k`<0mOGe103_knl3014A4@<03@d=0`0A4A430>g]k@<0lO7a
0`3_knl301DE5@<04a<C0`0@41030>c/k0<0jn_[103/k>`3010@40<04Q8B0`0C4a<60??cl`T04a<C
0`3bl_830??cl`<0l?3`100F5QH601DE5@H0mOGe0`0E5AD60?ooo`030000003oool0oooo00D0oooo
000L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool4000000@0oooo0`0E
5AD901LG5`<05QHF0`3_knl30?7al@H0l?3`103_knl60?;blP<0k^k^0`3`l?030>o_k`<04a<C0`0B
4Q8301DE5@<04a<C0`0D51@3014A4@@05ADE0`3]kNd60?7al@<0k>c/0`0E5AD3018B4P<05QHF0`0C
4a<301PH60<0lO7a103`l?0601@D50<04a<C1P0F5QH301<C4`<05aLG0`3`l?030?7al@<0m?Cd0`3b
l_840?3`l0<05QHF0`0E5AD301@D50T05ADE0`0C4a<301HF5P<051@D1`0C4a<301@D50<05QHF0`0B
4Q8301<C4`<04Q8B0`0A4A4601<C4`<0kNg]1P3clo<40>k^kP<05QHF0`0B4Q8301DE5@<04Q8B0`0F
5QH30>g]k@H0l_;b0`3_knl601<C4`@04Q8B0`0F5QH30>k^kP<0m?Cd0`3^k^h301LG5`<04a<C0`0D
51@301PH60<0kno_0`3emOD40>o_k`<04A4A0`0=3@d3014A4@<0kNg]0`3alO430>o_k`<05ADE0`0C
4a<3010@40<0k>c/0`3[jn/40>c/k0<0410@0`0B4Q8301<C4`H0lo?c2@0C4a<30?;blP<0lo?c0`3`
l?0401HF5PH05ADE1P3emOD301DE5@@0oooo0`0000070?ooo`00703oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool301<C4`<04A4A0`0G5aL6
0>o_k`<0l?3`0`3_knl30?7al@<0kno_103`l?030?7al@<0kno_0`0D51@3018B4P<05ADE0`0C4a<3
01DE5@<051@D0`0B4Q8601@D50@0k^k^0`3dm?@30>o_k`<0k^k^0`0F5QH3018B4P<05ADE0`0B4Q83
01HF5P<0k>c/0`3_knl40>k^kPH0k>c/0`0D51@301DE5@<051@D0`0G5aL301DE5@H05QHF0`3`l?03
0?;blP@0m_Kf0`3bl_830?3`l0<05ADE0`0C4a<301HF5P<04a<C0`0E5AD601@D50d04a<C0`0B4Q83
01@D50<04A4A0`0C4a<30>o_k`<0l?3`0`3clo<30?3`l0<0kno_100F5QH3014A4@<051@D0`0B4Q83
01HF5P<0kno_0`3dm?@30?3`l0<0kno_0`0F5QH3014A4@<0410@100E5AD30>g]k@<0m?Cd0`3^k^h3
01HF5P<04a<C1P0E5AD30?7al@<0mOGe0`3]kNd401@D50<03Ph>0`0@41030>c/k0<0lO7a0`3_knl3
01@D50<04a<C0`0D51@3010@40<0k>c/0`3[jn/40>g]k@<0410@0`0B4Q8301<C4`<0lo?c0`3bl_83
014A4@<04a<C0`0E5AD30>o_k`<0lo?c0`3bl_8401<C4`<051@D0`0F5QH30?KfmP<0mOGe0`0C4a<6
0?ooo`030000003oool0oooo00D0oooo000L0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`<04a<C0`0A4A4301LG5`H0kno_0`3`l?030>o_
k`<0lO7a0`3_knl40?3`l0<0lO7a0`3_knl301@D50<04Q8B0`0E5AD301<C4`<05ADE0`0D51@3018B
4PH051@D103^k^h30?Cdm0<0kno_0`3^k^h301HF5P<04Q8B0`0E5AD3018B4P<05QHF0`3/k>`30>o_
k`@0k^k^1P3/k>`301@D50<05ADE0`0D51@301LG5`<05ADE1P0F5QH30?3`l0<0l_;b103fm_H30?;b
lP<0l?3`0`0E5AD301<C4`<05QHF0`0C4a<301DE5@H051@D3@0C4a<3018B4P<051@D0`0A4A4301<C
4`<0kno_0`3`l?030??cl`<0l?3`0`3_knl401HF5P<04A4A0`0D51@3018B4P<05QHF0`3_knl30?Cd
m0<0l?3`0`3_knl301HF5P<04A4A0`0@410401DE5@<0kNg]0`3dm?@30>k^kP<05QHF0`0C4a<601DE
5@<0lO7a0`3emOD30>g]k@@051@D0`0>3Ph3010@40<0k>c/0`3alO430>o_k`<051@D0`0C4a<301@D
50<0410@0`3/k>`30>_[j`@0kNg]0`0@4103018B4P<04a<C0`3clo<30?;blP<04A4A0`0C4a<301DE
5@<0kno_0`3clo<30?;blP@04a<C0`0D51@301HF5P<0m_Kf0`3emOD301<C4`H0oooo00<000000?oo
o`3oool01@3oool001`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo0`0C4a<3014A4@<05aLG1P3_knl30?3`l0<0kno_0`3alO430>o_k`@0
l?3`0`3alO430>o_k`<051@D0`0B4Q8301DE5@<04a<C0`0E5AD301@D50<04Q8B1P0D51@40>k^kP<0
m?Cd0`3_knl30>k^kP<05QHF0`0B4Q8301DE5@<04Q8B0`0F5QH30>c/k0<0kno_103^k^h60>c/k0<0
51@D0`0E5AD301@D50<05aLG0`0E5AD601HF5P<0l?3`0`3bl_840?KfmP<0l_;b0`3`l?0301DE5@<0
4a<C0`0F5QH301<C4`<05ADE1P0D51@=01<C4`<04Q8B0`0D51@3014A4@<04a<C0`3_knl30?3`l0<0
lo?c0`3`l?030>o_k`@05QHF0`0A4A4301@D50<04Q8B0`0F5QH30>o_k`<0m?Cd0`3`l?030>o_k`<0
5QHF0`0A4A43010@40@05ADE0`3]kNd30?Cdm0<0k^k^0`0F5QH301<C4`H05ADE0`3alO430?Gem@<0
kNg]100D51@300h>3P<0410@0`3/k>`30?7al@<0kno_0`0D51@301<C4`<051@D0`0@41030>c/k0<0
jn_[103]kNd3010@40<04Q8B0`0C4a<30??cl`<0l_;b0`0A4A4301<C4`<05ADE0`3_knl30??cl`<0
l_;b100C4a<301@D50<05QHF0`3fm_H30?Gem@<04a<C1P3oool00`000000oooo0?ooo`050?ooo`00
703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool3010@40<03`l?0`3]kNd30?7al@<0l?3`0`3/k>`30>o_k`<0k^k^0`0C4a<4014A4@<04a<C
0`0F5QH301<C4`T05ADE0`0C4a<601DE5@<0l?3`0`3bl_840?Gem@<0k^k^1P0D51@3018B4P<051@D
0`0A4A4301DE5@<0k>c/0`3_knl30>_[j`@0jNWY0`3[jn/60>k^kP<0kno_0`0G5aL301<C4`<05QHF
0`0G5aL301@D50H05QHF103alO430?;blP<0mOGe0`3`l?030?;blP<0l?3`0`0D51@3018B4Q004a<C
0`0A4A4301<C4`<0kno_0`3alO430?3`l0<0m?Cd0`3alO430>o_k`<051@D0`0C4a<7014A4@<04a<C
0`0D51@30>k^kP<0m_Kf0`3^k^h301@D50<04a<C0`0A4A4300l?3`<051@D103/k>`30?;blP<0l?3`
0`0D51@3018B4P<05ADE0`0B4Q8301DE5@<0lO7a0`3`l?03014A4@L03@d=0`0A4A430>k^kP<0l_;b
0`3_knl301DE5@<05aLG0`0D51@300l?3`<0k>c/0`3]kNd40>o_k`<04Q8B1P0C4a<30?;blP<0l?3`
0`0C4a<6014A4@<04a<C0`3_knl30?7al@@04A4A0`0D51@301PH60<0m?Cd0`3fm_H3010@40H0oooo
00<000000?ooo`3oool01@3oool001d0oooo100000070?ooo`030000003oool0oooo00D0oooo0`0@
410300l?3`<0kNg]0`3alO430?3`l0<0k>c/0`3_knl30>k^kP<04a<C100A4A4301<C4`<05QHF0`0C
4a<901DE5@<04a<C1P0E5AD30?3`l0<0l_;b103emOD30>k^kPH051@D0`0B4Q8301@D50<04A4A0`0E
5AD30>c/k0<0kno_0`3[jn/40>WYj@<0jn_[1P3^k^h30>o_k`<05aLG0`0C4a<301HF5P<05aLG0`0D
51@601HF5P@0lO7a0`3bl_830?Gem@<0l?3`0`3bl_830?3`l0<051@D0`0B4Q8@01<C4`<04A4A0`0C
4a<30>o_k`<0lO7a0`3`l?030?Cdm0<0lO7a0`3_knl301@D50<04a<C1`0A4A4301<C4`<051@D0`3^
k^h30?KfmP<0k^k^0`0D51@301<C4`<04A4A0`0?3`l301@D50@0k>c/0`3bl_830?3`l0<051@D0`0B
4Q8301DE5@<04Q8B0`0E5AD30?7al@<0l?3`0`0A4A4700d=3@<04A4A0`3^k^h30?;blP<0kno_0`0E
5AD301LG5`<051@D0`0?3`l30>c/k0<0kNg]103_knl3018B4PH04a<C0`3bl_830?3`l0<04a<C1P0A
4A4301<C4`<0kno_0`3alO44014A4@<051@D0`0H61P30?Cdm0<0m_Kf0`0@41060?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0@410300l?3`<0kNg]0`3alO43
0?3`l0<0k>c/0`3_knl30>k^kP<04a<C100A4A4301<C4`<05QHF0`0C4a<901DE5@<04a<C1P0E5AD3
0?3`l0<0l_;b103emOD30>k^kPH051@D0`0B4Q8301@D50<04A4A0`0E5AD30>c/k0<0kno_0`3[jn/4
0>WYj@<0jn_[1P3^k^h30>o_k`<05aLG0`0C4a<301HF5P<05aLG0`0D51@601HF5P@0lO7a0`3bl_83
0?Gem@<0l?3`0`3bl_830?3`l0<051@D0`0B4Q8@01<C4`<04A4A0`0C4a<30>o_k`<0lO7a0`3`l?03
0?Cdm0<0lO7a0`3_knl301@D50<04a<C1`0A4A4301<C4`<051@D0`3^k^h30?KfmP<0k^k^0`0D51@3
01<C4`<04A4A0`0?3`l301@D50@0k>c/0`3bl_830?3`l0<051@D0`0B4Q8301DE5@<04Q8B0`0E5AD3
0?7al@<0l?3`0`0A4A4700d=3@<04A4A0`3^k^h30?;blP<0kno_0`0E5AD301LG5`<051@D0`0?3`l3
0>c/k0<0kNg]103_knl3018B4PH04a<C0`3bl_830?3`l0<04a<C1P0A4A4301<C4`<0kno_0`3alO44
014A4@<051@D0`0H61P30?Cdm0<0m_Kf0`0@41060?ooo`030000003oool0oooo00D0oooo000X0?oo
o`030000003oool0oooo00D0oooo0`0=3@d300l?3`<0kNg]0`3alO430>_[j`H04Q8B0`0F5QH301@D
50L05ADE0`0D51@301DE5@<04a<C0`0F5QH3018B4P<051@D0`3`l?030?;blP<0mOGe0`3bl_840?7a
l@<05aLG0`0B4Q8301@D50<04a<C1P0D51@30>g]k@<0lo?c3@3/k>`30>_[j`<0l?3`0`3bl_830>g]
k@H05ADE0`0D51@601LG5`<05ADE1`0F5QH30?3`l0<0lO7a1P3clo<30?3`l0<0l_;b0`3clo<60?Cd
m0L0lo?c0`3bl_830?3`l0H0lo?c0`3`l?030>o_k`<051@D0`0C4a<6014A4@@03`l?0`0E5AD30>o_
k`<0l?3`0`3emOD30>o_k`<05aLG0`0B4Q8301<C4`<0410@0`0D51@30>_[j`@0l?3`0`3alO430>k^
kPH051@D0`0C4a<301LG5`<0k^k^0`3dm?@30>k^kP<03`l?100<30`301<C4`<0k>c/0`3dm?@30>g]
k@<05aLG0`0D51@301HF5PH04A4A0`3/k>`30>o_k`@0k^k^0`0F5QH301DE5@<051@D1P3bl_830>o_
k`<051@D0`0B4Q83014A4@<0lO7a0`3_knl401@D50<04a<C0`0D51@301TI6@<0l_;b0`0=3@d60?oo
o`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0=3@d300l?3`<0
kNg]0`3alO430>_[j`H04Q8B0`0F5QH301@D50L05ADE0`0D51@301DE5@<04a<C0`0F5QH3018B4P<0
51@D0`3`l?030?;blP<0mOGe0`3bl_840?7al@<05aLG0`0B4Q8301@D50<04a<C1P0D51@30>g]k@<0
lo?c3@3/k>`30>_[j`<0l?3`0`3bl_830>g]k@H05ADE0`0D51@601LG5`<05ADE1`0F5QH30?3`l0<0
lO7a1P3clo<30?3`l0<0l_;b0`3clo<60?Cdm0L0lo?c0`3bl_830?3`l0H0lo?c0`3`l?030>o_k`<0
51@D0`0C4a<6014A4@@03`l?0`0E5AD30>o_k`<0l?3`0`3emOD30>o_k`<05aLG0`0B4Q8301<C4`<0
410@0`0D51@30>_[j`@0l?3`0`3alO430>k^kPH051@D0`0C4a<301LG5`<0k^k^0`3dm?@30>k^kP<0
3`l?100<30`301<C4`<0k>c/0`3dm?@30>g]k@<05aLG0`0D51@301HF5PH04A4A0`3/k>`30>o_k`@0
k^k^0`0F5QH301DE5@<051@D1P3bl_830>o_k`<051@D0`0B4Q83014A4@<0lO7a0`3_knl401@D50<0
4a<C0`0D51@301TI6@<0l_;b0`0=3@d60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo00D0oooo0`0=3@d300l?3`<0kNg]0`3alO430>_[j`H04Q8B0`0F5QH301@D50L05ADE
0`0D51@301DE5@<04a<C0`0F5QH3018B4P<051@D0`3`l?030?;blP<0mOGe0`3bl_840?7al@<05aLG
0`0B4Q8301@D50<04a<C1P0D51@30>g]k@<0lo?c3@3/k>`30>_[j`<0l?3`0`3bl_830>g]k@H05ADE
0`0D51@601LG5`<05ADE1`0F5QH30?3`l0<0lO7a1P3clo<30?3`l0<0l_;b0`3clo<60?Cdm0L0lo?c
0`3bl_830?3`l0H0lo?c0`3`l?030>o_k`<051@D0`0C4a<6014A4@@03`l?0`0E5AD30>o_k`<0l?3`
0`3emOD30>o_k`<05aLG0`0B4Q8301<C4`<0410@0`0D51@30>_[j`@0l?3`0`3alO430>k^kPH051@D
0`0C4a<301LG5`<0k^k^0`3dm?@30>k^kP<03`l?100<30`301<C4`<0k>c/0`3dm?@30>g]k@<05aLG
0`0D51@301HF5PH04A4A0`3/k>`30>o_k`@0k^k^0`0F5QH301DE5@<051@D1P3bl_830>o_k`<051@D
0`0B4Q83014A4@<0lO7a0`3_knl401@D50<04a<C0`0D51@301TI6@<0l_;b0`0=3@d60?ooo`030000
003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0@41030>[ZjP<0lO7a0`3/
k>`301DE5@<04a<C0`0G5aL301PH60<05aLG100D51@301HF5P<04a<C0`0B4Q8301@D50<0kno_0`3a
lO430?3`l0<0mOGe0`3bl_830?7al@<05QHF100E5AD301<C4`<051@D0`0A4A4301HF5P<0kno_0`3`
l?030?Cdm0<0kNg]0`0B4Q8300l?3`L0410@0`0B4Q830>k^kP<0l?3`0`3dm?@30?7al@<0l?3`1P0E
5AD301@D50<05aLG100F5QH301@D50H05ADE0`3`l?060?;blQH0lo?c1P3bl_830>o_k`<051@D0`0C
4a<3014A4@<04Q8B0`0@4107018B4P<0k>c/1P3clo<30>k^kP<05aLG0`0C4a<301HF5P<04Q8B0`0E
5AD30>c/k0L0l?3`0`3/k>`301HF5PH04a<C0`0G5aL30>o_k`<0m?Cd0`3/k>`3014A4@<02PX:100B
4Q830>g]k@<0mOGe0`3^k^h301DE5@<04A4A0`0D51@3018B4P<05ADE0`3/k>`30?7al@<0kno_1`0E
5AD301PH60<05QHF0`3^k^h60?7al@T04Q8B0`3bl_830??cl`@0l?3`0`0F5QH301DE5@<05QHF0`3c
lo<3010@40H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool3
010@40<0j^[Z0`3alO430>c/k0<05ADE0`0C4a<301LG5`<061PH0`0G5aL401@D50<05QHF0`0C4a<3
018B4P<051@D0`3_knl30?7al@<0l?3`0`3emOD30?;blP<0lO7a0`0F5QH401DE5@<04a<C0`0D51@3
014A4@<05QHF0`3_knl30?3`l0<0m?Cd0`3]kNd3018B4P<03`l?1`0@4103018B4P<0k^k^0`3`l?03
0?Cdm0<0lO7a0`3`l?0601DE5@<051@D0`0G5aL401HF5P<051@D1P0E5AD30?3`l0H0l_;b5P3clo<6
0?;blP<0kno_0`0D51@301<C4`<04A4A0`0B4Q83010@40L04Q8B0`3/k>`60??cl`<0k^k^0`0G5aL3
01<C4`<05QHF0`0B4Q8301DE5@<0k>c/1`3`l?030>c/k0<05QHF1P0C4a<301LG5`<0kno_0`3dm?@3
0>c/k0<04A4A0`0:2PX4018B4P<0kNg]0`3emOD30>k^kP<05ADE0`0A4A4301@D50<04Q8B0`0E5AD3
0>c/k0<0lO7a0`3_knl701DE5@<061PH0`0F5QH30>k^kPH0lO7a2@0B4Q830?;blP<0lo?c103`l?03
01HF5P<05ADE0`0F5QH30??cl`<0410@1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`050?ooo`<0410@0`3Zj^X30?7al@<0k>c/0`0E5AD301<C4`<05aLG0`0H61P301LG
5`@051@D0`0F5QH301<C4`<04Q8B0`0D51@30>o_k`<0lO7a0`3`l?030?Gem@<0l_;b0`3alO4301HF
5P@05ADE0`0C4a<301@D50<04A4A0`0F5QH30>o_k`<0l?3`0`3dm?@30>g]k@<04Q8B0`0?3`l7010@
40<04Q8B0`3^k^h30?3`l0<0m?Cd0`3alO430?3`l0H05ADE0`0D51@301LG5`@05QHF0`0D51@601DE
5@<0l?3`1P3bl_8F0??cl`H0l_;b0`3_knl301@D50<04a<C0`0A4A43018B4P<0410@1`0B4Q830>c/
k0H0lo?c0`3^k^h301LG5`<04a<C0`0F5QH3018B4P<05ADE0`3/k>`70?3`l0<0k>c/0`0F5QH601<C
4`<05aLG0`3_knl30?Cdm0<0k>c/0`0A4A4300X:2P@04Q8B0`3]kNd30?Gem@<0k^k^0`0E5AD3014A
4@<051@D0`0B4Q8301DE5@<0k>c/0`3alO430>o_k`L05ADE0`0H61P301HF5P<0k^k^1P3alO49018B
4P<0l_;b0`3clo<40?3`l0<05QHF0`0E5AD301HF5P<0lo?c0`0@41060?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0>3Ph30>k^kP<0kno_1P0C4a<301XJ6P<0
6a/K0`0F5QH701DE5@<0kno_0`3bl_830?7al@<0kno_1P3clo<30?7al@<0l?3`1P0F5QH301@D50@0
5ADE0`0C4a<301@D50<04a<C0`3]kNd60??cl`<0k^k^0`0F5QH3018B4P<05QHF100G5aL301HF5P<0
4a<C1P0E5AD30?3`l0<0lO7a0`3dm?@30?3`l0<0kno_1P0E5AD401<C4`<05ADE0`0D51@3018B4P<0
5ADE0`0C4a<9018B4Pd04a<C1P0B4Q8301<C4`<05ADE1P0B4Q83014A4@<04Q8B0`0C4a<30>g]k@@0
k^k^0`3bl_860>o_k`<05aLG0`0C4a<301HF5P<04a<C0`0F5QH30>g]k@<0l_;b0`3alO440>c/k0<0
5ADE0`0B4Q8601@D50<0l?3`0`3dm?@30>_[j`<0410@0`092@T3014A4@@0k>c/0`3emOD30>k^kP<0
5ADE0`0?3`l3010@40H04a<C0`3]kNd30??cl`<0l?3`0`3alO4401LG5`<06ATI0`0J6QX3018B4P<0
410@0`3/k>`30>o_k`<0410@0`0B4Q8301@D50<0kno_0`3clo<40?;blP<051@D0`0E5AD301HF5P<0
l_;b0`0>3Ph60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo
0`0>3Ph30>k^kP<0kno_1P0C4a<301XJ6P<06a/K0`0F5QH701DE5@<0kno_0`3bl_830?7al@<0kno_
1P3clo<30?7al@<0l?3`1P0F5QH301@D50@05ADE0`0C4a<301@D50<04a<C0`3]kNd60??cl`<0k^k^
0`0F5QH3018B4P<05QHF100G5aL301HF5P<04a<C1P0E5AD30?3`l0<0lO7a0`3dm?@30?3`l0<0kno_
1P0E5AD401<C4`<05ADE0`0D51@3018B4P<05ADE0`0C4a<9018B4Pd04a<C1P0B4Q8301<C4`<05ADE
1P0B4Q83014A4@<04Q8B0`0C4a<30>g]k@@0k^k^0`3bl_860>o_k`<05aLG0`0C4a<301HF5P<04a<C
0`0F5QH30>g]k@<0l_;b0`3alO440>c/k0<05ADE0`0B4Q8601@D50<0l?3`0`3dm?@30>_[j`<0410@
0`092@T3014A4@@0k>c/0`3emOD30>k^kP<05ADE0`0?3`l3010@40H04a<C0`3]kNd30??cl`<0l?3`
0`3alO4401LG5`<06ATI0`0J6QX3018B4P<0410@0`3/k>`30>o_k`<0410@0`0B4Q8301@D50<0kno_
0`3clo<40?;blP<051@D0`0E5AD301HF5P<0l_;b0`0>3Ph60?ooo`030000003oool0oooo00D0oooo
000X0?ooo`030000003oool0oooo00D0oooo0`0>3Ph30>k^kP<0kno_1P0C4a<301XJ6P<06a/K0`0F
5QH701DE5@<0kno_0`3bl_830?7al@<0kno_1P3clo<30?7al@<0l?3`1P0F5QH301@D50@05ADE0`0C
4a<301@D50<04a<C0`3]kNd60??cl`<0k^k^0`0F5QH3018B4P<05QHF100G5aL301HF5P<04a<C1P0E
5AD30?3`l0<0lO7a0`3dm?@30?3`l0<0kno_1P0E5AD401<C4`<05ADE0`0D51@3018B4P<05ADE0`0C
4a<9018B4Pd04a<C1P0B4Q8301<C4`<05ADE1P0B4Q83014A4@<04Q8B0`0C4a<30>g]k@@0k^k^0`3b
l_860>o_k`<05aLG0`0C4a<301HF5P<04a<C0`0F5QH30>g]k@<0l_;b0`3alO440>c/k0<05ADE0`0B
4Q8601@D50<0l?3`0`3dm?@30>_[j`<0410@0`092@T3014A4@@0k>c/0`3emOD30>k^kP<05ADE0`0?
3`l3010@40H04a<C0`3]kNd30??cl`<0l?3`0`3alO4401LG5`<06ATI0`0J6QX3018B4P<0410@0`3/
k>`30>o_k`<0410@0`0B4Q8301@D50<0kno_0`3clo<40?;blP<051@D0`0E5AD301HF5P<0l_;b0`0>
3Ph60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0<30`3
0>g]k@<0l_;b0`0C4a<301PH60<06a/K0`0F5QH301PH60L0kno_0`3alO430?;blP<0kno_0`3alO43
0?;blP<0l?3`1P0E5AD301@D50H05QHF100B4Q8301LG5`<0kno_0`3`l?030??cl`<0l?3`0`3_knl3
01LG5`<04a<C0`0H61P:01TI6@<061PH0`0G5aL301@D50<05ADE0`0D51@30>k^kPH0lo?c0`3alO43
0>o_k`@051@D0`0B4Q8301DE5@l04Q8B2@0A4A4C018B4P<04A4A1P0C4a<30>g]k@<0k^k^0`3alO44
0?;blP<0k>c/0`0C4a<301@D50<04a<C0`0E5AD3018B4P<05aLG0`3_knl30?Cdm0<0l?3`0`3^k^h4
01HF5P<04Q8B0`0D51@3014A4@<051@D0`3alO430>o_k`<03`l?0`092@T3010@40<0k>c/103dm?@3
0>k^kP<05ADE1P0?3`l301DE5@<0k^k^0`3_knl30??cl`<0kNg]0`0C4a<301DE5@@05QHF0`0I6AT3
01HF5P<03`l?0`0>3Ph30>[ZjP<0k>c/0`0B4Q83014A4@<04Q8B0`0D51@30?3`l0@0lo?c0`0C4a<3
01@D50<05QHF0`3alO4300`<30H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool01@3oool300`<30<0kNg]0`3bl_8301<C4`<061PH0`0K6a/301HF5P<061PH1`3_knl30?7a
l@<0l_;b0`3_knl30?7al@<0l_;b0`3`l?0601DE5@<051@D1P0F5QH4018B4P<05aLG0`3_knl30?3`
l0<0lo?c0`3`l?030>o_k`<05aLG0`0C4a<301PH60X06ATI0`0H61P301LG5`<051@D0`0E5AD301@D
50<0k^k^1P3clo<30?7al@<0kno_100D51@3018B4P<05ADE3`0B4Q89014A4A<04Q8B0`0A4A4601<C
4`<0kNg]0`3^k^h30?7al@@0l_;b0`3/k>`301<C4`<051@D0`0C4a<301DE5@<04Q8B0`0G5aL30>o_
k`<0m?Cd0`3`l?030>k^kP@05QHF0`0B4Q8301@D50<04A4A0`0D51@30?7al@<0kno_0`0?3`l300T9
2@<0410@0`3/k>`40?Cdm0<0k^k^0`0E5AD600l?3`<05ADE0`3^k^h30>o_k`<0lo?c0`3]kNd301<C
4`<05ADE100F5QH301TI6@<05QHF0`0?3`l300h>3P<0j^[Z0`3/k>`3018B4P<04A4A0`0B4Q8301@D
50<0l?3`103clo<301<C4`<051@D0`0F5QH30?7al@<030`<1P3oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`050?ooo`<030`<0`3]kNd30?;blP<04a<C0`0H61P301/K6`<0
5QHF0`0H61P70>o_k`<0lO7a0`3bl_830>o_k`<0lO7a0`3bl_830?3`l0H05ADE0`0D51@601HF5P@0
4Q8B0`0G5aL30>o_k`<0l?3`0`3clo<30?3`l0<0kno_0`0G5aL301<C4`<061PH2P0I6AT301PH60<0
5aLG0`0D51@301DE5@<051@D0`3^k^h60??cl`<0lO7a0`3_knl401@D50<04Q8B0`0E5AD?018B4PT0
4A4A4`0B4Q83014A4@H04a<C0`3]kNd30>k^kP<0lO7a103bl_830>c/k0<04a<C0`0D51@301<C4`<0
5ADE0`0B4Q8301LG5`<0kno_0`3dm?@30?3`l0<0k^k^100F5QH3018B4P<051@D0`0A4A4301@D50<0
lO7a0`3_knl300l?3`<02@T90`0@41030>c/k0@0m?Cd0`3^k^h301DE5@H03`l?0`0E5AD30>k^kP<0
kno_0`3clo<30>g]k@<04a<C0`0E5AD401HF5P<06ATI0`0F5QH300l?3`<03Ph>0`3Zj^X30>c/k0<0
4Q8B0`0A4A43018B4P<051@D0`3`l?040??cl`<04a<C0`0D51@301HF5P<0lO7a0`0<30`60?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`<000001@3oool300l?3`<0k^k^0`3`l?0301LG5`<06ATI
0`0F5QH301PH60<0kNg]0`3alO440?3`l0H0k^k^0`0C4a<3014A4@<04a<C0`0E5AD3018B4P<051@D
0`0E5AD301<C4`<05ADE100D51@30>k^kPH0lo?c0`3]kNd301<C4`<051@D0`0C4a<601DE5@<061PH
1`0E5AD301LG5`<051@D0`0F5QH301DE5@<04Q8B0`0G5aL30?3`l0<0l_;b0`3`l?030?Cdm0@0l?3`
0`3alO430>o_k`<04a<C0`0@4106014A4@H0410@1P0?3`l7010@40<04A4A1P0B4Q83014A4@<051@D
0`3_knl30?3`l0<0l_;b0`3alO470>k^kP<05QHF0`0A4A4301@D50<04a<C1P0D51@30>k^kP<0m_Kf
0`3^k^h301@D50<04a<C100B4Q8301<C4`<04A4A0`0E5AD30>g]k@<0lo?c0`3/k>`600`<30<0k>c/
0`3clo<40>g]k@<05ADE1P0@410301@D50<0k>c/1P3alO430>c/k0<051@D0`0@410701<C4`<05aLG
0`0B4Q83014A4@<0i^KV0`3[jn/60>k^kP<05ADE0`0C4a<3018B4P<0l_;b103clo<301<C4`H051@D
0`3_knl300l?3`D0oooo0P0000070?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<03`l?0`3^
k^h30?3`l0<05aLG0`0I6AT301HF5P<061PH0`3]kNd30?7al@@0l?3`1P3^k^h301<C4`<04A4A0`0C
4a<301DE5@<04Q8B0`0D51@301DE5@<04a<C0`0E5AD401@D50<0k^k^1P3clo<30>g]k@<04a<C0`0D
51@301<C4`H05ADE0`0H61P701DE5@<05aLG0`0D51@301HF5P<05ADE0`0B4Q8301LG5`<0l?3`0`3b
l_830?3`l0<0m?Cd103`l?030?7al@<0kno_0`0C4a<3010@40H04A4A1P0@410600l?3`L0410@0`0A
4A46018B4P<04A4A0`0D51@30>o_k`<0l?3`0`3bl_830?7al@L0k^k^0`0F5QH3014A4@<051@D0`0C
4a<601@D50<0k^k^0`3fm_H30>k^kP<051@D0`0C4a<4018B4P<04a<C0`0A4A4301DE5@<0kNg]0`3c
lo<30>c/k0H030`<0`3/k>`30??cl`@0kNg]0`0E5AD6010@40<051@D0`3/k>`60?7al@<0k>c/0`0D
51@3010@40L04a<C0`0G5aL3018B4P<04A4A0`3Vi^H30>_[j`H0k^k^0`0E5AD301<C4`<04Q8B0`3b
l_840??cl`<04a<C1P0D51@30>o_k`<03`l?1P3oool00`000000oooo0?ooo`050?ooo`00:03oool0
0`000000oooo0?ooo`050?ooo`<03`l?0`3^k^h30?3`l0<05aLG0`0I6AT301HF5P<061PH0`3]kNd3
0?7al@@0l?3`1P3^k^h301<C4`<04A4A0`0C4a<301DE5@<04Q8B0`0D51@301DE5@<04a<C0`0E5AD4
01@D50<0k^k^1P3clo<30>g]k@<04a<C0`0D51@301<C4`H05ADE0`0H61P701DE5@<05aLG0`0D51@3
01HF5P<05ADE0`0B4Q8301LG5`<0l?3`0`3bl_830?3`l0<0m?Cd103`l?030?7al@<0kno_0`0C4a<3
010@40H04A4A1P0@410600l?3`L0410@0`0A4A46018B4P<04A4A0`0D51@30>o_k`<0l?3`0`3bl_83
0?7al@L0k^k^0`0F5QH3014A4@<051@D0`0C4a<601@D50<0k^k^0`3fm_H30>k^kP<051@D0`0C4a<4
018B4P<04a<C0`0A4A4301DE5@<0kNg]0`3clo<30>c/k0H030`<0`3/k>`30??cl`@0kNg]0`0E5AD6
010@40<051@D0`3/k>`60?7al@<0k>c/0`0D51@3010@40L04a<C0`0G5aL3018B4P<04A4A0`3Vi^H3
0>_[j`H0k^k^0`0E5AD301<C4`<04Q8B0`3bl_840??cl`<04a<C1P0D51@30>o_k`<03`l?1P3oool0
0`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0k>c/0`3_knl601@D
50<05aLG0`0F5QH30>o_k`<0lO7a0`3`l?040>_[j`<04Q8B1P0C4a<601@D50<04a<C0`0B4Q8301DE
5@<04Q8B0`0D51@30?3`l0@0lO7a0`3dm?@30?3`l0<0kno_0`0F5QH3014A4@<051@D0`0C4a<601@D
50<0kno_1`3alO430>o_k`H051@D0`0C4a<301@D50<04a<C0`0F5QH3018B4P<051@D0`3_knl40?3`
l0H0lo?c0`3`l?030?7al@<0l?3`0`3_knl30>g]k@d0k>c/0`3]kNd30>o_k`<0lO7a1P3bl_830?7a
l@<0mOGe0`3`l?030?7al@<0kno_1`0C4a<3018B4P<051@D0`0A4A4301HF5P<0kno_0`3`l?030?Ge
m@<0kno_0`0F5QH3014A4@<04a<C100A4A46018B4P<0k>c/0`3clo<30>[ZjP<03`l?0`0820P300h>
3P<0k^k^0`3`l?0401<C4`<04A4A1P0C4a<30>k^kP<0lO7a0`3`l?030>_[j`<04a<C0`0?3`l3014A
4@<051@D100F5QH30?7al@<0l_;b1P3^k^h30>_[j`<0kno_0`3clo<301HF5P<05ADE0`0D51@70?Cd
m0T04a<C0`3alO430>c/k0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool01@3oool30>c/k0<0kno_1P0D51@301LG5`<05QHF0`3_knl30?7al@<0l?3`103[jn/3018B4PH0
4a<C1P0D51@301<C4`<04Q8B0`0E5AD3018B4P<051@D0`3`l?040?7al@<0m?Cd0`3`l?030>o_k`<0
5QHF0`0A4A4301@D50<04a<C1P0D51@30>o_k`L0lO7a0`3_knl601@D50<04a<C0`0D51@301<C4`<0
5QHF0`0B4Q8301@D50<0kno_103`l?060??cl`<0l?3`0`3alO430?3`l0<0kno_0`3]kNd=0>c/k0<0
kNg]0`3_knl30?7al@H0l_;b0`3alO430?Gem@<0l?3`0`3alO430>o_k`L04a<C0`0B4Q8301@D50<0
4A4A0`0F5QH30>o_k`<0l?3`0`3emOD30>o_k`<05QHF0`0A4A4301<C4`@04A4A1P0B4Q830>c/k0<0
lo?c0`3Zj^X300l?3`<020P80`0>3Ph30>k^kP<0l?3`100C4a<3014A4@H04a<C0`3^k^h30?7al@<0
l?3`0`3[jn/301<C4`<03`l?0`0A4A4301@D50@05QHF0`3alO430?;blPH0k^k^0`3[jn/30>o_k`<0
lo?c0`0F5QH301DE5@<051@D1`3dm?@901<C4`<0lO7a0`3/k>`60?ooo`030000003oool0oooo00D0
oooo000X0?ooo`030000003oool0oooo00D0oooo0`3/k>`30>o_k`H051@D0`0G5aL301HF5P<0kno_
0`3alO430?3`l0@0jn_[0`0B4Q8601<C4`H051@D0`0C4a<3018B4P<05ADE0`0B4Q8301@D50<0l?3`
103alO430?Cdm0<0l?3`0`3_knl301HF5P<04A4A0`0D51@301<C4`H051@D0`3_knl70?7al@<0kno_
1P0D51@301<C4`<051@D0`0C4a<301HF5P<04Q8B0`0D51@30>o_k`@0l?3`1P3clo<30?3`l0<0lO7a
0`3`l?030>o_k`<0kNg]3@3/k>`30>g]k@<0kno_0`3alO460?;blP<0lO7a0`3emOD30?3`l0<0lO7a
0`3_knl701<C4`<04Q8B0`0D51@3014A4@<05QHF0`3_knl30?3`l0<0mOGe0`3_knl301HF5P<04A4A
0`0C4a<4014A4@H04Q8B0`3/k>`30??cl`<0j^[Z0`0?3`l300P820<03Ph>0`3^k^h30?3`l0@04a<C
0`0A4A4601<C4`<0k^k^0`3alO430?3`l0<0jn_[0`0C4a<300l?3`<04A4A0`0D51@401HF5P<0lO7a
0`3bl_860>k^kP<0jn_[0`3_knl30??cl`<05QHF0`0E5AD301@D50L0m?Cd2@0C4a<30?7al@<0k>c/
1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`H0l?3`0`0B
4Q8301HF5P<051@D0`0E5AD30>o_k`<0l?3`0`3[jn/401@D50<04A4A1P0E5AD301<C4`<05ADE0`0A
4A4301<C4`<0kno_0`3alO430?3`l0<0mOGe103bl_830?3`l0H05ADE0`0C4a<301@D50<04A4A0`0F
5QH30>o_k`<0k^k^0`3`l?070>k^kP<0kno_0`3^k^h30>g]k@H04a<C0`0B4Q8601@D50<04a<C0`0D
51@401DE5@<0l?3`1P3bl_830?7al@<0kno_0`3`l?030>g]k@<0k>c/1P3[jn/40>c/k0<0kNg]0`3`
l?030>o_k`<0l_;b0`3clo<30?Cdm0<0lO7a0`0E5AD3018B4P<05ADE0`0A4A44018B4P<04A4A0`0C
4a<301@D50<0kNg]1P3clo<30>k^kP<05QHF0`0B4Q8301@D50<0410@100D51@60>c/k0<0l?3`0`3X
j>P300d=3@<01`L70`0=3@d30>SXj0<0l_;b0`3^k^h701<C4`<04A4A0`0C4a<30>o_k`<0lO7a0`3[
jn/301<C4`<03Ph>0`0?3`l301HF5P<0l?3`103bl_830?Gem@H0l?3`1P3_knl30?;blP<0mOGe0`0K
6a/301LG5`<05ADE1`3dm?@601<C4`<04Q8B1P3`l?060?ooo`030000003oool0oooo00D0oooo000X
0?ooo`030000003oool0oooo00D0oooo1P3`l?03018B4P<05QHF0`0D51@301DE5@<0kno_0`3`l?03
0>_[j`@051@D0`0A4A4601DE5@<04a<C0`0E5AD3014A4@<04a<C0`3_knl30?7al@<0l?3`0`3emOD4
0?;blP<0l?3`1P0E5AD301<C4`<051@D0`0A4A4301HF5P<0kno_0`3^k^h30?3`l0L0k^k^0`3_knl3
0>k^kP<0kNg]1P0C4a<3018B4PH051@D0`0C4a<301@D50@05ADE0`3`l?060?;blP<0lO7a0`3_knl3
0?3`l0<0kNg]0`3/k>`60>_[j`@0k>c/0`3]kNd30?3`l0<0kno_0`3bl_830??cl`<0m?Cd0`3alO43
01DE5@<04Q8B0`0E5AD3014A4@@04Q8B0`0A4A4301<C4`<051@D0`3]kNd60??cl`<0k^k^0`0F5QH3
018B4P<051@D0`0@410401@D50H0k>c/0`3`l?030>SXj0<03@d=0`071`L300d=3@<0j>SX0`3bl_83
0>k^kPL04a<C0`0A4A4301<C4`<0kno_0`3alO430>_[j`<04a<C0`0>3Ph300l?3`<05QHF0`3`l?04
0?;blP<0mOGe1P3`l?060>o_k`<0l_;b0`3emOD301/K6`<05aLG0`0E5AD70?Cdm0H04a<C0`0B4Q86
0?3`l0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool60?3`
l0<04Q8B0`0F5QH301@D50<05ADE0`3_knl30?3`l0<0jn_[100D51@3014A4@H05ADE0`0C4a<301DE
5@<04A4A0`0C4a<30>o_k`<0lO7a0`3`l?030?Gem@@0l_;b0`3`l?0601DE5@<04a<C0`0D51@3014A
4@<05QHF0`3_knl30>k^kP<0l?3`1`3^k^h30>o_k`<0k^k^0`3]kNd601<C4`<04Q8B1P0D51@301<C
4`<051@D100E5AD30?3`l0H0l_;b0`3alO430>o_k`<0l?3`0`3]kNd30>c/k0H0jn_[103/k>`30>g]
k@<0l?3`0`3_knl30?;blP<0lo?c0`3dm?@30?7al@<05ADE0`0B4Q8301DE5@<04A4A100B4Q83014A
4@<04a<C0`0D51@30>g]k@H0lo?c0`3^k^h301HF5P<04Q8B0`0D51@3010@40@051@D1P3/k>`30?3`
l0<0j>SX0`0=3@d300L71`<03@d=0`3Xj>P30?;blP<0k^k^1`0C4a<3014A4@<04a<C0`3_knl30?7a
l@<0jn_[0`0C4a<300h>3P<03`l?0`0F5QH30?3`l0@0l_;b0`3emOD60?3`l0H0kno_0`3bl_830?Ge
m@<06a/K0`0G5aL301DE5@L0m?Cd1P0C4a<3018B4PH0l?3`1P3oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`050?ooo`<0lO7a0`3_knl601HF5P<05aLG0`3`l?030?7al@<0
k^k^1`0B4Q8301HF5P<051@D0`0E5AD301@D50<0k^k^0`3`l?030>o_k`<0l_;b0`3clo<30?7al@<0
l?3`100F5QH301DE5@<051@D0`0E5AD301<C4`<051@D0`0C4a<30>c/k0<0l_;b0`3`l?0:0>c/k0<0
jn_[1P3`l?060>k^kPH051@D0`0C4a<601@D50@04Q8B0`0E5AD301@D50<04a<C0`0B4Q8301@D50<0
k^k^0`3_knl30>g]k@H0k>c/103]kNd30>o_k`<0k^k^0`0D51@3018B4P<051@D0`0E5AD301LG5`<0
51@D0`0E5AD301@D50<04Q8B100C4a<301@D50<0kno_0`3alO430?Cdm0<0l?3`0`3_knl301LG5`<0
4Q8B0`0D51@3010@40<04Q8B103WinL60>_[j`<0hn?S0`0:2PX300D51@<030`<0`3Vi^H30>o_k`<0
k^k^0`0C4a<4014A4@<04Q8B0`0G5aL30>k^kP<0m?Cd0`3/k>`301<C4`<03Ph>0`0?3`l301DE5@<0
kno_0`3emOD40?;blP<0kno_0`0C4a<3010@40<04A4A0`0C4a<301HF5P<07AdM0`0L71`301/K6`<0
5QHF0`3emOD40?Cdm0H04a<C0`0B4Q830?3`l0<0lO7a1P3oool00`000000oooo0?ooo`050?ooo`00
:03oool00`000000oooo0?ooo`050?ooo`<0lO7a0`3_knl601HF5P<05aLG0`3`l?030?7al@<0k^k^
1`0B4Q8301HF5P<051@D0`0E5AD301@D50<0k^k^0`3`l?030>o_k`<0l_;b0`3clo<30?7al@<0l?3`
100F5QH301DE5@<051@D0`0E5AD301<C4`<051@D0`0C4a<30>c/k0<0l_;b0`3`l?0:0>c/k0<0jn_[
1P3`l?060>k^kPH051@D0`0C4a<601@D50@04Q8B0`0E5AD301@D50<04a<C0`0B4Q8301@D50<0k^k^
0`3_knl30>g]k@H0k>c/103]kNd30>o_k`<0k^k^0`0D51@3018B4P<051@D0`0E5AD301LG5`<051@D
0`0E5AD301@D50<04Q8B100C4a<301@D50<0kno_0`3alO430?Cdm0<0l?3`0`3_knl301LG5`<04Q8B
0`0D51@3010@40<04Q8B103WinL60>_[j`<0hn?S0`0:2PX300D51@<030`<0`3Vi^H30>o_k`<0k^k^
0`0C4a<4014A4@<04Q8B0`0G5aL30>k^kP<0m?Cd0`3/k>`301<C4`<03Ph>0`0?3`l301DE5@<0kno_
0`3emOD40?;blP<0kno_0`0C4a<3010@40<04A4A0`0C4a<301HF5P<07AdM0`0L71`301/K6`<05QHF
0`3emOD40?Cdm0H04a<C0`0B4Q830?3`l0<0lO7a1P3oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`050?ooo`<0lO7a0`3_knl601HF5P<05aLG0`3`l?030?7al@<0k^k^1`0B
4Q8301HF5P<051@D0`0E5AD301@D50<0k^k^0`3`l?030>o_k`<0l_;b0`3clo<30?7al@<0l?3`100F
5QH301DE5@<051@D0`0E5AD301<C4`<051@D0`0C4a<30>c/k0<0l_;b0`3`l?0:0>c/k0<0jn_[1P3`
l?060>k^kPH051@D0`0C4a<601@D50@04Q8B0`0E5AD301@D50<04a<C0`0B4Q8301@D50<0k^k^0`3_
knl30>g]k@H0k>c/103]kNd30>o_k`<0k^k^0`0D51@3018B4P<051@D0`0E5AD301LG5`<051@D0`0E
5AD301@D50<04Q8B100C4a<301@D50<0kno_0`3alO430?Cdm0<0l?3`0`3_knl301LG5`<04Q8B0`0D
51@3010@40<04Q8B103WinL60>_[j`<0hn?S0`0:2PX300D51@<030`<0`3Vi^H30>o_k`<0k^k^0`0C
4a<4014A4@<04Q8B0`0G5aL30>k^kP<0m?Cd0`3/k>`301<C4`<03Ph>0`0?3`l301DE5@<0kno_0`3e
mOD40?;blP<0kno_0`0C4a<3010@40<04A4A0`0C4a<301HF5P<07AdM0`0L71`301/K6`<05QHF0`3e
mOD40?Cdm0H04a<C0`0B4Q830?3`l0<0lO7a1P3oool00`000000oooo0?ooo`050?ooo`00:03oool0
0`000000oooo0?ooo`050?ooo`<0l?3`1P0D51@301LG5`<051@D1P3bl_830>k^kP<051@D100F5QH3
01DE5@<061PH1P3^k^h30?3`l0<0lO7a0`3_knl30?7al@<0l?3`1P0F5QH401@D50<05aLG0`0F5QH3
018B4P<05aLG0`3_knl30?3`l0<0lo?c0`3_knl30>g]k@<04Q8B1`0?3`l3014A4@<0k>c/0`3^k^h3
0?7al@<0l_;b0`3`l?030>o_k`<051@D0`0B4Q8301DE5@@04Q8B0`0C4a<301DE5@H05QHF0`0D51@3
01DE5@<04Q8B3@0@4103018B4P<05ADE0`0D51@301HF5P<05aLG0`0F5QH601DE5@<04a<C1P0D51@4
0>k^kP<0l?3`0`3dm?@30?7al@<0kno_1P0D51@6018B4P<03Ph>0`0@41030>CTi0@0inOW0`3Shn<3
0=SHf0<01PH60`051@D300T92@<0i>CT0`3]kNd30?3`l0<0k^k^1`0C4a<301@D50<0l?3`0`3emOD3
0>g]k@<051@D1P0?3`l301DE5@<0kno_0`3fm_H30>k^kP@051@D0`0C4a<3018B4P<04a<C0`0D51@3
01HF5P<06QXJ0`0N7Qh3024Q8@<071`L0`0G5aL30?Gem@@0m?Cd1P0C4a<3018B4P<0l_;b0`3`l?06
0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3`l?0601@D
50<05aLG0`0D51@60?;blP<0k^k^0`0D51@401HF5P<05ADE0`0H61P60>k^kP<0l?3`0`3alO430>o_
k`<0lO7a0`3`l?0601HF5P@051@D0`0G5aL301HF5P<04Q8B0`0G5aL30>o_k`<0l?3`0`3clo<30>o_
k`<0kNg]0`0B4Q8700l?3`<04A4A0`3/k>`30>k^kP<0lO7a0`3bl_830?3`l0<0kno_0`0D51@3018B
4P<05ADE100B4Q8301<C4`<05ADE1P0F5QH301@D50<05ADE0`0B4Q8=010@40<04Q8B0`0E5AD301@D
50<05QHF0`0G5aL301HF5PH05ADE0`0C4a<601@D50@0k^k^0`3`l?030?Cdm0<0lO7a0`3_knl601@D
50H04Q8B0`0>3Ph3010@40<0i>CT103WinL30>?Sh`<0f=SH0`061PH300D51@<02@T90`3Ti>@30>g]
k@<0l?3`0`3^k^h701<C4`<051@D0`3`l?030?Gem@<0kNg]0`0D51@600l?3`<05ADE0`3_knl30?Kf
mP<0k^k^100D51@301<C4`<04Q8B0`0C4a<301@D50<05QHF0`0J6QX301hN7P<08B4Q0`0L71`301LG
5`<0mOGe103dm?@601<C4`<04Q8B0`3bl_830?3`l0H0oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool01@3oool30?3`l0H051@D0`0G5aL301@D50H0l_;b0`3^k^h301@D50@0
5QHF0`0E5AD301PH60H0k^k^0`3`l?030?7al@<0kno_0`3alO430?3`l0H05QHF100D51@301LG5`<0
5QHF0`0B4Q8301LG5`<0kno_0`3`l?030??cl`<0kno_0`3]kNd3018B4PL03`l?0`0A4A430>c/k0<0
k^k^0`3alO430?;blP<0l?3`0`3_knl301@D50<04Q8B0`0E5AD4018B4P<04a<C0`0E5AD601HF5P<0
51@D0`0E5AD3018B4Pd0410@0`0B4Q8301DE5@<051@D0`0F5QH301LG5`<05QHF1P0E5AD301<C4`H0
51@D103^k^h30?3`l0<0m?Cd0`3alO430>o_k`H051@D1P0B4Q8300h>3P<0410@0`3Ti>@40>OWi`<0
hn?S0`3Hf=P300H61P<01@D50`092@T30>CTi0<0kNg]0`3`l?030>k^kPL04a<C0`0D51@30?3`l0<0
mOGe0`3]kNd301@D50H03`l?0`0E5AD30>o_k`<0m_Kf0`3^k^h401@D50<04a<C0`0B4Q8301<C4`<0
51@D0`0F5QH301XJ6P<07QhN0`0Q8B4301`L70<05aLG0`3emOD40?Cdm0H04a<C0`0B4Q830?;blP<0
l?3`1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0l_;b
0`0C4a<601HF5P<04Q8B0`3alO430>o_k`H04a<C100G5aL301HF5P<0kno_0`3`l?030>k^kP<0k>c/
0`3]kNd301@D50<04a<C0`0G5aL301DE5@L05aLG0`0D51@601DE5@<0k^k^1P3clo<30>g]k@<04a<C
0`0D51@301<C4`L05ADE0`0B4Q8601<C4`<0k^k^0`3alO430>o_k`<0m?Cd0`3`l?030?7al@<0kno_
100C4a<3018B4P<05ADE0`0D51@601HF5P<051@D0`0C4a<3018B4PH04A4A100B4Q8301<C4`<05ADE
0`0F5QH301LG5`<051@D0`0G5aL301@D50<04Q8B0`0D51@30>o_k`<0l?3`103bl_830??cl`<0kNg]
1P0D51@3018B4P<04a<C1P0@410300d=3@<0hN7Q0`3Shn<40=cLg0<0dm?C1P0410@30>7Qh@<0inOW
0`3/k>`30>o_k`<0k>c/0`0F5QH701<C4`<05ADE0`3bl_830?7al@<04a<C1P0@410301HF5P<0kno_
0`3fm_H30>o_k`<05QHF100@410601<C4`<05aLG0`0F5QH301TI6@<061PH0`0M7Ad301lO7`<06a/K
0`0E5AD70?Cdm0T04a<C0`3clo<30?;blPH0oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool01@3oool30?;blP<04a<C1P0F5QH3018B4P<0lO7a0`3_knl601<C4`@05aLG0`0F
5QH30>o_k`<0l?3`0`3^k^h30>c/k0<0kNg]0`0D51@301<C4`<05aLG0`0E5AD701LG5`<051@D1P0E
5AD30>k^kPH0lo?c0`3]kNd301<C4`<051@D0`0C4a<701DE5@<04Q8B1P0C4a<30>k^kP<0lO7a0`3_
knl30?Cdm0<0l?3`0`3alO430>o_k`@04a<C0`0B4Q8301DE5@<051@D1P0F5QH301@D50<04a<C0`0B
4Q86014A4@@04Q8B0`0C4a<301DE5@<05QHF0`0G5aL301@D50<05aLG0`0D51@3018B4P<051@D0`3_
knl30?3`l0@0l_;b0`3clo<30>g]k@H051@D0`0B4Q8301<C4`H0410@0`0=3@d30>7Qh@<0hn?S103L
g=`30=?Cd`H010@40`3QhN430>OWi`<0k>c/0`3_knl30>c/k0<05QHF1`0C4a<301DE5@<0l_;b0`3a
lO4301<C4`H0410@0`0F5QH30>o_k`<0m_Kf0`3_knl301HF5P@0410@1P0C4a<301LG5`<05QHF0`0I
6AT301PH60<07AdM0`0O7al301/K6`<05ADE1`3dm?@901<C4`<0lo?c0`3bl_860?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3bl_8301<C4`H05QHF0`0B4Q83
0?7al@<0kno_1P0C4a<401LG5`<05QHF0`3_knl30?3`l0<0k^k^0`3/k>`30>g]k@<051@D0`0C4a<3
01LG5`<05ADE1`0G5aL301@D50H05ADE0`3^k^h60??cl`<0kNg]0`0C4a<301@D50<04a<C1`0E5AD3
018B4PH04a<C0`3^k^h30?7al@<0kno_0`3dm?@30?3`l0<0lO7a0`3_knl401<C4`<04Q8B0`0E5AD3
01@D50H05QHF0`0D51@301<C4`<04Q8B1P0A4A44018B4P<04a<C0`0E5AD301HF5P<05aLG0`0D51@3
01LG5`<051@D0`0B4Q8301@D50<0kno_0`3`l?040?;blP<0lo?c0`3]kNd601@D50<04Q8B0`0C4a<6
010@40<03@d=0`3QhN430>?Sh`@0g=cL0`3Cdm<600@410<0hN7Q0`3WinL30>c/k0<0kno_0`3/k>`3
01HF5PL04a<C0`0E5AD30?;blP<0lO7a0`0C4a<6010@40<05QHF0`3_knl30?KfmP<0kno_0`0F5QH4
010@40H04a<C0`0G5aL301HF5P<06ATI0`0H61P301dM7@<07alO0`0K6a/301DE5@L0m?Cd2@0C4a<3
0??cl`<0l_;b1P3oool00`000000oooo0?ooo`050?ooo`00:03oool3000000D0oooo0`3dm?@301@D
50<05QHF1P0D51@30>o_k`<0l?3`0`0A4A4701HF5P<04Q8B0`3_knl30>g]k@<0jn_[0`0@410301<C
4`<051@D0`0H61P301TI6@<05aLG0`0E5AD701HF5P<0l?3`0`3bl_830?Cdm0<0l?3`0`3_knl301LG
5`<04Q8B0`0F5QH:01LG5`<05ADE0`0C4a<3014A4@<051@D0`0A4A4301<C4`<0kno_0`3`l?060?;b
lP@0kno_0`3alO430>o_k`<05ADE0`0C4a<601@D50<04a<C3@0B4Q8301<C4`H051@D0`0C4a<301DE
5@<0l?3`0`3bl_830?7al@<0l?3`0`3dm?@30?3`l0@0lO7a0`3`l?0301HF5P<04A4A1P0C4a<300l?
3`<04A4A0`3WinL30>?Sh`<0h>3P0`3GemL40=GEe@<0fm_K0`3MgMd30>?Sh`<0jn_[0`3^k^h30>c/
k0<0k^k^0`0G5aL301<C4`L05QHF0`3`l?030?Gem@<0kno_0`0C4a<3018B4P<051@D0`3`l?030?Ge
m@<0k^k^0`0F5QH3014A4@@04Q8B0`0D51@301HF5P<0l_;b0`3fm_H30??cl`H06ATI0`0G5aL301DE
5@<04A4A0`3bl_840??cl`T04a<C1P3dm?@50?ooo`8000001`3oool002P0oooo00<000000?ooo`3o
ool01@3oool30?Cdm0<051@D0`0F5QH601@D50<0kno_0`3`l?03014A4@L05QHF0`0B4Q830>o_k`<0
kNg]0`3[jn/3010@40<04a<C0`0D51@301PH60<06ATI0`0G5aL301DE5@L05QHF0`3`l?030?;blP<0
m?Cd0`3`l?030>o_k`<05aLG0`0B4Q8301HF5PX05aLG0`0E5AD301<C4`<04A4A0`0D51@3014A4@<0
4a<C0`3_knl30?3`l0H0l_;b103_knl30?7al@<0kno_0`0E5AD301<C4`H051@D0`0C4a<=018B4P<0
4a<C1P0D51@301<C4`<05ADE0`3`l?030?;blP<0lO7a0`3`l?030?Cdm0<0l?3`103alO430?3`l0<0
5QHF0`0A4A4601<C4`<03`l?0`0A4A430>OWi`<0hn?S0`3Ph>030=OGe`@0eMGE0`3Kfm/30=gMg@<0
hn?S0`3[jn/30>k^kP<0k>c/0`3^k^h301LG5`<04a<C1`0F5QH30?3`l0<0mOGe0`3_knl301<C4`<0
4Q8B0`0D51@30?3`l0<0mOGe0`3^k^h301HF5P<04A4A100B4Q8301@D50<05QHF0`3bl_830?KfmP<0
lo?c1P0I6AT301LG5`<05ADE0`0A4A430?;blP@0lo?c2@0C4a<60?Cdm0H0oooo00<000000?ooo`3o
ool01@3oool002P0oooo00<000000?ooo`3oool01@3oool30?Cdm0<051@D0`0F5QH601@D50<0kno_
0`3`l?03014A4@L05QHF0`0B4Q830>o_k`<0kNg]0`3[jn/3010@40<04a<C0`0D51@301PH60<06ATI
0`0G5aL301DE5@L05QHF0`3`l?030?;blP<0m?Cd0`3`l?030>o_k`<05aLG0`0B4Q8301HF5PX05aLG
0`0E5AD301<C4`<04A4A0`0D51@3014A4@<04a<C0`3_knl30?3`l0H0l_;b103_knl30?7al@<0kno_
0`0E5AD301<C4`H051@D0`0C4a<=018B4P<04a<C1P0D51@301<C4`<05ADE0`3`l?030?;blP<0lO7a
0`3`l?030?Cdm0<0l?3`103alO430?3`l0<05QHF0`0A4A4601<C4`<03`l?0`0A4A430>OWi`<0hn?S
0`3Ph>030=OGe`@0eMGE0`3Kfm/30=gMg@<0hn?S0`3[jn/30>k^kP<0k>c/0`3^k^h301LG5`<04a<C
1`0F5QH30?3`l0<0mOGe0`3_knl301<C4`<04Q8B0`0D51@30?3`l0<0mOGe0`3^k^h301HF5P<04A4A
100B4Q8301@D50<05QHF0`3bl_830?KfmP<0lo?c1P0I6AT301LG5`<05ADE0`0A4A430?;blP@0lo?c
2@0C4a<60?Cdm0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3o
ool30?Cdm0<051@D0`0F5QH601@D50<0kno_0`3`l?03014A4@L05QHF0`0B4Q830>o_k`<0kNg]0`3[
jn/3010@40<04a<C0`0D51@301PH60<06ATI0`0G5aL301DE5@L05QHF0`3`l?030?;blP<0m?Cd0`3`
l?030>o_k`<05aLG0`0B4Q8301HF5PX05aLG0`0E5AD301<C4`<04A4A0`0D51@3014A4@<04a<C0`3_
knl30?3`l0H0l_;b103_knl30?7al@<0kno_0`0E5AD301<C4`H051@D0`0C4a<=018B4P<04a<C1P0D
51@301<C4`<05ADE0`3`l?030?;blP<0lO7a0`3`l?030?Cdm0<0l?3`103alO430?3`l0<05QHF0`0A
4A4601<C4`<03`l?0`0A4A430>OWi`<0hn?S0`3Ph>030=OGe`@0eMGE0`3Kfm/30=gMg@<0hn?S0`3[
jn/30>k^kP<0k>c/0`3^k^h301LG5`<04a<C1`0F5QH30?3`l0<0mOGe0`3_knl301<C4`<04Q8B0`0D
51@30?3`l0<0mOGe0`3^k^h301HF5P<04A4A100B4Q8301@D50<05QHF0`3bl_830?KfmP<0lo?c1P0I
6AT301LG5`<05ADE0`0A4A430?;blP@0lo?c2@0C4a<60?Cdm0H0oooo00<000000?ooo`3oool01@3o
ool002P0oooo00<000000?ooo`3oool01@3oool30?Cdm0<051@D0`0E5AD301HF5P<0kno_0`3alO43
0?3`l0<04Q8B0`0E5AD701<C4`<0k>c/0`3^k^h30>c/k0<04a<C0`0G5aL301/K6`<06ATI0`0E5AD6
01HF5P@0l?3`0`3bl_830?Gem@<0l_;b0`3`l?0301DE5@<051@D0`0C4a<301DE5@<04a<C0`0F5QH4
01@D50H04Q8B0`0D51@3014A4@<04Q8B0`0C4a<3018B4P<04a<C0`0D51@30>o_k`<0lO7a103_knl3
0?;blP<0lo?c0`3alO430??cl`H0m?Cd0`3clo<30?;blPH0lO7a103bl_830??cl`H0m?Cd0`3clo<3
0?7al@H0lo?c0`3`l?030?;blP<0l?3`0`0D51@4018B4P<051@D1P0B4Q86010@40<03@d=0`3Rh^83
0>GUi@<0g=cL0`3Fe]H30=GEe@@0fm_K0`3Shn<30>GUi@<0jn_[0`3^k^h30>g]k@<04a<C0`0D51@3
01DE5@<061PH0`0F5QH4018B4P<0l_;b0`3`l?0301<C4`<04A4A0`0B4Q8301DE5@H0l_;b0`0D51@3
010@40<04Q8B100H61P30?7al@<0lo?c1P3alO430?;blP<0lo?c0`3bl_83014A4@<030`<0`0?3`l3
0>k^kP@0lO7a2@0C4a<60?Cdm0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool01@3oool30?Cdm0<051@D0`0E5AD301HF5P<0kno_0`3alO430?3`l0<04Q8B0`0E5AD701<C
4`<0k>c/0`3^k^h30>c/k0<04a<C0`0G5aL301/K6`<06ATI0`0E5AD601HF5P@0l?3`0`3bl_830?Ge
m@<0l_;b0`3`l?0301DE5@<051@D0`0C4a<301DE5@<04a<C0`0F5QH401@D50H04Q8B0`0D51@3014A
4@<04Q8B0`0C4a<3018B4P<04a<C0`0D51@30>o_k`<0lO7a103_knl30?;blP<0lo?c0`3alO430??c
l`H0m?Cd0`3clo<30?;blPH0lO7a103bl_830??cl`H0m?Cd0`3clo<30?7al@H0lo?c0`3`l?030?;b
lP<0l?3`0`0D51@4018B4P<051@D1P0B4Q86010@40<03@d=0`3Rh^830>GUi@<0g=cL0`3Fe]H30=GE
e@@0fm_K0`3Shn<30>GUi@<0jn_[0`3^k^h30>g]k@<04a<C0`0D51@301DE5@<061PH0`0F5QH4018B
4P<0l_;b0`3`l?0301<C4`<04A4A0`0B4Q8301DE5@H0l_;b0`0D51@3010@40<04Q8B100H61P30?7a
l@<0lo?c1P3alO430?;blP<0lo?c0`3bl_83014A4@<030`<0`0?3`l30>k^kP@0lO7a2@0C4a<60?Cd
m0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool30?Cdm0<0
51@D0`0E5AD301HF5P<0kno_0`3alO430?3`l0<04Q8B0`0E5AD701<C4`<0k>c/0`3^k^h30>c/k0<0
4a<C0`0G5aL301/K6`<06ATI0`0E5AD601HF5P@0l?3`0`3bl_830?Gem@<0l_;b0`3`l?0301DE5@<0
51@D0`0C4a<301DE5@<04a<C0`0F5QH401@D50H04Q8B0`0D51@3014A4@<04Q8B0`0C4a<3018B4P<0
4a<C0`0D51@30>o_k`<0lO7a103_knl30?;blP<0lo?c0`3alO430??cl`H0m?Cd0`3clo<30?;blPH0
lO7a103bl_830??cl`H0m?Cd0`3clo<30?7al@H0lo?c0`3`l?030?;blP<0l?3`0`0D51@4018B4P<0
51@D1P0B4Q86010@40<03@d=0`3Rh^830>GUi@<0g=cL0`3Fe]H30=GEe@@0fm_K0`3Shn<30>GUi@<0
jn_[0`3^k^h30>g]k@<04a<C0`0D51@301DE5@<061PH0`0F5QH4018B4P<0l_;b0`3`l?0301<C4`<0
4A4A0`0B4Q8301DE5@H0l_;b0`0D51@3010@40<04Q8B100H61P30?7al@<0lo?c1P3alO430?;blP<0
lo?c0`3bl_83014A4@<030`<0`0?3`l30>k^kP@0lO7a2@0C4a<60?Cdm0H0oooo00<000000?ooo`3o
ool01@3oool002P0oooo00<000000?ooo`3oool01@3oool30?Cdm0<051@D1P0C4a<30?3`l0H0kno_
0`0B4Q8301@D50@05ADE0`3^k^h30>o_k`<0k>c/0`0B4Q8301@D50<06a/K0`0I6AT301PH60<05QHF
0`3_knl30?3`l0@0m?Cd0`3bl_830?3`l0<05QHF0`0E5AD301<C4`<051@D0`0C4a<601@D50<0k^k^
103_knl60>k^kP<0jn_[1P0A4A43010@40<04Q8B0`0C4a<3014A4@<051@D0`0A4A4401@D50<0l?3`
1P3clo<90?Cdm0<0lo?c0`3alO460?Cdm0@0lO7a0`3clo<60?Cdm0H0lo?c0`3bl_830>o_k`<04a<C
0`0A4A4301DE5@<04Q8B100C4a<3018B4P<03`l?0`0@410300h>3P<0i^KV0`3Shn<30>7Qh@<0f][J
0`3Hf=P30=_Kf`<0h^;R103Shn<30>KViPH03Ph>0`0A4A4301DE5@<04a<C0`0F5QH301LG5`<05QHF
0`0@4104014A4@<0k^k^0`3`l?03010@40<04a<C0`0F5QH30?7al@<0mOGe0`3`l?0301@D50<04a<C
0`0E5AD40?7al@<0m_Kf0`3/k>`300d=3@H03Ph>0`3[jn/30>o_k`<02`/;0`0:2PX30>CTi0<0k^k^
103`l?0301<C4`H051@D1P3dm?@60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003o
ool0oooo00D0oooo0`3dm?@301@D50H04a<C0`3`l?060>o_k`<04Q8B0`0D51@401DE5@<0k^k^0`3_
knl30>c/k0<04Q8B0`0D51@301/K6`<06ATI0`0H61P301HF5P<0kno_0`3`l?040?Cdm0<0l_;b0`3`
l?0301HF5P<05ADE0`0C4a<301@D50<04a<C1P0D51@30>k^kP@0kno_1P3^k^h30>_[j`H04A4A0`0@
4103018B4P<04a<C0`0A4A4301@D50<04A4A100D51@30?3`l0H0lo?c2@3dm?@30??cl`<0lO7a1P3d
m?@40?7al@<0lo?c1P3dm?@60??cl`<0l_;b0`3_knl301<C4`<04A4A0`0E5AD3018B4P@04a<C0`0B
4Q8300l?3`<0410@0`0>3Ph30>KViP<0hn?S0`3QhN430=[JfP<0f=SH0`3Kfm/30>;RhP@0hn?S0`3V
i^H600h>3P<04A4A0`0E5AD301<C4`<05QHF0`0G5aL301HF5P<0410@100A4A430>k^kP<0l?3`0`0@
410301<C4`<05QHF0`3alO430?Gem@<0l?3`0`0D51@301<C4`<05ADE103alO430?KfmP<0k>c/0`0=
3@d600h>3P<0jn_[0`3_knl300/;2`<02PX:0`3Ti>@30>k^kP@0l?3`0`0C4a<601@D50H0m?Cd1P3o
ool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0m?Cd0`0D51@6
01<C4`<0l?3`1P3_knl3018B4P<051@D100E5AD30>k^kP<0kno_0`3/k>`3018B4P<051@D0`0K6a/3
01TI6@<061PH0`0F5QH30>o_k`<0l?3`103dm?@30?;blP<0l?3`0`0F5QH301DE5@<04a<C0`0D51@3
01<C4`H051@D0`3^k^h40>o_k`H0k^k^0`3[jn/6014A4@<0410@0`0B4Q8301<C4`<04A4A0`0D51@3
014A4@@051@D0`3`l?060??cl`T0m?Cd0`3clo<30?7al@H0m?Cd103alO430??cl`H0m?Cd1P3clo<3
0?;blP<0kno_0`0C4a<3014A4@<05ADE0`0B4Q8401<C4`<04Q8B0`0?3`l3010@40<03Ph>0`3Vi^H3
0>?Sh`<0hN7Q0`3Jf]X30=SHf0<0fm_K0`3Rh^840>?Sh`<0i^KV1P0>3Ph3014A4@<05ADE0`0C4a<3
01HF5P<05aLG0`0F5QH3010@40@04A4A0`3^k^h30?3`l0<0410@0`0C4a<301HF5P<0lO7a0`3emOD3
0?3`l0<051@D0`0C4a<301DE5@@0lO7a0`3fm_H30>c/k0<03@d=1P0>3Ph30>_[j`<0kno_0`0;2`/3
00X:2P<0i>CT0`3^k^h40?3`l0<04a<C1P0D51@60?Cdm0H0oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool01@3oool30?Cdm0H04a<C0`0A4A460>o_k`<0l?3`2P0C4a<30?7a
l@H0kno_0`0B4Q8301LG5`<06QXJ0`0H61P30?;blP<0l?3`0`3bl_830??cl`@0k^k^1P0E5AD301@D
50<05ADE0`0D51@3014A4@<05QHF0`3_knl30>k^kP<0kno_103[jn/30>[ZjP<0jNWY0`3Zj^X30>SX
j0<0inOW1P0>3Ph3018B4P<04A4A2P0C4a<301LG5`T05ADE0`0F5QH301DE5@<051@D0`0G5aL30??c
l`<0m?Cd100H61P901DE5@<051@D1P0C4a<301@D50<04A4A2@0B4Q87010@40<03Ph>0`3Vi^H30>?S
h`<0h^;R0`3Lg=`30=[JfP<0g=cL0`3Rh^830>?Sh`<0iNGU100>3Ph300l?3`<0410@1P0C4a<301@D
50<05ADE0`0C4a<301DE5@<04A4A0`0@41040>SXj0<0kno_0`3`l?03018B4P<04a<C0`0D51@30?Cd
m0<0l_;b0`0D51@3018B4P<04a<C0`0F5QH40??cl`<0kNg]1P0?3`l30>[ZjP<02`/;0`0<30`30>WY
j@<0i>CT0`3QhN430>OWi`<0k>c/103]kNd601DE5@<051@D1P3dm?@60?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3dm?@601<C4`<04A4A1P3_knl30?3`l0X0
4a<C0`3alO460>o_k`<04Q8B0`0G5aL301XJ6P<061PH0`3bl_830?3`l0<0l_;b0`3clo<40>k^kPH0
5ADE0`0D51@301DE5@<051@D0`0A4A4301HF5P<0kno_0`3^k^h30>o_k`@0jn_[0`3Zj^X30>WYj@<0
j^[Z0`3Xj>P30>OWi`H03Ph>0`0B4Q83014A4@X04a<C0`0G5aL901DE5@<05QHF0`0E5AD301@D50<0
5aLG0`3clo<30?Cdm0@061PH2@0E5AD301@D50H04a<C0`0D51@3014A4@T04Q8B1`0@410300h>3P<0
i^KV0`3Shn<30>;RhP<0g=cL0`3Jf]X30=cLg0<0h^;R0`3Shn<30>GUi@@03Ph>0`0?3`l3010@40H0
4a<C0`0D51@301DE5@<04a<C0`0E5AD3014A4@<0410@103Xj>P30>o_k`<0l?3`0`0B4Q8301<C4`<0
51@D0`3dm?@30?;blP<051@D0`0B4Q8301<C4`<05QHF103clo<30>g]k@H03`l?0`3Zj^X300/;2`<0
30`<0`3YjNT30>CTi0<0hN7Q0`3WinL30>c/k0@0kNg]1P0E5AD301@D50H0m?Cd1P3oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0m?Cd1P0C4a<3014A4@H0kno_
0`3`l?0:01<C4`<0lO7a1P3_knl3018B4P<05aLG0`0J6QX301PH60<0l_;b0`3`l?030?;blP<0lo?c
103^k^h601DE5@<051@D0`0E5AD301@D50<04A4A0`0F5QH30>o_k`<0k^k^0`3_knl40>_[j`<0j^[Z
0`3YjNT30>[ZjP<0j>SX0`3WinL600h>3P<04Q8B0`0A4A4:01<C4`<05aLG2@0E5AD301HF5P<05ADE
0`0D51@301LG5`<0lo?c0`3dm?@401PH60T05ADE0`0D51@601<C4`<051@D0`0A4A49018B4PL0410@
0`0>3Ph30>KViP<0hn?S0`3Rh^830=cLg0<0f][J0`3Lg=`30>;RhP<0hn?S0`3UiND400h>3P<03`l?
0`0@410601<C4`<051@D0`0E5AD301<C4`<05ADE0`0A4A43010@40@0j>SX0`3_knl30?3`l0<04Q8B
0`0C4a<301@D50<0m?Cd0`3bl_8301@D50<04Q8B0`0C4a<301HF5P@0lo?c0`3]kNd600l?3`<0j^[Z
0`0;2`/300`<30<0jNWY0`3Ti>@30>7Qh@<0inOW0`3/k>`40>g]k@H05ADE0`0D51@60?Cdm0H0oooo
00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool30?Cdm0H04a<C0`0A
4A430?3`l0<0lO7a0`3_knl301DE5@<051@D100C4a<30?3`l0<0lO7a0`3_knl301LG5`<06ATI1P0F
5QH30?3`l0<0lO7a0`3^k^h30>o_k`@05aLG0`0C4a<601DE5@H04Q8B0`0A4A430>_[j`<0l_;b0`3/
k>`30>[ZjP@0j>SX0`3Vi^H30>?Sh`<0g]kN0`3Shn<30>GUi@<0i>CT0`3Zj^X30>_[j`H04Q8B0`0G
5aL401DE5@<05aLG1P0H61P901TI6@<06QXJ0`0I6AT301hN7P<07alO100J6QX301/K6`<06ATI0`0F
5QH301@D50<04a<C0`0B4Q83014A4@<03`l?0`0B4Q83010@40<03@d=100>3Ph30>KViP<0i>CT0`3R
h^830=[JfP<0e]KF0`3IfMT30>3Ph0<0h^;R0`3UiND300h>3P<03`l?100>3Ph3014A4@<04a<C0`0B
4Q8301HF5P<051@D0`0B4Q8301<C4`H0k^k^0`3YjNT40>c/k0<0k^k^0`3alO4901@D50<0m?Cd0`3c
lo<3018B4P<04a<C0`0F5QH70?;blP<03`l?0`0=3@d30>o_k`<0m?Cd0`0=3@d300T92@<0i^KV0`3S
hn<30=oOg`<0i>CT0`3YjNT4018B4P<04a<C0`0F5QH301@D50H0m?Cd1P3oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0m?Cd1P0C4a<3014A4@<0l?3`0`3alO43
0>o_k`<05ADE0`0D51@401<C4`<0l?3`0`3alO430>o_k`<05aLG0`0I6AT601HF5P<0l?3`0`3alO43
0>k^kP<0kno_100G5aL301<C4`H05ADE1P0B4Q83014A4@<0jn_[0`3bl_830>c/k0<0j^[Z103Xj>P3
0>KViP<0hn?S0`3Ng]h30>?Sh`<0iNGU0`3Ti>@30>[ZjP<0jn_[1P0B4Q8301LG5`@05ADE0`0G5aL6
01PH60T06ATI0`0J6QX301TI6@<07QhN0`0O7al401XJ6P<06a/K0`0I6AT301HF5P<051@D0`0C4a<3
018B4P<04A4A0`0?3`l3018B4P<0410@0`0=3@d400h>3P<0i^KV0`3Ti>@30>;RhP<0f][J0`3Fe]H3
0=WIf@<0h>3P0`3Rh^830>GUi@<03Ph>0`0?3`l400h>3P<04A4A0`0C4a<3018B4P<05QHF0`0D51@3
018B4P<04a<C1P3^k^h30>WYj@@0k>c/0`3^k^h30?7al@T051@D0`3dm?@30??cl`<04Q8B0`0C4a<3
01HF5PL0l_;b0`0?3`l300d=3@<0kno_0`3dm?@300d=3@<02@T90`3Vi^H30>?Sh`<0gmoO0`3Ti>@3
0>WYj@@04Q8B0`0C4a<301HF5P<051@D1P3dm?@60?ooo`030000003oool0oooo00D0oooo000X0?oo
o`030000003oool0oooo00D0oooo0`3dm?@601<C4`<04A4A0`3`l?030?7al@<0kno_0`0E5AD301@D
50@04a<C0`3`l?030?7al@<0kno_0`0G5aL301TI6@H05QHF0`3`l?030?7al@<0k^k^0`3_knl401LG
5`<04a<C1P0E5AD6018B4P<04A4A0`3[jn/30?;blP<0k>c/0`3Zj^X40>SXj0<0i^KV0`3Shn<30=kN
gP<0hn?S0`3UiND30>CTi0<0j^[Z0`3[jn/6018B4P<05aLG100E5AD301LG5`H061PH2@0I6AT301XJ
6P<06ATI0`0N7Qh301lO7`@06QXJ0`0K6a/301TI6@<05QHF0`0D51@301<C4`<04Q8B0`0A4A4300l?
3`<04Q8B0`0@410300d=3@@03Ph>0`3Vi^H30>CTi0<0h^;R0`3Jf]X30=KFeP<0fMWI0`3Ph>030>;R
hP<0iNGU0`0>3Ph300l?3`@03Ph>0`0A4A4301<C4`<04Q8B0`0F5QH301@D50<04Q8B0`0C4a<60>k^
kP<0jNWY103/k>`30>k^kP<0lO7a2@0D51@30?Cdm0<0lo?c0`0B4Q8301<C4`<05QHF1`3bl_8300l?
3`<03@d=0`3_knl30?Cdm0<03@d=0`092@T30>KViP<0hn?S0`3Ogml30>CTi0<0jNWY100B4Q8301<C
4`<05QHF0`0D51@60?Cdm0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool01@3oool30?Cdm0<051@D0`0C4a<3018B4P<0lO7a0`3`l?0601@D50<05QHF100C4a<30?7al@<0
l?3`0`0D51@301DE5@<06ATI0`0G5aL30?3`l0<0l_;b0`3^k^h3010@40L051@D0`0F5QH301<C4`<0
4Q8B0`0A4A430>WYj@<0j^[Z0`3_knl30>OWi`<030`<1`092@T300H61P<00`<30`061PH30=SHf0<0
gMgM0`3Ogml30>CTi0<0jn_[0`3]kNd30??cl`<0m?Cd100L71`301/K6`<07AdM0`0N7Qh301lO7`<0
820P0`0R8R8302HV9P<08R8R0`0T92@302HV9P@09BDU1P0Q8B4301XJ6P<05ADE0`0C4a<3010@40<0
3@d=0`0>3Ph30>WYj@<0jn_[0`3YjNT70>GUi@<0g=cL0`3EeMD30=;BdP<0f=SH0`3Rh^830>3Ph0<0
3@d=0`0?3`l300h>3PL0410@0`0C4a<3014A4@<051@D0`3`l?030??cl`<0l_;b0`3_knl30?3`l0<0
kNg]0`3/k>`70>k^kP<0l_;b0`0H61P301HF5P<05ADE0`3dm?@30??cl`H04a<C0`0D51@30?Cdm0@0
lO7a0`0=3@d300l?3`<0m_Kf0`3bl_8300l?3`<02@T90`3UiND30>7Qh@<0h>3P0`3YjNT30>[ZjP@0
4a<C1P0F5QH301<C4`<0lo?c0`3dm?@60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo00D0oooo0`3dm?@301@D50<04a<C0`0B4Q830?7al@<0l?3`1P0D51@301HF5P@04a<C
0`3alO430?3`l0<051@D0`0E5AD301TI6@<05aLG0`3`l?030?;blP<0k^k^0`0@410701@D50<05QHF
0`0C4a<3018B4P<04A4A0`3YjNT30>[ZjP<0kno_0`3WinL300`<30L02@T90`061PH300<30`<01PH6
0`3Hf=P30=gMg@<0gmoO0`3Ti>@30>_[j`<0kNg]0`3clo<30?Cdm0@071`L0`0K6a/301dM7@<07QhN
0`0O7al3020P80<08R8R0`0V9RH3028R8P<092@T0`0V9RH402DU9@H08B4Q0`0J6QX301DE5@<04a<C
0`0@410300d=3@<03Ph>0`3YjNT30>_[j`<0jNWY1`3UiND30=cLg0<0eMGE0`3Bd]830=SHf0<0h^;R
0`3Ph>0300d=3@<03`l?0`0>3Ph7010@40<04a<C0`0A4A4301@D50<0l?3`0`3clo<30?;blP<0kno_
0`3`l?030>g]k@<0k>c/1`3^k^h30?;blP<061PH0`0F5QH301DE5@<0m?Cd0`3clo<601<C4`<051@D
0`3dm?@40?7al@<03@d=0`0?3`l30?KfmP<0l_;b0`0?3`l300T92@<0iNGU0`3QhN430>3Ph0<0jNWY
0`3Zj^X401<C4`H05QHF0`0C4a<30??cl`<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`050?ooo`<0m?Cd0`0D51@301<C4`<04Q8B0`3alO430?3`l0H051@D0`0F
5QH401<C4`<0lO7a0`3`l?0301@D50<05ADE0`0I6AT301LG5`<0l?3`0`3bl_830>k^kP<0410@1`0D
51@301HF5P<04a<C0`0B4Q83014A4@<0jNWY0`3Zj^X30>o_k`<0inOW0`0<30`700T92@<01PH60`03
0`<300H61P<0f=SH0`3MgMd30=oOg`<0i>CT0`3[jn/30>g]k@<0lo?c0`3dm?@401`L70<06a/K0`0M
7Ad301hN7P<07alO0`0P8203028R8P<09RHV0`0R8R8302@T90<09RHV100U9BD6024Q8@<06QXJ0`0E
5AD301<C4`<0410@0`0=3@d300h>3P<0jNWY0`3[jn/30>WYj@L0iNGU0`3Lg=`30=GEe@<0d];B0`3H
f=P30>;RhP<0h>3P0`0=3@d300l?3`<03Ph>1`0@410301<C4`<04A4A0`0D51@30?3`l0<0lo?c0`3b
l_830>o_k`<0l?3`0`3]kNd30>c/k0L0k^k^0`3bl_8301PH60<05QHF0`0E5AD30?Cdm0<0lo?c1P0C
4a<301@D50<0m?Cd103alO4300d=3@<03`l?0`3fm_H30?;blP<03`l?0`092@T30>GUi@<0hN7Q0`3P
h>030>WYj@<0j^[Z100C4a<601HF5P<04a<C0`3clo<30?Cdm0H0oooo00<000000?ooo`3oool01@3o
ool002P0oooo0`0000050?ooo`<0m?Cd0`0D51@301<C4`<04Q8B1P3bl_83018B4PH05QHF100B4Q86
0?;blP<04Q8B1P0G5aL301<C4`<0lO7a0`3bl_830>g]k@<04a<C0`0E5AD401LG5`<04Q8B0`0D51@3
0>[ZjPT0i^KV0`3Ng]h300X:2P<01`L70`0820P400/;2`H020P80`3Lg=`30>?Sh`<0h>3P0`3QhN43
0>GUi@<0jn_[0`3]kNd30??cl`L0moOg0`3jn_X30?_kn`H0o?cl0`3moOd30?knoP<0oOgm0`0b<S83
02`/;0<0;Rh^1`0[:b/30?Win@<0n_[j0`3fm_H30?;blP<0k^k^0`3Zj^X30>CTi0<0i^KV0`3Ti>@3
0=gMg@@0g=cL0`3EeMD30=SHf0<0e]KF0`3Kfm/30>GUi@<0hn?S0`0?3`l300d=3@<04A4A0`0@4107
018B4P<0k^k^1P3`l?030?Cdm0<0l?3`1P3alO430>o_k`<0k^k^0`3_knl40>k^kP<05ADE0`0H61P3
01TI6@<061PH0`0E5AD30?Cdm0<0lo?c2@0C4a<30??cl`@0lO7a0`0=3@d3014A4@<0lO7a0`0G5aL3
00`<30<02PX:0`3Vi^H30>CTi0<0inOW0`3Vi^H301<C4`@04Q8B0`0G5aL301<C4`<051@D0`3bl_83
0?Cdm0D0oooo0P0000070?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0m?Cd0`0D51@301<C
4`<04Q8B1P3bl_83018B4PH05QHF100B4Q860?;blP<04Q8B1P0G5aL301<C4`<0lO7a0`3bl_830>g]
k@<04a<C0`0E5AD401LG5`<04Q8B0`0D51@30>[ZjPT0i^KV0`3Ng]h300X:2P<01`L70`0820P400/;
2`H020P80`3Lg=`30>?Sh`<0h>3P0`3QhN430>GUi@<0jn_[0`3]kNd30??cl`L0moOg0`3jn_X30?_k
n`H0o?cl0`3moOd30?knoP<0oOgm0`0b<S8302`/;0<0;Rh^1`0[:b/30?Win@<0n_[j0`3fm_H30?;b
lP<0k^k^0`3Zj^X30>CTi0<0i^KV0`3Ti>@30=gMg@@0g=cL0`3EeMD30=SHf0<0e]KF0`3Kfm/30>GU
i@<0hn?S0`0?3`l300d=3@<04A4A0`0@4107018B4P<0k^k^1P3`l?030?Cdm0<0l?3`1P3alO430>o_
k`<0k^k^0`3_knl40>k^kP<05ADE0`0H61P301TI6@<061PH0`0E5AD30?Cdm0<0lo?c2@0C4a<30??c
l`@0lO7a0`0=3@d3014A4@<0lO7a0`0G5aL300`<30<02PX:0`3Vi^H30>CTi0<0inOW0`3Vi^H301<C
4`@04Q8B0`0G5aL301<C4`<051@D0`3bl_830?Cdm0H0oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool01@3oool30?Cdm0<051@D0`0C4a<3018B4PH0l_;b0`0B4Q8601HF5P@0
4Q8B1P3bl_83018B4PH05aLG0`0C4a<30?7al@<0l_;b0`3]kNd301<C4`<05ADE100G5aL3018B4P<0
51@D0`3Zj^X90>KViP<0g]kN0`0:2PX300L71`<020P8100;2`/600P820<0g=cL0`3Shn<30>3Ph0<0
hN7Q0`3UiND30>_[j`<0kNg]0`3clo<70?Ogm`<0n_[j0`3kno/60?clo0<0oOgm0`3no_h30?gmo@<0
<S8b0`0/;2`302h^;PL0:b/[0`3inOT30?[jnP<0m_Kf0`3bl_830>k^kP<0j^[Z0`3Ti>@30>KViP<0
i>CT0`3MgMd40=cLg0<0eMGE0`3Hf=P30=KFeP<0fm_K0`3UiND30>?Sh`<03`l?0`0=3@d3014A4@<0
410@1`0B4Q830>k^kPH0l?3`0`3dm?@30?3`l0H0lO7a0`3_knl30>k^kP<0kno_103^k^h301DE5@<0
61PH0`0I6AT301PH60<05ADE0`3dm?@30??cl`T04a<C0`3clo<40?7al@<03@d=0`0A4A430?7al@<0
5aLG0`0<30`300X:2P<0i^KV0`3Ti>@30>OWi`<0i^KV0`0C4a<4018B4P<05aLG0`0C4a<301@D50<0
l_;b0`3dm?@60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo
0`3bl_8301HF5P<04Q8B0`0A4A430?;blP<0lo?c0`0D51@301HF5PL051@D0`3`l?030?;blP<051@D
0`0G5aL301@D50<05ADE1P3_knl301@D50<04a<C0`0H61P401<C4`<051@D1P3WinL30=kNgP<0f][J
0`3EeMD300H61P<01@D50`092@T300d=3@@0j^[Z0`3]kNd30>[ZjP<0kNg]1P3WinL30>WYj@<0k>c/
0`3[jn/6018B4P<05QHF100I6AT301`L70<07QhN1P0O7al3024Q8@<08b<S0`0X:2P302HV9P<0:b/[
0`0];Bd402TY:@<08B4Q0`0V9RH30?Ogm`<0mOGe0`3`l?030>o_k`<0jNWY0`3Shn<30=kNgP<0e=CD
0`020P84000000<00P820`3Fe]H30>?Sh`<0i>CT0`3WinL3014A4@<03Ph>0`0A4A4300l?3`<051@D
0`3]kNd40>k^kPH0lO7a0`3`l?030>o_k`<04a<C0`0@4109014A4@<04Q8B100F5QH301DE5@<06QXJ
0`0M7Ad301PH60<04a<C1P3bl_83014A4@<04Q8B0`0D51@30??cl`@0l?3`0`0@410300`<30<04a<C
0`0>3Ph300X:2P<030`<0`3WinL30>[ZjP<0i^KV0`0A4A4300l?3`@04a<C0`0B4Q8301HF5P<0kno_
0`3fm_H30?;blPH0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3o
ool30?;blP<05QHF0`0B4Q83014A4@<0l_;b0`3clo<301@D50<05QHF1`0D51@30?3`l0<0l_;b0`0D
51@301LG5`<051@D0`0E5AD60>o_k`<051@D0`0C4a<301PH60@04a<C0`0D51@60>OWi`<0g]kN0`3J
f]X30=GEe@<01PH60`051@D300T92@<03@d=103Zj^X30>g]k@<0j^[Z0`3]kNd60>OWi`<0jNWY0`3/
k>`30>_[j`H04Q8B0`0F5QH401TI6@<071`L0`0N7Qh601lO7`<08B4Q0`0S8b<302PX:0<09RHV0`0[
:b/302d];@@0:BTY0`0Q8B4302HV9P<0moOg0`3emOD30?3`l0<0kno_0`3YjNT30>?Sh`<0g]kN0`3D
e=@300820P@000000`020P830=KFeP<0hn?S0`3Ti>@30>OWi`<04A4A0`0>3Ph3014A4@<03`l?0`0D
51@30>g]k@@0k^k^1P3alO430?3`l0<0kno_0`0C4a<3010@40T04A4A0`0B4Q8401HF5P<05ADE0`0J
6QX301dM7@<061PH0`0C4a<60?;blP<04A4A0`0B4Q8301@D50<0lo?c103`l?03010@40<030`<0`0C
4a<300h>3P<02PX:0`0<30`30>OWi`<0j^[Z0`3Vi^H3014A4@<03`l?100C4a<3018B4P<05QHF0`3_
knl30?KfmP<0l_;b1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`05
0?ooo`<0l_;b0`0F5QH3018B4P<04A4A0`3bl_830??cl`<051@D0`0F5QH701@D50<0l?3`0`3bl_83
01@D50<05aLG0`0D51@301DE5@H0kno_0`0D51@301<C4`<061PH100C4a<301@D50H0inOW0`3Ng]h3
0=[JfP<0eMGE0`061PH300D51@<02@T90`0=3@d40>[ZjP<0kNg]0`3Zj^X30>g]k@H0inOW0`3YjNT3
0>c/k0<0jn_[1P0B4Q8301HF5P@06ATI0`0L71`301hN7PH07alO0`0Q8B4302<S8`<0:2PX0`0V9RH3
02/[:`<0;Bd]100Y:BT3024Q8@<09RHV0`3gmoL30?Gem@<0l?3`0`3_knl30>WYj@<0hn?S0`3Ng]h3
0=CDe0<00P821000000300820P<0e]KF0`3Shn<30>CTi0<0inOW0`0A4A4300h>3P<04A4A0`0?3`l3
01@D50<0kNg]103^k^h60?7al@<0l?3`0`3_knl301<C4`<0410@2@0A4A43018B4P@05QHF0`0E5AD3
01XJ6P<07AdM0`0H61P301<C4`H0l_;b0`0A4A43018B4P<051@D0`3clo<40?3`l0<0410@0`0<30`3
01<C4`<03Ph>0`0:2PX300`<30<0inOW0`3Zj^X30>KViP<04A4A0`0?3`l401<C4`<04Q8B0`0F5QH3
0>o_k`<0m_Kf0`3bl_860?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo
00D0oooo0`0H61P3018B4P<0410@0`0B4Q830?7al@<0m?Cd0`0D51@601DE5@@0kno_0`3clo<30?;b
lP<051@D0`0E5AD301HF5P<0l?3`0`3clo<30?7al@<04a<C0`0F5QH301DE5@@05aLG0`3YjNT30>SX
j0<0gMgM0`3EeMD30=CDe0<0fm_K0`3Ng]h30>OWi`<0k>c/0`3]kNd40?;blP<0k^k^0`3`l?030>g]
k@<0410@0`0=3@d300h>3P<0410@0`0C4a<3014A4@<04a<C0`0D51@401HF5P<05aLG1P0H61P601TI
6@<06a/K0`0L71`301lO7`H08B4Q100P820301dM7@H06ATI0`0D51@301<C4`<0jn_[0`3YjNT30>SX
j0<0h^;R0`3Ph>030=WIf@@0fm_K0`3MgMd30>SXj0<0i>CT0`0>3Ph3010@40<03`l?0`0@4106018B
4P<0k>c/1`3alO430>k^kP<0kNg]1P0C4a<3014A4@`04Q8B0`0C4a<401DE5@<061PH0`0I6AT301PH
60<04a<C0`0?3`l60>o_k`<03`l?0`0A4A4301DE5@<0lO7a103dm?@30>c/k0<0410@0`092@T600`<
30<0i>CT0`3]kNd30>KViP<03`l?0`0<30`300l?3`@04Q8B0`0C4a<30>k^kP<0m_Kf0`3`l?0301PH
60H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool301PH60<0
4Q8B0`0@4103018B4P<0lO7a0`3dm?@301@D50H05ADE103_knl30??cl`<0l_;b0`0D51@301DE5@<0
5QHF0`3`l?030??cl`<0lO7a0`0C4a<301HF5P<05ADE100G5aL30>WYj@<0j>SX0`3MgMd30=GEe@<0
e=CD0`3Kfm/30=kNgP<0inOW0`3/k>`30>g]k@@0l_;b0`3^k^h30?3`l0<0kNg]0`0@410300d=3@<0
3Ph>0`0@410301<C4`<04A4A0`0C4a<301@D50@05QHF0`0G5aL601PH60H06ATI0`0K6a/301`L70<0
7alO1P0Q8B44020P80<07AdM1P0I6AT301@D50<04a<C0`3[jn/30>WYj@<0j>SX0`3Rh^830>3Ph0<0
fMWI103Kfm/30=gMg@<0j>SX0`3Ti>@300h>3P<0410@0`0?3`l3010@40H04Q8B0`3/k>`70?7al@<0
k^k^0`3]kNd601<C4`<04A4A300B4Q8301<C4`@05ADE0`0H61P301TI6@<061PH0`0C4a<300l?3`H0
kno_0`0?3`l3014A4@<05ADE0`3alO440?Cdm0<0k>c/0`0@410300T92@H030`<0`3Ti>@30>g]k@<0
i^KV0`0?3`l300`<30<03`l?100B4Q8301<C4`<0k^k^0`3fm_H30?3`l0<061PH1P3oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<061PH0`0B4Q83010@40<04Q8B
0`3alO430?Cdm0<051@D1P0E5AD40>o_k`<0lo?c0`3bl_8301@D50<05ADE0`0F5QH30?3`l0<0lo?c
0`3alO4301<C4`<05QHF0`0E5AD401LG5`<0jNWY0`3Xj>P30=gMg@<0eMGE0`3De=@30=_Kf`<0g]kN
0`3WinL30>c/k0<0kNg]103bl_830>k^kP<0l?3`0`3]kNd3010@40<03@d=0`0>3Ph3010@40<04a<C
0`0A4A4301<C4`<051@D100F5QH301LG5`H061PH1P0I6AT301/K6`<071`L0`0O7al6024Q8@@0820P
0`0M7Ad601TI6@<051@D0`0C4a<30>_[j`<0jNWY0`3Xj>P30>;RhP<0h>3P0`3IfMT40=_Kf`<0gMgM
0`3Xj>P30>CTi0<03Ph>0`0@410300l?3`<0410@1P0B4Q830>c/k0L0lO7a0`3^k^h30>g]k@H04a<C
0`0A4A4<018B4P<04a<C100E5AD301PH60<06ATI0`0H61P301<C4`<03`l?1P3_knl300l?3`<04A4A
0`0E5AD30?7al@@0m?Cd0`3/k>`3010@40<02@T91P0<30`30>CTi0<0kNg]0`3Vi^H300l?3`<030`<
0`0?3`l4018B4P<04a<C0`3^k^h30?KfmP<0l?3`0`0H61P60?ooo`030000003oool0oooo00D0oooo
000X0?ooo`030000003oool0oooo00D0oooo1P0B4Q8301HF5P<0kNg]0`3dm?@30?3`l0<05QHF0`0C
4a<3014A4@@0lO7a0`3bl_830>o_k`<05QHF0`0E5AD301@D50<0l_;b0`3clo<30?3`l0<05aLG0`0H
61P301TI6@@0l?3`0`3^k^h30>CTi0<0g]kN0`3Lg=`30=gMg@<0h^;R0`3YjNT30>[ZjP<0kno_0`3a
lO440>o_k`<04a<C0`0B4Q8301@D50<04A4A300B4Q83014A4@<05ADE1`0D51@601DE5@T05QHF1P0G
5aL=01PH60<06ATI1P0E5AD301@D50T04A4A1P3Zj^X30>KViPL0jNWY0`3/k>`30>SXj0<04Q8B0`0?
3`l3018B4P<0410@0`0E5AD30>k^kP<0kno_0`3bl_830>k^kP@0kNg]1P0B4Q83014A4@<04Q8B0`0A
4A4301DE5@`04a<C100D51@601DE5@<04a<C0`0>3Ph300`<30<0j>SX0`3YjNT600h>3P<0410@0`0F
5QH40>k^kP<0lo?c0`3Xj>P300h>3P<0i>CT0`3UiND30>[ZjP<0jNWY0`0=3@d300/;2`<030`<0`0C
4a<40>g]k@<0kno_0`3dm?@30>o_k`<05aLG0`0B4Q860?ooo`030000003oool0oooo00D0oooo000X
0?ooo`030000003oool0oooo00D0oooo1P0B4Q8301HF5P<0kNg]0`3dm?@30?3`l0<05QHF0`0C4a<3
014A4@@0lO7a0`3bl_830>o_k`<05QHF0`0E5AD301@D50<0l_;b0`3clo<30?3`l0<05aLG0`0H61P3
01TI6@@0l?3`0`3^k^h30>CTi0<0g]kN0`3Lg=`30=gMg@<0h^;R0`3YjNT30>[ZjP<0kno_0`3alO44
0>o_k`<04a<C0`0B4Q8301@D50<04A4A300B4Q83014A4@<05ADE1`0D51@601DE5@T05QHF1P0G5aL=
01PH60<06ATI1P0E5AD301@D50T04A4A1P3Zj^X30>KViPL0jNWY0`3/k>`30>SXj0<04Q8B0`0?3`l3
018B4P<0410@0`0E5AD30>k^kP<0kno_0`3bl_830>k^kP@0kNg]1P0B4Q83014A4@<04Q8B0`0A4A43
01DE5@`04a<C100D51@601DE5@<04a<C0`0>3Ph300`<30<0j>SX0`3YjNT600h>3P<0410@0`0F5QH4
0>k^kP<0lo?c0`3Xj>P300h>3P<0i>CT0`3UiND30>[ZjP<0jNWY0`0=3@d300/;2`<030`<0`0C4a<4
0>g]k@<0kno_0`3dm?@30>o_k`<05aLG0`0B4Q860?ooo`030000003oool0oooo00D0oooo000X0?oo
o`030000003oool0oooo00D0oooo1P0B4Q8301HF5P<0kNg]0`3dm?@30?3`l0<05QHF0`0C4a<3014A
4@@0lO7a0`3bl_830>o_k`<05QHF0`0E5AD301@D50<0l_;b0`3clo<30?3`l0<05aLG0`0H61P301TI
6@@0l?3`0`3^k^h30>CTi0<0g]kN0`3Lg=`30=gMg@<0h^;R0`3YjNT30>[ZjP<0kno_0`3alO440>o_
k`<04a<C0`0B4Q8301@D50<04A4A300B4Q83014A4@<05ADE1`0D51@601DE5@T05QHF1P0G5aL=01PH
60<06ATI1P0E5AD301@D50T04A4A1P3Zj^X30>KViPL0jNWY0`3/k>`30>SXj0<04Q8B0`0?3`l3018B
4P<0410@0`0E5AD30>k^kP<0kno_0`3bl_830>k^kP@0kNg]1P0B4Q83014A4@<04Q8B0`0A4A4301DE
5@`04a<C100D51@601DE5@<04a<C0`0>3Ph300`<30<0j>SX0`3YjNT600h>3P<0410@0`0F5QH40>k^
kP<0lo?c0`3Xj>P300h>3P<0i>CT0`3UiND30>[ZjP<0jNWY0`0=3@d300/;2`<030`<0`0C4a<40>g]
k@<0kno_0`3dm?@30>o_k`<05aLG0`0B4Q860?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo00D0oooo0`0D51@301<C4`<0kno_0`3clo<30?3`l0<051@D0`0B4Q83014A4@<0
4Q8B103^k^h30>o_k`<051@D0`0C4a<301DE5@<04Q8B0`3bl_830?7al@H05QHF0`0K6a/301TI6@@0
mOGe0`3_knl30>[ZjP<0i>CT0`3UiND30>OWi`H0j^[Z0`0A4A43010@40<04a<C100E5AD301<C4`<0
51@D0`0E5AD301@D50<04Q8B0`0D51@3018B4P<0410@0`0C4a<30>o_k`<0l_;b103clo<60?Cdm180
mOGe0`3dm?@70??cl`<0l?3`0`0E5AD301<C4`<05ADE1P0B4Q83010@40<04Q8B0`0?3`l3010@40<0
k>c/103`l?030>k^kP<05QHF0`0B4Q8301@D50<04Q8B0`0F5QH30>k^kP<0lo?c0`3bl_830>c/k0L0
4Q8B0`0@4103018B4P<04A4A0`0C4a<301@D50<0kno_1P3bl_860??cl`L0m?Cd0`3clo<30?7al@<0
kNg]0`3UiND30>CTi0<0iNGU0`3Shn<3014A4@<03`l?0`0@410401DE5@<0kNg]0`3alO460>KViP<0
i>CT0`3Xj>P30>KViP<030`<0`0:2PX3010@40<0jNWY103`l?030?7al@<0k^k^0`0G5aL301<C4`<0
51@D1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<051@D
0`0C4a<30>o_k`<0lo?c0`3`l?0301@D50<04Q8B0`0A4A43018B4P@0k^k^0`3_knl301@D50<04a<C
0`0E5AD3018B4P<0l_;b0`3alO4601HF5P<06a/K0`0I6AT40?Gem@<0kno_0`3Zj^X30>CTi0<0iNGU
0`3WinL60>[ZjP<04A4A0`0@410301<C4`@05ADE0`0C4a<301@D50<05ADE0`0D51@3018B4P<051@D
0`0B4Q83010@40<04a<C0`3_knl30?;blP@0lo?c1P3dm?@B0?Gem@<0m?Cd1`3clo<30?3`l0<05ADE
0`0C4a<301DE5@H04Q8B0`0@4103018B4P<03`l?0`0@41030>c/k0@0l?3`0`3^k^h301HF5P<04Q8B
0`0D51@3018B4P<05QHF0`3^k^h30??cl`<0l_;b0`3/k>`7018B4P<0410@0`0B4Q83014A4@<04a<C
0`0D51@30>o_k`H0l_;b1P3clo<70?Cdm0<0lo?c0`3alO430>g]k@<0iNGU0`3Ti>@30>GUi@<0hn?S
0`0A4A4300l?3`<0410@100E5AD30>g]k@<0lO7a1P3Vi^H30>CTi0<0j>SX0`3Vi^H300`<30<02PX:
0`0@41030>WYj@@0l?3`0`3alO430>k^kP<05aLG0`0C4a<301@D50H0oooo00<000000?ooo`3oool0
1@3oool002P0oooo00<000000?ooo`3oool01@3oool301@D50<04a<C0`3_knl30??cl`<0l?3`0`0D
51@3018B4P<04A4A0`0B4Q840>k^kP<0kno_0`0D51@301<C4`<05ADE0`0B4Q830?;blP<0lO7a1P0F
5QH301/K6`<06ATI103emOD30>o_k`<0j^[Z0`3Ti>@30>GUi@<0inOW1P3Zj^X3014A4@<0410@0`0C
4a<401DE5@<04a<C0`0D51@301DE5@<051@D0`0B4Q8301@D50<04Q8B0`0@410301<C4`<0kno_0`3b
l_840??cl`H0m?Cd4P3emOD30?Cdm0L0lo?c0`3`l?0301DE5@<04a<C0`0E5AD6018B4P<0410@0`0B
4Q8300l?3`<0410@0`3/k>`40?3`l0<0k^k^0`0F5QH3018B4P<051@D0`0B4Q8301HF5P<0k^k^0`3c
lo<30?;blP<0k>c/1`0B4Q83010@40<04Q8B0`0A4A4301<C4`<051@D0`3_knl60?;blPH0lo?c1`3d
m?@30??cl`<0lO7a0`3]kNd30>GUi@<0i>CT0`3UiND30>?Sh`<04A4A0`0?3`l3010@40@05ADE0`3]
kNd30?7al@H0i^KV0`3Ti>@30>SXj0<0i^KV0`0<30`300X:2P<0410@0`3YjNT40?3`l0<0lO7a0`3^
k^h301LG5`<04a<C0`0D51@60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0
oooo00D0oooo0`0A4A4301<C4`<0kno_0`3clo<30>o_k`<04a<C1P0B4Q830>g]k@@0lO7a0`3`l?03
018B4P<051@D0`0C4a<301@D50<0lO7a0`3clo<301DE5@<06a/K0`0O7al301hN7P@0m_Kf0`3dm?@3
0>g]k@<03`l?0`0=3@d300h>3P<0410@0`0C4a<3014A4@<04a<C2P0D51@301<C4`<05ADE0`0B4Q83
01<C4`<0kno_0`3alO430?3`l0<0kno_0`3bl_830??cl`@0lO7a0`3clo<B0?Cdm0<0lo?c0`3alO43
0??cl`@0lO7a0`3bl_830?3`l0<0l_;b0`3`l?0301DE5@<04a<C0`0A4A4601<C4`<04Q8B0`0F5QH4
01DE5@<05aLG0`0D51@301HF5P<04a<C0`0G5aL30>o_k`<0mOGe0`3`l?030>o_k`<05ADE0`0?3`l7
014A4@<04a<C0`0D51@30>o_k`<0l?3`0`3bl_830??cl`<0l?3`0`3bl_830??cl`@0m?Cd1P3clo<3
0?3`l0<0jn_[0`3Xj>P30>3Ph0<0g]kN0`3Vi^H30>OWi`<0410@0`0B4Q84014A4@<05QHF0`3]kNd3
0>WYj@<0i^KV0`3Ti>@30>KViP<030`<0`0820P300l?3`<0inOW0`3]kNd40>k^kP<0jn_[0`0F5QH3
01<C4`<05QHF0`0A4A460?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo
00D0oooo0`0A4A4301<C4`<0kno_0`3clo<30>o_k`<04a<C1P0B4Q830>g]k@@0lO7a0`3`l?03018B
4P<051@D0`0C4a<301@D50<0lO7a0`3clo<301DE5@<06a/K0`0O7al301hN7P@0m_Kf0`3dm?@30>g]
k@<03`l?0`0=3@d300h>3P<0410@0`0C4a<3014A4@<04a<C2P0D51@301<C4`<05ADE0`0B4Q8301<C
4`<0kno_0`3alO430?3`l0<0kno_0`3bl_830??cl`@0lO7a0`3clo<B0?Cdm0<0lo?c0`3alO430??c
l`@0lO7a0`3bl_830?3`l0<0l_;b0`3`l?0301DE5@<04a<C0`0A4A4601<C4`<04Q8B0`0F5QH401DE
5@<05aLG0`0D51@301HF5P<04a<C0`0G5aL30>o_k`<0mOGe0`3`l?030>o_k`<05ADE0`0?3`l7014A
4@<04a<C0`0D51@30>o_k`<0l?3`0`3bl_830??cl`<0l?3`0`3bl_830??cl`@0m?Cd1P3clo<30?3`
l0<0jn_[0`3Xj>P30>3Ph0<0g]kN0`3Vi^H30>OWi`<0410@0`0B4Q84014A4@<05QHF0`3]kNd30>WY
j@<0i^KV0`3Ti>@30>KViP<030`<0`0820P300l?3`<0inOW0`3]kNd40>k^kP<0jn_[0`0F5QH301<C
4`<05QHF0`0A4A460?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0
oooo0`0A4A4301<C4`<0kno_0`3clo<30>o_k`<04a<C1P0B4Q830>g]k@@0lO7a0`3`l?03018B4P<0
51@D0`0C4a<301@D50<0lO7a0`3clo<301DE5@<06a/K0`0O7al301hN7P@0m_Kf0`3dm?@30>g]k@<0
3`l?0`0=3@d300h>3P<0410@0`0C4a<3014A4@<04a<C2P0D51@301<C4`<05ADE0`0B4Q8301<C4`<0
kno_0`3alO430?3`l0<0kno_0`3bl_830??cl`@0lO7a0`3clo<B0?Cdm0<0lo?c0`3alO430??cl`@0
lO7a0`3bl_830?3`l0<0l_;b0`3`l?0301DE5@<04a<C0`0A4A4601<C4`<04Q8B0`0F5QH401DE5@<0
5aLG0`0D51@301HF5P<04a<C0`0G5aL30>o_k`<0mOGe0`3`l?030>o_k`<05ADE0`0?3`l7014A4@<0
4a<C0`0D51@30>o_k`<0l?3`0`3bl_830??cl`<0l?3`0`3bl_830??cl`@0m?Cd1P3clo<30?3`l0<0
jn_[0`3Xj>P30>3Ph0<0g]kN0`3Vi^H30>OWi`<0410@0`0B4Q84014A4@<05QHF0`3]kNd30>WYj@<0
i^KV0`3Ti>@30>KViP<030`<0`0820P300l?3`<0inOW0`3]kNd40>k^kP<0jn_[0`0F5QH301<C4`<0
5QHF0`0A4A460?ooo`030000003oool0oooo00D0oooo000X0?ooo`<000001@3oool301DE5@<0k>c/
0`3bl_830>c/k0<05QHF0`0B4Q83014A4@<04a<C0`3^k^h40?7al@<0k^k^2@0D51@30>k^kP<0m?Cd
0`3`l?0301TI6@<07QhN0`0S8b<301hN7P@071`L0`0G5aL301DE5@<04A4A300B4Q8301<C4`<04Q8B
0`0E5AD4018B4P<04A4A0`0C4a<30>k^kP<0l?3`0`3_knl60?;blP<0kno_0`3alO430?;blP<0kno_
100D51@3018B4P`04a<C0`0D51@301<C4`<04Q8B0`0D51@30>o_k`@0lO7a0`3`l?030?7al@<0l?3`
0`3emOD30?7al@<0l?3`0`0E5AD301@D50<04a<C0`0E5AD:01LG5`<05QHF0`0B4Q8301LG5`<0l?3`
0`3fm_H30>o_k`H051@D1P0A4A4401<C4`<051@D0`3_knl30?7al@<0m?Cd0`3`l?030?7al@<0kno_
0`0C4a<3014A4@X04a<C0`0B4Q8600l?3`<0i>CT0`3UiND30=gMg@<0gmoO0`3Ti>@300h>3P<03`l?
100D51@301<C4`<04A4A0`0=3@d30>OWi`<0j^[Z0`3WinL300`<30<03@d=0`3YjNT30>c/k0<0jn_[
103Xj>P301@D50<04a<C0`0G5aL301<C4`<05ADE1@3oool2000000L0oooo000X0?ooo`030000003o
ool0oooo00D0oooo0`0E5AD30>c/k0<0l_;b0`3/k>`301HF5P<04Q8B0`0A4A4301<C4`<0k^k^103a
lO430>k^kPT051@D0`3^k^h30?Cdm0<0l?3`0`0I6AT301hN7P<08b<S0`0N7Qh401`L70<05aLG0`0E
5AD3014A4@`04Q8B0`0C4a<3018B4P<05ADE100B4Q83014A4@<04a<C0`3^k^h30?3`l0<0kno_1P3b
l_830>o_k`<0lO7a0`3bl_830>o_k`@051@D0`0B4Q8<01<C4`<051@D0`0C4a<3018B4P<051@D0`3_
knl40?7al@<0l?3`0`3alO430?3`l0<0mOGe0`3alO430?3`l0<05ADE0`0D51@301<C4`<05ADE2P0G
5aL301HF5P<04Q8B0`0G5aL30?3`l0<0m_Kf0`3_knl601@D50H04A4A100C4a<301@D50<0kno_0`3a
lO430?Cdm0<0l?3`0`3alO430>o_k`<04a<C0`0A4A4:01<C4`<04Q8B1P0?3`l30>CTi0<0iNGU0`3M
gMd30=oOg`<0i>CT0`0>3Ph300l?3`@051@D0`0C4a<3014A4@<03@d=0`3WinL30>[ZjP<0inOW0`0<
30`300d=3@<0jNWY0`3/k>`30>_[j`@0j>SX0`0D51@301<C4`<05aLG0`0C4a<301DE5@H0oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool301DE5@<0k>c/0`3bl_83
0>c/k0<05QHF0`0B4Q83014A4@<04a<C0`3^k^h40?7al@<0k^k^2@0D51@30>k^kP<0m?Cd0`3`l?03
01TI6@<07QhN0`0S8b<301hN7P@071`L0`0G5aL301DE5@<04A4A300B4Q8301<C4`<04Q8B0`0E5AD4
018B4P<04A4A0`0C4a<30>k^kP<0l?3`0`3_knl60?;blP<0kno_0`3alO430?;blP<0kno_100D51@3
018B4P`04a<C0`0D51@301<C4`<04Q8B0`0D51@30>o_k`@0lO7a0`3`l?030?7al@<0l?3`0`3emOD3
0?7al@<0l?3`0`0E5AD301@D50<04a<C0`0E5AD:01LG5`<05QHF0`0B4Q8301LG5`<0l?3`0`3fm_H3
0>o_k`H051@D1P0A4A4401<C4`<051@D0`3_knl30?7al@<0m?Cd0`3`l?030?7al@<0kno_0`0C4a<3
014A4@X04a<C0`0B4Q8600l?3`<0i>CT0`3UiND30=gMg@<0gmoO0`3Ti>@300h>3P<03`l?100D51@3
01<C4`<04A4A0`0=3@d30>OWi`<0j^[Z0`3WinL300`<30<03@d=0`3YjNT30>c/k0<0jn_[103Xj>P3
01@D50<04a<C0`0G5aL301<C4`<05ADE1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`050?ooo`<0k>c/0`3`l?030>k^kP<04a<C0`0A4A4301@D50<04a<C0`3]kNd30?3`
l0@0k^k^0`0C4a<6018B4P<04a<C0`3^k^h30>g]k@<04Q8B0`0D51@301hN7P<08R8R0`0O7al401XJ
6P<05QHF0`0E5AD301@D50<04Q8B0`0D51@3018B4P<04A4A0`0@410301<C4`<0k^k^103`l?030>o_
k`<0k^k^1P3bl_830>o_k`<0lO7a0`3_knl301<C4`<04A4A0`0C4a<301DE5@@04a<C1P0D51@<01<C
4`<051@D0`0E5AD301<C4`<05QHF100C4a<3018B4P<04A4A0`0C4a<30>o_k`<0lO7a0`3emOD30?7a
l@<0kno_1P0D51@3018B4P@051@D0`0B4Q8301<C4`<051@D0`3_knl30?KfmP<0l?3`0`0G5aL3018B
4P<051@D0`0A4A4301HF5P@0kno_0`3`l?030?Cdm0<0lO7a0`3_knl301<C4`<04A4A0`0D51@3018B
4Pd04a<C0`0B4Q83014A4@<03@d=0`0?3`l30>;RhP<0hn?S0`3MgMd60>;RhPL04A4A0`0E5AD3018B
4P<03Ph>0`3]kNd30>_[j`<03Ph>0`0;2`/300d=3@<0k>c/0`3Zj^X30>SXj0@03`l?0`0A4A4301PH
60<05QHF0`0G5aL30>c/k0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool01@3oool30>c/k0<0l?3`0`3^k^h301<C4`<04A4A0`0D51@301<C4`<0kNg]0`3`l?040>k^kP<0
4a<C1P0B4Q8301<C4`<0k^k^0`3]kNd3018B4P<051@D0`0N7Qh3028R8P<07alO100J6QX301HF5P<0
5ADE0`0D51@3018B4P<051@D0`0B4Q83014A4@<0410@0`0C4a<30>k^kP@0l?3`0`3_knl30>k^kPH0
l_;b0`3_knl30?7al@<0kno_0`0C4a<3014A4@<04a<C0`0E5AD401<C4`H051@D300C4a<301@D50<0
5ADE0`0C4a<301HF5P@04a<C0`0B4Q83014A4@<04a<C0`3_knl30?7al@<0mOGe0`3alO430>o_k`H0
51@D0`0B4Q8401@D50<04Q8B0`0C4a<301@D50<0kno_0`3fm_H30?3`l0<05aLG0`0B4Q8301@D50<0
4A4A0`0F5QH40>o_k`<0l?3`0`3dm?@30?7al@<0kno_0`0C4a<3014A4@<051@D0`0B4Q8=01<C4`<0
4Q8B0`0A4A4300d=3@<03`l?0`3Rh^830>?Sh`<0gMgM1P3Rh^87014A4@<05ADE0`0B4Q8300h>3P<0
kNg]0`3[jn/300h>3P<02`/;0`0=3@d30>c/k0<0j^[Z0`3Xj>P400l?3`<04A4A0`0H61P301HF5P<0
5aLG0`3/k>`60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo
0`3/k>`30?3`l0<0k^k^0`0C4a<3014A4@<051@D0`0C4a<30>g]k@<0l?3`103^k^h301<C4`H04Q8B
0`0C4a<30>k^kP<0kNg]0`0B4Q8301@D50<07QhN0`0R8R8301lO7`@06QXJ0`0F5QH301DE5@<051@D
0`0B4Q8301@D50<04Q8B0`0A4A43010@40<04a<C0`3^k^h40?3`l0<0kno_0`3^k^h60?;blP<0kno_
0`3alO430>o_k`<04a<C0`0A4A4301<C4`<05ADE100C4a<601@D50`04a<C0`0D51@301DE5@<04a<C
0`0F5QH401<C4`<04Q8B0`0A4A4301<C4`<0kno_0`3alO430?Gem@<0lO7a0`3_knl601@D50<04Q8B
100D51@3018B4P<04a<C0`0D51@30>o_k`<0m_Kf0`3`l?0301LG5`<04Q8B0`0D51@3014A4@<05QHF
103_knl30?3`l0<0m?Cd0`3alO430>o_k`<04a<C0`0A4A4301@D50<04Q8B3@0C4a<3018B4P<04A4A
0`0=3@d300l?3`<0h^;R0`3Shn<30=gMg@H0h^;R1`0A4A4301DE5@<04Q8B0`0>3Ph30>g]k@<0jn_[
0`0>3Ph300/;2`<03@d=0`3/k>`30>[ZjP<0j>SX100?3`l3014A4@<061PH0`0F5QH301LG5`<0k>c/
1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0l?3`0`3^
k^h30>c/k0<04a<C0`0E5AD301<C4`<051@D0`3]kNd30>o_k`@0k>c/0`0C4a<601@D50<0kNg]0`3^
k^h30>[ZjP<02`/;0`0@410301LG5`<06ATI0`0G5aL401PH60<05ADE0`0C4a<3014A4@<04a<C0`3^
k^h90?3`l0<0k^k^0`3alO440?3`l0<0lO7a0`3^k^h30?3`l0<0kno_0`0C4a<3018B4P<05ADE0`0B
4Q8601<C4`L051@D0`0C4a<301DE5@<04Q8B1P0A4A43018B4P<05ADE0`0C4a<601@D50X04a<C0`0A
4A4301@D50<05ADE0`3_knl30?7al@<0lo?c0`3_knl30>g]k@<04A4A100=3@d3010@40<0k>c/0`3_
knl30?Cdm0<0kno_0`0H61P301@D50<05QHF0`0C4a<301LG5`<0k^k^1`3clo<30>g]k@H04a<C0`0A
4A43018B4P<04a<C0`0B4Q8301DE5@X051@D0`0C4a<301@D50<0410@0`0=3@d300h>3P<0gmoO0`3P
h>030=cLg0<0i>CT0`3UiND701<C4`<051@D0`0A4A430?7al@<0l?3`2@0>3Ph30>_[j`H0j^[Z100?
3`l301HF5P<06ATI0`0H61P30>o_k`<0l?3`1P3oool00`000000oooo0?ooo`050?ooo`00:03oool0
0`000000oooo0?ooo`050?ooo`<0l?3`0`3^k^h30>c/k0<04a<C0`0E5AD301<C4`<051@D0`3]kNd3
0>o_k`@0k>c/0`0C4a<601@D50<0kNg]0`3^k^h30>[ZjP<02`/;0`0@410301LG5`<06ATI0`0G5aL4
01PH60<05ADE0`0C4a<3014A4@<04a<C0`3^k^h90?3`l0<0k^k^0`3alO440?3`l0<0lO7a0`3^k^h3
0?3`l0<0kno_0`0C4a<3018B4P<05ADE0`0B4Q8601<C4`L051@D0`0C4a<301DE5@<04Q8B1P0A4A43
018B4P<05ADE0`0C4a<601@D50X04a<C0`0A4A4301@D50<05ADE0`3_knl30?7al@<0lo?c0`3_knl3
0>g]k@<04A4A100=3@d3010@40<0k>c/0`3_knl30?Cdm0<0kno_0`0H61P301@D50<05QHF0`0C4a<3
01LG5`<0k^k^1`3clo<30>g]k@H04a<C0`0A4A43018B4P<04a<C0`0B4Q8301DE5@X051@D0`0C4a<3
01@D50<0410@0`0=3@d300h>3P<0gmoO0`3Ph>030=cLg0<0i>CT0`3UiND701<C4`<051@D0`0A4A43
0?7al@<0l?3`2@0>3Ph30>_[j`H0j^[Z100?3`l301HF5P<06ATI0`0H61P30>o_k`<0l?3`1P3oool0
0`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0l?3`0`3^k^h30>c/
k0<04a<C0`0E5AD301<C4`<051@D0`3]kNd30>o_k`@0k>c/0`0C4a<601@D50<0kNg]0`3^k^h30>[Z
jP<02`/;0`0@410301LG5`<06ATI0`0G5aL401PH60<05ADE0`0C4a<3014A4@<04a<C0`3^k^h90?3`
l0<0k^k^0`3alO440?3`l0<0lO7a0`3^k^h30?3`l0<0kno_0`0C4a<3018B4P<05ADE0`0B4Q8601<C
4`L051@D0`0C4a<301DE5@<04Q8B1P0A4A43018B4P<05ADE0`0C4a<601@D50X04a<C0`0A4A4301@D
50<05ADE0`3_knl30?7al@<0lo?c0`3_knl30>g]k@<04A4A100=3@d3010@40<0k>c/0`3_knl30?Cd
m0<0kno_0`0H61P301@D50<05QHF0`0C4a<301LG5`<0k^k^1`3clo<30>g]k@H04a<C0`0A4A43018B
4P<04a<C0`0B4Q8301DE5@X051@D0`0C4a<301@D50<0410@0`0=3@d300h>3P<0gmoO0`3Ph>030=cL
g0<0i>CT0`3UiND701<C4`<051@D0`0A4A430?7al@<0l?3`2@0>3Ph30>_[j`H0j^[Z100?3`l301HF
5P<06ATI0`0H61P30>o_k`<0l?3`1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000
oooo0?ooo`050?ooo`<0l?3`0`3^k^h30>c/k0<04a<C0`0E5AD301<C4`<051@D0`3]kNd30>o_k`@0
k>c/0`0C4a<601@D50<0kNg]0`3^k^h30>[ZjP<02`/;0`0@410301LG5`<06ATI0`0G5aL401PH60<0
5ADE0`0C4a<3014A4@<04a<C0`3^k^h90?3`l0<0k^k^0`3alO440?3`l0<0lO7a0`3^k^h30?3`l0<0
kno_0`0C4a<3018B4P<05ADE0`0B4Q8601<C4`L051@D0`0C4a<301DE5@<04Q8B1P0A4A43018B4P<0
5ADE0`0C4a<601@D50X04a<C0`0A4A4301@D50<05ADE0`3_knl30?7al@<0lo?c0`3_knl30>g]k@<0
4A4A100=3@d3010@40<0k>c/0`3_knl30?Cdm0<0kno_0`0H61P301@D50<05QHF0`0C4a<301LG5`<0
k^k^1`3clo<30>g]k@H04a<C0`0A4A43018B4P<04a<C0`0B4Q8301DE5@X051@D0`0C4a<301@D50<0
410@0`0=3@d300h>3P<0gmoO0`3Ph>030=cLg0<0i>CT0`3UiND701<C4`<051@D0`0A4A430?7al@<0
l?3`2@0>3Ph30>_[j`H0j^[Z100?3`l301HF5P<06ATI0`0H61P30>o_k`<0l?3`1P3oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0k>c/0`3Zj^X3014A4@<04Q8B
0`0G5aL301HF5P<0k^k^0`3_knl30>_[j`@04A4A0`0B4Q8301DE5@<04a<C0`3^k^h30>WYj@<0hn?S
0`092@T300`<30<0410@0`0B4Q8301DE5@@0l?3`0`3clo<30?;blP<0lO7a0`3_knl30?7al@<0l?3`
0`3alO430>o_k`H0l?3`103alO430>k^kP<04a<C0`0B4Q8301DE5@<04a<C1P0D51@3018B4P<05ADE
0`0C4a<3018B4P@04A4A0`0C4a<30>k^kP<0kno_1P3^k^h30>o_k`<0k^k^0`0C4a<3018B4PL04a<C
0`0D51@301HF5P<04Q8B0`0C4a<3014A4@H04a<C0`3/k>`30?;blP<0kno_0`3Zj^X40>WYj@<0j>SX
0`3^k^h30?7al@<0k^k^0`0G5aL301@D50<05aLG0`0D51@301PH60<0l?3`0`3emOD40?3`l0<0kno_
0`0F5QH3010@40H04Q8B0`0E5AD3018B4P<051@D0`3`l?070??cl`<0kno_0`3clo<30?3`l0<05QHF
0`0?3`l300`<30<02PX:0`3MgMd30=SHf0<0f][J0`3WinL40>_[j`H04a<C0`0B4Q860?;blPH0410@
0`0>3Ph30>_[j`<0j^[Z0`3/k>`4014A4@<061PH0`0I6AT301DE5@<0l?3`0`3/k>`60?ooo`030000
003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3/k>`30>[ZjP<04A4A0`0B
4Q8301LG5`<05QHF0`3^k^h30>o_k`<0jn_[100A4A43018B4P<05ADE0`0C4a<30>k^kP<0jNWY0`3S
hn<300T92@<030`<0`0@4103018B4P<05ADE103`l?030??cl`<0l_;b0`3alO430>o_k`<0lO7a0`3`
l?030?7al@<0kno_1P3`l?040?7al@<0k^k^0`0C4a<3018B4P<05ADE0`0C4a<601@D50<04Q8B0`0E
5AD301<C4`<04Q8B100A4A4301<C4`<0k^k^0`3_knl60>k^kP<0kno_0`3^k^h301<C4`<04Q8B1`0C
4a<301@D50<05QHF0`0B4Q8301<C4`<04A4A1P0C4a<30>c/k0<0l_;b0`3_knl30>[ZjP@0jNWY0`3X
j>P30>k^kP<0lO7a0`3^k^h301LG5`<051@D0`0G5aL301@D50<061PH0`3`l?030?Gem@@0l?3`0`3_
knl301HF5P<0410@1P0B4Q8301DE5@<04Q8B0`0D51@30?3`l0L0lo?c0`3_knl30??cl`<0l?3`0`0F
5QH300l?3`<030`<0`0:2PX30=gMg@<0f=SH0`3Jf]X30>OWi`@0jn_[1P0C4a<3018B4PH0l_;b1P0@
410300h>3P<0jn_[0`3Zj^X30>c/k0@04A4A0`0H61P301TI6@<05ADE0`3`l?030>c/k0H0oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool30>c/k0<0j^[Z0`0A4A43
018B4P<05aLG0`0F5QH30>k^kP<0kno_0`3[jn/4014A4@<04Q8B0`0E5AD301<C4`<0k^k^0`3YjNT3
0>?Sh`<02@T90`0<30`3010@40<04Q8B0`0E5AD40?3`l0<0lo?c0`3bl_830?7al@<0kno_0`3alO43
0?3`l0<0lO7a0`3_knl60?3`l0@0lO7a0`3^k^h301<C4`<04Q8B0`0E5AD301<C4`H051@D0`0B4Q83
01DE5@<04a<C0`0B4Q84014A4@<04a<C0`3^k^h30>o_k`H0k^k^0`3_knl30>k^kP<04a<C0`0B4Q87
01<C4`<051@D0`0F5QH3018B4P<04a<C0`0A4A4601<C4`<0k>c/0`3bl_830>o_k`<0j^[Z103YjNT3
0>SXj0<0k^k^0`3alO430>k^kP<05aLG0`0D51@301LG5`<051@D0`0H61P30?3`l0<0mOGe103`l?03
0>o_k`<05QHF0`0@4106018B4P<05ADE0`0B4Q8301@D50<0l?3`1`3clo<30>o_k`<0lo?c0`3`l?03
01HF5P<03`l?0`0<30`300X:2P<0gMgM0`3Hf=P30=[JfP<0inOW103[jn/601<C4`<04Q8B1P3bl_86
010@40<03Ph>0`3[jn/30>[ZjP<0k>c/100A4A4301PH60<06ATI0`0E5AD30?3`l0<0k>c/1P3oool0
0`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`H0jn_[0`0>3Ph301DE
5@<061PH0`0E5AD30?7al@<0k^k^0`3/k>`400l?3`<05ADE0`0F5QH3018B4P<0k>c/0`3UiND30>;R
hP<0hN7Q0`3Xj>P30>g]k@H0kno_1`3clo<30?3`l0H0lO7a0`3`l?030?7al@<0kno_0`0C4a<3014A
4@<04Q8B100C4a<301DE5@<04a<C2@0E5AD301<C4`<051@D0`0E5AD30>o_k`H0l_;b103alO430>o_
k`<0l?3`0`3^k^h60>c/k0<0k^k^0`3`l?030>o_k`<0l_;b1`3clo<30?Cdm0<0lO7a0`0E5AD301@D
50H04Q8B0`0@410301DE5@<0k^k^1P3]kNd70>WYj@<0k^k^0`3[jn/301HF5P<04a<C0`0G5aL301@D
50<06ATI0`3alO430?Ogm`<0kno_1`0D51@6018B4P<051@D0`0E5AD30?3`l0<0l_;b0`3`l?060??c
l`@0jn_[0`0@41030>c/k0<0l_;b0`3_knl301<C4`<03Ph>0`0:2PX30>;RhP<0f=SH0`3Bd]830=oO
g`@0j^[Z0`0@4106018B4PH0lo?c0`0A4A43010@40<03`l?1P3[jn/30>g]k@@04Q8B0`0H61P301TI
6@<051@D0`3_knl30>_[j`H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool01@3oool60>_[j`<03Ph>0`0E5AD301PH60<05ADE0`3alO430>k^kP<0k>c/100?3`l301DE5@<0
5QHF0`0B4Q830>c/k0<0iNGU0`3Rh^830>7Qh@<0j>SX0`3]kNd60>o_k`L0lo?c0`3`l?060?7al@<0
l?3`0`3alO430>o_k`<04a<C0`0A4A43018B4P@04a<C0`0E5AD301<C4`T05ADE0`0C4a<301@D50<0
5ADE0`3_knl60?;blP@0lO7a0`3_knl30?3`l0<0k^k^1P3/k>`30>k^kP<0l?3`0`3_knl30?;blPL0
lo?c0`3dm?@30?7al@<05ADE0`0D51@6018B4P<0410@0`0E5AD30>k^kPH0kNg]1`3YjNT30>k^kP<0
jn_[0`0F5QH301<C4`<05aLG0`0D51@301TI6@<0lO7a0`3gmoL30>o_k`L051@D1P0B4Q8301@D50<0
5ADE0`3`l?030?;blP<0l?3`1P3clo<40>_[j`<0410@0`3/k>`30?;blP<0kno_0`0C4a<300h>3P<0
2PX:0`3Rh^830=SHf0<0d];B0`3Ogml40>[ZjP<0410@1P0B4Q860??cl`<04A4A0`0@410300l?3`H0
jn_[0`3]kNd4018B4P<061PH0`0I6AT301@D50<0kno_0`3[jn/60?ooo`030000003oool0oooo00D0
oooo000:0?ooo`L000000`3oool4000000D0oooo100000070?ooo`030000003oool0oooo00D0oooo
1P3[jn/300h>3P<05ADE0`0H61P301DE5@<0lO7a0`3^k^h30>c/k0@03`l?0`0E5AD301HF5P<04Q8B
0`3/k>`30>GUi@<0h^;R0`3QhN430>SXj0<0kNg]1P3_knl70??cl`<0l?3`1P3alO430?3`l0<0lO7a
0`3_knl301<C4`<04A4A0`0B4Q8401<C4`<05ADE0`0C4a<901DE5@<04a<C0`0D51@301DE5@<0kno_
1P3bl_840?7al@<0kno_0`3`l?030>k^kPH0k>c/0`3^k^h30?3`l0<0kno_0`3bl_870??cl`<0m?Cd
0`3alO4301DE5@<051@D1P0B4Q83010@40<05ADE0`3^k^h60>g]k@L0jNWY0`3^k^h30>_[j`<05QHF
0`0C4a<301LG5`<051@D0`0I6AT30?7al@<0moOg0`3_knl701@D50H04Q8B0`0D51@301DE5@<0l?3`
0`3bl_830?3`l0H0lo?c103[jn/3010@40<0k>c/0`3bl_830>o_k`<04a<C0`0>3Ph300X:2P<0h^;R
0`3Hf=P30=;BdP<0gmoO103Zj^X3010@40H04Q8B1P3clo<3014A4@<0410@0`0?3`l60>_[j`<0kNg]
100B4Q8301PH60<06ATI0`0D51@30>o_k`<0jn_[1P3oool00`000000oooo0?ooo`050?ooo`003@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool60>_[j`<03Ph>
0`0D51@301LG5`<05ADE0`3alO430>k^kP<0k>c/100?3`l301@D50<05aLG0`0C4a<30>k^kP<0i^KV
0`3Ph>030>;RhP<0j>SX1P3^k^h30?3`l0@0l_;b0`3_knl301@D50<04A4A1P0B4Q8301<C4`<05ADE
0`0C4a<601HF5P@05ADE1P0D51@301<C4`<05ADE0`0B4Q8301@D50<0kno_0`3`l?060??cl`<0l?3`
103alO430?3`l0<0kno_0`3^k^h60>g]k@<0k^k^0`3_knl30?7al@<0l_;b1`3clo<30?7al@<0mOGe
0`3bl_830?3`l0<05ADE0`0D51@6014A4@<04a<C0`0B4Q830>[ZjP@0kno_0`3`l?030>c/k0<05QHF
0`0C4a<301LG5`<051@D0`0I6AT30?7al@<0moOg0`3alO4301PH60@04Q8B0`0D51@3018B4P<05aLG
0`3alO430?;blP<0mOGe0`3`l?030?7al@<0l_;b0`3_knl4014A4@<02PX:0`3[jn/30>o_k`<0lO7a
0`0B4Q83010@40<030`<0`3Shn<30=SHf0<0c/k>0`3Kfm/40>OWi`<03Ph>0`0A4A43018B4PH0lo?c
0`0B4Q83014A4@<03`l?0`3/k>`30>_[j`<0kNg]100B4Q8301PH60<06ATI0`0D51@30>o_k`<0jn_[
1P3oool00`000000oooo0?ooo`050?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool60>_[j`<03Ph>0`0D51@301LG5`<05ADE0`3alO430>k^kP<0k>c/
100?3`l301@D50<05aLG0`0C4a<30>k^kP<0i^KV0`3Ph>030>;RhP<0j>SX1P3^k^h30?3`l0@0l_;b
0`3_knl301@D50<04A4A1P0B4Q8301<C4`<05ADE0`0C4a<601HF5P@05ADE1P0D51@301<C4`<05ADE
0`0B4Q8301@D50<0kno_0`3`l?060??cl`<0l?3`103alO430?3`l0<0kno_0`3^k^h60>g]k@<0k^k^
0`3_knl30?7al@<0l_;b1`3clo<30?7al@<0mOGe0`3bl_830?3`l0<05ADE0`0D51@6014A4@<04a<C
0`0B4Q830>[ZjP@0kno_0`3`l?030>c/k0<05QHF0`0C4a<301LG5`<051@D0`0I6AT30?7al@<0moOg
0`3alO4301PH60@04Q8B0`0D51@3018B4P<05aLG0`3alO430?;blP<0mOGe0`3`l?030?7al@<0l_;b
0`3_knl4014A4@<02PX:0`3[jn/30>o_k`<0lO7a0`0B4Q83010@40<030`<0`3Shn<30=SHf0<0c/k>
0`3Kfm/40>OWi`<03Ph>0`0A4A43018B4PH0lo?c0`0B4Q83014A4@<03`l?0`3/k>`30>_[j`<0kNg]
100B4Q8301PH60<06ATI0`0D51@30>o_k`<0jn_[1P3oool00`000000oooo0?ooo`050?ooo`003@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00@0oooo100000040?ooo`H0jn_[0`0>3Ph301@D50<05aLG
0`0E5AD30?7al@<0k^k^0`3/k>`400l?3`<051@D0`0G5aL301<C4`<0k^k^0`3Vi^H30>3Ph0<0h^;R
0`3Xj>P60>k^kP<0l?3`103bl_830>o_k`<051@D0`0A4A46018B4P<04a<C0`0E5AD301<C4`H05QHF
100E5AD601@D50<04a<C0`0E5AD3018B4P<051@D0`3_knl30?3`l0H0lo?c0`3`l?040?7al@<0l?3`
0`3_knl30>k^kPH0kNg]0`3^k^h30>o_k`<0lO7a0`3bl_870??cl`<0lO7a0`3emOD30?;blP<0l?3`
0`0E5AD301@D50H04A4A0`0C4a<3018B4P<0j^[Z103_knl30?3`l0<0k>c/0`0F5QH301<C4`<05aLG
0`0D51@301TI6@<0lO7a0`3gmoL30?7al@<061PH100B4Q8301@D50<04Q8B0`0G5aL30?7al@<0l_;b
0`3emOD30?3`l0<0lO7a0`3bl_830>o_k`@04A4A0`0:2PX30>_[j`<0kno_0`3alO43018B4P<0410@
0`0<30`30>?Sh`<0f=SH0`3>c/h30=_Kf`@0inOW0`0>3Ph3014A4@<04Q8B1P3clo<3018B4P<04A4A
0`0?3`l30>c/k0<0jn_[0`3]kNd4018B4P<061PH0`0I6AT301@D50<0kno_0`3[jn/40?ooo`<00000
1`3oool000d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
0`3/k>`30>WYj@<0410@0`0A4A4601HF5P<0l?3`0`3alO430>c/k0L04A4A1P0F5QH30>o_k`<0k^k^
0`3Xj>P60>[ZjP<0jn_[0`0B4Q83014A4@@04a<C0`0F5QH301<C4`H051@D1P0C4a<301@D50<05ADE
0`0F5QH301@D50@05QHF0`0C4a<3014A4@<04a<C0`3_knl30?7al@<0l?3`0`3dm?@30?3`l0<0lO7a
0`3_knl301<C4`@0410@1P0A4A4<010@40<04A4A2@0B4Q84014A4@<051@D0`3`l?030?;blP<0mOGe
0`3bl_830?7al@<05aLG0`0B4Q8301@D50<04Q8B0`0G5aL70?;blP<06ATI0`0D51@301LG5`<051@D
0`0I6AT30?7al@<0moOg0`3alO4301TI6@<051@D100F5QH301<C4`<05aLG0`3`l?030?KfmP<0lO7a
0`3_knl301<C4`<0410@0`0C4a<301DE5@@03`l?0`0>3Ph30>g]k@<0l?3`0`3^k^h301@D50<04A4A
0`0<30`30>CTi0<0f=SH0`3<c<`30=[JfP@0i^KV0`0=3@d3010@40<04Q8B1P3clo<6014A4@<03`l?
0`3/k>`30>_[j`<0kNg]100B4Q8301PH60<06QXJ0`0E5AD30?3`l0<0k>c/1P3oool00`000000oooo
0?ooo`050?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool30>c/k0<0jNWY0`0@4103014A4@H05QHF0`3`l?030?7al@<0k>c/1`0A4A4601HF5P<0kno_
0`3^k^h30>SXj0H0j^[Z0`3[jn/3018B4P<04A4A100C4a<301HF5P<04a<C1P0D51@601<C4`<051@D
0`0E5AD301HF5P<051@D100F5QH301<C4`<04A4A0`0C4a<30>o_k`<0lO7a0`3`l?030?Cdm0<0l?3`
0`3alO430>o_k`<04a<C100@4106014A4@`0410@0`0A4A49018B4P@04A4A0`0D51@30?3`l0<0l_;b
0`3emOD30?;blP<0lO7a0`0G5aL3018B4P<051@D0`0B4Q8301LG5`L0l_;b0`0I6AT301@D50<05aLG
0`0D51@301TI6@<0lO7a0`3gmoL30?7al@<06ATI0`0D51@401HF5P<04a<C0`0G5aL30?3`l0<0m_Kf
0`3alO430>o_k`<04a<C0`0@410301<C4`<05ADE100?3`l300h>3P<0kNg]0`3`l?030>k^kP<051@D
0`0A4A4300`<30<0i>CT0`3Hf=P30<c<c0<0f][J103Vi^H300d=3@<0410@0`0B4Q860??cl`H04A4A
0`0?3`l30>c/k0<0jn_[0`3]kNd4018B4P<061PH0`0J6QX301DE5@<0l?3`0`3/k>`60?ooo`030000
003oool0oooo00D0oooo000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`<0k>c/0`3YjNT3010@40<04A4A1P0F5QH30?3`l0<0lO7a0`3/k>`7014A4@H05QHF
0`3_knl30>k^kP<0j>SX1P3Zj^X30>_[j`<04Q8B0`0A4A4401<C4`<05QHF0`0C4a<601@D50H04a<C
0`0D51@301DE5@<05QHF0`0D51@401HF5P<04a<C0`0A4A4301<C4`<0kno_0`3alO430?3`l0<0m?Cd
0`3`l?030?7al@<0kno_0`0C4a<4010@40H04A4A300@4103014A4@T04Q8B100A4A4301@D50<0l?3`
0`3bl_830?Gem@<0l_;b0`3alO4301LG5`<04Q8B0`0D51@3018B4P<05aLG1`3bl_8301TI6@<051@D
0`0G5aL301@D50<06ATI0`3alO430?Ogm`<0lO7a0`0I6AT301@D50@05QHF0`0C4a<301LG5`<0l?3`
0`3fm_H30?7al@<0kno_0`0C4a<3010@40<04a<C0`0E5AD400l?3`<03Ph>0`3]kNd30?3`l0<0k^k^
0`0D51@3014A4@<030`<0`3Ti>@30=SHf0<0c<c<0`3Jf]X40>KViP<03@d=0`0@4103018B4PH0lo?c
1P0A4A4300l?3`<0k>c/0`3[jn/30>g]k@@04Q8B0`0H61P301XJ6P<05ADE0`3`l?030>c/k0H0oooo
00<000000?ooo`3oool01@3oool000/0oooo0`0000050?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool30>o_k`<0kNg]0`3YjNT301DE5@H04a<C0`0F5QH30>c/k0<0l_;b103/k>`301HF5P<051@D
0`0E5AD301TI6@H0l?3`0`3/k>`9018B4P<051@D2P0E5AD301<C4`<05ADE0`0B4Q83014A4@T04Q8B
0`0D51@40>o_k`<0lO7a0`3_knl30>k^kP<0l_;b0`3clo<30?7al@<0kno_0`0D51@3018B4P<05ADE
0`0B4Q8701<C4a804Q8B3@0C4a<3018B4P<051@D0`0E5AD30?3`l0<0l_;b0`3fm_H30?3`l0<05aLG
0`0C4a<601LG5`L06a/K0`0G5aL301PH60<05ADE0`0I6AT30?7al@<0moOg0`3alO4301TI6@<05ADE
0`0G5aL401@D50<061PH0`3`l?030?KfmP<0kno_0`0D51@3018B4P<0410@0`0H61P301HF5P<061PH
100D51@3010@40<0kno_0`3^k^h301<C4`H04A4A0`0<30`30>?Sh`<0f=SH0`3?cll30=[JfP@0i^KV
0`0=3@d3010@40<04Q8B0`3clo<30?;blPT0410@0`3^k^h60>c/k0@0410@0`0G5aL301/K6`<06ATI
0`3`l?030>o_k`H0oooo00<000000?ooo`3oool01@3oool000d0oooo00<000000?ooo`3oool0103o
ool4000000D0oooo100000070?ooo`030000003oool0oooo00D0oooo0`3_knl30>g]k@<0jNWY0`0E
5AD601<C4`<05QHF0`3/k>`30?;blP@0k>c/0`0F5QH301@D50<05ADE0`0I6AT60?3`l0<0k>c/2@0B
4Q8301@D50X05ADE0`0C4a<301DE5@<04Q8B0`0A4A49018B4P<051@D103_knl30?7al@<0kno_0`3^
k^h30?;blP<0lo?c0`3alO430>o_k`<051@D0`0B4Q8301DE5@<04Q8B1`0C4a<B018B4Pd04a<C0`0B
4Q8301@D50<05ADE0`3`l?030?;blP<0m_Kf0`3`l?0301LG5`<04a<C1P0G5aL701/K6`<05aLG0`0H
61P301DE5@<06ATI0`3alO430?Ogm`<0lO7a0`0I6AT301DE5@<05aLG100D51@301PH60<0l?3`0`3f
m_H30>o_k`<051@D0`0B4Q83010@40<061PH0`0F5QH301PH60@051@D0`0@41030>o_k`<0k^k^0`0C
4a<6014A4@<030`<0`3Shn<30=SHf0<0clo?0`3Jf]X40>KViP<03@d=0`0@4103018B4P<0lo?c0`3b
l_89010@40<0k^k^1P3/k>`4010@40<05aLG0`0K6a/301TI6@<0l?3`0`3_knl60?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3_knl30>g]k@<0jNWY0`0E5AD6
01<C4`<05QHF0`3/k>`30?;blP@0k>c/0`0F5QH301@D50<05ADE0`0I6AT60?3`l0<0k>c/2@0B4Q83
01@D50X05ADE0`0C4a<301DE5@<04Q8B0`0A4A49018B4P<051@D103_knl30?7al@<0kno_0`3^k^h3
0?;blP<0lo?c0`3alO430>o_k`<051@D0`0B4Q8301DE5@<04Q8B1`0C4a<B018B4Pd04a<C0`0B4Q83
01@D50<05ADE0`3`l?030?;blP<0m_Kf0`3`l?0301LG5`<04a<C1P0G5aL701/K6`<05aLG0`0H61P3
01DE5@<06ATI0`3alO430?Ogm`<0lO7a0`0I6AT301DE5@<05aLG100D51@301PH60<0l?3`0`3fm_H3
0>o_k`<051@D0`0B4Q83010@40<061PH0`0F5QH301PH60@051@D0`0@41030>o_k`<0k^k^0`0C4a<6
014A4@<030`<0`3Shn<30=SHf0<0clo?0`3Jf]X40>KViP<03@d=0`0@4103018B4P<0lo?c0`3bl_89
010@40<0k^k^1P3/k>`4010@40<05aLG0`0K6a/301TI6@<0l?3`0`3_knl60?ooo`030000003oool0
oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3/k>`30>o_k`<0l?3`0`3^k^h601@D
50<04A4A0`0C4a<30>o_k`@0l_;b0`3_knl301DE5@H05aLG0`0I6AT601DE5@<04Q8B0`0C4a<301@D
50<04a<C100F5QH301@D50<04Q8B0`0D51@30>k^kP<0l?3`0`3_knl30?3`l0H0lO7a0`3_knl40?7a
l@<0l?3`0`3alO430>k^kP<0lO7a0`3`l?0601DE5@<04a<C0`0E5AD301@D50<04a<C100F5QH301@D
51P04a<C0`0D51@401HF5P<04Q8B0`0C4a<3018B4P<051@D0`0E5AD30>o_k`<0m_Kf0`3`l?0301PH
60<051@D0`0I6AT701/K6`<06QXJ0`0E5AD301TI6@<0lO7a0`3gmoL30?7al@<06ATI0`0E5AD301PH
60<051@D100H61P30>o_k`<0mOGe0`3_knl301HF5P<04A4A0`0B4Q8301dM7@<0m_Kf0`0N7Qh301XJ
6PL051@D0`3_knl30?3`l0<04A4A0`0C4a<3010@40<03Ph>0`3Rh^830=_Kf`<0eMGE0`3MgMd40>OW
i`<03@d=0`0A4A4301<C4`<0lo?c0`3alO4301<C4`<03`l?0`0B4Q830>c/k0<0k^k^0`3[jn/4018B
4P<051@D0`0K6a/301LG5`<061PH0`3/k>`60?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo00D0oooo0`3/k>`30>o_k`<0l?3`0`3^k^h601@D50<04A4A0`0C4a<30>o_k`@0
l_;b0`3_knl301DE5@H05aLG0`0I6AT601DE5@<04Q8B0`0C4a<301@D50<04a<C100F5QH301@D50<0
4Q8B0`0D51@30>k^kP<0l?3`0`3_knl30?3`l0H0lO7a0`3_knl40?7al@<0l?3`0`3alO430>k^kP<0
lO7a0`3`l?0601DE5@<04a<C0`0E5AD301@D50<04a<C100F5QH301@D51P04a<C0`0D51@401HF5P<0
4Q8B0`0C4a<3018B4P<051@D0`0E5AD30>o_k`<0m_Kf0`3`l?0301PH60<051@D0`0I6AT701/K6`<0
6QXJ0`0E5AD301TI6@<0lO7a0`3gmoL30?7al@<06ATI0`0E5AD301PH60<051@D100H61P30>o_k`<0
mOGe0`3_knl301HF5P<04A4A0`0B4Q8301dM7@<0m_Kf0`0N7Qh301XJ6PL051@D0`3_knl30?3`l0<0
4A4A0`0C4a<3010@40<03Ph>0`3Rh^830=_Kf`<0eMGE0`3MgMd40>OWi`<03@d=0`0A4A4301<C4`<0
lo?c0`3alO4301<C4`<03`l?0`0B4Q830>c/k0<0k^k^0`3[jn/4018B4P<051@D0`0K6a/301LG5`<0
61PH0`3/k>`60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo
0`3/k>`30>o_k`<0l?3`0`3^k^h601@D50<04A4A0`0C4a<30>o_k`@0l_;b0`3_knl301DE5@H05aLG
0`0I6AT601DE5@<04Q8B0`0C4a<301@D50<04a<C100F5QH301@D50<04Q8B0`0D51@30>k^kP<0l?3`
0`3_knl30?3`l0H0lO7a0`3_knl40?7al@<0l?3`0`3alO430>k^kP<0lO7a0`3`l?0601DE5@<04a<C
0`0E5AD301@D50<04a<C100F5QH301@D51P04a<C0`0D51@401HF5P<04Q8B0`0C4a<3018B4P<051@D
0`0E5AD30>o_k`<0m_Kf0`3`l?0301PH60<051@D0`0I6AT701/K6`<06QXJ0`0E5AD301TI6@<0lO7a
0`3gmoL30?7al@<06ATI0`0E5AD301PH60<051@D100H61P30>o_k`<0mOGe0`3_knl301HF5P<04A4A
0`0B4Q8301dM7@<0m_Kf0`0N7Qh301XJ6PL051@D0`3_knl30?3`l0<04A4A0`0C4a<3010@40<03Ph>
0`3Rh^830=_Kf`<0eMGE0`3MgMd40>OWi`<03@d=0`0A4A4301<C4`<0lo?c0`3alO4301<C4`<03`l?
0`0B4Q830>c/k0<0k^k^0`3[jn/4018B4P<051@D0`0K6a/301LG5`<061PH0`3/k>`60?ooo`030000
003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0F5QH30>c/k0<0l_;b0`3_
knl301<C4`<04A4A1P0C4a<30>k^kP@0lo?c0`3`l?0301HF5P<05ADE1P0K6a/301PH60<05ADE0`0B
4Q8301DE5@<04Q8B0`0D51@40?7al@<0lo?c0`3bl_830>o_k`<0lO7a1P3_knl30?7al@<0kno_3@3a
lO430>o_k`<051@D0`0C4a<301LG5`<051@D1P0F5QH301<C4`<05ADE0`0F5QH40?7alAh0m?Cd103a
lO4301HF5P<05ADE0`0C4a<301@D50<04A4A0`0F5QH30>o_k`<0m_Kf0`3`l?0301LG5`<04Q8B1`0F
5QH301<C4`<061PH0`3`l?030?Ogm`<0lO7a0`0I6AT301DE5@<061PH0`0D51@301PH60@0kno_0`3e
mOD30?;blP<05ADE0`0B4Q8301DE5@<05aLG0`3fm_H30?_kn`<071`L0`0H61P401LG5`<0l?3`1P3b
l_8901<C4`<0j^[Z0`3Xj>P30>7Qh@<0e]KF0`3Shn<40>SXj0<03@d=0`0A4A4301DE5@<0l?3`0`3e
mOD30>o_k`<04Q8B0`0?3`l3014A4@<0k>c/0`3_knl40>c/k0<051@D0`0H61P301XJ6P<051@D0`0F
5QH60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0F5QH3
0>c/k0<0l_;b0`3_knl301<C4`<04A4A1P0C4a<30>k^kP@0lo?c0`3`l?0301HF5P<05ADE1P0K6a/3
01PH60<05ADE0`0B4Q8301DE5@<04Q8B0`0D51@40?7al@<0lo?c0`3bl_830>o_k`<0lO7a1P3_knl3
0?7al@<0kno_3@3alO430>o_k`<051@D0`0C4a<301LG5`<051@D1P0F5QH301<C4`<05ADE0`0F5QH4
0?7alAh0m?Cd103alO4301HF5P<05ADE0`0C4a<301@D50<04A4A0`0F5QH30>o_k`<0m_Kf0`3`l?03
01LG5`<04Q8B1`0F5QH301<C4`<061PH0`3`l?030?Ogm`<0lO7a0`0I6AT301DE5@<061PH0`0D51@3
01PH60@0kno_0`3emOD30?;blP<05ADE0`0B4Q8301DE5@<05aLG0`3fm_H30?_kn`<071`L0`0H61P4
01LG5`<0l?3`1P3bl_8901<C4`<0j^[Z0`3Xj>P30>7Qh@<0e]KF0`3Shn<40>SXj0<03@d=0`0A4A43
01DE5@<0l?3`0`3emOD30>o_k`<04Q8B0`0?3`l3014A4@<0k>c/0`3_knl40>c/k0<051@D0`0H61P3
01XJ6P<051@D0`0F5QH60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo
00D0oooo0`0F5QH30>c/k0<0l_;b0`3_knl301<C4`<04A4A1P0C4a<30>k^kP@0lo?c0`3`l?0301HF
5P<05ADE1P0K6a/301PH60<05ADE0`0B4Q8301DE5@<04Q8B0`0D51@40?7al@<0lo?c0`3bl_830>o_
k`<0lO7a1P3_knl30?7al@<0kno_3@3alO430>o_k`<051@D0`0C4a<301LG5`<051@D1P0F5QH301<C
4`<05ADE0`0F5QH40?7alAh0m?Cd103alO4301HF5P<05ADE0`0C4a<301@D50<04A4A0`0F5QH30>o_
k`<0m_Kf0`3`l?0301LG5`<04Q8B1`0F5QH301<C4`<061PH0`3`l?030?Ogm`<0lO7a0`0I6AT301DE
5@<061PH0`0D51@301PH60@0kno_0`3emOD30?;blP<05ADE0`0B4Q8301DE5@<05aLG0`3fm_H30?_k
n`<071`L0`0H61P401LG5`<0l?3`1P3bl_8901<C4`<0j^[Z0`3Xj>P30>7Qh@<0e]KF0`3Shn<40>SX
j0<03@d=0`0A4A4301DE5@<0l?3`0`3emOD30>o_k`<04Q8B0`0?3`l3014A4@<0k>c/0`3_knl40>c/
k0<051@D0`0H61P301XJ6P<051@D0`0F5QH60?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo00D0oooo0`0C4a<301DE5@<0kNg]0`3dm?@30>k^kP<05QHF1P0A4A4301DE5@@0
k>c/0`3clo<30?3`l0<05QHF0`0H61P301TI6@H05ADE0`0D51@30>o_k`<0lO7a0`3`l?040?Cdm0<0
lO7a0`3bl_830?7al@<0l?3`0`3_knl30?3`l0<0kno_0`0D51@3018B4PX04a<C0`0E5AD301<C4`<0
5QHF0`0G5aL301HF5P<04a<C0`0D51@301DE5@<0l?3`0`3bl_840?Gem@<0lO7a1P3clo<<0?Cdm0H0
lo?c0`3bl_840?Gem@<0l_;b0`3`l?0301LG5`<04A4A0`0C4a<3014A4@<05QHF0`3_knl30?Gem@<0
kNg]0`0A4A4700l?3`<04Q8B0`3^k^h30?KfmP<0l?3`0`0I6AT301@D50<05aLG0`0E5AD301TI6@<0
l?3`103fm_H60?;blP<05QHF0`0E5AD301<C4`<061PH0`3hn?P30?KfmP<06a/K0`0G5aL401@D50<0
l_;b0`3clo<30>o_k`<05ADE0`0D51@3018B4P<0kno_0`3[jn/30=cLg0<020P80`3UiND40>[ZjP<0
4A4A0`0@4103014A4@<051@D0`3alO430?;blPH0410@0`0A4A430>_[j`<0kno_103]kNd6018B4P<0
5aLG0`0H61P301<C4`H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
1@3oool301<C4`<05ADE0`3]kNd30?Cdm0<0k^k^0`0F5QH6014A4@<05ADE103/k>`30??cl`<0l?3`
0`0F5QH301PH60<06ATI1P0E5AD301@D50<0kno_0`3alO430?3`l0@0m?Cd0`3alO430?;blP<0lO7a
0`3`l?030>o_k`<0l?3`0`3_knl301@D50<04Q8B2P0C4a<301DE5@<04a<C0`0F5QH301LG5`<05QHF
0`0C4a<301@D50<05ADE0`3`l?030?;blP@0mOGe0`3alO460??cl``0m?Cd1P3clo<30?;blP@0mOGe
0`3bl_830?3`l0<05aLG0`0A4A4301<C4`<04A4A0`0F5QH30>o_k`<0mOGe0`3]kNd3014A4@L03`l?
0`0B4Q830>k^kP<0m_Kf0`3`l?0301TI6@<051@D0`0G5aL301DE5@<06ATI0`3`l?040?KfmPH0l_;b
0`0F5QH301DE5@<04a<C0`0H61P30?Shn0<0m_Kf0`0K6a/301LG5`@051@D0`3bl_830??cl`<0kno_
0`0E5AD301@D50<04Q8B0`3_knl30>_[j`<0g=cL0`0820P30>GUi@@0j^[Z0`0A4A43010@40<04A4A
0`0D51@30?7al@<0l_;b1P0@4103014A4@<0jn_[0`3_knl40>g]k@H04Q8B0`0G5aL301PH60<04a<C
1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<04a<C0`0E
5AD30>g]k@<0m?Cd0`3^k^h301HF5PH04A4A0`0E5AD40>c/k0<0lo?c0`3`l?0301HF5P<061PH0`0I
6AT601DE5@<051@D0`3_knl30?7al@<0l?3`103dm?@30?7al@<0l_;b0`3alO430?3`l0<0kno_0`3`
l?030>o_k`<051@D0`0B4Q8:01<C4`<05ADE0`0C4a<301HF5P<05aLG0`0F5QH301<C4`<051@D0`0E
5AD30?3`l0<0l_;b103emOD30?7al@H0lo?c303dm?@60??cl`<0l_;b103emOD30?;blP<0l?3`0`0G
5aL3014A4@<04a<C0`0A4A4301HF5P<0kno_0`3emOD30>g]k@<04A4A1`0?3`l3018B4P<0k^k^0`3f
m_H30?3`l0<06ATI0`0D51@301LG5`<05ADE0`0I6AT30?3`l0@0m_Kf1P3bl_8301HF5P<05ADE0`0C
4a<301PH60<0n?Sh0`3fm_H301/K6`<05aLG100D51@30?;blP<0lo?c0`3_knl301DE5@<051@D0`0B
4Q830>o_k`<0jn_[0`3Lg=`300P820<0iNGU103Zj^X3014A4@<0410@0`0A4A4301@D50<0lO7a0`3b
l_86010@40<04A4A0`3[jn/30>o_k`@0kNg]1P0B4Q8301LG5`<061PH0`0C4a<60?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0D51@3014A4@<05ADE0`3^k^h3
0?Gem@<0kno_0`0G5aL3018B4P<0410@100A4A430>k^kP<0l?3`0`0?3`l6014A4@<05QHF1P3_knl3
0?7al@<0l_;b0`3`l?040>o_k`<051@D0`0A4A43018B4PH04A4A0`0C4a<301DE5@<051@D1P0F5QH4
01@D50<04a<C0`0D51@601DE5@<04a<C1P0D51@30>k^kP<0kno_0`3dm?@30?7al@@0kno_0`0D51@3
018B4PH04a<C1P0D51@601<C4`<04Q8B0`0D51@40?3`l0<0lO7a0`3emOD30>k^kPH04a<C1P0@4103
01DE5@<0kNg]0`3bl_8:0>_[j`<0k>c/0`3clo<30>o_k`<05aLG0`0C4a<301LG5`<051@D0`0I6AT3
0?7al@<0moOg103_knl301DE5@<05QHF0`0D51@301<C4`<06ATI0`3bl_830?Ogm`<06a/K1P0F5QH4
018B4P<0lO7a0`3`l?0301@D50<04a<C0`0D51@3014A4@<0kno_0`3[jn/300/;2`<020P80`3Xj>P4
0?7al@<0k^k^0`0D51@301<C4`<04Q8B0`3clo<30?7al@<04Q8B0`0?3`l300h>3P<04A4A0`3]kNd4
0>o_k`<0j^[Z0`0B4Q8901@D50H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool01@3oool301@D50<04A4A0`0E5AD30>k^kP<0mOGe0`3_knl301LG5`<04Q8B0`0@4104014A
4@<0k^k^0`3`l?0300l?3`H04A4A0`0F5QH60>o_k`<0lO7a0`3bl_830?3`l0@0kno_0`0D51@3014A
4@<04Q8B1P0A4A4301<C4`<05ADE0`0D51@601HF5P@051@D0`0C4a<301@D50H05ADE0`0C4a<601@D
50<0k^k^0`3_knl30?Cdm0<0lO7a103_knl301@D50<04Q8B1P0C4a<601@D50H04a<C0`0B4Q8301@D
50@0l?3`0`3alO430?Gem@<0k^k^1P0C4a<6010@40<05ADE0`3]kNd30?;blPX0jn_[0`3/k>`30??c
l`<0kno_0`0G5aL301<C4`<05aLG0`0D51@301TI6@<0lO7a0`3gmoL40>o_k`<05ADE0`0F5QH301@D
50<04a<C0`0I6AT30?;blP<0moOg0`0K6a/601HF5P@04Q8B0`3alO430?3`l0<051@D0`0C4a<301@D
50<04A4A0`3_knl30>_[j`<02`/;0`0820P30>SXj0@0lO7a0`3^k^h301@D50<04a<C0`0B4Q830??c
l`<0lO7a0`0B4Q8300l?3`<03Ph>0`0A4A430>g]k@@0kno_0`3Zj^X3018B4PT051@D1P3oool00`00
0000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<051@D0`0A4A4301DE5@<0
k^k^0`3emOD30>o_k`<05aLG0`0B4Q83010@40@04A4A0`3^k^h30?3`l0<03`l?1P0A4A4301HF5PH0
kno_0`3alO430?;blP<0l?3`103_knl301@D50<04A4A0`0B4Q86014A4@<04a<C0`0E5AD301@D50H0
5QHF100D51@301<C4`<051@D1P0E5AD301<C4`H051@D0`3^k^h30>o_k`<0m?Cd0`3alO440>o_k`<0
51@D0`0B4Q8601<C4`H051@D1P0C4a<3018B4P<051@D103`l?030?7al@<0mOGe0`3^k^h601<C4`H0
410@0`0E5AD30>g]k@<0l_;b2P3[jn/30>c/k0<0lo?c0`3_knl301LG5`<04a<C0`0G5aL301@D50<0
6ATI0`3alO430?Ogm`@0kno_0`0E5AD301HF5P<051@D0`0C4a<301TI6@<0l_;b0`3gmoL301/K6`H0
5QHF100B4Q830?7al@<0l?3`0`0D51@301<C4`<051@D0`0A4A430>o_k`<0jn_[0`0;2`/300P820<0
j>SX103alO430>k^kP<051@D0`0C4a<3018B4P<0lo?c0`3alO43018B4P<03`l?0`0>3Ph3014A4@<0
kNg]103_knl30>[ZjP<04Q8B2@0D51@60?ooo`030000003oool0oooo00D0oooo000X0?ooo`<00000
1@3oool301@D50<04Q8B0`0A4A4301DE5@<0k^k^0`3fm_H30?;blP<05ADE0`0B4Q8400l?3`<0k^k^
0`3[jn/600/;2`<03`l?0`3[jn/60?7al@H0k^k^1`0D51@301<C4`H051@D2@0C4a<301DE5@H05QHF
0`0D51@401DE5@<04Q8B1P0A4A43010@40<04Q8B1P3]kNd30?3`l0<0lO7a0`3/k>`701<C4`<04Q8B
0`0C4a<601@D50l04a<C0`0B4Q8701<C4`<0kNg]0`3dm?@30>o_k`<0k^k^0`0D51@600l?3`<04a<C
0`3Zj^X30>g]k@@0jNWY0`3Zj^X30>o_k`<0k>c/0`0F5QH3018B4P<05ADE0`0C4a<301PH60<0l?3`
0`3gmoL30?3`l0@05aLG0`0C4a<301DE5@<04a<C0`0H61P30?7al@<0n?Sh0`3dm?@301PH60<05QHF
0`0B4Q8401<C4`<0l?3`0`3bl_8301<C4`<05ADE0`0C4a<301@D50H0l?3`0`0>3Ph300`<30<0410@
103_knl30?;blP<04Q8B0`0C4a<301HF5P<0lO7a0`3emOD30>k^kP<05ADE0`0?3`l3010@40<0kNg]
103`l?030>o_k`H0k^k^1P0D51@50?ooo`8000001`3oool002P0oooo00<000000?ooo`3oool01@3o
ool301@D50<04Q8B0`0A4A4301DE5@<0k^k^0`3fm_H30?;blP<05ADE0`0B4Q8400l?3`<0k^k^0`3[
jn/600/;2`<03`l?0`3[jn/60?7al@H0k^k^1`0D51@301<C4`H051@D2@0C4a<301DE5@H05QHF0`0D
51@401DE5@<04Q8B1P0A4A43010@40<04Q8B1P3]kNd30?3`l0<0lO7a0`3/k>`701<C4`<04Q8B0`0C
4a<601@D50l04a<C0`0B4Q8701<C4`<0kNg]0`3dm?@30>o_k`<0k^k^0`0D51@600l?3`<04a<C0`3Z
j^X30>g]k@@0jNWY0`3Zj^X30>o_k`<0k>c/0`0F5QH3018B4P<05ADE0`0C4a<301PH60<0l?3`0`3g
moL30?3`l0@05aLG0`0C4a<301DE5@<04a<C0`0H61P30?7al@<0n?Sh0`3dm?@301PH60<05QHF0`0B
4Q8401<C4`<0l?3`0`3bl_8301<C4`<05ADE0`0C4a<301@D50H0l?3`0`0>3Ph300`<30<0410@103_
knl30?;blP<04Q8B0`0C4a<301HF5P<0lO7a0`3emOD30>k^kP<05ADE0`0?3`l3010@40<0kNg]103`
l?030>o_k`H0k^k^1P0D51@60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0
oooo00D0oooo0`0D51@3018B4P<04A4A0`0E5AD30>k^kP<0m_Kf0`3bl_8301DE5@<04Q8B100?3`l3
0>k^kP<0jn_[1P0;2`/300l?3`<0jn_[1P3alO460>k^kPL051@D0`0C4a<601@D50T04a<C0`0E5AD6
01HF5P<051@D100E5AD3018B4PH04A4A0`0@4103018B4PH0kNg]0`3`l?030?7al@<0k>c/1`0C4a<3
018B4P<04a<C1P0D51@?01<C4`<04Q8B1`0C4a<30>g]k@<0m?Cd0`3_knl30>k^kP<051@D1P0?3`l3
01<C4`<0j^[Z0`3]kNd40>WYj@<0j^[Z0`3_knl30>c/k0<05QHF0`0B4Q8301DE5@<04a<C0`0H61P3
0?3`l0<0moOg0`3`l?0401LG5`<04a<C0`0E5AD301<C4`<061PH0`3alO430?Shn0<0m?Cd0`0H61P3
01HF5P<04Q8B100C4a<30?3`l0<0l_;b0`0C4a<301DE5@<04a<C0`0D51@60?3`l0<03Ph>0`0<30`3
010@40@0kno_0`3bl_83018B4P<04a<C0`0F5QH30?7al@<0mOGe0`3^k^h301DE5@<03`l?0`0@4103
0>g]k@@0l?3`0`3_knl60>k^kPH051@D1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`050?ooo`<0l?3`0`0H61P3018B4P<0410@0`0C4a<30?7al@<0m?Cd0`0D51@3018B
4P@0410@0`3]kNd30>[ZjP<0iNGU0`3Xj>P30>[ZjP<0l?3`0`3^k^h30>g]k@H04a<C0`0B4Q8401@D
50<05ADE0`0C4a<301HF5PT04a<C1P0D51@3018B4P<051@D103^k^h30?3`l0T0k^k^0`3]kNd30?3`
l0<0kno_0`3`l?030>c/k0<05ADE0`0A4A4701<C4`<05QHF0`0E5AD?01@D50<05QHF1`0B4Q83010@
40<051@D0`3/k>`60?7al@<0jn_[0`0D51@3010@40<03`l?0`0A4A470>c/k0<0k^k^0`3[jn/301DE
5@<04Q8B0`0D51@301HF5P<05ADE0`3_knl30?KfmP<0l?3`0`0G5aL401<C4`<05QHF0`0C4a<301PH
60<0lO7a0`3gmoL30?;blP<06QXJ0`0E5AD301@D50<05aLG103]kNd30?Cdm0<0l?3`0`0E5AD601@D
50<0l?3`0`3emOD30?3`l0<05ADE0`0C4a<3018B4P@0lo?c0`3alO4301@D50<04Q8B0`0C4a<301PH
60<0kno_0`3emOD30>o_k`<04A4A0`0>3Ph301@D50@0kNg]0`3^k^h30?7al@<0l_;b1P3`l?060?oo
o`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3`l?0301PH60<0
4Q8B0`0@410301<C4`<0lO7a0`3dm?@301@D50<04Q8B100@41030>g]k@<0j^[Z0`3UiND30>SXj0<0
j^[Z0`3`l?030>k^kP<0kNg]1P0C4a<3018B4P@051@D0`0E5AD301<C4`<05QHF2@0C4a<601@D50<0
4Q8B0`0D51@40>k^kP<0l?3`2@3^k^h30>g]k@<0l?3`0`3_knl30?3`l0<0k>c/0`0E5AD3014A4@L0
4a<C0`0F5QH301DE5@l051@D0`0F5QH7018B4P<0410@0`0D51@30>c/k0H0lO7a0`3[jn/301@D50<0
410@0`0?3`l3014A4@L0k>c/0`3^k^h30>_[j`<05ADE0`0B4Q8301@D50<05QHF0`0E5AD30>o_k`<0
m_Kf0`3`l?0301LG5`@04a<C0`0F5QH301<C4`<061PH0`3alO430?Ogm`<0l_;b0`0J6QX301DE5@<0
51@D0`0G5aL40>g]k@<0m?Cd0`3`l?0301DE5@H051@D0`3`l?030?Gem@<0l?3`0`0E5AD301<C4`<0
4Q8B103clo<30?7al@<051@D0`0B4Q8301<C4`<061PH0`3_knl30?Gem@<0kno_0`0A4A4300h>3P<0
51@D103]kNd30>k^kP<0lO7a0`3bl_860?3`l0H0oooo00<000000?ooo`3oool01@3oool002P0oooo
00<000000?ooo`3oool01@3oool30?3`l0<061PH0`0B4Q83010@40<04a<C0`3alO430?Cdm0<051@D
0`0B4Q84010@40<0kNg]0`3Zj^X30>GUi@<0j>SX0`3Zj^X30?3`l0<0k^k^0`3]kNd601<C4`<04Q8B
100D51@301DE5@<04a<C0`0F5QH901<C4`H051@D0`0B4Q8301@D50@0k^k^0`3`l?090>k^kP<0kNg]
0`3`l?030>o_k`<0l?3`0`3/k>`301DE5@<04A4A1`0C4a<301HF5P<05ADE3`0D51@301HF5PL04Q8B
0`0@410301@D50<0k>c/1P3alO430>_[j`<051@D0`0@410300l?3`<04A4A1`3/k>`30>k^kP<0jn_[
0`0E5AD3018B4P<051@D0`0F5QH301DE5@<0kno_0`3fm_H30?3`l0<05aLG100C4a<301HF5P<04a<C
0`0H61P30?7al@<0moOg0`3bl_8301XJ6P<05ADE0`0D51@301LG5`@0kNg]0`3dm?@30?3`l0<05ADE
1P0D51@30?3`l0<0mOGe0`3`l?0301DE5@<04a<C0`0B4Q840??cl`<0lO7a0`0D51@3018B4P<04a<C
0`0H61P30>o_k`<0mOGe0`3_knl3014A4@<03Ph>0`0D51@40>g]k@<0k^k^0`3alO430?;blPH0l?3`
1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0m?Cd0`3a
lO4301HF5P<04a<C0`0A4A430??cl`<0m?Cd0`0D51@301<C4`@04A4A0`3]kNd30>WYj@<0i^KV0`3Y
jNT30>k^kP<0j^[Z0`0A4A43018B4P<0410@1P0B4Q8401DE5@<04a<C0`0D51@30?3`l0H0l_;b2@3c
lo<30?;blP<0kno_103`l?030>k^kPH0kNg]0`3_knl30>g]k@<0kno_0`3alO430?3`l0<05aLG0`0B
4Q8301<C4`@05ADE0`0F5QH30?;blP<0mOGe3`3dm?@30?7al@<05ADE100D51@3014A4@<03`l?0`0C
4a<30>_[j`<0l?3`0`3alO430>k^kP<04Q8B0`0A4A4301<C4`<0l?3`103emOD30>k^kP<05QHF0`0C
4a<601DE5@H0l_;b0`3emOD30>o_k`<05QHF0`0A4A4401@D50<04Q8B0`0G5aL30?3`l0<0moOg0`3a
lO4301TI6@<051@D0`0F5QH301DE5@<0l?3`103clo<30?3`l0<051@D1P0B4Q8301DE5@H0l_;b0`0G
5aL301HF5P<06ATI0`0H61P40?;blP<0mOGe0`3`l?0601@D50<04Q8B0`0E5AD30?;blP<0lO7a0`0C
4a<300l?3`<0410@100B4Q8301<C4`<0kno_0`3`l?030>o_k`<0m?Cd1P3oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0m?Cd0`3alO4301HF5P<04a<C0`0A4A43
0??cl`<0m?Cd0`0D51@301<C4`@04A4A0`3]kNd30>WYj@<0i^KV0`3YjNT30>k^kP<0j^[Z0`0A4A43
018B4P<0410@1P0B4Q8401DE5@<04a<C0`0D51@30?3`l0H0l_;b2@3clo<30?;blP<0kno_103`l?03
0>k^kPH0kNg]0`3_knl30>g]k@<0kno_0`3alO430?3`l0<05aLG0`0B4Q8301<C4`@05ADE0`0F5QH3
0?;blP<0mOGe3`3dm?@30?7al@<05ADE100D51@3014A4@<03`l?0`0C4a<30>_[j`<0l?3`0`3alO43
0>k^kP<04Q8B0`0A4A4301<C4`<0l?3`103emOD30>k^kP<05QHF0`0C4a<601DE5@H0l_;b0`3emOD3
0>o_k`<05QHF0`0A4A4401@D50<04Q8B0`0G5aL30?3`l0<0moOg0`3alO4301TI6@<051@D0`0F5QH3
01DE5@<0l?3`103clo<30?3`l0<051@D1P0B4Q8301DE5@H0l_;b0`0G5aL301HF5P<06ATI0`0H61P4
0?;blP<0mOGe0`3`l?0601@D50<04Q8B0`0E5AD30?;blP<0lO7a0`0C4a<300l?3`<0410@100B4Q83
01<C4`<0kno_0`3`l?030>o_k`<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`050?ooo`<0m?Cd0`3alO4301HF5P<04a<C0`0A4A430??cl`<0m?Cd0`0D51@301<C
4`@04A4A0`3]kNd30>WYj@<0i^KV0`3YjNT30>k^kP<0j^[Z0`0A4A43018B4P<0410@1P0B4Q8401DE
5@<04a<C0`0D51@30?3`l0H0l_;b2@3clo<30?;blP<0kno_103`l?030>k^kPH0kNg]0`3_knl30>g]
k@<0kno_0`3alO430?3`l0<05aLG0`0B4Q8301<C4`@05ADE0`0F5QH30?;blP<0mOGe3`3dm?@30?7a
l@<05ADE100D51@3014A4@<03`l?0`0C4a<30>_[j`<0l?3`0`3alO430>k^kP<04Q8B0`0A4A4301<C
4`<0l?3`103emOD30>k^kP<05QHF0`0C4a<601DE5@H0l_;b0`3emOD30>o_k`<05QHF0`0A4A4401@D
50<04Q8B0`0G5aL30?3`l0<0moOg0`3alO4301TI6@<051@D0`0F5QH301DE5@<0l?3`103clo<30?3`
l0<051@D1P0B4Q8301DE5@H0l_;b0`0G5aL301HF5P<06ATI0`0H61P40?;blP<0mOGe0`3`l?0601@D
50<04Q8B0`0E5AD30?;blP<0lO7a0`0C4a<300l?3`<0410@100B4Q8301<C4`<0kno_0`3`l?030>o_
k`<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<0
l?3`0`3dm?@301@D50H04a<C1P3dm?@:01@D50<0lO7a0`3^k^h30>c/k0<0jn_[0`3/k>`301@D50<0
3`l?1P0A4A4301<C4`<05ADE103`l?030?;blP<0l?3`1P3clo<30?3`l0<0l_;b1P3clo<30?;blP<0
lO7a103_knl60>k^kP<0kno_0`3^k^h301<C4`<04A4A0`0D51@301PH60H05QHF0`0E5AD=0?;blPH0
lo?c0`3dm?@30??cl`<0l_;b0`3fm_H30?;blP@0l?3`0`0F5QH300l?3`<03Ph>0`0C4a<30>_[j`<0
lO7a0`3_knl301<C4`<04A4A0`0C4a<301dM7@@0lo?c0`0M7Ad301DE5@<05aLG0`0C4a<301DE5@<0
l_;b0`3dm?@30>k^kP<05ADE0`0@4103014A4@@04a<C0`0D51@30>o_k`<0moOg0`3alO4301TI6@<0
5ADE0`0G5aL301<C4`<05ADE0`3alO440??cl`<0kno_0`0C4a<3018B4P<051@D0`3`l?030?KfmP<0
lO7a0`0H61P301dM7@<0820P0`0I6AT401PH60<0lo?c0`3bl_8301@D50<04Q8B0`0D51@301DE5@<0
lO7a0`3emOD30>k^kP<051@D0`0@4104018B4P<04a<C0`0F5QH3014A4@<0410@0`3`l?060?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3`l?030?Cdm0<051@D
1P0C4a<60?Cdm0X051@D0`3alO430>k^kP<0k>c/0`3[jn/30>c/k0<051@D0`0?3`l6014A4@<04a<C
0`0E5AD40?3`l0<0l_;b0`3`l?060??cl`<0l?3`0`3bl_860??cl`<0l_;b0`3alO440>o_k`H0k^k^
0`3_knl30>k^kP<04a<C0`0A4A4301@D50<061PH1P0F5QH301DE5@d0l_;b1P3clo<30?Cdm0<0lo?c
0`3bl_830?KfmP<0l_;b103`l?0301HF5P<03`l?0`0>3Ph301<C4`<0jn_[0`3alO430>o_k`<04a<C
0`0A4A4301<C4`<07AdM103clo<301dM7@<05ADE0`0G5aL301<C4`<05ADE0`3bl_830?Cdm0<0k^k^
0`0E5AD3010@40<04A4A100C4a<301@D50<0kno_0`3gmoL30?7al@<06ATI0`0E5AD301LG5`<04a<C
0`0E5AD30?7al@@0lo?c0`3_knl301<C4`<04Q8B0`0D51@30?3`l0<0m_Kf0`3alO4301PH60<07AdM
0`0P820301TI6@@061PH0`3clo<30?;blP<051@D0`0B4Q8301@D50<05ADE0`3alO430?Gem@<0k^k^
0`0D51@3010@40@04Q8B0`0C4a<301HF5P<04A4A0`0@41030?3`l0H0oooo00<000000?ooo`3oool0
1@3oool002P0oooo00<000000?ooo`3oool01@3oool30?3`l0<0m?Cd0`0D51@601<C4`H0m?Cd2P0D
51@30?7al@<0k^k^0`3/k>`30>_[j`<0k>c/0`0D51@300l?3`H04A4A0`0C4a<301DE5@@0l?3`0`3b
l_830?3`l0H0lo?c0`3`l?030?;blPH0lo?c0`3bl_830?7al@@0kno_1P3^k^h30>o_k`<0k^k^0`0C
4a<3014A4@<051@D0`0H61P601HF5P<05ADE3@3bl_860??cl`<0m?Cd0`3clo<30?;blP<0m_Kf0`3b
l_840?3`l0<05QHF0`0?3`l300h>3P<04a<C0`3[jn/30?7al@<0kno_0`0C4a<3014A4@<04a<C0`0M
7Ad40??cl`<07AdM0`0E5AD301LG5`<04a<C0`0E5AD30?;blP<0m?Cd0`3^k^h301DE5@<0410@0`0A
4A4401<C4`<051@D0`3_knl30?Ogm`<0lO7a0`0I6AT301DE5@<05aLG0`0C4a<301DE5@<0lO7a103c
lo<30>o_k`<04a<C0`0B4Q8301@D50<0l?3`0`3fm_H30?7al@<061PH0`0M7Ad3020P80<06ATI100H
61P30??cl`<0l_;b0`0D51@3018B4P<051@D0`0E5AD30?7al@<0mOGe0`3^k^h301@D50<0410@100B
4Q8301<C4`<05QHF0`0A4A43010@40<0l?3`1P3oool00`000000oooo0?ooo`050?ooo`00:03oool0
0`000000oooo0?ooo`050?ooo`<0lo?c0`3dm?@301@D50H04a<C1P3dm?@301DE5@<05aLG100J6QX3
0?Gem@<0m?Cd0`3_knl601<C4`H04A4A0`0C4a<301@D50<0kno_0`3alO440?Gem@<0l?3`0`3alO43
0?;blP<0kno_0`0C4a<3014A4@T04Q8B0`0A4A4:010@40<04A4A0`0D51@301<C4`<05aLG0`0I6AT3
01XJ6P<06ATI0`0C4a<301@D50@0l?3`0`3^k^h600h>3P<04A4A1P0C4a<3018B4P<05ADE0`3`l?03
0?;blP@0m_Kf0`3_knl301DE5@<03`l?0`0>3Ph301<C4`<0k>c/0`3dm?@30>k^kP<061PH0`0F5QH3
01XJ6P@08R8R0`0L71`301/K6`<05ADE0`0H61P30>o_k`<0mOGe0`3^k^h301DE5@H03`l?0`0D51@4
0>k^kP<0l?3`0`3emOD30?3`l0<06ATI0`0E5AD301PH60<051@D0`0H61P30>o_k`<0mOGe103^k^h3
01HF5P<04A4A0`0@410301@D50<0l_;b0`3clo<601PH60<08B4Q0`0S8b<301dM7@@061PH0`3alO43
0?Gem@<0k^k^0`0G5aL601<C4`<061PH0`3_knl30?Gem@<0kNg]0`0C4a<401DE5@<05QHF0`0H61P3
01@D50<04A4A0`3clo<60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo
00D0oooo0`3clo<30?Cdm0<051@D1P0C4a<60?Cdm0<05ADE0`0G5aL401XJ6P<0mOGe0`3dm?@30>o_
k`H04a<C1P0A4A4301<C4`<051@D0`3_knl30?7al@@0mOGe0`3`l?030?7al@<0l_;b0`3_knl301<C
4`<04A4A2@0B4Q83014A4@X0410@0`0A4A4301@D50<04a<C0`0G5aL301TI6@<06QXJ0`0I6AT301<C
4`<051@D103`l?030>k^kPH03Ph>0`0A4A4601<C4`<04Q8B0`0E5AD30?3`l0<0l_;b103fm_H30>o_
k`<05ADE0`0?3`l300h>3P<04a<C0`3/k>`30?Cdm0<0k^k^0`0H61P301HF5P<06QXJ100R8R8301`L
70<06a/K0`0E5AD301PH60<0kno_0`3emOD30>k^kP<05ADE1P0?3`l301@D50@0k^k^0`3`l?030?Ge
m@<0l?3`0`0I6AT301DE5@<061PH0`0D51@301PH60<0kno_0`3emOD40>k^kP<05QHF0`0A4A43010@
40<051@D0`3bl_830??cl`H061PH0`0Q8B4302<S8`<07AdM100H61P30?7al@<0mOGe0`3^k^h301LG
5`H04a<C0`0H61P30>o_k`<0mOGe0`3]kNd301<C4`@05ADE0`0F5QH301PH60<051@D0`0A4A430??c
l`H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool30??cl`<0
m?Cd0`0D51@601<C4`H0m?Cd0`0E5AD301LG5`@06QXJ0`3emOD30?Cdm0<0kno_1P0C4a<6014A4@<0
4a<C0`0D51@30>o_k`<0lO7a103emOD30?3`l0<0lO7a0`3bl_830>o_k`<04a<C0`0A4A49018B4P<0
4A4A2P0@4103014A4@<051@D0`0C4a<301LG5`<06ATI0`0J6QX301TI6@<04a<C0`0D51@40?3`l0<0
k^k^1P0>3Ph3014A4@H04a<C0`0B4Q8301DE5@<0l?3`0`3bl_840?KfmP<0kno_0`0E5AD300l?3`<0
3Ph>0`0C4a<30>c/k0<0m?Cd0`3^k^h301PH60<05QHF0`0J6QX4028R8P<071`L0`0K6a/301DE5@<0
61PH0`3_knl30?Gem@<0k^k^0`0E5AD600l?3`<051@D103^k^h30?3`l0<0mOGe0`3`l?0301TI6@<0
5ADE0`0H61P301@D50<061PH0`3_knl30?Gem@@0k^k^0`0F5QH3014A4@<0410@0`0D51@30?;blP<0
lo?c1P0H61P3024Q8@<08b<S0`0M7Ad401PH60<0lO7a0`3emOD30>k^kP<05aLG1P0C4a<301PH60<0
kno_0`3emOD30>g]k@<04a<C100E5AD301HF5P<061PH0`0D51@3014A4@<0lo?c1P3oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`H0m?Cd0`0D51@301<C4`<051@D
0`3dm?@30?Gem@<05QHF0`0K6a/401`L70<07QhN1P0I6AT601@D50<04A4A0`0F5QH30>o_k`<0l?3`
0`3dm?@30?7al@@0kno_0`0C4a<3014A4@<04Q8B0`0D51@3014A4@H04Q8B2@0A4A4:010@40<04A4A
0`0C4a<301DE5@<05aLG1P0H61P301@D50<04Q8B0`3/k>`40>o_k`<0k>c/0`0;2`/300d=3@<0410@
0`0C4a<301@D50<05ADE0`0D51@601DE5@@0kno_0`3fm_H30>o_k`<05ADE1P0?3`l301@D50<0k^k^
0`3fm_H30??cl`<06a/K0`0O7al402<S8`<08B4Q0`0J6QX301/K6`<0lO7a0`3fm_H30>o_k`<05ADE
0`0?3`l300h>3P<04a<C0`3[jn/40?7al@<0l_;b0`3^k^h301PH60<051@D0`0G5aL301DE5@<06ATI
0`3`l?030?KfmP<0kno_100G5aL6014A4@<05QHF0`3]kNd30?Gem@<0lO7a0`0H61P301`L70<0820P
0`0Z:RX301lO7`L05aLG0`3alO430??cl`<0kno_0`0D51@301DE5@<04a<C0`0G5aL30>k^kP<0lo?c
0`3_knl40?;blP<061PH0`0J6QX301PH60<051@D0`3dm?@60?ooo`030000003oool0oooo00D0oooo
000X0?ooo`030000003oool0oooo00D0oooo1P3dm?@301@D50<04a<C0`0D51@30?Cdm0<0mOGe0`0F
5QH301/K6`@071`L0`0N7Qh601TI6@H051@D0`0A4A4301HF5P<0kno_0`3`l?030?Cdm0<0lO7a103_
knl301<C4`<04A4A0`0B4Q8301@D50<04A4A1P0B4Q89014A4@X0410@0`0A4A4301<C4`<05ADE0`0G
5aL601PH60<051@D0`0B4Q830>c/k0@0kno_0`3/k>`300/;2`<03@d=0`0@410301<C4`<051@D0`0E
5AD301@D50H05ADE103_knl30?KfmP<0kno_0`0E5AD600l?3`<051@D0`3^k^h30?KfmP<0lo?c0`0K
6a/301lO7`@08b<S0`0Q8B4301XJ6P<06a/K0`3alO430?KfmP<0kno_0`0E5AD300l?3`<03Ph>0`0C
4a<30>_[j`@0lO7a0`3bl_830>k^kP<061PH0`0D51@301LG5`<05ADE0`0I6AT30?3`l0<0m_Kf0`3_
knl401LG5`H04A4A0`0F5QH30>g]k@<0mOGe0`3alO4301PH60<071`L0`0P820302XZ:P<07alO1`0G
5aL30?7al@<0lo?c0`3_knl301@D50<05ADE0`0C4a<301LG5`<0k^k^0`3clo<30>o_k`@0l_;b0`0H
61P301XJ6P<061PH0`0D51@30?Cdm0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<00000
0?ooo`3oool01@3oool60?Cdm0<051@D0`0C4a<301@D50<0m?Cd0`3emOD301HF5P<06a/K100L71`3
01hN7PH06ATI1P0D51@3014A4@<05QHF0`3_knl30?3`l0<0m?Cd0`3alO440>o_k`<04a<C0`0A4A43
018B4P<051@D0`0A4A46018B4PT04A4A2P0@4103014A4@<04a<C0`0E5AD301LG5`H061PH0`0D51@3
018B4P<0k>c/103_knl30>c/k0<02`/;0`0=3@d3010@40<04a<C0`0D51@301DE5@<051@D1P0E5AD4
0>o_k`<0m_Kf0`3_knl301DE5@H03`l?0`0D51@30>k^kP<0m_Kf0`3clo<301/K6`<07alO100S8b<3
024Q8@<06QXJ0`0K6a/30?7al@<0m_Kf0`3_knl301DE5@<03`l?0`0>3Ph301<C4`<0jn_[103alO43
0?;blP<0k^k^0`0H61P301@D50<05aLG0`0E5AD301TI6@<0l?3`0`3fm_H30>o_k`@05aLG1P0A4A43
01HF5P<0kNg]0`3emOD30?7al@<061PH0`0L71`3020P80<0:RXZ0`0O7al701LG5`<0lO7a0`3clo<3
0>o_k`<051@D0`0E5AD301<C4`<05aLG0`3^k^h30??cl`<0kno_103bl_8301PH60<06QXJ0`0H61P3
01@D50<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool3000000D0oooo1P3dm?@301@D
50<04a<C0`0D51@30?Cdm0<0mOGe0`0F5QH301/K6`@071`L0`0N7Qh601TI6@H051@D0`0A4A4301HF
5P<0kno_0`3`l?030?Cdm0<0lO7a103_knl301<C4`<04A4A0`0B4Q8301@D50<04A4A1P0B4Q89014A
4@X0410@0`0A4A4301<C4`<05ADE0`0G5aL601PH60<051@D0`0B4Q830>c/k0@0kno_0`3/k>`300/;
2`<03@d=0`0@410301<C4`<051@D0`0E5AD301@D50H05ADE103_knl30?KfmP<0kno_0`0E5AD600l?
3`<051@D0`3^k^h30?KfmP<0lo?c0`0K6a/301lO7`@08b<S0`0Q8B4301XJ6P<06a/K0`3alO430?Kf
mP<0kno_0`0E5AD300l?3`<03Ph>0`0C4a<30>_[j`@0lO7a0`3bl_830>k^kP<061PH0`0D51@301LG
5`<05ADE0`0I6AT30?3`l0<0m_Kf0`3_knl401LG5`H04A4A0`0F5QH30>g]k@<0mOGe0`3alO4301PH
60<071`L0`0P820302XZ:P<07alO1`0G5aL30?7al@<0lo?c0`3_knl301@D50<05ADE0`0C4a<301LG
5`<0k^k^0`3clo<30>o_k`@0l_;b0`0H61P301XJ6P<061PH0`0D51@30?Cdm0D0oooo0P0000070?oo
o`00:03oool00`000000oooo0?ooo`050?ooo`H0m?Cd0`0D51@601<C4`H0m?Cd0`0F5QH301`L70@0
8b<S0`0R8R8301hN7P<06a/K0`0G5aL3018B4P<05QHF0`3^k^h60??cl`<0kNg]1`0C4a<3014A4@<0
4Q8B0`0C4a<3018B4P<04A4A0`0D51@3014A4@<0410@4`0?3`l3010@40<04A4A2@0B4Q8300l?3`<0
3Ph>0`3Zj^X40>c/k0<0jNWY0`0=3@d300h>3P<04A4A0`0C4a<301HF5P<051@D1P0G5aL301<C4`@0
61PH0`3`l?030?KfmP<0kno_0`0G5aL3014A4@<0410@0`0C4a<30?;blP<0m_Kf0`0J6QX3020P80@0
9RHV0`0P820301XJ6P<0lo?c0`3gmoL30>o_k`<05QHF0`0A4A43010@40<051@D0`3[jn/30>o_k`@0
l?3`0`3/k>`301HF5P<051@D0`0G5aL301DE5@<06ATI0`3alO430?Ogm`<0l?3`0`0G5aL4018B4P<0
51@D0`0C4a<30>o_k`<0lo?c0`3alO4601LG5`<071`L0`0/;2`30?_kn`<09BDU100K6a/301PH60<0
l?3`0`3clo<30>o_k`<04a<C0`0B4Q8301HF5P<04Q8B0`0C4a<30>k^kP<0l?3`103alO4301<C4`<0
61PH0`0I6AT301DE5@<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`050?ooo`H0m?Cd0`0D51@601<C4`H0m?Cd0`0F5QH301`L70@08b<S0`0R8R8301hN7P<06a/K
0`0G5aL3018B4P<05QHF0`3^k^h60??cl`<0kNg]1`0C4a<3014A4@<04Q8B0`0C4a<3018B4P<04A4A
0`0D51@3014A4@<0410@4`0?3`l3010@40<04A4A2@0B4Q8300l?3`<03Ph>0`3Zj^X40>c/k0<0jNWY
0`0=3@d300h>3P<04A4A0`0C4a<301HF5P<051@D1P0G5aL301<C4`@061PH0`3`l?030?KfmP<0kno_
0`0G5aL3014A4@<0410@0`0C4a<30?;blP<0m_Kf0`0J6QX3020P80@09RHV0`0P820301XJ6P<0lo?c
0`3gmoL30>o_k`<05QHF0`0A4A43010@40<051@D0`3[jn/30>o_k`@0l?3`0`3/k>`301HF5P<051@D
0`0G5aL301DE5@<06ATI0`3alO430?Ogm`<0l?3`0`0G5aL4018B4P<051@D0`0C4a<30>o_k`<0lo?c
0`3alO4601LG5`<071`L0`0/;2`30?_kn`<09BDU100K6a/301PH60<0l?3`0`3clo<30>o_k`<04a<C
0`0B4Q8301HF5P<04Q8B0`0C4a<30>k^kP<0l?3`103alO4301<C4`<061PH0`0I6AT301DE5@<0m?Cd
1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`H0m?Cd0`0D
51@601<C4`H0m?Cd0`0F5QH301`L70@08b<S0`0R8R8301hN7P<06a/K0`0G5aL3018B4P<05QHF0`3^
k^h60??cl`<0kNg]1`0C4a<3014A4@<04Q8B0`0C4a<3018B4P<04A4A0`0D51@3014A4@<0410@4`0?
3`l3010@40<04A4A2@0B4Q8300l?3`<03Ph>0`3Zj^X40>c/k0<0jNWY0`0=3@d300h>3P<04A4A0`0C
4a<301HF5P<051@D1P0G5aL301<C4`@061PH0`3`l?030?KfmP<0kno_0`0G5aL3014A4@<0410@0`0C
4a<30?;blP<0m_Kf0`0J6QX3020P80@09RHV0`0P820301XJ6P<0lo?c0`3gmoL30>o_k`<05QHF0`0A
4A43010@40<051@D0`3[jn/30>o_k`@0l?3`0`3/k>`301HF5P<051@D0`0G5aL301DE5@<06ATI0`3a
lO430?Ogm`<0l?3`0`0G5aL4018B4P<051@D0`0C4a<30>o_k`<0lo?c0`3alO4601LG5`<071`L0`0/
;2`30?_kn`<09BDU100K6a/301PH60<0l?3`0`3clo<30>o_k`<04a<C0`0B4Q8301HF5P<04Q8B0`0C
4a<30>k^kP<0l?3`103alO4301<C4`<061PH0`0I6AT301DE5@<0m?Cd1P3oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`H0m?Cd2@0C4a<30??cl`<0l_;b0`0C4a<3
01XJ6P@08R8R0`0S8b<301hN7P<05aLG0`0F5QH301@D50<0k^k^0`3dm?@30?3`l0<0kno_0`0F5QH3
010@40L04Q8B0`0E5AD301<C4`<04A4A0`0C4a<30>g]k@<0kno_0`3]kNd30>c/k100jn_[0`3/k>`6
0>g]k@<0k^k^0`3_knl30>k^kP<0jn_[0`3]kNd40>SXj0<0k>c/0`3_knl30?7al@H0l_;b0`3`l?03
01DE5@<05QHF0`0E5AD301LG5`@04a<C0`0G5aL30>o_k`<0m_Kf0`3bl_8301HF5P<04a<C0`0B4Q83
0??cl`<0mOGe0`0I6AT3020P80@092@T0`0K6a/301XJ6P<0m?Cd0`3clo<301DE5@<04Q8B1P0C4a<3
0>k^kPH0l?3`103[jn/301DE5@<04a<C0`0G5aL301@D50<06ATI0`3alO430?Ogm`<0l?3`0`0H61P3
01<C4`@05ADE0`0A4A4301<C4`<0l?3`0`3clo<30?7al@<061PH0`0K6a/302<S8`<0o?cl0oooool3
02<S8`@07alO1P0H61P30>c/k0<0lO7a0`3/k>`301HF5P<051@D0`0F5QH301@D50<0kNg]0`3_knl4
0>c/k0<04a<C0`0D51@301LG5`<05ADE0`3dm?@60?ooo`030000003oool0oooo00D0oooo000X0?oo
o`030000003oool0oooo00D0oooo1P3dm?@901<C4`<0lo?c0`3bl_8301<C4`<06QXJ100R8R8302<S
8`<07QhN0`0G5aL301HF5P<051@D0`3^k^h30?Cdm0<0l?3`0`3_knl301HF5P<0410@1`0B4Q8301DE
5@<04a<C0`0A4A4301<C4`<0kNg]0`3_knl30>g]k@<0k>c/403[jn/30>c/k0H0kNg]0`3^k^h30>o_
k`<0k^k^0`3[jn/30>g]k@@0j>SX0`3/k>`30>o_k`<0lO7a1P3bl_830?3`l0<05ADE0`0F5QH301DE
5@<05aLG100C4a<301LG5`<0kno_0`3fm_H30?;blP<05QHF0`0C4a<3018B4P<0lo?c0`3emOD301TI
6@<0820P100T92@301/K6`<06QXJ0`3dm?@30??cl`<05ADE0`0B4Q8601<C4`<0k^k^1P3`l?040>_[
j`<05ADE0`0C4a<301LG5`<051@D0`0I6AT30?7al@<0moOg0`3`l?0301PH60<04a<C100E5AD3014A
4@<04a<C0`3`l?030??cl`<0lO7a0`0H61P301/K6`<08b<S0`3lo?`3ooooo`<08b<S100O7al601PH
60<0k>c/0`3alO430>c/k0<05QHF0`0D51@301HF5P<051@D0`3]kNd30>o_k`@0k>c/0`0C4a<301@D
50<05aLG0`0E5AD30?Cdm0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool01@3oool60?Cdm0T04a<C0`3clo<30?;blP<04a<C0`0J6QX4028R8P<08b<S0`0N7Qh301LG5`<0
5QHF0`0D51@30>k^kP<0m?Cd0`3`l?030>o_k`<05QHF0`0@4107018B4P<05ADE0`0C4a<3014A4@<0
4a<C0`3]kNd30>o_k`<0kNg]0`3/k>`@0>_[j`<0k>c/1P3]kNd30>k^kP<0kno_0`3^k^h30>_[j`<0
kNg]103Xj>P30>c/k0<0kno_0`3alO460?;blP<0l?3`0`0E5AD301HF5P<05ADE0`0G5aL401<C4`<0
5aLG0`3_knl30?KfmP<0l_;b0`0F5QH301<C4`<04Q8B0`3clo<30?Gem@<06ATI0`0P820402@T90<0
6a/K0`0J6QX30?Cdm0<0lo?c0`0E5AD3018B4PH04a<C0`3^k^h60?3`l0@0jn_[0`0E5AD301<C4`<0
5aLG0`0D51@301TI6@<0lO7a0`3gmoL30?3`l0<061PH0`0C4a<401DE5@<04A4A0`0C4a<30?3`l0<0
lo?c0`3alO4301PH60<06a/K0`0S8b<30?clo0?ooooo0`0S8b<401lO7`H061PH0`3/k>`30?7al@<0
k>c/0`0F5QH301@D50<05QHF0`0D51@30>g]k@<0kno_103/k>`301<C4`<051@D0`0G5aL301DE5@<0
m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`H0m?Cd
1P0C4a<3018B4P<0lO7a0`3_knl301<C4`<051@D100K6a/301XJ6P<05ADE0`0I6AT30?3`l0<0lO7a
0`3dm?@30>k^kPH051@D1P0A4A4401<C4`<051@D0`3`l?030??cl`<0lO7a0`3_knl30?3`l0<0kNg]
1P3[jn/C0>[ZjP<0jn_[0`3/k>`30>k^kP<0jn_[2@3/k>`400`<30<0410@0`3`l?030??cl`<0lO7a
0`3clo<30?;blPH0l?3`0`0H61P301@D50@05QHF0`0A4A4301<C4`<0l_;b0`3dm?@301DE5@<051@D
0`0C4a<30?Cdm0<0mOGe0`0I6AT301lO7`@08B4Q0`0M7Ad30?Cdm0<0moOg0`3alO4301DE5@<051@D
0`0A4A4301<C4`<0kno_0`3alO430>_[j`@051@D0`0B4Q8301HF5P<051@D0`0I6AT30?7al@<0moOg
0`3`l?0301LG5`<04Q8B0`0E5AD4014A4@<051@D0`3/k>`30??cl`<0k^k^1P0I6AT301lO7`<09RHV
1P3moOd302HV9P@08R8R0`0M7Ad3018B4P<0410@0`3[jn/30?3`l0<0kno_0`0F5QH301LG5`<04a<C
0`0B4Q830>_[j`L0k^k^1P0E5AD301@D50<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`050?ooo`H0m?Cd1P0C4a<3018B4P<0lO7a0`3_knl301<C4`<051@D100K
6a/301XJ6P<05ADE0`0I6AT30?3`l0<0lO7a0`3dm?@30>k^kPH051@D1P0A4A4401<C4`<051@D0`3`
l?030??cl`<0lO7a0`3_knl30?3`l0<0kNg]1P3[jn/C0>[ZjP<0jn_[0`3/k>`30>k^kP<0jn_[2@3/
k>`400`<30<0410@0`3`l?030??cl`<0lO7a0`3clo<30?;blPH0l?3`0`0H61P301@D50@05QHF0`0A
4A4301<C4`<0l_;b0`3dm?@301DE5@<051@D0`0C4a<30?Cdm0<0mOGe0`0I6AT301lO7`@08B4Q0`0M
7Ad30?Cdm0<0moOg0`3alO4301DE5@<051@D0`0A4A4301<C4`<0kno_0`3alO430>_[j`@051@D0`0B
4Q8301HF5P<051@D0`0I6AT30?7al@<0moOg0`3`l?0301LG5`<04Q8B0`0E5AD4014A4@<051@D0`3/
k>`30??cl`<0k^k^1P0I6AT301lO7`<09RHV1P3moOd302HV9P@08R8R0`0M7Ad3018B4P<0410@0`3[
jn/30?3`l0<0kno_0`0F5QH301LG5`<04a<C0`0B4Q830>_[j`L0k^k^1P0E5AD301@D50<0m?Cd1P3o
ool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`H0m?Cd1P0C4a<3
018B4P<0lO7a0`3_knl301<C4`<051@D100K6a/301XJ6P<05ADE0`0I6AT30?3`l0<0lO7a0`3dm?@3
0>k^kPH051@D1P0A4A4401<C4`<051@D0`3`l?030??cl`<0lO7a0`3_knl30?3`l0<0kNg]1P3[jn/C
0>[ZjP<0jn_[0`3/k>`30>k^kP<0jn_[2@3/k>`400`<30<0410@0`3`l?030??cl`<0lO7a0`3clo<3
0?;blPH0l?3`0`0H61P301@D50@05QHF0`0A4A4301<C4`<0l_;b0`3dm?@301DE5@<051@D0`0C4a<3
0?Cdm0<0mOGe0`0I6AT301lO7`@08B4Q0`0M7Ad30?Cdm0<0moOg0`3alO4301DE5@<051@D0`0A4A43
01<C4`<0kno_0`3alO430>_[j`@051@D0`0B4Q8301HF5P<051@D0`0I6AT30?7al@<0moOg0`3`l?03
01LG5`<04Q8B0`0E5AD4014A4@<051@D0`3/k>`30??cl`<0k^k^1P0I6AT301lO7`<09RHV1P3moOd3
02HV9P@08R8R0`0M7Ad3018B4P<0410@0`3[jn/30?3`l0<0kno_0`0F5QH301LG5`<04a<C0`0B4Q83
0>_[j`L0k^k^1P0E5AD301@D50<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`050?ooo`H0m?Cd0`0C4a<3018B4P<04A4A0`3^k^h30>o_k`<0j^[Z1`0?3`l601@D
50<0kNg]1P3clo<30>k^kP<05QHF0`0B4Q8301@D50<04A4A0`0F5QH40>o_k`<0l?3`0`3dm?@30?7a
l@<0l_;b0`3alO430>o_k`<0kNg]2@3/k>`C0>_[j`<0k>c/0`3YjNT300d=3@<02@T90`0=3@d30>o_
k`L04A4A0`0H61P301HF5P<05aLG1P3`l?030??cl`<0m?Cd0`3_knl301LG5`L04Q8B0`0@41030??c
l`<0m?Cd2@0D51@30?Gem@<0m_Kf0`0H61P701hN7P<06QXJ0`3fm_H30??cl`<05ADE0`0B4Q8301<C
4`<05aLG0`3]kNd30??cl`<0jn_[0`0C4a<4010@40<04a<C0`0B4Q8301PH60<0l?3`0`3gmoL30?3`
l0<05QHF0`0A4A43018B4P<03`l?100B4Q830>[ZjP<0l?3`0`3Zj^X601@D50<07AdM0`0R8R83024Q
8@H09BDU0`0P8204028R8P<071`L0`0B4Q8300/;2`<0j>SX0`3[jn/30>k^kP<04Q8B0`0F5QH301DE
5@<0410@1`3/k>`30>o_k`<04Q8B0`0C4a<301@D50<0m?Cd1P3oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`050?ooo`H0m?Cd0`0C4a<3018B4P<04A4A0`3^k^h30>o_k`<0
j^[Z1`0?3`l601@D50<0kNg]1P3clo<30>k^kP<05QHF0`0B4Q8301@D50<04A4A0`0F5QH40>o_k`<0
l?3`0`3dm?@30?7al@<0l_;b0`3alO430>o_k`<0kNg]2@3/k>`C0>_[j`<0k>c/0`3YjNT300d=3@<0
2@T90`0=3@d30>o_k`L04A4A0`0H61P301HF5P<05aLG1P3`l?030??cl`<0m?Cd0`3_knl301LG5`L0
4Q8B0`0@41030??cl`<0m?Cd2@0D51@30?Gem@<0m_Kf0`0H61P701hN7P<06QXJ0`3fm_H30??cl`<0
5ADE0`0B4Q8301<C4`<05aLG0`3]kNd30??cl`<0jn_[0`0C4a<4010@40<04a<C0`0B4Q8301PH60<0
l?3`0`3gmoL30?3`l0<05QHF0`0A4A43018B4P<03`l?100B4Q830>[ZjP<0l?3`0`3Zj^X601@D50<0
7AdM0`0R8R83024Q8@H09BDU0`0P8204028R8P<071`L0`0B4Q8300/;2`<0j>SX0`3[jn/30>k^kP<0
4Q8B0`0F5QH301DE5@<0410@1`3/k>`30>o_k`<04Q8B0`0C4a<301@D50<0m?Cd1P3oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`H0m?Cd0`0C4a<3018B4P<04A4A
0`3^k^h30>o_k`<0j^[Z1`0?3`l601@D50<0kNg]1P3clo<30>k^kP<05QHF0`0B4Q8301@D50<04A4A
0`0F5QH40>o_k`<0l?3`0`3dm?@30?7al@<0l_;b0`3alO430>o_k`<0kNg]2@3/k>`C0>_[j`<0k>c/
0`3YjNT300d=3@<02@T90`0=3@d30>o_k`L04A4A0`0H61P301HF5P<05aLG1P3`l?030??cl`<0m?Cd
0`3_knl301LG5`L04Q8B0`0@41030??cl`<0m?Cd2@0D51@30?Gem@<0m_Kf0`0H61P701hN7P<06QXJ
0`3fm_H30??cl`<05ADE0`0B4Q8301<C4`<05aLG0`3]kNd30??cl`<0jn_[0`0C4a<4010@40<04a<C
0`0B4Q8301PH60<0l?3`0`3gmoL30?3`l0<05QHF0`0A4A43018B4P<03`l?100B4Q830>[ZjP<0l?3`
0`3Zj^X601@D50<07AdM0`0R8R83024Q8@H09BDU0`0P8204028R8P<071`L0`0B4Q8300/;2`<0j>SX
0`3[jn/30>k^kP<04Q8B0`0F5QH301DE5@<0410@1`3/k>`30>o_k`<04Q8B0`0C4a<301@D50<0m?Cd
1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`H0m?Cd0`0C
4a<3018B4P<0410@0`3/k>`30>WYj@<0i^KV0`0:2PX400d=3@<0jn_[0`3^k^h30??cl`<0l?3`0`3_
knl301LG5`<04a<C0`0E5AD301<C4`<05aLG0`3^k^h40?Cdm0<0lo?c0`3^k^h301@D50H04Q8B0`0A
4A46010@41003`l?1P0>3Ph300d=3@<030`<0`0=3@d300T92@<030`<0`0A4A430?Cdm0@06ATI0`0L
71`3020P80<07QhN0`0J6QX301TI6@<061PH0`3alO430?;blP<0mOGe0`3_knl401DE5@<03@d=0`0?
3`l30??cl`<0mOGe0`0E5AD601@D50<0m?Cd0`3fm_H301PH60<07AdM100N7Qh301TI6@<0m_Kf0`3d
m?@3018B4P<051@D0`0F5QH30?7al@<0m?Cd0`3[jn/3018B4P<03Ph>100@410301@D50<05ADE0`3`
l?030?Ogm`<0l?3`0`0G5aL6010@40<04A4A0`0?3`l40>GUi@<0j^[Z0`3UiND600/;2`<051@D0`0J
6QX601dM7@<071`L0`0K6a/301`L70@06QXJ0`0D51@3014A4@<02`/;0`3Shn<30>OWi`<0j^[Z0`0D
51@301DE5@<05QHF0`0A4A430>c/k0@0jn_[0`3]kNd3010@40<04Q8B0`0C4a<30?Cdm0H0oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool60?Cdm0<04a<C0`0B4Q83
010@40<0k>c/0`3YjNT30>KViP<02PX:100=3@d30>_[j`<0k^k^0`3clo<30?3`l0<0kno_0`0G5aL3
01<C4`<05ADE0`0C4a<301LG5`<0k^k^103dm?@30??cl`<0k^k^0`0D51@6018B4P<04A4A1P0@410@
00l?3`H03Ph>0`0=3@d300`<30<03@d=0`092@T300`<30<04A4A0`3dm?@401TI6@<071`L0`0P8203
01hN7P<06QXJ0`0I6AT301PH60<0lO7a0`3bl_830?Gem@<0kno_100E5AD300d=3@<03`l?0`3clo<3
0?Gem@<05ADE1P0D51@30?Cdm0<0m_Kf0`0H61P301dM7@@07QhN0`0I6AT30?KfmP<0m?Cd0`0B4Q83
01@D50<05QHF0`3alO430?Cdm0<0jn_[0`0B4Q8300h>3P@0410@0`0D51@301DE5@<0l?3`0`3gmoL3
0?3`l0<05aLG1P0@4103014A4@<03`l?103UiND30>[ZjP<0iNGU1P0;2`/301@D50<06QXJ1P0M7Ad3
01`L70<06a/K0`0L71`401XJ6P<051@D0`0A4A4300/;2`<0hn?S0`3WinL30>[ZjP<051@D0`0E5AD3
01HF5P<04A4A0`3/k>`40>_[j`<0kNg]0`0@4103018B4P<04a<C0`3dm?@60?ooo`030000003oool0
oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo1P3dm?@301<C4`<04Q8B0`0@41030>c/
k0<0jNWY0`3Vi^H300X:2P@03@d=0`3[jn/30>k^kP<0lo?c0`3`l?030>o_k`<05aLG0`0C4a<301DE
5@<04a<C0`0G5aL30>k^kP@0m?Cd0`3clo<30>k^kP<051@D1P0B4Q83014A4@H0410@400?3`l600h>
3P<03@d=0`0<30`300d=3@<02@T90`0<30`3014A4@<0m?Cd100I6AT301`L70<0820P0`0N7Qh301XJ
6P<06ATI0`0H61P30?7al@<0l_;b0`3emOD30>o_k`@05ADE0`0=3@d300l?3`<0lo?c0`3emOD301DE
5@H051@D0`3dm?@30?KfmP<061PH0`0M7Ad401hN7P<06ATI0`3fm_H30?Cdm0<04Q8B0`0D51@301HF
5P<0lO7a0`3dm?@30>_[j`<04Q8B0`0>3Ph4010@40<051@D0`0E5AD30?3`l0<0moOg0`3`l?0301LG
5`H0410@0`0A4A4300l?3`@0iNGU0`3Zj^X30>GUi@H02`/;0`0D51@301XJ6PH07AdM0`0L71`301/K
6`<071`L100J6QX301@D50<04A4A0`0;2`/30>?Sh`<0inOW0`3Zj^X301@D50<05ADE0`0F5QH3014A
4@<0k>c/103[jn/30>g]k@<0410@0`0B4Q8301<C4`<0m?Cd1P3oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`050?ooo`H0m?Cd0`0C4a<3018B4P<0410@0`3/k>`30>OWi`<0
iNGU0`3Shn<40>OWi`<0k^k^0`3alO430>c/k0<04a<C0`0D51@301<C4`<05ADE0`0B4Q8301LG5`<0
kno_0`3emOD40?7al@<0l?3`0`0H61P301<C4`H05QHF0`0D51@6018B4Q004A4A0`0@410300l?3`<0
30`<0`0>3Ph300`<30<0410@0`3^k^h30?Gem@<0m_Kf100O7al302@T90<0;2`/0`0];Bd302PX:0<0
8R8R0`0J6QX301TI6@<05aLG0`3`l?030?Ogm`@0k^k^1P0A4A460?Cdm0<061PH0`0D51@301<C4`<0
m?Cd0`3fm_H301TI6@<07QhN100M7Ad301PH60<0mOGe0`3dm?@301<C4`<051@D0`0E5AD30?Cdm0<0
kno_0`0>3Ph300X:2P<03@d=100E5AD30?3`l0<0lo?c0`3gmoL30?7al@<061PH0`0A4A43010@40<0
51@D0`3Zj^X30>KViP@0i>CT0`3Ph>030=kNgP<01`L70`0;2`/3014A4@<05ADE0`0G5aL601PH60<0
5aLG0`0F5QH401@D50<04a<C0`3[jn/30>OWi`H0iNGU0`3_knl30>k^kP<06a/K0`0F5QH3014A4@<0
kNg]103[jn/30>c/k0<0410@0`0B4Q8301<C4`<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00
:03oool00`000000oooo0?ooo`050?ooo`H0m?Cd0`0C4a<3018B4P<0410@0`3/k>`30>OWi`<0iNGU
0`3Shn<40>OWi`<0k^k^0`3alO430>c/k0<04a<C0`0D51@301<C4`<05ADE0`0B4Q8301LG5`<0kno_
0`3emOD40?7al@<0l?3`0`0H61P301<C4`H05QHF0`0D51@6018B4Q004A4A0`0@410300l?3`<030`<
0`0>3Ph300`<30<0410@0`3^k^h30?Gem@<0m_Kf100O7al302@T90<0;2`/0`0];Bd302PX:0<08R8R
0`0J6QX301TI6@<05aLG0`3`l?030?Ogm`@0k^k^1P0A4A460?Cdm0<061PH0`0D51@301<C4`<0m?Cd
0`3fm_H301TI6@<07QhN100M7Ad301PH60<0mOGe0`3dm?@301<C4`<051@D0`0E5AD30?Cdm0<0kno_
0`0>3Ph300X:2P<03@d=100E5AD30?3`l0<0lo?c0`3gmoL30?7al@<061PH0`0A4A43010@40<051@D
0`3Zj^X30>KViP@0i>CT0`3Ph>030=kNgP<01`L70`0;2`/3014A4@<05ADE0`0G5aL601PH60<05aLG
0`0F5QH401@D50<04a<C0`3[jn/30>OWi`H0iNGU0`3_knl30>k^kP<06a/K0`0F5QH3014A4@<0kNg]
103[jn/30>c/k0<0410@0`0B4Q8301<C4`<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`050?ooo`H0m?Cd0`0C4a<3018B4P<0410@0`3/k>`30>OWi`<0iNGU0`3S
hn<40>OWi`<0k^k^0`3alO430>c/k0<04a<C0`0D51@301<C4`<05ADE0`0B4Q8301LG5`<0kno_0`3e
mOD40?7al@<0l?3`0`0H61P301<C4`H05QHF0`0D51@6018B4Q004A4A0`0@410300l?3`<030`<0`0>
3Ph300`<30<0410@0`3^k^h30?Gem@<0m_Kf100O7al302@T90<0;2`/0`0];Bd302PX:0<08R8R0`0J
6QX301TI6@<05aLG0`3`l?030?Ogm`@0k^k^1P0A4A460?Cdm0<061PH0`0D51@301<C4`<0m?Cd0`3f
m_H301TI6@<07QhN100M7Ad301PH60<0mOGe0`3dm?@301<C4`<051@D0`0E5AD30?Cdm0<0kno_0`0>
3Ph300X:2P<03@d=100E5AD30?3`l0<0lo?c0`3gmoL30?7al@<061PH0`0A4A43010@40<051@D0`3Z
j^X30>KViP@0i>CT0`3Ph>030=kNgP<01`L70`0;2`/3014A4@<05ADE0`0G5aL601PH60<05aLG0`0F
5QH401@D50<04a<C0`3[jn/30>OWi`H0iNGU0`3_knl30>k^kP<06a/K0`0F5QH3014A4@<0kNg]103[
jn/30>c/k0<0410@0`0B4Q8301<C4`<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool3
000000D0oooo1P3dm?@601@D50<04a<C0`3_knl30>WYj@<0i^KV0`3Xj>P40>g]k@<0k>c/0`3]kNd3
01DE5@<04A4A0`0D51@301<C4`H05ADE0`3_knl30?KfmP<0kno_100E5AD601HF5P<06ATI0`0H61P3
01DE5@<05QHF0`0C4a<C018B4P<04A4A0`0?3`l3014A4@<0kNg]1P3`l?030?KfmP<0l_;b0`0O7al4
01hN7P<0:b/[0`0f=SH303dm?@<0=cLg0`0_;bl302PX:0<08B4Q0`0H61P301`L70<0l_;b103gmoL3
0??cl`<0m?Cd0`3clo<301/K6`<05ADE0`0C4a<301DE5@<0lo?c0`3fm_H301XJ6PL07QhN0`0H61P3
0?Gem@<0m?Cd0`0C4a<301@D50<05ADE0`3dm?@30>o_k`<03@d=0`0;2`/3010@40@0k^k^0`3fm_H6
0??cl`<06a/K0`0E5AD301@D50<05aLG1P3[jn/30>;RhP@0fm_K0`3IfMT30>3Ph0<0i>CT0`3/k>`3
0?7al@<0m?Cd0`3emOD60?KfmPH0mOGe103clo<60>o_k`<0j^[Z0`3WinL30>[ZjP<0k^k^0`0H61P6
01LG5`<04Q8B0`3]kNd40>_[j`<0k>c/0`0?3`l3018B4P<04a<C0`3dm?@50?ooo`8000001`3oool0
02P0oooo00<000000?ooo`3oool01@3oool60?Cdm0H051@D0`0C4a<30>o_k`<0jNWY0`3Vi^H30>SX
j0@0kNg]0`3/k>`30>g]k@<05ADE0`0A4A4301@D50<04a<C1P0E5AD30>o_k`<0m_Kf0`3_knl401DE
5@H05QHF0`0I6AT301PH60<05ADE0`0F5QH301<C4a<04Q8B0`0A4A4300l?3`<04A4A0`3]kNd60?3`
l0<0m_Kf0`3bl_8301lO7`@07QhN0`0[:b/303Hf=P<0?Cdm0`0g=cL302l_;`<0:2PX0`0Q8B4301PH
60<071`L0`3bl_840?Ogm`<0lo?c0`3dm?@30??cl`<06a/K0`0E5AD301<C4`<05ADE0`3clo<30?Kf
mP<06QXJ1`0N7Qh301PH60<0mOGe0`3dm?@301<C4`<051@D0`0E5AD30?Cdm0<0kno_0`0=3@d300/;
2`<0410@103^k^h30?KfmPH0lo?c0`0K6a/301DE5@<051@D0`0G5aL60>_[j`<0h^;R103Kfm/30=WI
f@<0h>3P0`3Ti>@30>c/k0<0lO7a0`3dm?@30?Gem@H0m_Kf1P3emOD40??cl`H0kno_0`3Zj^X30>OW
i`<0j^[Z0`3^k^h301PH60H05aLG0`0B4Q830>g]k@@0jn_[0`3/k>`300l?3`<04Q8B0`0C4a<30?Cd
m0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool60?Cdm0H0
51@D0`0C4a<30>o_k`<0jNWY0`3Vi^H30>SXj0@0kNg]0`3/k>`30>g]k@<05ADE0`0A4A4301@D50<0
4a<C1P0E5AD30>o_k`<0m_Kf0`3_knl401DE5@H05QHF0`0I6AT301PH60<05ADE0`0F5QH301<C4a<0
4Q8B0`0A4A4300l?3`<04A4A0`3]kNd60?3`l0<0m_Kf0`3bl_8301lO7`@07QhN0`0[:b/303Hf=P<0
?Cdm0`0g=cL302l_;`<0:2PX0`0Q8B4301PH60<071`L0`3bl_840?Ogm`<0lo?c0`3dm?@30??cl`<0
6a/K0`0E5AD301<C4`<05ADE0`3clo<30?KfmP<06QXJ1`0N7Qh301PH60<0mOGe0`3dm?@301<C4`<0
51@D0`0E5AD30?Cdm0<0kno_0`0=3@d300/;2`<0410@103^k^h30?KfmPH0lo?c0`0K6a/301DE5@<0
51@D0`0G5aL60>_[j`<0h^;R103Kfm/30=WIf@<0h>3P0`3Ti>@30>c/k0<0lO7a0`3dm?@30?Gem@H0
m_Kf1P3emOD40??cl`H0kno_0`3Zj^X30>OWi`<0j^[Z0`3^k^h301PH60H05aLG0`0B4Q830>g]k@@0
jn_[0`3/k>`300l?3`<04Q8B0`0C4a<30?Cdm0H0oooo00<000000?ooo`3oool01@3oool002P0oooo
00<000000?ooo`3oool01@3oool60?Cdm0<05ADE0`0F5QH301LG5`<0lO7a0`3bl_830>_[j`<0kNg]
103/k>`9018B4P<051@D0`0B4Q8301PH60<0lO7a0`3clo<30?KfmP<0l?3`0`0H61P401<C4`H05aLG
0`0E5AD601HF5P<0l?3`1P3bl_8@0??cl`<0l_;b0`3alO430>o_k`<0lo?c0`3`l?030?;blP<0lO7a
0`0J6QX301PH60@08R8R0`0[:b/3034a<@H0=3@d0`0b<S83030`<0<0;2`/0`0T92@301/K6`<07alO
103emOD30?Ogm`<0mOGe0`0K6a/301@D50H05ADE0`3alO430?Ogm`<0m?Cd0`0M7Ad3024Q8@@07QhN
0`0H61P30?Gem@<0lo?c0`0B4Q8301@D50<061PH0`3clo<30?Gem@<0kno_0`3`l?030?7al@@0m_Kf
0`3`l?0301PH60H06QXJ1P0L71`30?Cdm0<0l_;b0`3Zj^X30>?Sh`@0gmoO0`3Ph>030>CTi0<0jn_[
0`3]kNd30?;blP<0m?Cd0`3emOD60?KfmPH0mOGe103clo<30?7al@<0kno_0`3]kNd30>c/k0<0l?3`
0`3bl_8301TI6@<06a/K0`0H61P3018B4P<0k>c/103Zj^X30>c/k0<03`l?0`0A4A4301<C4`<0m?Cd
1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`H0m?Cd0`0E
5AD301HF5P<05aLG0`3alO430?;blP<0jn_[0`3]kNd40>c/k0T04Q8B0`0D51@3018B4P<061PH0`3a
lO430??cl`<0m_Kf0`3`l?0301PH60@04a<C1P0G5aL301DE5@H05QHF0`3`l?060?;blQ00lo?c0`3b
l_830?7al@<0kno_0`3clo<30?3`l0<0l_;b0`3alO4301XJ6P<061PH100R8R8302/[:`<0<C4a1P0d
=3@3038b<P<0<30`0`0/;2`302@T90<06a/K0`0O7al40?Gem@<0moOg0`3emOD301/K6`<051@D1P0E
5AD30?7al@<0moOg0`3dm?@301dM7@<08B4Q100N7Qh301PH60<0mOGe0`3clo<3018B4P<051@D0`0H
61P30??cl`<0mOGe0`3_knl30?3`l0<0lO7a103fm_H30?3`l0<061PH1P0J6QX601`L70<0m?Cd0`3b
l_830>[ZjP<0hn?S103Ogml30>3Ph0<0i>CT0`3[jn/30>g]k@<0l_;b0`3dm?@30?Gem@H0m_Kf1P3e
mOD40??cl`<0lO7a0`3_knl30>g]k@<0k>c/0`3`l?030?;blP<06ATI0`0K6a/301PH60<04Q8B0`3/
k>`40>[ZjP<0k>c/0`0?3`l3014A4@<04a<C0`3dm?@60?ooo`030000003oool0oooo00D0oooo000X
0?ooo`030000003oool0oooo00D0oooo1P3dm?@301DE5@<05QHF0`0G5aL30?7al@<0l_;b0`3[jn/3
0>g]k@@0k>c/2@0B4Q8301@D50<04Q8B0`0H61P30?7al@<0lo?c0`3fm_H30?3`l0<061PH100C4a<6
01LG5`<05ADE1P0F5QH30?3`l0H0l_;b403clo<30?;blP<0lO7a0`3_knl30??cl`<0l?3`0`3bl_83
0?7al@<06QXJ0`0H61P4028R8P<0:b/[0`0a<C4603@d=0<0<S8b0`0`<30302`/;0<092@T0`0K6a/3
01lO7`@0mOGe0`3gmoL30?Gem@<06a/K0`0D51@601DE5@<0lO7a0`3gmoL30?Cdm0<07AdM0`0Q8B44
01hN7P<061PH0`3emOD30??cl`<04Q8B0`0D51@301PH60<0lo?c0`3emOD30>o_k`<0l?3`0`3alO44
0?KfmP<0l?3`0`0H61P601XJ6PH071`L0`3dm?@30?;blP<0j^[Z0`3Shn<40=oOg`<0h>3P0`3Ti>@3
0>_[j`<0kNg]0`3bl_830?Cdm0<0mOGe1P3fm_H60?Gem@@0lo?c0`3alO430>o_k`<0kNg]0`3/k>`3
0?3`l0<0l_;b0`0I6AT301/K6`<061PH0`0B4Q830>c/k0@0j^[Z0`3/k>`300l?3`<04A4A0`0C4a<3
0?Cdm0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool60?Cd
m0<05ADE1P0I6AT301hN7P<0lO7a0`0E5AD3014A4@@051@D0`0A4A43018B4P<04A4A0`0D51@301DE
5@<0kno_0`3fm_H30??cl`<0lO7a0`0I6AT301@D50@05aLG0`0E5AD601HF5P<0l?3`0`3alO430??c
l`<0l_;b0`3`l?030?;blPd0lo?c0`3bl_860?7al@<0k^k^0`0B4Q83014A4@<051@D0`0C4a<301TI
6@@07AdM0`0Q8B4602<S8`<092@T0`0U9BD302PX:0<0:b/[0`0/;2`302LW9`L07alO0`0K6a/301XJ
6PH05ADE0`0B4Q8301DE5@<0lo?c0`3dm?@301XJ6P<06a/K0`0T92@401lO7`<061PH0`3dm?@30?7a
l@<05ADE0`0D51@301HF5P<07AdM0`3clo<30?Gem@<0m?Cd0`3emOD40??cl`<071`L0`0H61P301lO
7`<092@T0`0R8R83020P80<0moOg0`3clo<30>g]k@<0j^[Z103Xj>P30>WYj@H0k>c/1P0C4a<301HF
5P`05aLG0`0E5AD401@D50<04Q8B0`0A4A43010@40<04A4A0`0D51@301XJ6P<06a/K0`0N7Qh301PH
60<04A4A0`3[jn/40>[ZjP<0jn_[0`0?3`l3018B4P<04a<C0`3dm?@60?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00D0oooo1P3dm?@301DE5@H06ATI0`0N7Qh30?7al@<0
5ADE0`0A4A4401@D50<04A4A0`0B4Q83014A4@<051@D0`0E5AD30>o_k`<0m_Kf0`3clo<30?7al@<0
6ATI0`0D51@401LG5`<05ADE1P0F5QH30?3`l0<0lO7a0`3clo<30?;blP<0l?3`0`3bl_8=0??cl`<0
l_;b1P3alO430>k^kP<04Q8B0`0A4A4301@D50<04a<C0`0I6AT401dM7@<08B4Q1P0S8b<302@T90<0
9BDU0`0X:2P302/[:`<0;2`/0`0W9bL701lO7`<06a/K0`0J6QX601DE5@<04Q8B0`0E5AD30??cl`<0
m?Cd0`0J6QX301/K6`<092@T100O7al301PH60<0m?Cd0`3alO4301DE5@<051@D0`0F5QH301dM7@<0
lo?c0`3emOD30?Cdm0<0mOGe103clo<301`L70<061PH0`0O7al302@T90<08R8R0`0P82030?Ogm`<0
lo?c0`3]kNd30>[ZjP@0j>SX0`3YjNT60>c/k0H04a<C0`0F5QH<01LG5`<05ADE100D51@3018B4P<0
4A4A0`0@4103014A4@<051@D0`0J6QX301/K6`<07QhN0`0H61P3014A4@<0jn_[103Zj^X30>_[j`<0
3`l?0`0B4Q8301<C4`<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`050?ooo`H0m?Cd0`0E5AD601TI6@<07QhN0`3alO4301DE5@<04A4A100D51@3014A4@<04Q8B
0`0A4A4301@D50<05ADE0`3_knl30?KfmP<0lo?c0`3alO4301TI6@<051@D100G5aL301DE5@H05QHF
0`3`l?030?7al@<0lo?c0`3bl_830?3`l0<0l_;b3@3clo<30?;blPH0lO7a0`3^k^h3018B4P<04A4A
0`0D51@301<C4`<06ATI100M7Ad3024Q8@H08b<S0`0T92@302DU9@<0:2PX0`0[:b/302`/;0<09bLW
1`0O7al301/K6`<06QXJ1P0E5AD3018B4P<05ADE0`3clo<30?Cdm0<06QXJ0`0K6a/302@T90@07alO
0`0H61P30?Cdm0<0lO7a0`0E5AD301@D50<05QHF0`0M7Ad30??cl`<0mOGe0`3dm?@30?Gem@@0lo?c
0`0L71`301PH60<07alO0`0T92@3028R8P<0820P0`3gmoL30??cl`<0kNg]0`3Zj^X40>SXj0<0jNWY
1P3/k>`601<C4`<05QHF300G5aL301DE5@@051@D0`0B4Q83014A4@<0410@0`0A4A4301@D50<06QXJ
0`0K6a/301hN7P<061PH0`0A4A430>_[j`@0j^[Z0`3[jn/300l?3`<04Q8B0`0C4a<30?Cdm0H0oooo
00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool30?Cdm0<0lo?c0`0D
51@301XJ6P<07alO0`0L71`301lO7`<05QHF0`0E5AD401<C4`<04A4A0`0C4a<301@D50<0kno_0`3b
l_830?KfmP<0kno_1P0F5QH301@D50<05ADE100C4a<301PH60<0lO7a0`3bl_830?Cdm0<0kno_0`3`
l?030>k^kP<04Q8B0`0@410:018B4P<04A4A0`0@410600h>3P<03`l?0`0=3@d300l?3`<0410@0`0E
5AD301HF5P@05aLG0`0H61P301TI6@H06QXJ0`0L71`6024Q8@<0:BTY0`0^;Rh302TY:@@08R8R0`0L
71`301LG5`<04a<C1P0D51@30>k^kP<0m_Kf0`3clo<301/K6`<08B4Q0`0W9bL4020P80<061PH1P3c
lo<30?3`l0<06ATI1P0K6a/301`L70<061PH1P0F5QH401XJ6P<06ATI0`0P820302DU9@<0:2PX0`0U
9BD301hN7P<071`L0`0E5AD3014A4@X03`l?0`0A4A4601@D50<061PH0`0J6QX601`L70<06a/K0`0J
6QX301PH60@05ADE0`0C4a<6014A4@<04Q8B0`0E5AD301TI6@<07AdM0`0L71`301@D50<03@d=1`3Y
jNT30>_[j`<03`l?0`0B4Q8301<C4`<0m?Cd1P3oool00`000000oooo0?ooo`050?ooo`00:03oool0
0`000000oooo0?ooo`050?ooo`<0m?Cd0`3clo<301@D50<06QXJ0`0O7al301`L70<07alO0`0F5QH3
01DE5@@04a<C0`0A4A4301<C4`<051@D0`3_knl30?;blP<0m_Kf0`3_knl601HF5P<051@D0`0E5AD4
01<C4`<061PH0`3alO430?;blP<0m?Cd0`3_knl30?3`l0<0k^k^0`0B4Q83010@40X04Q8B0`0A4A43
010@40H03Ph>0`0?3`l300d=3@<03`l?0`0@410301DE5@<05QHF100G5aL301PH60<06ATI1P0J6QX3
01`L70H08B4Q0`0Y:BT302h^;P<0:BTY100R8R8301`L70<05aLG0`0C4a<601@D50<0k^k^0`3fm_H3
0??cl`<06a/K0`0Q8B4302LW9`@0820P0`0H61P60??cl`<0l?3`0`0I6AT601/K6`<071`L0`0H61P6
01HF5P@06QXJ0`0I6AT3020P80<09BDU0`0X:2P302DU9@<07QhN0`0L71`301DE5@<04A4A2P0?3`l3
014A4@H051@D0`0H61P301XJ6PH071`L0`0K6a/301XJ6P<061PH100E5AD301<C4`H04A4A0`0B4Q83
01DE5@<06ATI0`0M7Ad301`L70<051@D0`0=3@d70>WYj@<0jn_[0`0?3`l3018B4P<04a<C0`3dm?@6
0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`3dm?@30??c
l`<051@D0`0J6QX301lO7`<071`L0`0O7al301HF5P<05ADE100C4a<3014A4@<04a<C0`0D51@30>o_
k`<0l_;b0`3fm_H30>o_k`H05QHF0`0D51@301DE5@@04a<C0`0H61P30?7al@<0l_;b0`3dm?@30>o_
k`<0l?3`0`3^k^h3018B4P<0410@2P0B4Q83014A4@<0410@1P0>3Ph300l?3`<03@d=0`0?3`l3010@
40<05ADE0`0F5QH401LG5`<061PH0`0I6AT601XJ6P<071`L1P0Q8B4302TY:@<0;Rh^0`0Y:BT4028R
8P<071`L0`0G5aL301<C4`H051@D0`3^k^h30?KfmP<0lo?c0`0K6a/3024Q8@<09bLW100P820301PH
60H0lo?c0`3`l?0301TI6@H06a/K0`0L71`301PH60H05QHF100J6QX301TI6@<0820P0`0U9BD302PX
:0<09BDU0`0N7Qh301`L70<05ADE0`0A4A4:00l?3`<04A4A1P0D51@301PH60<06QXJ1P0L71`301/K
6`<06QXJ0`0H61P401DE5@<04a<C1P0A4A43018B4P<05ADE0`0I6AT301dM7@<071`L0`0D51@300d=
3@L0jNWY0`3[jn/300l?3`<04Q8B0`0C4a<30?Cdm0H0oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool01@3oool30?Cdm0<0l_;b0`0F5QH301LG5`<07alO0`0P820301`L70<0
61PH2P0C4a<30>k^kP<0kno_0`3dm?@30?;blP<0lO7a0`0I6AT301<C4`<05ADE0`0D51@301DE5@@0
51@D0`3^k^h30?Gem@<0lO7a0`3^k^h3018B4P<0410@0`0B4Q83010@40<04A4A2P0B4Q83010@40<0
3Ph>0`0?3`l600h>3PH03`l?0`0B4Q830>o_k`<0lo?c103dm?@<0?Gem@<0m_Kf0`3emOD3028R8P<0
820P1P0Z:RX4024Q8@<061PH0`0F5QH301DE5@<0k^k^0`3`l?030?Gem@<0l?3`1P0J6QX302@T90<0
:2PX100Q8B4301TI6@<0lo?c0`3bl_830??cl`<05aLG0`0N7Qh302<S8`<0820P0`0K6a/301PH60<0
5QHF100G5aL301XJ6P<07AdM1P0P820301lO7`<071`L0`0H61P301DE5@<04a<C0`0B4Q84014A4@<0
4Q8B0`0C4a<301DE5@<05aLG0`0J6QX301/K6`H071`L0`0K6a/301PH60<05ADE100F5QH3018B4PH0
4A4A0`0B4Q8301DE5@<051@D0`0F5QH301<C4`<04A4A0`0<30`30>CTi0@0inOW0`3[jn/3010@40<0
4a<C0`0D51@30?Cdm0H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
1@3oool30?Cdm0<0l_;b0`0F5QH301LG5`<07alO0`0P820301`L70<061PH2P0C4a<30>k^kP<0kno_
0`3dm?@30?;blP<0lO7a0`0I6AT301<C4`<05ADE0`0D51@301DE5@@051@D0`3^k^h30?Gem@<0lO7a
0`3^k^h3018B4P<0410@0`0B4Q83010@40<04A4A2P0B4Q83010@40<03Ph>0`0?3`l600h>3PH03`l?
0`0B4Q830>o_k`<0lo?c103dm?@<0?Gem@<0m_Kf0`3emOD3028R8P<0820P1P0Z:RX4024Q8@<061PH
0`0F5QH301DE5@<0k^k^0`3`l?030?Gem@<0l?3`1P0J6QX302@T90<0:2PX100Q8B4301TI6@<0lo?c
0`3bl_830??cl`<05aLG0`0N7Qh302<S8`<0820P0`0K6a/301PH60<05QHF100G5aL301XJ6P<07AdM
1P0P820301lO7`<071`L0`0H61P301DE5@<04a<C0`0B4Q84014A4@<04Q8B0`0C4a<301DE5@<05aLG
0`0J6QX301/K6`H071`L0`0K6a/301PH60<05ADE100F5QH3018B4PH04A4A0`0B4Q8301DE5@<051@D
0`0F5QH301<C4`<04A4A0`0<30`30>CTi0@0inOW0`3[jn/3010@40<04a<C0`0D51@30?Cdm0H0oooo
00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool30?Cdm0<0l_;b0`0F
5QH301LG5`<07alO0`0P820301`L70<061PH2P0C4a<30>k^kP<0kno_0`3dm?@30?;blP<0lO7a0`0I
6AT301<C4`<05ADE0`0D51@301DE5@@051@D0`3^k^h30?Gem@<0lO7a0`3^k^h3018B4P<0410@0`0B
4Q83010@40<04A4A2P0B4Q83010@40<03Ph>0`0?3`l600h>3PH03`l?0`0B4Q830>o_k`<0lo?c103d
m?@<0?Gem@<0m_Kf0`3emOD3028R8P<0820P1P0Z:RX4024Q8@<061PH0`0F5QH301DE5@<0k^k^0`3`
l?030?Gem@<0l?3`1P0J6QX302@T90<0:2PX100Q8B4301TI6@<0lo?c0`3bl_830??cl`<05aLG0`0N
7Qh302<S8`<0820P0`0K6a/301PH60<05QHF100G5aL301XJ6P<07AdM1P0P820301lO7`<071`L0`0H
61P301DE5@<04a<C0`0B4Q84014A4@<04Q8B0`0C4a<301DE5@<05aLG0`0J6QX301/K6`H071`L0`0K
6a/301PH60<05ADE100F5QH3018B4PH04A4A0`0B4Q8301DE5@<051@D0`0F5QH301<C4`<04A4A0`0<
30`30>CTi0@0inOW0`3[jn/3010@40<04a<C0`0D51@30?Cdm0H0oooo00<000000?ooo`3oool01@3o
ool002P0oooo00<000000?ooo`3oool01@3oool30?7al@<0mOGe0`3`l?0301HF5P<061PH0`0I6AT6
01DE5@<051@D103]kNd30>k^kP<0lO7a0`3bl_830>g]k@<051@D0`0F5QH301DE5@<05aLG0`0C4a<3
01LG5`L0l?3`0`3clo<30>c/k0<04A4A0`0@410300h>3P<0410@0`0?3`l=01<C4`<04Q8B0`0@4103
014A4@<0kNg]1P3`l?060?7al@<0l?3`1P3clo<40?7al@T0lo?c0`3bl_830?7al@<0moOg0`3fm_H3
01lO7`H08R8R100H61P301XJ6PH0kno_0`3alO430?;blP<0k^k^0`0G5aL301@D50<06a/K0`0Q8B43
02DU9@@0820P0`0K6a/30?7al@H0lo?c0`0G5aL301hN7P<092@T0`0Q8B4601TI6@<05QHF100E5AD3
01HF5P<061PH1P0I6AT301PH60<05aLG0`0F5QH601@D50d04a<C0`0D51@301HF5P`05aLG0`0F5QH3
01<C4`<05ADE103_knl30?3`l0H0k^k^0`3_knl30>k^kP<04a<C0`0@4103018B4P<0jn_[0`3WinL3
0>KViP@0inOW0`3]kNd3018B4P<05ADE0`0G5aL30?7al@H0oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool01@3oool30?7al@<0mOGe0`3`l?0301HF5P<061PH0`0I6AT601DE
5@<051@D103]kNd30>k^kP<0lO7a0`3bl_830>g]k@<051@D0`0F5QH301DE5@<05aLG0`0C4a<301LG
5`L0l?3`0`3clo<30>c/k0<04A4A0`0@410300h>3P<0410@0`0?3`l=01<C4`<04Q8B0`0@4103014A
4@<0kNg]1P3`l?060?7al@<0l?3`1P3clo<40?7al@T0lo?c0`3bl_830?7al@<0moOg0`3fm_H301lO
7`H08R8R100H61P301XJ6PH0kno_0`3alO430?;blP<0k^k^0`0G5aL301@D50<06a/K0`0Q8B4302DU
9@@0820P0`0K6a/30?7al@H0lo?c0`0G5aL301hN7P<092@T0`0Q8B4601TI6@<05QHF100E5AD301HF
5P<061PH1P0I6AT301PH60<05aLG0`0F5QH601@D50d04a<C0`0D51@301HF5P`05aLG0`0F5QH301<C
4`<05ADE103_knl30?3`l0H0k^k^0`3_knl30>k^kP<04a<C0`0@4103018B4P<0jn_[0`3WinL30>KV
iP@0inOW0`3]kNd3018B4P<05ADE0`0G5aL30?7al@H0oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool01@3oool30?7al@<0mOGe0`3`l?0301HF5P<061PH0`0I6AT601DE5@<0
51@D103]kNd30>k^kP<0lO7a0`3bl_830>g]k@<051@D0`0F5QH301DE5@<05aLG0`0C4a<301LG5`L0
l?3`0`3clo<30>c/k0<04A4A0`0@410300h>3P<0410@0`0?3`l=01<C4`<04Q8B0`0@4103014A4@<0
kNg]1P3`l?060?7al@<0l?3`1P3clo<40?7al@T0lo?c0`3bl_830?7al@<0moOg0`3fm_H301lO7`H0
8R8R100H61P301XJ6PH0kno_0`3alO430?;blP<0k^k^0`0G5aL301@D50<06a/K0`0Q8B4302DU9@@0
820P0`0K6a/30?7al@H0lo?c0`0G5aL301hN7P<092@T0`0Q8B4601TI6@<05QHF100E5AD301HF5P<0
61PH1P0I6AT301PH60<05aLG0`0F5QH601@D50d04a<C0`0D51@301HF5P`05aLG0`0F5QH301<C4`<0
5ADE103_knl30?3`l0H0k^k^0`3_knl30>k^kP<04a<C0`0@4103018B4P<0jn_[0`3WinL30>KViP@0
inOW0`3]kNd3018B4P<05ADE0`0G5aL30?7al@H0oooo00<000000?ooo`3oool01@3oool002P0oooo
0`0000050?ooo`<05ADE1P3`l?0600h>3P<04a<C0`0D51@60>k^kP@0lO7a0`3`l?060>k^kP<05QHF
0`0B4Q8601HF5P<04a<C0`0G5aL30>k^kP<0lo?c103bl_830>_[j`<04A4A0`0<30`300d=3@<04Q8B
0`0@410301<C4`<0l?3`3@3clo<30?;blP<0kno_1P3bl_830>o_k`<0lO7a2@3bl_830>o_k`@04a<C
1P0A4A43010@40<03@d=0`0>3Ph30?;blP<0moOg0`0K6a/301`L70<061PH100J6QX30>k^kP<0lO7a
0`3`l?060>k^kP<05ADE0`0@410301<C4`<06QXJ0`0M7Ad301`L70@07AdM0`0G5aL301HF5P<0lO7a
0`3clo<301LG5`<07AdM0`0P820301TI6@<06a/K0`3bl_870??cl`<0m?Cd1P3emOD60?KfmPH0mOGe
5P3dm?@?0?Gem@<0m?Cd0`3clo<30?3`l0@0lO7a0`3^k^h60>c/k0<0kNg]0`3`l?030>k^kP<0l?3`
0`3^k^h30>o_k`<0j^[Z0`3Xj>P40>c/k0<0lO7a0`0E5AD301PH60H05ADE1@3oool2000000L0oooo
000X0?ooo`030000003oool0oooo00D0oooo0`0E5AD60?3`l0H03Ph>0`0C4a<301@D50H0k^k^103a
lO430?3`l0H0k^k^0`0F5QH3018B4PH05QHF0`0C4a<301LG5`<0k^k^0`3clo<40?;blP<0jn_[0`0A
4A4300`<30<03@d=0`0B4Q83010@40<04a<C0`3`l?0=0??cl`<0l_;b0`3_knl60?;blP<0kno_0`3a
lO490?;blP<0kno_100C4a<6014A4@<0410@0`0=3@d300h>3P<0l_;b0`3gmoL301/K6`<071`L0`0H
61P401XJ6P<0k^k^0`3alO430?3`l0H0k^k^0`0E5AD3010@40<04a<C0`0J6QX301dM7@<071`L100M
7Ad301LG5`<05QHF0`3alO430??cl`<05aLG0`0M7Ad3020P80<06ATI0`0K6a/30?;blPL0lo?c0`3d
m?@60?Gem@H0m_Kf1P3emODF0?Cdm0l0mOGe0`3dm?@30??cl`<0l?3`103alO430>k^kPH0k>c/0`3]
kNd30?3`l0<0k^k^0`3`l?030>k^kP<0kno_0`3Zj^X30>SXj0@0k>c/0`3alO4301DE5@<061PH1P0E
5AD60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0E5AD6
0?3`l0H03Ph>0`0C4a<301@D50H0k^k^103alO430?3`l0H0k^k^0`0F5QH3018B4PH05QHF0`0C4a<3
01LG5`<0k^k^0`3clo<40?;blP<0jn_[0`0A4A4300`<30<03@d=0`0B4Q83010@40<04a<C0`3`l?0=
0??cl`<0l_;b0`3_knl60?;blP<0kno_0`3alO490?;blP<0kno_100C4a<6014A4@<0410@0`0=3@d3
00h>3P<0l_;b0`3gmoL301/K6`<071`L0`0H61P401XJ6P<0k^k^0`3alO430?3`l0H0k^k^0`0E5AD3
010@40<04a<C0`0J6QX301dM7@<071`L100M7Ad301LG5`<05QHF0`3alO430??cl`<05aLG0`0M7Ad3
020P80<06ATI0`0K6a/30?;blPL0lo?c0`3dm?@60?Gem@H0m_Kf1P3emODF0?Cdm0l0mOGe0`3dm?@3
0??cl`<0l?3`103alO430>k^kPH0k>c/0`3]kNd30?3`l0<0k^k^0`3`l?030>k^kP<0kno_0`3Zj^X3
0>SXj0@0k>c/0`3alO4301DE5@<061PH1P0E5AD60?ooo`030000003oool0oooo00D0oooo000X0?oo
o`030000003oool0oooo00D0oooo0`0A4A430>k^kP<0j^[Z0`0:2PX300d=3@<0jn_[0`3^k^h60?7a
l@@0k^k^0`3]kNd601<C4`<04Q8B0`0D51@301<C4`H05ADE0`3_knl30?Cdm0<0kno_103]kNd3014A
4@<02PX:0`0?3`l3018B4P<0kno_0`3bl_830?7al@<0mOGe0`3alO4=0??cl`H0l_;b0`3_knl301@D
50<04A4A0`0B4Q8601<C4`<05ADE100A4A43018B4P<0410@0`0=3@d300h>3P<03`l?0`3clo<30?Cd
m0<06QXJ0`0G5aL301HF5P@0kno_0`3alO430?3`l0<0j^[Z1P0B4Q83010@40<03`l?0`0E5AD30?7a
l@<0lo?c0`0L71`701LG5`<04a<C0`3clo<30?Cdm0<05QHF0`0J6QX301TI6@<071`L0`3`l?030?Cd
m0<0l_;b103`l?030?;blPH0m?Cd2@3emODO0?Cdm0H0mOGe1P3dm?@30??cl`<0lO7a103_knl30>k^
kPT0kNg]0`3_knl90?7al@<0kno_1P3^k^h40?;blP<0m?Cd1P0L71`301PH60<04A4A1P3oool00`00
0000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<04A4A0`3^k^h30>[ZjP<0
2PX:0`0=3@d30>_[j`<0k^k^1P3alO440>k^kP<0kNg]1P0C4a<3018B4P<051@D0`0C4a<601DE5@<0
kno_0`3dm?@30>o_k`@0kNg]0`0A4A4300X:2P<03`l?0`0B4Q830>o_k`<0l_;b0`3alO430?Gem@<0
lO7a3@3clo<60?;blP<0kno_0`0D51@3014A4@<04Q8B1P0C4a<301DE5@@04A4A0`0B4Q83010@40<0
3@d=0`0>3Ph300l?3`<0lo?c0`3dm?@301XJ6P<05aLG0`0F5QH40>o_k`<0lO7a0`3`l?030>[ZjPH0
4Q8B0`0@410300l?3`<05ADE0`3alO430??cl`<071`L1`0G5aL301<C4`<0lo?c0`3dm?@301HF5P<0
6QXJ0`0I6AT301`L70<0l?3`0`3dm?@30?;blP@0l?3`0`3bl_860?Cdm0T0mOGe7`3dm?@60?Gem@H0
m?Cd0`3clo<30?7al@@0kno_0`3^k^h90>g]k@<0kno_2@3alO430>o_k`H0k^k^103bl_830?Cdm0H0
71`L0`0H61P3014A4@H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
1@3oool3014A4@<0k^k^0`3Zj^X300X:2P<03@d=0`3[jn/30>k^kPH0lO7a103^k^h30>g]k@H04a<C
0`0B4Q8301@D50<04a<C1P0E5AD30>o_k`<0m?Cd0`3_knl40>g]k@<04A4A0`0:2PX300l?3`<04Q8B
0`3_knl30?;blP<0lO7a0`3emOD30?7al@d0lo?c1P3bl_830>o_k`<051@D0`0A4A43018B4PH04a<C
0`0E5AD4014A4@<04Q8B0`0@410300d=3@<03Ph>0`0?3`l30??cl`<0m?Cd0`0J6QX301LG5`<05QHF
103_knl30?7al@<0l?3`0`3Zj^X6018B4P<0410@0`0?3`l301DE5@<0lO7a0`3clo<301`L70L05aLG
0`0C4a<30??cl`<0m?Cd0`0F5QH301XJ6P<06ATI0`0L71`30?3`l0<0m?Cd0`3bl_840?3`l0<0l_;b
1P3dm?@90?GemAl0m?Cd1P3emOD60?Cdm0<0lo?c0`3alO440>o_k`<0k^k^2@3]kNd30>o_k`T0lO7a
0`3_knl60>k^kP@0l_;b0`3dm?@601`L70<061PH0`0A4A460?ooo`030000003oool0oooo00D0oooo
000X0?ooo`030000003oool0oooo00D0oooo0`0A4A430>k^kP<0j^[Z0`0:2PX300d=3@<0jn_[0`3^
k^h60?7al@@0k^k^0`3]kNd601<C4`<04Q8B0`0D51@301<C4`H05ADE0`3_knl30?Cdm0<0kno_103]
kNd3014A4@<02PX:0`0?3`l3018B4P<0kno_0`3bl_830?7al@<0mOGe0`3alO4=0??cl`H0l_;b0`3_
knl301@D50<04A4A0`0B4Q8601<C4`<05ADE100A4A43018B4P<0410@0`0=3@d300h>3P<03`l?0`3c
lo<30?Cdm0<06QXJ0`0G5aL301HF5P@0kno_0`3alO430?3`l0<0j^[Z1P0B4Q83010@40<03`l?0`0E
5AD30?7al@<0lo?c0`0L71`701LG5`<04a<C0`3clo<30?Cdm0<05QHF0`0J6QX301TI6@<071`L0`3`
l?030?Cdm0<0l_;b103`l?030?;blPH0m?Cd2@3emODO0?Cdm0H0mOGe1P3dm?@30??cl`<0lO7a103_
knl30>k^kPT0kNg]0`3_knl90?7al@<0kno_1P3^k^h40?;blP<0m?Cd1P0L71`301PH60<04A4A1P3o
ool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<04A4A0`3[jn/3
0>SXj0<0h^;R0`3Vi^H30>k^kP<0k>c/0`3_knl30>k^kPL04a<C0`0A4A43018B4P<04A4A0`0D51@3
01DE5@<0l?3`0`3bl_830?KfmP<0k^k^0`0C4a<4010@40<02`/;0`0B4Q830>g]k@<0l?3`0`3dm?@3
0?3`l0<0l_;b0`3`l?0301@D50<04Q8B2P0C4a<3018B4P<04a<C0`0E5AD301<C4`H051@D1P0C4a<3
018B4P@04A4A0`0D51@3010@40<04Q8B0`3_knl30??cl`<0l_;b0`0K6a/301DE5@<051@D0`0E5AD4
0>o_k`<0l?3`0`3Zj^X301<C4`<0410@0`0B4Q8300l?3`<04Q8B0`3YjNT30>k^kPH0l?3`100F5QH3
01DE5@<051@D1P3dm?@301DE5@<05aLG0`0J6QX30??cl`<0m?Cd0`3^k^h30>c/k0@04A4A0`0@4103
018B4SL051@D0`0C4a<3018B4P@04A4A300@4106014A4@H04Q8B1P0C4a<301@D50@05aLG0`0M7Ad3
01hN7P<0820P0`0I6AT3014A4@H0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool01@3oool3014A4@<0jn_[0`3Xj>P30>;RhP<0i^KV0`3^k^h30>c/k0<0kno_0`3^k^h701<C
4`<04A4A0`0B4Q83014A4@<051@D0`0E5AD30?3`l0<0l_;b0`3fm_H30>k^kP<04a<C100@410300/;
2`<04Q8B0`3]kNd30?3`l0<0m?Cd0`3`l?030?;blP<0l?3`0`0D51@3018B4PX04a<C0`0B4Q8301<C
4`<05ADE0`0C4a<601@D50H04a<C0`0B4Q84014A4@<051@D0`0@4103018B4P<0kno_0`3clo<30?;b
lP<06a/K0`0E5AD301@D50<05ADE103_knl30?3`l0<0j^[Z0`0C4a<3010@40<04Q8B0`0?3`l3018B
4P<0jNWY0`3^k^h60?3`l0@05QHF0`0E5AD301@D50H0m?Cd0`0E5AD301LG5`<06QXJ0`3clo<30?Cd
m0<0k^k^0`3/k>`4014A4@<0410@0`0B4Q8g01@D50<04a<C0`0B4Q84014A4@`0410@1P0A4A46018B
4PH04a<C0`0D51@401LG5`<07AdM0`0N7Qh3020P80<06ATI0`0A4A460?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00D0oooo0`0A4A430>_[j`<0j>SX0`3Rh^830>KViP<0
k^k^0`3/k>`30>o_k`<0k^k^1`0C4a<3014A4@<04Q8B0`0A4A4301@D50<05ADE0`3`l?030?;blP<0
m_Kf0`3^k^h301<C4`@0410@0`0;2`/3018B4P<0kNg]0`3`l?030?Cdm0<0l?3`0`3bl_830?3`l0<0
51@D0`0B4Q8:01<C4`<04Q8B0`0C4a<301DE5@<04a<C1P0D51@601<C4`<04Q8B100A4A4301@D50<0
410@0`0B4Q830>o_k`<0lo?c0`3bl_8301/K6`<05ADE0`0D51@301DE5@@0kno_0`3`l?030>[ZjP<0
4a<C0`0@4103018B4P<03`l?0`0B4Q830>WYj@<0k^k^1P3`l?0401HF5P<05ADE0`0D51@60?Cdm0<0
5ADE0`0G5aL301XJ6P<0lo?c0`3dm?@30>k^kP<0k>c/100A4A43010@40<04Q8B=`0D51@301<C4`<0
4Q8B100A4A4<010@40H04A4A1P0B4Q8601<C4`<051@D100G5aL301dM7@<07QhN0`0P820301TI6@<0
4A4A1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`050?ooo`<03Ph>
0`3WinL30>;RhPH0hN7Q0`3Shn<300`<30<03Ph>0`0D51@401<C4`<051@D0`0B4Q8601<C4`<0k^k^
0`3`l?030?Gem@H0l_;b0`0H61P3014A4@@03`l?0`0D51@30>g]k@<0m?Cd0`3`l?030>k^kP<04Q8B
0`0A4A4301DE5@<04a<C1`0D51@301<C4`H04Q8B0`0C4a<601@D50<04a<C0`0F5QH301<C4`<04Q8B
0`0A4A4401<C4`<0kno_0`3alO430?3`l0<0m_Kf0`3alO4301TI6@<051@D0`0F5QH301@D50<0kno_
103alO430>k^kP<04Q8B0`0@410301<C4`<0410@0`0B4Q830>OWi`<0jNWY0`3Ti>@30>SXj0<0k^k^
100B4Q8601<C4`H0m?Cd0`0D51@301DE5@<05aLG0`3fm_H30?3`l0X03@d=0`0@4103018B4P<04a<C
=00D51@601<C4aH04Q8B0`0C4a<301@D50<05QHF0`0H61P301XJ6P@071`L0`0O7al3028R8P<07alO
0`0F5QH300h>3PH0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3o
ool300h>3P<0inOW0`3Rh^860>7Qh@<0hn?S0`0<30`300h>3P<051@D100C4a<301@D50<04Q8B1P0C
4a<30>k^kP<0l?3`0`3emOD60?;blP<061PH0`0A4A4400l?3`<051@D0`3]kNd30?Cdm0<0l?3`0`3^
k^h3018B4P<04A4A0`0E5AD301<C4`L051@D0`0C4a<6018B4P<04a<C1P0D51@301<C4`<05QHF0`0C
4a<3018B4P<04A4A100C4a<30>o_k`<0lO7a0`3`l?030?KfmP<0lO7a0`0I6AT301@D50<05QHF0`0D
51@30>o_k`@0lO7a0`3^k^h3018B4P<0410@0`0C4a<3010@40<04Q8B0`3WinL30>WYj@<0i>CT0`3X
j>P30>k^kP@04Q8B1P0C4a<60?Cdm0<051@D0`0E5AD301LG5`<0m_Kf0`3`l?0:00d=3@<0410@0`0B
4Q8301<C4c@051@D1P0C4a<F018B4P<04a<C0`0D51@301HF5P<061PH0`0J6QX401`L70<07alO0`0R
8R8301lO7`<05QHF0`0>3Ph60?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0
oooo00D0oooo0`0>3Ph30>OWi`<0h^;R1P3QhN430>?Sh`<030`<0`0>3Ph301@D50@04a<C0`0D51@3
018B4PH04a<C0`3^k^h30?3`l0<0mOGe1P3bl_8301PH60<04A4A100?3`l301@D50<0kNg]0`3dm?@3
0?3`l0<0k^k^0`0B4Q83014A4@<05ADE0`0C4a<701@D50<04a<C1P0B4Q8301<C4`H051@D0`0C4a<3
01HF5P<04a<C0`0B4Q83014A4@@04a<C0`3_knl30?7al@<0l?3`0`3fm_H30?7al@<06ATI0`0D51@3
01HF5P<051@D0`3_knl40?7al@<0k^k^0`0B4Q83010@40<04a<C0`0@4103018B4P<0inOW0`3YjNT3
0>CTi0<0j>SX0`3^k^h4018B4PH04a<C1P3dm?@301@D50<05ADE0`0G5aL30?KfmP<0l?3`2P0=3@d3
010@40<04Q8B0`0C4a<d01@D50H04a<C5P0B4Q8301<C4`<051@D0`0F5QH301PH60<06QXJ100L71`3
01lO7`<08R8R0`0O7al301HF5P<03Ph>1P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`050?ooo`<030`<0`3Ph>030=cLg0<0e=CD0`061PH300P820<030`<0`0C4a<301@D
50@05QHF0`0B4Q8301HF5PH0k^k^0`3alO430??cl`<0kno_0`0G5aL301PH60<05aLG0`0F5QH401@D
50<0l?3`0`3dm?@30>c/k0H04A4A0`0?3`l3014A4@<04Q8B0`0C4a<3018B4P@05ADE0`0B4Q86014A
4@T04Q8B0`0D51@30?3`l0H0l_;b0`3alO440?3`l0<0l_;b0`3clo<60?7al@<06ATI0`0D51@301HF
5P<04a<C0`0D51@30?3`l0@0lo?c0`3_knl601<C4`<04A4A0`0C4a<30>SXj0<0j^[Z0`3Shn<30>3P
h0<0iNGU0`3[jn/4010@40<04Q8B0`0C4a<60??cl`<04A4A0`0C4a<301LG5`<0lo?c0`3bl_8300h>
3P<03@d=100@4103018B4P<04a<C?@0D51@=01<C4`T04Q8B0`0C4a<301HF5P<051@D0`0H61P301XJ
6P@071`L0`0M7Ad301`L70<061PH0`0?3`l300`<30H0oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool01@3oool300`<30<0h>3P0`3Lg=`30=CDe0<01PH60`0820P300`<30<0
4a<C0`0D51@401HF5P<04Q8B0`0F5QH60>k^kP<0lO7a0`3clo<30>o_k`<05aLG0`0H61P301LG5`<0
5QHF100D51@30?3`l0<0m?Cd0`3/k>`6014A4@<03`l?0`0A4A43018B4P<04a<C0`0B4Q8401DE5@<0
4Q8B1P0A4A49018B4P<051@D0`3`l?060?;blP<0lO7a103`l?030?;blP<0lo?c1P3alO4301TI6@<0
51@D0`0F5QH301<C4`<051@D0`3`l?040??cl`<0kno_1P0C4a<3014A4@<04a<C0`3Xj>P30>[ZjP<0
hn?S0`3Ph>030>GUi@<0jn_[100@4103018B4P<04a<C1P3clo<3014A4@<04a<C0`0G5aL30??cl`<0
l_;b0`0>3Ph300d=3@@0410@0`0B4Q8301<C4cd051@D3@0C4a<9018B4P<04a<C0`0F5QH301@D50<0
61PH0`0J6QX401`L70<07AdM0`0L71`301PH60<03`l?0`0<30`60?ooo`030000003oool0oooo00D0
oooo000:0?ooo`H00000103oool4000000D0oooo100000070?ooo`030000003oool0oooo00D0oooo
0`0<30`30>3Ph0<0g=cL0`3De=@300H61P<020P80`0<30`301<C4`<051@D100F5QH3018B4P<05QHF
1P3^k^h30?7al@<0lo?c0`3_knl301LG5`<061PH0`0G5aL301HF5P@051@D0`3`l?030?Cdm0<0k>c/
1P0A4A4300l?3`<04A4A0`0B4Q8301<C4`<04Q8B100E5AD3018B4PH04A4A2@0B4Q8301@D50<0l?3`
1P3bl_830?7al@@0l?3`0`3bl_830??cl`H0lO7a0`0I6AT301@D50<05QHF0`0C4a<301@D50<0l?3`
103clo<30>o_k`H04a<C0`0A4A4301<C4`<0j>SX0`3Zj^X30>?Sh`<0h>3P0`3UiND30>_[j`@0410@
0`0B4Q8301<C4`H0lo?c0`0A4A4301<C4`<05aLG0`3clo<30?;blP<03Ph>0`0=3@d4010@40<04Q8B
0`0C4a<m01@D50d04a<C2@0B4Q8301<C4`<05QHF0`0D51@301PH60<06QXJ100L71`301dM7@<071`L
0`0H61P300l?3`<030`<1P3oool00`000000oooo0?ooo`050?ooo`002P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`H0h>3P0`3Hf=P30=gMg@<0
h^;R0`3]kNd30?7al@<0lo?c0`0I6AT4014A4@<05ADE0`3/k>`30?7al@<0l?3`0`3_knl30?3`l0<0
6ATI0`0G5aL301dM7@<07QhN1`0G5aL30?;blP<0l?3`0`0A4A4300d=3@<03Ph>0`0A4A46010@40<0
3`l?0`0B4Q840>k^kP<0l?3`0`3_knl30?3`l0<0lO7a1P3bl_830?3`l0H0lo?c0`3`l?030?7al@L0
l_;b0`3`l?0601DE5@<04a<C0`0E5AD301<C4`<05aLG0`3_knl30?Gem@@0k^k^0`0G5aL301<C4`<0
4Q8B0`0E5AD30>[ZjP<0kNg]0`3YjNT30>7Qh@<0gmoO0`3Xj>P30>c/k0@03`l?0`0B4Q8301<C4`<0
lo?c0`3alO4301<C4`<04A4A0`0C4a<301TI6@<0lO7a0`3clo<30?;blPL0lo?c1P3dm?@d0?GemA00
m?Cd1P3clo<30?;blPH0lO7a0`3_knl301DE5@<04a<C0`0F5QH701LG5`<05ADE0`0A4A4300h>3P<0
h>3P1P3oool00`000000oooo0?ooo`050?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool60>3Ph0<0f=SH0`3MgMd30>;RhP<0kNg]0`3alO430??cl`<0
6ATI100A4A4301DE5@<0k>c/0`3alO430?3`l0<0kno_0`3`l?0301TI6@<05aLG0`0M7Ad301hN7PL0
5aLG0`3bl_830?3`l0<04A4A0`0=3@d300h>3P<04A4A1P0@410300l?3`<04Q8B103^k^h30?3`l0<0
kno_0`3`l?030?7al@H0l_;b0`3`l?060??cl`<0l?3`0`3alO470?;blP<0l?3`1P0E5AD301<C4`<0
5ADE0`0C4a<301LG5`<0kno_0`3emOD40>k^kP<05aLG0`0C4a<3018B4P<05ADE0`3Zj^X30>g]k@<0
jNWY0`3QhN430=oOg`<0j>SX0`3/k>`400l?3`<04Q8B0`0C4a<30??cl`<0lO7a0`0C4a<3014A4@<0
4a<C0`0I6AT30?7al@<0lo?c0`3bl_870??cl`H0m?Cd=03emOD@0?Cdm0H0lo?c0`3bl_860?7al@<0
kno_0`0E5AD301<C4`<05QHF1`0G5aL301DE5@<04A4A0`0>3Ph30>3Ph0H0oooo00<000000?ooo`3o
ool01@3oool000`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo1P3Ph>030=SHf0<0gMgM0`3Rh^830>g]k@<0lO7a0`3clo<301TI6@@04A4A0`0E5AD30>c/k0<0
lO7a0`3`l?030>o_k`<0l?3`0`0I6AT301LG5`<07AdM0`0N7Qh701LG5`<0l_;b0`3`l?03014A4@<0
3@d=0`0>3Ph3014A4@H0410@0`0?3`l3018B4P@0k^k^0`3`l?030>o_k`<0l?3`0`3alO460?;blP<0
l?3`1P3clo<30?3`l0<0lO7a1`3bl_830?3`l0H05ADE0`0C4a<301DE5@<04a<C0`0G5aL30>o_k`<0
mOGe103^k^h301LG5`<04a<C0`0B4Q8301DE5@<0j^[Z0`3]kNd30>WYj@<0hN7Q0`3Ogml30>SXj0<0
k>c/100?3`l3018B4P<04a<C0`3clo<30?7al@<04a<C0`0A4A4301<C4`<06ATI0`3alO430??cl`<0
l_;b1`3clo<60?Cdm3@0mOGe403dm?@60??cl`<0l_;b1P3alO430>o_k`<05ADE0`0C4a<301HF5PL0
5aLG0`0E5AD3014A4@<03Ph>0`3Ph>060?ooo`030000003oool0oooo00D0oooo000=0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0103oool400000?l0ooooN`3oool3000000L0oooo000>0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooogh0oooo00<000000?ooo`3o
ool01@3oool000X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0o`3ooomn0?ooo`030000003oool0oooo00D0oooo000:0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooOP3oool00`000000oooo0?ooo`05
0?ooo`002`3oool4000000D0oooo100000050?ooo`@000001`3oool00`000000oooo0?ooo`3o0?oo
ogh0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool002P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`00:03ooooo0000088000001`3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-252.193, -243.32, 1.62465, \
1.62465}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[TextData[{
  StyleBox["NDSolve", "MR"],
  " also now has the ability to solve index 1 systems of \
differential-algebraic equations (DAEs).  Just as with ODEs and PDEs, all you \
have to do is put in the equations and NDSolve figures out when it needs to \
use the DAE solver."
}], "Text"],

Cell["\<\
Here is an index 1 system of DAEs (due to Robertson) modelling chemical \
kinetics. The problem involves 2 DEs and a material balance equation.\
\>", "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"DEs", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(x'\)[t] \[Equal] \(-x[t]\)/25 + 10\^4\ y[t]\ z[t]\)},
              {\(\(y'\)[t] \[Equal] 
                  x[t]/25 - 10^4\ y[t]\ z[t] - 3\ 10\^7\ y[t]\^2\)}
              }], ")"}]}], ";"}]], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \(\(bal\  = \ x[t] + y[t] + z[t] \[Equal] 1;\)\)], "Input",
  CellLabel->"In[76]:="],

Cell["This solves the DAEs.", "MathCaption"],

Cell[BoxData[
    \(sol\  = \ 
      First[NDSolve[{DEs, \ bal, \ x[0] \[Equal] 1, y[0] \[Equal] 0}, {x, y, 
            z}, {t, 0, 4\ 10\^4}]]\)], "Input",
  CellLabel->"In[77]:=",
  CellTags->{"b:1", "ndsg:0"}],

Cell["\<\
When NDSolve detected the equation bal without any derivative terms, it \
recognized the system as being a DAE and used the appropriate solver which is \
based on the IDA package.\
\>", "Text"],

Cell["\<\
This makes a plot showing how well the algebraic condition was satisfied.\
\>", "MathCaption",
  CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}],

Cell[BoxData[
    \(\(Plot[Evaluate[x[t] + y[t] + z[t]\  - \ 1\  /. \ %], {t, 0, 40000}, \ 
        PlotRange \[Rule] All];\)\)], "Input",
  CellLabel->"In[78]:=",
  CellTags->{"b:1", "ndsg:0"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell["\<\
As a final example, to demonstrate the flexibility of NDSolve, I give an \
example of how you can add a simple method to NDSolve.  In principle, with \
this mechanism, it will be possible to add specialized methods for particular \
types of equations.\
\>", "Text"],

Cell["\<\
This defines a method function to take a single step towards integrating an \
ODE using the classical fourth order RungeKutta method.  Since the method is \
so simple, it is not necessary to save any private data.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(CRK4[]\)["\<Step\>"[rhs_, \ t_, \ h_, \ y_, \ yp_]]\  := 
      Module[{k0, k1, k2, k3}, \[IndentingNewLine]k0 = 
          h\ yp; \[IndentingNewLine]k1 = 
          h\ rhs[t + h/2, y + k0/2]; \[IndentingNewLine]k2 = 
          h\ rhs[t + h/2, y + k1/2]; \[IndentingNewLine]k3 = 
          h\ rhs[t + h, 
              y + k2]; \[IndentingNewLine]{h, \ \((k0 + 2\ \ k1 + 2\ \ k2 + 
                k3)\)/6}]\)], "Input",
  CellLabel->"In[12]:="],

Cell["\<\
This defines a method function so that NDSolve can obtain the proper \
difference order to use for the method.  The ___ template is used because the \
difference order for the method is always 4.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(CRK4[___]\)["\<DifferenceOrder\>"[]]\  := \ 4\)], "Input",
  CellLabel->"In[13]:="],

Cell["\<\
This defines a method function for the step mode so that NDSolve will know \
how to control time steps.  This algorithm method does not \
\>", "MathCaption"],

Cell[BoxData[
    \(\(CRK4[___]\)["\<Stepmode\>"[]]\  := \ Fixed\)], "Input",
  CellLabel->"In[14]:="],

Cell["\<\
This integrates the simple harmonic oscillator equation with fixed step size.\
\
\>", "MathCaption"],

Cell[BoxData[
    \(fixed\  = \ 
      NDSolve[{\(x''\)[t]\  + \ x[t]\  \[Equal] \ 0, \ 
          x[0]\  \[Equal] \ 1, \ \(x'\)[0]\  \[Equal] \ 0}, 
        x, {t, 0, 2\ \[Pi]}, \ Method \[Rule] CRK4]\)], "Input",
  CellLabel->"In[15]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[TextData[{
  "Generally using a fixed step size is less efficient than allowing the step \
size to vary with the local difficulty of the integration.  Most ",
  StyleBox["NDSolve", "MR"],
  " methods have error estimators which makes it possible to very efficiently \
determine appropriate step sizes.  However, for methods without good error \
estimators, an alternative is to use built in step controller methods which \
use extrapolation.  The method ",
  StyleBox["DoubleStep", "MR"],
  " uses an extrapolation based on integrating a time step with a single step \
of size h and two steps of size h/2. "
}], "Text"],

Cell["\<\
The more sophisticated step controller needs to have some additional method \
properties set.  This indicates that the method is not symmetric and is \
explicit.\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(\(CRK4[___]\)["\<SymmetricMethodQ\>"[]]\  := \ 
        False;\)\), "\[IndentingNewLine]", 
    \(\(\(CRK4[___]\)["\<StiffMethodQ\>"[]]\  := \ 
        False;\)\), "\[IndentingNewLine]", 
    \(\(\(CRK4[___]\)["\<LinearStabilityBoundary\>"[]]\  := \ \
\(-2.8\);\)\)}], "Input",
  CellLabel->"In[83]:="],

Cell[TextData[{
  "This integrates the simple harmonic oscillator using the classical fourth \
order Runge-Kutta method with steps controlled by using the ",
  StyleBox["DoubleStep", "MR"],
  " method."
}], "MathCaption"],

Cell[BoxData[
    \(dstep\  = \ 
      NDSolve[{\(x''\)[t]\  + \ x[t]\  \[Equal] \ 0, \ 
          x[0]\  \[Equal] \ 1, \ \(x'\)[0]\  \[Equal] \ 0}, 
        x, {t, 0, 2\ \[Pi]}, \ 
        Method \[Rule] {DoubleStep, \ Method \[Rule] CRK4}]\)], "Input",
  CellLabel->"In[86]:="],

Cell["\<\
This makes a plot comparing the error in the computed solutions at the step \
ends.  The error for the DoubleStep method is shown in blue.\
\>", "MathCaption",
  CellTags->"LastSlide"],

Cell[BoxData[{
    \(\(ploterror[{sol_}, \ opts___]\  := \ 
        Module[{\[IndentingNewLine]points\  = \ 
              x@Coordinates[1]\  /. \ sol, \ \[IndentingNewLine]values\  = \ 
              x@ValuesOnGrid[]\  /. \ sol}, \ \[IndentingNewLine]ListPlot[
            Transpose[{points, \ values\  - \ Cos[points]}], \ 
            opts]\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\(Show[
        Block[{$DisplayFunction\  = \ 
              Identity}, {\[IndentingNewLine]ploterror[
              fixed], \[IndentingNewLine]ploterror[dstep, \ 
              PlotStyle \[Rule] 
                RGBColor[0, 0, 1]]\[IndentingNewLine]}]];\)\)}], "Input",
  CellLabel->"In[87]:="]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
ScreenStyleEnvironment->"SlideShow",
WindowSize->{1016, 696},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.5,
StyleDefinitions -> "New In 5.0 Style.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "NDSolve"->{
    Cell[4020, 116, 1854, 41, 172, "2ColumnTable",
      CellTags->{"NDSolve", "S0.1634"}],
    Cell[5877, 159, 1258, 45, 57, "Notes",
      CellTags->{"S0.1634", "NDSolve"}],
    Cell[7138, 206, 2622, 58, 232, "2ColumnTable",
      CellTags->{"NDSolve", "S0.1634"}],
    Cell[9763, 266, 125, 3, 34, "Notes",
      CellTags->{"S0.1634", "NDSolve"}],
    Cell[9891, 271, 2337, 52, 228, "2ColumnTable",
      CellTags->{"NDSolve", "S0.1634"}]},
  "S0.1634"->{
    Cell[4020, 116, 1854, 41, 172, "2ColumnTable",
      CellTags->{"NDSolve", "S0.1634"}],
    Cell[5877, 159, 1258, 45, 57, "Notes",
      CellTags->{"S0.1634", "NDSolve"}],
    Cell[7138, 206, 2622, 58, 232, "2ColumnTable",
      CellTags->{"NDSolve", "S0.1634"}],
    Cell[9763, 266, 125, 3, 34, "Notes",
      CellTags->{"S0.1634", "NDSolve"}],
    Cell[9891, 271, 2337, 52, 228, "2ColumnTable",
      CellTags->{"NDSolve", "S0.1634"}]},
  "b:1"->{
    Cell[10686670, 261191, 212, 5, 77, "Input",
      CellTags->{"b:1", "ndsg:0"}],
    Cell[10687091, 261204, 153, 3, 43, "MathCaption",
      CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}],
    Cell[10687247, 261209, 194, 4, 77, "Input",
      CellTags->{"b:1", "ndsg:0"}]},
  "ndsg:0"->{
    Cell[10686670, 261191, 212, 5, 77, "Input",
      CellTags->{"b:1", "ndsg:0"}],
    Cell[10687091, 261204, 153, 3, 43, "MathCaption",
      CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}],
    Cell[10687247, 261209, 194, 4, 77, "Input",
      CellTags->{"b:1", "ndsg:0"}]},
  "S3.9.7"->{
    Cell[10687091, 261204, 153, 3, 43, "MathCaption",
      CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}]},
  "7.16"->{
    Cell[10687091, 261204, 153, 3, 43, "MathCaption",
      CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}]},
  "LastSlide"->{
    Cell[10694324, 261405, 194, 4, 64, "MathCaption",
      CellTags->"LastSlide"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"NDSolve", 10695924, 261445},
  {"S0.1634", 10696382, 261456},
  {"b:1", 10696836, 261467},
  {"ndsg:0", 10697127, 261474},
  {"S3.9.7", 10697418, 261481},
  {"7.16", 10697539, 261484},
  {"LastSlide", 10697665, 261487}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 1594, 41, 20, "SlideShowNavigationBar"],

Cell[CellGroupData[{
Cell[3373, 96, 26, 0, 76, "Section"],
Cell[3402, 98, 472, 10, 113, "Text"],
Cell[3877, 110, 140, 4, 38, "Text"],
Cell[4020, 116, 1854, 41, 172, "2ColumnTable",
  CellTags->{"NDSolve", "S0.1634"}],
Cell[5877, 159, 1258, 45, 57, "Notes",
  CellTags->{"S0.1634", "NDSolve"}],
Cell[7138, 206, 2622, 58, 232, "2ColumnTable",
  CellTags->{"NDSolve", "S0.1634"}],
Cell[9763, 266, 125, 3, 34, "Notes",
  CellTags->{"S0.1634", "NDSolve"}],
Cell[9891, 271, 2337, 52, 228, "2ColumnTable",
  CellTags->{"NDSolve", "S0.1634"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12265, 328, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[13862, 371, 194, 4, 62, "Text"],
Cell[14059, 377, 103, 2, 43, "MathCaption"],
Cell[14165, 381, 84, 2, 51, "Input"],
Cell[14252, 385, 55, 0, 43, "MathCaption"],
Cell[14310, 387, 1918, 36, 363, "Input"],
Cell[16231, 425, 461, 10, 115, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16729, 440, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[18326, 483, 62, 0, 43, "MathCaption"],
Cell[18391, 485, 256, 5, 77, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18684, 495, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[20281, 538, 102, 3, 37, "Text"],
Cell[20386, 543, 99, 2, 43, "MathCaption"],
Cell[20488, 547, 1899, 44, 180, "Input"],
Cell[22390, 593, 106, 2, 43, "MathCaption"],
Cell[22499, 597, 304, 5, 118, "Input"],
Cell[22806, 604, 45, 0, 43, "MathCaption"],

Cell[CellGroupData[{
Cell[22876, 608, 1118, 21, 319, "Input",
  Evaluatable->False],
Cell[23997, 631, 327, 5, 57, "Message"],
Cell[24327, 638, 419, 6, 82, "Message"],
Cell[24749, 646, 419, 6, 82, "Message"],
Cell[25171, 654, 708, 10, 182, "Message"],
Cell[25882, 666, 843, 20, 107, "Output"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26774, 692, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[28371, 735, 70, 0, 43, "MathCaption"],

Cell[CellGroupData[{
Cell[28466, 739, 425, 10, 129, "Input",
  Evaluatable->False],
Cell[28894, 751, 10325904, 255857, 372, 9994008, 251754, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[10354813, 256611, 57, 0, 38, "MathCaption"],

Cell[CellGroupData[{
Cell[10354895, 256615, 242, 5, 77, "Input",
  Evaluatable->False],
Cell[10355140, 256622, 328914, 4491, 453, 33501, 839, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10684103, 261119, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[10685700, 261162, 294, 6, 88, "Text"],
Cell[10685997, 261170, 174, 3, 65, "MathCaption"],
Cell[10686174, 261175, 341, 8, 76, "Input"],
Cell[10686518, 261185, 102, 2, 51, "Input"],
Cell[10686623, 261189, 44, 0, 43, "MathCaption"],
Cell[10686670, 261191, 212, 5, 77, "Input",
  CellTags->{"b:1", "ndsg:0"}],
Cell[10686885, 261198, 203, 4, 62, "Text"],
Cell[10687091, 261204, 153, 3, 43, "MathCaption",
  CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}],
Cell[10687247, 261209, 194, 4, 77, "Input",
  CellTags->{"b:1", "ndsg:0"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10687478, 261218, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[10689075, 261261, 275, 5, 87, "Text"],
Cell[10689353, 261268, 244, 4, 65, "MathCaption"],
Cell[10689600, 261274, 467, 9, 181, "Input"],
Cell[10690070, 261285, 226, 4, 65, "MathCaption"],
Cell[10690299, 261291, 105, 2, 51, "Input"],
Cell[10690407, 261295, 167, 3, 65, "MathCaption"],
Cell[10690577, 261300, 102, 2, 51, "Input"],
Cell[10690682, 261304, 110, 3, 43, "MathCaption"],
Cell[10690795, 261309, 239, 5, 77, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10691071, 261319, 1594, 41, 20, "SlideShowNavigationBar"],
Cell[10692668, 261362, 624, 11, 139, "Text"],
Cell[10693295, 261375, 192, 4, 65, "MathCaption"],
Cell[10693490, 261381, 325, 7, 103, "Input"],
Cell[10693818, 261390, 221, 5, 66, "MathCaption"],
Cell[10694042, 261397, 279, 6, 77, "Input"],
Cell[10694324, 261405, 194, 4, 64, "MathCaption",
  CellTags->"LastSlide"],
Cell[10694521, 261411, 695, 13, 259, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

